/*
 * In a generated replay, this file is partially common, boilerplate code
 * included in every replay, and partially generated replay code. The following
 * header applies to the boilerplate code. A comment indicating "Auto-generated
 * below this comment" marks the separation between these two parts.
 *
 * Copyright (C) 2011, 2012 Purdue University
 * Written by Gregor Richards
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

(function() {
    // global eval alias
    var geval = eval;

    // detect if we're in a browser or not
    var inbrowser = false;
    var inharness = false;
    if (typeof window !== "undefined" && "document" in window) {
        inbrowser = true;
        if (window.parent && "JSBNG_handleResult" in window.parent) {
            inharness = true;
        }
    } else if (typeof global !== "undefined") {
        window = global;
        window.top = window;
    } else {
        window = (function() { return this; })();
        window.top = window;
    }

    if ("console" in window) {
        window.JSBNG_Console = window.console;
    }

    var callpath = [];

    // global state
    var JSBNG_Replay = window.top.JSBNG_Replay = {
        push: function(arr, fun) {
            arr.push(fun);
            return fun;
        },

        path: function(str) {
            verifyPath(str);
        }
    };

    // the actual replay runner
    function onload() {
        try {
            delete window.onload;
        } catch (ex) {}

        var jr = JSBNG_Replay$;
        var cb = function() {
            var end = new Date().getTime();

            var msg = "Time: " + (end - st) + "ms";
    
            if (inharness) {
                window.parent.JSBNG_handleResult({error:false, time:(end - st)});
            } else if (inbrowser) {
                var res = document.createElement("div");
    
                res.style.position = "fixed";
                res.style.left = "1em";
                res.style.top = "1em";
                res.style.width = "35em";
                res.style.height = "5em";
                res.style.padding = "1em";
                res.style.backgroundColor = "white";
                res.style.color = "black";
                res.appendChild(document.createTextNode(msg));
    
                document.body.appendChild(res);
            } else if (typeof console !== "undefined") {
                console.log(msg);
            } else if (typeof print !== "undefined") {
                // hopefully not the browser print() function :)
                print(msg);
            }
        };

        // force it to JIT
        jr(false);

        // then time it
        var st = new Date().getTime();
        while (jr !== null) {
            jr = jr(true, cb);
        }
    }

    // add a frame at replay time
    function iframe(pageid) {
        var iw;
        if (inbrowser) {
            // represent the iframe as an iframe (of course)
            var iframe = document.createElement("iframe");
            iframe.style.display = "none";
            document.body.appendChild(iframe);
            iw = iframe.contentWindow;
            iw.document.write("<script type=\"text/javascript\">Function.prototype.bind = null; var JSBNG_Replay_geval = eval;</script>");
            iw.document.close();
        } else {
            // no general way, just lie and do horrible things
            var topwin = window;
            (function() {
                var window = {};
                window.window = window;
                window.top = topwin;
                window.JSBNG_Replay_geval = function(str) {
                    eval(str);
                }
                iw = window;
            })();
        }
        return iw;
    }

    // called at the end of the replay stuff
    function finalize() {
        if (inbrowser) {
            setTimeout(onload, 0);
        } else {
            onload();
        }
    }

    // verify this recorded value and this replayed value are close enough
    function verify(rep, rec) {
        if (rec !== rep &&
            (rep === rep || rec === rec) /* NaN test */) {
            if (typeof rec !== "object" || rec === null ||
                !(("__JSBNG_unknown_" + typeof(rep)) in rec)) {
                return false;
            }
        }
        return true;
    }

    // general message
    var firstMessage = true;
    function replayMessage(msg) {
        if (inbrowser) {
            if (firstMessage)
                document.open();
            firstMessage = false;
            document.write(msg);
        } else {
            console.log(msg);
        }
    }

    // complain when there's an error
    function verificationError(msg) {
        if (inharness) {
            window.parent.JSBNG_handleResult({error:true, msg: msg});
        } else replayMessage(msg);
        throw new Error();
    }

    // to verify a set
    function verifySet(objstr, obj, prop, gvalstr, gval) {
        if (/^on/.test(prop)) {
            // these aren't instrumented compatibly
            return;
        }

        if (!verify(obj[prop], gval)) {
            var bval = obj[prop];
            var msg = "Verification failure! " + objstr + "." + prop + " is not " + gvalstr + ", it's " + bval + "!";
            verificationError(msg);
        }
    }

    // to verify a call or new
    function verifyCall(iscall, func, cthis, cargs) {
        var ok = true;
        var callArgs = func.callArgs[func.inst];
        iscall = iscall ? 1 : 0;
        if (cargs.length !== callArgs.length - 1) {
            ok = false;
        } else {
            if (iscall && !verify(cthis, callArgs[0])) ok = false;
            for (var i = 0; i < cargs.length; i++) {
                if (!verify(cargs[i], callArgs[i+1])) ok = false;
            }
        }
        if (!ok) {
            var msg = "Call verification failure!";
            verificationError(msg);
        }

        return func.returns[func.inst++];
    }

    // to verify the callpath
    function verifyPath(func) {
        var real = callpath.shift();
        if (real !== func) {
            var msg = "Call path verification failure! Expected " + real + ", found " + func;
            verificationError(msg);
        }
    }

    // figure out how to define getters
    var defineGetter;
    if (Object.defineProperty) {
        var odp = Object.defineProperty;
        defineGetter = function(obj, prop, getter) {
            odp(obj, prop, {"enumerable": true, "get": getter, "set": function(){}});
        };
    } else if (Object.prototype.__defineGetter__) {
        var opdg = Object.prototype.__defineGetter__;
        var opds = Object.prototype.__defineSetter__;
        defineGetter = function(obj, prop, getter) {
            opdg.call(obj, prop, getter);
            opds.call(obj, prop, function(){});
        };
    } else {
        defineGetter = function() {
            verificationError("This replay requires getters for correct behavior, and your JS engine appears to be incapable of defining getters. Sorry!");
        };
    }

    // for calling events
    var fpc = Function.prototype.call;

// resist the urge, don't put a })(); here!
/******************************************************************************
 * Auto-generated below this comment
 *****************************************************************************/
var ow33216266 = window;
var f33216266_0;
var o0;
var o1;
var f33216266_4;
var f33216266_7;
var f33216266_12;
var f33216266_13;
var f33216266_14;
var f33216266_15;
var o2;
var o3;
var f33216266_75;
var f33216266_162;
var f33216266_279;
var f33216266_430;
var o4;
var f33216266_432;
var f33216266_433;
var f33216266_435;
var f33216266_436;
var f33216266_438;
var o5;
var f33216266_441;
var f33216266_443;
var o6;
var f33216266_450;
var o7;
var f33216266_455;
var f33216266_456;
var o8;
var o9;
var o10;
var f33216266_476;
var o11;
var fo33216266_477_firstChild;
var f33216266_480;
var o12;
var fo33216266_486_firstChild;
var o13;
var o14;
var o15;
var o16;
var o17;
var o18;
var o19;
var fo33216266_585_firstChild;
var o20;
var f33216266_603;
var o21;
var fo33216266_431___FB_TOKEN;
var o22;
var f33216266_606;
var f33216266_607;
var o23;
var f33216266_609;
var o24;
var fo33216266_611_className;
var fo33216266_611___FB_TOKEN;
var o25;
var fo33216266_483___FB_TOKEN;
var o26;
var f33216266_623;
var o27;
var o28;
var o29;
var o30;
var o31;
var o32;
var o33;
var o34;
var o35;
var o36;
var o37;
var o38;
var o39;
var f33216266_638;
var o40;
var o41;
var o42;
var o43;
var o44;
var o45;
var o46;
var o47;
var f33216266_664;
var f33216266_665;
var f33216266_667;
var f33216266_668;
var o48;
var o49;
var o50;
var o51;
var o52;
var f33216266_749;
var f33216266_751;
var f33216266_752;
var f33216266_755;
var f33216266_758;
JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1 = [];
JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_136 = [];
JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_84 = [];
JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_139 = [];
JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_14 = [];
JSBNG_Replay.sec3f7c0a188503295a66a797eaa3892a5e54bc0e_273 = [];
JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_28 = [];
JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_140 = [];
// 1
// record generated by JSBench 0e049915c07b at 2012-08-13T15:33:09.793Z
// 2
// 3
f33216266_0 = function() { return f33216266_0.returns[f33216266_0.inst++]; };
f33216266_0.returns = [];
f33216266_0.inst = 0;
// 4
ow33216266.JSBNG__Date = f33216266_0;
// 5
o0 = {};
// 6
ow33216266.JSBNG__document = o0;
// 7
o1 = {};
// 8
ow33216266.JSBNG__sessionStorage = o1;
// 11
f33216266_4 = function() { return f33216266_4.returns[f33216266_4.inst++]; };
f33216266_4.returns = [];
f33216266_4.inst = 0;
// 12
ow33216266.JSBNG__getComputedStyle = f33216266_4;
// 17
f33216266_7 = function() { return f33216266_7.returns[f33216266_7.inst++]; };
f33216266_7.returns = [];
f33216266_7.inst = 0;
// 18
ow33216266.JSBNG__addEventListener = f33216266_7;
// 19
ow33216266.JSBNG__top = ow33216266;
// 24
ow33216266.JSBNG__scrollX = 0;
// 25
ow33216266.JSBNG__scrollY = 0;
// 30
f33216266_12 = function() { return f33216266_12.returns[f33216266_12.inst++]; };
f33216266_12.returns = [];
f33216266_12.inst = 0;
// 31
ow33216266.JSBNG__setTimeout = f33216266_12;
// 32
f33216266_13 = function() { return f33216266_13.returns[f33216266_13.inst++]; };
f33216266_13.returns = [];
f33216266_13.inst = 0;
// 33
ow33216266.JSBNG__setInterval = f33216266_13;
// 34
f33216266_14 = function() { return f33216266_14.returns[f33216266_14.inst++]; };
f33216266_14.returns = [];
f33216266_14.inst = 0;
// 35
ow33216266.JSBNG__clearTimeout = f33216266_14;
// 36
f33216266_15 = function() { return f33216266_15.returns[f33216266_15.inst++]; };
f33216266_15.returns = [];
f33216266_15.inst = 0;
// 37
ow33216266.JSBNG__clearInterval = f33216266_15;
// 42
ow33216266.JSBNG__frames = ow33216266;
// 45
ow33216266.JSBNG__self = ow33216266;
// 46
o2 = {};
// 47
ow33216266.JSBNG__navigator = o2;
// 62
ow33216266.JSBNG__closed = false;
// 65
ow33216266.JSBNG__opener = null;
// 66
ow33216266.JSBNG__defaultStatus = "";
// 67
o3 = {};
// 68
ow33216266.JSBNG__location = o3;
// 69
ow33216266.JSBNG__innerWidth = 1280;
// 70
ow33216266.JSBNG__innerHeight = 709;
// 71
ow33216266.JSBNG__outerWidth = 1280;
// 72
ow33216266.JSBNG__outerHeight = 771;
// 73
ow33216266.JSBNG__screenX = 0;
// 74
ow33216266.JSBNG__screenY = 0;
// 75
ow33216266.JSBNG__pageXOffset = 0;
// 76
ow33216266.JSBNG__pageYOffset = 0;
// 131
ow33216266.JSBNG__screenLeft = 0;
// 136
ow33216266.JSBNG__clientInformation = o2;
// 139
ow33216266.JSBNG__defaultstatus = "";
// 152
ow33216266.JSBNG__devicePixelRatio = 1;
// 157
ow33216266.JSBNG__offscreenBuffering = true;
// 158
ow33216266.JSBNG__screenTop = 0;
// 175
f33216266_75 = function() { return f33216266_75.returns[f33216266_75.inst++]; };
f33216266_75.returns = [];
f33216266_75.inst = 0;
// 176
ow33216266.JSBNG__Image = f33216266_75;
// 177
ow33216266.JSBNG__name = "";
// 184
ow33216266.JSBNG__status = "";
// 351
f33216266_162 = function() { return f33216266_162.returns[f33216266_162.inst++]; };
f33216266_162.returns = [];
f33216266_162.inst = 0;
// 352
ow33216266.JSBNG__Document = f33216266_162;
// 585
f33216266_279 = function() { return f33216266_279.returns[f33216266_279.inst++]; };
f33216266_279.returns = [];
f33216266_279.inst = 0;
// 586
ow33216266.JSBNG__Event = f33216266_279;
// 631
ow33216266.JSBNG__XMLDocument = f33216266_162;
// 852
ow33216266.JSBNG__TEMPORARY = 0;
// 853
ow33216266.JSBNG__PERSISTENT = 1;
// 890
f33216266_430 = function() { return f33216266_430.returns[f33216266_430.inst++]; };
f33216266_430.returns = [];
f33216266_430.inst = 0;
// 891
ow33216266.Math.JSBNG__random = f33216266_430;
// 892
// 896
o4 = {};
// 897
o0.documentElement = o4;
// 899
o4.className = "no_js";
// 900
// 901
f33216266_432 = function() { return f33216266_432.returns[f33216266_432.inst++]; };
f33216266_432.returns = [];
f33216266_432.inst = 0;
// 902
f33216266_0.now = f33216266_432;
// 903
f33216266_432.returns.push(1344872059108);
// 904
// 905
// 906
f33216266_433 = function() { return f33216266_433.returns[f33216266_433.inst++]; };
f33216266_433.returns = [];
f33216266_433.inst = 0;
// 907
o0.JSBNG__addEventListener = f33216266_433;
// 908
o2.userAgent = "Mozilla/5.0 (X11; Linux i686 (x86_64)) AppleWebKit/535.16 (KHTML, like Gecko) Chrome/18.0.999.0 Safari/535.16";
// undefined
o2 = null;
// 910
f33216266_433.returns.push(undefined);
// 912
o3.protocol = "http:";
// 914
f33216266_432.returns.push(1344872059117);
// 915
o2 = {};
// 916
f33216266_0.returns.push(o2);
// 917
f33216266_435 = function() { return f33216266_435.returns[f33216266_435.inst++]; };
f33216266_435.returns = [];
f33216266_435.inst = 0;
// 918
o2.toGMTString = f33216266_435;
// undefined
o2 = null;
// 919
f33216266_435.returns.push("Mon, 20 Aug 2012 15:34:19 GMT");
// 920
o3.hostname = "www.facebook.com";
// 921
o0.cookie = "c_user=100001812504199; act=1344872054923\u00252F1\u00253A2";
// 923
f33216266_432.returns.push(1344872059118);
// 924
f33216266_436 = function() { return f33216266_436.returns[f33216266_436.inst++]; };
f33216266_436.returns = [];
f33216266_436.inst = 0;
// 925
o1.getItem = f33216266_436;
// 926
f33216266_436.returns.push("1;1");
// 927
o2 = {};
// 937
o3.search = "?sk=nf";
// 938
o0.domain = "www.facebook.com";
// 940
// 941
o3.href = "http://www.facebook.com/?sk=nf";
// undefined
o3 = null;
// 943
// 944
// 945
// 946
o4.JSBNG__addEventListener = f33216266_433;
// 948
f33216266_433.returns.push(undefined);
// 979
o0.documentMode = void 0;
// 981
f33216266_438 = function() { return f33216266_438.returns[f33216266_438.inst++]; };
f33216266_438.returns = [];
f33216266_438.inst = 0;
// 982
o0.getElementsByTagName = f33216266_438;
// 983
o3 = {};
// 984
f33216266_438.returns.push(o3);
// 985
o3.length = 1;
// 986
o5 = {};
// 987
o3["0"] = o5;
// undefined
o3 = null;
// 988
f33216266_441 = function() { return f33216266_441.returns[f33216266_441.inst++]; };
f33216266_441.returns = [];
f33216266_441.inst = 0;
// 989
o0.createDocumentFragment = f33216266_441;
// 990
o3 = {};
// 991
f33216266_441.returns.push(o3);
// 992
f33216266_443 = function() { return f33216266_443.returns[f33216266_443.inst++]; };
f33216266_443.returns = [];
f33216266_443.inst = 0;
// 993
o5.appendChild = f33216266_443;
// 994
f33216266_443.returns.push(o3);
// undefined
o3 = null;
// 998
o3 = {};
// 999
f33216266_441.returns.push(o3);
// 1001
f33216266_443.returns.push(o3);
// undefined
o3 = null;
// 1006
o3 = {};
// 1007
f33216266_438.returns.push(o3);
// 1008
o3.length = 3;
// 1009
o6 = {};
// 1010
o3["0"] = o6;
// 1011
o6.rel = "alternate";
// undefined
o6 = null;
// 1013
o6 = {};
// 1014
o3["1"] = o6;
// 1015
o6.rel = "stylesheet";
// 1017
o6.href = "http://static.ak.fbcdn.net/rsrc.php/v2/y_/r/9yVXpo8C3LO.css";
// undefined
o6 = null;
// 1020
o6 = {};
// 1021
o3["2"] = o6;
// undefined
o3 = null;
// 1022
o6.rel = "shortcut icon";
// undefined
o6 = null;
// 1026
o4.clientWidth = 1265;
// 1028
// 1032
f33216266_433.returns.push(undefined);
// 1034
f33216266_433.returns.push(undefined);
// 1041
f33216266_432.returns.push(1344872059170);
// 1046
f33216266_432.returns.push(1344872059171);
// 1049
f33216266_432.returns.push(1344872059171);
// 1053
f33216266_432.returns.push(1344872059172);
// 1055
f33216266_432.returns.push(1344872059172);
// 1059
o3 = {};
// 1060
f33216266_441.returns.push(o3);
// 1062
f33216266_443.returns.push(o3);
// undefined
o3 = null;
// 1064
f33216266_432.returns.push(1344872059173);
// 1067
f33216266_432.returns.push(1344872059174);
// 1069
f33216266_432.returns.push(1344872059174);
// 1074
f33216266_432.returns.push(1344872059175);
// 1077
f33216266_432.returns.push(1344872059175);
// 1081
f33216266_432.returns.push(1344872059175);
// 1082
f33216266_450 = function() { return f33216266_450.returns[f33216266_450.inst++]; };
f33216266_450.returns = [];
f33216266_450.inst = 0;
// 1083
o0.getElementById = f33216266_450;
// 1084
o3 = {};
// 1085
f33216266_450.returns.push(o3);
// 1087
o6 = {};
// 1088
f33216266_450.returns.push(o6);
// 1089
o7 = {};
// 1090
o6.firstChild = o7;
// 1092
o7.nodeType = 8;
// 1094
o7.nodeValue = " <div class=\"clearfix fbxWelcomeBox\"><a class=\"fbxWelcomeBoxBlock -cx-PRIVATE-uiImageBlock__image -cx-PRIVATE-uiImageBlock__mediumImage lfloat\" href=\"http://www.facebook.com/javascript.testengineer\" aria-hidden=\"true\"><img class=\"fbxWelcomeBoxImg img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-ash2/275624_100001812504199_1255023530_q.jpg\" id=\"profile_pic_welcome_100001812504199\" alt=\"\" /></a><div class=\"-cx-PRIVATE-uiImageBlock__content \"><div class=\"-cx-PRIVATE-uiInlineBlock__root prs\"><div class=\"-cx-PRIVATE-uiInlineBlock__root -cx-PRIVATE-uiInlineBlock__middle\" style=\"height:40px\"></div><div class=\"-cx-PRIVATE-uiInlineBlock__root -cx-PRIVATE-uiInlineBlock__middle\"><a class=\"fbxWelcomeBoxName\" href=\"http://www.facebook.com/javascript.testengineer\">JavaScript TestEngineer</a></div></div></div></div> ";
// undefined
o7 = null;
// 1095
o7 = {};
// 1096
o6.parentNode = o7;
// 1097
f33216266_455 = function() { return f33216266_455.returns[f33216266_455.inst++]; };
f33216266_455.returns = [];
f33216266_455.inst = 0;
// 1098
o7.removeChild = f33216266_455;
// 1099
f33216266_455.returns.push(o6);
// undefined
o6 = null;
// 1100
// 1101
f33216266_456 = function() { return f33216266_456.returns[f33216266_456.inst++]; };
f33216266_456.returns = [];
f33216266_456.inst = 0;
// 1102
o3.getAttribute = f33216266_456;
// undefined
o3 = null;
// 1103
f33216266_456.returns.push("pagelet_welcome_box");
// 1105
f33216266_432.returns.push(1344872059180);
// 1109
o3 = {};
// 1110
f33216266_441.returns.push(o3);
// 1112
f33216266_443.returns.push(o3);
// undefined
o3 = null;
// 1114
f33216266_432.returns.push(1344872059181);
// 1116
f33216266_432.returns.push(1344872059181);
// 1121
f33216266_432.returns.push(1344872059182);
// 1125
o3 = {};
// 1126
f33216266_441.returns.push(o3);
// 1128
f33216266_443.returns.push(o3);
// undefined
o3 = null;
// 1131
f33216266_432.returns.push(1344872059183);
// 1135
f33216266_432.returns.push(1344872059183);
// 1137
o3 = {};
// 1138
f33216266_450.returns.push(o3);
// 1140
o6 = {};
// 1141
f33216266_450.returns.push(o6);
// 1142
o8 = {};
// 1143
o6.firstChild = o8;
// 1145
o8.nodeType = 8;
// 1147
o8.nodeValue = " <div role=\"navigation\" class=\"uiFutureSideNav\" data-gt=\"&#123;&quot;ref&quot;:&quot;bookmarks&quot;&#125;\" id=\"sideNav\"><div id=\"pagelet_pinned_nav\"></div><div id=\"pagelet_bookmark_nav\"></div></div> ";
// undefined
o8 = null;
// 1148
o6.parentNode = o7;
// 1150
f33216266_455.returns.push(o6);
// undefined
o6 = null;
// 1151
// 1152
o3.getAttribute = f33216266_456;
// 1153
f33216266_456.returns.push("pagelet_navigation");
// 1155
f33216266_432.returns.push(1344872059187);
// 1159
o6 = {};
// 1160
f33216266_441.returns.push(o6);
// 1162
f33216266_443.returns.push(o6);
// undefined
o6 = null;
// 1164
f33216266_432.returns.push(1344872059187);
// 1166
f33216266_432.returns.push(1344872059187);
// 1171
f33216266_432.returns.push(1344872059193);
// 1175
o6 = {};
// 1176
f33216266_441.returns.push(o6);
// 1178
f33216266_443.returns.push(o6);
// undefined
o6 = null;
// 1181
f33216266_432.returns.push(1344872059194);
// 1185
f33216266_432.returns.push(1344872059194);
// 1187
o6 = {};
// 1188
f33216266_450.returns.push(o6);
// 1190
o8 = {};
// 1191
f33216266_450.returns.push(o8);
// 1192
o9 = {};
// 1193
o8.firstChild = o9;
// 1195
o9.nodeType = 8;
// 1197
o9.nodeValue = " <script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function e1146df452b7e9c946cbb8402d7d8716264600333(event) {\\u000a    Bootloader.loadComponents([\\\"Composer\\\",\\\"DataSource\\\",], function() {\\u000a        JSCC.get(\\\"j3nzBkZS6GmXveoreu0\\\");\\u000a    });\\u000a};\"), (\"s46e1e0cc50cb783c0fcd8225d2566275ad9bef32\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction e1146df452b7e9c946cbb8402d7d8716264600333(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s46e1e0cc50cb783c0fcd8225d2566275ad9bef32_0\"), (s46e1e0cc50cb783c0fcd8225d2566275ad9bef32_0_instance), (this), (arguments)))\n    };\n    (null);\n    (((JSBNG_Record.get)(Bootloader, (\"loadComponents\")))[(\"loadComponents\")])([\"Composer\",\"DataSource\",], ((function() {\n        var s46e1e0cc50cb783c0fcd8225d2566275ad9bef32_1_instance;\n        ((s46e1e0cc50cb783c0fcd8225d2566275ad9bef32_1_instance) = ((JSBNG_Record.eventInstance)((\"s46e1e0cc50cb783c0fcd8225d2566275ad9bef32_1\"))));\n        return ((JSBNG_Record.markFunction)((function() {\n            if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n                return ((JSBNG_Record.eventCall)((arguments.callee), (\"s46e1e0cc50cb783c0fcd8225d2566275ad9bef32_1\"), (s46e1e0cc50cb783c0fcd8225d2566275ad9bef32_1_instance), (this), (arguments)))\n            };\n            (null);\n            (((JSBNG_Record.get)(JSCC, (\"get\")))[(\"get\")])(\"j3nzBkZS6GmXveoreu0\");\n        })));\n    })()));\n};\nvar s46e1e0cc50cb783c0fcd8225d2566275ad9bef32_0_instance;\n((s46e1e0cc50cb783c0fcd8225d2566275ad9bef32_0_instance) = ((JSBNG_Record.eventInstance)((\"s46e1e0cc50cb783c0fcd8225d2566275ad9bef32_0\"))));\n((JSBNG_Record.markFunction)((e1146df452b7e9c946cbb8402d7d8716264600333)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><div class=\"uiComposer uiComposerHideContent stat_elem uiMetaComposer fbComposerWideSpacing uiComposerOpen uiComposerHideContent uiComposerWhiteMessageBox\" onclick=\"return e1146df452b7e9c946cbb8402d7d8716264600333.call(this, event);\" id=\"uq3j16_6\"><div class=\"focus_target child_was_focused\"><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function ef78d6703c780391a39276e85de860fa69b9b5d2a(event) {\\u000a    return Event.__inlineSubmit(this, event);\\u000a};\"), (\"s7329e2dd45c8ab229048a2a39f01085aa9c91610\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction ef78d6703c780391a39276e85de860fa69b9b5d2a(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s7329e2dd45c8ab229048a2a39f01085aa9c91610_0\"), (s7329e2dd45c8ab229048a2a39f01085aa9c91610_0_instance), (this), (arguments)))\n    };\n    (null);\n    return (((JSBNG_Record.get)(JSBNG__Event, (\"__inlineSubmit\")))[(\"__inlineSubmit\")])(this, JSBNG__event);\n};\nvar s7329e2dd45c8ab229048a2a39f01085aa9c91610_0_instance;\n((s7329e2dd45c8ab229048a2a39f01085aa9c91610_0_instance) = ((JSBNG_Record.eventInstance)((\"s7329e2dd45c8ab229048a2a39f01085aa9c91610_0\"))));\n((JSBNG_Record.markFunction)((ef78d6703c780391a39276e85de860fa69b9b5d2a)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><form rel=\"async\" class=\"attachmentSelectForm clearfix\" action=\"/\" method=\"get\" onsubmit=\"return ef78d6703c780391a39276e85de860fa69b9b5d2a.call(this, event);\" id=\"uq3j16_14\"><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function e37eedd735b6223abdc2d7425b795705c8374c815(event) {\\u000a    var el = ((event.target || event.srcElement)), a = Parent.byClass(el, \\\"uiComposerAttachment\\\");\\u000a    if (!a) {\\u000a        return;\\u000a    }\\u000a;\\u000a    var b = (window.DOM && DOM.find(a, \\\"a\\\")), f = Parent.byTag(a, \\\"form\\\");\\u000a    f.action = a.getAttribute(\\\"data-endpoint\\\");\\u000a    (b && f.setAttribute(\\\"data-gt\\\", b.getAttribute(\\\"data-gt\\\")));\\u000a    f.xhpc.value = a.id;\\u000a    f.xhpc.click();\\u000a};\"), (\"s60dbadcf7d61f3837479b8f382fd47650f7e39c3\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction e37eedd735b6223abdc2d7425b795705c8374c815(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s60dbadcf7d61f3837479b8f382fd47650f7e39c3_0\"), (s60dbadcf7d61f3837479b8f382fd47650f7e39c3_0_instance), (this), (arguments)))\n    };\n    (null);\n    var el = (((((JSBNG_Record.get)(JSBNG__event, (\"target\")))[(\"target\")]) || (((JSBNG_Record.get)(JSBNG__event, (\"srcElement\")))[(\"srcElement\")]))), a = (((JSBNG_Record.get)(Parent, (\"byClass\")))[(\"byClass\")])(el, \"uiComposerAttachment\");\n    if (!a) {\n        return;\n    }\n    ;\n    var b = ((((JSBNG_Record.get)(window, (\"DOM\")))[(\"DOM\")]) && (((JSBNG_Record.get)(DOM, (\"JSBNG__find\")))[(\"JSBNG__find\")])(a, \"a\")), f = (((JSBNG_Record.get)(Parent, (\"byTag\")))[(\"byTag\")])(a, \"form\");\n    ((JSBNG_Record.set)(f, (\"action\"), (((JSBNG_Record.get)(a, (\"getAttribute\")))[(\"getAttribute\")])(\"data-endpoint\")));\n    (b && (((JSBNG_Record.get)(f, (\"setAttribute\")))[(\"setAttribute\")])(\"data-gt\", (((JSBNG_Record.get)(b, (\"getAttribute\")))[(\"getAttribute\")])(\"data-gt\")));\n    ((JSBNG_Record.set)((((JSBNG_Record.get)(f, (\"xhpc\")))[(\"xhpc\")]), (\"value\"), (((JSBNG_Record.get)(a, (\"id\")))[(\"id\")])));\n    (((JSBNG_Record.get)((((JSBNG_Record.get)(f, (\"xhpc\")))[(\"xhpc\")]), (\"click\")))[(\"click\")])();\n};\nvar s60dbadcf7d61f3837479b8f382fd47650f7e39c3_0_instance;\n((s60dbadcf7d61f3837479b8f382fd47650f7e39c3_0_instance) = ((JSBNG_Record.eventInstance)((\"s60dbadcf7d61f3837479b8f382fd47650f7e39c3_0\"))));\n((JSBNG_Record.markFunction)((e37eedd735b6223abdc2d7425b795705c8374c815)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><ul class=\"uiList uiListHorizontal clearfix uiComposerAttachments\" onclick=\"return e37eedd735b6223abdc2d7425b795705c8374c815.call(this, event);\"><li class=\"uiListItem  uiListHorizontalItemBorder uiListHorizontalItem\"><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function e196434646ab30cd94113f04a485d44e3c13d2332(event) {\\u000a    var c;\\u000a    var root = Parent.byClass(this, \\\"uiComposer\\\");\\u000a    if (((window.Composer && (c = Composer.getInstance(this))) && !CSS.hasClass(this, \\\"uiComposerAttachmentSelected\\\"))) {\\u000a        c.reset(true);\\u000a    }\\u000a;\\u000a    CSS.addClass(this, \\\"uiComposerAttachmentSelected\\\");\\u000a    CSS.addClass(root, \\\"uiComposerOpen\\\");\\u000a    Bootloader.loadComponents(\\\"dom\\\", function() {\\u000a        DOM.find(root, \\\"textarea.mentionsTextarea\\\").focus();\\u000a    });\\u000a    CSS.removeClass.curry(root, \\\"async_saving\\\").defer();\\u000a};\"), (\"s1391419701277983b55eb3c9d16f6025748e7c6d\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction e196434646ab30cd94113f04a485d44e3c13d2332(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s1391419701277983b55eb3c9d16f6025748e7c6d_0\"), (s1391419701277983b55eb3c9d16f6025748e7c6d_0_instance), (this), (arguments)))\n    };\n    (null);\n    var c;\n    var root = (((JSBNG_Record.get)(Parent, (\"byClass\")))[(\"byClass\")])(this, \"uiComposer\");\n    if ((((((JSBNG_Record.get)(window, (\"Composer\")))[(\"Composer\")]) && (c = (((JSBNG_Record.get)(Composer, (\"getInstance\")))[(\"getInstance\")])(this))) && !(((JSBNG_Record.get)(CSS, (\"hasClass\")))[(\"hasClass\")])(this, \"uiComposerAttachmentSelected\"))) {\n        (((JSBNG_Record.get)(c, (\"reset\")))[(\"reset\")])(true);\n    }\n    ;\n    (((JSBNG_Record.get)(CSS, (\"addClass\")))[(\"addClass\")])(this, \"uiComposerAttachmentSelected\");\n    (((JSBNG_Record.get)(CSS, (\"addClass\")))[(\"addClass\")])(root, \"uiComposerOpen\");\n    (((JSBNG_Record.get)(Bootloader, (\"loadComponents\")))[(\"loadComponents\")])(\"dom\", ((function() {\n        var s1391419701277983b55eb3c9d16f6025748e7c6d_1_instance;\n        ((s1391419701277983b55eb3c9d16f6025748e7c6d_1_instance) = ((JSBNG_Record.eventInstance)((\"s1391419701277983b55eb3c9d16f6025748e7c6d_1\"))));\n        return ((JSBNG_Record.markFunction)((function() {\n            if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n                return ((JSBNG_Record.eventCall)((arguments.callee), (\"s1391419701277983b55eb3c9d16f6025748e7c6d_1\"), (s1391419701277983b55eb3c9d16f6025748e7c6d_1_instance), (this), (arguments)))\n            };\n            (null);\n            (((JSBNG_Record.get)((((JSBNG_Record.get)(DOM, (\"JSBNG__find\")))[(\"JSBNG__find\")])(root, \"textarea.mentionsTextarea\"), (\"JSBNG__focus\")))[(\"JSBNG__focus\")])();\n        })));\n    })()));\n    (((JSBNG_Record.get)((((JSBNG_Record.get)((((JSBNG_Record.get)(CSS, (\"removeClass\")))[(\"removeClass\")]), (\"curry\")))[(\"curry\")])(root, \"async_saving\"), (\"defer\")))[(\"defer\")])();\n};\nvar s1391419701277983b55eb3c9d16f6025748e7c6d_0_instance;\n((s1391419701277983b55eb3c9d16f6025748e7c6d_0_instance) = ((JSBNG_Record.eventInstance)((\"s1391419701277983b55eb3c9d16f6025748e7c6d_0\"))));\n((JSBNG_Record.markFunction)((e196434646ab30cd94113f04a485d44e3c13d2332)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><span class=\"uiComposerAttachment statusAttachment uiComposerAttachmentSelected attachmentAcceptsLink\" id=\"composerTourStart\" onclick=\"return e196434646ab30cd94113f04a485d44e3c13d2332.call(this, event);\" data-endpoint=\"/ajax/metacomposer/attachment/status/status.php\"><a class=\"uiIconText attachmentLink normal\" href=\"#\" tabindex=\"0\"><i class=\"img sp_14y7us sx_603833\"></i><strong class=\"attachmentName\">Update Status</strong></a><span class=\"uiIconText selected\"><i class=\"img sp_14y7us sx_603833\"></i><strong class=\"attachmentName\">Update Status<i class=\"nub\"></i></strong></span></span></li><li class=\"plm uiListItem  uiListHorizontalItemBorder uiListHorizontalItem\"><span class=\"uiComposerAttachment photoAttachment\" id=\"uq3j16_7\" data-endpoint=\"/ajax/metacomposer/attachment/photo/photo.php\"><a class=\"uiIconText attachmentLink normal\" href=\"#\" tabindex=\"0\"><i class=\"img sp_627qpw sx_db3d6d\"></i><strong class=\"attachmentName\">Add Photo / Video</strong></a><span class=\"uiIconText selected\"><i class=\"img sp_627qpw sx_db3d6d\"></i><strong class=\"attachmentName\">Add Photo / Video<i class=\"nub\"></i></strong></span></span></li><li class=\"plm uiListItem  uiListHorizontalItemBorder uiListHorizontalItem\"><span class=\"uiComposerAttachment\" id=\"uq3j16_8\" data-endpoint=\"/ajax/metacomposer/attachment/question/question.php?create_eigenpoll=1&amp;source=composer\"><a class=\"uiIconText attachmentLink normal\" href=\"#\" tabindex=\"0\"><i class=\"img sp_14y7us sx_cd3f20\"></i><strong class=\"attachmentName\">Ask Question</strong></a><span class=\"uiIconText selected\"><i class=\"img sp_14y7us sx_cd3f20\"></i><strong class=\"attachmentName\">Ask Question<i class=\"nub\"></i></strong></span></span></li><li class=\"attachmentLoader plm uiListItem  uiListHorizontalItemBorder uiListHorizontalItem\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /></li></ul><input type=\"hidden\" autocomplete=\"off\" name=\"targetid\" value=\"100001812504199\" /><input class=\"hidden_elem\" type=\"submit\" name=\"xhpc\" /></form><div class=\"showWhenOpen mutableContent uiComposerMetaContainer\"><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function e7da25d412104308717a2cb6fa1a78c40eb21373e(event) {\\u000a    return Event.__inlineSubmit(this, event);\\u000a};\"), (\"s5f9e70b8f5cf5a385197d171a6dae493468c82d2\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction e7da25d412104308717a2cb6fa1a78c40eb21373e(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s5f9e70b8f5cf5a385197d171a6dae493468c82d2_0\"), (s5f9e70b8f5cf5a385197d171a6dae493468c82d2_0_instance), (this), (arguments)))\n    };\n    (null);\n    return (((JSBNG_Record.get)(JSBNG__Event, (\"__inlineSubmit\")))[(\"__inlineSubmit\")])(this, JSBNG__event);\n};\nvar s5f9e70b8f5cf5a385197d171a6dae493468c82d2_0_instance;\n((s5f9e70b8f5cf5a385197d171a6dae493468c82d2_0_instance) = ((JSBNG_Record.eventInstance)((\"s5f9e70b8f5cf5a385197d171a6dae493468c82d2_0\"))));\n((JSBNG_Record.markFunction)((e7da25d412104308717a2cb6fa1a78c40eb21373e)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><form rel=\"async\" class=\"attachmentForm\" action=\"/ajax/updatestatus.php\" method=\"post\" onsubmit=\"return e7da25d412104308717a2cb6fa1a78c40eb21373e.call(this, event);\" id=\"uq3j16_15\"><input type=\"hidden\" name=\"fb_dtsg\" value=\"AQCc21Em\" autocomplete=\"off\" /><input type=\"hidden\" autocomplete=\"off\" name=\"xhpc_composerid\" value=\"uq3j16_6\" /><input type=\"hidden\" autocomplete=\"off\" name=\"xhpc_targetid\" value=\"100001812504199\" /><input type=\"hidden\" autocomplete=\"off\" name=\"xhpc_context\" value=\"home\" /><input type=\"hidden\" autocomplete=\"off\" name=\"xhpc_fbx\" value=\"1\" /><input type=\"hidden\" autocomplete=\"off\" name=\"xhpc_timeline\" value=\"\" /><input type=\"hidden\" autocomplete=\"off\" name=\"xhpc_ismeta\" value=\"1\" /><div class=\"attachmentFrame\"><div class=\"attachmentContent\"></div></div><div class=\"uiMetaComposerMessageBox uiComposerMessageBoxMentions\" id=\"uq3j16_9\"><table class=\"uiMetaComposerMessageBoxTable\" cellspacing=\"0\" cellpadding=\"0\"><tr><td><div class=\"inputContainer\"><div class=\"uiMentionsInput\" id=\"uq3j16_10\"><div class=\"highlighter\"><div><span class=\"highlighterContent\"></span></div></div><div class=\"uiTypeahead composerTypeahead mentionsTypeahead\" id=\"uq3j16_11\"><div class=\"wrap\"><input type=\"hidden\" autocomplete=\"off\" class=\"hiddenInput\" /><div class=\"innerWrap\"><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function e6ce8037adcad1aa86d6f7c1ed7a7778c5fd666df(event) {\\u000a    Bootloader.loadComponents([\\\"control-textarea\\\",], function() {\\u000a        TextAreaControl.getInstance(this);\\u000a    }.bind(this));\\u000a};\"), (\"s313ee9a03a3c0c7703168f8749b23628c107a23e\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction e6ce8037adcad1aa86d6f7c1ed7a7778c5fd666df(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s313ee9a03a3c0c7703168f8749b23628c107a23e_0\"), (s313ee9a03a3c0c7703168f8749b23628c107a23e_0_instance), (this), (arguments)))\n    };\n    (null);\n    (((JSBNG_Record.get)(Bootloader, (\"loadComponents\")))[(\"loadComponents\")])([\"control-textarea\",], (((JSBNG_Record.get)(((function() {\n        var s313ee9a03a3c0c7703168f8749b23628c107a23e_1_instance;\n        ((s313ee9a03a3c0c7703168f8749b23628c107a23e_1_instance) = ((JSBNG_Record.eventInstance)((\"s313ee9a03a3c0c7703168f8749b23628c107a23e_1\"))));\n        return ((JSBNG_Record.markFunction)((function() {\n            if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n                return ((JSBNG_Record.eventCall)((arguments.callee), (\"s313ee9a03a3c0c7703168f8749b23628c107a23e_1\"), (s313ee9a03a3c0c7703168f8749b23628c107a23e_1_instance), (this), (arguments)))\n            };\n            (null);\n            (((JSBNG_Record.get)(TextAreaControl, (\"getInstance\")))[(\"getInstance\")])(this);\n        })));\n    })()), (\"bind\")))[(\"bind\")])(this));\n};\nvar s313ee9a03a3c0c7703168f8749b23628c107a23e_0_instance;\n((s313ee9a03a3c0c7703168f8749b23628c107a23e_0_instance) = ((JSBNG_Record.eventInstance)((\"s313ee9a03a3c0c7703168f8749b23628c107a23e_0\"))));\n((JSBNG_Record.markFunction)((e6ce8037adcad1aa86d6f7c1ed7a7778c5fd666df)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><textarea class=\"DOMControl_placeholder uiTextareaAutogrow input mentionsTextarea textInput\" title=\"What&#039;s on your mind?\" name=\"xhpc_message\" placeholder=\"What&#039;s on your mind?\" autocomplete=\"off\" aria-autocomplete=\"list\" aria-expanded=\"false\" aria-invalid=\"false\" aria-owns=\"typeahead_list_uq3j16_11\" role=\"textbox\" onkeydown=\"return e6ce8037adcad1aa86d6f7c1ed7a7778c5fd666df.call(this, event);\" id=\"uq3j16_12\">What&#039;s on your mind?</textarea></div></div></div><input type=\"hidden\" autocomplete=\"off\" class=\"mentionsHidden\" /></div><div class=\"attachmentMetaArea\"></div></div></td></tr><tr><td><div class=\"attachmentBottomArea\"></div></td></tr></table><div class=\"showOnceInteracted uiMetaComposerMessageBoxShelf\"><div class=\"clearfix uiComposerMessageBoxControls\" id=\"uiComposerMessageBoxControls\"><div class=\"lfloat\"><div class=\"pls textBlurb fsm fwn fcg\"></div><div class=\"attachmentBarArea\"></div></div><ul class=\"uiList uiListHorizontal clearfix uiComposerBarRightArea rfloat\"><li class=\"attachmentAuxBarArea uiListItem  uiListHorizontalItemBorder uiListHorizontalItem\"></li><li class=\"privacyWidget pls uiListItem  uiListHorizontalItemBorder uiListHorizontalItem\" id=\"composerTourAudience\" data-gt=\"&#123;&quot;composer&quot;:&#123;&quot;comp&quot;:&quot;audience&quot;,&quot;ua_id&quot;:&quot;composer:post&quot;&#125;&#125;\"><div id=\"pagelet_privacy_widget\" data-referrer=\"pagelet_privacy_widget\"></div></li><li class=\"pls uiListItem  uiListHorizontalItemBorder uiListHorizontalItem\"><label class=\"submitBtn uiButton uiButtonConfirm\" for=\"uq3j16_13\"><input value=\"Post\" type=\"submit\" id=\"uq3j16_13\" /></label></li></ul></div></div></div></form></div></div></div> ";
// undefined
o9 = null;
// 1198
o8.parentNode = o7;
// 1200
f33216266_455.returns.push(o8);
// undefined
o8 = null;
// 1201
// 1202
o6.getAttribute = f33216266_456;
// undefined
o6 = null;
// 1203
f33216266_456.returns.push("pagelet_composer");
// 1206
f33216266_432.returns.push(1344872059240);
// 1210
o6 = {};
// 1211
f33216266_441.returns.push(o6);
// 1213
f33216266_443.returns.push(o6);
// undefined
o6 = null;
// 1215
f33216266_432.returns.push(1344872059241);
// 1217
f33216266_432.returns.push(1344872059241);
// 1222
f33216266_432.returns.push(1344872059242);
// 1226
o6 = {};
// 1227
f33216266_441.returns.push(o6);
// 1229
f33216266_443.returns.push(o6);
// undefined
o6 = null;
// 1232
f33216266_432.returns.push(1344872059244);
// 1236
f33216266_432.returns.push(1344872059245);
// 1238
o6 = {};
// 1239
f33216266_450.returns.push(o6);
// 1241
o8 = {};
// 1242
f33216266_450.returns.push(o8);
// 1243
o9 = {};
// 1244
o8.firstChild = o9;
// 1246
o9.nodeType = 8;
// 1248
o9.nodeValue = " <ul id=\"boulder_fixed_header\" class=\"uiStream\"><li class=\"mts uiStreamHeader\"><span class=\"plm uiStreamHeaderText fss fwb\"></span><div class=\"-cx-PRIVATE-uiInlineBlock__root  uiPopover uiStreamHeaderChronologicalForm\" id=\"uq3j2t_2\"><a class=\"sortLink -cx-PRIVATE-uiPopover__trigger\" href=\"#\" aria-haspopup=\"true\" aria-expanded=\"false\" rel=\"toggle\" id=\"uq3j2t_3\">SORT</a></div></li></ul><div class=\"UIIntentionalStream UIStream\"  id=\"c50291e771e77b1369087562\"><ul class=\"uiList uiStream uiStreamHomepage translateParent uiStreamRedesign uiStreamLargeHeadline UIIntentionalStream_Content\" id=\"home_stream\"></ul><div ><div class=\"UIIntentionalStream_Error\"><div class=\"pam uiBoxRed\"><div class=\"fsl fwb fcb\">This stream is unavailable at this time. Please try again soon.</div></div></div></div><div ><div id=\"pagelet_stream_pager\"></div></div></div> ";
// undefined
o9 = null;
// 1249
o8.parentNode = o7;
// 1251
f33216266_455.returns.push(o8);
// undefined
o8 = null;
// 1252
// 1253
o6.getAttribute = f33216266_456;
// 1254
f33216266_456.returns.push("pagelet_home_stream");
// 1257
f33216266_432.returns.push(1344872059251);
// 1261
o8 = {};
// 1262
f33216266_441.returns.push(o8);
// 1264
f33216266_443.returns.push(o8);
// undefined
o8 = null;
// 1266
f33216266_432.returns.push(1344872059251);
// 1268
f33216266_432.returns.push(1344872059252);
// 1273
f33216266_432.returns.push(1344872059252);
// 1276
f33216266_432.returns.push(1344872059253);
// 1280
f33216266_432.returns.push(1344872059253);
// 1282
o8 = {};
// 1283
f33216266_450.returns.push(o8);
// 1285
o9 = {};
// 1286
f33216266_450.returns.push(o9);
// 1287
o10 = {};
// 1288
o9.firstChild = o10;
// 1290
o10.nodeType = 8;
// 1292
o10.nodeValue = " <div class=\"homeSideNav\" role=\"navigation\" id=\"pinnedNav\"><div class=\"navHeader\">FAVORITES</div><div class=\"mts mbm droppableNav\"><ul class=\"uiSideNav\" data-gt=\"&#123;&quot;nav_items_count&quot;:&quot;5&quot;,&quot;nav_section&quot;:&quot;pinnedNav&quot;&#125;\"><li class=\"sideNavItem stat_elem\" id=\"navItem_app_156203961126022\"><div class=\"buttonWrap\"></div><a class=\"item clearfix\" href=\"/?sk=welcome\" title=\"\" data-gt=\"&#123;&quot;bmid&quot;:&quot;156203961126022&quot;,&quot;fbtype&quot;:&quot;128&quot;,&quot;count&quot;:&quot;0&quot;,&quot;coeff2_info&quot;:&quot;AatIrMgxkpdSYsgERUx26ylTL-RCBf4NhTQKVtdAY77vSKY9n6ek__-IftjZtVIR4QgbDCyW5ggMn3y5QyFVdOYl&quot;,&quot;coeff2_registry_key&quot;:&quot;0016&quot;,&quot;coeff2_action&quot;:&quot;3&quot;,&quot;coeff2_pv_signature&quot;:&quot;1880892099&quot;,&quot;rank&quot;:&quot;1&quot;&#125;\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span><span class=\"maxCountIndicator\"></span></span></div><div><span class=\"imgWrap\"><i class=\"img sp_55oxbe sx_98804b\"></i></span><div class=\"linkWrap noCount\">Welcome</div></div></a></li><li class=\"sideNavItem stat_elem selectedItem open\" id=\"navItem_app_4748854339\"><div class=\"buttonWrap\"></div><a class=\"item clearfix\" href=\"/?sk=nf\" title=\"\" data-gt=\"&#123;&quot;bmid&quot;:&quot;4748854339&quot;,&quot;fbtype&quot;:&quot;128&quot;,&quot;count&quot;:&quot;0&quot;,&quot;coeff2_info&quot;:&quot;AasCkV9Wza3ehwY3KP0itJ7GhaEF_K5m269MJIR_mS82SJN9hwoYjyIiNZHpcxtfbHM&quot;,&quot;coeff2_registry_key&quot;:&quot;0016&quot;,&quot;coeff2_action&quot;:&quot;3&quot;,&quot;coeff2_pv_signature&quot;:&quot;1880892099&quot;,&quot;rank&quot;:&quot;2&quot;&#125;\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span><span class=\"maxCountIndicator\"></span></span></div><div><span class=\"imgWrap\"><i class=\"img sp_14y7us sx_f8da38\"></i></span><div class=\"linkWrap noCount\">News Feed</div></div></a></li><li class=\"sideNavItem stat_elem\" id=\"navItem_app_217974574879787\"><div class=\"buttonWrap\"></div><a class=\"item clearfix sortableItem\" href=\"/messages/\" title=\"\" data-gt=\"&#123;&quot;bmid&quot;:&quot;217974574879787&quot;,&quot;fbtype&quot;:&quot;128&quot;,&quot;count&quot;:&quot;0&quot;,&quot;coeff2_info&quot;:&quot;Aaudzcmv-h3nDcqIvUoyfTJfJUWvN9GE1lzuTEhiNkNMB4KP_QjEqxOYxYCFz5D4Bx8QmBgLKbokbjvBAU9PO31C&quot;,&quot;coeff2_registry_key&quot;:&quot;0016&quot;,&quot;coeff2_action&quot;:&quot;3&quot;,&quot;coeff2_pv_signature&quot;:&quot;1880892099&quot;,&quot;rank&quot;:&quot;3&quot;&#125;\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span><span class=\"maxCountIndicator\"></span></span><span class=\"grip\"></span></div><div><span class=\"imgWrap\"><i class=\"img sp_ae80w4 sx_0ca7fd\"></i></span><div class=\"linkWrap noCount\">Messages</div></div></a><span class=\"mover hidden_elem\"></span></li><li class=\"sideNavItem stat_elem\" id=\"navItem_app_2344061033\"><div class=\"buttonWrap\"></div><a class=\"item clearfix sortableItem\" href=\"/events/list\" title=\"\" data-gt=\"&#123;&quot;bmid&quot;:&quot;2344061033&quot;,&quot;fbtype&quot;:&quot;128&quot;,&quot;count&quot;:&quot;0&quot;,&quot;coeff2_info&quot;:&quot;AavvUnK78N3F-vOKtww0gzlU4cVaicGt3iAHq7dKHWs-HQm19fCRWONkSuZRn3KSSjA&quot;,&quot;coeff2_registry_key&quot;:&quot;0016&quot;,&quot;coeff2_action&quot;:&quot;3&quot;,&quot;coeff2_pv_signature&quot;:&quot;1880892099&quot;,&quot;rank&quot;:&quot;4&quot;&#125;\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span><span class=\"maxCountIndicator\"></span></span><span class=\"grip\"></span></div><div><span class=\"imgWrap\"><img class=\"img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yg/r/HZt027gpydB.png\" alt=\"\" width=\"15\" height=\"16\" /></span><div class=\"linkWrap noCount\">Events</div></div></a><span class=\"mover hidden_elem\"></span></li><li class=\"sideNavItem stat_elem\" id=\"navItem_app_2356318349\"><div class=\"buttonWrap\"></div><a class=\"item clearfix sortableItem\" href=\"/?sk=fr\" title=\"Find Friends\" data-gt=\"&#123;&quot;bmid&quot;:&quot;2356318349&quot;,&quot;fbtype&quot;:&quot;128&quot;,&quot;count&quot;:&quot;0&quot;,&quot;coeff2_info&quot;:&quot;Aauz2LWugZ_xNgCStDNjyrGIUbWzfSy3S-iyiGQPVevxtYjPhLp0HBxFo1IKsfHVDAE&quot;,&quot;coeff2_registry_key&quot;:&quot;0016&quot;,&quot;coeff2_action&quot;:&quot;3&quot;,&quot;coeff2_pv_signature&quot;:&quot;1880892099&quot;,&quot;rank&quot;:&quot;5&quot;&#125;\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span><span class=\"maxCountIndicator\"></span></span><span class=\"grip\"></span></div><div><span class=\"imgWrap\"><i class=\"img sp_ae80w4 sx_015f64\"></i></span><div class=\"linkWrap noCount\">Find Friends</div></div></a><span class=\"mover hidden_elem\"></span></li></ul><div class=\"actionLinks stat_elem\"><a class=\"navEditDone\" href=\"#\" data-endpoint=\"/ajax/bookmark/edit/\"><span class=\"navEdit\">Edit</span><span class=\"navDone\">Done</span></a><span class=\"loadingIndicator\"></span></div></div></div> ";
// undefined
o10 = null;
// 1293
o9.parentNode = o7;
// 1295
f33216266_455.returns.push(o9);
// undefined
o9 = null;
// 1296
f33216266_476 = function() { return f33216266_476.returns[f33216266_476.inst++]; };
f33216266_476.returns = [];
f33216266_476.inst = 0;
// 1297
o0.createElement = f33216266_476;
// 1298
o9 = {};
// 1299
f33216266_476.returns.push(o9);
// 1300
// 1302
o10 = {};
// 1303
f33216266_441.returns.push(o10);
// 1304
o11 = {};
// undefined
fo33216266_477_firstChild = function() { return fo33216266_477_firstChild.returns[fo33216266_477_firstChild.inst++]; };
fo33216266_477_firstChild.returns = [];
fo33216266_477_firstChild.inst = 0;
defineGetter(o9, "firstChild", fo33216266_477_firstChild);
// undefined
o9 = null;
// undefined
fo33216266_477_firstChild.returns.push(o11);
// 1306
o10.appendChild = f33216266_443;
// undefined
fo33216266_477_firstChild.returns.push(o11);
// 1308
f33216266_443.returns.push(o11);
// undefined
o11 = null;
// undefined
fo33216266_477_firstChild.returns.push(null);
// 1310
o8.appendChild = f33216266_443;
// 1311
f33216266_443.returns.push(o10);
// undefined
o10 = null;
// 1312
o8.getAttribute = f33216266_456;
// 1313
f33216266_456.returns.push(null);
// 1314
f33216266_480 = function() { return f33216266_480.returns[f33216266_480.inst++]; };
f33216266_480.returns = [];
f33216266_480.inst = 0;
// 1315
o8.setAttribute = f33216266_480;
// 1316
f33216266_480.returns.push(undefined);
// 1318
f33216266_432.returns.push(1344872059263);
// 1322
o9 = {};
// 1323
f33216266_441.returns.push(o9);
// 1325
f33216266_443.returns.push(o9);
// undefined
o9 = null;
// 1327
f33216266_432.returns.push(1344872059264);
// 1329
f33216266_432.returns.push(1344872059264);
// 1334
f33216266_432.returns.push(1344872059280);
// 1338
o9 = {};
// 1339
f33216266_441.returns.push(o9);
// 1341
f33216266_443.returns.push(o9);
// undefined
o9 = null;
// 1344
f33216266_432.returns.push(1344872059281);
// 1348
f33216266_432.returns.push(1344872059281);
// 1350
o9 = {};
// 1351
f33216266_450.returns.push(o9);
// 1353
o10 = {};
// 1354
f33216266_450.returns.push(o10);
// 1355
o11 = {};
// 1356
o10.firstChild = o11;
// 1358
o11.nodeType = 8;
// 1360
o11.nodeValue = " <li class=\"uiUnifiedStory uiStreamStory genericStreamStory aid_1055580469 uiListItem uiListLight uiListVerticalItemBorder\" data-ft=\"&#123;&quot;qid&quot;:&quot;5776181494237290802&quot;,&quot;mf_story_key&quot;:&quot;-4571705487949635972&quot;&#125;\" id=\"stream_story_50291e77418e06768205346\"><div class=\"clearfix storyContent\"><a class=\"actorPhoto lfloat\" href=\"http://www.facebook.com/LawlabeeTheWallaby\" tabindex=\"-1\" aria-hidden=\"true\" data-ft=\"&#123;&quot;type&quot;:60,&quot;tn&quot;:&quot;\\\\u003C&quot;&#125;\" data-hovercard=\"/ajax/hovercard/hovercard.php?id=1055580469\"><img class=\"-cx-PRIVATE-uiSquareImage__root profilePic -cx-PRIVATE-uiSquareImage__large img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/157194_1055580469_1433282671_q.jpg\" alt=\"\" /></a><div class=\"storyInnerContent\"><div class=\"mainWrapper\"><h6 class=\"uiStreamMessage uiStreamHeadline\" data-ft=\"&#123;&quot;tn&quot;:&quot;:&quot;&#125;\"><div class=\"actorDescription actorName\" data-ft=\"&#123;&quot;type&quot;:2,&quot;tn&quot;:&quot;:&quot;&#125;\"><a href=\"http://www.facebook.com/LawlabeeTheWallaby\" data-ft=\"&#123;&quot;tn&quot;:&quot;;&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=1055580469\">Gregor Richards</a></div></h6><h6 class=\"uiStreamMessage\" data-ft=\"&#123;&quot;type&quot;:1,&quot;tn&quot;:&quot;K&quot;&#125;\"> <span class=\"messageBody\" data-ft=\"&#123;&quot;type&quot;:3&#125;\"><div>Ladies, ladies, please, there&#039;s only one of me, do try to restrain yourselves!</div></span></h6><div class=\"mvm uiStreamAttachments fbMainStreamAttachment\" data-ft=\"&#123;&quot;type&quot;:10,&quot;tn&quot;:&quot;H&quot;&#125;\"><div class=\"clearfix photoRedesign\"><a class=\"uiPhotoThumb photoRedesignAspect\" href=\"http://www.facebook.com/photo.php?fbid=3688952976504&amp;set=a.1138433375108.2021456.1055580469&amp;type=1&amp;relevant_count=1&amp;ref=nf\" data-ft=\"&#123;&quot;type&quot;:41,&quot;tn&quot;:&quot;E&quot;&#125;\" rel=\"theater\" ajaxify=\"http://www.facebook.com/photo.php?fbid=3688952976504&amp;set=a.1138433375108.2021456.1055580469&amp;type=1&amp;relevant_count=1&amp;ref=nf&amp;src=http\u00253A\u00252F\u00252Fsphotos-b.xx.fbcdn.net\u00252Fhphotos-ash4\u00252F304942_3688952976504_585933400_n.jpg&amp;size=319\u00252C600&amp;theater\" aria-label=\"Photo\"><img class=\"img\" height=\"398\" src=\"http://sphotos-b.xx.fbcdn.net/hphotos-ash4/s480x480/304942_3688952976504_585933400_n.jpg\" width=\"211\" alt=\"\" /></a></div></div><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function ede5ae57fb967fe0f874082fde0f2da275b7eaed1(event) {\\u000a    return Event.__inlineSubmit(this, event);\\u000a};\"), (\"s780f4bb9a3d2cfb0c80a3fa2cf125aa1bd427cc5\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction ede5ae57fb967fe0f874082fde0f2da275b7eaed1(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s780f4bb9a3d2cfb0c80a3fa2cf125aa1bd427cc5_0\"), (s780f4bb9a3d2cfb0c80a3fa2cf125aa1bd427cc5_0_instance), (this), (arguments)))\n    };\n    (null);\n    return (((JSBNG_Record.get)(JSBNG__Event, (\"__inlineSubmit\")))[(\"__inlineSubmit\")])(this, JSBNG__event);\n};\nvar s780f4bb9a3d2cfb0c80a3fa2cf125aa1bd427cc5_0_instance;\n((s780f4bb9a3d2cfb0c80a3fa2cf125aa1bd427cc5_0_instance) = ((JSBNG_Record.eventInstance)((\"s780f4bb9a3d2cfb0c80a3fa2cf125aa1bd427cc5_0\"))));\n((JSBNG_Record.markFunction)((ede5ae57fb967fe0f874082fde0f2da275b7eaed1)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><form rel=\"async\" class=\"live_3688952976504_131325686911214 commentable_item autoexpand_mode\" method=\"post\" action=\"/ajax/ufi/modify.php\" data-live=\"&#123;&quot;seq&quot;:2422886&#125;\" onsubmit=\"return ede5ae57fb967fe0f874082fde0f2da275b7eaed1.call(this, event);\" id=\"uq3j2t_30\"><input type=\"hidden\" name=\"charset_test\" value=\"&euro;,&acute;,€,´,水,Д,Є\" /><input type=\"hidden\" name=\"fb_dtsg\" value=\"AQCc21Em\" autocomplete=\"off\" /><input type=\"hidden\" autocomplete=\"off\" name=\"feedback_params\" value=\"&#123;&quot;actor&quot;:&quot;1055580469&quot;,&quot;target_fbid&quot;:&quot;3688952976504&quot;,&quot;target_profile_id&quot;:&quot;1055580469&quot;,&quot;type_id&quot;:&quot;7&quot;,&quot;assoc_obj_id&quot;:&quot;&quot;,&quot;source_app_id&quot;:&quot;&quot;,&quot;extra_story_params&quot;:[],&quot;content_timestamp&quot;:&quot;1344557646&quot;,&quot;check_hash&quot;:&quot;AQDIPpRc_NCu6XoF&quot;,&quot;source&quot;:&quot;1&quot;&#125;\" /><span class=\"uiStreamFooter\"><span class=\"UIActionLinks UIActionLinks_bottom\" data-ft=\"&#123;&quot;tn&quot;:&quot;=&quot;,&quot;type&quot;:20&#125;\"><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function ef3e0637fdce5af8e7c9dc530cde9cbfc63c8dc1e(event) {\\u000a    fc_click(this, false);\\u000a    return true;\\u000a};\"), (\"sdb48916c90bd99699ada19030e9c4bcaa0c77c7d\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction ef3e0637fdce5af8e7c9dc530cde9cbfc63c8dc1e(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"sdb48916c90bd99699ada19030e9c4bcaa0c77c7d_0\"), (sdb48916c90bd99699ada19030e9c4bcaa0c77c7d_0_instance), (this), (arguments)))\n    };\n    (null);\n    fc_click(this, false);\n    return true;\n};\nvar sdb48916c90bd99699ada19030e9c4bcaa0c77c7d_0_instance;\n((sdb48916c90bd99699ada19030e9c4bcaa0c77c7d_0_instance) = ((JSBNG_Record.eventInstance)((\"sdb48916c90bd99699ada19030e9c4bcaa0c77c7d_0\"))));\n((JSBNG_Record.markFunction)((ef3e0637fdce5af8e7c9dc530cde9cbfc63c8dc1e)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><button class=\"like_link stat_elem as_link\" title=\"Like this item\" type=\"submit\" name=\"like\" onclick=\"return ef3e0637fdce5af8e7c9dc530cde9cbfc63c8dc1e.call(this, event);\" data-ft=\"&#123;&quot;tn&quot;:&quot;&gt;&quot;,&quot;type&quot;:22&#125;\"><span class=\"default_message\">Like</span><span class=\"saving_message\">Unlike</span></button> &#183; <label class=\"uiLinkButton comment_link\" title=\"Leave a comment\"><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function e1caa5eebe581df9e9cee0adc6d6d9521cf72b499(event) {\\u000a    return fc_click(this);\\u000a};\"), (\"s7f7e81b92c891d35452eb8e8de73d706031a9a0f\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction e1caa5eebe581df9e9cee0adc6d6d9521cf72b499(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s7f7e81b92c891d35452eb8e8de73d706031a9a0f_0\"), (s7f7e81b92c891d35452eb8e8de73d706031a9a0f_0_instance), (this), (arguments)))\n    };\n    (null);\n    return fc_click(this);\n};\nvar s7f7e81b92c891d35452eb8e8de73d706031a9a0f_0_instance;\n((s7f7e81b92c891d35452eb8e8de73d706031a9a0f_0_instance) = ((JSBNG_Record.eventInstance)((\"s7f7e81b92c891d35452eb8e8de73d706031a9a0f_0\"))));\n((JSBNG_Record.markFunction)((e1caa5eebe581df9e9cee0adc6d6d9521cf72b499)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><input data-ft=\"&#123;&quot;type&quot;:24,&quot;tn&quot;:&quot;S&quot;&#125;\" type=\"button\" value=\"Comment\" onclick=\"return e1caa5eebe581df9e9cee0adc6d6d9521cf72b499.call(this, event);\"></label> &#183; <a class=\"share_action_link\" href=\"/ajax/sharer/?s=2&amp;appid=2305272732&amp;p\u00255B0\u00255D=1055580469&amp;p\u00255B1\u00255D=33195505\" rel=\"dialog\" data-ft=\"&#123;&quot;tn&quot;:&quot;J&quot;,&quot;type&quot;:25&#125;\" title=\"Send this to friends or post it on your timeline.\">Share</a> &#183; </span><span class=\"uiStreamSource\" data-ft=\"&#123;&quot;type&quot;:26,&quot;tn&quot;:&quot;N&quot;&#125;\"><a href=\"http://www.facebook.com/photo.php?fbid=3688952976504&amp;set=a.1138433375108.2021456.1055580469&amp;type=1\"><abbr title=\"Thursday, August 9, 2012 at 8:14pm\" data-utime=\"1344557647\">August 9 at 8:14pm</abbr></a></span> · <a data-hover=\"tooltip\" title=\"Shared with: Public\" class=\"uiStreamPrivacy inlineBlock fbStreamPrivacy fbPrivacyAudienceIndicator\" href=\"#\"><i class=\"lock img sp_67189i sx_767b12\"></i></a></span><div><ul class=\"uiList uiUfi focus_target fbUfi fbUfiNoBorder\" data-ft=\"&#123;&quot;type&quot;:30,&quot;tn&quot;:&quot;]&quot;&#125;\"><li class=\"ufiNub uiListItem  uiListVerticalItemBorder\"><i></i></li><li class=\"ufiItem uiUfiLike uiListItem  uiListVerticalItemBorder\" data-ft=\"&#123;&quot;type&quot;:31&#125;\"><div class=\"UIImageBlock clearfix\"><a class=\"UIImageBlock_Image UIImageBlock_ICON_Image\" href=\"#\" tabindex=\"-1\" aria-hidden=\"true\"><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function eda1587e4c8d690b40d5444876b70c0358e887bf4(event) {\\u000a    this.form.like.click();\\u000a};\"), (\"s4509f7574317a0e2b37315132bd3102cba71d554\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction eda1587e4c8d690b40d5444876b70c0358e887bf4(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s4509f7574317a0e2b37315132bd3102cba71d554_0\"), (s4509f7574317a0e2b37315132bd3102cba71d554_0_instance), (this), (arguments)))\n    };\n    (null);\n    (((JSBNG_Record.get)((((JSBNG_Record.get)((((JSBNG_Record.get)(this, (\"form\")))[(\"form\")]), (\"like\")))[(\"like\")]), (\"click\")))[(\"click\")])();\n};\nvar s4509f7574317a0e2b37315132bd3102cba71d554_0_instance;\n((s4509f7574317a0e2b37315132bd3102cba71d554_0_instance) = ((JSBNG_Record.eventInstance)((\"s4509f7574317a0e2b37315132bd3102cba71d554_0\"))));\n((JSBNG_Record.markFunction)((eda1587e4c8d690b40d5444876b70c0358e887bf4)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><label class=\"uiUfiLikeIcon\" title=\"Like this item\" onclick=\"return eda1587e4c8d690b40d5444876b70c0358e887bf4.call(this, event);\"></label></a><div class=\"UIImageBlock_Content UIImageBlock_ICON_Content\"><a href=\"/browse/likes/?id=3688952976504\" rel=\"dialog\" title=\"See who likes this\" ajaxify=\"/ajax/browser/dialog/likes/?id=3688952976504\">10 people</a> like this.</div></div></li><li class=\"translateable_info hidden_elem uiListItem  uiListVerticalItemBorder\"><input type=\"hidden\" autocomplete=\"off\" name=\"translate_on_load\" value=\"\" /></li><li class=\"uiUfiComments uiListItem  uiListVerticalItemBorder\" data-ft=\"&#123;&quot;type&quot;:32&#125;\"><ul class=\"commentList\"><li class=\"uiUfiViewAll  ufiItem\"><label class=\"uiIconText uiLinkButton async_throbber\"><i class=\"img sp_627qpw sx_4fad2b\"></i><input type=\"submit\" name=\"view_all[1]\" value=\"View all 11 comments\" data-ft=\"&#123;&quot;tn&quot;:&quot;Q&quot;&#125;\" class=\"stat_elem\" /></label></li><li class=\"uiUfiComment comment_2422741 ufiItem ufiItem\" data-ft=\"&#123;&quot;tn&quot;:&quot;R0&quot;&#125;\"><div class=\"UIImageBlock clearfix uiUfiActorBlock\"><a class=\"actorPic UIImageBlock_Image UIImageBlock_SMALL_Image\" href=\"http://www.facebook.com/LawlabeeTheWallaby\" tabindex=\"-1\" data-ft=\"&#123;&quot;type&quot;:34,&quot;tn&quot;:&quot;T&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=1055580469\"><img class=\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__medium img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/157194_1055580469_1433282671_q.jpg\" alt=\"\" /></a><a data-hover=\"tooltip\" title=\"Hide as Spam\" class=\"commentRemoverButton UIImageBlock_Ext uiCloseButton\" href=\"#\" role=\"button\" rel=\"async-post\" ajaxify=\"/ajax/ufi/one_click_remove?comment_id=2422741&amp;commenter_id=1055580469&amp;profile_id=1055580469&amp;post_fbid=3692779032153&amp;can_remove=0&amp;can_report=1&amp;can_edit=0&amp;is_spam=0&amp;report_link=\u00252Fajax\u00252Freport.php\u00253Fcontent_type\u00253D71\u002526cid\u00253D3692779032153\u002526rid\u00253D1055580469\u002526cid2\u00253D0\u002526profile\u00253D1055580469\u002526h\u00253DAfidsbLww8ag4fIu&amp;feedback_params=\u00257B\u002522actor\u002522\u00253A\u0025221055580469\u002522\u00252C\u002522target_fbid\u002522\u00253A\u0025223688952976504\u002522\u00252C\u002522target_profile_id\u002522\u00253A\u0025221055580469\u002522\u00252C\u002522type_id\u002522\u00253A\u0025227\u002522\u00252C\u002522assoc_obj_id\u002522\u00253A\u002522\u002522\u00252C\u002522source_app_id\u002522\u00253A\u002522\u002522\u00252C\u002522extra_story_params\u002522\u00253A\u00255B\u00255D\u00252C\u002522content_timestamp\u002522\u00253A\u0025221344557646\u002522\u00252C\u002522check_hash\u002522\u00253A\u002522AQDIPpRc_NCu6XoF\u002522\u00252C\u002522source\u002522\u00253A\u00252213\u002522\u00257D\"></a><div data-ft=\"&#123;&quot;type&quot;:33,&quot;tn&quot;:&quot;K&quot;&#125;\" class=\"UIImageBlock_Content UIImageBlock_SMALL_Content\"><div class=\"commentContent\"><a class=\"actorName\" href=\"http://www.facebook.com/LawlabeeTheWallaby\" data-ft=\"&#123;&quot;type&quot;:35,&quot;tn&quot;:&quot;;&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=1055580469\">Gregor Richards</a> <span data-jsid=\"text\" class=\"commentBody\">‎&#064;Cici: … no comment.<br /> <br /> &#064;Jayaram: ??????<br /> <br /> &#064;Jo: Apparently anything I do is though, now? ;)<br /> <br /> - Y&#039;know what&#039;s funny? That jacket is sort of a light cobalt blue. It&#039;s not grey. It looks grey in the photo, and I blame the pants ^^</span><span></span></div><div class=\"commentActions fsm fwn fcg\"><a class=\"uiLinkSubtle\" href=\"http://www.facebook.com/photo.php?fbid=3688952976504&amp;set=a.1138433375108.2021456.1055580469&amp;type=1&amp;comment_id=2422741&amp;offset=0&amp;total_comments=11\" data-ft=\"&#123;&quot;tn&quot;:&quot;N&quot;&#125;\"><abbr title=\"Friday, August 10, 2012 at 10:59pm\" data-utime=\"1344653978\">Friday at 10:59pm</abbr></a> · <span class=\"comment_like_2422741 fsm fwn fcg\" data-ft=\"&#123;&quot;type&quot;:36,&quot;tn&quot;:&quot;&gt;&quot;&#125;\"><button class=\"stat_elem as_link cmnt_like_link\" type=\"submit\" name=\"like_comment_id[2422741]\" value=\"2422741\" title=\"Like this comment\"><span class=\"default_message\">Like</span><span class=\"saving_message\">Unlike</span></button> · <a data-hover=\"tooltip\" data-tooltip-uri=\"/ajax/like/tooltip.php?comment_fbid=3692779032153&amp;comment_from=1055580469\" data-tooltip-alignh=\"center\" class=\"comment_like_button\" rel=\"dialog\" href=\"/browse/likes/?id=3692779032153\" ajaxify=\"/ajax/browser/dialog/likes/?id=3692779032153\"><i class=\"cmt_like_icon\"></i>1</a></span></div></div></div></li><li class=\"uiUfiComment comment_2422886 ufiItem ufiItem\" data-ft=\"&#123;&quot;tn&quot;:&quot;R&quot;&#125;\"><div class=\"UIImageBlock clearfix uiUfiActorBlock\"><a class=\"actorPic UIImageBlock_Image UIImageBlock_SMALL_Image\" href=\"http://www.facebook.com/jo.thorpe.10\" tabindex=\"-1\" data-ft=\"&#123;&quot;type&quot;:34,&quot;tn&quot;:&quot;T&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=100002324364222\"><img class=\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__medium img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/371306_100002324364222_1706353699_q.jpg\" alt=\"\" /></a><a data-hover=\"tooltip\" title=\"Hide as Spam\" class=\"commentRemoverButton UIImageBlock_Ext uiCloseButton\" href=\"#\" role=\"button\" rel=\"async-post\" ajaxify=\"/ajax/ufi/one_click_remove?comment_id=2422886&amp;commenter_id=100002324364222&amp;profile_id=1055580469&amp;post_fbid=3692989517415&amp;can_remove=0&amp;can_report=1&amp;can_edit=0&amp;is_spam=0&amp;report_link=\u00252Fajax\u00252Freport.php\u00253Fcontent_type\u00253D71\u002526cid\u00253D3692989517415\u002526rid\u00253D100002324364222\u002526cid2\u00253D0\u002526profile\u00253D1055580469\u002526h\u00253DAfgrwwponrdrtd3E&amp;feedback_params=\u00257B\u002522actor\u002522\u00253A\u0025221055580469\u002522\u00252C\u002522target_fbid\u002522\u00253A\u0025223688952976504\u002522\u00252C\u002522target_profile_id\u002522\u00253A\u0025221055580469\u002522\u00252C\u002522type_id\u002522\u00253A\u0025227\u002522\u00252C\u002522assoc_obj_id\u002522\u00253A\u002522\u002522\u00252C\u002522source_app_id\u002522\u00253A\u002522\u002522\u00252C\u002522extra_story_params\u002522\u00253A\u00255B\u00255D\u00252C\u002522content_timestamp\u002522\u00253A\u0025221344557646\u002522\u00252C\u002522check_hash\u002522\u00253A\u002522AQDIPpRc_NCu6XoF\u002522\u00252C\u002522source\u002522\u00253A\u00252213\u002522\u00257D\"></a><div data-ft=\"&#123;&quot;type&quot;:33,&quot;tn&quot;:&quot;K&quot;&#125;\" class=\"UIImageBlock_Content UIImageBlock_SMALL_Content\"><div class=\"commentContent\"><a class=\"actorName\" href=\"http://www.facebook.com/jo.thorpe.10\" data-ft=\"&#123;&quot;type&quot;:35,&quot;tn&quot;:&quot;;&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=100002324364222\">Jo Thorpe</a> <span data-jsid=\"text\" class=\"commentBody\">It&#039;s the colors yo. He&#039;s always wearing bright pastels, snappy dresser.</span><span></span></div><div class=\"commentActions fsm fwn fcg\"><a class=\"uiLinkSubtle\" href=\"http://www.facebook.com/photo.php?fbid=3688952976504&amp;set=a.1138433375108.2021456.1055580469&amp;type=1&amp;comment_id=2422886&amp;offset=0&amp;total_comments=11\" data-ft=\"&#123;&quot;tn&quot;:&quot;N&quot;&#125;\"><abbr title=\"Saturday, August 11, 2012 at 12:41am\" data-utime=\"1344660097\">Saturday at 12:41am</abbr></a> · <span class=\"comment_like_2422886 fsm fwn fcg\" data-ft=\"&#123;&quot;type&quot;:36,&quot;tn&quot;:&quot;&gt;&quot;&#125;\"><button class=\"stat_elem as_link cmnt_like_link\" type=\"submit\" name=\"like_comment_id[2422886]\" value=\"2422886\" title=\"Like this comment\"><span class=\"default_message\">Like</span><span class=\"saving_message\">Unlike</span></button></span></div></div></div></li></ul></li><li class=\"uiUfiAddComment clearfix uiUfiSmall ufiItem ufiItem uiListItem  uiListVerticalItemBorder\" data-ft=\"&#123;&quot;tn&quot;:&quot;[&quot;&#125;\"><div class=\"UIImageBlock clearfix mentionsAddComment\"><img class=\"-cx-PRIVATE-uiSquareImage__root actorPic UIImageBlock_Image UIImageBlock_ICON_Image -cx-PRIVATE-uiSquareImage__medium img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-ash2/275624_100001812504199_1255023530_q.jpg\" alt=\"\" /><div class=\"commentArea UIImageBlock_Content UIImageBlock_ICON_Content\"><div class=\"commentBox\"><div class=\"uiMentionsInput textBoxContainer\" id=\"uq3j2t_17\"><div class=\"highlighter\"><div><span class=\"highlighterContent\"></span></div></div><div class=\"uiTypeahead mentionsTypeahead\" id=\"uq3j2t_18\"><div class=\"wrap\"><input type=\"hidden\" autocomplete=\"off\" class=\"hiddenInput\" /><div class=\"innerWrap\"><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function e4297755604d278364313f6f944c8b009684c811d(event) {\\u000a    Bootloader.loadComponents([\\\"control-textarea\\\",], function() {\\u000a        TextAreaControl.getInstance(this);\\u000a    }.bind(this));\\u000a};\"), (\"sb7d558e3925575e7a553eec62aa6b924680263b1\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction e4297755604d278364313f6f944c8b009684c811d(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"sb7d558e3925575e7a553eec62aa6b924680263b1_0\"), (sb7d558e3925575e7a553eec62aa6b924680263b1_0_instance), (this), (arguments)))\n    };\n    (null);\n    (((JSBNG_Record.get)(Bootloader, (\"loadComponents\")))[(\"loadComponents\")])([\"control-textarea\",], (((JSBNG_Record.get)(((function() {\n        var sb7d558e3925575e7a553eec62aa6b924680263b1_1_instance;\n        ((sb7d558e3925575e7a553eec62aa6b924680263b1_1_instance) = ((JSBNG_Record.eventInstance)((\"sb7d558e3925575e7a553eec62aa6b924680263b1_1\"))));\n        return ((JSBNG_Record.markFunction)((function() {\n            if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n                return ((JSBNG_Record.eventCall)((arguments.callee), (\"sb7d558e3925575e7a553eec62aa6b924680263b1_1\"), (sb7d558e3925575e7a553eec62aa6b924680263b1_1_instance), (this), (arguments)))\n            };\n            (null);\n            (((JSBNG_Record.get)(TextAreaControl, (\"getInstance\")))[(\"getInstance\")])(this);\n        })));\n    })()), (\"bind\")))[(\"bind\")])(this));\n};\nvar sb7d558e3925575e7a553eec62aa6b924680263b1_0_instance;\n((sb7d558e3925575e7a553eec62aa6b924680263b1_0_instance) = ((JSBNG_Record.eventInstance)((\"sb7d558e3925575e7a553eec62aa6b924680263b1_0\"))));\n((JSBNG_Record.markFunction)((e4297755604d278364313f6f944c8b009684c811d)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><textarea class=\"enter_submit DOMControl_placeholder uiTextareaNoResize uiTextareaAutogrow textBox mentionsTextarea textInput\" title=\"Write a comment...\" placeholder=\"Write a comment...\" name=\"add_comment_text\" autocomplete=\"off\" aria-autocomplete=\"list\" aria-expanded=\"false\" aria-invalid=\"false\" aria-owns=\"typeahead_list_uq3j2t_18\" role=\"textbox\" onkeydown=\"return e4297755604d278364313f6f944c8b009684c811d.call(this, event);\" id=\"uq3j2t_19\">Write a comment...</textarea></div></div></div><input type=\"hidden\" autocomplete=\"off\" class=\"mentionsHidden\" /></div></div><label class=\"mts commentBtn stat_elem hidden_elem optimistic_submit uiButton uiButtonConfirm\" for=\"uq3j2t_20\"><input value=\"Comment\" class=\"enter_submit_target\" name=\"comment\" type=\"submit\" id=\"uq3j2t_20\" /></label></div></div></li></ul></div></form></div><div class=\"-cx-PRIVATE-uiInlineBlock__root  mlm uiPopover highlightSelector uiStreamHide\" data-ft=\"&#123;&quot;type&quot;:55,&quot;tn&quot;:&quot;V&quot;&#125;\" id=\"uq3j2t_4\"><a class=\"highlightSelectorButton uiStreamContextButton -cx-PRIVATE-uiPopover__trigger\" href=\"#\" aria-haspopup=\"true\" aria-expanded=\"false\" rel=\"toggle\" id=\"uq3j2t_5\">Options</a></div></div></div></li><li class=\"uiUnifiedStory uiStreamStory genericStreamStory aid_1055580469 uiListItem uiListLight uiListVerticalItemBorder\" data-ft=\"&#123;&quot;qid&quot;:&quot;5776181494237290802&quot;,&quot;mf_story_key&quot;:&quot;8438955046610351598&quot;&#125;\" id=\"stream_story_50291e77421b58760782402\"><div class=\"clearfix storyContent\"><a class=\"actorPhoto lfloat\" href=\"http://www.facebook.com/LawlabeeTheWallaby\" tabindex=\"-1\" aria-hidden=\"true\" data-ft=\"&#123;&quot;type&quot;:60,&quot;tn&quot;:&quot;\\\\u003C&quot;&#125;\" data-hovercard=\"/ajax/hovercard/hovercard.php?id=1055580469\"><img class=\"-cx-PRIVATE-uiSquareImage__root profilePic -cx-PRIVATE-uiSquareImage__large img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/157194_1055580469_1433282671_q.jpg\" alt=\"\" /></a><div class=\"storyInnerContent\"><div class=\"mainWrapper\"><h6 class=\"uiStreamMessage uiStreamHeadline\" data-ft=\"&#123;&quot;tn&quot;:&quot;:&quot;&#125;\"><div class=\"actorDescription actorName\" data-ft=\"&#123;&quot;type&quot;:2,&quot;tn&quot;:&quot;:&quot;&#125;\"><a href=\"http://www.facebook.com/LawlabeeTheWallaby\" data-ft=\"&#123;&quot;tn&quot;:&quot;;&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=1055580469\">Gregor Richards</a></div></h6><h6 class=\"uiStreamMessage\" data-ft=\"&#123;&quot;type&quot;:1,&quot;tn&quot;:&quot;K&quot;&#125;\"> <span class=\"messageBody\" data-ft=\"&#123;&quot;type&quot;:3&#125;\"><div>I linked this a few days ago, but now I&#039;m linking it again anyway. Anyone who thinks they don&#039;t like the accordion needs to listen to this. I&#039;ve been listening to it on loop for DAYS. (Well, OK, not quite, but I&#039;ve listened to it a lot)<br /> <br /> Part I: <script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function eff2146ce326494096be3c9e775f440c3b7efa7af(event) {\\u000a    LinkshimAsyncLink.swap(this, \\\"http:\\\\\\\\/\\\\\\\\/youtu.be\\\\\\\\/pkV6hX66HO0\\\");\\u000a};\"), (\"s017addfff779a4d3cabec883d930843a533753b6\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction eff2146ce326494096be3c9e775f440c3b7efa7af(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s017addfff779a4d3cabec883d930843a533753b6_0\"), (s017addfff779a4d3cabec883d930843a533753b6_0_instance), (this), (arguments)))\n    };\n    (null);\n    (((JSBNG_Record.get)(LinkshimAsyncLink, (\"swap\")))[(\"swap\")])(this, \"http:\\\\/\\\\/youtu.be\\\\/pkV6hX66HO0\");\n};\nvar s017addfff779a4d3cabec883d930843a533753b6_0_instance;\n((s017addfff779a4d3cabec883d930843a533753b6_0_instance) = ((JSBNG_Record.eventInstance)((\"s017addfff779a4d3cabec883d930843a533753b6_0\"))));\n((JSBNG_Record.markFunction)((eff2146ce326494096be3c9e775f440c3b7efa7af)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function eb69bde7a80cf88e01a4a37ca97ada8e957a59d2b(event) {\\u000a    LinkshimAsyncLink.referrer_log(this, \\\"http:\\\\\\\\/\\\\\\\\/youtu.be\\\\\\\\/pkV6hX66HO0\\\", \\\"http:\\\\\\\\/\\\\\\\\/www.facebook.com\\\\\\\\/si\\\\\\\\/ajax\\\\\\\\/l\\\\\\\\/render_linkshim_log\\\\\\\\/?u=http\\\\\\\\u00253A\\\\\\\\u00252F\\\\\\\\u00252Fyoutu.be\\\\\\\\u00252FpkV6hX66HO0&h=EAQFbYwsLAQHKxGOFyeXa9v-zPmVwZS1Nyh8rLQuruWMQiA&s=1\\\");\\u000a};\"), (\"s05e2ee762d787bf210e864c37aa6e632b9d48e33\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction eb69bde7a80cf88e01a4a37ca97ada8e957a59d2b(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s05e2ee762d787bf210e864c37aa6e632b9d48e33_0\"), (s05e2ee762d787bf210e864c37aa6e632b9d48e33_0_instance), (this), (arguments)))\n    };\n    (null);\n    (((JSBNG_Record.get)(LinkshimAsyncLink, (\"referrer_log\")))[(\"referrer_log\")])(this, \"http:\\\\/\\\\/youtu.be\\\\/pkV6hX66HO0\", \"http:\\\\/\\\\/www.facebook.com\\\\/si\\\\/ajax\\\\/l\\\\/render_linkshim_log\\\\/?u=http\\\\u00253A\\\\u00252F\\\\u00252Fyoutu.be\\\\u00252FpkV6hX66HO0&h=EAQFbYwsLAQHKxGOFyeXa9v-zPmVwZS1Nyh8rLQuruWMQiA&s=1\");\n};\nvar s05e2ee762d787bf210e864c37aa6e632b9d48e33_0_instance;\n((s05e2ee762d787bf210e864c37aa6e632b9d48e33_0_instance) = ((JSBNG_Record.eventInstance)((\"s05e2ee762d787bf210e864c37aa6e632b9d48e33_0\"))));\n((JSBNG_Record.markFunction)((eb69bde7a80cf88e01a4a37ca97ada8e957a59d2b)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><a href=\"/l.php?u=http\u00253A\u00252F\u00252Fyoutu.be\u00252FpkV6hX66HO0&amp;h=EAQFbYwsLAQHKxGOFyeXa9v-zPmVwZS1Nyh8rLQuruWMQiA&amp;s=1\" target=\"_blank\" rel=\"nofollow nofollow\" onmouseover=\"return eff2146ce326494096be3c9e775f440c3b7efa7af.call(this, event);\" onclick=\"return eb69bde7a80cf88e01a4a37ca97ada8e957a59d2b.call(this, event);\">http://youtu.be/pkV6hX66HO0</a><br /> Part II: <script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function e1e3199ca27b3c42d29948f149786411c1581ae6b(event) {\\u000a    LinkshimAsyncLink.swap(this, \\\"http:\\\\\\\\/\\\\\\\\/youtu.be\\\\\\\\/FvNmA7FSCW0\\\");\\u000a};\"), (\"sdd4bbe8de8c7551301b45f4b40aca4653f50b0d1\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction e1e3199ca27b3c42d29948f149786411c1581ae6b(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"sdd4bbe8de8c7551301b45f4b40aca4653f50b0d1_0\"), (sdd4bbe8de8c7551301b45f4b40aca4653f50b0d1_0_instance), (this), (arguments)))\n    };\n    (null);\n    (((JSBNG_Record.get)(LinkshimAsyncLink, (\"swap\")))[(\"swap\")])(this, \"http:\\\\/\\\\/youtu.be\\\\/FvNmA7FSCW0\");\n};\nvar sdd4bbe8de8c7551301b45f4b40aca4653f50b0d1_0_instance;\n((sdd4bbe8de8c7551301b45f4b40aca4653f50b0d1_0_instance) = ((JSBNG_Record.eventInstance)((\"sdd4bbe8de8c7551301b45f4b40aca4653f50b0d1_0\"))));\n((JSBNG_Record.markFunction)((e1e3199ca27b3c42d29948f149786411c1581ae6b)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function ec7bbce58245a0417c63798b6757cb528eaa5a1cb(event) {\\u000a    LinkshimAsyncLink.referrer_log(this, \\\"http:\\\\\\\\/\\\\\\\\/youtu.be\\\\\\\\/FvNmA7FSCW0\\\", \\\"http:\\\\\\\\/\\\\\\\\/www.facebook.com\\\\\\\\/si\\\\\\\\/ajax\\\\\\\\/l\\\\\\\\/render_linkshim_log\\\\\\\\/?u=http\\\\\\\\u00253A\\\\\\\\u00252F\\\\\\\\u00252Fyoutu.be\\\\\\\\u00252FFvNmA7FSCW0&h=QAQFT_bkjAQFjbw53EOR4OTwhkjOXgSjk9COrg3ZjAvHKQQ&s=1\\\");\\u000a};\"), (\"s3452c4a42ec6451cf50803b7fd0b5ee07fb940f8\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction ec7bbce58245a0417c63798b6757cb528eaa5a1cb(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s3452c4a42ec6451cf50803b7fd0b5ee07fb940f8_0\"), (s3452c4a42ec6451cf50803b7fd0b5ee07fb940f8_0_instance), (this), (arguments)))\n    };\n    (null);\n    (((JSBNG_Record.get)(LinkshimAsyncLink, (\"referrer_log\")))[(\"referrer_log\")])(this, \"http:\\\\/\\\\/youtu.be\\\\/FvNmA7FSCW0\", \"http:\\\\/\\\\/www.facebook.com\\\\/si\\\\/ajax\\\\/l\\\\/render_linkshim_log\\\\/?u=http\\\\u00253A\\\\u00252F\\\\u00252Fyoutu.be\\\\u00252FFvNmA7FSCW0&h=QAQFT_bkjAQFjbw53EOR4OTwhkjOXgSjk9COrg3ZjAvHKQQ&s=1\");\n};\nvar s3452c4a42ec6451cf50803b7fd0b5ee07fb940f8_0_instance;\n((s3452c4a42ec6451cf50803b7fd0b5ee07fb940f8_0_instance) = ((JSBNG_Record.eventInstance)((\"s3452c4a42ec6451cf50803b7fd0b5ee07fb940f8_0\"))));\n((JSBNG_Record.markFunction)((ec7bbce58245a0417c63798b6757cb528eaa5a1cb)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><a href=\"/l.php?u=http\u00253A\u00252F\u00252Fyoutu.be\u00252FFvNmA7FSCW0&amp;h=QAQFT_bkjAQFjbw53EOR4OTwhkjOXgSjk9COrg3ZjAvHKQQ&amp;s=1\" target=\"_blank\" rel=\"nofollow nofollow\" onmouseover=\"return e1e3199ca27b3c42d29948f149786411c1581ae6b.call(this, event);\" onclick=\"return ec7bbce58245a0417c63798b6757cb528eaa5a1cb.call(this, event);\">http://youtu.be/FvNmA7FSCW0</a></div></span></h6><div class=\"mvm uiStreamAttachments fbMainStreamAttachment\" data-ft=\"&#123;&quot;type&quot;:10,&quot;tn&quot;:&quot;H&quot;&#125;\"><div><div class=\"shareRedesign\"><div class=\"clearfix shareRedesignContainer\"><div class=\"-cx-PRIVATE-uiInlineBlock__root shareRedesignVideo shareRedesignMedia -cx-PRIVATE-uiImageBlock__image  lfloat\" id=\"uq3j2t_7\"><div class=\"-cx-PRIVATE-uiInlineBlock__root -cx-PRIVATE-uiInlineBlock__middle\" style=\"height:90px\"></div><div class=\"-cx-PRIVATE-uiInlineBlock__root -cx-PRIVATE-uiInlineBlock__middle\"><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function e5a466b1ad373c92e44c1c55887aed1c7a600d83a(event) {\\u000a    CSS.addClass(this, \\\"uiVideoThumbLoading\\\");\\u000a};\"), (\"s7fee7671dd07b4f44cc1515bc0dd5153b263ffa4\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction e5a466b1ad373c92e44c1c55887aed1c7a600d83a(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s7fee7671dd07b4f44cc1515bc0dd5153b263ffa4_0\"), (s7fee7671dd07b4f44cc1515bc0dd5153b263ffa4_0_instance), (this), (arguments)))\n    };\n    (null);\n    (((JSBNG_Record.get)(CSS, (\"addClass\")))[(\"addClass\")])(this, \"uiVideoThumbLoading\");\n};\nvar s7fee7671dd07b4f44cc1515bc0dd5153b263ffa4_0_instance;\n((s7fee7671dd07b4f44cc1515bc0dd5153b263ffa4_0_instance) = ((JSBNG_Record.eventInstance)((\"s7fee7671dd07b4f44cc1515bc0dd5153b263ffa4_0\"))));\n((JSBNG_Record.markFunction)((e5a466b1ad373c92e44c1c55887aed1c7a600d83a)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><a class=\"uiVideoThumb shareMediaVideo\" href=\"\" ajaxify=\"/ajax/flash/expand_inline.php?replace=1&amp;target_div=uq3j2t_7&amp;context=story&amp;bgcolor=\u002523f7f7f7&amp;share_id=427041767338328\" rel=\"async\" onclick=\"return e5a466b1ad373c92e44c1c55887aed1c7a600d83a.call(this, event);\" id=\"uq3j2t_6\" target=\"_blank\" data-ft=\"&#123;&quot;video_type&quot;:&quot;share&quot;,&quot;type&quot;:42,&quot;tn&quot;:&quot;F&quot;&#125;\"><img class=\"img\" src=\"http://external.ak.fbcdn.net/safe_image.php?d=AQDmWbko-9TeikYo&amp;url=http\u00253A\u00252F\u00252Fi1.ytimg.com\u00252Fvi\u00252FpkV6hX66HO0\u00252Fmqdefault.jpg\" alt=\"\" /><i></i></a></div></div><div class=\"-cx-PRIVATE-uiImageBlock__content \"><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function e71217b959a7ce4c65c5fc7f96cf5c2c7bf69c63e(event) {\\u000a    LinkshimAsyncLink.swap(this, \\\"http:\\\\\\\\/\\\\\\\\/youtu.be\\\\\\\\/pkV6hX66HO0\\\");\\u000a};\"), (\"s9dc73c6e5cb7005c646b280441e8610338abff73\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction e71217b959a7ce4c65c5fc7f96cf5c2c7bf69c63e(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s9dc73c6e5cb7005c646b280441e8610338abff73_0\"), (s9dc73c6e5cb7005c646b280441e8610338abff73_0_instance), (this), (arguments)))\n    };\n    (null);\n    (((JSBNG_Record.get)(LinkshimAsyncLink, (\"swap\")))[(\"swap\")])(this, \"http:\\\\/\\\\/youtu.be\\\\/pkV6hX66HO0\");\n};\nvar s9dc73c6e5cb7005c646b280441e8610338abff73_0_instance;\n((s9dc73c6e5cb7005c646b280441e8610338abff73_0_instance) = ((JSBNG_Record.eventInstance)((\"s9dc73c6e5cb7005c646b280441e8610338abff73_0\"))));\n((JSBNG_Record.markFunction)((e71217b959a7ce4c65c5fc7f96cf5c2c7bf69c63e)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function e60aa07d624600f565b2928b1f3227de2aeaeb4f8(event) {\\u000a    LinkshimAsyncLink.referrer_log(this, \\\"http:\\\\\\\\/\\\\\\\\/youtu.be\\\\\\\\/pkV6hX66HO0\\\", \\\"http:\\\\\\\\/\\\\\\\\/www.facebook.com\\\\\\\\/si\\\\\\\\/ajax\\\\\\\\/l\\\\\\\\/render_linkshim_log\\\\\\\\/?u=http\\\\\\\\u00253A\\\\\\\\u00252F\\\\\\\\u00252Fyoutu.be\\\\\\\\u00252FpkV6hX66HO0&h=2AQFK5pwR&s=1\\\");\\u000a};\"), (\"s3636d776fba70a71ce8704384f1926627d62c07d\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction e60aa07d624600f565b2928b1f3227de2aeaeb4f8(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s3636d776fba70a71ce8704384f1926627d62c07d_0\"), (s3636d776fba70a71ce8704384f1926627d62c07d_0_instance), (this), (arguments)))\n    };\n    (null);\n    (((JSBNG_Record.get)(LinkshimAsyncLink, (\"referrer_log\")))[(\"referrer_log\")])(this, \"http:\\\\/\\\\/youtu.be\\\\/pkV6hX66HO0\", \"http:\\\\/\\\\/www.facebook.com\\\\/si\\\\/ajax\\\\/l\\\\/render_linkshim_log\\\\/?u=http\\\\u00253A\\\\u00252F\\\\u00252Fyoutu.be\\\\u00252FpkV6hX66HO0&h=2AQFK5pwR&s=1\");\n};\nvar s3636d776fba70a71ce8704384f1926627d62c07d_0_instance;\n((s3636d776fba70a71ce8704384f1926627d62c07d_0_instance) = ((JSBNG_Record.eventInstance)((\"s3636d776fba70a71ce8704384f1926627d62c07d_0\"))));\n((JSBNG_Record.markFunction)((e60aa07d624600f565b2928b1f3227de2aeaeb4f8)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><a class=\"pam shareText\" href=\"/l.php?u=http\u00253A\u00252F\u00252Fyoutu.be\u00252FpkV6hX66HO0&amp;h=2AQFK5pwR&amp;s=1\" rel=\"nofollow\" onmouseover=\"return e71217b959a7ce4c65c5fc7f96cf5c2c7bf69c63e.call(this, event);\" onclick=\"return e60aa07d624600f565b2928b1f3227de2aeaeb4f8.call(this, event);\" target=\"_blank\"><div class=\"attachmentText fsm fwn fcg\"><div class=\"uiAttachmentTitle\" data-ft=\"&#123;&quot;type&quot;:11,&quot;tn&quot;:&quot;C&quot;&#125;\"><strong>Aleksandr Hrustevich, accordion / Juri Gilbo, conductor (Part I)</strong> </div><span class=\"caption\" data-ft=\"&#123;&quot;tn&quot;:&quot;L&quot;&#125;\">www.youtube.com</span><div class=\"mts uiAttachmentDesc translationEligibleUserAttachmentMessage\" data-ft=\"&#123;&quot;tn&quot;:&quot;M&quot;&#125;\">A. Zubitsky &quot;Omaggio ad Astor Piazzolla&quot; Russian Chamber Philharmonic St. Petersburg / Russische Kammerphilharmonie St.Petersburg Aleksandr Hrustevich, accor...</div></div></a></div></div><div class=\"shareRedesignTopBorder\"></div><div class=\"shareRedesignRightBorder\"></div><div class=\"shareRedesignBottomBorder\"></div></div></div></div><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function e18ebcdc7906bbe702866dbaee677261c520ffecd(event) {\\u000a    return Event.__inlineSubmit(this, event);\\u000a};\"), (\"s3671dff878f13e17153ae094b2a98206a0a6ee4e\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction e18ebcdc7906bbe702866dbaee677261c520ffecd(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s3671dff878f13e17153ae094b2a98206a0a6ee4e_0\"), (s3671dff878f13e17153ae094b2a98206a0a6ee4e_0_instance), (this), (arguments)))\n    };\n    (null);\n    return (((JSBNG_Record.get)(JSBNG__Event, (\"__inlineSubmit\")))[(\"__inlineSubmit\")])(this, JSBNG__event);\n};\nvar s3671dff878f13e17153ae094b2a98206a0a6ee4e_0_instance;\n((s3671dff878f13e17153ae094b2a98206a0a6ee4e_0_instance) = ((JSBNG_Record.eventInstance)((\"s3671dff878f13e17153ae094b2a98206a0a6ee4e_0\"))));\n((JSBNG_Record.markFunction)((e18ebcdc7906bbe702866dbaee677261c520ffecd)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><form rel=\"async\" class=\"live_427041767338328_131325686911214 commentable_item autoexpand_mode\" method=\"post\" action=\"/ajax/ufi/modify.php\" data-live=\"&#123;&quot;seq&quot;:4815740&#125;\" onsubmit=\"return e18ebcdc7906bbe702866dbaee677261c520ffecd.call(this, event);\" id=\"uq3j2t_31\"><input type=\"hidden\" name=\"charset_test\" value=\"&euro;,&acute;,€,´,水,Д,Є\" /><input type=\"hidden\" name=\"fb_dtsg\" value=\"AQCc21Em\" autocomplete=\"off\" /><input type=\"hidden\" autocomplete=\"off\" name=\"feedback_params\" value=\"&#123;&quot;actor&quot;:&quot;1055580469&quot;,&quot;target_fbid&quot;:&quot;427041767338328&quot;,&quot;target_profile_id&quot;:&quot;1055580469&quot;,&quot;type_id&quot;:&quot;17&quot;,&quot;assoc_obj_id&quot;:&quot;&quot;,&quot;source_app_id&quot;:&quot;0&quot;,&quot;extra_story_params&quot;:[],&quot;content_timestamp&quot;:&quot;1344632723&quot;,&quot;check_hash&quot;:&quot;AQBTZdjKUuiS7RK6&quot;,&quot;source&quot;:&quot;1&quot;&#125;\" /><span class=\"uiStreamFooter\"><span class=\"UIActionLinks UIActionLinks_bottom\" data-ft=\"&#123;&quot;tn&quot;:&quot;=&quot;,&quot;type&quot;:20&#125;\"><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function e0332583f9799b9cf532d38a5d160fa2c4428a35a(event) {\\u000a    fc_click(this, false);\\u000a    return true;\\u000a};\"), (\"sfda439b0bd8321b8ca2824524bf6bd655c9685c7\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction e0332583f9799b9cf532d38a5d160fa2c4428a35a(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"sfda439b0bd8321b8ca2824524bf6bd655c9685c7_0\"), (sfda439b0bd8321b8ca2824524bf6bd655c9685c7_0_instance), (this), (arguments)))\n    };\n    (null);\n    fc_click(this, false);\n    return true;\n};\nvar sfda439b0bd8321b8ca2824524bf6bd655c9685c7_0_instance;\n((sfda439b0bd8321b8ca2824524bf6bd655c9685c7_0_instance) = ((JSBNG_Record.eventInstance)((\"sfda439b0bd8321b8ca2824524bf6bd655c9685c7_0\"))));\n((JSBNG_Record.markFunction)((e0332583f9799b9cf532d38a5d160fa2c4428a35a)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><button class=\"like_link stat_elem as_link\" title=\"Like this item\" type=\"submit\" name=\"like\" onclick=\"return e0332583f9799b9cf532d38a5d160fa2c4428a35a.call(this, event);\" data-ft=\"&#123;&quot;tn&quot;:&quot;&gt;&quot;,&quot;type&quot;:22&#125;\"><span class=\"default_message\">Like</span><span class=\"saving_message\">Unlike</span></button> &#183; <label class=\"uiLinkButton comment_link\" title=\"Leave a comment\"><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function ef1124247c0678dc45fa44d349143bc81f8fcb4d5(event) {\\u000a    return fc_click(this);\\u000a};\"), (\"s68c7097e58b9c5c40fcec0f92c03ab6f3fa93991\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction ef1124247c0678dc45fa44d349143bc81f8fcb4d5(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s68c7097e58b9c5c40fcec0f92c03ab6f3fa93991_0\"), (s68c7097e58b9c5c40fcec0f92c03ab6f3fa93991_0_instance), (this), (arguments)))\n    };\n    (null);\n    return fc_click(this);\n};\nvar s68c7097e58b9c5c40fcec0f92c03ab6f3fa93991_0_instance;\n((s68c7097e58b9c5c40fcec0f92c03ab6f3fa93991_0_instance) = ((JSBNG_Record.eventInstance)((\"s68c7097e58b9c5c40fcec0f92c03ab6f3fa93991_0\"))));\n((JSBNG_Record.markFunction)((ef1124247c0678dc45fa44d349143bc81f8fcb4d5)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><input data-ft=\"&#123;&quot;type&quot;:24,&quot;tn&quot;:&quot;S&quot;&#125;\" type=\"button\" value=\"Comment\" onclick=\"return ef1124247c0678dc45fa44d349143bc81f8fcb4d5.call(this, event);\"></label> &#183; <a class=\"share_action_link\" href=\"/ajax/sharer/?s=99&amp;appid=2309869772&amp;p\u00255B0\u00255D=1055580469&amp;p\u00255B1\u00255D=427041767338328\" rel=\"dialog\" data-ft=\"&#123;&quot;tn&quot;:&quot;J&quot;,&quot;type&quot;:25&#125;\" title=\"Send this to friends or post it on your timeline.\">Share</a> &#183; </span><span class=\"uiStreamSource\" data-ft=\"&#123;&quot;type&quot;:26,&quot;tn&quot;:&quot;N&quot;&#125;\"><a href=\"/LawlabeeTheWallaby/posts/427041767338328\"><abbr title=\"Friday, August 10, 2012 at 5:05pm\" data-utime=\"1344632723\">Friday at 5:05pm</abbr></a></span> · <a data-hover=\"tooltip\" title=\"Shared with: Public\" class=\"uiStreamPrivacy inlineBlock fbStreamPrivacy fbPrivacyAudienceIndicator\" href=\"#\"><i class=\"lock img sp_67189i sx_767b12\"></i></a></span><div><ul class=\"uiList uiUfi focus_target fbUfi fbUfiNoBorder\" data-ft=\"&#123;&quot;type&quot;:30,&quot;tn&quot;:&quot;]&quot;&#125;\"><li class=\"ufiNub uiListItem  uiListVerticalItemBorder\"><i></i></li><li class=\"hidden_elem uiUfiLike uiListItem  uiListVerticalItemBorder\" data-ft=\"&#123;&quot;type&quot;:31&#125;\"></li><li class=\"translateable_info hidden_elem uiListItem  uiListVerticalItemBorder\"><input type=\"hidden\" autocomplete=\"off\" name=\"translate_on_load\" value=\"\" /></li><li class=\"uiUfiComments uiListItem  uiListVerticalItemBorder\" data-ft=\"&#123;&quot;type&quot;:32&#125;\"><ul class=\"commentList\"><li class=\"uiUfiViewAll  ufiItem\"><label class=\"uiIconText uiLinkButton async_throbber\"><i class=\"img sp_627qpw sx_4fad2b\"></i><input type=\"submit\" name=\"view_all[1]\" value=\"View all 12 comments\" data-ft=\"&#123;&quot;tn&quot;:&quot;Q&quot;&#125;\" class=\"stat_elem\" /></label></li><li class=\"uiUfiComment comment_4812064 ufiItem ufiItem\" data-ft=\"&#123;&quot;tn&quot;:&quot;R0&quot;&#125;\"><div class=\"UIImageBlock clearfix uiUfiActorBlock\"><a class=\"actorPic UIImageBlock_Image UIImageBlock_SMALL_Image\" href=\"http://www.facebook.com/TheJMoore\" tabindex=\"-1\" data-ft=\"&#123;&quot;type&quot;:34,&quot;tn&quot;:&quot;T&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=1164240897\"><img class=\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__medium img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/211990_1164240897_1932494148_q.jpg\" alt=\"\" /></a><a data-hover=\"tooltip\" title=\"Hide as Spam\" class=\"commentRemoverButton UIImageBlock_Ext uiCloseButton\" href=\"#\" role=\"button\" rel=\"async-post\" ajaxify=\"/ajax/ufi/one_click_remove?comment_id=4812064&amp;commenter_id=1164240897&amp;profile_id=1055580469&amp;post_fbid=427103580665480&amp;can_remove=0&amp;can_report=1&amp;can_edit=0&amp;is_spam=0&amp;report_link=\u00252Fajax\u00252Freport.php\u00253Fcontent_type\u00253D74\u002526cid\u00253D427103580665480\u002526rid\u00253D1164240897\u002526cid2\u00253D0\u002526profile\u00253D1055580469\u002526h\u00253DAfgaUtRwQdIBtUco&amp;feedback_params=\u00257B\u002522actor\u002522\u00253A\u0025221055580469\u002522\u00252C\u002522target_fbid\u002522\u00253A\u002522427041767338328\u002522\u00252C\u002522target_profile_id\u002522\u00253A\u0025221055580469\u002522\u00252C\u002522type_id\u002522\u00253A\u00252217\u002522\u00252C\u002522assoc_obj_id\u002522\u00253A\u002522\u002522\u00252C\u002522source_app_id\u002522\u00253A\u0025220\u002522\u00252C\u002522extra_story_params\u002522\u00253A\u00255B\u00255D\u00252C\u002522content_timestamp\u002522\u00253A\u0025221344632723\u002522\u00252C\u002522check_hash\u002522\u00253A\u002522AQBTZdjKUuiS7RK6\u002522\u00252C\u002522source\u002522\u00253A\u00252213\u002522\u00257D\"></a><div data-ft=\"&#123;&quot;type&quot;:33,&quot;tn&quot;:&quot;K&quot;&#125;\" class=\"UIImageBlock_Content UIImageBlock_SMALL_Content\"><div class=\"commentContent\"><a class=\"actorName\" href=\"http://www.facebook.com/TheJMoore\" data-ft=\"&#123;&quot;type&quot;:35,&quot;tn&quot;:&quot;;&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=1164240897\">Jon Moore</a> <span data-jsid=\"text\" class=\"commentBody\">‎^ Way ahead of you. Favorited*</span><span></span></div><div class=\"commentActions fsm fwn fcg\"><a class=\"uiLinkSubtle\" href=\"/LawlabeeTheWallaby/posts/427041767338328?comment_id=4812064&amp;offset=0&amp;total_comments=12\" data-ft=\"&#123;&quot;tn&quot;:&quot;N&quot;&#125;\"><abbr title=\"Friday, August 10, 2012 at 9:39pm\" data-utime=\"1344649183\">Friday at 9:39pm</abbr></a> · <span class=\"comment_like_4812064 fsm fwn fcg\" data-ft=\"&#123;&quot;type&quot;:36,&quot;tn&quot;:&quot;&gt;&quot;&#125;\"><button class=\"stat_elem as_link cmnt_like_link\" type=\"submit\" name=\"like_comment_id[4812064]\" value=\"4812064\" title=\"Like this comment\"><span class=\"default_message\">Like</span><span class=\"saving_message\">Unlike</span></button></span></div></div></div></li><li class=\"uiUfiComment comment_4815740 ufiItem ufiItem\" data-ft=\"&#123;&quot;tn&quot;:&quot;R&quot;&#125;\"><div class=\"UIImageBlock clearfix uiUfiActorBlock\"><a class=\"actorPic UIImageBlock_Image UIImageBlock_SMALL_Image\" href=\"http://www.facebook.com/jarrett.billingsley\" tabindex=\"-1\" data-ft=\"&#123;&quot;type&quot;:34,&quot;tn&quot;:&quot;T&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=535531388\"><img class=\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__medium img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-ash2/49137_535531388_5946_q.jpg\" alt=\"\" /></a><a data-hover=\"tooltip\" title=\"Hide as Spam\" class=\"commentRemoverButton UIImageBlock_Ext uiCloseButton\" href=\"#\" role=\"button\" rel=\"async-post\" ajaxify=\"/ajax/ufi/one_click_remove?comment_id=4815740&amp;commenter_id=535531388&amp;profile_id=1055580469&amp;post_fbid=427456097296895&amp;can_remove=0&amp;can_report=1&amp;can_edit=0&amp;is_spam=0&amp;report_link=\u00252Fajax\u00252Freport.php\u00253Fcontent_type\u00253D74\u002526cid\u00253D427456097296895\u002526rid\u00253D535531388\u002526cid2\u00253D0\u002526profile\u00253D1055580469\u002526h\u00253DAfjU9M46x4VCn3PL&amp;feedback_params=\u00257B\u002522actor\u002522\u00253A\u0025221055580469\u002522\u00252C\u002522target_fbid\u002522\u00253A\u002522427041767338328\u002522\u00252C\u002522target_profile_id\u002522\u00253A\u0025221055580469\u002522\u00252C\u002522type_id\u002522\u00253A\u00252217\u002522\u00252C\u002522assoc_obj_id\u002522\u00253A\u002522\u002522\u00252C\u002522source_app_id\u002522\u00253A\u0025220\u002522\u00252C\u002522extra_story_params\u002522\u00253A\u00255B\u00255D\u00252C\u002522content_timestamp\u002522\u00253A\u0025221344632723\u002522\u00252C\u002522check_hash\u002522\u00253A\u002522AQBTZdjKUuiS7RK6\u002522\u00252C\u002522source\u002522\u00253A\u00252213\u002522\u00257D\"></a><div data-ft=\"&#123;&quot;type&quot;:33,&quot;tn&quot;:&quot;K&quot;&#125;\" class=\"UIImageBlock_Content UIImageBlock_SMALL_Content\"><div class=\"commentContent\"><a class=\"actorName\" href=\"http://www.facebook.com/jarrett.billingsley\" data-ft=\"&#123;&quot;type&quot;:35,&quot;tn&quot;:&quot;;&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=535531388\">Jarrett Billingsley</a> <span data-jsid=\"text\" class=\"commentBody\">Okay this is weird. What IS this melody anyway? <script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function e4ee0f0f5812159e5713aa1f9146f53618300e54e(event) {\\u000a    LinkshimAsyncLink.swap(this, \\\"http:\\\\\\\\/\\\\\\\\/www.youtube.com\\\\\\\\/watch?v=FvNmA7FSCW0&list=ULFvNmA7FSCW0&feature=player_detailpage#t=312s\\\");\\u000a};\"), (\"sa106d5a1ef1cb088967dc096e1481ecb26d7011e\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction e4ee0f0f5812159e5713aa1f9146f53618300e54e(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"sa106d5a1ef1cb088967dc096e1481ecb26d7011e_0\"), (sa106d5a1ef1cb088967dc096e1481ecb26d7011e_0_instance), (this), (arguments)))\n    };\n    (null);\n    (((JSBNG_Record.get)(LinkshimAsyncLink, (\"swap\")))[(\"swap\")])(this, \"http:\\\\/\\\\/www.youtube.com\\\\/watch?v=FvNmA7FSCW0&list=ULFvNmA7FSCW0&feature=player_detailpage#t=312s\");\n};\nvar sa106d5a1ef1cb088967dc096e1481ecb26d7011e_0_instance;\n((sa106d5a1ef1cb088967dc096e1481ecb26d7011e_0_instance) = ((JSBNG_Record.eventInstance)((\"sa106d5a1ef1cb088967dc096e1481ecb26d7011e_0\"))));\n((JSBNG_Record.markFunction)((e4ee0f0f5812159e5713aa1f9146f53618300e54e)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function e737f28beeb8217dba8fc5e20c621d2f0e09230f7(event) {\\u000a    LinkshimAsyncLink.referrer_log(this, \\\"http:\\\\\\\\/\\\\\\\\/www.youtube.com\\\\\\\\/watch?v=FvNmA7FSCW0&list=ULFvNmA7FSCW0&feature=player_detailpage#t=312s\\\", \\\"http:\\\\\\\\/\\\\\\\\/www.facebook.com\\\\\\\\/si\\\\\\\\/ajax\\\\\\\\/l\\\\\\\\/render_linkshim_log\\\\\\\\/?u=http\\\\\\\\u00253A\\\\\\\\u00252F\\\\\\\\u00252Fwww.youtube.com\\\\\\\\u00252Fwatch\\\\\\\\u00253Fv\\\\\\\\u00253DFvNmA7FSCW0\\\\\\\\u002526list\\\\\\\\u00253DULFvNmA7FSCW0\\\\\\\\u002526feature\\\\\\\\u00253Dplayer_detailpage\\\\\\\\u002523t\\\\\\\\u00253D312s&h=aAQF3JJHhAQFJT8LKCmBGfWmXsC8WJz_wBYaZtzZFFNWBlA&enc=AZMtd6s9Hr8ZFE_XUAVyt1BBFNJO7ET-4Dkv_2EGhaxUSbLNnkthAw1v-M3ZmO3E6Qoztt5ggzOfogNHEobrXJI6jxKKMqBNGCva09-hRqB8OQ&s=1\\\");\\u000a};\"), (\"s99ab1b1875104eed15111458ea5053985218daf1\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction e737f28beeb8217dba8fc5e20c621d2f0e09230f7(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s99ab1b1875104eed15111458ea5053985218daf1_0\"), (s99ab1b1875104eed15111458ea5053985218daf1_0_instance), (this), (arguments)))\n    };\n    (null);\n    (((JSBNG_Record.get)(LinkshimAsyncLink, (\"referrer_log\")))[(\"referrer_log\")])(this, \"http:\\\\/\\\\/www.youtube.com\\\\/watch?v=FvNmA7FSCW0&list=ULFvNmA7FSCW0&feature=player_detailpage#t=312s\", \"http:\\\\/\\\\/www.facebook.com\\\\/si\\\\/ajax\\\\/l\\\\/render_linkshim_log\\\\/?u=http\\\\u00253A\\\\u00252F\\\\u00252Fwww.youtube.com\\\\u00252Fwatch\\\\u00253Fv\\\\u00253DFvNmA7FSCW0\\\\u002526list\\\\u00253DULFvNmA7FSCW0\\\\u002526feature\\\\u00253Dplayer_detailpage\\\\u002523t\\\\u00253D312s&h=aAQF3JJHhAQFJT8LKCmBGfWmXsC8WJz_wBYaZtzZFFNWBlA&enc=AZMtd6s9Hr8ZFE_XUAVyt1BBFNJO7ET-4Dkv_2EGhaxUSbLNnkthAw1v-M3ZmO3E6Qoztt5ggzOfogNHEobrXJI6jxKKMqBNGCva09-hRqB8OQ&s=1\");\n};\nvar s99ab1b1875104eed15111458ea5053985218daf1_0_instance;\n((s99ab1b1875104eed15111458ea5053985218daf1_0_instance) = ((JSBNG_Record.eventInstance)((\"s99ab1b1875104eed15111458ea5053985218daf1_0\"))));\n((JSBNG_Record.markFunction)((e737f28beeb8217dba8fc5e20c621d2f0e09230f7)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><a href=\"/l.php?u=http\u00253A\u00252F\u00252Fwww.youtube.com\u00252Fwatch\u00253Fv\u00253DFvNmA7FSCW0\u002526list\u00253DULFvNmA7FSCW0\u002526feature\u00253Dplayer_detailpage\u002523t\u00253D312s&amp;h=aAQF3JJHhAQFJT8LKCmBGfWmXsC8WJz_wBYaZtzZFFNWBlA&amp;enc=AZMtd6s9Hr8ZFE_XUAVyt1BBFNJO7ET-4Dkv_2EGhaxUSbLNnkthAw1v-M3ZmO3E6Qoztt5ggzOfogNHEobrXJI6jxKKMqBNGCva09-hRqB8OQ&amp;s=1\" target=\"_blank\" rel=\"nofollow nofollow\" onmouseover=\"return e4ee0f0f5812159e5713aa1f9146f53618300e54e.call(this, event);\" onclick=\"return e737f28beeb8217dba8fc5e20c621d2f0e09230f7.call(this, event);\"><span>http://www.youtube.com/</span><wbr /><span class=\"word_break\"></span><span>watch?v=FvNmA7FSCW0&amp;list=UL</span><wbr /><span class=\"word_break\"></span><span>FvNmA7FSCW0&amp;feature=player</span><wbr /><span class=\"word_break\"></span>_detailpage#t=312s</a>  Because it also shows up in a Radiohead song. <script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function e7b6c1659c163305c319eaa5cff7d8aeb95c7cf2a(event) {\\u000a    LinkshimAsyncLink.swap(this, \\\"http:\\\\\\\\/\\\\\\\\/www.youtube.com\\\\\\\\/watch?feature=player_detailpage&v=PtkZxqTH9tE#t=29s\\\");\\u000a};\"), (\"sf437ba23ae2701e8d1f33e18dc24d90da1859df2\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction e7b6c1659c163305c319eaa5cff7d8aeb95c7cf2a(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"sf437ba23ae2701e8d1f33e18dc24d90da1859df2_0\"), (sf437ba23ae2701e8d1f33e18dc24d90da1859df2_0_instance), (this), (arguments)))\n    };\n    (null);\n    (((JSBNG_Record.get)(LinkshimAsyncLink, (\"swap\")))[(\"swap\")])(this, \"http:\\\\/\\\\/www.youtube.com\\\\/watch?feature=player_detailpage&v=PtkZxqTH9tE#t=29s\");\n};\nvar sf437ba23ae2701e8d1f33e18dc24d90da1859df2_0_instance;\n((sf437ba23ae2701e8d1f33e18dc24d90da1859df2_0_instance) = ((JSBNG_Record.eventInstance)((\"sf437ba23ae2701e8d1f33e18dc24d90da1859df2_0\"))));\n((JSBNG_Record.markFunction)((e7b6c1659c163305c319eaa5cff7d8aeb95c7cf2a)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function e5ce52ccf8adfb00aa0fb7a1d85bf7486e2384dc2(event) {\\u000a    LinkshimAsyncLink.referrer_log(this, \\\"http:\\\\\\\\/\\\\\\\\/www.youtube.com\\\\\\\\/watch?feature=player_detailpage&v=PtkZxqTH9tE#t=29s\\\", \\\"http:\\\\\\\\/\\\\\\\\/www.facebook.com\\\\\\\\/si\\\\\\\\/ajax\\\\\\\\/l\\\\\\\\/render_linkshim_log\\\\\\\\/?u=http\\\\\\\\u00253A\\\\\\\\u00252F\\\\\\\\u00252Fwww.youtube.com\\\\\\\\u00252Fwatch\\\\\\\\u00253Ffeature\\\\\\\\u00253Dplayer_detailpage\\\\\\\\u002526v\\\\\\\\u00253DPtkZxqTH9tE\\\\\\\\u002523t\\\\\\\\u00253D29s&h=-AQEOAovrAQG9J8wj-B5oBIU6ew6BBRLKbggBzy71NsqBFQ&enc=AZPcyiybUUmSn5VmV_OwQ-37D-1oJaTHYads8tgcoYqGRIJag0-WakomB7ilGy2cBfD_gFLcsUIWDEzRC3y62mZRaOxKezYP-D351GPKlnaAjg&s=1\\\");\\u000a};\"), (\"s0d13f28c0518672dabb647672776b1d93c3cb755\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction e5ce52ccf8adfb00aa0fb7a1d85bf7486e2384dc2(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s0d13f28c0518672dabb647672776b1d93c3cb755_0\"), (s0d13f28c0518672dabb647672776b1d93c3cb755_0_instance), (this), (arguments)))\n    };\n    (null);\n    (((JSBNG_Record.get)(LinkshimAsyncLink, (\"referrer_log\")))[(\"referrer_log\")])(this, \"http:\\\\/\\\\/www.youtube.com\\\\/watch?feature=player_detailpage&v=PtkZxqTH9tE#t=29s\", \"http:\\\\/\\\\/www.facebook.com\\\\/si\\\\/ajax\\\\/l\\\\/render_linkshim_log\\\\/?u=http\\\\u00253A\\\\u00252F\\\\u00252Fwww.youtube.com\\\\u00252Fwatch\\\\u00253Ffeature\\\\u00253Dplayer_detailpage\\\\u002526v\\\\u00253DPtkZxqTH9tE\\\\u002523t\\\\u00253D29s&h=-AQEOAovrAQG9J8wj-B5oBIU6ew6BBRLKbggBzy71NsqBFQ&enc=AZPcyiybUUmSn5VmV_OwQ-37D-1oJaTHYads8tgcoYqGRIJag0-WakomB7ilGy2cBfD_gFLcsUIWDEzRC3y62mZRaOxKezYP-D351GPKlnaAjg&s=1\");\n};\nvar s0d13f28c0518672dabb647672776b1d93c3cb755_0_instance;\n((s0d13f28c0518672dabb647672776b1d93c3cb755_0_instance) = ((JSBNG_Record.eventInstance)((\"s0d13f28c0518672dabb647672776b1d93c3cb755_0\"))));\n((JSBNG_Record.markFunction)((e5ce52ccf8adfb00aa0fb7a1d85bf7486e2384dc2)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><a href=\"/l.php?u=http\u00253A\u00252F\u00252Fwww.youtube.com\u00252Fwatch\u00253Ffeature\u00253Dplayer_detailpage\u002526v\u00253DPtkZxqTH9tE\u002523t\u00253D29s&amp;h=-AQEOAovrAQG9J8wj-B5oBIU6ew6BBRLKbggBzy71NsqBFQ&amp;enc=AZPcyiybUUmSn5VmV_OwQ-37D-1oJaTHYads8tgcoYqGRIJag0-WakomB7ilGy2cBfD_gFLcsUIWDEzRC3y62mZRaOxKezYP-D351GPKlnaAjg&amp;s=1\" target=\"_blank\" rel=\"nofollow nofollow\" onmouseover=\"return e7b6c1659c163305c319eaa5cff7d8aeb95c7cf2a.call(this, event);\" onclick=\"return e5ce52ccf8adfb00aa0fb7a1d85bf7486e2384dc2.call(this, event);\"><span>http://www.youtube.com/</span><wbr /><span class=\"word_break\"></span><span>watch?feature=player_detail</span><wbr /><span class=\"word_break\"></span>page&amp;v=PtkZxqTH9tE#t=29s</a></span><span><div class=\"mvm uiStreamAttachments\" data-ft=\"&#123;&quot;type&quot;:10,&quot;tn&quot;:&quot;H&quot;&#125;\"><div class=\"clearfix\"><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function ee98895316bb5c12281fb5909751b1f4558414a96(event) {\\u000a    CSS.addClass(this, \\\"uiVideoThumbLoading\\\");\\u000a};\"), (\"s6896f3354bab92070f57f4780b48be544fd4a8bc\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction ee98895316bb5c12281fb5909751b1f4558414a96(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s6896f3354bab92070f57f4780b48be544fd4a8bc_0\"), (s6896f3354bab92070f57f4780b48be544fd4a8bc_0_instance), (this), (arguments)))\n    };\n    (null);\n    (((JSBNG_Record.get)(CSS, (\"addClass\")))[(\"addClass\")])(this, \"uiVideoThumbLoading\");\n};\nvar s6896f3354bab92070f57f4780b48be544fd4a8bc_0_instance;\n((s6896f3354bab92070f57f4780b48be544fd4a8bc_0_instance) = ((JSBNG_Record.eventInstance)((\"s6896f3354bab92070f57f4780b48be544fd4a8bc_0\"))));\n((JSBNG_Record.markFunction)((ee98895316bb5c12281fb5909751b1f4558414a96)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><a class=\"uiVideoThumb -cx-PRIVATE-uiImageBlock__image -cx-PRIVATE-uiImageBlock__largeImage lfloat\" href=\"\" ajaxify=\"/ajax/flash/expand_inline.php?replace=1&amp;target_div=uq3j2t_29&amp;context=comment&amp;bgcolor=\u002523FFFFFF&amp;max_width=310&amp;max_height=310&amp;share_id=454040841297040\" rel=\"async\" onclick=\"return ee98895316bb5c12281fb5909751b1f4558414a96.call(this, event);\" id=\"uq3j2t_29\" target=\"_blank\" data-ft=\"&#123;&quot;video_type&quot;:&quot;share&quot;,&quot;type&quot;:42,&quot;tn&quot;:&quot;F&quot;&#125;\"><img class=\"img\" src=\"http://external.ak.fbcdn.net/safe_image.php?d=AQDG8wvaIf9qB0yH&amp;url=http\u00253A\u00252F\u00252Fi3.ytimg.com\u00252Fvi\u00252FFvNmA7FSCW0\u00252Fmqdefault.jpg\" alt=\"\" /><i></i></a><div class=\"-cx-PRIVATE-uiImageBlock__content \"><div class=\"fsm fwn fcg\"><div class=\"uiAttachmentTitle\" data-ft=\"&#123;&quot;type&quot;:11,&quot;tn&quot;:&quot;C&quot;&#125;\"><strong><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function ef92fa315b611e718f42dd5d8637eda9e25bd1011(event) {\\u000a    LinkshimAsyncLink.referrer_log(this, \\\"http:\\\\\\\\/\\\\\\\\/www.youtube.com\\\\\\\\/watch?v=FvNmA7FSCW0&list=ULFvNmA7FSCW0&feature=player_detailpage#t=312s\\\", \\\"http:\\\\\\\\/\\\\\\\\/www.facebook.com\\\\\\\\/si\\\\\\\\/ajax\\\\\\\\/l\\\\\\\\/render_linkshim_log\\\\\\\\/?u=http\\\\\\\\u00253A\\\\\\\\u00252F\\\\\\\\u00252Fwww.youtube.com\\\\\\\\u00252Fwatch\\\\\\\\u00253Fv\\\\\\\\u00253DFvNmA7FSCW0\\\\\\\\u002526list\\\\\\\\u00253DULFvNmA7FSCW0\\\\\\\\u002526feature\\\\\\\\u00253Dplayer_detailpage\\\\\\\\u002523t\\\\\\\\u00253D312s&h=sAQGDj-sSAQGfQV97l1DSwE4u6gpGXvbpOaaDPu3GYM8CQA&enc=AZOK3I-Pvs_Quxh7Sm244xCmEe3UZZbfnuWhGLD_wnXuXO4BDtU96CjXkoXfbjhBa4b5NgR3YCsnsw_GXNHca2dQZwNBU6nfXI5HQfII6xe3nWiOSRn6v2y37YSnQIcfkek&s=1\\\");\\u000a    return StreamShareVideo.clickTitle(\\\"454040841297040\\\", \\\"feed\\\", event);\\u000a};\"), (\"s7f203f36774ab7e71309b7f6ad38a9f5a562cb4a\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction ef92fa315b611e718f42dd5d8637eda9e25bd1011(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s7f203f36774ab7e71309b7f6ad38a9f5a562cb4a_0\"), (s7f203f36774ab7e71309b7f6ad38a9f5a562cb4a_0_instance), (this), (arguments)))\n    };\n    (null);\n    (((JSBNG_Record.get)(LinkshimAsyncLink, (\"referrer_log\")))[(\"referrer_log\")])(this, \"http:\\\\/\\\\/www.youtube.com\\\\/watch?v=FvNmA7FSCW0&list=ULFvNmA7FSCW0&feature=player_detailpage#t=312s\", \"http:\\\\/\\\\/www.facebook.com\\\\/si\\\\/ajax\\\\/l\\\\/render_linkshim_log\\\\/?u=http\\\\u00253A\\\\u00252F\\\\u00252Fwww.youtube.com\\\\u00252Fwatch\\\\u00253Fv\\\\u00253DFvNmA7FSCW0\\\\u002526list\\\\u00253DULFvNmA7FSCW0\\\\u002526feature\\\\u00253Dplayer_detailpage\\\\u002523t\\\\u00253D312s&h=sAQGDj-sSAQGfQV97l1DSwE4u6gpGXvbpOaaDPu3GYM8CQA&enc=AZOK3I-Pvs_Quxh7Sm244xCmEe3UZZbfnuWhGLD_wnXuXO4BDtU96CjXkoXfbjhBa4b5NgR3YCsnsw_GXNHca2dQZwNBU6nfXI5HQfII6xe3nWiOSRn6v2y37YSnQIcfkek&s=1\");\n    return (((JSBNG_Record.get)(StreamShareVideo, (\"clickTitle\")))[(\"clickTitle\")])(\"454040841297040\", \"feed\", JSBNG__event);\n};\nvar s7f203f36774ab7e71309b7f6ad38a9f5a562cb4a_0_instance;\n((s7f203f36774ab7e71309b7f6ad38a9f5a562cb4a_0_instance) = ((JSBNG_Record.eventInstance)((\"s7f203f36774ab7e71309b7f6ad38a9f5a562cb4a_0\"))));\n((JSBNG_Record.markFunction)((ef92fa315b611e718f42dd5d8637eda9e25bd1011)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function e34a9f0c115f2f8724e04cc7d1c6731c12e86dcfc(event) {\\u000a    LinkshimAsyncLink.swap(this, \\\"http:\\\\\\\\/\\\\\\\\/www.youtube.com\\\\\\\\/watch?v=FvNmA7FSCW0&list=ULFvNmA7FSCW0&feature=player_detailpage#t=312s\\\");\\u000a};\"), (\"sf22c181ebcb23d6faedbe5b08579a1cc6888a07f\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction e34a9f0c115f2f8724e04cc7d1c6731c12e86dcfc(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"sf22c181ebcb23d6faedbe5b08579a1cc6888a07f_0\"), (sf22c181ebcb23d6faedbe5b08579a1cc6888a07f_0_instance), (this), (arguments)))\n    };\n    (null);\n    (((JSBNG_Record.get)(LinkshimAsyncLink, (\"swap\")))[(\"swap\")])(this, \"http:\\\\/\\\\/www.youtube.com\\\\/watch?v=FvNmA7FSCW0&list=ULFvNmA7FSCW0&feature=player_detailpage#t=312s\");\n};\nvar sf22c181ebcb23d6faedbe5b08579a1cc6888a07f_0_instance;\n((sf22c181ebcb23d6faedbe5b08579a1cc6888a07f_0_instance) = ((JSBNG_Record.eventInstance)((\"sf22c181ebcb23d6faedbe5b08579a1cc6888a07f_0\"))));\n((JSBNG_Record.markFunction)((e34a9f0c115f2f8724e04cc7d1c6731c12e86dcfc)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><a href=\"/l.php?u=http\u00253A\u00252F\u00252Fwww.youtube.com\u00252Fwatch\u00253Fv\u00253DFvNmA7FSCW0\u002526list\u00253DULFvNmA7FSCW0\u002526feature\u00253Dplayer_detailpage\u002523t\u00253D312s&amp;h=sAQGDj-sSAQGfQV97l1DSwE4u6gpGXvbpOaaDPu3GYM8CQA&amp;enc=AZOK3I-Pvs_Quxh7Sm244xCmEe3UZZbfnuWhGLD_wnXuXO4BDtU96CjXkoXfbjhBa4b5NgR3YCsnsw_GXNHca2dQZwNBU6nfXI5HQfII6xe3nWiOSRn6v2y37YSnQIcfkek&amp;s=1\" target=\"_blank\" onclick=\"return ef92fa315b611e718f42dd5d8637eda9e25bd1011.call(this, event);\" rel=\"nofollow\" onmouseover=\"return e34a9f0c115f2f8724e04cc7d1c6731c12e86dcfc.call(this, event);\">Aleksandr Hrustevich, accordion / Juri Gilbo, conductor (Part II)</a></strong> </div><span class=\"caption\" data-ft=\"&#123;&quot;tn&quot;:&quot;L&quot;&#125;\"></span><div class=\"mts uiAttachmentDesc translationEligibleUserAttachmentMessage\" data-ft=\"&#123;&quot;tn&quot;:&quot;M&quot;&#125;\"><div id=\"id_50291e7755b663982800336\" class=\"text_exposed_root\">A. Zubitsky &quot;Omaggio ad Astor Piazzolla&quot; Russian Chamber Philharmonic St. Peters<span class=\"text_exposed_hide\">...</span><div class=\"text_exposed_show\">burg / Russische Kammerphilharmonie St.Petersburg Aleksandr Hrustevich, accor...</div><span class=\"text_exposed_hide\"><span class=\"text_exposed_link\"><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function e3ee6ade0315dea366a9bcf2a35b75507fd031bfe(event) {\\u000a    CSS.addClass($(\\\"id_50291e7755b663982800336\\\"), \\\"text_exposed\\\");\\u000a    Arbiter.inform(\\\"reflow\\\");\\u000a};\"), (\"s367e681e58adb1cc4397bd4ebe856a12bf3d1c2c\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction e3ee6ade0315dea366a9bcf2a35b75507fd031bfe(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s367e681e58adb1cc4397bd4ebe856a12bf3d1c2c_0\"), (s367e681e58adb1cc4397bd4ebe856a12bf3d1c2c_0_instance), (this), (arguments)))\n    };\n    (null);\n    (((JSBNG_Record.get)(CSS, (\"addClass\")))[(\"addClass\")])($(\"id_50291e7755b663982800336\"), \"text_exposed\");\n    (((JSBNG_Record.get)(Arbiter, (\"inform\")))[(\"inform\")])(\"reflow\");\n};\nvar s367e681e58adb1cc4397bd4ebe856a12bf3d1c2c_0_instance;\n((s367e681e58adb1cc4397bd4ebe856a12bf3d1c2c_0_instance) = ((JSBNG_Record.eventInstance)((\"s367e681e58adb1cc4397bd4ebe856a12bf3d1c2c_0\"))));\n((JSBNG_Record.markFunction)((e3ee6ade0315dea366a9bcf2a35b75507fd031bfe)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><a onclick=\"return e3ee6ade0315dea366a9bcf2a35b75507fd031bfe.call(this, event);\">See More</a></span></span></div></div></div></div></div></div></span></div><div class=\"commentActions fsm fwn fcg\"><a class=\"uiLinkSubtle\" href=\"/LawlabeeTheWallaby/posts/427041767338328?comment_id=4815740&amp;offset=0&amp;total_comments=12\" data-ft=\"&#123;&quot;tn&quot;:&quot;N&quot;&#125;\"><abbr title=\"Sunday, August 12, 2012 at 12:30am\" data-utime=\"1344745834\">Yesterday at 12:30am</abbr></a> · <span class=\"comment_like_4815740 fsm fwn fcg\" data-ft=\"&#123;&quot;type&quot;:36,&quot;tn&quot;:&quot;&gt;&quot;&#125;\"><button class=\"stat_elem as_link cmnt_like_link\" type=\"submit\" name=\"like_comment_id[4815740]\" value=\"4815740\" title=\"Like this comment\"><span class=\"default_message\">Like</span><span class=\"saving_message\">Unlike</span></button></span></div></div></div></li></ul></li><li class=\"uiUfiAddComment clearfix uiUfiSmall ufiItem ufiItem uiListItem  uiListVerticalItemBorder\" data-ft=\"&#123;&quot;tn&quot;:&quot;[&quot;&#125;\"><div class=\"UIImageBlock clearfix mentionsAddComment\"><img class=\"-cx-PRIVATE-uiSquareImage__root actorPic UIImageBlock_Image UIImageBlock_ICON_Image -cx-PRIVATE-uiSquareImage__medium img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-ash2/275624_100001812504199_1255023530_q.jpg\" alt=\"\" /><div class=\"commentArea UIImageBlock_Content UIImageBlock_ICON_Content\"><div class=\"commentBox\"><div class=\"uiMentionsInput textBoxContainer\" id=\"uq3j2t_21\"><div class=\"highlighter\"><div><span class=\"highlighterContent\"></span></div></div><div class=\"uiTypeahead mentionsTypeahead\" id=\"uq3j2t_22\"><div class=\"wrap\"><input type=\"hidden\" autocomplete=\"off\" class=\"hiddenInput\" /><div class=\"innerWrap\"><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function e04605455202a9d94bb472ac16bfa048de6942c5f(event) {\\u000a    Bootloader.loadComponents([\\\"control-textarea\\\",], function() {\\u000a        TextAreaControl.getInstance(this);\\u000a    }.bind(this));\\u000a};\"), (\"s2af7f8b09c529bd0adb946fff1b676010fb00608\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction e04605455202a9d94bb472ac16bfa048de6942c5f(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s2af7f8b09c529bd0adb946fff1b676010fb00608_0\"), (s2af7f8b09c529bd0adb946fff1b676010fb00608_0_instance), (this), (arguments)))\n    };\n    (null);\n    (((JSBNG_Record.get)(Bootloader, (\"loadComponents\")))[(\"loadComponents\")])([\"control-textarea\",], (((JSBNG_Record.get)(((function() {\n        var s2af7f8b09c529bd0adb946fff1b676010fb00608_1_instance;\n        ((s2af7f8b09c529bd0adb946fff1b676010fb00608_1_instance) = ((JSBNG_Record.eventInstance)((\"s2af7f8b09c529bd0adb946fff1b676010fb00608_1\"))));\n        return ((JSBNG_Record.markFunction)((function() {\n            if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n                return ((JSBNG_Record.eventCall)((arguments.callee), (\"s2af7f8b09c529bd0adb946fff1b676010fb00608_1\"), (s2af7f8b09c529bd0adb946fff1b676010fb00608_1_instance), (this), (arguments)))\n            };\n            (null);\n            (((JSBNG_Record.get)(TextAreaControl, (\"getInstance\")))[(\"getInstance\")])(this);\n        })));\n    })()), (\"bind\")))[(\"bind\")])(this));\n};\nvar s2af7f8b09c529bd0adb946fff1b676010fb00608_0_instance;\n((s2af7f8b09c529bd0adb946fff1b676010fb00608_0_instance) = ((JSBNG_Record.eventInstance)((\"s2af7f8b09c529bd0adb946fff1b676010fb00608_0\"))));\n((JSBNG_Record.markFunction)((e04605455202a9d94bb472ac16bfa048de6942c5f)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><textarea class=\"enter_submit DOMControl_placeholder uiTextareaNoResize uiTextareaAutogrow textBox mentionsTextarea textInput\" title=\"Write a comment...\" placeholder=\"Write a comment...\" name=\"add_comment_text\" autocomplete=\"off\" aria-autocomplete=\"list\" aria-expanded=\"false\" aria-invalid=\"false\" aria-owns=\"typeahead_list_uq3j2t_22\" role=\"textbox\" onkeydown=\"return e04605455202a9d94bb472ac16bfa048de6942c5f.call(this, event);\" id=\"uq3j2t_23\">Write a comment...</textarea></div></div></div><input type=\"hidden\" autocomplete=\"off\" class=\"mentionsHidden\" /></div></div><label class=\"mts commentBtn stat_elem hidden_elem optimistic_submit uiButton uiButtonConfirm\" for=\"uq3j2t_24\"><input value=\"Comment\" class=\"enter_submit_target\" name=\"comment\" type=\"submit\" id=\"uq3j2t_24\" /></label></div></div></li></ul></div></form></div><div class=\"-cx-PRIVATE-uiInlineBlock__root  mlm uiPopover highlightSelector uiStreamHide\" data-ft=\"&#123;&quot;type&quot;:55,&quot;tn&quot;:&quot;V&quot;&#125;\" id=\"uq3j2t_8\"><a class=\"highlightSelectorButton uiStreamContextButton -cx-PRIVATE-uiPopover__trigger\" href=\"#\" aria-haspopup=\"true\" aria-expanded=\"false\" rel=\"toggle\" id=\"uq3j2t_9\">Options</a></div></div></div></li><li class=\"uiUnifiedStory uiStreamStory genericStreamStory aid_1055580469 uiListItem uiListLight uiListVerticalItemBorder\" data-ft=\"&#123;&quot;qid&quot;:&quot;5776181494237290802&quot;,&quot;mf_story_key&quot;:&quot;6023853588764622143&quot;&#125;\" id=\"stream_story_50291e77423ed9900470894\"><div class=\"clearfix storyContent\"><a class=\"actorPhoto lfloat\" href=\"http://www.facebook.com/LawlabeeTheWallaby\" tabindex=\"-1\" aria-hidden=\"true\" data-ft=\"&#123;&quot;type&quot;:60,&quot;tn&quot;:&quot;\\\\u003C&quot;&#125;\" data-hovercard=\"/ajax/hovercard/hovercard.php?id=1055580469\"><img class=\"-cx-PRIVATE-uiSquareImage__root profilePic -cx-PRIVATE-uiSquareImage__large img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/157194_1055580469_1433282671_q.jpg\" alt=\"\" /></a><div class=\"storyInnerContent\"><div class=\"mainWrapper\"><h6 class=\"uiStreamMessage uiStreamHeadline uiStreamPassive\" data-ft=\"&#123;&quot;tn&quot;:&quot;B&quot;,&quot;type&quot;:1&#125;\"><a class=\"passiveName\" href=\"http://www.facebook.com/LawlabeeTheWallaby\" data-ft=\"&#123;&quot;tn&quot;:&quot;;&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=1055580469\">Gregor Richards</a> commented on a <a class=\"pronoun-link \" href=\"/LawlabeeTheWallaby/posts/424129870965893\" data-ft=\"&#123;&quot;tn&quot;:&quot;A&quot;&#125;\">link</a>.</h6><span class=\"uiStreamFooter\"></span><div class=\"uiStreamEdgeStoryLine\"><hr /></div><ul class=\"uiList mtm uiCollapsedList uiCollapsedListHidden uiStreamSubstories\" id=\"uq3j2t_10\"><li class=\"uiListItem uiListLight uiListVerticalItemBorder\" id=\"stream_sub_story_50291e77430272367480569\" data-ft=\"&#123;&quot;tn&quot;:&quot;U&quot;&#125;\"><div class=\"genericStreamStory uiStreamSubstory aid_10715287 stream_sub_story_50291e77430272367480569 uiStory_424129870965893\"><div class=\"clearfix storyContent\"><a class=\"substoryActorPic lfloat\" href=\"http://www.facebook.com/michael.a.goss\" tabindex=\"-1\" data-ft=\"&#123;&quot;tn&quot;:&quot;T&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=10715287\"><img class=\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__medium img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/273778_10715287_322179859_q.jpg\" alt=\"\" /></a><div class=\"storyInnerContent storyInnerContentSmallPic\"><h6 class=\"uiStreamMessage uiStreamHeadline\" data-ft=\"&#123;&quot;tn&quot;:&quot;:&quot;&#125;\"><div class=\"actorDescription uiStreamRobotextBeforeMessage\"><a class=\"passiveName\" href=\"http://www.facebook.com/michael.a.goss\" data-ft=\"&#123;&quot;tn&quot;:&quot;;&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=10715287\">Michael A Goss</a> posted <a class=\"pronoun-link \" href=\"http://www.facebook.com/photo.php?fbid=475350339143917&amp;set=a.355071954505090.95019.352242898121329&amp;type=1\" data-ft=\"&#123;&quot;tn&quot;:&quot;A&quot;&#125;\">a photo</a> to <a href=\"http://www.facebook.com/LawlabeeTheWallaby\" data-ft=\"&#123;&quot;tn&quot;:&quot;P&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=1055580469\">Gregor Richards</a>&#039;s <a class=\"pronoun-link \" href=\"http://www.facebook.com/LawlabeeTheWallaby#wall\" data-ft=\"&#123;&quot;tn&quot;:&quot;A&quot;&#125;\">Wall</a>.</div></h6><h6 class=\"uiStreamMessage\" data-ft=\"&#123;&quot;type&quot;:1,&quot;tn&quot;:&quot;K&quot;&#125;\"><span class=\"messageBody\">Someone hates you...</span></h6><div class=\"mvm uiStreamAttachments\" data-ft=\"&#123;&quot;type&quot;:10,&quot;tn&quot;:&quot;H&quot;&#125;\"><div class=\"clearfix photoRedesign\"><a class=\"uiPhotoThumb photoRedesignAspect\" href=\"http://www.facebook.com/photo.php?fbid=475350339143917&amp;set=a.355071954505090.95019.352242898121329&amp;type=1&amp;ref=nf\" data-ft=\"&#123;&quot;type&quot;:41,&quot;tn&quot;:&quot;E&quot;&#125;\" rel=\"theater\" ajaxify=\"http://www.facebook.com/photo.php?fbid=475350339143917&amp;set=a.355071954505090.95019.352242898121329&amp;type=1&amp;ref=nf&amp;src=http\u00253A\u00252F\u00252Fa6.sphotos.ak.fbcdn.net\u00252Fhphotos-ak-snc6\u00252F616305_475350339143917_1238748270_o.jpg&amp;smallsrc=http\u00253A\u00252F\u00252Fsphotos-b.xx.fbcdn.net\u00252Fhphotos-snc7\u00252F424237_475350339143917_1238748270_n.jpg&amp;size=1610\u00252C1338&amp;theater\" aria-label=\"Photo\"><img class=\"img\" height=\"280\" src=\"http://sphotos-b.xx.fbcdn.net/hphotos-snc7/s480x480/424237_475350339143917_1238748270_n.jpg\" width=\"337\" alt=\"\" /></a></div><div class=\"shareSubtext fcg\">Rigged this for Blaze at <a href=\"http://www.facebook.com/DisregardHomeworkAcquirePonies\" data-hovercard=\"/ajax/hovercard/page.php?id=212331075551946\">Disregard homework, acquire ponies</a><br /> LOL, PONI BIRTHDAY GAME YOU KNOW WHAT TO DO <br /> 15 Is Trixie</div></div><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function ed44d07b70098ff8aa4ffb2448964fd53ae10e30b(event) {\\u000a    return Event.__inlineSubmit(this, event);\\u000a};\"), (\"s109d281d451a48b576ecccc543be2106fe6c78d5\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction ed44d07b70098ff8aa4ffb2448964fd53ae10e30b(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s109d281d451a48b576ecccc543be2106fe6c78d5_0\"), (s109d281d451a48b576ecccc543be2106fe6c78d5_0_instance), (this), (arguments)))\n    };\n    (null);\n    return (((JSBNG_Record.get)(JSBNG__Event, (\"__inlineSubmit\")))[(\"__inlineSubmit\")])(this, JSBNG__event);\n};\nvar s109d281d451a48b576ecccc543be2106fe6c78d5_0_instance;\n((s109d281d451a48b576ecccc543be2106fe6c78d5_0_instance) = ((JSBNG_Record.eventInstance)((\"s109d281d451a48b576ecccc543be2106fe6c78d5_0\"))));\n((JSBNG_Record.markFunction)((ed44d07b70098ff8aa4ffb2448964fd53ae10e30b)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><form rel=\"async\" class=\"live_424129870965893_131325686911214 commentable_item autoexpand_mode\" method=\"post\" action=\"/ajax/ufi/modify.php\" data-live=\"&#123;&quot;seq&quot;:4800979&#125;\" onsubmit=\"return ed44d07b70098ff8aa4ffb2448964fd53ae10e30b.call(this, event);\" id=\"uq3j2t_32\"><input type=\"hidden\" name=\"charset_test\" value=\"&euro;,&acute;,€,´,水,Д,Є\" /><input type=\"hidden\" name=\"fb_dtsg\" value=\"AQCc21Em\" autocomplete=\"off\" /><input type=\"hidden\" autocomplete=\"off\" name=\"feedback_params\" value=\"&#123;&quot;actor&quot;:&quot;10715287&quot;,&quot;target_fbid&quot;:&quot;424129870965893&quot;,&quot;target_profile_id&quot;:&quot;1055580469&quot;,&quot;type_id&quot;:&quot;17&quot;,&quot;assoc_obj_id&quot;:&quot;&quot;,&quot;source_app_id&quot;:&quot;2309869772&quot;,&quot;extra_story_params&quot;:[],&quot;content_timestamp&quot;:&quot;1344558605&quot;,&quot;check_hash&quot;:&quot;AQDlGaa92_4kZbI8&quot;,&quot;source&quot;:&quot;1&quot;&#125;\" /><span class=\"uiStreamFooter\"><span class=\"UIActionLinks UIActionLinks_bottom\" data-ft=\"&#123;&quot;tn&quot;:&quot;=&quot;,&quot;type&quot;:20&#125;\"><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function e83df0e82a964dd61ae3d52cffc1c8860785d879d(event) {\\u000a    fc_click(this, false);\\u000a    return true;\\u000a};\"), (\"s32e1c933e3c95b790a116fe2aae653b7e421c69e\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction e83df0e82a964dd61ae3d52cffc1c8860785d879d(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s32e1c933e3c95b790a116fe2aae653b7e421c69e_0\"), (s32e1c933e3c95b790a116fe2aae653b7e421c69e_0_instance), (this), (arguments)))\n    };\n    (null);\n    fc_click(this, false);\n    return true;\n};\nvar s32e1c933e3c95b790a116fe2aae653b7e421c69e_0_instance;\n((s32e1c933e3c95b790a116fe2aae653b7e421c69e_0_instance) = ((JSBNG_Record.eventInstance)((\"s32e1c933e3c95b790a116fe2aae653b7e421c69e_0\"))));\n((JSBNG_Record.markFunction)((e83df0e82a964dd61ae3d52cffc1c8860785d879d)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><button class=\"like_link stat_elem as_link\" title=\"Like this item\" type=\"submit\" name=\"like\" onclick=\"return e83df0e82a964dd61ae3d52cffc1c8860785d879d.call(this, event);\" data-ft=\"&#123;&quot;tn&quot;:&quot;&gt;&quot;,&quot;type&quot;:22&#125;\"><span class=\"default_message\">Like</span><span class=\"saving_message\">Unlike</span></button> &#183; <label class=\"uiLinkButton comment_link\" title=\"Leave a comment\"><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function eeea85f293d9dc1e2f9227c6c10283ef4af172e41(event) {\\u000a    return fc_click(this);\\u000a};\"), (\"s587c0e9b0afb4c6f4b4e7999007cb47da0d14912\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction eeea85f293d9dc1e2f9227c6c10283ef4af172e41(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s587c0e9b0afb4c6f4b4e7999007cb47da0d14912_0\"), (s587c0e9b0afb4c6f4b4e7999007cb47da0d14912_0_instance), (this), (arguments)))\n    };\n    (null);\n    return fc_click(this);\n};\nvar s587c0e9b0afb4c6f4b4e7999007cb47da0d14912_0_instance;\n((s587c0e9b0afb4c6f4b4e7999007cb47da0d14912_0_instance) = ((JSBNG_Record.eventInstance)((\"s587c0e9b0afb4c6f4b4e7999007cb47da0d14912_0\"))));\n((JSBNG_Record.markFunction)((eeea85f293d9dc1e2f9227c6c10283ef4af172e41)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><input data-ft=\"&#123;&quot;type&quot;:24,&quot;tn&quot;:&quot;S&quot;&#125;\" type=\"button\" value=\"Comment\" onclick=\"return eeea85f293d9dc1e2f9227c6c10283ef4af172e41.call(this, event);\"></label> &#183; <a class=\"share_action_link\" href=\"/ajax/sharer/?s=99&amp;appid=2309869772&amp;p\u00255B0\u00255D=10715287&amp;p\u00255B1\u00255D=424129870965893\" rel=\"dialog\" data-ft=\"&#123;&quot;tn&quot;:&quot;J&quot;,&quot;type&quot;:25&#125;\" title=\"Send this to friends or post it on your timeline.\">Share</a> &#183; </span><span class=\"uiStreamSource\" data-ft=\"&#123;&quot;type&quot;:26,&quot;tn&quot;:&quot;N&quot;&#125;\"><a href=\"/LawlabeeTheWallaby/posts/424129870965893\"><abbr title=\"Thursday, August 9, 2012 at 8:30pm\" data-utime=\"1344558605\">August 9 at 8:30pm</abbr></a></span> · <a data-hover=\"tooltip\" title=\"Shared with: Gregor&#039;s friends of friends\" class=\"uiStreamPrivacy inlineBlock fbStreamPrivacy fbPrivacyAudienceIndicator\" href=\"#\"><i class=\"lock img sp_67189i sx_0184a4\"></i></a></span><div><ul class=\"uiList uiUfi focus_target fbUfi fbUfiNoBorder\" data-ft=\"&#123;&quot;type&quot;:30,&quot;tn&quot;:&quot;]&quot;&#125;\"><li class=\"ufiNub uiListItem  uiListVerticalItemBorder\"><i></i></li><li class=\"hidden_elem uiUfiLike uiListItem  uiListVerticalItemBorder\" data-ft=\"&#123;&quot;type&quot;:31&#125;\"></li><li class=\"translateable_info hidden_elem uiListItem  uiListVerticalItemBorder\"><input type=\"hidden\" autocomplete=\"off\" name=\"translate_on_load\" value=\"\" /></li><li class=\"uiUfiComments uiListItem  uiListVerticalItemBorder\" data-ft=\"&#123;&quot;type&quot;:32&#125;\"><ul class=\"commentList\"><li class=\"uiUfiViewAll  ufiItem\"><label class=\"uiIconText uiLinkButton async_throbber\"><i class=\"img sp_627qpw sx_4fad2b\"></i><input type=\"submit\" name=\"view_all[1]\" value=\"View all 6 comments\" data-ft=\"&#123;&quot;tn&quot;:&quot;Q&quot;&#125;\" class=\"stat_elem\" /></label></li><li class=\"uiUfiComment comment_4800975 ufiItem ufiItem\" data-ft=\"&#123;&quot;tn&quot;:&quot;R0&quot;&#125;\"><div class=\"UIImageBlock clearfix uiUfiActorBlock\"><a class=\"actorPic UIImageBlock_Image UIImageBlock_SMALL_Image\" href=\"http://www.facebook.com/Jephraux\" tabindex=\"-1\" data-ft=\"&#123;&quot;type&quot;:34,&quot;tn&quot;:&quot;T&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=100000136180288\"><img class=\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__medium img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/260852_100000136180288_2023700134_q.jpg\" alt=\"\" /></a><a data-hover=\"tooltip\" title=\"Hide as Spam\" class=\"commentRemoverButton UIImageBlock_Ext uiCloseButton\" href=\"#\" role=\"button\" rel=\"async-post\" ajaxify=\"/ajax/ufi/one_click_remove?comment_id=4800975&amp;commenter_id=100000136180288&amp;profile_id=1055580469&amp;post_fbid=424131934299020&amp;can_remove=0&amp;can_report=1&amp;can_edit=0&amp;is_spam=0&amp;report_link=\u00252Fajax\u00252Freport.php\u00253Fcontent_type\u00253D74\u002526cid\u00253D424131934299020\u002526rid\u00253D100000136180288\u002526cid2\u00253D0\u002526profile\u00253D1055580469\u002526h\u00253DAfiHbZFwOHEnC6Dq&amp;feedback_params=\u00257B\u002522actor\u002522\u00253A\u00252210715287\u002522\u00252C\u002522target_fbid\u002522\u00253A\u002522424129870965893\u002522\u00252C\u002522target_profile_id\u002522\u00253A\u0025221055580469\u002522\u00252C\u002522type_id\u002522\u00253A\u00252217\u002522\u00252C\u002522assoc_obj_id\u002522\u00253A\u002522\u002522\u00252C\u002522source_app_id\u002522\u00253A\u0025222309869772\u002522\u00252C\u002522extra_story_params\u002522\u00253A\u00255B\u00255D\u00252C\u002522content_timestamp\u002522\u00253A\u0025221344558605\u002522\u00252C\u002522check_hash\u002522\u00253A\u002522AQDlGaa92_4kZbI8\u002522\u00252C\u002522source\u002522\u00253A\u00252213\u002522\u00257D\"></a><div data-ft=\"&#123;&quot;type&quot;:33,&quot;tn&quot;:&quot;K&quot;&#125;\" class=\"UIImageBlock_Content UIImageBlock_SMALL_Content\"><div class=\"commentContent\"><a class=\"actorName\" href=\"http://www.facebook.com/Jephraux\" data-ft=\"&#123;&quot;type&quot;:35,&quot;tn&quot;:&quot;;&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=100000136180288\">Jeff Johnson</a> <span data-jsid=\"text\" class=\"commentBody\">No 15th?! Booooooo.</span><span></span></div><div class=\"commentActions fsm fwn fcg\"><a class=\"uiLinkSubtle\" href=\"/LawlabeeTheWallaby/posts/424129870965893?comment_id=4800975&amp;offset=0&amp;total_comments=6\" data-ft=\"&#123;&quot;tn&quot;:&quot;N&quot;&#125;\"><abbr title=\"Thursday, August 9, 2012 at 8:40pm\" data-utime=\"1344559212\">August 9 at 8:40pm</abbr></a> via <a class=\"uiLinkSubtle\" href=\"http://www.facebook.com/mobile/\">mobile</a> · <span class=\"comment_like_4800975 fsm fwn fcg\" data-ft=\"&#123;&quot;type&quot;:36,&quot;tn&quot;:&quot;&gt;&quot;&#125;\"><button class=\"stat_elem as_link cmnt_like_link\" type=\"submit\" name=\"like_comment_id[4800975]\" value=\"4800975\" title=\"Like this comment\"><span class=\"default_message\">Like</span><span class=\"saving_message\">Unlike</span></button></span></div></div></div></li><li class=\"uiUfiComment comment_4800979 ufiItem ufiItem\" data-ft=\"&#123;&quot;tn&quot;:&quot;R&quot;&#125;\"><div class=\"UIImageBlock clearfix uiUfiActorBlock\"><a class=\"actorPic UIImageBlock_Image UIImageBlock_SMALL_Image\" href=\"http://www.facebook.com/PascalPenguin\" tabindex=\"-1\" data-ft=\"&#123;&quot;type&quot;:34,&quot;tn&quot;:&quot;T&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=500980277\"><img class=\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__medium img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/211729_500980277_2117045636_q.jpg\" alt=\"\" /></a><a data-hover=\"tooltip\" title=\"Hide as Spam\" class=\"commentRemoverButton UIImageBlock_Ext uiCloseButton\" href=\"#\" role=\"button\" rel=\"async-post\" ajaxify=\"/ajax/ufi/one_click_remove?comment_id=4800979&amp;commenter_id=500980277&amp;profile_id=1055580469&amp;post_fbid=424132380965642&amp;can_remove=0&amp;can_report=1&amp;can_edit=0&amp;is_spam=0&amp;report_link=\u00252Fajax\u00252Freport.php\u00253Fcontent_type\u00253D74\u002526cid\u00253D424132380965642\u002526rid\u00253D500980277\u002526cid2\u00253D0\u002526profile\u00253D1055580469\u002526h\u00253DAfi_SzFG9yimgZ5f&amp;feedback_params=\u00257B\u002522actor\u002522\u00253A\u00252210715287\u002522\u00252C\u002522target_fbid\u002522\u00253A\u002522424129870965893\u002522\u00252C\u002522target_profile_id\u002522\u00253A\u0025221055580469\u002522\u00252C\u002522type_id\u002522\u00253A\u00252217\u002522\u00252C\u002522assoc_obj_id\u002522\u00253A\u002522\u002522\u00252C\u002522source_app_id\u002522\u00253A\u0025222309869772\u002522\u00252C\u002522extra_story_params\u002522\u00253A\u00255B\u00255D\u00252C\u002522content_timestamp\u002522\u00253A\u0025221344558605\u002522\u00252C\u002522check_hash\u002522\u00253A\u002522AQDlGaa92_4kZbI8\u002522\u00252C\u002522source\u002522\u00253A\u00252213\u002522\u00257D\"></a><div data-ft=\"&#123;&quot;type&quot;:33,&quot;tn&quot;:&quot;K&quot;&#125;\" class=\"UIImageBlock_Content UIImageBlock_SMALL_Content\"><div class=\"commentContent\"><a class=\"actorName\" href=\"http://www.facebook.com/PascalPenguin\" data-ft=\"&#123;&quot;type&quot;:35,&quot;tn&quot;:&quot;;&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=500980277\">Kevin Goss</a> <span data-jsid=\"text\" class=\"commentBody\">The original post says that 15th is Trixie. They were too lazy to reupload it I guess.</span><span></span></div><div class=\"commentActions fsm fwn fcg\"><a class=\"uiLinkSubtle\" href=\"/LawlabeeTheWallaby/posts/424129870965893?comment_id=4800979&amp;offset=0&amp;total_comments=6\" data-ft=\"&#123;&quot;tn&quot;:&quot;N&quot;&#125;\"><abbr title=\"Thursday, August 9, 2012 at 8:42pm\" data-utime=\"1344559353\">August 9 at 8:42pm</abbr></a> · <span class=\"comment_like_4800979 fsm fwn fcg\" data-ft=\"&#123;&quot;type&quot;:36,&quot;tn&quot;:&quot;&gt;&quot;&#125;\"><button class=\"stat_elem as_link cmnt_like_link\" type=\"submit\" name=\"like_comment_id[4800979]\" value=\"4800979\" title=\"Like this comment\"><span class=\"default_message\">Like</span><span class=\"saving_message\">Unlike</span></button></span></div></div></div></li></ul></li><li class=\"uiUfiAddComment clearfix uiUfiSmall ufiItem ufiItem uiListItem  uiListVerticalItemBorder\" data-ft=\"&#123;&quot;tn&quot;:&quot;[&quot;&#125;\"><div class=\"UIImageBlock clearfix mentionsAddComment\"><img class=\"-cx-PRIVATE-uiSquareImage__root actorPic UIImageBlock_Image UIImageBlock_ICON_Image -cx-PRIVATE-uiSquareImage__medium img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-ash2/275624_100001812504199_1255023530_q.jpg\" alt=\"\" /><div class=\"commentArea UIImageBlock_Content UIImageBlock_ICON_Content\"><div class=\"commentBox\"><div class=\"uiMentionsInput textBoxContainer\" id=\"uq3j2t_25\"><div class=\"highlighter\"><div><span class=\"highlighterContent\"></span></div></div><div class=\"uiTypeahead mentionsTypeahead\" id=\"uq3j2t_26\"><div class=\"wrap\"><input type=\"hidden\" autocomplete=\"off\" class=\"hiddenInput\" /><div class=\"innerWrap\"><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function e045da6d32c1907eb3ec86c506a12d0f22c5f8e00(event) {\\u000a    Bootloader.loadComponents([\\\"control-textarea\\\",], function() {\\u000a        TextAreaControl.getInstance(this);\\u000a    }.bind(this));\\u000a};\"), (\"s20e6054e12ac25bb433a91710cda04b586addd04\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction e045da6d32c1907eb3ec86c506a12d0f22c5f8e00(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s20e6054e12ac25bb433a91710cda04b586addd04_0\"), (s20e6054e12ac25bb433a91710cda04b586addd04_0_instance), (this), (arguments)))\n    };\n    (null);\n    (((JSBNG_Record.get)(Bootloader, (\"loadComponents\")))[(\"loadComponents\")])([\"control-textarea\",], (((JSBNG_Record.get)(((function() {\n        var s20e6054e12ac25bb433a91710cda04b586addd04_1_instance;\n        ((s20e6054e12ac25bb433a91710cda04b586addd04_1_instance) = ((JSBNG_Record.eventInstance)((\"s20e6054e12ac25bb433a91710cda04b586addd04_1\"))));\n        return ((JSBNG_Record.markFunction)((function() {\n            if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n                return ((JSBNG_Record.eventCall)((arguments.callee), (\"s20e6054e12ac25bb433a91710cda04b586addd04_1\"), (s20e6054e12ac25bb433a91710cda04b586addd04_1_instance), (this), (arguments)))\n            };\n            (null);\n            (((JSBNG_Record.get)(TextAreaControl, (\"getInstance\")))[(\"getInstance\")])(this);\n        })));\n    })()), (\"bind\")))[(\"bind\")])(this));\n};\nvar s20e6054e12ac25bb433a91710cda04b586addd04_0_instance;\n((s20e6054e12ac25bb433a91710cda04b586addd04_0_instance) = ((JSBNG_Record.eventInstance)((\"s20e6054e12ac25bb433a91710cda04b586addd04_0\"))));\n((JSBNG_Record.markFunction)((e045da6d32c1907eb3ec86c506a12d0f22c5f8e00)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><textarea class=\"enter_submit DOMControl_placeholder uiTextareaNoResize uiTextareaAutogrow textBox mentionsTextarea textInput\" title=\"Write a comment...\" placeholder=\"Write a comment...\" name=\"add_comment_text\" autocomplete=\"off\" aria-autocomplete=\"list\" aria-expanded=\"false\" aria-invalid=\"false\" aria-owns=\"typeahead_list_uq3j2t_26\" role=\"textbox\" onkeydown=\"return e045da6d32c1907eb3ec86c506a12d0f22c5f8e00.call(this, event);\" id=\"uq3j2t_27\">Write a comment...</textarea></div></div></div><input type=\"hidden\" autocomplete=\"off\" class=\"mentionsHidden\" /></div></div><label class=\"mts commentBtn stat_elem hidden_elem optimistic_submit uiButton uiButtonConfirm\" for=\"uq3j2t_28\"><input value=\"Comment\" class=\"enter_submit_target\" name=\"comment\" type=\"submit\" id=\"uq3j2t_28\" /></label></div></div></li></ul></div></form></div></div></div></li></ul></div><div class=\"-cx-PRIVATE-uiInlineBlock__root  mlm uiPopover highlightSelector uiStreamHide\" data-ft=\"&#123;&quot;type&quot;:55,&quot;tn&quot;:&quot;V&quot;&#125;\" id=\"uq3j2t_11\"><a class=\"highlightSelectorButton uiStreamContextButton -cx-PRIVATE-uiPopover__trigger\" href=\"#\" aria-haspopup=\"true\" aria-expanded=\"false\" rel=\"toggle\" id=\"uq3j2t_12\">Options</a></div></div></div></li> ";
// undefined
o11 = null;
// 1361
o10.parentNode = o7;
// 1363
f33216266_455.returns.push(o10);
// undefined
o10 = null;
// 1365
o10 = {};
// 1366
f33216266_476.returns.push(o10);
// 1367
// 1369
o11 = {};
// 1370
f33216266_441.returns.push(o11);
// 1371
o12 = {};
// undefined
fo33216266_486_firstChild = function() { return fo33216266_486_firstChild.returns[fo33216266_486_firstChild.inst++]; };
fo33216266_486_firstChild.returns = [];
fo33216266_486_firstChild.inst = 0;
defineGetter(o10, "firstChild", fo33216266_486_firstChild);
// undefined
o10 = null;
// undefined
fo33216266_486_firstChild.returns.push(o12);
// 1373
o11.appendChild = f33216266_443;
// undefined
fo33216266_486_firstChild.returns.push(o12);
// 1375
f33216266_443.returns.push(o12);
// 1376
o10 = {};
// undefined
fo33216266_486_firstChild.returns.push(o10);
// undefined
fo33216266_486_firstChild.returns.push(o10);
// 1380
f33216266_443.returns.push(o10);
// 1381
o13 = {};
// undefined
fo33216266_486_firstChild.returns.push(o13);
// undefined
fo33216266_486_firstChild.returns.push(o13);
// 1385
f33216266_443.returns.push(o13);
// undefined
fo33216266_486_firstChild.returns.push(null);
// 1387
o9.appendChild = f33216266_443;
// 1388
f33216266_443.returns.push(o11);
// undefined
o11 = null;
// 1389
o9.getAttribute = f33216266_456;
// 1390
f33216266_456.returns.push(null);
// 1391
o9.setAttribute = f33216266_480;
// 1392
f33216266_480.returns.push(undefined);
// 1395
// 1397
f33216266_432.returns.push(1344872059354);
// 1401
o11 = {};
// 1402
f33216266_441.returns.push(o11);
// 1404
f33216266_443.returns.push(o11);
// undefined
o11 = null;
// 1406
f33216266_432.returns.push(1344872059354);
// 1409
f33216266_432.returns.push(1344872059355);
// 1411
f33216266_432.returns.push(1344872059355);
// 1413
f33216266_432.returns.push(1344872059355);
// 1418
f33216266_432.returns.push(1344872059361);
// 1421
f33216266_432.returns.push(1344872059369);
// 1425
f33216266_432.returns.push(1344872059370);
// 1427
o11 = {};
// 1428
f33216266_450.returns.push(o11);
// 1430
o14 = {};
// 1431
f33216266_450.returns.push(o14);
// 1432
o15 = {};
// 1433
o14.firstChild = o15;
// 1435
o15.nodeType = 8;
// 1437
o15.nodeValue = " <div><div><div class=\"fbRemindersThickline\"></div></div><div class=\"mvm fbReminders\"></div></div> ";
// undefined
o15 = null;
// 1438
o14.parentNode = o7;
// 1440
f33216266_455.returns.push(o14);
// undefined
o14 = null;
// 1441
// 1442
o11.getAttribute = f33216266_456;
// undefined
o11 = null;
// 1443
f33216266_456.returns.push("pagelet_reminders");
// 1445
f33216266_432.returns.push(1344872059371);
// 1449
o11 = {};
// 1450
f33216266_441.returns.push(o11);
// 1452
f33216266_443.returns.push(o11);
// undefined
o11 = null;
// 1454
f33216266_432.returns.push(1344872059371);
// 1456
f33216266_432.returns.push(1344872059372);
// 1461
f33216266_432.returns.push(1344872059376);
// 1464
f33216266_432.returns.push(1344872059376);
// 1468
f33216266_432.returns.push(1344872059377);
// 1470
o11 = {};
// 1471
f33216266_450.returns.push(o11);
// 1473
o14 = {};
// 1474
f33216266_450.returns.push(o14);
// 1475
o15 = {};
// 1476
o14.firstChild = o15;
// 1478
o15.nodeType = 8;
// 1480
o15.nodeValue = " <div class=\"ego_column egoOrganicColumn\"><div class=\"ego_section\"><div class=\"uiHeader uiHeaderTopBorder mbs uiSideHeader\"><div class=\"clearfix uiHeaderTop\"><div class=\"rfloat\"><h5 class=\"accessible_elem\">People You May Know</h5><a class=\"uiHeaderActions\" href=\"/l.php?u=\u00252Ffind-friends\u00252Fbrowser\u00252F\u00253Fref\u00253Dpsa&amp;h=dAQHw7DYa&amp;enc=AZORR27RkTDxSpbdFGtAfVy0-adLtaae36eqYC7V_sIZ90BVJJafy6K_I-ou4cX-zTmdOy7urqoDW3cyC8tn1-1Ej4qCbrvAXoUK2U6OMJzEfC_k9D1lhQJKoDNYQrzJ_ekLIu2cwN4rrhOXr3S0uHlYfASyqlBBC1KetzK1CkDf9D3_iJvzRGswMcLlVkHkyEX6hBhDdd824REfVwAAMwHM\">See All</a></div><div><h5 tabindex=\"0\" class=\"uiHeaderTitle\" aria-hidden=\"true\">People You May Know</h5></div></div></div><div class=\"ego_unit_container\"><div class=\"clearfix ego_unit\"><a class=\"-cx-PRIVATE-uiImageBlock__image -cx-PRIVATE-uiImageBlock__mediumImage lfloat\" href=\"/l.php?u=http\u00253A\u00252F\u00252Fwww.facebook.com\u00252Fbergel\u00253Fref\u00253Dpymk&amp;h=gAQFXNuQ0&amp;enc=AZMHDv2niHUnwq_-YwfmbCUA_KGV861aI4GziEXR1lH251gD1CDO29xoGnlLqK1bJ7afSNwQKt6IlDKHQBa7ECdu3LgJFX8VZ0tqZIXMRWp_Fo7qhCe-V-jmf2Og2h2ocUs7Z-hJOQfnROTwB4SZHkFP0C6bRp7zoJtijxbVcPDT1kadxl4G0-eXH5fQP-lW5eq2wFMByAv5zF66cfNyb_rF\" data-gt=\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;13&quot;,&quot;eng_tid&quot;:&quot;542496659&quot;,&quot;eng_data&quot;:&#123;&quot;ego_service&quot;:&quot;pymk_unicorn&quot;,&quot;ego_pos&quot;:&quot;1&quot;&#125;&#125;&#125;\"><img class=\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__large img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/50110_542496659_4788_q.jpg\" alt=\"\" /></a><div class=\"-cx-PRIVATE-uiImageBlock__content \"><div class=\"egoProfileTemplate\"><a class=\"ego_x uiCloseButton uiCloseButtonSmall\" href=\"#\" role=\"button\" aria-label=\"Remove\" ajaxify=\"/ajax/eh.php?p=AT6wvJH2EJ66Ezw1R4GUuj_KAvq3kLjP99pcVEmriEWzx23fOggaNqoTu9quFGs65ob7AmyT7EpTvCxKvVxGU10yiu-8HI9sAbY3-vKoB09GkuovuXjPOpkPMAUKIppRS22_IXEZTrGQaHzSt-hmntYVmaM&amp;xids=\u00257B\u002522542496659\u002522\u00253A1\u00252C\u002522116501796\u002522\u00253A1\u00252C\u00252214402141\u002522\u00253A1\u00252C\u00252259301143\u002522\u00253A1\u00252C\u00252242000045\u002522\u00253A1\u00252C\u00252242002276\u002522\u00253A1\u00252C\u00252213746649\u002522\u00253A1\u00257D\" rel=\"async-post\" title=\"Remove\"></a><a class=\"ego_title\" href=\"/l.php?u=http\u00253A\u00252F\u00252Fwww.facebook.com\u00252Fbergel\u00253Fref\u00253Dpymk&amp;h=yAQHLhuHi&amp;enc=AZMRFhn4ygCBNjDCPlAJ82yZsuH_xMSbsFkXLfrhOcWPwTxD3WmEJpU1PHVuE1-pLLZqma9KsoEnkh8kLZXGUKY87rDdU_HNWkFxTRshG9m4SGQENu3lNB4VNXFsP12_BnIDVCew0Y25oeIFc0EV3hcXK-iqOs_mexotExOXt19rfIIeQN62-CRamB42lx-Ljjb3EcdQIMvOPKhJGWwD9Siw\" data-gt=\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;13&quot;,&quot;eng_tid&quot;:&quot;542496659&quot;,&quot;eng_data&quot;:&#123;&quot;ego_service&quot;:&quot;pymk_unicorn&quot;,&quot;ego_pos&quot;:&quot;1&quot;&#125;&#125;&#125;\">Alexandre Bergel</a><div><a class=\"uiLinkSubtle\" href=\"#\" ajaxify=\"/ajax/eh.php?p=AT7UyhT2-5bWG47HLiB5GA1v0Kf8x6bxzokiDfCLwVNj_Bu8lWRvzKTpHmhv2Kq_LoWr-pDWW-PK8b5KNi2EBioxQ2tr3RJRsVMA10gAzhwWZxUSk23BdBqZQeIg9qP0eTZ8lg&amp;xids=\u00257B\u002522542496659\u002522\u00253A1\u00252C\u002522116501796\u002522\u00253A1\u00252C\u00252214402141\u002522\u00253A1\u00252C\u00252259301143\u002522\u00253A1\u00252C\u00252242000045\u002522\u00253A1\u00252C\u00252242002276\u002522\u00253A1\u00252C\u00252213746649\u002522\u00253A1\u00257D\" rel=\"async-post\">1 mutual friend</a></div><div class=\"ego_action\"><a class=\"uiIconText\" href=\"#\" style=\"padding-left: 18px;\" ajaxify=\"/ajax/eh.php?p=AT6fWbWIKxXugYx4lFwieXunsa1OoMHjD0sNZO-n878YEnuFjjj_OmdPhKfhD1kMBkqxUOQVl79sKZjpJJCswRHpePGKbuyd0F6qTag-ohl6lEhBj63mX19Yy53jYVrsMTsK-xtfp9pZfovc2rY3v2HOc5U&amp;xids=\u00257B\u002522542496659\u002522\u00253A1\u00252C\u002522116501796\u002522\u00253A1\u00252C\u00252214402141\u002522\u00253A1\u00252C\u00252259301143\u002522\u00253A1\u00252C\u00252242000045\u002522\u00253A1\u00252C\u00252242002276\u002522\u00253A1\u00252C\u00252213746649\u002522\u00253A1\u00257D\" rel=\"async-post\"><i class=\"img sp_627qpw sx_439480\" style=\"top: 2px;\"></i>Add Friend</a></div></div></div></div><div class=\"clearfix ego_unit\"><a class=\"-cx-PRIVATE-uiImageBlock__image -cx-PRIVATE-uiImageBlock__mediumImage lfloat\" href=\"/l.php?u=http\u00253A\u00252F\u00252Fwww.facebook.com\u00252Fplovanic\u00253Fref\u00253Dpymk&amp;h=5AQH1SD51&amp;enc=AZMzoEaQxv8TU-ImDy1tjmddHVl0mEou6xYKcSujm5hAuaZ481LtKlhGyR8ACRbj_lUVABb6XNEYokKUEDX_hb9bnIgUfUIsMGEvvi_nRKEYP-KKqIdq9TliyxH-QnTjVaoyZX9cFBaawuE0FCXk4l9eAg_9HfY5_GsrWayHz3L2tYEztxdN3xQyvOPraobYj_G7m9XUvsgL8Xqik5sjr8Rm\" data-gt=\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;13&quot;,&quot;eng_tid&quot;:&quot;116501796&quot;,&quot;eng_data&quot;:&#123;&quot;ego_service&quot;:&quot;pymk_unicorn&quot;,&quot;ego_pos&quot;:&quot;2&quot;&#125;&#125;&#125;\"><img class=\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__large img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-ash2/565211_116501796_1396119670_q.jpg\" alt=\"\" /></a><div class=\"-cx-PRIVATE-uiImageBlock__content \"><div class=\"egoProfileTemplate\"><a class=\"ego_x uiCloseButton uiCloseButtonSmall\" href=\"#\" role=\"button\" aria-label=\"Remove\" ajaxify=\"/ajax/eh.php?p=AT5cWAFBdgsVLC56e82nPn2n47tarsTTaEDczCI-5kJj1PxbIoi5PaC-7m8SDERfKpLuL6C_t2-\\-\\E4TugNzp8FzllwXLKsYWlCt76HcZIA5IwUTWBnmjF864oSj9clq7Rvtwd-zxndTnKxa52OemSDZJVuo&amp;xids=\u00257B\u002522542496659\u002522\u00253A1\u00252C\u002522116501796\u002522\u00253A1\u00252C\u00252214402141\u002522\u00253A1\u00252C\u00252259301143\u002522\u00253A1\u00252C\u00252242000045\u002522\u00253A1\u00252C\u00252242002276\u002522\u00253A1\u00252C\u00252213746649\u002522\u00253A1\u00257D\" rel=\"async-post\" title=\"Remove\"></a><a class=\"ego_title\" href=\"/l.php?u=http\u00253A\u00252F\u00252Fwww.facebook.com\u00252Fplovanic\u00253Fref\u00253Dpymk&amp;h=yAQHLhuHi&amp;enc=AZP0DS0cpD6N0BMd8nR8OQHxerziWqLmb_XjWoey_7CE4B_ZztKpCbiK1Gh6rgyKSOHyID6rEzpf-_5-PQiHosDgykWCb9Z1XhykY2ZNYq-zACLz6qGyLUIBne13zaR9FkIBUpNNwbYhGqiReT7JiA1-25qcjVDT8PpoPOAY_Cp7miYa38nwMLu5wS8Rzx9r0YdRNpGaob20x9sUgQJeptvR\" data-gt=\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;13&quot;,&quot;eng_tid&quot;:&quot;116501796&quot;,&quot;eng_data&quot;:&#123;&quot;ego_service&quot;:&quot;pymk_unicorn&quot;,&quot;ego_pos&quot;:&quot;2&quot;&#125;&#125;&#125;\">Zachary Plovanic</a><div><a class=\"uiLinkSubtle\" href=\"#\" ajaxify=\"/ajax/eh.php?p=AT5QU7OYdrU0ZCheT-CdPSXiO_KQgXBVVtlaPZXeCcMHe_Qc6FSxxVZyOEaqXD_jT0oxEbAMfcNH438h4cj0ebg-9GE6ZWNwDxLR9MzLJyJGx-PyzUPsi_n5H8vb5bvtL0UhnQ&amp;xids=\u00257B\u002522542496659\u002522\u00253A1\u00252C\u002522116501796\u002522\u00253A1\u00252C\u00252214402141\u002522\u00253A1\u00252C\u00252259301143\u002522\u00253A1\u00252C\u00252242000045\u002522\u00253A1\u00252C\u00252242002276\u002522\u00253A1\u00252C\u00252213746649\u002522\u00253A1\u00257D\" rel=\"async-post\">1 mutual friend</a></div><div class=\"ego_action\"><a class=\"uiIconText\" href=\"#\" style=\"padding-left: 18px;\" ajaxify=\"/ajax/eh.php?p=AT7xVUjEFXi6NQWC2HJj4FmsA3nuFVY2ROAbWoVNV6uSnaV_7WiG2iwcqxyeKZVoYUyOlIxFLgstGkVUh6z9y4jCSj3uq-4dBK0MnW9hOw4dfdT8Jn9ZbyCy6SuuE0GbwFplORx_kmfywdwR5jzvepPRdFI&amp;xids=\u00257B\u002522542496659\u002522\u00253A1\u00252C\u002522116501796\u002522\u00253A1\u00252C\u00252214402141\u002522\u00253A1\u00252C\u00252259301143\u002522\u00253A1\u00252C\u00252242000045\u002522\u00253A1\u00252C\u00252242002276\u002522\u00253A1\u00252C\u00252213746649\u002522\u00253A1\u00257D\" rel=\"async-post\"><i class=\"img sp_627qpw sx_439480\" style=\"top: 2px;\"></i>Add Friend</a></div></div></div></div><div class=\"clearfix ego_unit\"><a class=\"-cx-PRIVATE-uiImageBlock__image -cx-PRIVATE-uiImageBlock__mediumImage lfloat\" href=\"/l.php?u=http\u00253A\u00252F\u00252Fwww.facebook.com\u00252Fjeremy.sher\u00253Fref\u00253Dpymk&amp;h=kAQGu-FSt&amp;enc=AZN0i5snETsPma5Ovl7fQL_ORO9enrRry0TuyFgb_tprH-JbSOpI2w5cuTA_Ktd1rGbkLh1a2FRUkDatOmjJceAMB2gAPYy0Mgln53O81m0CakoOASC5LZOqFvnJ0LIOI8eO_6w9ogbUO7Q1rOTgao_VkGU8nAg-LuObPRkTLfmeWzqd5QN3953OgNMy97qpkSA-1p-Zt-ghROMKamiZ2cC5\" data-gt=\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;13&quot;,&quot;eng_tid&quot;:&quot;14402141&quot;,&quot;eng_data&quot;:&#123;&quot;ego_service&quot;:&quot;pymk_unicorn&quot;,&quot;ego_pos&quot;:&quot;3&quot;&#125;&#125;&#125;\"><img class=\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__large img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/157483_14402141_1803434093_q.jpg\" alt=\"\" /></a><div class=\"-cx-PRIVATE-uiImageBlock__content \"><div class=\"egoProfileTemplate\"><a class=\"ego_x uiCloseButton uiCloseButtonSmall\" href=\"#\" role=\"button\" aria-label=\"Remove\" ajaxify=\"/ajax/eh.php?p=AT5Pbr-xdR-d5K52zyANhjgmiKslj-ioUpmMg6_kc4ONDy3vG3h1YeUNw5nz75e0S4LFk3C3ANNBbadmsC203f0RyVatqLu1OA2iqcy_FCxjXJkgXGTiufSJ4SCy9rmi6aaMXEwuYjGkuAwyJBdOf77gsqI&amp;xids=\u00257B\u002522542496659\u002522\u00253A1\u00252C\u002522116501796\u002522\u00253A1\u00252C\u00252214402141\u002522\u00253A1\u00252C\u00252259301143\u002522\u00253A1\u00252C\u00252242000045\u002522\u00253A1\u00252C\u00252242002276\u002522\u00253A1\u00252C\u00252213746649\u002522\u00253A1\u00257D\" rel=\"async-post\" title=\"Remove\"></a><a class=\"ego_title\" href=\"/l.php?u=http\u00253A\u00252F\u00252Fwww.facebook.com\u00252Fjeremy.sher\u00253Fref\u00253Dpymk&amp;h=iAQHWTQBk&amp;enc=AZPe5uYzPuL0DyjqIFnq1xUSaOEShUNXwGusr2Q9MPxRxLvVNpB-Z1nxHYZNeWGjQIkoO32qxoRQjFTZfZ3S0TipxHzbY2oZT8ER0Tc-fh9yUqm0iy47FNV34UpuEME2hL54D7kG_KHs-_gzhpH_XmrCKiqA1jv2wYy0PUqYQbMDG7f_4PM1JbXfy5-XXYHTtNqghplbb0bWCIS0z6dtzeC8\" data-gt=\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;13&quot;,&quot;eng_tid&quot;:&quot;14402141&quot;,&quot;eng_data&quot;:&#123;&quot;ego_service&quot;:&quot;pymk_unicorn&quot;,&quot;ego_pos&quot;:&quot;3&quot;&#125;&#125;&#125;\">Jeremy Sher</a><div><a class=\"uiLinkSubtle\" href=\"#\" ajaxify=\"/ajax/eh.php?p=AT6-VTx5EbELUvp8gUoVpsunu8foSjvd9soWyIT7mdtiU9cbc8fdiNBBHbGdP74eewq09g5O6FsPF9fUUk1g2q3DSZi4rF5BIFXzpGHgTwHQSPkr3-zdXvRSzPzuO3hOCYmiSA&amp;xids=\u00257B\u002522542496659\u002522\u00253A1\u00252C\u002522116501796\u002522\u00253A1\u00252C\u00252214402141\u002522\u00253A1\u00252C\u00252259301143\u002522\u00253A1\u00252C\u00252242000045\u002522\u00253A1\u00252C\u00252242002276\u002522\u00253A1\u00252C\u00252213746649\u002522\u00253A1\u00257D\" rel=\"async-post\">1 mutual friend</a></div><div class=\"ego_action\"><a class=\"uiIconText\" href=\"#\" style=\"padding-left: 18px;\" ajaxify=\"/ajax/eh.php?p=AT5p3PKgvGeEaTNv2a2WZ0_JeunL2ztmVz8HMkDo3gZlRwMqBLaSlsmT9nbvU5UltyyLFZylk3thsPdpuyeF4AgT1eSNiuKO5ndZMgxYak9rL0wVNSvnOvncLwsv6WOdUmr35jNznhihVu5N6UVJ7X-ER4s&amp;xids=\u00257B\u002522542496659\u002522\u00253A1\u00252C\u002522116501796\u002522\u00253A1\u00252C\u00252214402141\u002522\u00253A1\u00252C\u00252259301143\u002522\u00253A1\u00252C\u00252242000045\u002522\u00253A1\u00252C\u00252242002276\u002522\u00253A1\u00252C\u00252213746649\u002522\u00253A1\u00257D\" rel=\"async-post\"><i class=\"img sp_627qpw sx_439480\" style=\"top: 2px;\"></i>Add Friend</a></div></div></div></div><div class=\"clearfix ego_unit\"><a class=\"-cx-PRIVATE-uiImageBlock__image -cx-PRIVATE-uiImageBlock__mediumImage lfloat\" href=\"/l.php?u=http\u00253A\u00252F\u00252Fwww.facebook.com\u00252Fjackie.soenneker\u00253Fref\u00253Dpymk&amp;h=cAQGlmxHG&amp;enc=AZNHTcqt6I3KA0Cxxto31AZ7dH_2B9RoA6wbAf2HAQ1xb9zxX09RgzHXNnbmKi4ttpSyzPHXILple8nYtiWWBEdjiMjIy-jQpwzbphwnVpu-01XvOGfKMcrFX4l4pJdMLgb__oDgzFP1Kzuc-zKkGT-UZBVYbOFVKI1EGVsdKMY1FmBA9eWGOcdbz1FcFzi4hw9ZV3ePOOgIi9QqjEvd1Reu\" data-gt=\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;13&quot;,&quot;eng_tid&quot;:&quot;59301143&quot;,&quot;eng_data&quot;:&#123;&quot;ego_service&quot;:&quot;pymk_unicorn&quot;,&quot;ego_pos&quot;:&quot;4&quot;&#125;&#125;&#125;\"><img class=\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__large img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-ash2/157415_59301143_1662057035_q.jpg\" alt=\"\" /></a><div class=\"-cx-PRIVATE-uiImageBlock__content \"><div class=\"egoProfileTemplate\"><a class=\"ego_x uiCloseButton uiCloseButtonSmall\" href=\"#\" role=\"button\" aria-label=\"Remove\" ajaxify=\"/ajax/eh.php?p=AT4ag-o4cHwYrF73h5b9DOqCMxIQlfHrEi3MD4ZXOsBODlUkjOJRHDjgRfcgwJXd8Hd85RKAx_avb0BH-4ojiMosX7Nhv4bQfNod_yP6KNBsh6cOe4mO5yCBUwHDaClEcWzyBXMEGQVAVxJXC2JOERciWRg&amp;xids=\u00257B\u002522542496659\u002522\u00253A1\u00252C\u002522116501796\u002522\u00253A1\u00252C\u00252214402141\u002522\u00253A1\u00252C\u00252259301143\u002522\u00253A1\u00252C\u00252242000045\u002522\u00253A1\u00252C\u00252242002276\u002522\u00253A1\u00252C\u00252213746649\u002522\u00253A1\u00257D\" rel=\"async-post\" title=\"Remove\"></a><a class=\"ego_title\" href=\"/l.php?u=http\u00253A\u00252F\u00252Fwww.facebook.com\u00252Fjackie.soenneker\u00253Fref\u00253Dpymk&amp;h=8AQEO4DgS&amp;enc=AZM6DQZsQenwdUUK-J4VPMqBAYtL1-jPE1XtBtSG24aYqQKukhoMoWUFouBCMi6GvmYI7J1jC9nF8J0GEofQqTf-KBItZyc629ZNSJD-p6MCZX5GyBqMigb3FtBJ5rVhl8fVxB8GlioaNjl65c5Zuoit6VEaG5q3G1Q2EtJOxibb-uA8UZoXjYU-A2IprxArgjQIrQzYZAkpyvegDDgdwF1z\" data-gt=\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;13&quot;,&quot;eng_tid&quot;:&quot;59301143&quot;,&quot;eng_data&quot;:&#123;&quot;ego_service&quot;:&quot;pymk_unicorn&quot;,&quot;ego_pos&quot;:&quot;4&quot;&#125;&#125;&#125;\">Jackie Soenneker</a><div><a class=\"uiLinkSubtle\" href=\"#\" ajaxify=\"/ajax/eh.php?p=AT4ui471cRi2jjN_k9xZpa1ucvsgyAO9QrJdAngPIkHTvhweDfNCHpGHFJp2aY4omvMY9n6WO4_1IrJ4htvzC0kKRR7bm4AHNZ6SiXM-oKQyoFBQ22nn4wxMrpWfgtnQZzo9bQ&amp;xids=\u00257B\u002522542496659\u002522\u00253A1\u00252C\u002522116501796\u002522\u00253A1\u00252C\u00252214402141\u002522\u00253A1\u00252C\u00252259301143\u002522\u00253A1\u00252C\u00252242000045\u002522\u00253A1\u00252C\u00252242002276\u002522\u00253A1\u00252C\u00252213746649\u002522\u00253A1\u00257D\" rel=\"async-post\">1 mutual friend</a></div><div class=\"ego_action\"><a class=\"uiIconText\" href=\"#\" style=\"padding-left: 18px;\" ajaxify=\"/ajax/eh.php?p=AT5GqNFonalQp4GU-rheYJz2m0jo-U6Za1G1dml4y9OxTWmk6cZAO4mEibjktC7o3xVHvdFgVdisFBoIMjJ9udkN6-Far9ztuWW8QfqLPKkR-hekIw_MhrXrwEBaGJeYnwCuHmF9h6dY1-p60ajsaord-04&amp;xids=\u00257B\u002522542496659\u002522\u00253A1\u00252C\u002522116501796\u002522\u00253A1\u00252C\u00252214402141\u002522\u00253A1\u00252C\u00252259301143\u002522\u00253A1\u00252C\u00252242000045\u002522\u00253A1\u00252C\u00252242002276\u002522\u00253A1\u00252C\u00252213746649\u002522\u00253A1\u00257D\" rel=\"async-post\"><i class=\"img sp_627qpw sx_439480\" style=\"top: 2px;\"></i>Add Friend</a></div></div></div></div><div class=\"clearfix ego_unit\"><a class=\"-cx-PRIVATE-uiImageBlock__image -cx-PRIVATE-uiImageBlock__mediumImage lfloat\" href=\"/l.php?u=http\u00253A\u00252F\u00252Fwww.facebook.com\u00252Frasnider\u00253Fref\u00253Dpymk&amp;h=UAQHWxY_U&amp;enc=AZO0seTy8_tTnxQt5V3nleYtCVocWhgr90incQ8Z3ZYL-7UWCEQvW2ql30A9_M1MGKx2Ff8UbohQeu1ZOx0h6XXNnM789lA3R7_yxQUhKV7S548bg074qY0-E-jkrm26Sg1tVmGxq0FQVnR6G1l_F8CT17LktbDbBfYAZkxufx3WeTXj82nmBJQM02snL6H3_vE_pU24z4fY3UVb9r-BUp5d\" data-gt=\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;13&quot;,&quot;eng_tid&quot;:&quot;42000045&quot;,&quot;eng_data&quot;:&#123;&quot;ego_service&quot;:&quot;pymk_unicorn&quot;,&quot;ego_pos&quot;:&quot;5&quot;&#125;&#125;&#125;\"><img class=\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__large img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/372249_42000045_609911003_q.jpg\" alt=\"\" id=\"uq3jae_1\" /></a><div class=\"-cx-PRIVATE-uiImageBlock__content \"><div class=\"egoProfileTemplate\"><a class=\"ego_x uiCloseButton uiCloseButtonSmall\" href=\"#\" role=\"button\" aria-label=\"Remove\" ajaxify=\"/ajax/eh.php?p=AT6Ei1I1vTKqzvkZvBJS4zOcxIAg7IQW2tmGkURdXEiczeYMwImtzfw_AUckZu7WmtNwYXJGI4tlYRymZOjEueWcUeYMQvTzKyiocHzC1SsafUOxSpPxkKS5LddBMqpwpOqHGJmvpK_h0TmqFqxv_6FmzDA&amp;xids=\u00257B\u002522542496659\u002522\u00253A1\u00252C\u002522116501796\u002522\u00253A1\u00252C\u00252214402141\u002522\u00253A1\u00252C\u00252259301143\u002522\u00253A1\u00252C\u00252242000045\u002522\u00253A1\u00252C\u00252242002276\u002522\u00253A1\u00252C\u00252213746649\u002522\u00253A1\u00257D\" rel=\"async-post\" title=\"Remove\"></a><a class=\"ego_title\" href=\"/l.php?u=http\u00253A\u00252F\u00252Fwww.facebook.com\u00252Frasnider\u00253Fref\u00253Dpymk&amp;h=MAQG4LJra&amp;enc=AZMIK7oG89B9guwq5FF6kVGX4JPwK1f4r9c9PBmjXYc2zQqRUBvE9LLulSOgPxcS5jMNw6zZX_IA50RffsQL95kAUVh1I-INw27b_eVUTsf1s8JBYWnw-d2UJQ26giPtHqFPld1bY0Mg4tlH8LDc_BwXCA4Kh04ZXuF2H6pGvjt_ZpgPRItjRab_yIckwKFOFnM-SRl_Ks8R_2gkJeeoeCsv\" data-gt=\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;13&quot;,&quot;eng_tid&quot;:&quot;42000045&quot;,&quot;eng_data&quot;:&#123;&quot;ego_service&quot;:&quot;pymk_unicorn&quot;,&quot;ego_pos&quot;:&quot;5&quot;&#125;&#125;&#125;\">Allen Snider</a><div><a class=\"uiLinkSubtle\" href=\"#\" ajaxify=\"/ajax/eh.php?p=AT7Vd6f5oksgRpImDShAJi6s9yg4qbXIY-\\-\\mBiwm27iPCjMi21pCU6zNIPovV3fS-Q4a_OtHpC96FKrQOU9L0xk9oMYzTiKabQfHk24ZkQxtmHj0P6-0kTAJu3zDE6VwOT-DHw&amp;xids=\u00257B\u002522542496659\u002522\u00253A1\u00252C\u002522116501796\u002522\u00253A1\u00252C\u00252214402141\u002522\u00253A1\u00252C\u00252259301143\u002522\u00253A1\u00252C\u00252242000045\u002522\u00253A1\u00252C\u00252242002276\u002522\u00253A1\u00252C\u00252213746649\u002522\u00253A1\u00257D\" rel=\"async-post\">1 mutual friend</a></div><div class=\"ego_action\"><a class=\"uiIconText\" href=\"#\" style=\"padding-left: 18px;\" ajaxify=\"/ajax/eh.php?p=AT7cemhLBpbCrCl2XZh85Evntwqj8oergrIsB4PA55onw6srB4N0JBhswFyDmRWDc8GlJKwdx_vtB37Q7nIkq37ku9GhbgSBlanu7PoHFOADXjSlsgUeLIeiaYCNm2SQtXPdFptWyD2VclWCj2eJN82f1ms&amp;xids=\u00257B\u002522542496659\u002522\u00253A1\u00252C\u002522116501796\u002522\u00253A1\u00252C\u00252214402141\u002522\u00253A1\u00252C\u00252259301143\u002522\u00253A1\u00252C\u00252242000045\u002522\u00253A1\u00252C\u00252242002276\u002522\u00253A1\u00252C\u00252213746649\u002522\u00253A1\u00257D\" rel=\"async-post\"><i class=\"img sp_627qpw sx_439480\" style=\"top: 2px;\"></i>Add Friend</a></div></div></div></div><div class=\"clearfix ego_unit\"><a class=\"-cx-PRIVATE-uiImageBlock__image -cx-PRIVATE-uiImageBlock__mediumImage lfloat\" href=\"/l.php?u=http\u00253A\u00252F\u00252Fwww.facebook.com\u00252Fcharlie.tang\u00253Fref\u00253Dpymk&amp;h=6AQEtvQfw&amp;enc=AZPr8BRBv2vZr9VImjz-M39YixyY9Ig6PgqODV5dPLjDYyRwd6SfwCiJvoxrH4thigOb_jPMM5_WccNJm8tbUcc_Prfx1Nk004DCNE6RSs8SbRs4hc2l3pkYWIy6hyLc2kEPJR9RLBhbxqEssUODtEtP3BKb2_krEN1Djaf3sVfwW7kQIxBH8WlXojEIRxn0bIMsYwRMPquO0U7SUg7tDo9C\" data-gt=\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;13&quot;,&quot;eng_tid&quot;:&quot;42002276&quot;,&quot;eng_data&quot;:&#123;&quot;ego_service&quot;:&quot;pymk_unicorn&quot;,&quot;ego_pos&quot;:&quot;6&quot;&#125;&#125;&#125;\"><img class=\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__large img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-ash2/157170_42002276_1820165639_q.jpg\" alt=\"\" /></a><div class=\"-cx-PRIVATE-uiImageBlock__content \"><div class=\"egoProfileTemplate\"><a class=\"ego_x uiCloseButton uiCloseButtonSmall\" href=\"#\" role=\"button\" aria-label=\"Remove\" ajaxify=\"/ajax/eh.php?p=AT4LwtNuOxrJbZ6p-LGdZwWy7BZXCT6icGccJ8SCpDpW4up_mlyn8ZttIsgmaMT90yKJWfgDfDfAfm37UeLdo0ezCRJTSauwq73JcKDWBPSmPYYxudhrjxetdQT77S-xahWNGMYItQbyiWinET7ua_vvFZ0&amp;xids=\u00257B\u002522542496659\u002522\u00253A1\u00252C\u002522116501796\u002522\u00253A1\u00252C\u00252214402141\u002522\u00253A1\u00252C\u00252259301143\u002522\u00253A1\u00252C\u00252242000045\u002522\u00253A1\u00252C\u00252242002276\u002522\u00253A1\u00252C\u00252213746649\u002522\u00253A1\u00257D\" rel=\"async-post\" title=\"Remove\"></a><a class=\"ego_title\" href=\"/l.php?u=http\u00253A\u00252F\u00252Fwww.facebook.com\u00252Fcharlie.tang\u00253Fref\u00253Dpymk&amp;h=gAQFXNuQ0&amp;enc=AZMNTPc-9SVqZUlah40FGz9DOk3w5xD-CXFeSNOyWWs4rMcxbZij6hAhMbkJoc6Hff1a8ZoDGkBWy7gjnsga5HNXYwSV8UD8KHjKRo-mS8Msurvl1s71yuUkznUL05_q9Q6TmVIEKEOg1jGG2ADKTUrwh3IguAbNnc1AS9l7j4yLZVunWdz_Znv6Kv2b0BAA9ouTDY16vhtTYAtQNvN-S_2W\" data-gt=\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;13&quot;,&quot;eng_tid&quot;:&quot;42002276&quot;,&quot;eng_data&quot;:&#123;&quot;ego_service&quot;:&quot;pymk_unicorn&quot;,&quot;ego_pos&quot;:&quot;6&quot;&#125;&#125;&#125;\">Charlie Tang</a><div><a class=\"uiLinkSubtle\" href=\"#\" ajaxify=\"/ajax/eh.php?p=AT5UcJeV484r1nP8sh2-bmWgjB77OBRF0yE8mwKYtlZxNJS-bySx1eBu3raPYYzPEqCrP3nxijBwS-zhRf2kDGmi4YNEwRYKiRGEsWxW_81IHWysfqz3ml2wiRJ8mcisCEJDyw&amp;xids=\u00257B\u002522542496659\u002522\u00253A1\u00252C\u002522116501796\u002522\u00253A1\u00252C\u00252214402141\u002522\u00253A1\u00252C\u00252259301143\u002522\u00253A1\u00252C\u00252242000045\u002522\u00253A1\u00252C\u00252242002276\u002522\u00253A1\u00252C\u00252213746649\u002522\u00253A1\u00257D\" rel=\"async-post\">1 mutual friend</a></div><div class=\"ego_action\"><a class=\"uiIconText\" href=\"#\" style=\"padding-left: 18px;\" ajaxify=\"/ajax/eh.php?p=AT5CixucsjdZSHPdn0jZXnYqts45R6h5jMD97mpR8dvW0s0ol7ep9ggn6sIGFHYJkc0aGSzZ9VIep60XOEZg57azVNayGEsgjPOPxFqRS7jFB2ZImY5iL23gfyU14d-g5V2b_hxCeme9e9JyD7wn5y8Em7I&amp;xids=\u00257B\u002522542496659\u002522\u00253A1\u00252C\u002522116501796\u002522\u00253A1\u00252C\u00252214402141\u002522\u00253A1\u00252C\u00252259301143\u002522\u00253A1\u00252C\u00252242000045\u002522\u00253A1\u00252C\u00252242002276\u002522\u00253A1\u00252C\u00252213746649\u002522\u00253A1\u00257D\" rel=\"async-post\"><i class=\"img sp_627qpw sx_439480\" style=\"top: 2px;\"></i>Add Friend</a></div></div></div></div><div class=\"clearfix ego_unit\"><a class=\"-cx-PRIVATE-uiImageBlock__image -cx-PRIVATE-uiImageBlock__mediumImage lfloat\" href=\"/l.php?u=http\u00253A\u00252F\u00252Fwww.facebook.com\u00252Fvinai\u00253Fref\u00253Dpymk&amp;h=zAQFbzZLP&amp;enc=AZNYljNhmKeqqJMek1CbXfN2bukyeOIGdPxz-GYmwBpUB05fGV2Kl21H_BXo-ICkIldlbv6TLOeg6jJrQf-LXhVxqN9i1AMBpRNTmPNCv0OP0C2jv0b5k48-vC8NUHwZnHCY9pzYMhQm93S5KgRFk6tdMrwnfSD-UVxfCCWzvGdizU-N3yTwJ2-Tz2GOCXYb9g_K5JL4MSD-uiXhoEHfwF2q\" data-gt=\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;13&quot;,&quot;eng_tid&quot;:&quot;13746649&quot;,&quot;eng_data&quot;:&#123;&quot;ego_service&quot;:&quot;pymk_unicorn&quot;,&quot;ego_pos&quot;:&quot;7&quot;&#125;&#125;&#125;\"><img class=\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__large img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-ash2/370070_13746649_710013701_q.jpg\" alt=\"\" /></a><div class=\"-cx-PRIVATE-uiImageBlock__content \"><div class=\"egoProfileTemplate\"><a class=\"ego_x uiCloseButton uiCloseButtonSmall\" href=\"#\" role=\"button\" aria-label=\"Remove\" ajaxify=\"/ajax/eh.php?p=AT7mcMjJJ2sjQfpGaTiD7kjxgdFxYPEqzMCxn8ftil201U8znmS5gDZrjFq6ZLybDHgLuCdA_3gsWuGzu3Xc3d0n2bUUMjGYe-gmoMswImbv2R84kDLrWXVK9TKrcMxEup-QfoTHq9PW4Z1uCFSCEBT3EOU&amp;xids=\u00257B\u002522542496659\u002522\u00253A1\u00252C\u002522116501796\u002522\u00253A1\u00252C\u00252214402141\u002522\u00253A1\u00252C\u00252259301143\u002522\u00253A1\u00252C\u00252242000045\u002522\u00253A1\u00252C\u00252242002276\u002522\u00253A1\u00252C\u00252213746649\u002522\u00253A1\u00257D\" rel=\"async-post\" title=\"Remove\"></a><a class=\"ego_title\" href=\"/l.php?u=http\u00253A\u00252F\u00252Fwww.facebook.com\u00252Fvinai\u00253Fref\u00253Dpymk&amp;h=BAQF2fk9L&amp;enc=AZM0XytY6Wa6nIZJVRCqU-zTUEs3Eqkmhrp5KiPkvPvPh_HGWbDu49lIb7iPvYRHeSg0SdyA9p0b6ZD-TRVxXQIvHzrEamXUz_kI8ZR4x9rN1ZEWh09F4htDdNsycNg6K8sziz8sEpI4G9gAiG8cvvlyyqJZMf0lZav72_65Rr6WvfiAXil_kRY2xs1Rr0mPArOgWPHafkc2ocjDCa1-vEE4\" data-gt=\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;13&quot;,&quot;eng_tid&quot;:&quot;13746649&quot;,&quot;eng_data&quot;:&#123;&quot;ego_service&quot;:&quot;pymk_unicorn&quot;,&quot;ego_pos&quot;:&quot;7&quot;&#125;&#125;&#125;\">Vinai Sundaram</a><div><a class=\"uiLinkSubtle\" href=\"#\" ajaxify=\"/ajax/eh.php?p=AT45NYLmFaY7h2ESLdHEVGLojhs0AEwVeoblVzbedVg9NeGH5rvjb3mbNDELHxNNO9e1_kre-iIaieqguqZh57ka4Z7lQIsppzhkvNGiwpvgeEvn5-55nE12hdLyd0JUlNQoSA&amp;xids=\u00257B\u002522542496659\u002522\u00253A1\u00252C\u002522116501796\u002522\u00253A1\u00252C\u00252214402141\u002522\u00253A1\u00252C\u00252259301143\u002522\u00253A1\u00252C\u00252242000045\u002522\u00253A1\u00252C\u00252242002276\u002522\u00253A1\u00252C\u00252213746649\u002522\u00253A1\u00257D\" rel=\"async-post\">1 mutual friend</a></div><div class=\"ego_action\"><a class=\"uiIconText\" href=\"#\" style=\"padding-left: 18px;\" ajaxify=\"/ajax/eh.php?p=AT7_IMiZNL662IBhV8_UcDZDo-1dMqRI0WF6XqyUMNQYkViKNLHnoQD7KZQnDInZ9n01Fl3-tnptp1KMK2JJtiGveqMnk4h6Y5JVKUefgkhmr4VY5DLckLMVmkfqvANYV6Duj2Zh4_QZdsS6PPl6hxa2p7I&amp;xids=\u00257B\u002522542496659\u002522\u00253A1\u00252C\u002522116501796\u002522\u00253A1\u00252C\u00252214402141\u002522\u00253A1\u00252C\u00252259301143\u002522\u00253A1\u00252C\u00252242000045\u002522\u00253A1\u00252C\u00252242002276\u002522\u00253A1\u00252C\u00252213746649\u002522\u00253A1\u00257D\" rel=\"async-post\"><i class=\"img sp_627qpw sx_439480\" style=\"top: 2px;\"></i>Add Friend</a></div></div></div></div></div></div></div> ";
// undefined
o15 = null;
// 1481
o14.parentNode = o7;
// 1483
f33216266_455.returns.push(o14);
// undefined
o14 = null;
// 1484
// 1485
o11.getAttribute = f33216266_456;
// undefined
o11 = null;
// 1486
f33216266_456.returns.push("pagelet_ego_pane_w");
// 1489
f33216266_432.returns.push(1344872059397);
// 1493
o11 = {};
// 1494
f33216266_441.returns.push(o11);
// 1496
f33216266_443.returns.push(o11);
// undefined
o11 = null;
// 1498
f33216266_432.returns.push(1344872059398);
// 1500
f33216266_432.returns.push(1344872059398);
// 1505
f33216266_432.returns.push(1344872059404);
// 1509
o11 = {};
// 1510
f33216266_441.returns.push(o11);
// 1512
f33216266_443.returns.push(o11);
// undefined
o11 = null;
// 1515
f33216266_432.returns.push(1344872059404);
// 1519
o11 = {};
// 1520
f33216266_441.returns.push(o11);
// 1521
o0.createStyleSheet = void 0;
// 1523
o14 = {};
// 1524
f33216266_476.returns.push(o14);
// 1525
// 1526
// 1527
// 1529
o15 = {};
// 1530
f33216266_476.returns.push(o15);
// 1531
// 1532
o11.appendChild = f33216266_443;
// 1533
f33216266_443.returns.push(o15);
// 1535
f33216266_432.returns.push(1344872059409);
// 1536
f33216266_13.returns.push(48);
// 1538
o16 = {};
// 1539
f33216266_476.returns.push(o16);
// 1540
// 1541
// 1542
// 1544
f33216266_443.returns.push(o16);
// undefined
o16 = null;
// 1546
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 1549
o14 = {};
// 1550
f33216266_476.returns.push(o14);
// 1551
// 1552
// 1553
// 1555
o16 = {};
// 1556
f33216266_476.returns.push(o16);
// 1557
// 1559
f33216266_443.returns.push(o16);
// 1561
f33216266_432.returns.push(1344872059410);
// 1563
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 1565
f33216266_443.returns.push(o11);
// undefined
o11 = null;
// 1567
f33216266_432.returns.push(1344872059432);
// 1569
f33216266_432.returns.push(1344872059432);
// 1574
f33216266_432.returns.push(1344872059436);
// 1577
f33216266_432.returns.push(1344872059437);
// 1581
f33216266_432.returns.push(1344872059437);
// 1583
f33216266_450.returns.push(o8);
// 1585
o11 = {};
// 1586
f33216266_450.returns.push(o11);
// 1587
o14 = {};
// 1588
o11.firstChild = o14;
// 1590
o14.nodeType = 8;
// 1592
o14.nodeValue = " <div class=\"homeSideNav\" role=\"navigation\" id=\"pinnedNav\"><div class=\"navHeader\">FAVORITES</div><div class=\"mts mbm droppableNav\"><ul class=\"uiSideNav\" data-gt=\"&#123;&quot;nav_items_count&quot;:&quot;5&quot;,&quot;nav_section&quot;:&quot;pinnedNav&quot;&#125;\"><li class=\"sideNavItem stat_elem\" id=\"navItem_app_156203961126022\"><div class=\"buttonWrap\"></div><a class=\"item clearfix\" href=\"/?sk=welcome\" title=\"\" data-gt=\"&#123;&quot;bmid&quot;:&quot;156203961126022&quot;,&quot;fbtype&quot;:&quot;128&quot;,&quot;count&quot;:&quot;0&quot;,&quot;coeff2_info&quot;:&quot;AataToJ2Fo0rvrsTk-EVPaRoUfGqiKFkf8UQkO067r_e74KnPtggHYU4Sl8Lre0TarQgy2yofHWC7qLqBLmproyC&quot;,&quot;coeff2_registry_key&quot;:&quot;0016&quot;,&quot;coeff2_action&quot;:&quot;3&quot;,&quot;coeff2_pv_signature&quot;:&quot;1880892099&quot;,&quot;rank&quot;:&quot;1&quot;&#125;\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span><span class=\"maxCountIndicator\"></span></span></div><div><span class=\"imgWrap\"><i class=\"img sp_55oxbe sx_98804b\"></i></span><div class=\"linkWrap noCount\">Welcome</div></div></a></li><li class=\"sideNavItem stat_elem selectedItem open\" id=\"navItem_app_4748854339\"><div class=\"buttonWrap\"><div class=\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\"><div class=\"wrap\"><a class=\"uiSelectorButton uiCloseButton\" href=\"#\" role=\"button\" title=\"Edit\" aria-label=\"Edit News Feed\" aria-haspopup=\"1\" rel=\"toggle\"></a><div class=\"uiSelectorMenuWrapper uiToggleFlyout\"><div role=\"menu\" class=\"uiMenu uiSelectorMenu\"><ul class=\"uiMenuInner\"><li class=\"uiMenuItem\" data-label=\"Edit Settings\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"0\" href=\"/ajax/feed/edit_options_dialog.php\" rel=\"dialog\"><span class=\"itemLabel fsm\">Edit Settings</span></a></li></ul></div></div></div></div></div><a class=\"item clearfix\" href=\"/?sk=nf\" title=\"\" data-gt=\"&#123;&quot;bmid&quot;:&quot;4748854339&quot;,&quot;fbtype&quot;:&quot;128&quot;,&quot;count&quot;:&quot;0&quot;,&quot;coeff2_info&quot;:&quot;AauGiUHW5k_Xknp92WAUK9ZUd1UXs7WyuNYKxrIYp47kW2piH9IztlTo9m_CzDY68cs&quot;,&quot;coeff2_registry_key&quot;:&quot;0016&quot;,&quot;coeff2_action&quot;:&quot;3&quot;,&quot;coeff2_pv_signature&quot;:&quot;1880892099&quot;,&quot;rank&quot;:&quot;2&quot;&#125;\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span><span class=\"maxCountIndicator\"></span></span></div><div><span class=\"imgWrap\"><i class=\"img sp_14y7us sx_f8da38\"></i></span><div class=\"linkWrap noCount\">News Feed</div></div></a></li><li class=\"sideNavItem stat_elem\" id=\"navItem_app_217974574879787\"><div class=\"buttonWrap\"><div class=\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\"><div class=\"wrap\"><a class=\"uiSelectorButton uiCloseButton\" href=\"#\" role=\"button\" title=\"Edit\" aria-label=\"Edit Messages\" aria-haspopup=\"1\" rel=\"toggle\"></a><div class=\"uiSelectorMenuWrapper uiToggleFlyout\"><div role=\"menu\" class=\"uiMenu uiSelectorMenu\"><ul class=\"uiMenuInner\"><li class=\"uiMenuItem favorite\" data-label=\"Remove from Favorites\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"0\" href=\"#\"><span class=\"itemLabel fsm\">Remove from Favorites</span></a></li><li class=\"uiMenuItem rearrange\" data-label=\"Rearrange\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"-1\" href=\"#\"><span class=\"itemLabel fsm\">Rearrange</span></a></li></ul></div></div></div></div></div><a class=\"item clearfix sortableItem\" href=\"/messages/\" title=\"\" data-gt=\"&#123;&quot;bmid&quot;:&quot;217974574879787&quot;,&quot;fbtype&quot;:&quot;128&quot;,&quot;count&quot;:&quot;0&quot;,&quot;coeff2_info&quot;:&quot;AavDIutWqUaJOF9cfFsCMaYmc9Qp00cTpwlKELrp2llS6hBcX-bIMC-5ySzm99G0RD8t-bQYZzB8Qkpg_dxZtHUS&quot;,&quot;coeff2_registry_key&quot;:&quot;0016&quot;,&quot;coeff2_action&quot;:&quot;3&quot;,&quot;coeff2_pv_signature&quot;:&quot;1880892099&quot;,&quot;rank&quot;:&quot;3&quot;&#125;\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span><span class=\"maxCountIndicator\"></span></span><span class=\"grip\"></span></div><div><span class=\"imgWrap\"><i class=\"img sp_ae80w4 sx_0ca7fd\"></i></span><div class=\"linkWrap noCount\">Messages</div></div></a><ul><li id=\"navItem_other\"><a class=\"subitem clearfix\" href=\"/messages/other/\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span><span class=\"maxCountIndicator\"></span></span></div><div><div class=\"linkWrap noCount\">Other</div></div></a></li></ul><span class=\"mover hidden_elem\"></span></li><li class=\"sideNavItem stat_elem\" id=\"navItem_app_2344061033\"><div class=\"buttonWrap\"><div class=\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\"><div class=\"wrap\"><a class=\"uiSelectorButton uiCloseButton\" href=\"#\" role=\"button\" title=\"Edit\" aria-label=\"Edit Events\" aria-haspopup=\"1\" rel=\"toggle\"></a><div class=\"uiSelectorMenuWrapper uiToggleFlyout\"><div role=\"menu\" class=\"uiMenu uiSelectorMenu\"><ul class=\"uiMenuInner\"><li class=\"uiMenuItem favorite\" data-label=\"Remove from Favorites\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"0\" href=\"#\"><span class=\"itemLabel fsm\">Remove from Favorites</span></a></li><li class=\"uiMenuItem rearrange\" data-label=\"Rearrange\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"-1\" href=\"#\"><span class=\"itemLabel fsm\">Rearrange</span></a></li></ul></div></div></div></div></div><a class=\"item clearfix sortableItem\" href=\"/events/list\" title=\"\" data-gt=\"&#123;&quot;bmid&quot;:&quot;2344061033&quot;,&quot;fbtype&quot;:&quot;128&quot;,&quot;count&quot;:&quot;0&quot;,&quot;coeff2_info&quot;:&quot;AauTGlHQ60KN9snG7fEBjYM5LAktbMGxOtJEcQ2Ud-x6xZ-hd3YxdCFwe92eq9YTkPg&quot;,&quot;coeff2_registry_key&quot;:&quot;0016&quot;,&quot;coeff2_action&quot;:&quot;3&quot;,&quot;coeff2_pv_signature&quot;:&quot;1880892099&quot;,&quot;rank&quot;:&quot;4&quot;&#125;\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span><span class=\"maxCountIndicator\"></span></span><span class=\"grip\"></span></div><div><span class=\"imgWrap\"><img class=\"img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yg/r/HZt027gpydB.png\" alt=\"\" width=\"15\" height=\"16\" /></span><div class=\"linkWrap noCount\">Events</div></div></a><span class=\"mover hidden_elem\"></span></li><li class=\"sideNavItem stat_elem\" id=\"navItem_app_2356318349\"><div class=\"buttonWrap\"><div class=\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\"><div class=\"wrap\"><a class=\"uiSelectorButton uiCloseButton\" href=\"#\" role=\"button\" title=\"Edit\" aria-label=\"Edit Find Friends\" aria-haspopup=\"1\" rel=\"toggle\"></a><div class=\"uiSelectorMenuWrapper uiToggleFlyout\"><div role=\"menu\" class=\"uiMenu uiSelectorMenu\"><ul class=\"uiMenuInner\"><li class=\"uiMenuItem favorite\" data-label=\"Remove from Favorites\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"0\" href=\"#\"><span class=\"itemLabel fsm\">Remove from Favorites</span></a></li><li class=\"uiMenuItem rearrange\" data-label=\"Rearrange\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"-1\" href=\"#\"><span class=\"itemLabel fsm\">Rearrange</span></a></li></ul></div></div></div></div></div><a class=\"item clearfix sortableItem\" href=\"/?sk=ff\" title=\"Find Friends\" data-gt=\"&#123;&quot;bmid&quot;:&quot;2356318349&quot;,&quot;fbtype&quot;:&quot;128&quot;,&quot;count&quot;:&quot;0&quot;,&quot;coeff2_info&quot;:&quot;AatLCY2RJwDaqzYrO_nc415utsw-t-jxz8PrlpYEbfLsrJTlXclkTD-gs0LGsv8a_NY&quot;,&quot;coeff2_registry_key&quot;:&quot;0016&quot;,&quot;coeff2_action&quot;:&quot;3&quot;,&quot;coeff2_pv_signature&quot;:&quot;1880892099&quot;,&quot;rank&quot;:&quot;5&quot;&#125;\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span><span class=\"maxCountIndicator\"></span></span><span class=\"grip\"></span></div><div><span class=\"imgWrap\"><i class=\"img sp_ae80w4 sx_015f64\"></i></span><div class=\"linkWrap noCount\">Find Friends</div></div></a><span class=\"mover hidden_elem\"></span></li></ul><div class=\"actionLinks stat_elem\"><a class=\"navEditDone\" href=\"#\" data-endpoint=\"/ajax/bookmark/edit/\"><span class=\"navEdit\">Edit</span><span class=\"navDone\">Done</span></a><span class=\"loadingIndicator\"></span></div></div></div> ";
// undefined
o14 = null;
// 1593
o11.parentNode = o7;
// 1595
f33216266_455.returns.push(o11);
// undefined
o11 = null;
// 1596
// undefined
o8 = null;
// 1598
f33216266_456.returns.push("pagelet_pinned_nav");
// 1601
f33216266_432.returns.push(1344872059462);
// 1605
o8 = {};
// 1606
f33216266_441.returns.push(o8);
// 1608
f33216266_443.returns.push(o8);
// undefined
o8 = null;
// 1610
f33216266_432.returns.push(1344872059463);
// 1612
f33216266_432.returns.push(1344872059463);
// 1617
f33216266_432.returns.push(1344872059467);
// 1620
f33216266_432.returns.push(1344872059467);
// 1624
f33216266_432.returns.push(1344872059468);
// 1626
o8 = {};
// 1627
f33216266_450.returns.push(o8);
// 1629
o11 = {};
// 1630
f33216266_450.returns.push(o11);
// 1631
o14 = {};
// 1632
o11.firstChild = o14;
// 1634
o14.nodeType = 8;
// 1636
o14.nodeValue = " <div><div class=\"homeSideNav\" role=\"navigation\" id=\"interestsNav\"><div class=\"navHeader hidden_elem\"><a href=\"/bookmarks/interests\"><div class=\"clearfix\"><div class=\"lfloat\">INTERESTS</div><span class=\"mrm rfloat\"><div class=\"bookmarksNavSeeAll\">MORE</div><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /></span></div></a></div><ul class=\"uiSideNav mts mbm nonDroppableNav\" data-gt=\"&#123;&quot;nav_items_count&quot;:&quot;0&quot;,&quot;nav_section&quot;:&quot;interestsNav&quot;&#125;\"></ul></div><div class=\"homeSideNav\" role=\"navigation\" id=\"pagesNav\"><div class=\"navHeader hidden_elem\">PAGES</div><ul class=\"uiSideNav mts mbm nonDroppableNav\" data-gt=\"&#123;&quot;nav_items_count&quot;:&quot;0&quot;,&quot;nav_section&quot;:&quot;pagesNav&quot;&#125;\"></ul></div><div class=\"homeSideNav\" role=\"navigation\" id=\"groupsNav\"><div class=\"navHeader\">GROUPS</div><ul class=\"uiSideNav mts mbm nonDroppableNav\" data-gt=\"&#123;&quot;nav_items_count&quot;:&quot;1&quot;,&quot;nav_section&quot;:&quot;groupsNav&quot;&#125;\"><li class=\"sideNavItem stat_elem\" id=\"navItem_app_230259100322928\"><div class=\"buttonWrap\"></div><a class=\"item clearfix\" href=\"/ajax/groups/create_get.php?ref=bookmarks\" title=\"Create Group...\" rel=\"async\" data-gt=\"&#123;&quot;bmid&quot;:&quot;230259100322928&quot;,&quot;fbtype&quot;:&quot;128&quot;,&quot;count&quot;:&quot;0&quot;,&quot;coeff2_info&quot;:&quot;AavBl7kW0NFEmNeUAj4e9KBaFpEs5wZBnfpaBTE0YgH5jmsJZiasxME6TVHDWG9YnO_cfk71lTc01u-SeVQEN2Bg&quot;,&quot;coeff2_registry_key&quot;:&quot;0016&quot;,&quot;coeff2_action&quot;:&quot;3&quot;,&quot;coeff2_pv_signature&quot;:&quot;1880892099&quot;,&quot;rank&quot;:&quot;1&quot;&#125;\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span><span class=\"maxCountIndicator\"></span></span></div><div><span class=\"imgWrap\"><i class=\"img sp_14y7us sx_8b605e\"></i></span><div class=\"linkWrap noCount\">Create Group...</div></div></a></li></ul></div><div class=\"homeSideNav\" role=\"navigation\" id=\"appsNav\"><div class=\"navHeader\"><a href=\"/bookmarks/apps\"><div class=\"clearfix\"><div class=\"lfloat\">APPS</div><span class=\"mrm rfloat\"><div class=\"bookmarksNavSeeAll\">MORE</div><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /></span></div></a></div><ul class=\"uiSideNav mts mbm nonDroppableNav\" data-gt=\"&#123;&quot;nav_items_count&quot;:&quot;6&quot;,&quot;nav_section&quot;:&quot;appsNav&quot;&#125;\"><li class=\"sideNavItem stat_elem expander\" id=\"navItem_app_140332009231\"><div class=\"buttonWrap\"><div class=\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\"><div class=\"wrap\"><a class=\"uiSelectorButton uiCloseButton\" href=\"#\" role=\"button\" title=\"Edit\" aria-label=\"Edit App Center\" aria-haspopup=\"1\" rel=\"toggle\"></a><div class=\"uiSelectorMenuWrapper uiToggleFlyout\"><div role=\"menu\" class=\"uiMenu uiSelectorMenu\"><ul class=\"uiMenuInner\"><li class=\"uiMenuItem favorite\" data-label=\"Add to Favorites\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"0\" href=\"#\"><span class=\"itemLabel fsm\">Add to Favorites</span></a></li><li class=\"uiMenuItem rearrange\" data-label=\"Rearrange\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"-1\" href=\"#\"><span class=\"itemLabel fsm\">Rearrange</span></a></li></ul></div></div></div></div></div><a class=\"item clearfix sortableItem\" href=\"/appcenter/?from_bookmark=1\" title=\"\" data-gt=\"&#123;&quot;bmid&quot;:&quot;140332009231&quot;,&quot;fbtype&quot;:&quot;128&quot;,&quot;count&quot;:&quot;0&quot;,&quot;type&quot;:&quot;click2appcenter&quot;,&quot;coeff2_info&quot;:&quot;Aau7ZN0qlo4ywgMtrA3wyh3mO3FF3fNW-aqlV2Iw5xk6ZDapolk_r0FBHY0_Sd0xeBYOev0D9pYYRnEhygiWIiI0&quot;,&quot;coeff2_registry_key&quot;:&quot;0016&quot;,&quot;coeff2_action&quot;:&quot;3&quot;,&quot;coeff2_pv_signature&quot;:&quot;1880892099&quot;,&quot;rank&quot;:&quot;1&quot;&#125;\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span><span class=\"maxCountIndicator\"></span></span><span class=\"grip\"></span></div><div><span class=\"imgWrap\"><i class=\"img sp_14y7us sx_5a1501\"></i></span><div class=\"linkWrap noCount\">App Center</div></div></a><ul><li id=\"navItem_appsandgames\"><a class=\"subitem clearfix\" href=\"/apps/feed\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span><span class=\"maxCountIndicator\"></span></span></div><div><div class=\"linkWrap noCount\">Friend Activity</div></div></a></li></ul><span class=\"mover hidden_elem\"></span></li><li class=\"sideNavItem stat_elem\" id=\"navItem_app_2305272732\"><div class=\"buttonWrap\"><div class=\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\"><div class=\"wrap\"><a class=\"uiSelectorButton uiCloseButton\" href=\"#\" role=\"button\" title=\"Edit\" aria-label=\"Edit Photos\" aria-haspopup=\"1\" rel=\"toggle\"></a><div class=\"uiSelectorMenuWrapper uiToggleFlyout\"><div role=\"menu\" class=\"uiMenu uiSelectorMenu\"><ul class=\"uiMenuInner\"><li class=\"uiMenuItem favorite\" data-label=\"Add to Favorites\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"0\" href=\"#\"><span class=\"itemLabel fsm\">Add to Favorites</span></a></li><li class=\"uiMenuItem rearrange\" data-label=\"Rearrange\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"-1\" href=\"#\"><span class=\"itemLabel fsm\">Rearrange</span></a></li></ul></div></div></div></div></div><a class=\"item clearfix sortableItem\" href=\"/?sk=app_2305272732_2392950137\" title=\"\" data-gt=\"&#123;&quot;bmid&quot;:&quot;2305272732&quot;,&quot;fbtype&quot;:&quot;128&quot;,&quot;count&quot;:&quot;0&quot;,&quot;coeff2_info&quot;:&quot;AasX8bixYIdPMFB40NOuKTwyI2HC5PWo6fUIVsioVmyYjR5MsewrmHMJ4wouuKPNygQ&quot;,&quot;coeff2_registry_key&quot;:&quot;0016&quot;,&quot;coeff2_action&quot;:&quot;3&quot;,&quot;coeff2_pv_signature&quot;:&quot;1880892099&quot;,&quot;rank&quot;:&quot;2&quot;&#125;\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span><span class=\"maxCountIndicator\"></span></span><span class=\"grip\"></span></div><div><span class=\"imgWrap\"><i class=\"img sp_627qpw sx_db3d6d\"></i></span><div class=\"linkWrap noCount\">Photos</div></div></a><span class=\"mover hidden_elem\"></span></li><li class=\"sideNavItem stat_elem\" id=\"navItem_app_119960514742544\"><div class=\"buttonWrap\"><div class=\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\"><div class=\"wrap\"><a class=\"uiSelectorButton uiCloseButton\" href=\"#\" role=\"button\" title=\"Edit\" aria-label=\"Edit Music\" aria-haspopup=\"1\" rel=\"toggle\"></a><div class=\"uiSelectorMenuWrapper uiToggleFlyout\"><div role=\"menu\" class=\"uiMenu uiSelectorMenu\"><ul class=\"uiMenuInner\"><li class=\"uiMenuItem favorite\" data-label=\"Add to Favorites\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"0\" href=\"#\"><span class=\"itemLabel fsm\">Add to Favorites</span></a></li><li class=\"uiMenuItem rearrange\" data-label=\"Rearrange\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"-1\" href=\"#\"><span class=\"itemLabel fsm\">Rearrange</span></a></li></ul></div></div></div></div></div><a class=\"item clearfix sortableItem\" href=\"/music\" title=\"\" data-gt=\"&#123;&quot;bmid&quot;:&quot;119960514742544&quot;,&quot;fbtype&quot;:&quot;128&quot;,&quot;count&quot;:&quot;0&quot;,&quot;coeff2_info&quot;:&quot;Aaso2i3hOQecIQxIA0MweH7mwvIgmverqoEA8_2yIMjvL2M3lGN-SAqQ5kk2Z7edFVdWg6LJ81GIZy2LzVXTLGXM&quot;,&quot;coeff2_registry_key&quot;:&quot;0016&quot;,&quot;coeff2_action&quot;:&quot;3&quot;,&quot;coeff2_pv_signature&quot;:&quot;1880892099&quot;,&quot;rank&quot;:&quot;3&quot;&#125;\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span><span class=\"maxCountIndicator\"></span></span><span class=\"grip\"></span></div><div><span class=\"imgWrap\"><i class=\"img sp_627qpw sx_02c246\"></i></span><div class=\"linkWrap noCount\">Music</div></div></a><span class=\"mover hidden_elem\"></span></li><li class=\"sideNavItem stat_elem\" id=\"navItem_app_2347471856\"><div class=\"buttonWrap\"><div class=\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\"><div class=\"wrap\"><a class=\"uiSelectorButton uiCloseButton\" href=\"#\" role=\"button\" title=\"Edit\" aria-label=\"Edit Notes\" aria-haspopup=\"1\" rel=\"toggle\"></a><div class=\"uiSelectorMenuWrapper uiToggleFlyout\"><div role=\"menu\" class=\"uiMenu uiSelectorMenu\"><ul class=\"uiMenuInner\"><li class=\"uiMenuItem favorite\" data-label=\"Add to Favorites\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"0\" href=\"#\"><span class=\"itemLabel fsm\">Add to Favorites</span></a></li><li class=\"uiMenuItem rearrange\" data-label=\"Rearrange\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"-1\" href=\"#\"><span class=\"itemLabel fsm\">Rearrange</span></a></li></ul></div></div></div></div></div><a class=\"item clearfix sortableItem\" href=\"/notes/\" title=\"\" data-gt=\"&#123;&quot;bmid&quot;:&quot;2347471856&quot;,&quot;fbtype&quot;:&quot;128&quot;,&quot;count&quot;:&quot;0&quot;,&quot;coeff2_info&quot;:&quot;AasMLRYm9i_US3EouPMh-M3pcHKbP020vXeIVtAbqFYe6BFDC1GY7cUIj8ZiGxHSgJ4&quot;,&quot;coeff2_registry_key&quot;:&quot;0016&quot;,&quot;coeff2_action&quot;:&quot;3&quot;,&quot;coeff2_pv_signature&quot;:&quot;1880892099&quot;,&quot;rank&quot;:&quot;4&quot;&#125;\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span><span class=\"maxCountIndicator\"></span></span><span class=\"grip\"></span></div><div><span class=\"imgWrap\"><i class=\"img sp_627qpw sx_b218c2\"></i></span><div class=\"linkWrap noCount\">Notes</div></div></a><ul><li id=\"navItem_notes_pages\"><a class=\"subitem clearfix\" href=\"/notes/pages/\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span></span></div><div><div class=\"linkWrap noCount\">Pages&#039; Notes</div></div></a></li><li id=\"navItem_notes_drafts\"><a class=\"subitem clearfix\" href=\"/notes/drafts/\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span></span></div><div><div class=\"linkWrap noCount\">My Drafts</div></div></a></li><li id=\"navItem_notes_tagged\"><a class=\"subitem clearfix\" href=\"/notes/tagged/\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span></span></div><div><div class=\"linkWrap noCount\">Notes About Me</div></div></a></li><li id=\"navItem_notes_me\"><a class=\"subitem clearfix\" href=\"/notes/me/\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span></span></div><div><div class=\"linkWrap noCount\">My Notes</div></div></a></li></ul><span class=\"mover hidden_elem\"></span></li><li class=\"sideNavItem stat_elem\" id=\"navItem_app_2309869772\"><div class=\"buttonWrap\"><div class=\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\"><div class=\"wrap\"><a class=\"uiSelectorButton uiCloseButton\" href=\"#\" role=\"button\" title=\"Edit\" aria-label=\"Edit Links\" aria-haspopup=\"1\" rel=\"toggle\"></a><div class=\"uiSelectorMenuWrapper uiToggleFlyout\"><div role=\"menu\" class=\"uiMenu uiSelectorMenu\"><ul class=\"uiMenuInner\"><li class=\"uiMenuItem favorite\" data-label=\"Add to Favorites\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"0\" href=\"#\"><span class=\"itemLabel fsm\">Add to Favorites</span></a></li><li class=\"uiMenuItem rearrange\" data-label=\"Rearrange\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"-1\" href=\"#\"><span class=\"itemLabel fsm\">Rearrange</span></a></li></ul></div></div></div></div></div><a class=\"item clearfix sortableItem\" href=\"/?sk=app_2309869772\" title=\"\" data-gt=\"&#123;&quot;bmid&quot;:&quot;2309869772&quot;,&quot;fbtype&quot;:&quot;128&quot;,&quot;count&quot;:&quot;0&quot;,&quot;type&quot;:&quot;click2canvas&quot;,&quot;coeff2_info&quot;:&quot;AavGXzopDBZ-fA13_ys-VTxAxQmgi0KFo_4Zmyf8AWkyZJVWKElSzBC3rL6cMjmnfoQ&quot;,&quot;coeff2_registry_key&quot;:&quot;0016&quot;,&quot;coeff2_action&quot;:&quot;3&quot;,&quot;coeff2_pv_signature&quot;:&quot;1880892099&quot;,&quot;rank&quot;:&quot;5&quot;&#125;\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span><span class=\"maxCountIndicator\"></span></span><span class=\"grip\"></span></div><div><span class=\"imgWrap\"><i class=\"img sp_627qpw sx_5ecea7\"></i></span><div class=\"linkWrap noCount\">Links</div></div></a><span class=\"mover hidden_elem\"></span></li><li class=\"sideNavItem stat_elem\" id=\"navItem_app_183217215062060\"><div class=\"buttonWrap\"><div class=\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\"><div class=\"wrap\"><a class=\"uiSelectorButton uiCloseButton\" href=\"#\" role=\"button\" title=\"Edit\" aria-label=\"Edit Pokes\" aria-haspopup=\"1\" rel=\"toggle\"></a><div class=\"uiSelectorMenuWrapper uiToggleFlyout\"><div role=\"menu\" class=\"uiMenu uiSelectorMenu\"><ul class=\"uiMenuInner\"><li class=\"uiMenuItem favorite\" data-label=\"Add to Favorites\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"0\" href=\"#\"><span class=\"itemLabel fsm\">Add to Favorites</span></a></li><li class=\"uiMenuItem rearrange\" data-label=\"Rearrange\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"-1\" href=\"#\"><span class=\"itemLabel fsm\">Rearrange</span></a></li></ul></div></div></div></div></div><a class=\"item clearfix sortableItem\" href=\"/pokes\" title=\"\" data-gt=\"&#123;&quot;bmid&quot;:&quot;183217215062060&quot;,&quot;fbtype&quot;:&quot;128&quot;,&quot;count&quot;:&quot;0&quot;,&quot;coeff2_info&quot;:&quot;AaundmEZy5mJdw0_tYOs91YXY5Jo7eAzyNx73gMAYDQNiUyLdLIzKlPc8Es6DSChQLXkiNKPKrpanrGiMyZw3pob&quot;,&quot;coeff2_registry_key&quot;:&quot;0016&quot;,&quot;coeff2_action&quot;:&quot;3&quot;,&quot;coeff2_pv_signature&quot;:&quot;1880892099&quot;,&quot;rank&quot;:&quot;6&quot;&#125;\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span><span class=\"maxCountIndicator\"></span></span><span class=\"grip\"></span></div><div><span class=\"imgWrap\"><i class=\"img sp_14y7us sx_916a78\"></i></span><div class=\"linkWrap noCount\">Pokes</div></div></a><span class=\"mover hidden_elem\"></span></li></ul></div><div class=\"homeSideNav\" role=\"navigation\" id=\"listsNav\"><div class=\"navHeader\"><a href=\"/bookmarks/lists\"><div class=\"clearfix\"><div class=\"lfloat\">FRIENDS</div><span class=\"mrm rfloat\"><div class=\"bookmarksNavSeeAll\">MORE</div><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /></span></div></a></div><ul class=\"uiSideNav mts mbm nonDroppableNav\" data-gt=\"&#123;&quot;nav_items_count&quot;:&quot;3&quot;,&quot;nav_section&quot;:&quot;listsNav&quot;&#125;\"><li class=\"sideNavItem stat_elem\" id=\"navItem_fl_196338550436560\"><div class=\"buttonWrap\"><div class=\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\"><div class=\"wrap\"><a class=\"uiSelectorButton uiCloseButton\" href=\"#\" role=\"button\" title=\"Edit\" aria-label=\"Edit Close Friends\" aria-haspopup=\"1\" rel=\"toggle\"></a><div class=\"uiSelectorMenuWrapper uiToggleFlyout\"><div role=\"menu\" class=\"uiMenu uiSelectorMenu\"><ul class=\"uiMenuInner\"><li class=\"uiMenuItem favorite\" data-label=\"Add to Favorites\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"0\" href=\"#\"><span class=\"itemLabel fsm\">Add to Favorites</span></a></li><li class=\"uiMenuItem rearrange\" data-label=\"Rearrange\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"-1\" href=\"#\"><span class=\"itemLabel fsm\">Rearrange</span></a></li></ul></div></div></div></div></div><a class=\"item clearfix sortableItem\" href=\"/lists/196338550436560\" title=\"Close Friends\" data-gt=\"&#123;&quot;bmid&quot;:&quot;196338550436560&quot;,&quot;fbtype&quot;:&quot;17&quot;,&quot;count&quot;:&quot;0&quot;,&quot;coeff2_info&quot;:&quot;AauEQXrkb9M985szyAAFR4No_oQF63ogvcLJ3syoi1QQmfv9jJhgMTh9VSuJK00rN8qlT6-8YRY6PTAft_Y4J1_R&quot;,&quot;coeff2_registry_key&quot;:&quot;0016&quot;,&quot;coeff2_action&quot;:&quot;3&quot;,&quot;coeff2_pv_signature&quot;:&quot;1880892099&quot;,&quot;rank&quot;:&quot;1&quot;&#125;\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span><span class=\"maxCountIndicator\"></span></span><span class=\"grip\"></span></div><div><span class=\"imgWrap\"><i class=\"img sp_14y7us sx_47c9ad\"></i></span><div class=\"linkWrap noCount\">Close Friends</div></div></a><span class=\"mover hidden_elem\"></span></li><li class=\"sideNavItem stat_elem\" id=\"navItem_fl_196338560436559\"><div class=\"buttonWrap\"><div class=\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\"><div class=\"wrap\"><a class=\"uiSelectorButton uiCloseButton\" href=\"#\" role=\"button\" title=\"Edit\" aria-label=\"Edit Family\" aria-haspopup=\"1\" rel=\"toggle\"></a><div class=\"uiSelectorMenuWrapper uiToggleFlyout\"><div role=\"menu\" class=\"uiMenu uiSelectorMenu\"><ul class=\"uiMenuInner\"><li class=\"uiMenuItem favorite\" data-label=\"Add to Favorites\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"0\" href=\"#\"><span class=\"itemLabel fsm\">Add to Favorites</span></a></li><li class=\"uiMenuItem rearrange\" data-label=\"Rearrange\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"-1\" href=\"#\"><span class=\"itemLabel fsm\">Rearrange</span></a></li><li class=\"uiMenuSeparator\"></li><li class=\"uiMenuItem\" data-label=\"Archive List\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"-1\" href=\"/ajax/friends/lists/archive/?flid=196338560436559\" rel=\"dialog\"><span class=\"itemLabel fsm\">Archive List</span></a></li></ul></div></div></div></div></div><a class=\"item clearfix sortableItem\" href=\"/lists/196338560436559\" title=\"\" data-gt=\"&#123;&quot;bmid&quot;:&quot;196338560436559&quot;,&quot;fbtype&quot;:&quot;17&quot;,&quot;count&quot;:&quot;0&quot;,&quot;coeff2_info&quot;:&quot;AavA4ZCk63bms17tTQimiVDjYKPD4M3yBUPoc-zbvLRRTciy8Mb0xXm95eECHc9UYFs6CzKE_U7KRyP6XT2K7O3Y&quot;,&quot;coeff2_registry_key&quot;:&quot;0016&quot;,&quot;coeff2_action&quot;:&quot;3&quot;,&quot;coeff2_pv_signature&quot;:&quot;1880892099&quot;,&quot;rank&quot;:&quot;2&quot;&#125;\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span><span class=\"maxCountIndicator\"></span></span><span class=\"grip\"></span></div><div><span class=\"imgWrap\"><i class=\"img sp_14y7us sx_1e2cc9\"></i></span><div class=\"linkWrap noCount\">Family</div></div></a><span class=\"mover hidden_elem\"></span></li><li class=\"sideNavItem stat_elem\" id=\"navItem_fl_350511818352565\"><div class=\"buttonWrap\"><div class=\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\"><div class=\"wrap\"><a class=\"uiSelectorButton uiCloseButton\" href=\"#\" role=\"button\" title=\"Edit\" aria-label=\"Edit Hell Area\" aria-haspopup=\"1\" rel=\"toggle\"></a><div class=\"uiSelectorMenuWrapper uiToggleFlyout\"><div role=\"menu\" class=\"uiMenu uiSelectorMenu\"><ul class=\"uiMenuInner\"><li class=\"uiMenuItem favorite\" data-label=\"Add to Favorites\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"0\" href=\"#\"><span class=\"itemLabel fsm\">Add to Favorites</span></a></li><li class=\"uiMenuItem rearrange\" data-label=\"Rearrange\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"-1\" href=\"#\"><span class=\"itemLabel fsm\">Rearrange</span></a></li><li class=\"uiMenuSeparator\"></li><li class=\"uiMenuItem\" data-label=\"Archive List\"><a class=\"itemAnchor\" role=\"menuitem\" tabindex=\"-1\" href=\"/ajax/friends/lists/archive/?flid=350511818352565\" rel=\"dialog\"><span class=\"itemLabel fsm\">Archive List</span></a></li></ul></div></div></div></div></div><a class=\"item clearfix sortableItem\" href=\"/lists/350511818352565\" title=\"\" data-gt=\"&#123;&quot;bmid&quot;:&quot;350511818352565&quot;,&quot;fbtype&quot;:&quot;17&quot;,&quot;count&quot;:&quot;0&quot;,&quot;coeff2_info&quot;:&quot;AasO1n4bsh-L2Sq5Mhr0kL0ZLcRhCYVKN51HIDN9jrNbYCT6jOktY4LVCK9DWyCq_JSSHe0qiZUZ-nP4AIUjHsum&quot;,&quot;coeff2_registry_key&quot;:&quot;0016&quot;,&quot;coeff2_action&quot;:&quot;3&quot;,&quot;coeff2_pv_signature&quot;:&quot;1880892099&quot;,&quot;rank&quot;:&quot;3&quot;&#125;\"><div class=\"rfloat\"><img class=\"uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /><span class=\"count hidden_elem uiSideNavCount\"><span class=\"countValue fss\">0</span><span class=\"maxCountIndicator\"></span></span><span class=\"grip\"></span></div><div><span class=\"imgWrap\"><i class=\"img sp_14y7us sx_60bd74\"></i></span><div class=\"linkWrap noCount\">Hell Area</div></div></a><span class=\"mover hidden_elem\"></span></li></ul></div></div> ";
// undefined
o14 = null;
// 1637
o11.parentNode = o7;
// 1639
f33216266_455.returns.push(o11);
// undefined
o11 = null;
// 1640
// 1641
o8.getAttribute = f33216266_456;
// 1642
f33216266_456.returns.push(null);
// 1643
o8.setAttribute = f33216266_480;
// 1644
f33216266_480.returns.push(undefined);
// 1646
f33216266_432.returns.push(1344872059481);
// 1650
o11 = {};
// 1651
f33216266_441.returns.push(o11);
// 1653
f33216266_443.returns.push(o11);
// undefined
o11 = null;
// 1655
f33216266_432.returns.push(1344872059482);
// 1657
f33216266_432.returns.push(1344872059482);
// 1662
f33216266_432.returns.push(1344872059483);
// 1664
f33216266_432.returns.push(1344872059483);
// 1669
f33216266_432.returns.push(1344872059487);
// 1671
f33216266_432.returns.push(1344872059487);
// 1676
f33216266_432.returns.push(1344872059488);
// 1680
o11 = {};
// 1681
f33216266_441.returns.push(o11);
// 1683
f33216266_443.returns.push(o11);
// undefined
o11 = null;
// 1685
f33216266_432.returns.push(1344872059489);
// 1690
f33216266_432.returns.push(1344872059489);
// 1692
f33216266_432.returns.push(1344872059490);
// 1697
f33216266_432.returns.push(1344872059502);
// 1701
o11 = {};
// 1702
f33216266_441.returns.push(o11);
// 1704
f33216266_443.returns.push(o11);
// undefined
o11 = null;
// 1706
f33216266_432.returns.push(1344872059502);
// 1711
f33216266_432.returns.push(1344872059503);
// 1713
f33216266_432.returns.push(1344872059504);
// 1718
f33216266_432.returns.push(1344872059521);
// 1722
o11 = {};
// 1723
f33216266_441.returns.push(o11);
// 1725
f33216266_443.returns.push(o11);
// undefined
o11 = null;
// 1727
f33216266_432.returns.push(1344872059521);
// 1732
f33216266_432.returns.push(1344872059522);
// 1734
f33216266_432.returns.push(1344872059523);
// 1739
f33216266_432.returns.push(1344872059527);
// 1741
f33216266_432.returns.push(1344872059527);
// 1746
f33216266_432.returns.push(1344872059528);
// 1750
o11 = {};
// 1751
f33216266_441.returns.push(o11);
// 1753
f33216266_443.returns.push(o11);
// undefined
o11 = null;
// 1755
f33216266_432.returns.push(1344872059528);
// 1760
f33216266_432.returns.push(1344872059529);
// 1762
f33216266_432.returns.push(1344872059529);
// 1763
o11 = {};
// 1770
o14 = {};
// 1771
f33216266_441.returns.push(o14);
// 1773
o17 = {};
// 1774
f33216266_476.returns.push(o17);
// 1775
// 1776
// 1777
// 1778
// 1779
// 1780
o14.appendChild = f33216266_443;
// 1781
f33216266_443.returns.push(o17);
// undefined
o17 = null;
// 1783
o17 = {};
// 1784
f33216266_476.returns.push(o17);
// 1785
// 1786
// 1787
// 1788
// 1789
// 1791
f33216266_443.returns.push(o17);
// undefined
o17 = null;
// 1793
o17 = {};
// 1794
f33216266_476.returns.push(o17);
// 1795
// 1796
// 1797
// 1798
// 1799
// 1801
f33216266_443.returns.push(o17);
// undefined
o17 = null;
// 1803
o17 = {};
// 1804
f33216266_476.returns.push(o17);
// 1805
// 1806
// 1807
// 1808
// 1809
// 1811
f33216266_443.returns.push(o17);
// undefined
o17 = null;
// 1813
o17 = {};
// 1814
f33216266_476.returns.push(o17);
// 1815
// 1816
// 1817
// 1818
// 1819
// 1821
f33216266_443.returns.push(o17);
// undefined
o17 = null;
// 1823
o17 = {};
// 1824
f33216266_476.returns.push(o17);
// 1825
// 1826
// 1827
// 1828
// 1829
// 1831
f33216266_443.returns.push(o17);
// undefined
o17 = null;
// 1833
o17 = {};
// 1834
f33216266_476.returns.push(o17);
// 1835
// 1836
// 1837
// 1838
// 1839
// 1841
f33216266_443.returns.push(o17);
// undefined
o17 = null;
// 1843
o17 = {};
// 1844
f33216266_476.returns.push(o17);
// 1845
// 1846
// 1847
// 1848
// 1849
// 1851
f33216266_443.returns.push(o17);
// undefined
o17 = null;
// 1853
o17 = {};
// 1854
f33216266_476.returns.push(o17);
// 1855
// 1856
// 1857
// 1858
// 1859
// 1861
f33216266_443.returns.push(o17);
// undefined
o17 = null;
// 1863
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 1866
f33216266_432.returns.push(1344872059539);
// 1870
o14 = {};
// 1871
f33216266_441.returns.push(o14);
// 1873
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 1876
f33216266_432.returns.push(1344872059539);
// 1880
o14 = {};
// 1881
f33216266_441.returns.push(o14);
// 1883
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 1886
f33216266_432.returns.push(1344872059540);
// 1890
o14 = {};
// 1891
f33216266_441.returns.push(o14);
// 1893
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 1896
f33216266_432.returns.push(1344872059540);
// 1900
o14 = {};
// 1901
f33216266_441.returns.push(o14);
// 1903
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 1906
f33216266_432.returns.push(1344872059544);
// 1910
o14 = {};
// 1911
f33216266_441.returns.push(o14);
// 1913
o17 = {};
// 1914
f33216266_476.returns.push(o17);
// 1915
// 1916
// 1917
// 1918
// 1919
// 1920
o14.appendChild = f33216266_443;
// 1921
f33216266_443.returns.push(o17);
// undefined
o17 = null;
// 1923
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 1926
f33216266_432.returns.push(1344872059546);
// 1929
f33216266_432.returns.push(1344872059547);
// 1933
o14 = {};
// 1934
f33216266_441.returns.push(o14);
// 1936
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 1939
f33216266_432.returns.push(1344872059547);
// 1943
o14 = {};
// 1944
f33216266_441.returns.push(o14);
// 1946
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 1949
f33216266_432.returns.push(1344872059548);
// 1953
o14 = {};
// 1954
f33216266_441.returns.push(o14);
// 1956
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 1959
f33216266_432.returns.push(1344872059548);
// 1963
o14 = {};
// 1964
f33216266_441.returns.push(o14);
// 1966
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 1969
f33216266_432.returns.push(1344872059549);
// 1973
o14 = {};
// 1974
f33216266_441.returns.push(o14);
// 1976
o17 = {};
// 1977
f33216266_476.returns.push(o17);
// 1978
// 1979
// 1980
// 1981
// 1982
// 1983
o14.appendChild = f33216266_443;
// 1984
f33216266_443.returns.push(o17);
// undefined
o17 = null;
// 1986
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 1989
f33216266_432.returns.push(1344872059551);
// 1993
o14 = {};
// 1994
f33216266_441.returns.push(o14);
// 1996
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 1998
f33216266_432.returns.push(1344872059609);
// 1999
o14 = {};
// 2000
f33216266_4.returns.push(o14);
// 2001
o14.height = "42px";
// undefined
o14 = null;
// 2002
o14 = {};
// 2003
f33216266_4.returns.push(o14);
// 2004
o14.height = "42px";
// undefined
o14 = null;
// 2005
o15.parentNode = o5;
// 2006
o5.removeChild = f33216266_455;
// 2007
f33216266_455.returns.push(o15);
// undefined
o15 = null;
// 2008
o16.parentNode = o5;
// 2010
f33216266_455.returns.push(o16);
// undefined
o16 = null;
// 2014
f33216266_432.returns.push(1344872059650);
// 2016
o14 = {};
// 2017
f33216266_450.returns.push(o14);
// 2019
o15 = {};
// 2020
f33216266_450.returns.push(o15);
// 2021
o16 = {};
// 2022
o15.firstChild = o16;
// 2024
o16.nodeType = 8;
// 2026
o16.nodeValue = " <div class=\"fbChatSidebar fixed_always hidden_elem\" id=\"uq3j16_23\"><div class=\"fbChatSidebarBody\"><div class=\"uiScrollableArea scrollableOrderedList fade\" style=\"width:205px;\" id=\"uq3j16_24\"><div class=\"uiScrollableAreaWrap scrollable\" tabindex=\"0\"><div class=\"uiScrollableAreaBody\" style=\"width:205px;\"><div class=\"uiScrollableAreaContent\"><ul class=\"fbChatOrderedList clearfix\" id=\"uq3j16_31\"><li><div class=\"phs fcg\"><span data-jsid=\"message\">Loading...</span></div></li></ul></div></div></div><div class=\"uiScrollableAreaTrack invisible_elem\"><div class=\"uiScrollableAreaGripper\"></div></div></div><div class=\"fbChatTypeaheadView hidden_elem\" id=\"uq3j16_22\"></div></div><div class=\"fbChatSidebarMessage clearfix\"><img class=\"img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/y4/r/-PAXP-deijE.gif\" alt=\"\" width=\"1\" height=\"1\" /><div class=\"message fcg\"></div></div><table class=\"uiGrid fbChatSidebarFooter\" cellspacing=\"0\" cellpadding=\"0\"><tbody><tr><td><div class=\"uiTypeahead uiClearableTypeahead fbChatTypeahead\" id=\"uq3j16_25\"><div class=\"wrap\"><label class=\"clear uiCloseButton\" id=\"uq3j16_26\" for=\"uq3j16_27\"><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function ef8a9fe85a84a7763ca7d4d18edd3f8d61df55ce3(event) {\\u000a\\u000a};\"), (\"s0f670185ab6520fdaa02221d95b65df2561c73bc\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction ef8a9fe85a84a7763ca7d4d18edd3f8d61df55ce3(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s0f670185ab6520fdaa02221d95b65df2561c73bc_0\"), (s0f670185ab6520fdaa02221d95b65df2561c73bc_0_instance), (this), (arguments)))\n    };\n    (null);\n;\n};\nvar s0f670185ab6520fdaa02221d95b65df2561c73bc_0_instance;\n((s0f670185ab6520fdaa02221d95b65df2561c73bc_0_instance) = ((JSBNG_Record.eventInstance)((\"s0f670185ab6520fdaa02221d95b65df2561c73bc_0\"))));\n((JSBNG_Record.markFunction)((ef8a9fe85a84a7763ca7d4d18edd3f8d61df55ce3)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><input title=\"Remove\" type=\"button\" onclick=\"return ef8a9fe85a84a7763ca7d4d18edd3f8d61df55ce3.call(this, event);\" id=\"uq3j16_27\"></label><input type=\"hidden\" autocomplete=\"off\" class=\"hiddenInput\" /><div class=\"innerWrap\"><input type=\"text\" class=\"inputtext inputsearch textInput DOMControl_placeholder\" autocomplete=\"off\" placeholder=\"Search\" aria-autocomplete=\"list\" aria-expanded=\"false\" aria-invalid=\"false\" aria-owns=\"typeahead_list_uq3j16_25\" role=\"textbox\" spellcheck=\"false\" value=\"Search\" aria-label=\"Search\" id=\"uq3j16_28\" /></div><img class=\"throbber uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /></div></div></td><td><div><div class=\"uiSelector inlineBlock fbChatSidebarDropdown button uiSelectorBottomUp uiSelectorRight\" id=\"uq3j16_29\" data-multiple=\"1\"><div class=\"wrap\"><a data-hover=\"tooltip\" class=\"uiSelectorButton uiCloseButton\" href=\"#\" role=\"button\" aria-haspopup=\"1\" rel=\"toggle\" id=\"uq3j16_32\"></a><div class=\"uiSelectorMenuWrapper uiToggleFlyout\"><div role=\"menu\" class=\"uiMenu uiSelectorMenu\"><ul class=\"uiMenuInner\"><li class=\"uiMenuItem uiMenuItemCheckbox uiSelectorOption checked\" data-label=\"Chat Sounds\"><a class=\"itemAnchor\" role=\"menuitemcheckbox\" tabindex=\"0\" href=\"#\" aria-checked=\"true\"><span class=\"itemLabel fsm\">Chat Sounds</span></a></li><li class=\"uiMenuItem uiMenuItemCheckbox uiSelectorOption\" data-label=\"Advanced Settings...\"><a class=\"itemAnchor\" role=\"menuitemcheckbox\" tabindex=\"-1\" href=\"/ajax/chat/privacy/settings_dialog.php\" aria-checked=\"false\" rel=\"dialog\"><span class=\"itemLabel fsm\">Advanced Settings...</span></a></li><li class=\"uiMenuSeparator\"></li><li class=\"uiMenuItem uiMenuItemCheckbox uiSelectorOption fbChatGoOnlineItem\" data-label=\"Go Online to Chat\"><a class=\"itemAnchor\" role=\"menuitemcheckbox\" tabindex=\"-1\" href=\"#\" aria-checked=\"false\"><span class=\"itemLabel fsm\">Go Online to Chat</span></a></li><li class=\"uiMenuItem uiMenuItemCheckbox uiSelectorOption fbChatGoOfflineItem\" data-label=\"Go Offline\"><a class=\"itemAnchor\" role=\"menuitemcheckbox\" tabindex=\"-1\" href=\"#\" aria-checked=\"false\"><span class=\"itemLabel fsm\">Go Offline</span></a></li></ul></div></div></div><select multiple=\"1\"><option value=\"\" disabled=\"1\"></option><option value=\"sound\" selected=\"1\">Chat Sounds</option><option value=\"advanced_settings\">Advanced Settings...</option><option value=\"online\">Go Online to Chat</option><option value=\"offline\">Go Offline</option></select></div></div></td><td><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function e52fa0319c7e70606b128beb4de26aaebdc95f391(event) {\\u000a    Chat.toggleSidebar();\\u000a};\"), (\"s4a0cd3e0d5790c48c86b1b3e2fb557e988f141d1\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction e52fa0319c7e70606b128beb4de26aaebdc95f391(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s4a0cd3e0d5790c48c86b1b3e2fb557e988f141d1_0\"), (s4a0cd3e0d5790c48c86b1b3e2fb557e988f141d1_0_instance), (this), (arguments)))\n    };\n    (null);\n    (((JSBNG_Record.get)(Chat, (\"toggleSidebar\")))[(\"toggleSidebar\")])();\n};\nvar s4a0cd3e0d5790c48c86b1b3e2fb557e988f141d1_0_instance;\n((s4a0cd3e0d5790c48c86b1b3e2fb557e988f141d1_0_instance) = ((JSBNG_Record.eventInstance)((\"s4a0cd3e0d5790c48c86b1b3e2fb557e988f141d1_0\"))));\n((JSBNG_Record.markFunction)((e52fa0319c7e70606b128beb4de26aaebdc95f391)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><a data-hover=\"tooltip\" data-tooltip-alignh=\"right\" class=\"toggle button\" href=\"#\" onclick=\"return e52fa0319c7e70606b128beb4de26aaebdc95f391.call(this, event);\" id=\"uq3j16_33\"></a></td></tr></tbody></table></div> ";
// undefined
o16 = null;
// 2027
o15.parentNode = o7;
// 2029
f33216266_455.returns.push(o15);
// undefined
o15 = null;
// 2030
// 2031
o14.getAttribute = f33216266_456;
// undefined
o14 = null;
// 2032
f33216266_456.returns.push("pagelet_sidebar");
// 2035
f33216266_432.returns.push(1344872059661);
// 2038
f33216266_432.returns.push(1344872059662);
// 2041
f33216266_432.returns.push(1344872059662);
// 2045
f33216266_432.returns.push(1344872059662);
// 2047
o14 = {};
// 2048
f33216266_450.returns.push(o14);
// 2050
o15 = {};
// 2051
f33216266_450.returns.push(o15);
// 2052
o16 = {};
// 2053
o15.firstChild = o16;
// 2055
o16.nodeType = 8;
// 2057
o16.nodeValue = " <div id=\"chatFriendsOnline\" class=\"isOffline\"><div class=\"uiHeader uiHeaderTopBorder uiHeaderNav uiHeaderNavEmpty\" role=\"separator\"><div class=\"clearfix uiHeaderTop\"><div><h4 tabindex=\"0\" class=\"uiHeaderTitle\"></h4></div></div></div><div class=\"pas\"><table class=\"uiGrid mbs mrs typeaheadContainer\" cellspacing=\"0\" cellpadding=\"0\"><tbody><tr><td><div class=\"uiTypeahead uiClearableTypeahead fbChatTypeahead typeahead\" id=\"uq3j16_40\"><div class=\"wrap\"><label class=\"clear uiCloseButton\" id=\"uq3j16_41\" for=\"uq3j16_42\"><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function ea863eff1b237351b8b33e60ab0cb13d0a7e286aa(event) {\\u000a\\u000a};\"), (\"s8e3bc1b9025f0443e4e13f7478218827dde21633\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction ea863eff1b237351b8b33e60ab0cb13d0a7e286aa(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s8e3bc1b9025f0443e4e13f7478218827dde21633_0\"), (s8e3bc1b9025f0443e4e13f7478218827dde21633_0_instance), (this), (arguments)))\n    };\n    (null);\n;\n};\nvar s8e3bc1b9025f0443e4e13f7478218827dde21633_0_instance;\n((s8e3bc1b9025f0443e4e13f7478218827dde21633_0_instance) = ((JSBNG_Record.eventInstance)((\"s8e3bc1b9025f0443e4e13f7478218827dde21633_0\"))));\n((JSBNG_Record.markFunction)((ea863eff1b237351b8b33e60ab0cb13d0a7e286aa)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><input title=\"Remove\" type=\"button\" onclick=\"return ea863eff1b237351b8b33e60ab0cb13d0a7e286aa.call(this, event);\" id=\"uq3j16_42\"></label><input type=\"hidden\" autocomplete=\"off\" class=\"hiddenInput\" /><div class=\"innerWrap\"><input type=\"text\" class=\"inputtext inputsearch textInput DOMControl_placeholder\" autocomplete=\"off\" placeholder=\"Friends on Chat\" aria-autocomplete=\"list\" aria-expanded=\"false\" aria-invalid=\"false\" aria-owns=\"typeahead_list_uq3j16_40\" role=\"textbox\" spellcheck=\"false\" value=\"Friends on Chat\" aria-label=\"Friends on Chat\" id=\"uq3j16_43\" /></div><img class=\"throbber uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /></div></div></td><td><label class=\"sidebarBtn uiButton uiButtonNoText\" for=\"uq3j16_38\"><i class=\"mrs customimg img sp_627qpw sx_f025d1\"></i><input value=\"\" title=\"Show Sidebar\" type=\"submit\" id=\"uq3j16_38\" /></label></td></tr></tbody></table><div class=\"uiFacepile fbFriendsOnlineFacepile uiFacepileMedium\" id=\"uq3j16_39\"><ul class=\"uiList uiListHorizontal clearfix\"></ul></div><div class=\"UIImageBlock clearfix chatGoOnlineLink hidden_elem\"><img class=\"UIImageBlock_Image UIImageBlock_ICON_Image img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/y4/r/-PAXP-deijE.gif\" alt=\"\" width=\"1\" height=\"1\" /><div class=\"fbChatOfflineMessage UIImageBlock_Content UIImageBlock_ICON_Content fsm fwn fcg\">You are currently offline. To chat with your friends, <a class=\"fbChatGoOnlineLink\" href=\"#\">go online</a>.</div></div><div class=\"UIImageBlock clearfix chatReconnectLink hidden_elem\"><img class=\"UIImageBlock_Image UIImageBlock_ICON_Image img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/y4/r/-PAXP-deijE.gif\" alt=\"\" width=\"1\" height=\"1\" /><div class=\"fbChatDisconnectedMessage UIImageBlock_Content UIImageBlock_ICON_Content fsm fwn fcg\">Unable to connect to chat. <div class=\"fbChatReconnecting\">Reconnecting...</div><a class=\"fbChatReconnectLink\" href=\"#\">Try again.</a></div></div><div class=\"fbChatTypeaheadView hidden_elem\" id=\"uq3j16_37\"></div></div></div> ";
// undefined
o16 = null;
// 2058
o15.parentNode = o7;
// 2060
f33216266_455.returns.push(o15);
// undefined
o15 = null;
// 2061
// 2062
o14.getAttribute = f33216266_456;
// undefined
o14 = null;
// 2063
f33216266_456.returns.push("pagelet_friends_online");
// 2066
f33216266_432.returns.push(1344872059669);
// 2069
f33216266_432.returns.push(1344872059669);
// 2073
o14 = {};
// 2074
f33216266_441.returns.push(o14);
// 2076
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 2080
o14 = {};
// 2081
f33216266_441.returns.push(o14);
// 2083
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 2085
f33216266_432.returns.push(1344872059670);
// 2088
f33216266_432.returns.push(1344872059670);
// 2092
f33216266_432.returns.push(1344872059671);
// 2094
o14 = {};
// 2095
f33216266_450.returns.push(o14);
// 2097
o15 = {};
// 2098
f33216266_450.returns.push(o15);
// 2099
o16 = {};
// 2100
o15.firstChild = o16;
// 2102
o16.nodeType = 8;
// 2104
o16.nodeValue = " <div class=\"mtl\"><div class=\"rhcFooterBorder\"></div><div class=\"rhcFooterWrap\"><div class=\"rhcFooterCopyright fsm fwn fcg\"><span> Facebook © 2012</span></div><div class=\"fsm fwn fcg\"><a rel=\"dialog\" href=\"/ajax/intl/language_dialog.php?uri=http\u00253A\u00252F\u00252Fwww.facebook.com\u00252F\u00253Fsk\u00253Dnf\" title=\"Use Facebook in another language.\">English (US)</a> · <a href=\"http://www.facebook.com/privacy/explanation\" title=\"Learn about your privacy and Facebook.\">Privacy</a> · <a href=\"http://www.facebook.com/policies?ref=pf\" title=\"Review our terms and policies.\">Terms</a> · <a href=\"http://www.facebook.com/help/cookies?ref_type=sitefooter\" title=\"Cookies\">Cookies</a> · <div class=\"-cx-PRIVATE-uiInlineBlock__root  uiPopover\" id=\"rhc_footer_selector\"><a class=\"rhcFooterSelectorButton -cx-PRIVATE-uiPopover__trigger\" href=\"#\" aria-haspopup=\"true\" aria-expanded=\"false\" rel=\"toggle\" id=\"uq3j16_46\">More<i class=\"img sp_627qpw sx_3be745\"></i></a></div></div></div></div> ";
// undefined
o16 = null;
// 2105
o15.parentNode = o7;
// 2107
f33216266_455.returns.push(o15);
// undefined
o15 = null;
// 2108
// 2109
o14.getAttribute = f33216266_456;
// undefined
o14 = null;
// 2110
f33216266_456.returns.push("pagelet_rhc_footer");
// 2113
f33216266_432.returns.push(1344872059675);
// 2116
f33216266_432.returns.push(1344872059675);
// 2120
o14 = {};
// 2121
f33216266_441.returns.push(o14);
// 2123
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 2127
o14 = {};
// 2128
f33216266_441.returns.push(o14);
// 2130
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 2132
f33216266_432.returns.push(1344872059679);
// 2135
f33216266_432.returns.push(1344872059679);
// 2139
o14 = {};
// 2140
f33216266_441.returns.push(o14);
// 2143
o15 = {};
// 2144
f33216266_476.returns.push(o15);
// 2145
// 2146
// 2147
// 2149
o16 = {};
// 2150
f33216266_476.returns.push(o16);
// 2151
// 2152
o14.appendChild = f33216266_443;
// 2153
f33216266_443.returns.push(o16);
// 2155
f33216266_432.returns.push(1344872059685);
// 2156
f33216266_13.returns.push(49);
// 2158
f33216266_443.returns.push(o15);
// undefined
o15 = null;
// 2160
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 2162
f33216266_432.returns.push(1344872059685);
// 2165
f33216266_432.returns.push(1344872059686);
// 2169
f33216266_432.returns.push(1344872059686);
// 2171
o14 = {};
// 2172
f33216266_450.returns.push(o14);
// 2174
o15 = {};
// 2175
f33216266_450.returns.push(o15);
// 2176
o17 = {};
// 2177
o15.firstChild = o17;
// 2179
o17.nodeType = 8;
// 2181
o17.nodeValue = " <div><div class=\"uiScrollableArea fade\" style=\"width:330px;\" id=\"uq3j16_49\"><div class=\"uiScrollableAreaWrap scrollable\" tabindex=\"0\"><div class=\"uiScrollableAreaBody\" style=\"width:330px;\"><div class=\"uiScrollableAreaContent\"><div class=\"-cx-PRIVATE-uiStickyArea__area\" id=\"uq3j16_50\"><div class=\"uiHeader uiHeaderBottomBorder jewelHeader\"><div class=\"clearfix uiHeaderTop\"><a class=\"uiHeaderActions rfloat\" href=\"http://www.facebook.com/?sk=ff\" accesskey=\"3\">Find Friends</a><div><h3 tabindex=\"0\" class=\"uiHeaderTitle\">Friend Requests</h3></div></div></div></div><div class=\"fbRequestList\"><ul class=\"uiList\"><li class=\"empty   uiListItem uiListLight uiListVerticalItemBorder\"><table class=\"uiGrid noRequestsGrid\" cellspacing=\"0\" cellpadding=\"0\"><tbody><tr><td class=\"vMid hCent\">No new requests</td></tr></tbody></table></li></ul></div></div></div></div><div class=\"uiScrollableAreaTrack invisible_elem\"><div class=\"uiScrollableAreaGripper\"></div></div></div><div class=\"jewelFooter\"><a class=\"seeMore\" href=\"http://www.facebook.com/friends/edit/?sk=requests\"><span>See All</span></a></div></div> ";
// undefined
o17 = null;
// 2182
o15.parentNode = o7;
// 2184
f33216266_455.returns.push(o15);
// undefined
o15 = null;
// 2185
// 2186
o14.getAttribute = f33216266_456;
// 2187
f33216266_456.returns.push(null);
// 2188
o14.setAttribute = f33216266_480;
// undefined
o14 = null;
// 2189
f33216266_480.returns.push(undefined);
// 2192
f33216266_432.returns.push(1344872059688);
// 2195
f33216266_432.returns.push(1344872059688);
// 2199
o14 = {};
// 2200
f33216266_441.returns.push(o14);
// 2202
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 2206
o14 = {};
// 2207
f33216266_441.returns.push(o14);
// 2209
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 2211
f33216266_432.returns.push(1344872059689);
// 2214
f33216266_432.returns.push(1344872059689);
// 2218
o14 = {};
// 2219
f33216266_441.returns.push(o14);
// 2222
o15 = {};
// 2223
f33216266_476.returns.push(o15);
// 2224
// 2225
// 2226
// 2228
o17 = {};
// 2229
f33216266_476.returns.push(o17);
// 2230
// 2231
o14.appendChild = f33216266_443;
// 2232
f33216266_443.returns.push(o17);
// 2234
f33216266_432.returns.push(1344872059693);
// 2236
f33216266_443.returns.push(o15);
// undefined
o15 = null;
// 2239
o15 = {};
// 2240
f33216266_476.returns.push(o15);
// 2241
// 2242
// 2243
// 2245
o18 = {};
// 2246
f33216266_476.returns.push(o18);
// 2247
// 2249
f33216266_443.returns.push(o18);
// 2251
f33216266_432.returns.push(1344872059693);
// 2253
f33216266_443.returns.push(o15);
// undefined
o15 = null;
// 2255
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 2257
f33216266_432.returns.push(1344872059694);
// 2260
f33216266_432.returns.push(1344872059695);
// 2264
f33216266_432.returns.push(1344872059695);
// 2266
o14 = {};
// 2267
f33216266_450.returns.push(o14);
// 2268
// 2269
o14.getAttribute = f33216266_456;
// undefined
o14 = null;
// 2270
f33216266_456.returns.push("pagelet_channel");
// 2273
f33216266_432.returns.push(1344872059696);
// 2276
f33216266_432.returns.push(1344872059696);
// 2280
o14 = {};
// 2281
f33216266_441.returns.push(o14);
// 2283
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 2287
o14 = {};
// 2288
f33216266_441.returns.push(o14);
// 2290
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 2292
f33216266_432.returns.push(1344872059697);
// 2295
f33216266_432.returns.push(1344872059697);
// 2299
f33216266_432.returns.push(1344872059697);
// 2301
o14 = {};
// 2302
f33216266_450.returns.push(o14);
// 2304
o15 = {};
// 2305
f33216266_450.returns.push(o15);
// 2306
o19 = {};
// 2307
o15.firstChild = o19;
// 2309
o19.nodeType = 8;
// 2311
o19.nodeValue = " <div class=\"fbDockWrapper fixed_always fbDockWrapperRight\" id=\"uq3j16_53\"><div class=\"fbDock clearfix\"><div class=\"clearfix nubContainer rNubContainer\"><div id=\"pagelet_chat\" data-referrer=\"pagelet_chat\"><div class=\"fbNubGroup clearfix fbDockChat\" id=\"fbDockChat\"><div class=\"fbNubGroup clearfix\" id=\"fbDockChatTabs\"></div><div class=\"fbNub fbDockChatBuddyListNub hide_on_presence_error\" id=\"fbDockChatBuddylistNub\"><a class=\"fbNubButton\" tabindex=\"0\" href=\"#\" rel=\"toggle\"><img class=\"icon img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/y4/r/-PAXP-deijE.gif\" alt=\"\" width=\"1\" height=\"1\" /><span class=\"label\">Chat (Offline)</span></a><div class=\"fbNubFlyout uiToggleFlyout\"><div class=\"fbNubFlyoutOuter\"><div class=\"fbNubFlyoutInner\"><div class=\"clearfix fbNubFlyoutTitlebar\" data-jsid=\"nubFlyoutTitlebar\"><div class=\"uiSelector inlineBlock fbChatSidebarDropdown button rfloat uiSelectorRight\" id=\"uq3j16_59\" data-multiple=\"1\"><div class=\"wrap\"><a data-hover=\"tooltip\" class=\"uiSelectorButton uiCloseButton\" href=\"#\" role=\"button\" aria-haspopup=\"1\" rel=\"toggle\" id=\"uq3j16_62\"></a><div class=\"uiSelectorMenuWrapper uiToggleFlyout\"><div role=\"menu\" class=\"uiMenu uiSelectorMenu\"><ul class=\"uiMenuInner\"><li class=\"uiMenuItem uiMenuItemCheckbox uiSelectorOption checked\" data-label=\"Chat Sounds\"><a class=\"itemAnchor\" role=\"menuitemcheckbox\" tabindex=\"0\" href=\"#\" aria-checked=\"true\"><span class=\"itemLabel fsm\">Chat Sounds</span></a></li><li class=\"uiMenuItem uiMenuItemCheckbox uiSelectorOption\" data-label=\"Advanced Settings...\"><a class=\"itemAnchor\" role=\"menuitemcheckbox\" tabindex=\"-1\" href=\"/ajax/chat/privacy/settings_dialog.php\" aria-checked=\"false\" rel=\"dialog\"><span class=\"itemLabel fsm\">Advanced Settings...</span></a></li><li class=\"uiMenuSeparator\"></li><li class=\"uiMenuItem uiMenuItemCheckbox uiSelectorOption fbChatGoOnlineItem\" data-label=\"Go Online to Chat\"><a class=\"itemAnchor\" role=\"menuitemcheckbox\" tabindex=\"-1\" href=\"#\" aria-checked=\"false\"><span class=\"itemLabel fsm\">Go Online to Chat</span></a></li><li class=\"uiMenuItem uiMenuItemCheckbox uiSelectorOption fbChatGoOfflineItem\" data-label=\"Go Offline\"><a class=\"itemAnchor\" role=\"menuitemcheckbox\" tabindex=\"-1\" href=\"#\" aria-checked=\"false\"><span class=\"itemLabel fsm\">Go Offline</span></a></li></ul></div></div></div><select multiple=\"1\"><option value=\"\" disabled=\"1\"></option><option value=\"sound\" selected=\"1\">Chat Sounds</option><option value=\"advanced_settings\">Advanced Settings...</option><option value=\"online\">Go Online to Chat</option><option value=\"offline\">Go Offline</option></select></div><div class=\"titlebarLabel clearfix\"><div class=\"titlebarTextWrapper\">Chat</div></div></div><div class=\"fbNubFlyoutBody scrollable\"><div class=\"fbNubFlyoutBodyContent\"><ul class=\"fbChatOrderedList clearfix\" id=\"uq3j16_61\"><li><div class=\"phs fcg\"><span data-jsid=\"message\">Loading...</span></div></li></ul><div class=\"fbChatTypeaheadView hidden_elem\" id=\"uq3j16_54\"></div></div></div><div class=\"fbNubFlyoutFooter\"><div class=\"fbDockChatBuddyListNubMessage clearfix\"><img class=\"img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/y4/r/-PAXP-deijE.gif\" alt=\"\" width=\"1\" height=\"1\" /><div class=\"message fcg\"></div></div><div class=\"uiTypeahead uiClearableTypeahead fbChatTypeahead\" id=\"uq3j16_55\"><div class=\"wrap\"><label class=\"clear uiCloseButton\" id=\"uq3j16_56\" for=\"uq3j16_57\"><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function ea4888251e94d17790954904619127c41f03f9733(event) {\\u000a\\u000a};\"), (\"s2e8d27cd3dc7d91f3419fac21038c9d40249cff0\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction ea4888251e94d17790954904619127c41f03f9733(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s2e8d27cd3dc7d91f3419fac21038c9d40249cff0_0\"), (s2e8d27cd3dc7d91f3419fac21038c9d40249cff0_0_instance), (this), (arguments)))\n    };\n    (null);\n;\n};\nvar s2e8d27cd3dc7d91f3419fac21038c9d40249cff0_0_instance;\n((s2e8d27cd3dc7d91f3419fac21038c9d40249cff0_0_instance) = ((JSBNG_Record.eventInstance)((\"s2e8d27cd3dc7d91f3419fac21038c9d40249cff0_0\"))));\n((JSBNG_Record.markFunction)((ea4888251e94d17790954904619127c41f03f9733)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><input title=\"Remove\" type=\"button\" onclick=\"return ea4888251e94d17790954904619127c41f03f9733.call(this, event);\" id=\"uq3j16_57\"></label><input type=\"hidden\" autocomplete=\"off\" class=\"hiddenInput\" /><div class=\"innerWrap\"><input type=\"text\" class=\"inputtext inputsearch textInput DOMControl_placeholder\" autocomplete=\"off\" placeholder=\"Search\" aria-autocomplete=\"list\" aria-expanded=\"false\" aria-invalid=\"false\" aria-owns=\"typeahead_list_uq3j16_55\" role=\"textbox\" spellcheck=\"false\" value=\"Search\" aria-label=\"Search\" id=\"uq3j16_58\" /></div><img class=\"throbber uiLoadingIndicatorAsync img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /></div></div></div></div></div></div></div></div></div></div></div></div><div id=\"BeeperBox\" class=\"UIBeeper fixed_always hidden_elem\"><div class=\"UIBeeper_Full\"><div class=\"Beeps\" data-gt=\"&#123;&quot;ref&quot;:&quot;beeper&quot;,&quot;jewel&quot;:&quot;notifications&quot;&#125;\"></div></div></div> ";
// undefined
o19 = null;
// 2312
o15.parentNode = o7;
// 2314
f33216266_455.returns.push(o15);
// undefined
o15 = null;
// 2315
// 2316
o14.getAttribute = f33216266_456;
// undefined
o14 = null;
// 2317
f33216266_456.returns.push("pagelet_dock");
// 2320
f33216266_432.returns.push(1344872059708);
// 2323
f33216266_432.returns.push(1344872059709);
// 2327
o14 = {};
// 2328
f33216266_441.returns.push(o14);
// 2330
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 2334
o14 = {};
// 2335
f33216266_441.returns.push(o14);
// 2337
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 2339
f33216266_432.returns.push(1344872059709);
// 2342
f33216266_432.returns.push(1344872059710);
// 2346
f33216266_432.returns.push(1344872059710);
// 2348
o14 = {};
// 2349
f33216266_450.returns.push(o14);
// 2351
o15 = {};
// 2352
f33216266_450.returns.push(o15);
// 2353
o19 = {};
// 2354
o15.firstChild = o19;
// 2356
o19.nodeType = 8;
// 2358
o19.nodeValue = " <div class=\"composerAudienceWrapper stat_elem widget composerAudienceWrapper\"><div class=\"uiSelector inlineBlock audienceSelector composerAudienceSelector audienceSelectorNoTruncate dynamicIconSelector uiSelectorRight uiSelectorNormal uiSelectorDynamicLabel uiSelectorDynamicTooltip\" data-name=\"audience[0][value]\"><div class=\"wrap\"><a data-hover=\"tooltip\" title=\"Public\" data-tooltip-alignh=\"right\" class=\"uiSelectorButton uiButton uiButtonSuppressed\" href=\"#\" role=\"button\" aria-haspopup=\"1\" aria-expanded=\"false\" data-label=\"\" data-length=\"30\" data-ariaprefix=\"Post Privacy Setting\" aria-label=\"Post Privacy Setting: Public\" rel=\"toggle\"><i class=\"mrs defaultIcon customimg img sp_14y7us sx_7bc8bb\"></i><span class=\"uiButtonText\">Public</span></a><div class=\"uiSelectorMenuWrapper uiToggleFlyout\"><div role=\"menu\" class=\"uiMenu uiSelectorMenu\"><ul class=\"uiMenuInner\"><li class=\"uiMenuItem uiMenuItemRadio uiSelectorOption fbPrivacyAudienceSelectorOption checked\" data-label=\"Public\"><a class=\"itemAnchor itemWithIcon\" role=\"menuitemradio\" tabindex=\"0\" href=\"#\" aria-checked=\"true\" rel=\"async-post\" ajaxify=\"/ajax/privacy/simple_save.php?id=0&amp;audience_json=\u00255B\u00257B\u002522value\u002522\u00253A\u00252280\u002522\u00257D\u00255D\"><i class=\"mrs itemIcon img sp_14y7us sx_7bc8bb\"></i><span class=\"itemLabel fsm\">Public</span></a></li><li class=\"uiMenuItem uiMenuItemRadio uiSelectorOption fbPrivacyAudienceSelectorOption\" data-label=\"Friends\" id=\"uq3j16_70\"><a class=\"itemAnchor itemWithIcon\" role=\"menuitemradio\" tabindex=\"-1\" href=\"#\" aria-checked=\"false\" rel=\"async-post\" ajaxify=\"/ajax/privacy/simple_save.php?id=0&amp;audience_json=\u00255B\u00257B\u002522value\u002522\u00253A\u00252240\u002522\u00257D\u00255D\"><i class=\"mrs itemIcon img sp_14y7us sx_cfd5fc\"></i><span class=\"itemLabel fsm\">Friends<span class=\"plusLabel hidden_elem fcg\"> (+)</span></span></a></li><li class=\"uiMenuItem uiMenuItemRadio uiSelectorOption fbPrivacyAudienceSelectorOption\" data-label=\"Only Me\" id=\"uq3j16_71\"><a class=\"itemAnchor itemWithIcon\" role=\"menuitemradio\" tabindex=\"-1\" href=\"#\" aria-checked=\"false\" rel=\"async-post\" ajaxify=\"/ajax/privacy/simple_save.php?id=0&amp;audience_json=\u00255B\u00257B\u002522value\u002522\u00253A\u00252210\u002522\u00257D\u00255D\"><i class=\"mrs itemIcon img sp_14y7us sx_6af2b0\"></i><span class=\"itemLabel fsm\">Only Me<span class=\"plusLabel hidden_elem fcg\"> (+)</span></span></a></li><li class=\"uiMenuItem uiMenuItemRadio uiSelectorOption fbPrivacyAudienceSelectorOption\" data-label=\"Custom\" id=\"uq3j16_69\"><a class=\"itemAnchor itemWithIcon\" role=\"menuitemradio\" tabindex=\"-1\" href=\"#\" aria-checked=\"false\"><i class=\"mrs itemIcon img sp_14y7us sx_245b49\"></i><span class=\"itemLabel fsm\">Custom<span class=\"customPrivacyInputs\"></span></span></a></li><li class=\"uiMenuSeparator\"></li><li class=\"uiMenuItem uiMenuItemRadio uiSelectorOption fbPrivacyAudienceSelectorOption friendListOption specialOption primaryOption\" data-label=\"Close Friends\" id=\"uq3j16_72\"><a class=\"itemAnchor itemWithIcon\" role=\"menuitemradio\" tabindex=\"-1\" href=\"#\" aria-checked=\"false\" data-flid=\"196338550436560\" rel=\"async-post\" ajaxify=\"/ajax/privacy/simple_save.php?id=0&amp;audience_json=\u00255B\u00257B\u002522value\u002522\u00253A\u002522196338550436560\u002522\u00257D\u00255D\"><i class=\"mrs itemIcon img sp_14y7us sx_47c9ad\"></i><span class=\"itemLabel fsm\">Close Friends</span></a></li><li class=\"uiMenuItem uiMenuItemRadio uiSelectorOption fbPrivacyAudienceSelectorOption friendListOption specialOption primaryOption\" data-label=\"Hell Area\" id=\"uq3j16_67\"><a class=\"itemAnchor itemWithIcon\" role=\"menuitemradio\" tabindex=\"-1\" href=\"#\" aria-checked=\"false\" data-flid=\"350511818352565\" data-dynamic=\"1\" rel=\"async-post\" ajaxify=\"/ajax/privacy/simple_save.php?id=0&amp;audience_json=\u00255B\u00257B\u002522value\u002522\u00253A\u002522350511818352565\u002522\u00257D\u00255D\"><i class=\"mrs itemIcon img sp_14y7us sx_60bd74\"></i><span class=\"itemLabel fsm\">Hell Area</span></a></li><li class=\"uiMenuItem uiMenuItemRadio uiSelectorOption moreOption specialOption\" data-label=\"See all lists...\"><a class=\"itemAnchor\" role=\"menuitemradio\" tabindex=\"-1\" href=\"#\" aria-checked=\"false\" data-type=\"friendList\"><span class=\"itemLabel fsm\">See all lists...</span></a></li><li class=\"uiMenuItem uiMenuItemRadio uiSelectorOption fbPrivacyAudienceSelectorOption friendListOption specialOption secondaryOption\" data-label=\"Family\" id=\"uq3j16_74\"><a class=\"itemAnchor itemWithIcon\" role=\"menuitemradio\" tabindex=\"-1\" href=\"#\" aria-checked=\"false\" rel=\"async-post\" ajaxify=\"/ajax/privacy/simple_save.php?id=0&amp;audience_json=\u00255B\u00257B\u002522value\u002522\u00253A\u002522196338560436559\u002522\u00257D\u00255D\"><i class=\"mrs itemIcon img sp_14y7us sx_1e2cc9\"></i><span class=\"itemLabel fsm\">Family</span></a></li><li class=\"uiMenuItem uiMenuItemRadio uiSelectorOption fbPrivacyAudienceSelectorOption friendListOption specialOption secondaryOption\" data-label=\"Acquaintances\" id=\"uq3j16_75\"><a class=\"itemAnchor itemWithIcon\" role=\"menuitemradio\" tabindex=\"-1\" href=\"#\" aria-checked=\"false\" data-flid=\"100001812504199_124542800973931\" rel=\"async-post\" ajaxify=\"/ajax/privacy/simple_save.php?id=0&amp;audience_json=\u00255B\u00257B\u002522value\u002522\u00253A\u002522100001812504199_124542800973931\u002522\u00257D\u00255D\"><i class=\"mrs itemIcon img sp_14y7us sx_03de67\"></i><span class=\"itemLabel fsm\">Acquaintances</span></a></li><li class=\"uiMenuSeparator secondaryOption\"></li><li class=\"uiMenuItem uiMenuItemRadio uiSelectorOption returnOption secondaryOption specialOption\" data-label=\"Go Back\"><a class=\"itemAnchor\" role=\"menuitemradio\" tabindex=\"-1\" href=\"#\" aria-checked=\"false\"><span class=\"itemLabel fsm\">Go Back</span></a></li></ul></div></div></div><select name=\"audience[0][value]\"><option value=\"\"></option><option value=\"80\" selected=\"1\">Public</option><option value=\"40\">Friends</option><option value=\"10\">Only Me</option><option value=\"111\">Custom</option><option value=\"196338550436560\">Close Friends</option><option value=\"350511818352565\">Hell Area</option><option value=\"See all lists...\">See all lists...</option><option value=\"196338560436559\">Family</option><option value=\"100001812504199_124542800973931\">Acquaintances</option><option value=\"Go Back\">Go Back</option></select></div></div> ";
// undefined
o19 = null;
// 2359
o15.parentNode = o7;
// 2361
f33216266_455.returns.push(o15);
// undefined
o15 = null;
// 2362
// 2363
o14.getAttribute = f33216266_456;
// undefined
o14 = null;
// 2364
f33216266_456.returns.push("pagelet_privacy_widget");
// 2367
f33216266_432.returns.push(1344872059717);
// 2370
f33216266_432.returns.push(1344872059717);
// 2374
o14 = {};
// 2375
f33216266_441.returns.push(o14);
// 2377
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 2381
o14 = {};
// 2382
f33216266_441.returns.push(o14);
// 2384
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 2386
f33216266_432.returns.push(1344872059718);
// 2389
f33216266_432.returns.push(1344872059718);
// 2393
f33216266_432.returns.push(1344872059718);
// 2395
f33216266_450.returns.push(o9);
// 2397
o14 = {};
// 2398
f33216266_450.returns.push(o14);
// 2399
o15 = {};
// 2400
o14.firstChild = o15;
// 2402
o15.nodeType = 8;
// 2404
o15.nodeValue = " <li class=\"uiUnifiedStory uiStreamStory genericStreamStory aid_1055580469 uiListItem uiListLight uiListVerticalItemBorder\" data-ft=\"&#123;&quot;qid&quot;:&quot;5776181494237290802&quot;,&quot;mf_story_key&quot;:&quot;8878831909009365538&quot;&#125;\" id=\"stream_story_50291e77633c36f83163300\"><div class=\"clearfix storyContent\"><a class=\"actorPhoto lfloat\" href=\"http://www.facebook.com/LawlabeeTheWallaby\" tabindex=\"-1\" aria-hidden=\"true\" data-ft=\"&#123;&quot;type&quot;:60,&quot;tn&quot;:&quot;\\\\u003C&quot;&#125;\" data-hovercard=\"/ajax/hovercard/hovercard.php?id=1055580469\"><img class=\"-cx-PRIVATE-uiSquareImage__root profilePic -cx-PRIVATE-uiSquareImage__large img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/157194_1055580469_1433282671_q.jpg\" alt=\"\" /></a><div class=\"storyInnerContent\"><div class=\"mainWrapper\"><h6 class=\"uiStreamMessage uiStreamHeadline uiStreamPassive\" data-ft=\"&#123;&quot;tn&quot;:&quot;B&quot;,&quot;type&quot;:1&#125;\"><a class=\"passiveName\" href=\"http://www.facebook.com/LawlabeeTheWallaby\" data-ft=\"&#123;&quot;tn&quot;:&quot;;&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=1055580469\">Gregor Richards</a> likes a <a class=\"pronoun-link \" href=\"http://www.facebook.com/photo.php?fbid=3088544471436&amp;set=a.2067052694780.79088.1798694279&amp;type=1\" data-ft=\"&#123;&quot;tn&quot;:&quot;A&quot;&#125;\" ajaxify=\"http://www.facebook.com/photo.php?fbid=3088544471436&amp;set=a.2067052694780.79088.1798694279&amp;type=1&amp;src=http\u00253A\u00252F\u00252Fa5.sphotos.ak.fbcdn.net\u00252Fhphotos-ak-snc7\u00252F468416_3088544471436_995895021_o.jpg&amp;smallsrc=http\u00253A\u00252F\u00252Fsphotos-a.xx.fbcdn.net\u00252Fhphotos-prn1\u00252F559131_3088544471436_995895021_n.jpg&amp;size=1632\u00252C1224\" rel=\"theater\">photo</a>.</h6><span class=\"uiStreamFooter\"></span><div class=\"uiStreamEdgeStoryLine\"><hr /></div><ul class=\"uiList mtm uiCollapsedList uiCollapsedListHidden uiStreamSubstories\" id=\"uq3j2t_34\"><li class=\"uiListItem uiListLight uiListVerticalItemBorder\" id=\"stream_sub_story_50291e7763ffa4459236988\" data-ft=\"&#123;&quot;tn&quot;:&quot;U&quot;&#125;\"><div class=\"genericStreamStory uiStreamSubstory aid_1798694279 stream_sub_story_50291e7763ffa4459236988 uiStory_3088544471436\"><div class=\"clearfix storyContent\"><a class=\"substoryActorPic lfloat\" href=\"http://www.facebook.com/h3r2tic\" tabindex=\"-1\" data-ft=\"&#123;&quot;tn&quot;:&quot;T&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=1798694279\"><img class=\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__medium img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/260787_1798694279_178383372_q.jpg\" alt=\"\" /></a><div class=\"storyInnerContent storyInnerContentSmallPic\"><h6 class=\"uiStreamMessage uiStreamHeadline\" data-ft=\"&#123;&quot;tn&quot;:&quot;:&quot;&#125;\"><div class=\"actorDescription actorName\" data-ft=\"&#123;&quot;type&quot;:2,&quot;tn&quot;:&quot;:&quot;&#125;\"><a href=\"http://www.facebook.com/h3r2tic\" data-ft=\"&#123;&quot;tn&quot;:&quot;;&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=1798694279\">Tomasz Stachowiak</a></div></h6><h6 class=\"uiStreamMessage\" data-ft=\"&#123;&quot;type&quot;:1,&quot;tn&quot;:&quot;K&quot;&#125;\"> <span class=\"messageBody\" data-ft=\"&#123;&quot;type&quot;:3&#125;\"><div>Came back home from Siggraph, found this blu-tacked to my door xD</div></span></h6><div class=\"mvm uiStreamAttachments\" data-ft=\"&#123;&quot;type&quot;:10,&quot;tn&quot;:&quot;H&quot;&#125;\"><div class=\"clearfix photoRedesign\"><a class=\"uiPhotoThumb photoRedesignAspect\" href=\"http://www.facebook.com/photo.php?fbid=3088544471436&amp;set=a.2067052694780.79088.1798694279&amp;type=1&amp;ref=nf\" data-ft=\"&#123;&quot;type&quot;:41,&quot;tn&quot;:&quot;E&quot;&#125;\" rel=\"theater\" ajaxify=\"http://www.facebook.com/photo.php?fbid=3088544471436&amp;set=a.2067052694780.79088.1798694279&amp;type=1&amp;ref=nf&amp;src=http\u00253A\u00252F\u00252Fa5.sphotos.ak.fbcdn.net\u00252Fhphotos-ak-snc7\u00252F468416_3088544471436_995895021_o.jpg&amp;smallsrc=http\u00253A\u00252F\u00252Fsphotos-a.xx.fbcdn.net\u00252Fhphotos-prn1\u00252F559131_3088544471436_995895021_n.jpg&amp;size=1632\u00252C1224&amp;theater\" aria-label=\"Photo\"><img class=\"img\" height=\"268\" src=\"http://sphotos-a.xx.fbcdn.net/hphotos-prn1/s480x480/559131_3088544471436_995895021_n.jpg\" width=\"358\" alt=\"\" /></a></div></div><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function ea00110230e3e0a9a069d26fc371c4f62a1d360e7(event) {\\u000a    return Event.__inlineSubmit(this, event);\\u000a};\"), (\"sb95e64b34b3e8d19cc4c51675c8c072915de87f9\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction ea00110230e3e0a9a069d26fc371c4f62a1d360e7(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"sb95e64b34b3e8d19cc4c51675c8c072915de87f9_0\"), (sb95e64b34b3e8d19cc4c51675c8c072915de87f9_0_instance), (this), (arguments)))\n    };\n    (null);\n    return (((JSBNG_Record.get)(JSBNG__Event, (\"__inlineSubmit\")))[(\"__inlineSubmit\")])(this, JSBNG__event);\n};\nvar sb95e64b34b3e8d19cc4c51675c8c072915de87f9_0_instance;\n((sb95e64b34b3e8d19cc4c51675c8c072915de87f9_0_instance) = ((JSBNG_Record.eventInstance)((\"sb95e64b34b3e8d19cc4c51675c8c072915de87f9_0\"))));\n((JSBNG_Record.markFunction)((ea00110230e3e0a9a069d26fc371c4f62a1d360e7)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><form rel=\"async\" class=\"live_3088544471436_131325686911214 commentable_item autoexpand_mode\" method=\"post\" action=\"/ajax/ufi/modify.php\" data-live=\"&#123;&quot;seq&quot;:1580963&#125;\" onsubmit=\"return ea00110230e3e0a9a069d26fc371c4f62a1d360e7.call(this, event);\" id=\"uq3j2t_37\"><input type=\"hidden\" name=\"charset_test\" value=\"&euro;,&acute;,€,´,水,Д,Є\" /><input type=\"hidden\" name=\"fb_dtsg\" value=\"AQCc21Em\" autocomplete=\"off\" /><input type=\"hidden\" autocomplete=\"off\" name=\"feedback_params\" value=\"&#123;&quot;actor&quot;:&quot;1798694279&quot;,&quot;target_fbid&quot;:&quot;3088544471436&quot;,&quot;target_profile_id&quot;:&quot;1798694279&quot;,&quot;type_id&quot;:&quot;7&quot;,&quot;assoc_obj_id&quot;:&quot;&quot;,&quot;source_app_id&quot;:&quot;350685531728&quot;,&quot;extra_story_params&quot;:[],&quot;content_timestamp&quot;:&quot;1344704238&quot;,&quot;check_hash&quot;:&quot;AQCqOd17xKwlU584&quot;,&quot;source&quot;:&quot;1&quot;&#125;\" /><span class=\"uiStreamFooter\"><span class=\"UIActionLinks UIActionLinks_bottom\" data-ft=\"&#123;&quot;tn&quot;:&quot;=&quot;,&quot;type&quot;:20&#125;\"><a class=\"share_action_link\" href=\"/ajax/sharer/?s=2&amp;appid=2305272732&amp;p\u00255B0\u00255D=1798694279&amp;p\u00255B1\u00255D=1903853\" rel=\"dialog\" data-ft=\"&#123;&quot;tn&quot;:&quot;J&quot;,&quot;type&quot;:25&#125;\" title=\"Send this to friends or post it on your timeline.\">Share</a> &#183; </span><span class=\"uiStreamSource\" data-ft=\"&#123;&quot;type&quot;:26,&quot;tn&quot;:&quot;N&quot;&#125;\"><a href=\"http://www.facebook.com/photo.php?fbid=3088544471436&amp;set=a.2067052694780.79088.1798694279&amp;type=1\"><abbr title=\"Saturday, August 11, 2012 at 12:57pm\" data-utime=\"1344704238\">Saturday at 12:57pm</abbr></a> via <a href=\"/mobile/?v=350685531728\">mobile</a></span> · <a data-hover=\"tooltip\" title=\"Shared with: Tomasz&#039;s friends of friends\" class=\"uiStreamPrivacy inlineBlock fbStreamPrivacy fbPrivacyAudienceIndicator\" href=\"#\"><i class=\"lock img sp_67189i sx_0184a4\"></i></a></span><div><ul class=\"uiList uiUfi focus_target fbUfi fbUfiNoBorder\" data-ft=\"&#123;&quot;type&quot;:30,&quot;tn&quot;:&quot;]&quot;&#125;\"><li class=\"ufiNub uiListItem  uiListVerticalItemBorder\"><i></i></li><li class=\"ufiItem uiUfiLike uiListItem  uiListVerticalItemBorder\" data-ft=\"&#123;&quot;type&quot;:31&#125;\"><div class=\"UIImageBlock clearfix\"><a class=\"uiUfiLikeIcon uiUfiLikeIconDisabled UIImageBlock_Image UIImageBlock_ICON_Image\" href=\"#\" tabindex=\"-1\" aria-hidden=\"true\"></a><div class=\"UIImageBlock_Content UIImageBlock_ICON_Content\"><a href=\"http://www.facebook.com/LawlabeeTheWallaby\" data-hovercard=\"/ajax/hovercard/user.php?id=1055580469\">Gregor Richards</a> and <a href=\"/browse/likes/?id=3088544471436\" rel=\"dialog\" title=\"See who likes this\" ajaxify=\"/ajax/browser/dialog/likes/?id=3088544471436\">9 others</a> like this.</div></div></li><li class=\"translateable_info hidden_elem uiListItem  uiListVerticalItemBorder\"><input type=\"hidden\" autocomplete=\"off\" name=\"translate_on_load\" value=\"\" /></li><li class=\"uiUfiComments uiListItem  uiListVerticalItemBorder\" data-ft=\"&#123;&quot;type&quot;:32&#125;\"><ul class=\"commentList\"><li class=\"uiUfiViewAll  ufiItem\"><label class=\"uiIconText uiLinkButton async_throbber\"><i class=\"img sp_627qpw sx_4fad2b\"></i><input type=\"submit\" name=\"view_all[1]\" value=\"View all 5 comments\" data-ft=\"&#123;&quot;tn&quot;:&quot;Q&quot;&#125;\" class=\"stat_elem\" /></label></li><li class=\"uiUfiComment comment_1580909 ufiItem ufiItem\" data-ft=\"&#123;&quot;tn&quot;:&quot;R0&quot;&#125;\"><div class=\"UIImageBlock clearfix uiUfiActorBlock\"><a class=\"actorPic UIImageBlock_Image UIImageBlock_SMALL_Image\" href=\"http://www.facebook.com/zongyi.chen.37\" tabindex=\"-1\" data-ft=\"&#123;&quot;type&quot;:34,&quot;tn&quot;:&quot;T&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=508949502\"><img class=\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__medium img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-ash2/369240_508949502_2050693853_q.jpg\" alt=\"\" /></a><a data-hover=\"tooltip\" title=\"Hide as Spam\" class=\"commentRemoverButton UIImageBlock_Ext uiCloseButton\" href=\"#\" role=\"button\" rel=\"async-post\" ajaxify=\"/ajax/ufi/one_click_remove?comment_id=1580909&amp;commenter_id=508949502&amp;profile_id=1798694279&amp;post_fbid=3092141721365&amp;can_remove=0&amp;can_report=1&amp;can_edit=0&amp;is_spam=0&amp;report_link=\u00252Fajax\u00252Freport.php\u00253Fcontent_type\u00253D71\u002526cid\u00253D3092141721365\u002526rid\u00253D508949502\u002526cid2\u00253D0\u002526profile\u00253D1798694279\u002526h\u00253DAfj9x4z5Zy0BXWTT&amp;feedback_params=\u00257B\u002522actor\u002522\u00253A\u0025221798694279\u002522\u00252C\u002522target_fbid\u002522\u00253A\u0025223088544471436\u002522\u00252C\u002522target_profile_id\u002522\u00253A\u0025221798694279\u002522\u00252C\u002522type_id\u002522\u00253A\u0025227\u002522\u00252C\u002522assoc_obj_id\u002522\u00253A\u002522\u002522\u00252C\u002522source_app_id\u002522\u00253A\u002522350685531728\u002522\u00252C\u002522extra_story_params\u002522\u00253A\u00255B\u00255D\u00252C\u002522content_timestamp\u002522\u00253A\u0025221344704238\u002522\u00252C\u002522check_hash\u002522\u00253A\u002522AQCqOd17xKwlU584\u002522\u00252C\u002522source\u002522\u00253A\u00252213\u002522\u00257D\"></a><div data-ft=\"&#123;&quot;type&quot;:33,&quot;tn&quot;:&quot;K&quot;&#125;\" class=\"UIImageBlock_Content UIImageBlock_SMALL_Content\"><div class=\"commentContent\"><a class=\"actorName\" href=\"http://www.facebook.com/zongyi.chen.37\" data-ft=\"&#123;&quot;type&quot;:35,&quot;tn&quot;:&quot;;&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=508949502\">Zongyi Chen</a> <span data-jsid=\"text\" class=\"commentBody\">‎*cough*</span><span></span></div><div class=\"commentActions fsm fwn fcg\"><a class=\"uiLinkSubtle\" href=\"http://www.facebook.com/photo.php?fbid=3088544471436&amp;set=a.2067052694780.79088.1798694279&amp;type=1&amp;comment_id=1580909&amp;offset=0&amp;total_comments=5\" data-ft=\"&#123;&quot;tn&quot;:&quot;N&quot;&#125;\"><abbr title=\"Sunday, August 12, 2012 at 1:40pm\" data-utime=\"1344793251\" class=\"timestamp livetimestamp\">21 hours ago</abbr></a> · <span><a data-hover=\"tooltip\" class=\"uiLinkSubtle\" ajaxify=\"/ajax/edits/browser/comment/?comment_token=3088544471436_1580909\" rel=\"dialog\" href=\"#\" id=\"uq3j2t_38\">Edited</a></span></div></div></div></li><li class=\"uiUfiComment comment_1580963 ufiItem ufiItem\" data-ft=\"&#123;&quot;tn&quot;:&quot;R&quot;&#125;\"><div class=\"UIImageBlock clearfix uiUfiActorBlock\"><a class=\"actorPic UIImageBlock_Image UIImageBlock_SMALL_Image\" href=\"http://www.facebook.com/h3r2tic\" tabindex=\"-1\" data-ft=\"&#123;&quot;type&quot;:34,&quot;tn&quot;:&quot;T&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=1798694279\"><img class=\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__medium img\" src=\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/260787_1798694279_178383372_q.jpg\" alt=\"\" /></a><a data-hover=\"tooltip\" title=\"Hide as Spam\" class=\"commentRemoverButton UIImageBlock_Ext uiCloseButton\" href=\"#\" role=\"button\" rel=\"async-post\" ajaxify=\"/ajax/ufi/one_click_remove?comment_id=1580963&amp;commenter_id=1798694279&amp;profile_id=1798694279&amp;post_fbid=3092362886894&amp;can_remove=0&amp;can_report=1&amp;can_edit=0&amp;is_spam=0&amp;report_link=\u00252Fajax\u00252Freport.php\u00253Fcontent_type\u00253D71\u002526cid\u00253D3092362886894\u002526rid\u00253D1798694279\u002526cid2\u00253D0\u002526profile\u00253D1798694279\u002526h\u00253DAfgf_Q48q7wYKkaz&amp;feedback_params=\u00257B\u002522actor\u002522\u00253A\u0025221798694279\u002522\u00252C\u002522target_fbid\u002522\u00253A\u0025223088544471436\u002522\u00252C\u002522target_profile_id\u002522\u00253A\u0025221798694279\u002522\u00252C\u002522type_id\u002522\u00253A\u0025227\u002522\u00252C\u002522assoc_obj_id\u002522\u00253A\u002522\u002522\u00252C\u002522source_app_id\u002522\u00253A\u002522350685531728\u002522\u00252C\u002522extra_story_params\u002522\u00253A\u00255B\u00255D\u00252C\u002522content_timestamp\u002522\u00253A\u0025221344704238\u002522\u00252C\u002522check_hash\u002522\u00253A\u002522AQCqOd17xKwlU584\u002522\u00252C\u002522source\u002522\u00253A\u00252213\u002522\u00257D\"></a><div data-ft=\"&#123;&quot;type&quot;:33,&quot;tn&quot;:&quot;K&quot;&#125;\" class=\"UIImageBlock_Content UIImageBlock_SMALL_Content\"><div class=\"commentContent\"><a class=\"actorName\" href=\"http://www.facebook.com/h3r2tic\" data-ft=\"&#123;&quot;type&quot;:35,&quot;tn&quot;:&quot;;&quot;&#125;\" data-hovercard=\"/ajax/hovercard/user.php?id=1798694279\">Tomasz Stachowiak</a> <span data-jsid=\"text\" class=\"commentBody\">YEAH, TOTALLY NOT SUSPECTING YOU, <a href=\"http://www.facebook.com/zongyi.chen.37\" data-hovercard=\"/ajax/hovercard/user.php?id=508949502\">Zongyi</a></span><span></span></div><div class=\"commentActions fsm fwn fcg\"><a class=\"uiLinkSubtle\" href=\"http://www.facebook.com/photo.php?fbid=3088544471436&amp;set=a.2067052694780.79088.1798694279&amp;type=1&amp;comment_id=1580963&amp;offset=0&amp;total_comments=5\" data-ft=\"&#123;&quot;tn&quot;:&quot;N&quot;&#125;\"><abbr title=\"Sunday, August 12, 2012 at 2:36pm\" data-utime=\"1344796591\" class=\"timestamp livetimestamp\">20 hours ago</abbr></a> · <span class=\"comment_like_1580963 fsm fwn fcg\"><a data-hover=\"tooltip\" data-tooltip-uri=\"/ajax/like/tooltip.php?comment_fbid=3092362886894&amp;comment_from=1798694279\" data-tooltip-alignh=\"center\" class=\"comment_like_button\" rel=\"dialog\" href=\"/browse/likes/?id=3092362886894\" ajaxify=\"/ajax/browser/dialog/likes/?id=3092362886894\"><i class=\"cmt_like_icon\"></i>1</a></span></div></div></div></li></ul></li></ul></div></form></div></div></div></li></ul></div><div class=\"-cx-PRIVATE-uiInlineBlock__root  mlm uiPopover highlightSelector uiStreamHide\" data-ft=\"&#123;&quot;type&quot;:55,&quot;tn&quot;:&quot;V&quot;&#125;\" id=\"uq3j2t_35\"><a class=\"highlightSelectorButton uiStreamContextButton -cx-PRIVATE-uiPopover__trigger\" href=\"#\" aria-haspopup=\"true\" aria-expanded=\"false\" rel=\"toggle\" id=\"uq3j2t_36\">Options</a></div></div></div></li> ";
// undefined
o15 = null;
// 2405
o14.parentNode = o7;
// 2407
f33216266_455.returns.push(o14);
// undefined
o14 = null;
// 2409
o14 = {};
// 2410
f33216266_476.returns.push(o14);
// 2411
// 2413
o15 = {};
// 2414
f33216266_441.returns.push(o15);
// 2415
o19 = {};
// undefined
fo33216266_585_firstChild = function() { return fo33216266_585_firstChild.returns[fo33216266_585_firstChild.inst++]; };
fo33216266_585_firstChild.returns = [];
fo33216266_585_firstChild.inst = 0;
defineGetter(o14, "firstChild", fo33216266_585_firstChild);
// undefined
o14 = null;
// undefined
fo33216266_585_firstChild.returns.push(o19);
// 2417
o15.appendChild = f33216266_443;
// undefined
fo33216266_585_firstChild.returns.push(o19);
// 2419
f33216266_443.returns.push(o19);
// undefined
fo33216266_585_firstChild.returns.push(null);
// 2422
f33216266_443.returns.push(o15);
// undefined
o15 = null;
// 2424
f33216266_456.returns.push("home_stream");
// 2427
f33216266_432.returns.push(1344872059729);
// 2430
f33216266_432.returns.push(1344872059730);
// 2434
o14 = {};
// 2435
f33216266_441.returns.push(o14);
// 2437
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 2441
o14 = {};
// 2442
f33216266_441.returns.push(o14);
// 2444
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 2446
f33216266_432.returns.push(1344872059731);
// 2449
f33216266_432.returns.push(1344872059731);
// 2453
f33216266_432.returns.push(1344872059732);
// 2455
o14 = {};
// 2456
f33216266_450.returns.push(o14);
// 2458
o15 = {};
// 2459
f33216266_450.returns.push(o15);
// 2460
o20 = {};
// 2461
o15.firstChild = o20;
// 2463
o20.nodeType = 8;
// 2465
o20.nodeValue = " <div class=\"clearfix mts uiMorePager stat_elem fbStreamPager hasMorePosts\"><div><script type=\"text/javascript\">((JSBNG_Record.scriptLoad)((\"function ec27bb60697a7a8e95d33c7fee7028904fb8c6605(event) {\\u000a    (UIIntentionalStream.instance && UIIntentionalStream.instance.loadOlderPosts());\\u000a    return false;\\u000a};\"), (\"s44f9a2b24b2ff1576d482b4d7577d796d76f1043\")));\n((window.top.JSBNG_Record.callerJS) = (true));\nfunction ec27bb60697a7a8e95d33c7fee7028904fb8c6605(JSBNG__event) {\n    if ((!(JSBNG_Record.top.JSBNG_Record.callerJS))) {\n        return ((JSBNG_Record.eventCall)((arguments.callee), (\"s44f9a2b24b2ff1576d482b4d7577d796d76f1043_0\"), (s44f9a2b24b2ff1576d482b4d7577d796d76f1043_0_instance), (this), (arguments)))\n    };\n    (null);\n    ((((JSBNG_Record.get)(UIIntentionalStream, (\"instance\")))[(\"instance\")]) && (((JSBNG_Record.get)((((JSBNG_Record.get)(UIIntentionalStream, (\"instance\")))[(\"instance\")]), (\"loadOlderPosts\")))[(\"loadOlderPosts\")])());\n    return false;\n};\nvar s44f9a2b24b2ff1576d482b4d7577d796d76f1043_0_instance;\n((s44f9a2b24b2ff1576d482b4d7577d796d76f1043_0_instance) = ((JSBNG_Record.eventInstance)((\"s44f9a2b24b2ff1576d482b4d7577d796d76f1043_0\"))));\n((JSBNG_Record.markFunction)((ec27bb60697a7a8e95d33c7fee7028904fb8c6605)));\n((window.top.JSBNG_Record.callerJS) = (false));\n((window.top.JSBNG_Record.flushDeferredEvents)());</script><a class=\"pam uiBoxLightblue  uiMorePagerPrimary\" href=\"#\" onclick=\"return ec27bb60697a7a8e95d33c7fee7028904fb8c6605.call(this, event);\">More Stories<i class=\"mts mls arrow img sp_55oxbe sx_240471\"></i></a><span class=\"uiMorePagerLoader pam uiBoxLightblue \"><img class=\"img\" src=\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\" alt=\"\" width=\"16\" height=\"11\" /></span></div></div> ";
// undefined
o20 = null;
// 2466
o15.parentNode = o7;
// 2468
f33216266_455.returns.push(o15);
// undefined
o15 = null;
// 2469
// 2470
o14.getAttribute = f33216266_456;
// 2471
f33216266_456.returns.push(null);
// 2472
o14.setAttribute = f33216266_480;
// undefined
o14 = null;
// 2473
f33216266_480.returns.push(undefined);
// 2475
f33216266_432.returns.push(1344872059733);
// 2478
f33216266_432.returns.push(1344872059736);
// 2482
o14 = {};
// 2483
f33216266_441.returns.push(o14);
// 2485
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 2489
o14 = {};
// 2490
f33216266_441.returns.push(o14);
// 2492
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 2494
f33216266_432.returns.push(1344872059736);
// 2497
f33216266_432.returns.push(1344872059737);
// 2501
f33216266_432.returns.push(1344872059737);
// 2503
f33216266_432.returns.push(1344872059737);
// 2506
f33216266_432.returns.push(1344872059742);
// 2510
o14 = {};
// 2511
f33216266_441.returns.push(o14);
// 2513
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 2517
o14 = {};
// 2518
f33216266_441.returns.push(o14);
// 2520
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 2522
f33216266_432.returns.push(1344872059743);
// 2525
f33216266_432.returns.push(1344872059743);
// 2529
o14 = {};
// 2530
f33216266_441.returns.push(o14);
// 2532
f33216266_443.returns.push(o14);
// undefined
o14 = null;
// 2534
f33216266_432.returns.push(1344872059744);
// 2535
o14 = {};
// 2536
o15 = {};
// 2537
o14.target = o15;
// undefined
o14 = null;
// 2538
o15.getAttribute = f33216266_456;
// 2540
f33216266_456.returns.push(null);
// 2541
o15.parentNode = o7;
// 2542
o7.getAttribute = f33216266_456;
// 2544
f33216266_456.returns.push(null);
// 2545
o7.parentNode = o4;
// 2546
o4.getAttribute = f33216266_456;
// 2548
f33216266_456.returns.push(null);
// 2549
o4.parentNode = o0;
// 2550
o0.getAttribute = void 0;
// 2551
o0.parentNode = null;
// 2554
f33216266_456.returns.push(null);
// 2558
f33216266_456.returns.push(null);
// 2562
f33216266_456.returns.push(null);
// 2569
// 2570
o14 = {};
// 2571
f33216266_279.prototype = o14;
// 2573
// 2574
// 2575
// 2576
// 2577
// 2578
// 2580
// 2581
// 2582
// 2583
// 2584
// undefined
o14 = null;
// 2585
// 2586
// 2587
// 2588
// 2589
// 2590
// 2591
// 2592
// 2593
// 2594
// 2596
// 2597
f33216266_12.returns.push(50);
// 2598
o1._ua_log = "{\"log\":[{\"ts\":1344872006578,\"path\":\"-\",\"index\":0,\"type\":\"init\",\"iref\":\"-\"},{\"path\":\"/index.php\",\"type\":\"click\",\"ts\":1344872030593,\"iref\":\"bluebar\",\"index\":1},{\"ts\":1344872040857,\"path\":\"-\",\"index\":2,\"type\":\"init\",\"iref\":\"-\"},{\"path\":\"/home.php\",\"type\":\"click\",\"ts\":1344872053682,\"iref\":\"bluebar\",\"index\":3},{\"path\":\"/home.php\",\"type\":\"click\",\"ts\":1344872054923,\"iref\":\"pinned_nav\",\"index\":4}],\"len\":5}";
// 2601
f33216266_432.returns.push(1344872059804);
// 2602
o14 = {};
// 2603
o20 = {};
// 2605
o14.length = 1;
// 2606
o14["0"] = "8gPM0";
// 2611
f33216266_430.returns.push(0.6121722033713013);
// 2612
f33216266_603 = function() { return f33216266_603.returns[f33216266_603.inst++]; };
f33216266_603.returns = [];
f33216266_603.inst = 0;
// 2613
f33216266_279.listen = f33216266_603;
// 2615
o21 = {};
// 2616
f33216266_279.Priority = o21;
// 2617
o21.NORMAL = 0;
// 2618
o4.nodeName = "HTML";
// undefined
fo33216266_431___FB_TOKEN = function() { return fo33216266_431___FB_TOKEN.returns[fo33216266_431___FB_TOKEN.inst++]; };
fo33216266_431___FB_TOKEN.returns = [];
fo33216266_431___FB_TOKEN.inst = 0;
defineGetter(o4, "__FB_TOKEN", fo33216266_431___FB_TOKEN);
// undefined
fo33216266_431___FB_TOKEN.returns.push(void 0);
// 2623
f33216266_456.returns.push(null);
// 2624
o22 = {};
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 2626
o22["0"] = 1;
// 2629
f33216266_433.returns.push(undefined);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 2632
o4.onmousedown = null;
// 2634
f33216266_603.returns.push({__JSBNG_unknown_object:true});
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 2646
f33216266_433.returns.push(undefined);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 2649
f33216266_606 = function() { return f33216266_606.returns[f33216266_606.inst++]; };
f33216266_606.returns = [];
f33216266_606.inst = 0;
// 2650
o4.onkeydown = f33216266_606;
// 2653
o21._BUBBLE = 1000;
// 2655
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 2662
f33216266_603.returns.push({__JSBNG_unknown_object:true});
// 2664
f33216266_603.returns.push({__JSBNG_unknown_object:true});
// 2668
o21.URGENT = -20;
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 2674
f33216266_603.returns.push({__JSBNG_unknown_object:true});
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 2686
f33216266_433.returns.push(undefined);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 2689
f33216266_607 = function() { return f33216266_607.returns[f33216266_607.inst++]; };
f33216266_607.returns = [];
f33216266_607.inst = 0;
// 2690
o4.onclick = f33216266_607;
// 2695
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 2702
f33216266_603.returns.push({__JSBNG_unknown_object:true});
// 2704
f33216266_603.returns.push({__JSBNG_unknown_object:true});
// 2706
o23 = {};
// 2707
f33216266_476.returns.push(o23);
// 2708
// 2710
// 2712
f33216266_609 = function() { return f33216266_609.returns[f33216266_609.inst++]; };
f33216266_609.returns = [];
f33216266_609.inst = 0;
// 2713
o23.getElementsByTagName = f33216266_609;
// 2714
o24 = {};
// 2715
f33216266_609.returns.push(o24);
// 2716
o24.length = 0;
// undefined
o24 = null;
// 2718
o24 = {};
// 2719
o23.childNodes = o24;
// undefined
o23 = null;
// 2720
o24.nodeType = void 0;
// 2721
o24.__html = void 0;
// 2722
o24.genMarkup = void 0;
// undefined
fo33216266_611_className = function() { return fo33216266_611_className.returns[fo33216266_611_className.inst++]; };
fo33216266_611_className.returns = [];
fo33216266_611_className.inst = 0;
defineGetter(o24, "className", fo33216266_611_className);
// undefined
fo33216266_611_className.returns.push(void 0);
// undefined
fo33216266_611_className.returns.push(void 0);
// undefined
fo33216266_611___FB_TOKEN = function() { return fo33216266_611___FB_TOKEN.returns[fo33216266_611___FB_TOKEN.inst++]; };
fo33216266_611___FB_TOKEN.returns = [];
fo33216266_611___FB_TOKEN.inst = 0;
defineGetter(o24, "__FB_TOKEN", fo33216266_611___FB_TOKEN);
// undefined
fo33216266_611___FB_TOKEN.returns.push(void 0);
// 2728
o24.getElementsByTagName = void 0;
// undefined
fo33216266_611_className.returns.push("undefined uiLayer");
// undefined
fo33216266_611_className.returns.push("undefined uiLayer");
// 2732
o0.body = o7;
// 2734
o7.nodeType = 1;
// 2735
o7.nodeName = "BODY";
// 2738
o23 = {};
// 2739
f33216266_441.returns.push(o23);
// 2742
o7.appendChild = f33216266_443;
// 2743
f33216266_443.returns.push(o23);
// undefined
o23 = null;
// 2744
o23 = {};
// undefined
fo33216266_611___FB_TOKEN.returns.push(o23);
// 2746
o23["0"] = 2;
// undefined
fo33216266_611___FB_TOKEN.returns.push(o23);
// 2749
o24.getAttribute = void 0;
// undefined
fo33216266_611___FB_TOKEN.returns.push(o23);
// undefined
fo33216266_611_className.returns.push("undefined uiLayer hidden_elem");
// undefined
fo33216266_611___FB_TOKEN.returns.push(o23);
// undefined
fo33216266_611___FB_TOKEN.returns.push(o23);
// undefined
fo33216266_611___FB_TOKEN.returns.push(o23);
// undefined
fo33216266_611___FB_TOKEN.returns.push(o23);
// undefined
fo33216266_611___FB_TOKEN.returns.push(o23);
// undefined
fo33216266_611___FB_TOKEN.returns.push(o23);
// undefined
fo33216266_611_className.returns.push("undefined uiLayer hidden_elem");
// undefined
fo33216266_611___FB_TOKEN.returns.push(o23);
// undefined
fo33216266_611___FB_TOKEN.returns.push(o23);
// undefined
fo33216266_611___FB_TOKEN.returns.push(o23);
// undefined
o23 = null;
// undefined
fo33216266_611_className.returns.push("undefined uiLayer hidden_elem");
// undefined
fo33216266_611_className.returns.push("undefined uiLayer hidden_elem");
// undefined
fo33216266_611_className.returns.push("undefined uiLayer hidden_elem uiContextualDialogAbove");
// undefined
fo33216266_611_className.returns.push("undefined uiLayer hidden_elem uiContextualDialogAbove");
// undefined
fo33216266_611_className.returns.push("undefined uiLayer hidden_elem uiContextualDialogAbove");
// undefined
fo33216266_611_className.returns.push("undefined uiLayer hidden_elem uiContextualDialogAbove");
// undefined
fo33216266_611_className.returns.push("undefined uiLayer hidden_elem uiContextualDialogAbove");
// undefined
fo33216266_611_className.returns.push("undefined uiLayer hidden_elem uiContextualDialogAbove");
// undefined
fo33216266_611_className.returns.push("undefined uiLayer hidden_elem uiContextualDialogAbove uiContextualDialogArrowBottom");
// undefined
fo33216266_611_className.returns.push("undefined uiLayer hidden_elem uiContextualDialogAbove uiContextualDialogArrowBottom");
// undefined
fo33216266_611_className.returns.push("undefined uiLayer hidden_elem uiContextualDialogAbove uiContextualDialogArrowBottom");
// undefined
fo33216266_611_className.returns.push("undefined uiLayer hidden_elem uiContextualDialogAbove uiContextualDialogArrowBottom");
// 2797
o23 = {};
// 2798
f33216266_476.returns.push(o23);
// 2799
o23.setAttribute = f33216266_480;
// 2801
f33216266_480.returns.push(undefined);
// 2802
o23.__html = void 0;
// 2805
o25 = {};
// 2806
f33216266_441.returns.push(o25);
// 2808
o23.nodeType = 1;
// 2809
o23.nodeName = "I";
// 2810
o25.appendChild = f33216266_443;
// undefined
o25 = null;
// 2811
f33216266_443.returns.push(o23);
// undefined
o23 = null;
// 2812
o24.appendChild = void 0;
// undefined
o24 = null;
// 2816
f33216266_432.returns.push(1344872060069);
// 2819
f33216266_432.returns.push(1344872060071);
// 2822
f33216266_432.returns.push(1344872060071);
// 2825
f33216266_432.returns.push(1344872060072);
// 2828
f33216266_432.returns.push(1344872060072);
// 2832
f33216266_450.returns.push(o9);
// 2835
o9.nodeName = "UL";
// undefined
fo33216266_483___FB_TOKEN = function() { return fo33216266_483___FB_TOKEN.returns[fo33216266_483___FB_TOKEN.inst++]; };
fo33216266_483___FB_TOKEN.returns = [];
fo33216266_483___FB_TOKEN.inst = 0;
defineGetter(o9, "__FB_TOKEN", fo33216266_483___FB_TOKEN);
// undefined
fo33216266_483___FB_TOKEN.returns.push(void 0);
// 2840
f33216266_456.returns.push(null);
// 2841
o23 = {};
// undefined
fo33216266_483___FB_TOKEN.returns.push(o23);
// 2843
o23["0"] = 3;
// 2844
o9.JSBNG__addEventListener = f33216266_433;
// 2846
f33216266_433.returns.push(undefined);
// undefined
fo33216266_483___FB_TOKEN.returns.push(o23);
// undefined
o23 = null;
// 2849
o9["onAsyncRequest/send"] = void 0;
// 2851
f33216266_603.returns.push({__JSBNG_unknown_object:true});
// 2852
o23 = {};
// 2853
o24 = {};
// 2861
o23.length = 1;
// 2862
o23["0"] = "JOZ9R";
// 2865
f33216266_432.returns.push(1344872060090);
// 2868
f33216266_432.returns.push(1344872060091);
// 2871
f33216266_432.returns.push(1344872060091);
// 2874
f33216266_432.returns.push(1344872060091);
// 2879
f33216266_12.returns.push(51);
// 2880
f33216266_12.returns.push(52);
// 2881
f33216266_12.returns.push(53);
// 2882
f33216266_12.returns.push(54);
// 2883
f33216266_12.returns.push(55);
// 2885
o25 = {};
// 2886
f33216266_450.returns.push(o25);
// undefined
o25 = null;
// 2888
o25 = {};
// 2889
f33216266_450.returns.push(o25);
// undefined
o25 = null;
// 2890
o25 = {};
// 2891
o26 = {};
// 2894
o25.length = 1;
// 2895
o25["0"] = "1zqwA";
// 2898
f33216266_432.returns.push(1344872060165);
// 2904
f33216266_432.returns.push(1344872060196);
// 2911
f33216266_7.returns.push(undefined);
// 2912
f33216266_603.returns.push({__JSBNG_unknown_object:true});
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 2925
f33216266_433.returns.push(undefined);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 2928
o4.onDOMMouseScroll = void 0;
// 2930
f33216266_603.returns.push({__JSBNG_unknown_object:true});
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 2939
f33216266_433.returns.push(undefined);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 2942
o4.onmousewheel = null;
// 2944
f33216266_603.returns.push({__JSBNG_unknown_object:true});
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 2951
f33216266_603.returns.push({__JSBNG_unknown_object:true});
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 2960
f33216266_433.returns.push(undefined);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 2963
f33216266_623 = function() { return f33216266_623.returns[f33216266_623.inst++]; };
f33216266_623.returns = [];
f33216266_623.inst = 0;
// 2964
o4.onmouseover = f33216266_623;
// 2969
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 2976
f33216266_603.returns.push({__JSBNG_unknown_object:true});
// 2978
f33216266_603.returns.push({__JSBNG_unknown_object:true});
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 2985
f33216266_603.returns.push({__JSBNG_unknown_object:true});
// 2986
f33216266_603.returns.push({__JSBNG_unknown_object:true});
// 2988
o27 = {};
// 2989
f33216266_450.returns.push(o27);
// undefined
o27 = null;
// 2991
o7.className = "hasLeftCol home composerExpanded fbx safari4 Locale_en_US";
// 2992
o27 = {};
// 2993
o28 = {};
// 2996
o27.length = 1;
// 2997
o27["0"] = "6n1TR";
// 3000
f33216266_432.returns.push(1344872060206);
// 3005
o29 = {};
// 3006
o30 = {};
// 3009
o29.length = 1;
// 3010
o29["0"] = "28ZbA";
// 3013
f33216266_432.returns.push(1344872060209);
// 3016
f33216266_432.returns.push(1344872060210);
// 3021
o31 = {};
// 3022
o32 = {};
// 3025
o31.length = 1;
// 3026
o31["0"] = "C6rJk";
// 3031
o33 = {};
// 3032
o34 = {};
// 3035
o33.length = 1;
// 3036
o33["0"] = "u8TjK";
// 3041
o35 = {};
// 3042
o36 = {};
// 3045
o35.length = 1;
// 3046
o35["0"] = "tZ04z";
// 3049
f33216266_432.returns.push(1344872060224);
// 3052
f33216266_432.returns.push(1344872060224);
// 3055
f33216266_432.returns.push(1344872060225);
// 3058
f33216266_432.returns.push(1344872060225);
// 3063
o37 = {};
// 3064
o38 = {};
// 3067
o37.length = 1;
// 3068
o37["0"] = "oGZW7";
// 3073
f33216266_12.returns.push(56);
// 3081
f33216266_432.returns.push(1344872062972);
// 3083
f33216266_432.returns.push(1344872062973);
// 3086
f33216266_432.returns.push(1344872062973);
// 3088
f33216266_432.returns.push(1344872062973);
// 3091
f33216266_432.returns.push(1344872062973);
// 3095
o39 = {};
// 3096
f33216266_450.returns.push(o39);
// undefined
o39 = null;
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 3101
f33216266_638 = function() { return f33216266_638.returns[f33216266_638.inst++]; };
f33216266_638.returns = [];
f33216266_638.inst = 0;
// 3102
f33216266_279.getPriorities = f33216266_638;
// 3105
o21.TRADITIONAL = -10;
// undefined
o21 = null;
// 3108
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 3111
f33216266_432.returns.push(1344872062977);
// 3113
f33216266_623.returns.push(undefined);
// 3116
o21 = {};
// 3117
f33216266_450.returns.push(o21);
// undefined
o21 = null;
// 3119
f33216266_432.returns.push(1344872062981);
// 3122
f33216266_432.returns.push(1344872062981);
// 3124
f33216266_432.returns.push(1344872062981);
// 3127
f33216266_432.returns.push(1344872062982);
// 3129
f33216266_432.returns.push(1344872062982);
// 3132
f33216266_432.returns.push(1344872062982);
// 3134
f33216266_432.returns.push(1344872062982);
// 3137
f33216266_432.returns.push(1344872062982);
// 3139
f33216266_432.returns.push(1344872062982);
// 3142
f33216266_432.returns.push(1344872062983);
// 3148
o21 = {};
// 3149
f33216266_450.returns.push(o21);
// undefined
o21 = null;
// 3152
o21 = {};
// 3153
f33216266_450.returns.push(o21);
// undefined
o21 = null;
// 3155
f33216266_432.returns.push(1344872062990);
// 3158
f33216266_432.returns.push(1344872062991);
// 3160
f33216266_432.returns.push(1344872062991);
// 3163
f33216266_432.returns.push(1344872062991);
// 3166
f33216266_432.returns.push(1344872062991);
// 3169
f33216266_432.returns.push(1344872062991);
// 3172
o21 = {};
// 3173
f33216266_450.returns.push(o21);
// 3175
f33216266_432.returns.push(1344872062995);
// 3178
f33216266_432.returns.push(1344872062995);
// 3185
f33216266_432.returns.push(1344872063000);
// 3188
f33216266_432.returns.push(1344872063001);
// 3191
f33216266_432.returns.push(1344872063002);
// 3194
f33216266_432.returns.push(1344872063002);
// 3196
f33216266_432.returns.push(1344872063002);
// 3199
f33216266_432.returns.push(1344872063002);
// 3203
f33216266_432.returns.push(1344872063003);
// 3206
f33216266_432.returns.push(1344872063004);
// 3208
f33216266_432.returns.push(1344872063004);
// 3211
f33216266_432.returns.push(1344872063004);
// 3214
f33216266_432.returns.push(1344872063004);
// 3216
f33216266_432.returns.push(1344872063004);
// 3219
f33216266_432.returns.push(1344872063005);
// 3222
f33216266_432.returns.push(1344872063005);
// 3224
f33216266_432.returns.push(1344872063005);
// 3226
o39 = {};
// 3227
o40 = {};
// 3228
o39.target = o40;
// undefined
o39 = null;
// 3229
o40.getAttribute = f33216266_456;
// 3231
f33216266_456.returns.push(null);
// 3232
o39 = {};
// 3233
o40.parentNode = o39;
// 3234
o39.getAttribute = f33216266_456;
// 3236
f33216266_456.returns.push(null);
// 3237
o41 = {};
// 3238
o39.parentNode = o41;
// undefined
o39 = null;
// 3239
o41.getAttribute = f33216266_456;
// 3241
f33216266_456.returns.push(null);
// 3242
o39 = {};
// 3243
o41.parentNode = o39;
// 3244
o39.getAttribute = f33216266_456;
// 3246
f33216266_456.returns.push(null);
// 3247
o42 = {};
// 3248
o39.parentNode = o42;
// 3249
o42.getAttribute = f33216266_456;
// 3251
f33216266_456.returns.push(null);
// 3252
o43 = {};
// 3253
o42.parentNode = o43;
// 3254
o43.getAttribute = f33216266_456;
// 3256
f33216266_456.returns.push(null);
// 3257
o43.parentNode = o15;
// 3260
f33216266_456.returns.push(null);
// 3264
f33216266_456.returns.push(null);
// 3268
f33216266_456.returns.push(null);
// 3274
f33216266_456.returns.push(null);
// 3278
f33216266_456.returns.push(null);
// 3282
f33216266_456.returns.push(null);
// 3286
f33216266_456.returns.push(null);
// 3290
f33216266_456.returns.push(null);
// 3294
f33216266_456.returns.push(null);
// 3298
f33216266_456.returns.push(null);
// 3302
f33216266_456.returns.push(null);
// 3306
f33216266_456.returns.push(null);
// 3313
o44 = {};
// 3314
o45 = {};
// 3318
o44.length = 1;
// 3319
o44["0"] = "Vitu9";
// 3322
f33216266_432.returns.push(1344872063011);
// 3325
f33216266_432.returns.push(1344872063012);
// 3329
f33216266_432.returns.push(1344872063014);
// 3332
f33216266_432.returns.push(1344872063014);
// 3343
f33216266_432.returns.push(1344872063021);
// 3346
f33216266_432.returns.push(1344872063021);
// 3353
f33216266_432.returns.push(1344872063026);
// 3355
o46 = {};
// 3358
f33216266_432.returns.push(1344872063032);
// 3359
o47 = {};
// 3360
f33216266_4.returns.push(o47);
// 3361
o47.height = "42px";
// undefined
o47 = null;
// 3362
o47 = {};
// 3363
f33216266_4.returns.push(o47);
// 3364
o47.height = "42px";
// undefined
o47 = null;
// 3365
o47 = {};
// 3366
f33216266_4.returns.push(o47);
// 3367
o47.height = "42px";
// undefined
o47 = null;
// 3368
o16.parentNode = o5;
// 3370
f33216266_455.returns.push(o16);
// undefined
o16 = null;
// 3371
o17.parentNode = o5;
// 3373
f33216266_455.returns.push(o17);
// undefined
o17 = null;
// 3374
o18.parentNode = o5;
// 3376
f33216266_455.returns.push(o18);
// undefined
o18 = null;
// 3380
f33216266_432.returns.push(1344872063036);
// 3382
o16 = {};
// 3383
f33216266_450.returns.push(o16);
// 3385
o17 = {};
// 3386
f33216266_450.returns.push(o17);
// 3387
o18 = {};
// 3388
o17.firstChild = o18;
// 3390
o18.nodeType = 8;
// 3392
o18.nodeValue = " <div id=\"megaphone_story_671\" class=\"megaphone_story_wrapper\"><div class=\"megaphone_location_home\"><div class=\"pal megaphone_box\"><div class=\"megaphone_story clearfix\"><a class=\"megaphone_hide_link uiCloseButton\" href=\"#\" role=\"button\" ajaxify=\"/ajax/megaphone/megaphone_hide.php?mp_id=671&amp;location=5&amp;story_elem=megaphone_story_671\" rel=\"async-post\" title=\"Remove\"></a><div class=\"megaphone_content\"><div class=\"clearfix\"><div class=\"pbs\"><span class=\"fsl\"><span class=\"fwb\">You Now Have Timeline</span> — a New Kind of Profile</span></div>Preview your timeline now and make any changes you want before other people see it <span class=\"fwb\">starting August 20</span>.<div class=\"ptm\"><a class=\"uiButton uiButtonConfirm\" href=\"/profile.php\" role=\"button\"><span class=\"uiButtonText\">View Your Timeline</span></a><a class=\"uiButton\" href=\"/help/?page=186325444780109\" role=\"button\"><span class=\"uiButtonText\">Learn More</span></a></div></div></div></div></div></div></div> ";
// undefined
o18 = null;
// 3393
o17.parentNode = o7;
// 3395
f33216266_455.returns.push(o17);
// undefined
o17 = null;
// 3396
// 3397
o16.getAttribute = f33216266_456;
// undefined
o16 = null;
// 3398
f33216266_456.returns.push("pagelet_megaphone");
// 3400
f33216266_432.returns.push(1344872063037);
// 3403
f33216266_432.returns.push(1344872063038);
// 3406
f33216266_432.returns.push(1344872063038);
// 3409
f33216266_432.returns.push(1344872063038);
// 3411
f33216266_432.returns.push(1344872063038);
// 3415
o16 = {};
// 3416
f33216266_441.returns.push(o16);
// 3418
f33216266_443.returns.push(o16);
// undefined
o16 = null;
// 3422
f33216266_432.returns.push(1344872063039);
// 3424
o16 = {};
// 3425
f33216266_450.returns.push(o16);
// 3426
// 3427
o16.getAttribute = f33216266_456;
// undefined
o16 = null;
// 3428
f33216266_456.returns.push("pagelet_messages_data");
// 3431
f33216266_432.returns.push(1344872063043);
// 3435
f33216266_432.returns.push(1344872063045);
// 3438
f33216266_432.returns.push(1344872063045);
// 3441
f33216266_432.returns.push(1344872063046);
// 3444
f33216266_432.returns.push(1344872063046);
// 3446
f33216266_432.returns.push(1344872063046);
// 3456
o16 = {};
// 3457
f33216266_441.returns.push(o16);
// 3459
f33216266_443.returns.push(o16);
// undefined
o16 = null;
// 3463
// undefined
o4 = null;
// 3467
o4 = {};
// 3468
f33216266_441.returns.push(o4);
// 3470
f33216266_443.returns.push(o4);
// undefined
o4 = null;
// 3473
o4 = {};
// 3474
f33216266_0.returns.push(o4);
// 3475
f33216266_664 = function() { return f33216266_664.returns[f33216266_664.inst++]; };
f33216266_664.returns = [];
f33216266_664.inst = 0;
// 3476
o4.getTimezoneOffset = f33216266_664;
// 3477
f33216266_664.returns.push(240);
// 3478
f33216266_665 = function() { return f33216266_665.returns[f33216266_665.inst++]; };
f33216266_665.returns = [];
f33216266_665.inst = 0;
// 3479
o4.getTime = f33216266_665;
// undefined
o4 = null;
// 3480
f33216266_665.returns.push(1344872063050);
// 3484
o4 = {};
// 3485
f33216266_441.returns.push(o4);
// 3487
f33216266_443.returns.push(o4);
// undefined
o4 = null;
// 3491
f33216266_432.returns.push(1344872063051);
// 3493
o7.getElementsByTagName = f33216266_609;
// 3494
f33216266_667 = function() { return f33216266_667.returns[f33216266_667.inst++]; };
f33216266_667.returns = [];
f33216266_667.inst = 0;
// 3495
o0.querySelectorAll = f33216266_667;
// 3496
f33216266_668 = function() { return f33216266_668.returns[f33216266_668.inst++]; };
f33216266_668.returns = [];
f33216266_668.inst = 0;
// 3497
o7.querySelectorAll = f33216266_668;
// 3498
o4 = {};
// 3499
f33216266_668.returns.push(o4);
// 3500
o4.length = 2;
// 3501
o16 = {};
// 3502
o4["0"] = o16;
// 3503
o17 = {};
// 3504
o4["1"] = o17;
// undefined
o4 = null;
// 3505
f33216266_14.returns.push(undefined);
// 3506
f33216266_12.returns.push(57);
// 3510
o4 = {};
// 3511
f33216266_441.returns.push(o4);
// 3513
f33216266_443.returns.push(o4);
// undefined
o4 = null;
// 3515
f33216266_12.returns.push(58);
// 3519
f33216266_7.returns.push(undefined);
// 3520
f33216266_603.returns.push({__JSBNG_unknown_object:true});
// 3524
f33216266_7.returns.push(undefined);
// 3525
f33216266_603.returns.push({__JSBNG_unknown_object:true});
// 3535
o4 = {};
// 3536
f33216266_441.returns.push(o4);
// 3538
o18 = {};
// 3539
f33216266_476.returns.push(o18);
// 3540
// 3541
// 3542
// 3543
// 3544
// 3545
o4.appendChild = f33216266_443;
// 3546
f33216266_443.returns.push(o18);
// undefined
o18 = null;
// 3548
f33216266_443.returns.push(o4);
// undefined
o4 = null;
// 3555
o4 = {};
// 3556
f33216266_441.returns.push(o4);
// 3558
f33216266_443.returns.push(o4);
// undefined
o4 = null;
// 3564
o4 = {};
// 3565
f33216266_441.returns.push(o4);
// 3567
f33216266_443.returns.push(o4);
// undefined
o4 = null;
// 3573
o4 = {};
// 3574
f33216266_441.returns.push(o4);
// 3576
f33216266_443.returns.push(o4);
// undefined
o4 = null;
// 3581
o4 = {};
// 3582
f33216266_441.returns.push(o4);
// 3585
o18 = {};
// 3586
f33216266_476.returns.push(o18);
// 3587
// 3588
// 3589
// 3591
o47 = {};
// 3592
f33216266_476.returns.push(o47);
// 3593
// 3594
o4.appendChild = f33216266_443;
// 3595
f33216266_443.returns.push(o47);
// 3597
f33216266_432.returns.push(1344872063270);
// 3598
f33216266_13.returns.push(59);
// 3600
f33216266_443.returns.push(o18);
// undefined
o18 = null;
// 3602
f33216266_443.returns.push(o4);
// undefined
o4 = null;
// 3608
o4 = {};
// 3609
f33216266_441.returns.push(o4);
// 3611
o18 = {};
// 3612
f33216266_476.returns.push(o18);
// 3613
// 3614
// 3615
// 3616
// 3617
// 3618
o4.appendChild = f33216266_443;
// 3619
f33216266_443.returns.push(o18);
// undefined
o18 = null;
// 3621
f33216266_443.returns.push(o4);
// undefined
o4 = null;
// 3625
o4 = {};
// 3626
f33216266_441.returns.push(o4);
// 3628
f33216266_443.returns.push(o4);
// undefined
o4 = null;
// 3632
f33216266_432.returns.push(1344872063274);
// 3637
o4 = {};
// 3638
f33216266_668.returns.push(o4);
// 3639
o4.length = 2;
// 3640
o4["0"] = o16;
// undefined
o16 = null;
// 3641
o4["1"] = o17;
// undefined
o4 = null;
// undefined
o17 = null;
// 3642
f33216266_14.returns.push(undefined);
// 3643
f33216266_12.returns.push(60);
// 3647
o4 = {};
// 3648
f33216266_441.returns.push(o4);
// 3650
f33216266_443.returns.push(o4);
// undefined
o4 = null;
// 3659
o4 = {};
// 3660
f33216266_441.returns.push(o4);
// 3662
f33216266_443.returns.push(o4);
// undefined
o4 = null;
// 3681
o4 = {};
// 3682
f33216266_441.returns.push(o4);
// 3684
f33216266_443.returns.push(o4);
// undefined
o4 = null;
// 3686
f33216266_432.returns.push(1344872063282);
// 3690
o4 = {};
// 3691
o16 = {};
// 3696
o4.length = 1;
// 3697
o4["0"] = "J9ZDd";
// 3703
o17 = {};
// 3704
f33216266_668.returns.push(o17);
// 3705
o17.length = 4;
// 3706
o18 = {};
// 3707
o17["0"] = o18;
// 3708
o48 = {};
// 3709
o17["1"] = o48;
// 3710
o49 = {};
// 3711
o17["2"] = o49;
// 3712
o50 = {};
// 3713
o17["3"] = o50;
// undefined
o17 = null;
// 3714
o18.link_data = void 0;
// 3715
o18.getAttribute = f33216266_456;
// 3717
f33216266_456.returns.push(null);
// 3720
f33216266_456.returns.push(null);
// 3721
o17 = {};
// 3722
o18.parentNode = o17;
// 3723
o17.getAttribute = f33216266_456;
// 3725
f33216266_456.returns.push(null);
// 3728
f33216266_456.returns.push(null);
// 3729
o51 = {};
// 3730
o17.parentNode = o51;
// 3731
o51.getAttribute = f33216266_456;
// 3733
f33216266_456.returns.push(null);
// 3736
f33216266_456.returns.push(null);
// 3737
o52 = {};
// 3738
o51.parentNode = o52;
// 3739
o52.getAttribute = f33216266_456;
// 3741
f33216266_456.returns.push(null);
// 3744
f33216266_456.returns.push(null);
// 3745
o52.parentNode = o12;
// 3746
o12.getAttribute = f33216266_456;
// 3748
f33216266_456.returns.push("{\"qid\":\"5776181494237290802\",\"mf_story_key\":\"-4571705487949635972\"}");
// 3751
f33216266_456.returns.push(null);
// 3752
o12.parentNode = o9;
// undefined
o12 = null;
// 3755
f33216266_456.returns.push(null);
// 3758
f33216266_456.returns.push(null);
// 3759
o12 = {};
// 3760
o9.parentNode = o12;
// 3761
o12.getAttribute = f33216266_456;
// 3763
f33216266_456.returns.push(null);
// 3766
f33216266_456.returns.push(null);
// 3767
o12.parentNode = o6;
// undefined
o12 = null;
// 3770
f33216266_456.returns.push(null);
// 3773
f33216266_456.returns.push(null);
// 3774
o6.parentNode = o40;
// undefined
o6 = null;
// undefined
o40 = null;
// 3777
f33216266_456.returns.push(null);
// 3780
f33216266_456.returns.push(null);
// 3784
f33216266_456.returns.push(null);
// 3787
f33216266_456.returns.push(null);
// 3791
f33216266_456.returns.push(null);
// 3794
f33216266_456.returns.push(null);
// 3798
f33216266_456.returns.push(null);
// 3801
f33216266_456.returns.push(null);
// 3805
f33216266_456.returns.push(null);
// 3808
f33216266_456.returns.push(null);
// 3812
f33216266_456.returns.push(null);
// 3815
f33216266_456.returns.push(null);
// 3819
f33216266_456.returns.push(null);
// 3822
f33216266_456.returns.push(null);
// 3826
f33216266_456.returns.push(null);
// 3829
f33216266_456.returns.push(null);
// 3833
f33216266_456.returns.push(null);
// 3836
f33216266_456.returns.push(null);
// 3842
o6 = {};
// 3843
f33216266_476.returns.push(o6);
// 3844
// 3845
o6.setAttribute = f33216266_480;
// 3847
f33216266_480.returns.push(undefined);
// 3850
f33216266_480.returns.push(undefined);
// 3851
o18.appendChild = f33216266_443;
// undefined
o18 = null;
// 3852
f33216266_443.returns.push(o6);
// undefined
o6 = null;
// 3853
o48.link_data = void 0;
// 3854
o48.getAttribute = f33216266_456;
// 3856
f33216266_456.returns.push(null);
// 3859
f33216266_456.returns.push(null);
// 3860
o6 = {};
// 3861
o48.parentNode = o6;
// 3862
o6.getAttribute = f33216266_456;
// 3864
f33216266_456.returns.push(null);
// 3867
f33216266_456.returns.push(null);
// 3868
o12 = {};
// 3869
o6.parentNode = o12;
// undefined
o6 = null;
// 3870
o12.getAttribute = f33216266_456;
// 3872
f33216266_456.returns.push(null);
// 3875
f33216266_456.returns.push(null);
// 3876
o6 = {};
// 3877
o12.parentNode = o6;
// undefined
o12 = null;
// 3878
o6.getAttribute = f33216266_456;
// 3880
f33216266_456.returns.push(null);
// 3883
f33216266_456.returns.push(null);
// 3884
o6.parentNode = o10;
// undefined
o6 = null;
// 3885
o10.getAttribute = f33216266_456;
// 3887
f33216266_456.returns.push("{\"qid\":\"5776181494237290802\",\"mf_story_key\":\"8438955046610351598\"}");
// 3890
f33216266_456.returns.push(null);
// 3891
o10.parentNode = o9;
// undefined
o10 = null;
// 3894
f33216266_456.returns.push(null);
// 3897
f33216266_456.returns.push(null);
// 3901
f33216266_456.returns.push(null);
// 3904
f33216266_456.returns.push(null);
// 3908
f33216266_456.returns.push(null);
// 3911
f33216266_456.returns.push(null);
// 3915
f33216266_456.returns.push(null);
// 3918
f33216266_456.returns.push(null);
// 3922
f33216266_456.returns.push(null);
// 3925
f33216266_456.returns.push(null);
// 3929
f33216266_456.returns.push(null);
// 3932
f33216266_456.returns.push(null);
// 3936
f33216266_456.returns.push(null);
// 3939
f33216266_456.returns.push(null);
// 3943
f33216266_456.returns.push(null);
// 3946
f33216266_456.returns.push(null);
// 3950
f33216266_456.returns.push(null);
// 3953
f33216266_456.returns.push(null);
// 3957
f33216266_456.returns.push(null);
// 3960
f33216266_456.returns.push(null);
// 3964
f33216266_456.returns.push(null);
// 3967
f33216266_456.returns.push(null);
// 3971
f33216266_456.returns.push(null);
// 3974
f33216266_456.returns.push(null);
// 3980
o6 = {};
// 3981
f33216266_476.returns.push(o6);
// 3982
// 3983
o6.setAttribute = f33216266_480;
// 3985
f33216266_480.returns.push(undefined);
// 3988
f33216266_480.returns.push(undefined);
// 3989
o48.appendChild = f33216266_443;
// undefined
o48 = null;
// 3990
f33216266_443.returns.push(o6);
// undefined
o6 = null;
// 3991
o49.link_data = void 0;
// 3992
o49.getAttribute = f33216266_456;
// 3994
f33216266_456.returns.push(null);
// 3997
f33216266_456.returns.push(null);
// 3998
o6 = {};
// 3999
o49.parentNode = o6;
// 4000
o6.getAttribute = f33216266_456;
// 4002
f33216266_456.returns.push(null);
// 4005
f33216266_456.returns.push(null);
// 4006
o10 = {};
// 4007
o6.parentNode = o10;
// undefined
o6 = null;
// 4008
o10.getAttribute = f33216266_456;
// 4010
f33216266_456.returns.push(null);
// 4013
f33216266_456.returns.push(null);
// 4014
o6 = {};
// 4015
o10.parentNode = o6;
// undefined
o10 = null;
// 4016
o6.getAttribute = f33216266_456;
// 4018
f33216266_456.returns.push(null);
// 4021
f33216266_456.returns.push(null);
// 4022
o10 = {};
// 4023
o6.parentNode = o10;
// undefined
o6 = null;
// 4024
o10.getAttribute = f33216266_456;
// 4026
f33216266_456.returns.push("{\"tn\":\"U\"}");
// 4029
f33216266_456.returns.push(null);
// 4030
o6 = {};
// 4031
o10.parentNode = o6;
// undefined
o10 = null;
// 4032
o6.getAttribute = f33216266_456;
// 4034
f33216266_456.returns.push(null);
// 4037
f33216266_456.returns.push(null);
// 4038
o10 = {};
// 4039
o6.parentNode = o10;
// undefined
o6 = null;
// 4040
o10.getAttribute = f33216266_456;
// 4042
f33216266_456.returns.push(null);
// 4045
f33216266_456.returns.push(null);
// 4046
o6 = {};
// 4047
o10.parentNode = o6;
// undefined
o10 = null;
// 4048
o6.getAttribute = f33216266_456;
// 4050
f33216266_456.returns.push(null);
// 4053
f33216266_456.returns.push(null);
// 4054
o10 = {};
// 4055
o6.parentNode = o10;
// undefined
o6 = null;
// 4056
o10.getAttribute = f33216266_456;
// 4058
f33216266_456.returns.push(null);
// 4061
f33216266_456.returns.push(null);
// 4062
o10.parentNode = o13;
// undefined
o10 = null;
// 4063
o13.getAttribute = f33216266_456;
// 4065
f33216266_456.returns.push("{\"qid\":\"5776181494237290802\",\"mf_story_key\":\"6023853588764622143\"}");
// 4068
f33216266_456.returns.push(null);
// 4069
o13.parentNode = o9;
// undefined
o13 = null;
// 4072
f33216266_456.returns.push(null);
// 4075
f33216266_456.returns.push(null);
// 4079
f33216266_456.returns.push(null);
// 4082
f33216266_456.returns.push(null);
// 4086
f33216266_456.returns.push(null);
// 4089
f33216266_456.returns.push(null);
// 4093
f33216266_456.returns.push(null);
// 4096
f33216266_456.returns.push(null);
// 4100
f33216266_456.returns.push(null);
// 4103
f33216266_456.returns.push(null);
// 4107
f33216266_456.returns.push(null);
// 4110
f33216266_456.returns.push(null);
// 4114
f33216266_456.returns.push(null);
// 4117
f33216266_456.returns.push(null);
// 4121
f33216266_456.returns.push(null);
// 4124
f33216266_456.returns.push(null);
// 4128
f33216266_456.returns.push(null);
// 4131
f33216266_456.returns.push(null);
// 4135
f33216266_456.returns.push(null);
// 4138
f33216266_456.returns.push(null);
// 4142
f33216266_456.returns.push(null);
// 4145
f33216266_456.returns.push(null);
// 4149
f33216266_456.returns.push(null);
// 4152
f33216266_456.returns.push(null);
// 4158
o6 = {};
// 4159
f33216266_476.returns.push(o6);
// 4160
// 4161
o6.setAttribute = f33216266_480;
// 4163
f33216266_480.returns.push(undefined);
// 4166
f33216266_480.returns.push(undefined);
// 4167
o49.appendChild = f33216266_443;
// undefined
o49 = null;
// 4168
f33216266_443.returns.push(o6);
// undefined
o6 = null;
// 4169
o50.link_data = void 0;
// 4170
o50.getAttribute = f33216266_456;
// 4172
f33216266_456.returns.push(null);
// 4175
f33216266_456.returns.push(null);
// 4176
o6 = {};
// 4177
o50.parentNode = o6;
// 4178
o6.getAttribute = f33216266_456;
// 4180
f33216266_456.returns.push(null);
// 4183
f33216266_456.returns.push(null);
// 4184
o10 = {};
// 4185
o6.parentNode = o10;
// undefined
o6 = null;
// 4186
o10.getAttribute = f33216266_456;
// 4188
f33216266_456.returns.push(null);
// 4191
f33216266_456.returns.push(null);
// 4192
o6 = {};
// 4193
o10.parentNode = o6;
// undefined
o10 = null;
// 4194
o6.getAttribute = f33216266_456;
// 4196
f33216266_456.returns.push(null);
// 4199
f33216266_456.returns.push(null);
// 4200
o10 = {};
// 4201
o6.parentNode = o10;
// undefined
o6 = null;
// 4202
o10.getAttribute = f33216266_456;
// 4204
f33216266_456.returns.push("{\"tn\":\"U\"}");
// 4207
f33216266_456.returns.push(null);
// 4208
o6 = {};
// 4209
o10.parentNode = o6;
// undefined
o10 = null;
// 4210
o6.getAttribute = f33216266_456;
// 4212
f33216266_456.returns.push(null);
// 4215
f33216266_456.returns.push(null);
// 4216
o10 = {};
// 4217
o6.parentNode = o10;
// undefined
o6 = null;
// 4218
o10.getAttribute = f33216266_456;
// 4220
f33216266_456.returns.push(null);
// 4223
f33216266_456.returns.push(null);
// 4224
o6 = {};
// 4225
o10.parentNode = o6;
// undefined
o10 = null;
// 4226
o6.getAttribute = f33216266_456;
// 4228
f33216266_456.returns.push(null);
// 4231
f33216266_456.returns.push(null);
// 4232
o10 = {};
// 4233
o6.parentNode = o10;
// undefined
o6 = null;
// 4234
o10.getAttribute = f33216266_456;
// 4236
f33216266_456.returns.push(null);
// 4239
f33216266_456.returns.push(null);
// 4240
o10.parentNode = o19;
// undefined
o10 = null;
// 4241
o19.getAttribute = f33216266_456;
// 4243
f33216266_456.returns.push("{\"qid\":\"5776181494237290802\",\"mf_story_key\":\"8878831909009365538\"}");
// 4246
f33216266_456.returns.push(null);
// 4247
o19.parentNode = o9;
// undefined
o19 = null;
// undefined
o9 = null;
// 4250
f33216266_456.returns.push(null);
// 4253
f33216266_456.returns.push(null);
// 4257
f33216266_456.returns.push(null);
// 4260
f33216266_456.returns.push(null);
// 4264
f33216266_456.returns.push(null);
// 4267
f33216266_456.returns.push(null);
// 4271
f33216266_456.returns.push(null);
// 4274
f33216266_456.returns.push(null);
// 4278
f33216266_456.returns.push(null);
// 4281
f33216266_456.returns.push(null);
// 4285
f33216266_456.returns.push(null);
// 4288
f33216266_456.returns.push(null);
// 4292
f33216266_456.returns.push(null);
// 4295
f33216266_456.returns.push(null);
// 4299
f33216266_456.returns.push(null);
// 4302
f33216266_456.returns.push(null);
// 4306
f33216266_456.returns.push(null);
// 4309
f33216266_456.returns.push(null);
// 4313
f33216266_456.returns.push(null);
// 4316
f33216266_456.returns.push(null);
// 4320
f33216266_456.returns.push(null);
// 4323
f33216266_456.returns.push(null);
// 4327
f33216266_456.returns.push(null);
// 4330
f33216266_456.returns.push(null);
// 4336
o6 = {};
// 4337
f33216266_476.returns.push(o6);
// 4338
// 4339
o6.setAttribute = f33216266_480;
// 4341
f33216266_480.returns.push(undefined);
// 4344
f33216266_480.returns.push(undefined);
// 4345
o50.appendChild = f33216266_443;
// undefined
o50 = null;
// 4346
f33216266_443.returns.push(o6);
// undefined
o6 = null;
// 4351
o6 = {};
// 4352
o9 = {};
// 4355
o6.length = 1;
// 4356
o6["0"] = "1vNpf";
// 4360
f33216266_432.returns.push(1344872063384);
// 4361
o10 = {};
// 4362
f33216266_4.returns.push(o10);
// 4363
o10.height = "42px";
// undefined
o10 = null;
// 4364
o47.parentNode = o5;
// undefined
o5 = null;
// 4366
f33216266_455.returns.push(o47);
// undefined
o47 = null;
// 4369
f33216266_432.returns.push(1344872063387);
// 4370
f33216266_15.returns.push(undefined);
// 4373
f33216266_432.returns.push(1344872063447);
// 4374
f33216266_15.returns.push(undefined);
// 4376
f33216266_432.returns.push(1344872063448);
// 4377
f33216266_15.returns.push(undefined);
// 4382
// 4383
f33216266_430.returns.push(0.6675583785399795);
// 4384
o5 = {};
// 4385
f33216266_75.returns.push(o5);
// 4386
f33216266_430.returns.push(0.9595616187434644);
// 4387
// undefined
o5 = null;
// 4388
o5 = {};
// 4389
o5._inherits_from_prototype = "true";
// 4390
o5.type = "mouseover";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 4396
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 4399
f33216266_432.returns.push(1344872063628);
// 4400
o5.cancelBubble = "false";
// 4402
f33216266_623.returns.push(undefined);
// 4404
o5.returnValue = "true";
// 4405
o5.target = o51;
// undefined
o5 = null;
// undefined
o51 = null;
// 4408
f33216266_456.returns.push(null);
// 4412
f33216266_456.returns.push(null);
// 4416
f33216266_456.returns.push(null);
// 4420
f33216266_456.returns.push(null);
// 4424
f33216266_456.returns.push(null);
// 4428
f33216266_456.returns.push(null);
// 4432
f33216266_456.returns.push(null);
// 4436
f33216266_456.returns.push(null);
// 4440
f33216266_456.returns.push(null);
// 4444
f33216266_456.returns.push(null);
// 4448
f33216266_456.returns.push(null);
// 4452
f33216266_456.returns.push(null);
// 4456
f33216266_456.returns.push(null);
// 4460
f33216266_456.returns.push(null);
// 4464
f33216266_456.returns.push(null);
// 4470
f33216266_456.returns.push(null);
// 4474
f33216266_456.returns.push(null);
// 4478
f33216266_456.returns.push(null);
// 4482
f33216266_456.returns.push(null);
// 4486
f33216266_456.returns.push(null);
// 4490
f33216266_456.returns.push(null);
// 4494
f33216266_456.returns.push(null);
// 4498
f33216266_456.returns.push(null);
// 4502
f33216266_456.returns.push(null);
// 4506
f33216266_456.returns.push(null);
// 4510
f33216266_456.returns.push(null);
// 4514
f33216266_456.returns.push(null);
// 4518
f33216266_456.returns.push(null);
// 4522
f33216266_456.returns.push(null);
// 4526
f33216266_456.returns.push(null);
// 4530
o5 = {};
// 4531
o5._inherits_from_prototype = "true";
// 4532
o5.type = "mouseover";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 4538
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 4541
f33216266_432.returns.push(1344872063649);
// 4542
o5.cancelBubble = "false";
// 4544
f33216266_623.returns.push(undefined);
// 4546
o5.returnValue = "true";
// 4547
o10 = {};
// 4548
o5.target = o10;
// undefined
o5 = null;
// 4549
o10.getAttribute = f33216266_456;
// 4551
f33216266_456.returns.push(null);
// 4552
o10.parentNode = o17;
// undefined
o10 = null;
// 4555
f33216266_456.returns.push(null);
// 4559
f33216266_456.returns.push(null);
// 4563
f33216266_456.returns.push(null);
// 4567
f33216266_456.returns.push(null);
// 4571
f33216266_456.returns.push(null);
// 4575
f33216266_456.returns.push(null);
// 4579
f33216266_456.returns.push(null);
// 4583
f33216266_456.returns.push(null);
// 4587
f33216266_456.returns.push(null);
// 4591
f33216266_456.returns.push(null);
// 4595
f33216266_456.returns.push(null);
// 4599
f33216266_456.returns.push(null);
// 4603
f33216266_456.returns.push(null);
// 4607
f33216266_456.returns.push(null);
// 4611
f33216266_456.returns.push(null);
// 4615
f33216266_456.returns.push(null);
// 4621
f33216266_456.returns.push(null);
// 4625
f33216266_456.returns.push(null);
// 4629
f33216266_456.returns.push(null);
// 4633
f33216266_456.returns.push(null);
// 4637
f33216266_456.returns.push(null);
// 4641
f33216266_456.returns.push(null);
// 4645
f33216266_456.returns.push(null);
// 4649
f33216266_456.returns.push(null);
// 4653
f33216266_456.returns.push(null);
// 4657
f33216266_456.returns.push(null);
// 4661
f33216266_456.returns.push(null);
// 4665
f33216266_456.returns.push(null);
// 4669
f33216266_456.returns.push(null);
// 4673
f33216266_456.returns.push(null);
// 4677
f33216266_456.returns.push(null);
// 4681
f33216266_456.returns.push(null);
// 4685
f33216266_456.returns.push(null);
// 4689
o5 = {};
// 4690
o5._inherits_from_prototype = "true";
// 4691
o5.type = "mouseover";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 4697
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 4700
f33216266_432.returns.push(1344872063706);
// 4701
o5.cancelBubble = "false";
// 4703
f33216266_623.returns.push(undefined);
// 4705
o5.returnValue = "true";
// 4706
o5.target = o17;
// undefined
o5 = null;
// 4709
f33216266_456.returns.push(null);
// 4713
f33216266_456.returns.push(null);
// 4717
f33216266_456.returns.push(null);
// 4721
f33216266_456.returns.push(null);
// 4725
f33216266_456.returns.push(null);
// 4729
f33216266_456.returns.push(null);
// 4733
f33216266_456.returns.push(null);
// 4737
f33216266_456.returns.push(null);
// 4741
f33216266_456.returns.push(null);
// 4745
f33216266_456.returns.push(null);
// 4749
f33216266_456.returns.push(null);
// 4753
f33216266_456.returns.push(null);
// 4757
f33216266_456.returns.push(null);
// 4761
f33216266_456.returns.push(null);
// 4765
f33216266_456.returns.push(null);
// 4769
f33216266_456.returns.push(null);
// 4775
f33216266_456.returns.push(null);
// 4779
f33216266_456.returns.push(null);
// 4783
f33216266_456.returns.push(null);
// 4787
f33216266_456.returns.push(null);
// 4791
f33216266_456.returns.push(null);
// 4795
f33216266_456.returns.push(null);
// 4799
f33216266_456.returns.push(null);
// 4803
f33216266_456.returns.push(null);
// 4807
f33216266_456.returns.push(null);
// 4811
f33216266_456.returns.push(null);
// 4815
f33216266_456.returns.push(null);
// 4819
f33216266_456.returns.push(null);
// 4823
f33216266_456.returns.push(null);
// 4827
f33216266_456.returns.push(null);
// 4831
f33216266_456.returns.push(null);
// 4835
f33216266_456.returns.push(null);
// 4839
o5 = {};
// 4840
o5._inherits_from_prototype = "true";
// 4841
o5.type = "mouseover";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 4847
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 4850
f33216266_432.returns.push(1344872063752);
// 4851
o5.cancelBubble = "false";
// 4853
f33216266_623.returns.push(undefined);
// 4855
o5.returnValue = "true";
// 4856
o10 = {};
// 4857
o5.target = o10;
// undefined
o5 = null;
// 4858
o10.getAttribute = f33216266_456;
// 4860
f33216266_456.returns.push(null);
// 4861
o5 = {};
// 4862
o10.parentNode = o5;
// undefined
o10 = null;
// 4863
o5.getAttribute = f33216266_456;
// 4865
f33216266_456.returns.push(null);
// 4866
o10 = {};
// 4867
o5.parentNode = o10;
// undefined
o5 = null;
// 4868
o10.getAttribute = f33216266_456;
// 4870
f33216266_456.returns.push(null);
// 4871
o10.parentNode = o17;
// undefined
o10 = null;
// undefined
o17 = null;
// 4874
f33216266_456.returns.push(null);
// 4878
f33216266_456.returns.push(null);
// 4882
f33216266_456.returns.push(null);
// 4886
f33216266_456.returns.push(null);
// 4890
f33216266_456.returns.push(null);
// 4894
f33216266_456.returns.push(null);
// 4898
f33216266_456.returns.push(null);
// 4902
f33216266_456.returns.push(null);
// 4906
f33216266_456.returns.push(null);
// 4910
f33216266_456.returns.push(null);
// 4914
f33216266_456.returns.push(null);
// 4918
f33216266_456.returns.push(null);
// 4922
f33216266_456.returns.push(null);
// 4926
f33216266_456.returns.push(null);
// 4930
f33216266_456.returns.push(null);
// 4934
f33216266_456.returns.push(null);
// 4940
f33216266_456.returns.push(null);
// 4944
f33216266_456.returns.push(null);
// 4948
f33216266_456.returns.push(null);
// 4952
f33216266_456.returns.push(null);
// 4956
f33216266_456.returns.push(null);
// 4960
f33216266_456.returns.push(null);
// 4964
f33216266_456.returns.push(null);
// 4968
f33216266_456.returns.push(null);
// 4972
f33216266_456.returns.push(null);
// 4976
f33216266_456.returns.push(null);
// 4980
f33216266_456.returns.push(null);
// 4984
f33216266_456.returns.push(null);
// 4988
f33216266_456.returns.push(null);
// 4992
f33216266_456.returns.push(null);
// 4996
f33216266_456.returns.push(null);
// 5000
f33216266_456.returns.push(null);
// 5004
f33216266_456.returns.push(null);
// 5008
f33216266_456.returns.push(null);
// 5012
f33216266_456.returns.push(null);
// 5016
o5 = {};
// 5017
o5._inherits_from_prototype = "true";
// 5018
o5.type = "mouseover";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 5024
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 5027
f33216266_432.returns.push(1344872063772);
// 5028
o5.cancelBubble = "false";
// 5030
f33216266_623.returns.push(undefined);
// 5032
o5.returnValue = "true";
// 5033
o5.target = o52;
// undefined
o5 = null;
// undefined
o52 = null;
// 5036
f33216266_456.returns.push(null);
// 5040
f33216266_456.returns.push(null);
// 5044
f33216266_456.returns.push(null);
// 5048
f33216266_456.returns.push(null);
// 5052
f33216266_456.returns.push(null);
// 5056
f33216266_456.returns.push(null);
// 5060
f33216266_456.returns.push(null);
// 5064
f33216266_456.returns.push(null);
// 5068
f33216266_456.returns.push(null);
// 5072
f33216266_456.returns.push(null);
// 5076
f33216266_456.returns.push(null);
// 5080
f33216266_456.returns.push(null);
// 5084
f33216266_456.returns.push(null);
// 5088
f33216266_456.returns.push(null);
// 5094
f33216266_456.returns.push(null);
// 5098
f33216266_456.returns.push(null);
// 5102
f33216266_456.returns.push(null);
// 5106
f33216266_456.returns.push(null);
// 5110
f33216266_456.returns.push(null);
// 5114
f33216266_456.returns.push(null);
// 5118
f33216266_456.returns.push(null);
// 5122
f33216266_456.returns.push(null);
// 5126
f33216266_456.returns.push(null);
// 5130
f33216266_456.returns.push(null);
// 5134
f33216266_456.returns.push(null);
// 5138
f33216266_456.returns.push(null);
// 5142
f33216266_456.returns.push(null);
// 5146
f33216266_456.returns.push(null);
// 5150
o5 = {};
// 5151
o5._inherits_from_prototype = "true";
// 5152
o5.type = "mouseover";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 5158
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 5161
f33216266_432.returns.push(1344872063791);
// 5162
o5.cancelBubble = "false";
// 5164
f33216266_623.returns.push(undefined);
// 5166
o5.returnValue = "true";
// 5167
o10 = {};
// 5168
o5.target = o10;
// undefined
o5 = null;
// 5169
o10.getAttribute = f33216266_456;
// 5171
f33216266_456.returns.push(null);
// 5172
o5 = {};
// 5173
o10.parentNode = o5;
// undefined
o10 = null;
// 5174
o5.getAttribute = f33216266_456;
// 5176
f33216266_456.returns.push(null);
// 5177
o10 = {};
// 5178
o5.parentNode = o10;
// undefined
o5 = null;
// 5179
o10.getAttribute = f33216266_456;
// 5181
f33216266_456.returns.push(null);
// 5182
o5 = {};
// 5183
o10.parentNode = o5;
// 5184
o5.getAttribute = f33216266_456;
// 5186
f33216266_456.returns.push(null);
// 5187
o12 = {};
// 5188
o5.parentNode = o12;
// undefined
o5 = null;
// 5189
o12.getAttribute = f33216266_456;
// 5191
f33216266_456.returns.push(null);
// 5192
o5 = {};
// 5193
o12.parentNode = o5;
// undefined
o12 = null;
// 5194
o5.getAttribute = f33216266_456;
// 5196
f33216266_456.returns.push(null);
// 5197
o12 = {};
// 5198
o5.parentNode = o12;
// undefined
o5 = null;
// 5199
o12.getAttribute = f33216266_456;
// 5201
f33216266_456.returns.push(null);
// 5202
o12.parentNode = o8;
// 5205
f33216266_456.returns.push(null);
// 5206
o8.parentNode = o21;
// undefined
o8 = null;
// 5207
o21.getAttribute = f33216266_456;
// 5209
f33216266_456.returns.push(null);
// 5210
o21.parentNode = o3;
// undefined
o21 = null;
// 5213
f33216266_456.returns.push(null);
// 5214
o5 = {};
// 5215
o3.parentNode = o5;
// undefined
o3 = null;
// 5216
o5.getAttribute = f33216266_456;
// 5218
f33216266_456.returns.push(null);
// 5219
o3 = {};
// 5220
o5.parentNode = o3;
// undefined
o5 = null;
// 5221
o3.getAttribute = f33216266_456;
// 5223
f33216266_456.returns.push(null);
// 5224
o3.parentNode = o41;
// undefined
o3 = null;
// 5227
f33216266_456.returns.push(null);
// 5231
f33216266_456.returns.push(null);
// 5235
f33216266_456.returns.push(null);
// 5239
f33216266_456.returns.push(null);
// 5243
f33216266_456.returns.push(null);
// 5247
f33216266_456.returns.push(null);
// 5251
f33216266_456.returns.push(null);
// 5257
f33216266_456.returns.push(null);
// 5261
f33216266_456.returns.push(null);
// 5265
f33216266_456.returns.push(null);
// 5269
f33216266_456.returns.push(null);
// 5273
f33216266_456.returns.push(null);
// 5277
f33216266_456.returns.push(null);
// 5281
f33216266_456.returns.push(null);
// 5285
f33216266_456.returns.push(null);
// 5289
f33216266_456.returns.push(null);
// 5293
f33216266_456.returns.push(null);
// 5297
f33216266_456.returns.push(null);
// 5301
f33216266_456.returns.push(null);
// 5305
f33216266_456.returns.push(null);
// 5309
f33216266_456.returns.push(null);
// 5313
f33216266_456.returns.push(null);
// 5317
f33216266_456.returns.push(null);
// 5321
f33216266_456.returns.push(null);
// 5325
f33216266_456.returns.push(null);
// 5329
f33216266_456.returns.push(null);
// 5333
o3 = {};
// 5334
o3._inherits_from_prototype = "true";
// 5335
o3.type = "mouseover";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 5341
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 5344
f33216266_432.returns.push(1344872063806);
// 5345
o3.cancelBubble = "false";
// 5347
f33216266_623.returns.push(undefined);
// 5349
o3.returnValue = "true";
// 5350
o3.target = o10;
// undefined
o3 = null;
// undefined
o10 = null;
// 5353
f33216266_456.returns.push(null);
// 5357
f33216266_456.returns.push(null);
// 5361
f33216266_456.returns.push(null);
// 5365
f33216266_456.returns.push(null);
// 5369
f33216266_456.returns.push(null);
// 5373
f33216266_456.returns.push(null);
// 5377
f33216266_456.returns.push(null);
// 5381
f33216266_456.returns.push(null);
// 5385
f33216266_456.returns.push(null);
// 5389
f33216266_456.returns.push(null);
// 5393
f33216266_456.returns.push(null);
// 5397
f33216266_456.returns.push(null);
// 5401
f33216266_456.returns.push(null);
// 5405
f33216266_456.returns.push(null);
// 5409
f33216266_456.returns.push(null);
// 5413
f33216266_456.returns.push(null);
// 5417
f33216266_456.returns.push(null);
// 5423
f33216266_456.returns.push(null);
// 5427
f33216266_456.returns.push(null);
// 5431
f33216266_456.returns.push(null);
// 5435
f33216266_456.returns.push(null);
// 5439
f33216266_456.returns.push(null);
// 5443
f33216266_456.returns.push(null);
// 5447
f33216266_456.returns.push(null);
// 5451
f33216266_456.returns.push(null);
// 5455
f33216266_456.returns.push(null);
// 5459
f33216266_456.returns.push(null);
// 5463
f33216266_456.returns.push(null);
// 5467
f33216266_456.returns.push(null);
// 5471
f33216266_456.returns.push(null);
// 5475
f33216266_456.returns.push(null);
// 5479
f33216266_456.returns.push(null);
// 5483
f33216266_456.returns.push(null);
// 5487
f33216266_456.returns.push(null);
// 5491
o3 = {};
// 5492
o3._inherits_from_prototype = "true";
// 5493
o3.type = "mouseover";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 5499
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 5502
f33216266_432.returns.push(1344872063818);
// 5503
o3.cancelBubble = "false";
// 5505
f33216266_623.returns.push(undefined);
// 5507
o3.returnValue = "true";
// 5508
o3.target = o12;
// undefined
o3 = null;
// undefined
o12 = null;
// 5511
f33216266_456.returns.push(null);
// 5515
f33216266_456.returns.push(null);
// 5519
f33216266_456.returns.push(null);
// 5523
f33216266_456.returns.push(null);
// 5527
f33216266_456.returns.push(null);
// 5531
f33216266_456.returns.push(null);
// 5535
f33216266_456.returns.push(null);
// 5539
f33216266_456.returns.push(null);
// 5543
f33216266_456.returns.push(null);
// 5547
f33216266_456.returns.push(null);
// 5551
f33216266_456.returns.push(null);
// 5555
f33216266_456.returns.push(null);
// 5559
f33216266_456.returns.push(null);
// 5565
f33216266_456.returns.push(null);
// 5569
f33216266_456.returns.push(null);
// 5573
f33216266_456.returns.push(null);
// 5577
f33216266_456.returns.push(null);
// 5581
f33216266_456.returns.push(null);
// 5585
f33216266_456.returns.push(null);
// 5589
f33216266_456.returns.push(null);
// 5593
f33216266_456.returns.push(null);
// 5597
f33216266_456.returns.push(null);
// 5601
f33216266_456.returns.push(null);
// 5605
f33216266_456.returns.push(null);
// 5609
f33216266_456.returns.push(null);
// 5613
f33216266_456.returns.push(null);
// 5617
o3 = {};
// 5618
o3._inherits_from_prototype = "true";
// 5619
o3.type = "mouseover";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 5625
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 5628
f33216266_432.returns.push(1344872063825);
// 5629
o3.cancelBubble = "false";
// 5631
f33216266_623.returns.push(undefined);
// 5633
o3.returnValue = "true";
// 5634
o3.target = o15;
// undefined
o3 = null;
// 5637
f33216266_456.returns.push(null);
// 5641
f33216266_456.returns.push(null);
// 5645
f33216266_456.returns.push(null);
// 5651
f33216266_456.returns.push(null);
// 5655
f33216266_456.returns.push(null);
// 5659
f33216266_456.returns.push(null);
// 5663
o3 = {};
// 5664
o3.scan_count = 0;
// 5665
f33216266_749 = function() { return f33216266_749.returns[f33216266_749.inst++]; };
f33216266_749.returns = [];
f33216266_749.inst = 0;
// 5666
o3.checkAdwareElements = f33216266_749;
// 5667
o5 = {};
// 5668
o3.adware_elements = o5;
// 5669
f33216266_751 = function() { return f33216266_751.returns[f33216266_751.inst++]; };
f33216266_751.returns = [];
f33216266_751.inst = 0;
// 5670
o5.contains = f33216266_751;
// 5671
f33216266_751.length = 1;
// 5672
f33216266_751["0"] = void 0;
// 5674
f33216266_752 = function() { return f33216266_752.returns[f33216266_752.inst++]; };
f33216266_752.returns = [];
f33216266_752.inst = 0;
// 5675
o5.remove = f33216266_752;
// undefined
o5 = null;
// 5676
f33216266_752.length = 1;
// 5677
f33216266_752["0"] = void 0;
// 5679
f33216266_749.returns.push(undefined);
// 5680
o3.fb_domains = null;
// undefined
o3 = null;
// 5682
o3 = {};
// 5683
o3._inherits_from_prototype = "true";
// 5684
o3.type = "mouseover";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 5690
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 5693
f33216266_432.returns.push(1344872064267);
// 5694
o3.cancelBubble = "false";
// 5696
f33216266_623.returns.push(undefined);
// 5698
o3.returnValue = "true";
// 5699
o3.target = o41;
// undefined
o3 = null;
// 5702
f33216266_456.returns.push(null);
// 5706
f33216266_456.returns.push(null);
// 5710
f33216266_456.returns.push(null);
// 5714
f33216266_456.returns.push(null);
// 5718
f33216266_456.returns.push(null);
// 5722
f33216266_456.returns.push(null);
// 5726
f33216266_456.returns.push(null);
// 5732
f33216266_456.returns.push(null);
// 5736
f33216266_456.returns.push(null);
// 5740
f33216266_456.returns.push(null);
// 5744
f33216266_456.returns.push(null);
// 5748
f33216266_456.returns.push(null);
// 5752
f33216266_456.returns.push(null);
// 5756
f33216266_456.returns.push(null);
// 5760
o3 = {};
// 5761
o3._inherits_from_prototype = "true";
// 5762
o3.type = "mousedown";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 5768
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 5770
f33216266_755 = function() { return f33216266_755.returns[f33216266_755.inst++]; };
f33216266_755.returns = [];
f33216266_755.inst = 0;
// 5771
o3.getTarget = f33216266_755;
// 5772
o3.target = o41;
// 5773
f33216266_755.returns.push(o41);
// 5774
o41.nodeName = "DIV";
// 5776
o39.nodeName = "DIV";
// 5778
o42.nodeName = "DIV";
// 5780
o43.nodeName = "DIV";
// 5782
o15.nodeName = "DIV";
// 5788
o0.nodeName = "#document";
// 5790
o3.cancelBubble = "false";
// 5791
o3.returnValue = "true";
// undefined
o3 = null;
// 5809
o3 = {};
// 5810
o3._inherits_from_prototype = "true";
// 5811
o3.type = "click";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 5816
o3.getTarget = f33216266_755;
// 5817
o3.target = o41;
// 5818
f33216266_755.returns.push(o41);
// 5836
f33216266_432.returns.push(1344872064869);
// 5839
f33216266_755.returns.push(o41);
// 5843
f33216266_456.returns.push(null);
// 5845
f33216266_456.returns.push(null);
// 5846
o41.action = void 0;
// 5847
o41.href = void 0;
// 5848
o41.JSBNG__name = void 0;
// 5851
f33216266_456.returns.push(null);
// 5856
o41.id = "mainContainer";
// 5863
o39.id = "";
// undefined
o39 = null;
// 5866
o42.id = "content";
// undefined
o42 = null;
// 5873
o43.id = "globalContainer";
// 5880
o15.id = "";
// undefined
o15 = null;
// 5883
f33216266_12.returns.push(61);
// 5885
f33216266_432.returns.push(1344872064875);
// 5889
f33216266_456.returns.push(null);
// 5891
f33216266_456.returns.push(null);
// 5895
f33216266_12.returns.push(62);
// 5897
f33216266_432.returns.push(1344872064876);
// 5899
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 5903
f33216266_755.returns.push(o41);
// 5904
o3.cancelBubble = "false";
// 5907
f33216266_432.returns.push(1344872064876);
// 5913
f33216266_456.returns.push(null);
// 5917
f33216266_456.returns.push(null);
// 5921
f33216266_456.returns.push(null);
// 5925
f33216266_456.returns.push(null);
// 5929
f33216266_456.returns.push(null);
// 5933
f33216266_456.returns.push(null);
// 5937
f33216266_456.returns.push(null);
// 5957
f33216266_607.returns.push(undefined);
// 5959
o3.returnValue = "true";
// undefined
o3 = null;
// 5960
o3 = {};
// 5961
o3._info_version = 1;
// 5962
o3.ue = "1344872064869/0";
// 5963
o3._ns = "evt_ext";
// 5964
o3._ua_id = null;
// 5965
f33216266_758 = function() { return f33216266_758.returns[f33216266_758.inst++]; };
f33216266_758.returns = [];
f33216266_758.inst = 0;
// 5966
o3._log = f33216266_758;
// undefined
o3 = null;
// 5968
f33216266_758.returns.push(undefined);
// 5969
o3 = {};
// 5970
o3._inherits_from_prototype = "true";
// 5971
o3.type = "keydown";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 5977
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 5979
o3.getTarget = f33216266_755;
// 5980
o3.target = o7;
// 5981
f33216266_755.returns.push(o7);
// 5982
o7.contentEditable = "inherit";
// 5986
o3.cancelBubble = "false";
// 5990
f33216266_755.returns.push(o7);
// 6000
f33216266_432.returns.push(1344872065524);
// 6004
o3.keyCode = 35;
// 6005
f33216266_606.returns.push(undefined);
// 6007
o3.returnValue = "true";
// undefined
o3 = null;
// 6008
o3 = {};
// 6009
o3._inherits_from_prototype = "true";
// 6010
o3.type = "scroll";
// 6012
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6015
f33216266_432.returns.push(1344872065556);
// 6016
o3.cancelBubble = "false";
// 6017
o3.returnValue = "true";
// undefined
o3 = null;
// 6018
o3 = {};
// 6019
o3._inherits_from_prototype = "true";
// 6020
o3.type = "mouseover";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 6026
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6029
f33216266_432.returns.push(1344872065628);
// 6030
o3.cancelBubble = "false";
// 6032
f33216266_623.returns.push(undefined);
// 6034
o3.returnValue = "true";
// 6035
o3.target = o43;
// undefined
o3 = null;
// 6038
f33216266_456.returns.push(null);
// 6042
f33216266_456.returns.push(null);
// 6046
f33216266_456.returns.push(null);
// 6050
f33216266_456.returns.push(null);
// 6056
f33216266_456.returns.push(null);
// 6060
f33216266_456.returns.push(null);
// 6064
f33216266_456.returns.push(null);
// 6068
f33216266_456.returns.push(null);
// 6072
// undefined
o1 = null;
// 6073
o1 = {};
// 6074
o1._inherits_from_prototype = "true";
// 6075
o1.type = "keydown";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 6081
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6083
o1.getTarget = f33216266_755;
// 6084
o1.target = o7;
// 6085
f33216266_755.returns.push(o7);
// 6090
o1.cancelBubble = "false";
// 6094
f33216266_755.returns.push(o7);
// 6104
f33216266_432.returns.push(1344872066436);
// 6108
o1.keyCode = 34;
// 6109
f33216266_606.returns.push(undefined);
// 6111
o1.returnValue = "true";
// undefined
o1 = null;
// 6114
f33216266_432.returns.push(1344872067963);
// 6117
f33216266_432.returns.push(1344872067963);
// 6118
o1 = {};
// 6119
o1._inherits_from_prototype = "true";
// 6120
o1.type = "keydown";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 6126
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6128
o1.getTarget = f33216266_755;
// 6129
o1.target = o7;
// 6130
f33216266_755.returns.push(o7);
// 6135
o1.cancelBubble = "false";
// 6139
f33216266_755.returns.push(o7);
// 6149
f33216266_432.returns.push(1344872068132);
// 6153
o1.keyCode = 36;
// 6154
f33216266_606.returns.push(undefined);
// 6156
o1.returnValue = "true";
// undefined
o1 = null;
// 6157
o1 = {};
// 6158
o1._inherits_from_prototype = "true";
// 6159
o1.type = "scroll";
// 6161
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6164
f33216266_432.returns.push(1344872068147);
// 6165
o1.cancelBubble = "false";
// 6166
o1.returnValue = "true";
// undefined
o1 = null;
// 6167
o1 = {};
// 6168
o1._inherits_from_prototype = "true";
// 6169
o1.type = "mouseover";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 6175
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6178
f33216266_432.returns.push(1344872068242);
// 6179
o1.cancelBubble = "false";
// 6181
f33216266_623.returns.push(undefined);
// 6183
o1.returnValue = "true";
// 6184
o1.target = o41;
// undefined
o1 = null;
// 6187
f33216266_456.returns.push(null);
// 6191
f33216266_456.returns.push(null);
// 6195
f33216266_456.returns.push(null);
// 6199
f33216266_456.returns.push(null);
// 6203
f33216266_456.returns.push(null);
// 6207
f33216266_456.returns.push(null);
// 6211
f33216266_456.returns.push(null);
// 6217
f33216266_456.returns.push(null);
// 6221
f33216266_456.returns.push(null);
// 6225
f33216266_456.returns.push(null);
// 6229
f33216266_456.returns.push(null);
// 6233
f33216266_456.returns.push(null);
// 6237
f33216266_456.returns.push(null);
// 6241
f33216266_456.returns.push(null);
// 6245
o1 = {};
// 6246
o1._inherits_from_prototype = "true";
// 6247
o1.type = "keydown";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 6253
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6255
o1.getTarget = f33216266_755;
// 6256
o1.target = o7;
// 6257
f33216266_755.returns.push(o7);
// 6262
o1.cancelBubble = "false";
// 6266
f33216266_755.returns.push(o7);
// 6276
f33216266_432.returns.push(1344872068455);
// 6280
o1.keyCode = 35;
// 6281
f33216266_606.returns.push(undefined);
// 6283
o1.returnValue = "true";
// undefined
o1 = null;
// 6284
o1 = {};
// 6285
o1._inherits_from_prototype = "true";
// 6286
o1.type = "scroll";
// 6288
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6291
f33216266_432.returns.push(1344872068474);
// 6292
o1.cancelBubble = "false";
// 6293
o1.returnValue = "true";
// undefined
o1 = null;
// 6294
o1 = {};
// 6295
o1._inherits_from_prototype = "true";
// 6296
o1.type = "mouseover";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 6302
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6305
f33216266_432.returns.push(1344872068566);
// 6306
o1.cancelBubble = "false";
// 6308
f33216266_623.returns.push(undefined);
// 6310
o1.returnValue = "true";
// 6311
o1.target = o43;
// undefined
o1 = null;
// undefined
o43 = null;
// 6314
f33216266_456.returns.push(null);
// 6318
f33216266_456.returns.push(null);
// 6322
f33216266_456.returns.push(null);
// 6326
f33216266_456.returns.push(null);
// 6332
f33216266_456.returns.push(null);
// 6336
f33216266_456.returns.push(null);
// 6340
f33216266_456.returns.push(null);
// 6344
f33216266_456.returns.push(null);
// 6348
o1 = {};
// 6349
o1._inherits_from_prototype = "true";
// 6350
o1.type = "keydown";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 6356
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6358
o1.getTarget = f33216266_755;
// 6359
o1.target = o7;
// 6360
f33216266_755.returns.push(o7);
// 6365
o1.cancelBubble = "false";
// 6369
f33216266_755.returns.push(o7);
// 6379
f33216266_432.returns.push(1344872068791);
// 6383
o1.keyCode = 35;
// 6384
f33216266_606.returns.push(undefined);
// 6386
o1.returnValue = "true";
// undefined
o1 = null;
// 6387
o1 = {};
// 6388
o1._inherits_from_prototype = "true";
// 6389
o1.type = "keydown";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 6395
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6397
o1.getTarget = f33216266_755;
// 6398
o1.target = o7;
// 6399
f33216266_755.returns.push(o7);
// 6404
o1.cancelBubble = "false";
// 6408
f33216266_755.returns.push(o7);
// 6418
f33216266_432.returns.push(1344872069223);
// 6422
o1.keyCode = 33;
// 6423
f33216266_606.returns.push(undefined);
// 6425
o1.returnValue = "true";
// undefined
o1 = null;
// 6426
o1 = {};
// 6427
o1._inherits_from_prototype = "true";
// 6428
o1.type = "scroll";
// 6430
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6433
f33216266_432.returns.push(1344872069253);
// 6434
o1.cancelBubble = "false";
// 6435
o1.returnValue = "true";
// undefined
o1 = null;
// 6436
o1 = {};
// 6437
o1._inherits_from_prototype = "true";
// 6438
o1.type = "mouseover";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 6444
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6447
f33216266_432.returns.push(1344872069327);
// 6448
o1.cancelBubble = "false";
// 6450
f33216266_623.returns.push(undefined);
// 6452
o1.returnValue = "true";
// 6453
o1.target = o41;
// undefined
o1 = null;
// undefined
o41 = null;
// 6456
f33216266_456.returns.push(null);
// 6460
f33216266_456.returns.push(null);
// 6464
f33216266_456.returns.push(null);
// 6468
f33216266_456.returns.push(null);
// 6472
f33216266_456.returns.push(null);
// 6476
f33216266_456.returns.push(null);
// 6480
f33216266_456.returns.push(null);
// 6486
f33216266_456.returns.push(null);
// 6490
f33216266_456.returns.push(null);
// 6494
f33216266_456.returns.push(null);
// 6498
f33216266_456.returns.push(null);
// 6502
f33216266_456.returns.push(null);
// 6506
f33216266_456.returns.push(null);
// 6510
f33216266_456.returns.push(null);
// 6514
o1 = {};
// 6515
o1._inherits_from_prototype = "true";
// 6516
o1.type = "keydown";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 6522
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6524
o1.getTarget = f33216266_755;
// 6525
o1.target = o7;
// 6526
f33216266_755.returns.push(o7);
// 6531
o1.cancelBubble = "false";
// 6535
f33216266_755.returns.push(o7);
// 6545
f33216266_432.returns.push(1344872069440);
// 6549
o1.keyCode = 33;
// 6550
f33216266_606.returns.push(undefined);
// 6552
o1.returnValue = "true";
// undefined
o1 = null;
// 6553
o1 = {};
// 6554
o1._inherits_from_prototype = "true";
// 6555
o1.type = "scroll";
// 6557
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6560
f33216266_432.returns.push(1344872069466);
// 6561
o1.cancelBubble = "false";
// 6562
o1.returnValue = "true";
// undefined
o1 = null;
// 6563
o1 = {};
// 6564
o1._inherits_from_prototype = "true";
// 6565
o1.type = "keydown";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 6571
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6573
o1.getTarget = f33216266_755;
// 6574
o1.target = o7;
// 6575
f33216266_755.returns.push(o7);
// 6580
o1.cancelBubble = "false";
// 6584
f33216266_755.returns.push(o7);
// 6594
f33216266_432.returns.push(1344872069669);
// 6598
o1.keyCode = 33;
// 6599
f33216266_606.returns.push(undefined);
// 6601
o1.returnValue = "true";
// undefined
o1 = null;
// 6602
o1 = {};
// 6603
o1._inherits_from_prototype = "true";
// 6604
o1.type = "scroll";
// 6606
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6609
f33216266_432.returns.push(1344872069680);
// 6610
o1.cancelBubble = "false";
// 6611
o1.returnValue = "true";
// undefined
o1 = null;
// 6612
o1 = {};
// 6613
o1._inherits_from_prototype = "true";
// 6614
o1.type = "keydown";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 6620
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6622
o1.getTarget = f33216266_755;
// 6623
o1.target = o7;
// 6624
f33216266_755.returns.push(o7);
// 6629
o1.cancelBubble = "false";
// 6633
f33216266_755.returns.push(o7);
// 6643
f33216266_432.returns.push(1344872069943);
// 6647
o1.keyCode = 33;
// 6648
f33216266_606.returns.push(undefined);
// 6650
o1.returnValue = "true";
// undefined
o1 = null;
// 6651
o1 = {};
// 6652
o1._inherits_from_prototype = "true";
// 6653
o1.type = "scroll";
// 6655
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6658
f33216266_432.returns.push(1344872069952);
// 6659
o1.cancelBubble = "false";
// 6660
o1.returnValue = "true";
// undefined
o1 = null;
// 6661
o1 = {};
// 6662
o1._inherits_from_prototype = "true";
// 6663
o1.type = "keydown";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 6669
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6671
o1.getTarget = f33216266_755;
// 6672
o1.target = o7;
// 6673
f33216266_755.returns.push(o7);
// 6678
o1.cancelBubble = "false";
// 6682
f33216266_755.returns.push(o7);
// 6692
f33216266_432.returns.push(1344872070181);
// 6696
o1.keyCode = 33;
// 6697
f33216266_606.returns.push(undefined);
// 6699
o1.returnValue = "true";
// undefined
o1 = null;
// 6700
o1 = {};
// 6701
o1._inherits_from_prototype = "true";
// 6702
o1.type = "scroll";
// 6704
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6707
f33216266_432.returns.push(1344872070193);
// 6708
o1.cancelBubble = "false";
// 6709
o1.returnValue = "true";
// undefined
o1 = null;
// 6710
o1 = {};
// 6711
o1._inherits_from_prototype = "true";
// 6712
o1.type = "keydown";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 6718
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6720
o1.getTarget = f33216266_755;
// 6721
o1.target = o7;
// 6722
f33216266_755.returns.push(o7);
// 6727
o1.cancelBubble = "false";
// 6731
f33216266_755.returns.push(o7);
// 6741
f33216266_432.returns.push(1344872070344);
// 6745
o1.keyCode = 33;
// 6746
f33216266_606.returns.push(undefined);
// 6748
o1.returnValue = "true";
// undefined
o1 = null;
// 6749
o1 = {};
// 6750
o1._inherits_from_prototype = "true";
// 6751
o1.type = "keydown";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 6757
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6759
o1.getTarget = f33216266_755;
// 6760
o1.target = o7;
// 6761
f33216266_755.returns.push(o7);
// 6766
o1.cancelBubble = "false";
// 6770
f33216266_755.returns.push(o7);
// 6780
f33216266_432.returns.push(1344872070519);
// 6784
o1.keyCode = 33;
// 6785
f33216266_606.returns.push(undefined);
// 6787
o1.returnValue = "true";
// undefined
o1 = null;
// 6788
o1 = {};
// 6789
o1._inherits_from_prototype = "true";
// 6790
o1.type = "keydown";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 6796
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6798
o1.getTarget = f33216266_755;
// 6799
o1.target = o7;
// 6800
f33216266_755.returns.push(o7);
// 6805
o1.cancelBubble = "false";
// 6809
f33216266_755.returns.push(o7);
// 6819
f33216266_432.returns.push(1344872070709);
// 6823
o1.keyCode = 33;
// 6824
f33216266_606.returns.push(undefined);
// 6826
o1.returnValue = "true";
// undefined
o1 = null;
// 6827
o1 = {};
// 6828
o1._inherits_from_prototype = "true";
// 6829
o1.type = "keydown";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 6835
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6837
o1.getTarget = f33216266_755;
// 6838
o1.target = o7;
// 6839
f33216266_755.returns.push(o7);
// 6844
o1.cancelBubble = "false";
// 6848
f33216266_755.returns.push(o7);
// 6858
f33216266_432.returns.push(1344872071135);
// 6862
o1.keyCode = 17;
// 6863
f33216266_606.returns.push(undefined);
// 6865
o1.returnValue = "true";
// undefined
o1 = null;
// 6866
o1 = {};
// 6867
o1._inherits_from_prototype = "true";
// 6868
o1.type = "keydown";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// 6874
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6876
o1.getTarget = f33216266_755;
// 6877
o1.target = o7;
// 6878
f33216266_755.returns.push(o7);
// 6883
o1.cancelBubble = "false";
// 6887
f33216266_755.returns.push(o7);
// 6897
f33216266_432.returns.push(1344872071232);
// 6901
o1.keyCode = 81;
// 6902
f33216266_606.returns.push(undefined);
// 6904
o1.returnValue = "true";
// undefined
o1 = null;
// 6905
o1 = {};
// 6906
o1._inherits_from_prototype = "true";
// 6907
o1.type = "keydown";
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
fo33216266_431___FB_TOKEN.returns.push(o22);
// undefined
o22 = null;
// 6913
f33216266_638.returns.push({__JSBNG_unknown_object:true});
// 6915
o1.getTarget = f33216266_755;
// 6916
o1.target = o7;
// 6917
f33216266_755.returns.push(o7);
// 6922
o1.cancelBubble = "false";
// 6926
f33216266_755.returns.push(o7);
// undefined
o7 = null;
// 6936
f33216266_432.returns.push(1344872072287);
// 6940
o1.keyCode = 17;
// 6941
f33216266_606.returns.push(undefined);
// 6943
o1.returnValue = "true";
// undefined
o1 = null;
// 6944
o1 = {};
// 6947
// 0
JSBNG_Replay$ = function(real, cb) { if (!real) return;
// 893
geval("function envFlush(a) {\n    function b(c) {\n        for (var d in a) {\n            c[d] = a[d];\n        ;\n        };\n    ;\n    };\n;\n    if (window.requireLazy) {\n        requireLazy([\"Env\",], b);\n    }\n     else {\n        Env = ((window.Env || {\n        }));\n        b(Env);\n    }\n;\n;\n};\n;\nenvFlush({\n    user: \"100001812504199\",\n    locale: \"en_US\",\n    method: \"GET\",\n    svn_rev: 608370,\n    tier: \"\",\n    vip: \"69.171.237.16\",\n    static_base: \"http://static.ak.fbcdn.net/\",\n    www_base: \"http://www.facebook.com/\",\n    rep_lag: 2,\n    fb_dtsg: \"AQCc21Em\",\n    ajaxpipe_token: \"AXhhHAInBwuf9e-J\",\n    lhsh: \"_AQHVav1f\",\n    tracking_domain: \"http://pixel.facebook.com\",\n    retry_ajax_on_network_error: \"1\",\n    fbid_emoticons: \"1\"\n});");
// 894
geval("envFlush({\n    eagleEyeConfig: {\n        seed: \"08yE\",\n        JSBNG__sessionStorage: true\n    }\n});\nCavalryLogger = false;\nwindow._script_path = \"/home.php\";");
// 895
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"NPGon\",]);\n}\n;\n;\nwindow.__DEV__ = ((window.__DEV__ || 0));\nif (!JSON.stringify.__fb) {\n    JSON.stringify = function(a) {\n        {\n            function b() {\n                var c = a.apply(this, arguments);\n                if (!c) {\n                    return c;\n                }\n            ;\n            ;\n                return c.replace(/[%\\u2028\\u2029]/g, function(d) {\n                    var e = d.charCodeAt(0).toString(16);\n                    return ((\"\\\\u0000\".substring(0, ((6 - e.length))) + e));\n                });\n            };\n            ((window.top.JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1.push)((b)));\n        };\n    ;\n        b.__fb = true;\n        return b;\n    }(JSON.stringify);\n}\n;\n;\n(function(a) {\n    if (a.require) {\n        return;\n    }\n;\n;\n    var b = Object.prototype.toString, c = {\n    }, d = {\n    }, e = {\n    }, f = 0, g = 1, h = 2, i = Object.prototype.hasOwnProperty;\n    function j(u) {\n        var v = c[u], w, x, y;\n        if (!c[u]) {\n            y = ((((\"Requiring unknown module \\\"\" + u)) + \"\\\"\"));\n            throw new Error(y);\n        }\n    ;\n    ;\n        if (((v.waiting && ((v.special & h))))) {\n            m();\n        }\n    ;\n    ;\n        if (v.waiting) {\n            y = ((((\"Requiring module \\\"\" + u)) + \"\\\" with unresolved dependencies\"));\n            throw new Error(y);\n        }\n    ;\n    ;\n        if (!v.exports) {\n            var z = v.exports = {\n            }, aa = v.factory;\n            if (((typeof aa === \"string\"))) {\n                var ba = ((((\"(\" + aa)) + \")\"));\n                aa = (eval)(ba);\n            }\n        ;\n        ;\n            if (((b.call(aa) === \"[object Function]\"))) {\n                var ca = [], da = v.dependencies, ea = da.length;\n                if (((v.special & h))) {\n                    ea = Math.min(ea, aa.length);\n                }\n            ;\n            ;\n                for (x = 0; ((x < ea)); x++) {\n                    w = da[x];\n                    ca.push(((((w === \"module\")) ? v : ((((w === \"exports\")) ? z : j(w))))));\n                };\n            ;\n                var fa = aa.apply(((v.context || a)), ca);\n                if (fa) {\n                    v.exports = fa;\n                }\n            ;\n            ;\n            }\n             else v.exports = aa;\n        ;\n        ;\n        }\n    ;\n    ;\n        if (((v.refcount-- === 1))) {\n            delete c[u];\n        }\n    ;\n    ;\n        return v.exports;\n    };\n;\n    function k(u, v, w, x, y, z) {\n        if (((v === undefined))) {\n            v = [];\n            w = u;\n            u = o();\n        }\n         else if (((w === undefined))) {\n            w = v;\n            if (((b.call(u) === \"[object Array]\"))) {\n                v = u;\n                u = o();\n            }\n             else v = [];\n        ;\n        ;\n        }\n        \n    ;\n    ;\n        var aa = c[u];\n        if (aa) {\n            if (z) {\n                aa.refcount += z;\n            }\n        ;\n        ;\n            return;\n        }\n         else if (((((!v && !w)) && z))) {\n            e[u] = ((((e[u] || 0)) + z));\n            return;\n        }\n         else {\n            aa = {\n                id: u\n            };\n            aa.refcount = ((((e[u] || 0)) + ((z || 0))));\n            delete e[u];\n        }\n        \n    ;\n    ;\n        aa.factory = w;\n        aa.dependencies = v;\n        aa.context = y;\n        aa.special = x;\n        c[u] = aa;\n        p(u);\n    };\n;\n    function l(u, v, w) {\n        k(u, v, undefined, g, w, 1);\n    };\n;\n    function m() {\n        var u = {\n        }, v;\n        for (v in d) {\n            if (i.call(d, v)) {\n                if (((((c[v] && !u[v])) && ((c[v].special & h))))) {\n                    n({\n                    }, v, u);\n                }\n            ;\n            }\n        ;\n        ;\n        };\n    ;\n    };\n;\n    function n(u, v, w) {\n        w[v] = 1;\n        var x = d[v], y;\n        if (!x) {\n            return;\n        }\n    ;\n    ;\n        u[v] = 1;\n        for (y in x) {\n            if (i.call(x, y)) {\n                if (((!c[y].special & h))) {\n                    continue;\n                }\n            ;\n            ;\n                if (u[y]) {\n                    delete x[y];\n                    c[y].waiting--;\n                    if (!c[y].waiting) {\n                        q(y);\n                    }\n                ;\n                ;\n                }\n                 else n(u, y, w);\n            ;\n            ;\n            }\n        ;\n        ;\n        };\n    ;\n        u[v] = 0;\n    };\n;\n    function o() {\n        return ((\"__mod__\" + f++));\n    };\n;\n    function p(u) {\n        var v = c[u], w = 0;\n        for (var x = 0; ((x < v.dependencies.length)); x++) {\n            var y = v.dependencies[x];\n            if (((!c[y] || c[y].waiting))) {\n                ((d[y] || (d[y] = {\n                })));\n                if (!d[y][u]) {\n                    w++;\n                }\n            ;\n            ;\n                d[y][u] = 1;\n            }\n        ;\n        ;\n        };\n    ;\n        v.waiting = w;\n        if (!w) {\n            q(u);\n        }\n    ;\n    ;\n    };\n;\n    function q(u) {\n        var v = c[u];\n        if (((v.special & g))) {\n            j(u);\n        }\n    ;\n    ;\n        var w = d[u], x = [];\n        if (w) {\n            delete d[u];\n            for (var y in w) {\n                if (i.call(w, y)) {\n                    if (!--c[y].waiting) {\n                        x.push(y);\n                    }\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n        }\n    ;\n    ;\n        for (var z = 0; ((z < x.length)); z++) {\n            q(x[z]);\n        ;\n        };\n    ;\n    };\n;\n    function r(u, v) {\n        c[u] = {\n            id: u\n        };\n        c[u].exports = v;\n    };\n;\n    r(\"module\", 0);\n    r(\"exports\", 0);\n    r(\"define\", k);\n    r(\"global\", a);\n    r(\"require\", j);\n    r(\"requireDynamic\", j);\n    r(\"requireLazy\", l);\n    k.amd = {\n    };\n    a.define = k;\n    a.require = j;\n    a.requireDynamic = j;\n    a.requireLazy = l;\n    j.__debug = {\n        modules: c,\n        deps: d\n    };\n    var s = false, t = function(u, v, w, x) {\n        k(u, v, w, ((x || h)));\n        if (((c[u].waiting && !s))) {\n            s = JSBNG__setTimeout(((window.top.JSBNG_Replay.push)((window.top.JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_14), function() {\n                m();\n                s = false;\n            })), 9);\n        }\n    ;\n    ;\n    };\n    a.__d = function(u, v, w, x) {\n        v = [\"global\",\"require\",\"requireDynamic\",\"requireLazy\",\"module\",\"exports\",].concat(v);\n        t(u, v, w, x);\n    };\n    a.__e = a.__d;\n})(this);\nfunction bagofholding() {\n\n};\n;\nfunction bagof(a) {\n    return function() {\n        return a;\n    };\n};\n;\nArray.prototype.reduce = null;\nArray.prototype.reduceRight = null;\nJSBNG__document.documentElement.className = JSBNG__document.documentElement.className.replace(\"no_js\", \"\");\n__d(\"SidebarPrelude\", [], function(a, b, c, d, e, f) {\n    var g = {\n        addSidebarMode: function(h) {\n            var i = JSBNG__document.documentElement;\n            if (((i.clientWidth > h))) {\n                i.className = ((i.className + \" sidebarMode\"));\n            }\n        ;\n        ;\n        }\n    };\n    e.exports = g;\n});\n__d(\"copyProperties\", [], function(a, b, c, d, e, f) {\n    function g(h, i, j, k, l, m, n) {\n        h = ((h || {\n        }));\n        var o = [i,j,k,l,m,], p = 0, q;\n        while (o[p]) {\n            q = o[p++];\n            for (var r in q) {\n                h[r] = q[r];\n            ;\n            };\n        ;\n            if (((((((q.hasOwnProperty && q.hasOwnProperty(\"toString\"))) && ((typeof q.toString != \"undefined\")))) && ((h.toString !== q.toString))))) {\n                h.toString = q.toString;\n            }\n        ;\n        ;\n        };\n    ;\n        return h;\n    };\n;\n    e.exports = g;\n});\n__d(\"Env\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\"), h = {\n        start: JSBNG__Date.now()\n    };\n    if (a.Env) {\n        g(h, a.Env);\n        a.Env = undefined;\n    }\n;\n;\n    e.exports = h;\n});\n__d(\"ErrorUtils\", [\"Env\",], function(a, b, c, d, e, f) {\n    var g = b(\"Env\"), h = [], i = [], j = 10, k = ((window.JSBNG__chrome && ((\"type\" in new Error()))));\n    function l(q) {\n        if (!q) {\n            return {\n            };\n        }\n         else if (q._originalError) {\n            return q;\n        }\n        \n    ;\n    ;\n        var r = {\n            line: ((q.lineNumber || q.line)),\n            message: q.message,\n            JSBNG__name: q.JSBNG__name,\n            script: ((((q.fileName || q.sourceURL)) || q.script)),\n            stack: ((q.stackTrace || q.stack))\n        };\n        r._originalError = q;\n        if (((k && /(\\w{3,5}:\\/\\/[^:]+):(\\d+)/.test(q.stack)))) {\n            r.script = RegExp.$1;\n            r.line = parseInt(RegExp.$2, 10);\n        }\n    ;\n    ;\n        for (var s in r) {\n            ((((r[s] == null)) && delete r[s]));\n        ;\n        };\n    ;\n        return r;\n    };\n;\n    function m(q, r) {\n        q = l(q);\n        !r;\n        if (((i.length < j))) {\n            i.push(q);\n        }\n    ;\n    ;\n        for (var s = 0; ((s < h.length)); s++) {\n            try {\n                h[s](q);\n            } catch (t) {\n            \n            };\n        ;\n        };\n    ;\n    };\n;\n    function n(q, r, s, t) {\n        if (((g.nocatch || (/nocatch/).test(JSBNG__location.search)))) {\n            return q.apply(r, ((s || [])));\n        }\n    ;\n    ;\n        try {\n            return q.apply(r, ((s || [])));\n        } catch (u) {\n            var v = l(u);\n            if (t) {\n                t(v);\n            }\n        ;\n        ;\n            if (q) {\n                v.callee = q.toString().substring(0, 100);\n            }\n        ;\n        ;\n            if (s) {\n                v.args = String(s).substring(0, 100);\n            }\n        ;\n        ;\n            m(v);\n        };\n    ;\n    };\n;\n    {\n        function o(q, r, s) {\n            m({\n                message: q,\n                script: r,\n                line: s\n            }, true);\n        };\n        ((window.top.JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_28.push)((o)));\n    };\n;\n    window.JSBNG__onerror = o;\n    function p(q, r) {\n        h.push(q);\n        if (!r) {\n            i.forEach(q);\n        }\n    ;\n    ;\n    };\n;\n    e.exports = {\n        JSBNG__history: i,\n        JSBNG__onerror: o,\n        reportError: m,\n        normalizeError: l,\n        applyWithGuard: n,\n        addListener: p\n    };\n});\n__d(\"hasArrayNature\", [], function(a, b, c, d, e, f) {\n    function g(h) {\n        return ((((((((!!h && ((((typeof h == \"object\")) || ((typeof h == \"function\")))))) && ((\"length\" in h)))) && !((\"JSBNG__setInterval\" in h)))) && ((((((Object.prototype.toString.call(h) === \"[object Array]\")) || ((\"callee\" in h)))) || ((\"item\" in h))))));\n    };\n;\n    e.exports = g;\n});\n__d(\"createArrayFrom\", [\"hasArrayNature\",], function(a, b, c, d, e, f) {\n    var g = b(\"hasArrayNature\");\n    function h(i) {\n        if (!g(i)) {\n            return [i,];\n        }\n    ;\n    ;\n        if (i.item) {\n            var j = i.length, k = new Array(j);\n            while (j--) {\n                k[j] = i[j];\n            ;\n            };\n        ;\n            return k;\n        }\n    ;\n    ;\n        return Array.prototype.slice.call(i);\n    };\n;\n    e.exports = h;\n});\n__d(\"Arbiter\", [\"ErrorUtils\",\"copyProperties\",\"createArrayFrom\",\"hasArrayNature\",], function(a, b, c, d, e, f) {\n    var g = b(\"ErrorUtils\"), h = b(\"copyProperties\"), i = b(\"createArrayFrom\"), j = b(\"hasArrayNature\");\n    if (!window.async_callback) {\n        window.async_callback = function(m, n) {\n            return m;\n        };\n    }\n;\n;\n    function k() {\n        h(this, {\n            _listeners: [],\n            _events: {\n            },\n            _callbacks: {\n            },\n            _last_id: 1,\n            _listen: {\n            },\n            _index: {\n            }\n        });\n        h(this, k);\n    };\n;\n    h(k, {\n        SUBSCRIBE_NEW: \"new\",\n        SUBSCRIBE_ALL: \"all\",\n        BEHAVIOR_EVENT: \"JSBNG__event\",\n        BEHAVIOR_PERSISTENT: \"persistent\",\n        BEHAVIOR_STATE: \"state\",\n        LIVEMESSAGE: \"livemessage\",\n        BOOTLOAD: \"bootload\",\n        FUNCTION_EXTENSION: \"function_ext\",\n        subscribe: function(m, n, o) {\n            m = i(m);\n            var p = m.some(function(x) {\n                return ((!x || ((typeof (x) != \"string\"))));\n            });\n            if (p) {\n                return null;\n            }\n        ;\n        ;\n            o = ((o || k.SUBSCRIBE_ALL));\n            var q = k._getInstance(this);\n            q._listeners.push({\n                callback: n,\n                types: m\n            });\n            var r = ((q._listeners.length - 1));\n            for (var s = 0; ((s < m.length)); s++) {\n                var t = m[s];\n                if (!q._index[t]) {\n                    q._index[t] = [];\n                }\n            ;\n            ;\n                q._index[t].push(r);\n                if (((o == k.SUBSCRIBE_ALL))) {\n                    if (((t in q._events))) {\n                        for (var u = 0; ((u < q._events[t].length)); u++) {\n                            var v = q._events[t][u], w = g.applyWithGuard(n, null, [t,v,]);\n                            if (((w === false))) {\n                                q._events[t].splice(u, 1);\n                                u--;\n                            }\n                        ;\n                        ;\n                        };\n                    }\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            return new l(q, r);\n        },\n        unsubscribe: function(m) {\n            m.unsubscribe();\n        },\n        inform: function(m, n, o) {\n            var p = j(m);\n            m = i(m);\n            var q = k._getInstance(this), r = {\n            };\n            o = ((o || k.BEHAVIOR_EVENT));\n            for (var s = 0; ((s < m.length)); s++) {\n                var t = m[s], u = null;\n                if (((o == k.BEHAVIOR_PERSISTENT))) {\n                    u = q._events.length;\n                    if (!((t in q._events))) {\n                        q._events[t] = [];\n                    }\n                ;\n                ;\n                    q._events[t].push(n);\n                    q._events[t]._stateful = false;\n                }\n                 else if (((o == k.BEHAVIOR_STATE))) {\n                    u = 0;\n                    q._events[t] = [n,];\n                    q._events[t]._stateful = true;\n                }\n                 else if (((t in q._events))) {\n                    q._events[t]._stateful = false;\n                }\n                \n                \n            ;\n            ;\n                ((a.ArbiterMonitor && a.ArbiterMonitor.record(\"JSBNG__event\", t, n, q)));\n                var v;\n                if (q._index[t]) {\n                    var w = i(q._index[t]);\n                    for (var x = 0; ((x < w.length)); x++) {\n                        var y = q._listeners[w[x]];\n                        if (y) {\n                            v = g.applyWithGuard(y.callback, null, [t,n,]);\n                            if (((v === false))) {\n                                if (((u !== null))) {\n                                    q._events[t].splice(u, 1);\n                                }\n                            ;\n                            ;\n                                break;\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n                q._updateCallbacks(t, n);\n                ((a.ArbiterMonitor && a.ArbiterMonitor.record(\"done\", t, n, q)));\n                r[t] = v;\n            };\n        ;\n            return ((p ? r : r[m[0]]));\n        },\n        query: function(m) {\n            var n = k._getInstance(this);\n            if (!((m in n._events))) {\n                return null;\n            }\n        ;\n        ;\n            if (n._events[m].length) {\n                return n._events[m][0];\n            }\n        ;\n        ;\n            return null;\n        },\n        _instance: null,\n        _getInstance: function(m) {\n            if (((m instanceof k))) {\n                return m;\n            }\n        ;\n        ;\n            if (!k._instance) {\n                k._instance = new k();\n            }\n        ;\n        ;\n            return k._instance;\n        },\n        registerCallback: function(m, n) {\n            var o, p = 0, q = k._getInstance(this), r = false;\n            if (((typeof m == \"function\"))) {\n                o = q._last_id;\n                q._last_id++;\n                r = true;\n            }\n             else {\n                if (!q._callbacks[m]) {\n                    return null;\n                }\n            ;\n            ;\n                o = m;\n            }\n        ;\n        ;\n            if (j(n)) {\n                var s = {\n                };\n                for (var t = 0; ((t < n.length)); t++) {\n                    s[n[t]] = 1;\n                ;\n                };\n            ;\n                n = s;\n            }\n        ;\n        ;\n            for (var u in n) {\n                try {\n                    if (q.query(u)) {\n                        continue;\n                    }\n                ;\n                ;\n                } catch (v) {\n                \n                };\n            ;\n                p += n[u];\n                if (((q._listen[u] === undefined))) {\n                    q._listen[u] = {\n                    };\n                }\n            ;\n            ;\n                q._listen[u][o] = ((((q._listen[u][o] || 0)) + n[u]));\n            };\n        ;\n            if (((((p === 0)) && r))) {\n                g.applyWithGuard(m);\n                return null;\n            }\n        ;\n        ;\n            if (!r) {\n                q._callbacks[o].depnum += p;\n            }\n             else q._callbacks[o] = {\n                callback: window.async_callback(m, \"arbiter\"),\n                depnum: p\n            };\n        ;\n        ;\n            return o;\n        },\n        _updateCallbacks: function(m, n) {\n            if (((((n === null)) || !this._listen[m]))) {\n                return;\n            }\n        ;\n        ;\n            for (var o in this._listen[m]) {\n                this._listen[m][o]--;\n                if (((this._listen[m][o] <= 0))) {\n                    delete this._listen[m][o];\n                }\n            ;\n            ;\n                this._callbacks[o].depnum--;\n                if (((this._callbacks[o].depnum <= 0))) {\n                    var p = this._callbacks[o].callback;\n                    delete this._callbacks[o];\n                    g.applyWithGuard(p);\n                }\n            ;\n            ;\n            };\n        ;\n        }\n    });\n    function l(m, n) {\n        this._instance = m;\n        this._id = n;\n    };\n;\n    h(l.prototype, {\n        unsubscribe: function() {\n            var m = this._instance._listeners, n = m[this._id];\n            if (!n) {\n                return;\n            }\n        ;\n        ;\n            for (var o = 0; ((o < n.types.length)); o++) {\n                var p = n.types[o], q = this._instance._index[p];\n                if (q) {\n                    for (var r = 0; ((r < q.length)); r++) {\n                        if (((q[r] == this._id))) {\n                            q.splice(r, 1);\n                            if (((q.length === 0))) {\n                                delete q[p];\n                            }\n                        ;\n                        ;\n                            break;\n                        }\n                    ;\n                    ;\n                    };\n                }\n            ;\n            ;\n            };\n        ;\n            delete m[this._id];\n        }\n    });\n    e.exports = k;\n});\n__d(\"ArbiterMixin\", [\"Arbiter\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = {\n        _getArbiterInstance: function() {\n            return ((this._arbiter || (this._arbiter = new g())));\n        },\n        inform: function(i, j, k) {\n            return this._getArbiterInstance().inform(i, j, k);\n        },\n        subscribe: function(i, j, k) {\n            return this._getArbiterInstance().subscribe(i, j, k);\n        },\n        unsubscribe: function(i) {\n            this._getArbiterInstance().unsubscribe(i);\n        },\n        registerCallback: function(i, j) {\n            this._getArbiterInstance().registerCallback(i, j);\n        }\n    };\n    e.exports = h;\n});\n__d(\"legacy:ArbiterMixin\", [\"ArbiterMixin\",], function(a, b, c, d) {\n    a.ArbiterMixin = b(\"ArbiterMixin\");\n}, 3);\n__d(\"function-extensions\", [\"createArrayFrom\",], function(a, b, c, d, e, f) {\n    var g = b(\"createArrayFrom\");\n    Function.prototype.curry = function() {\n        var h = g(arguments);\n        return this.bind.apply(this, [null,].concat(h));\n    };\n    Function.prototype.shield = function(h) {\n        if (((typeof this != \"function\"))) {\n            throw new TypeError();\n        }\n    ;\n    ;\n        var i = this.bind.apply(this, g(arguments));\n        return function() {\n            return i();\n        };\n    };\n    Function.prototype.defer = function(h, i) {\n        if (((typeof this != \"function\"))) {\n            throw new TypeError();\n        }\n    ;\n    ;\n        h = ((h || 0));\n        return JSBNG__setTimeout(this, h, i);\n    };\n}, 3);\n__d(\"isEmpty\", [], function(a, b, c, d, e, f) {\n    function g(h) {\n        if (((h instanceof Array))) {\n            return ((h.length === 0));\n        }\n         else if (((h instanceof Object))) {\n            for (var i in h) {\n                return false;\n            };\n        ;\n            return true;\n        }\n         else return !h\n        \n    ;\n    };\n;\n    e.exports = g;\n});\n__d(\"CSSLoader\", [\"isEmpty\",], function(a, b, c, d, e, f) {\n    var g = b(\"isEmpty\"), h = 20, i = 5000, j, k, l = {\n    }, m = [], n, o = {\n    };\n    function p(u) {\n        var v = Array.prototype.slice(arguments, 1);\n        for (var w = 0; ((w < u.length)); w++) {\n            u[w].apply(null, v);\n        ;\n        };\n    ;\n    };\n;\n    function q(u) {\n        if (k) {\n            return;\n        }\n    ;\n    ;\n        k = true;\n        var v = JSBNG__document.createElement(\"link\");\n        v.JSBNG__onload = function() {\n            j = true;\n            v.parentNode.removeChild(v);\n        };\n        v.rel = \"stylesheet\";\n        v.href = \"data:text/css;base64,\";\n        u.appendChild(v);\n    };\n;\n    function r() {\n        var u, v = [], w = [];\n        if (((JSBNG__Date.now() >= n))) {\n            for (u in o) {\n                w.push(o[u].signal);\n                v.push(o[u].error);\n            };\n        ;\n            o = {\n            };\n        }\n         else for (u in o) {\n            var x = o[u].signal, y = ((window.JSBNG__getComputedStyle ? JSBNG__getComputedStyle(x, null) : x.currentStyle));\n            if (((y && ((parseInt(y.height, 10) > 1))))) {\n                v.push(o[u].load);\n                w.push(x);\n                delete o[u];\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        for (var z = 0; ((z < w.length)); z++) {\n            w[z].parentNode.removeChild(w[z]);\n        ;\n        };\n    ;\n        if (!g(v)) {\n            p(v);\n            n = ((JSBNG__Date.now() + i));\n        }\n    ;\n    ;\n        return g(o);\n    };\n;\n    function s(u, v, w, x) {\n        var y = JSBNG__document.createElement(\"meta\");\n        y.id = ((\"bootloader_\" + u.replace(/[^a-z0-9]/gi, \"_\")));\n        v.appendChild(y);\n        var z = !g(o);\n        n = ((JSBNG__Date.now() + i));\n        o[u] = {\n            signal: y,\n            load: w,\n            error: x\n        };\n        if (!z) {\n            var aa = JSBNG__setInterval(function ba() {\n                if (r()) {\n                    JSBNG__clearInterval(aa);\n                }\n            ;\n            ;\n            }, h, false);\n        }\n    ;\n    ;\n    };\n;\n    var t = {\n        loadStyleSheet: function(u, v, w, x, y) {\n            if (l[u]) {\n                throw new Error(((((\"CSS component \" + u)) + \" has already been requested.\")));\n            }\n        ;\n        ;\n            if (JSBNG__document.createStyleSheet) {\n                var z;\n                for (var aa = 0; ((aa < m.length)); aa++) {\n                    if (((m[aa].imports.length < 31))) {\n                        z = aa;\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n                if (((z === undefined))) {\n                    m.push(JSBNG__document.createStyleSheet());\n                    z = ((m.length - 1));\n                }\n            ;\n            ;\n                m[z].addImport(v);\n                l[u] = {\n                    styleSheet: m[z],\n                    uri: v\n                };\n                s(u, w, x, y);\n                return;\n            }\n        ;\n        ;\n            var ba = JSBNG__document.createElement(\"link\");\n            ba.rel = \"stylesheet\";\n            ba.type = \"text/css\";\n            ba.href = v;\n            l[u] = {\n                link: ba\n            };\n            if (j) {\n                ba.JSBNG__onload = function() {\n                    ba.JSBNG__onload = ba.JSBNG__onerror = null;\n                    x();\n                };\n                ba.JSBNG__onerror = function() {\n                    ba.JSBNG__onload = ba.JSBNG__onerror = null;\n                    y();\n                };\n            }\n             else {\n                s(u, w, x, y);\n                if (((j === undefined))) {\n                    q(w);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            w.appendChild(ba);\n        },\n        registerLoadedStyleSheet: function(u, v) {\n            if (l[u]) {\n                throw new Error(((((\"CSS component \" + u)) + \" has already been registered.\")));\n            }\n        ;\n        ;\n            l[u] = {\n                link: v\n            };\n        },\n        unloadStyleSheet: function(u) {\n            if (((!u in l))) {\n                return;\n            }\n        ;\n        ;\n            var v = l[u], w = v.link;\n            if (w) {\n                w.JSBNG__onload = w.JSBNG__onerror = null;\n                w.parentNode.removeChild(w);\n            }\n             else {\n                var x = v.styleSheet;\n                for (var y = 0; ((y < x.imports.length)); y++) {\n                    if (((x.imports[y].href == v.uri))) {\n                        x.removeImport(y);\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            delete o[u];\n            delete l[u];\n        }\n    };\n    e.exports = t;\n});\n__d(\"Bootloader\", [\"function-extensions\",\"Arbiter\",\"CSSLoader\",\"Env\",\"createArrayFrom\",\"isEmpty\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"CSSLoader\"), i = b(\"Env\"), j = b(\"createArrayFrom\"), k = b(\"isEmpty\"), l = {\n    }, m = {\n    }, n = {\n    }, o = null, p = {\n    }, q = {\n    }, r = false, s = [];\n    function t(x, y, z, aa) {\n        var ba = w.done.curry([z,], ((x == \"css\")));\n        if (((x == \"js\"))) {\n            var ca = JSBNG__document.createElement(\"script\");\n            ca.src = y;\n            ca.async = true;\n            var da = p[z];\n            if (((((da && da.crossOrigin)) && i.crossorigin_attribute))) {\n                ca.crossOrigin = \"anonymous\";\n            }\n        ;\n        ;\n            ca.JSBNG__onload = ca.JSBNG__onerror = ba;\n            ca.JSBNG__onreadystatechange = function() {\n                if (((this.readyState in {\n                    loaded: 1,\n                    complete: 1\n                }))) {\n                    ba();\n                }\n            ;\n            ;\n            };\n            aa.appendChild(ca);\n        }\n         else if (((x == \"css\"))) {\n            h.loadStyleSheet(z, y, aa, ba, function() {\n                ba();\n            });\n        }\n        \n    ;\n    ;\n    };\n;\n    function u(x) {\n        if (!p[x]) {\n            return;\n        }\n    ;\n    ;\n        if (((p[x].type == \"css\"))) {\n            h.unloadStyleSheet(x);\n            delete l[x];\n            g.inform(((((g.BOOTLOAD + \"/\")) + x)), null, g.BEHAVIOR_STATE);\n        }\n    ;\n    ;\n    };\n;\n    function v(x, y) {\n        if (!r) {\n            s.push([x,y,]);\n            return;\n        }\n    ;\n    ;\n        x = j(x);\n        var z = [];\n        for (var aa = 0; ((aa < x.length)); ++aa) {\n            if (!x[aa]) {\n                continue;\n            }\n        ;\n        ;\n            var ba = n[x[aa]];\n            if (ba) {\n                var ca = ba.resources;\n                for (var da = 0; ((da < ca.length)); ++da) {\n                    z.push(ca[da]);\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n        };\n    ;\n        w.loadResources(z, y);\n    };\n;\n    var w = {\n        configurePage: function(x) {\n            var y = {\n            }, z = w.resolveResources(x), aa;\n            for (aa = 0; ((aa < z.length)); aa++) {\n                y[z[aa].src] = z[aa];\n                w.requested(z[aa].JSBNG__name);\n            };\n        ;\n            var ba = JSBNG__document.getElementsByTagName(\"link\");\n            for (aa = 0; ((aa < ba.length)); ++aa) {\n                if (((ba[aa].rel != \"stylesheet\"))) {\n                    continue;\n                }\n            ;\n            ;\n                for (var ca in y) {\n                    if (((ba[aa].href.indexOf(ca) !== -1))) {\n                        var da = y[ca].JSBNG__name;\n                        if (y[ca].permanent) {\n                            m[da] = true;\n                        }\n                    ;\n                    ;\n                        delete y[ca];\n                        h.registerLoadedStyleSheet(da, ba[aa]);\n                        w.done([da,], true);\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n        },\n        loadComponents: function(x, y) {\n            x = j(x);\n            var z = [], aa = [];\n            for (var ba = 0; ((ba < x.length)); ba++) {\n                var ca = n[x[ba]];\n                if (((ca && !ca.module))) {\n                    continue;\n                }\n            ;\n            ;\n                var da = ((\"legacy:\" + x[ba]));\n                if (n[da]) {\n                    x[ba] = da;\n                    z.push(da);\n                }\n                 else if (((ca && ca.module))) {\n                    z.push(x[ba]);\n                    if (!ca.runWhenReady) {\n                        aa.push(x[ba]);\n                    }\n                ;\n                ;\n                }\n                \n            ;\n            ;\n            };\n        ;\n            v(x, ((z.length ? d.curry(z, y) : y)));\n        },\n        loadModules: function(x, y) {\n            var z = [], aa = [];\n            for (var ba = 0; ((ba < x.length)); ba++) {\n                var ca = n[x[ba]];\n                if (((!ca || ca.module))) {\n                    z.push(x[ba]);\n                }\n            ;\n            ;\n            };\n        ;\n            v(x, d.curry(z, y));\n        },\n        loadResources: function(x, y, z, aa) {\n            var ba;\n            x = w.resolveResources(j(x));\n            if (z) {\n                var ca = {\n                };\n                for (ba = 0; ((ba < x.length)); ++ba) {\n                    ca[x[ba].JSBNG__name] = true;\n                ;\n                };\n            ;\n                for (var da in l) {\n                    if (((((!((da in m)) && !((da in ca)))) && !((da in q))))) {\n                        u(da);\n                    }\n                ;\n                ;\n                };\n            ;\n                q = {\n                };\n            }\n        ;\n        ;\n            var ea = [], fa = [];\n            for (ba = 0; ((ba < x.length)); ++ba) {\n                var ga = x[ba];\n                if (ga.permanent) {\n                    m[ga.JSBNG__name] = true;\n                }\n            ;\n            ;\n                var ha = ((((g.BOOTLOAD + \"/\")) + ga.JSBNG__name));\n                if (((g.query(ha) !== null))) {\n                    continue;\n                }\n            ;\n            ;\n                if (!ga.nonblocking) {\n                    fa.push(ha);\n                }\n            ;\n            ;\n                if (!l[ga.JSBNG__name]) {\n                    w.requested(ga.JSBNG__name);\n                    ea.push(ga);\n                    ((window.CavalryLogger && window.CavalryLogger.getInstance().measureResources(ga, aa)));\n                }\n            ;\n            ;\n            };\n        ;\n            if (y) {\n                y = g.registerCallback(y, fa);\n            }\n        ;\n        ;\n            var ia = ((JSBNG__document.documentMode || +((/MSIE.(\\d+)/.exec(JSBNG__navigator.userAgent) || []))[1])), ja = w.getHardpoint(), ka = ((ia ? ja : JSBNG__document.createDocumentFragment()));\n            for (ba = 0; ((ba < ea.length)); ++ba) {\n                t(ea[ba].type, ea[ba].src, ea[ba].JSBNG__name, ka);\n            ;\n            };\n        ;\n            if (((ja !== ka))) {\n                ja.appendChild(ka);\n            }\n        ;\n        ;\n            return y;\n        },\n        requestResource: function(x, y, z) {\n            var aa = w.getHardpoint();\n            t(x, y, z, aa);\n        },\n        done: ((window.top.JSBNG_Replay.push)((window.top.JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_84), function(x, y) {\n            w.requested(x);\n            if (!y) {\n                var z = {\n                    sender: this\n                };\n                g.inform(g.BOOTLOAD, z, g.BEHAVIOR_EVENT);\n            }\n        ;\n        ;\n            for (var aa = 0; ((aa < x.length)); ++aa) {\n                var ba = x[aa];\n                g.inform(((((g.BOOTLOAD + \"/\")) + ba)), true, g.BEHAVIOR_STATE);\n            };\n        ;\n        })),\n        requested: function(x) {\n            x = j(x);\n            for (var y = 0; ((y < x.length)); ++y) {\n                l[x[y]] = true;\n            ;\n            };\n        ;\n        },\n        enableBootload: function(x) {\n            for (var y in x) {\n                if (!n[y]) {\n                    n[y] = x[y];\n                }\n            ;\n            ;\n            };\n        ;\n            if (!r) {\n                r = true;\n                for (var z = 0; ((z < s.length)); z++) {\n                    v.apply(null, s[z]);\n                ;\n                };\n            ;\n                s = [];\n            }\n        ;\n        ;\n        },\n        getHardpoint: function() {\n            if (!o) {\n                var x = JSBNG__document.getElementsByTagName(\"head\");\n                o = ((((x.length && x[0])) || JSBNG__document.body));\n            }\n        ;\n        ;\n            return o;\n        },\n        setResourceMap: function(x) {\n            if (!x) {\n                return;\n            }\n        ;\n        ;\n            var y = [];\n            for (var z in x) {\n                if (!p[z]) {\n                    if (!x[z].JSBNG__name) {\n                        x[z].JSBNG__name = z;\n                    }\n                ;\n                ;\n                    p[z] = x[z];\n                    if (p[z].preloadable) {\n                        y.push(p[z]);\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            w.loadResources(y);\n        },\n        resolveResources: function(x) {\n            if (!x) {\n                return [];\n            }\n        ;\n        ;\n            var y = [];\n            for (var z = 0; ((z < x.length)); ++z) {\n                if (((typeof x[z] == \"string\"))) {\n                    if (((x[z] in p))) {\n                        y.push(p[x[z]]);\n                    }\n                ;\n                ;\n                }\n                 else y.push(x[z]);\n            ;\n            ;\n            };\n        ;\n            return y;\n        },\n        loadEarlyResources: function(x) {\n            var y;\n            w.setResourceMap(x);\n            var z = [];\n            for (y in x) {\n                z.push(p[y]);\n            ;\n            };\n        ;\n            w.loadResources(z);\n            for (y in x) {\n                var aa = p[y];\n                if (!aa.permanent) {\n                    q[aa.JSBNG__name] = aa;\n                }\n            ;\n            ;\n            };\n        ;\n        }\n    };\n    e.exports = w;\n});\n__d(\"ge\", [], function(a, b, c, d, e, f) {\n    function g(h) {\n        return ((((typeof h == \"string\")) ? JSBNG__document.getElementById(h) : h));\n    };\n;\n    e.exports = g;\n});\n__d(\"$\", [\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"ge\");\n    function h(i) {\n        var j = g(i);\n        return j;\n    };\n;\n    e.exports = h;\n});\n__d(\"CSS\", [\"$\",], function(a, b, c, d, e, f) {\n    var g = b(\"$\"), h = \"hidden_elem\", i = {\n        setClass: function(j, k) {\n            g(j).className = ((k || \"\"));\n            return j;\n        },\n        hasClass: function(j, k) {\n            j = g(j);\n            return ((((((\" \" + j.className)) + \" \")).indexOf(((((\" \" + k)) + \" \"))) > -1));\n        },\n        addClass: function(j, k) {\n            j = g(j);\n            if (((k && !i.hasClass(j, k)))) {\n                j.className = ((((j.className + \" \")) + k));\n            }\n        ;\n        ;\n            return j;\n        },\n        removeClass: function(j, k) {\n            j = g(j);\n            if (i.hasClass(j, k)) {\n                j.className = j.className.replace(new RegExp(((((\"(^|\\\\s)\" + k)) + \"(?:\\\\s|$)\")), \"g\"), \"$1\").replace(/\\s+/g, \" \").replace(/^\\s*|\\s*$/g, \"\");\n            }\n        ;\n        ;\n            return j;\n        },\n        conditionClass: function(j, k, l) {\n            return ((l ? i.addClass : i.removeClass))(j, k);\n        },\n        toggleClass: function(j, k) {\n            return i.conditionClass(j, k, !i.hasClass(j, k));\n        },\n        shown: function(j) {\n            return !i.hasClass(j, h);\n        },\n        hide: function(j) {\n            return i.addClass(j, h);\n        },\n        show: function(j) {\n            return i.removeClass(j, h);\n        },\n        toggle: function(j) {\n            return i.toggleClass(j, h);\n        },\n        conditionShow: function(j, k) {\n            return i.conditionClass(j, h, !k);\n        }\n    };\n    e.exports = i;\n});\n__d(\"BlueBarController\", [\"Bootloader\",\"CSS\",], function(a, b, c, d, e, f) {\n    var g = b(\"Bootloader\"), h = b(\"CSS\");\n    f.init = function(i) {\n        if (((\"getBoundingClientRect\" in i))) {\n            var j = function() {\n                var k = i.getBoundingClientRect(), l = ((Math.round(k.JSBNG__top) - JSBNG__document.documentElement.clientTop));\n                h.conditionClass(i.firstChild, \"fixed_elem\", ((l <= 0)));\n            };\n            j();\n            g.loadModules([\"event-extensions\",], function() {\n                JSBNG__Event.listen(window, \"JSBNG__scroll\", j);\n            });\n        }\n    ;\n    ;\n    };\n});\n__d(\"legacy:css-core\", [\"CSS\",], function(a, b, c, d) {\n    a.CSS = b(\"CSS\");\n}, 3);\n__d(\"legacy:dom-core\", [\"$\",\"ge\",], function(a, b, c, d) {\n    a.$ = b(\"$\");\n    a.ge = b(\"ge\");\n}, 3);\n__d(\"Parent\", [\"CSS\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = {\n        byTag: function(i, j) {\n            j = j.toUpperCase();\n            while (((i && ((i.nodeName != j))))) {\n                i = i.parentNode;\n            ;\n            };\n        ;\n            return i;\n        },\n        byClass: function(i, j) {\n            while (((i && !g.hasClass(i, j)))) {\n                i = i.parentNode;\n            ;\n            };\n        ;\n            return i;\n        },\n        byAttribute: function(i, j) {\n            while (((i && ((!i.getAttribute || !i.getAttribute(j)))))) {\n                i = i.parentNode;\n            ;\n            };\n        ;\n            return i;\n        }\n    };\n    e.exports = h;\n});\n__d(\"legacy:parent\", [\"Parent\",], function(a, b, c, d) {\n    a.Parent = b(\"Parent\");\n}, 3);\n__d(\"legacy:arbiter\", [\"Arbiter\",], function(a, b, c, d) {\n    a.Arbiter = b(\"Arbiter\");\n}, 3);\n__d(\"event-form-bubbling\", [], function(a, b, c, d, e, f) {\n    a.JSBNG__Event = ((a.JSBNG__Event || function() {\n    \n    }));\n    a.JSBNG__Event.__inlineSubmit = function(g, JSBNG__event) {\n        var h = ((a.JSBNG__Event.__getHandler && a.JSBNG__Event.__getHandler(g, \"submit\")));\n        return ((h ? null : a.JSBNG__Event.__bubbleSubmit(g, JSBNG__event)));\n    };\n    a.JSBNG__Event.__bubbleSubmit = function(g, JSBNG__event) {\n        if (JSBNG__document.documentElement.JSBNG__attachEvent) {\n            var h;\n            while (((((h !== false)) && (g = g.parentNode)))) {\n                h = ((g.JSBNG__onsubmit ? g.JSBNG__onsubmit(JSBNG__event) : ((a.JSBNG__Event.__fire && a.JSBNG__Event.__fire(g, \"submit\", JSBNG__event)))));\n            ;\n            };\n        ;\n            return h;\n        }\n    ;\n    ;\n    };\n}, 3);\n__d(\"OnloadEvent\", [], function(a, b, c, d, e, f) {\n    var g = {\n        ONLOAD: \"JSBNG__onload/onload\",\n        ONLOAD_CALLBACK: \"JSBNG__onload/onload_callback\",\n        ONLOAD_DOMCONTENT: \"JSBNG__onload/dom_content_ready\",\n        ONLOAD_DOMCONTENT_CALLBACK: \"JSBNG__onload/domcontent_callback\",\n        ONBEFOREUNLOAD: \"JSBNG__onload/beforeunload\",\n        ONUNLOAD: \"JSBNG__onload/unload\"\n    };\n    e.exports = g;\n});\n__d(\"Run\", [\"Arbiter\",\"OnloadEvent\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"OnloadEvent\"), i = g.BEHAVIOR_STATE;\n    function j(x) {\n        var y = a.CavalryLogger;\n        ((y && y.getInstance().setTimeStamp(x)));\n    };\n;\n    function k() {\n        return !window.loading_page_chrome;\n    };\n;\n    function l(x) {\n        var y = a.OnloadHooks;\n        if (((window.loaded && y))) {\n            y.runHook(x, \"JSBNG__onlateloadhooks\");\n        }\n         else q(\"JSBNG__onloadhooks\", x);\n    ;\n    ;\n    };\n;\n    function m(x) {\n        var y = a.OnloadHooks;\n        if (((window.afterloaded && y))) {\n            JSBNG__setTimeout(function() {\n                y.runHook(x, \"JSBNG__onlateafterloadhooks\");\n            }, 0);\n        }\n         else q(\"JSBNG__onafterloadhooks\", x);\n    ;\n    ;\n    };\n;\n    function n(x, y) {\n        if (((y === undefined))) {\n            y = k();\n        }\n    ;\n    ;\n        ((y ? q(\"JSBNG__onbeforeleavehooks\", x) : q(\"JSBNG__onbeforeunloadhooks\", x)));\n    };\n;\n    function o(x) {\n        if (!window.JSBNG__onunload) {\n            window.JSBNG__onunload = function() {\n                g.inform(h.ONUNLOAD, true, i);\n            };\n        }\n    ;\n    ;\n        q(\"JSBNG__onunloadhooks\", x);\n    };\n;\n    function p(x) {\n        q(\"JSBNG__onleavehooks\", x);\n    };\n;\n    function q(x, y) {\n        window[x] = ((window[x] || [])).concat(y);\n    };\n;\n    function r(x) {\n        window[x] = [];\n    };\n;\n    {\n        function s() {\n            g.inform(h.ONLOAD_DOMCONTENT, true, i);\n        };\n        ((window.top.JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_136.push)((s)));\n    };\n;\n    a._domcontentready = s;\n    function t() {\n        var x = JSBNG__document, y = window;\n        if (x.JSBNG__addEventListener) {\n            var z = /AppleWebKit.(\\d+)/.exec(JSBNG__navigator.userAgent);\n            if (((z && ((z[1] < 525))))) {\n                var aa = JSBNG__setInterval(function() {\n                    if (/loaded|complete/.test(x.readyState)) {\n                        s();\n                        JSBNG__clearInterval(aa);\n                    }\n                ;\n                ;\n                }, 10);\n            }\n             else x.JSBNG__addEventListener(\"DOMContentLoaded\", s, true);\n        ;\n        ;\n        }\n         else {\n            var ba = \"javascript:void(0)\";\n            if (((y.JSBNG__location.protocol == \"https:\"))) {\n                ba = \"//:\";\n            }\n        ;\n        ;\n            x.write(((((((((\"\\u003Cscript onreadystatechange=\\\"if (this.readyState=='complete') {\" + \"this.parentNode.removeChild(this);_domcontentready();}\\\" \")) + \"defer=\\\"defer\\\" src=\\\"\")) + ba)) + \"\\\"\\u003E\\u003C/script\\u003E\")));\n        }\n    ;\n    ;\n        var ca = y.JSBNG__onload;\n        y.JSBNG__onload = ((window.top.JSBNG_Replay.push)((window.top.JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_139), function() {\n            j(\"t_layout\");\n            ((ca && ca()));\n            g.inform(h.ONLOAD, true, i);\n        }));\n        y.JSBNG__onbeforeunload = ((window.top.JSBNG_Replay.push)((window.top.JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_140), function() {\n            var da = {\n            };\n            g.inform(h.ONBEFOREUNLOAD, da, i);\n            if (!da.warn) {\n                g.inform(\"JSBNG__onload/exit\", true);\n            }\n        ;\n        ;\n            return da.warn;\n        }));\n    };\n;\n    var u = g.registerCallback(function() {\n        j(\"t_onload\");\n        g.inform(h.ONLOAD_CALLBACK, true, i);\n    }, [h.ONLOAD,]), v = g.registerCallback(function() {\n        j(\"t_domcontent\");\n        g.inform(h.ONLOAD_DOMCONTENT_CALLBACK, true, i);\n    }, [h.ONLOAD_DOMCONTENT,]);\n    t();\n    var w = {\n        JSBNG__onLoad: l,\n        JSBNG__onAfterLoad: m,\n        JSBNG__onLeave: p,\n        JSBNG__onBeforeUnload: n,\n        JSBNG__onUnload: o,\n        __domContentCallback: v,\n        __onloadCallback: u,\n        __removeHook: r\n    };\n    e.exports = w;\n});\n__d(\"legacy:onload\", [\"Run\",\"OnloadEvent\",], function(a, b, c, d) {\n    var e = b(\"Run\");\n    a.OnloadEvent = b(\"OnloadEvent\");\n    a.JSBNG__onloadRegister_DEPRECATED = e.JSBNG__onLoad;\n    a.JSBNG__onloadRegister = function() {\n        return e.JSBNG__onLoad.apply(this, arguments);\n    };\n    a.JSBNG__onafterloadRegister_DEPRECATED = e.JSBNG__onAfterLoad;\n    a.JSBNG__onafterloadRegister = function() {\n        return e.JSBNG__onAfterLoad.apply(this, arguments);\n    };\n    a.JSBNG__onleaveRegister = e.JSBNG__onLeave;\n    a.JSBNG__onbeforeunloadRegister = e.JSBNG__onBeforeUnload;\n    a.JSBNG__onunloadRegister = e.JSBNG__onUnload;\n}, 3);\n__d(\"wait_for_load\", [\"Bootloader\",\"Run\",], function(a, b, c, d, e, f) {\n    var g = b(\"Bootloader\"), h = b(\"Run\");\n    function i(l, m) {\n        return ((window.loaded && m.call(l)));\n    };\n;\n    function j(l, m, n) {\n        g.loadComponents.call(g, m, n.bind(l));\n        return false;\n    };\n;\n    function k(l, m, n) {\n        n = n.bind(l, m);\n        if (window.loaded) {\n            return n();\n        }\n    ;\n    ;\n        switch (((m || JSBNG__event)).type) {\n          case \"load\":\n        \n          case \"JSBNG__focus\":\n            h.JSBNG__onAfterLoad(n);\n            return;\n          case \"click\":\n            var o = l.style, p = JSBNG__document.body.style;\n            o.cursor = p.cursor = \"progress\";\n            h.JSBNG__onAfterLoad(function() {\n                o.cursor = p.cursor = \"\";\n                if (((l.tagName.toLowerCase() == \"a\"))) {\n                    if (((((false !== n())) && l.href))) {\n                        window.JSBNG__location.href = l.href;\n                    }\n                ;\n                ;\n                }\n                 else if (l.click) {\n                    l.click();\n                }\n                \n            ;\n            ;\n            });\n            break;\n        };\n    ;\n        return false;\n    };\n;\n    a.run_if_loaded = i;\n    a.run_with = j;\n    a.wait_for_load = k;\n}, 3);\n__d(\"Intl\", [], function(a, b, c, d, e, f) {\n    function g(i) {\n        if (((typeof i != \"string\"))) {\n            return false;\n        }\n    ;\n    ;\n        return i.match(new RegExp(((((((((((((((((((((((((((((((((((((((((((((((((((((g.punct_char_class + \"[\")) + \")\\\"\")) + \"'\")) + \"\\u00bb\")) + \"\\u0f3b\")) + \"\\u0f3d\")) + \"\\u2019\")) + \"\\u201d\")) + \"\\u203a\")) + \"\\u3009\")) + \"\\u300b\")) + \"\\u300d\")) + \"\\u300f\")) + \"\\u3011\")) + \"\\u3015\")) + \"\\u3017\")) + \"\\u3019\")) + \"\\u301b\")) + \"\\u301e\")) + \"\\u301f\")) + \"\\ufd3f\")) + \"\\uff07\")) + \"\\uff09\")) + \"\\uff3d\")) + \"s\")) + \"]*$\"))));\n    };\n;\n    g.punct_char_class = ((((((((((((((((((((((\"[\" + \".!?\")) + \"\\u3002\")) + \"\\uff01\")) + \"\\uff1f\")) + \"\\u0964\")) + \"\\u2026\")) + \"\\u0eaf\")) + \"\\u1801\")) + \"\\u0e2f\")) + \"\\uff0e\")) + \"]\"));\n    function h(i) {\n        var j = window.intl_locale_rewrites;\n        if (j) {\n            var k = [], l = [];\n            for (var m in j.patterns) {\n                var n = j.patterns[m];\n                for (var o in j.meta) {\n                    var p = new RegExp(o.slice(1, -1), \"g\"), q = j.meta[o];\n                    m = m.replace(p, q);\n                    n = n.replace(p, q);\n                };\n            ;\n                k.push(m);\n                l.push(n);\n            };\n        ;\n            for (var r = 0; ((r < k.length)); r++) {\n                var s = new RegExp(k[r].slice(1, -1), \"g\");\n                if (((l[r] == \"javascript\"))) {\n                    i.replace(s, function(t) {\n                        return t.slice(1).toLowerCase();\n                    });\n                }\n                 else i = i.replace(s, l[r]);\n            ;\n            ;\n            };\n        ;\n        }\n    ;\n    ;\n        return i.replace(/\\x01/g, \"\");\n    };\n;\n    e.exports = {\n        endsInPunct: g,\n        phonologicalRules: h\n    };\n});\n__d(\"tx\", [\"Intl\",], function(a, b, c, d, e, f) {\n    var g = b(\"Intl\");\n    function h(j, k) {\n        if (!k) {\n            return j;\n        }\n    ;\n    ;\n        var l = ((((\"\\\\{([^}]+)\\\\}(\" + g.endsInPunct.punct_char_class)) + \"*)\")), m = new RegExp(l, \"g\"), n = [], o = j.replace(m, function(r, s, t) {\n            var u = k[s];\n            if (((u && ((typeof u === \"object\"))))) {\n                n.push(u);\n                return ((\"\\u0017\" + t));\n            }\n        ;\n        ;\n            return ((u + ((g.endsInPunct(u) ? \"\" : t))));\n        }).split(\"\\u0017\").map(g.phonologicalRules);\n        if (((o.length === 1))) {\n            return o[0];\n        }\n    ;\n    ;\n        var p = [o[0],];\n        for (var q = 0; ((q < n.length)); q++) {\n            p.push(n[q], o[((q + 1))]);\n        ;\n        };\n    ;\n        return p;\n    };\n;\n    function i(j, k) {\n        if (((typeof _string_table == \"undefined\"))) {\n            return;\n        }\n    ;\n    ;\n        j = _string_table[j];\n        return h(j, k);\n    };\n;\n    i._ = h;\n    e.exports = i;\n});\n__d(\"legacy:intl-core\", [\"tx\",], function(a, b, c, d) {\n    var e = b(\"tx\");\n    a.tx = e;\n    a._tx = e._;\n}, 3);\n__d(\"array-extensions\", [], function(a, b, c, d, e, f) {\n    Array.prototype.contains = function(g) {\n        return ((this.indexOf(g) != -1));\n    };\n    Array.prototype.remove = function(g) {\n        var h = this.indexOf(g);\n        if (((h != -1))) {\n            this.splice(h, 1);\n        }\n    ;\n    ;\n    };\n}, 3);\n__d(\"JSCC\", [\"isEmpty\",], function(a, b, c, d, e, f) {\n    var g = b(\"isEmpty\"), h = {\n    }, i = {\n    };\n    function j(m) {\n        var n, o = false;\n        return function() {\n            if (!o) {\n                n = m();\n                o = true;\n            }\n        ;\n        ;\n            return n;\n        };\n    };\n;\n    function k(m, n) {\n        if (g(m)) {\n            return;\n        }\n    ;\n    ;\n        for (var o in m) {\n            h[o] = j(m[o]);\n            if (n) {\n                if (!i[n]) {\n                    i[n] = [];\n                }\n            ;\n            ;\n                i[n].push(o);\n            }\n        ;\n        ;\n        };\n    ;\n    };\n;\n    var l = {\n        get: function(m) {\n            if (!h[m]) {\n                throw new Error(\"JSCC entry is missing\");\n            }\n        ;\n        ;\n            return h[m]();\n        },\n        init: function(m) {\n            k(m);\n        },\n        initForPagelet: function(m, n) {\n            k(n, m);\n        },\n        clearForPagelet: function(m) {\n            if (i[m]) {\n                for (var n = 0; ((n < i[m].length)); n++) {\n                    var o = i[m][n];\n                    delete h[o];\n                };\n            ;\n                delete i[m];\n            }\n        ;\n        ;\n        }\n    };\n    e.exports = l;\n});\n__d(\"ServerJS\", [\"function-extensions\",\"ErrorUtils\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"ErrorUtils\"), h = b(\"copyProperties\");\n    function i() {\n        this._moduleMap = {\n        };\n        this._relativeTo = null;\n    };\n;\n    h(i.prototype, {\n        handle: function(n) {\n            g.applyWithGuard(function(o) {\n                if (o.__guard) {\n                    throw new Error(\"ServerJS.handle called on data that has already been handled\");\n                }\n            ;\n            ;\n                o.__guard = true;\n                k(((o.define || [])), this._handleDefine, this);\n                k(((o.markup || [])), this._handleMarkup, this);\n                k(((o.elements || [])), this._handleElement, this);\n                k(((o.instances || [])), this._handleInstance, this);\n                k(((o.require || [])), this._handleRequire, this);\n            }, this, [].concat(n));\n        },\n        handlePartial: function(n) {\n            ((n.instances || [])).forEach(l.curry(this._moduleMap, 3));\n            ((n.markup || [])).forEach(l.curry(this._moduleMap, 2));\n            this.handle(n);\n        },\n        cleanup: function() {\n            var n = [];\n            for (var o in this._moduleMap) {\n                n.push(o);\n            ;\n            };\n        ;\n            d.call(null, n, m);\n            this._moduleMap = {\n            };\n        },\n        setRelativeTo: function(n) {\n            this._relativeTo = n;\n            return this;\n        },\n        _handleDefine: function(n, o, p) {\n            define(n, o, function() {\n                this._replaceTransportMarkers(p);\n                return p;\n            }.bind(this));\n        },\n        _handleRequire: function(n, o, p, q) {\n            var r = [n,].concat(((p || [])));\n            d(r, function(s) {\n                ((q && this._replaceTransportMarkers(q)));\n                if (o) {\n                    if (!s[o]) {\n                        throw new TypeError(((((((\"Module \" + n)) + \" has no method \")) + o)));\n                    }\n                ;\n                ;\n                    s[o].apply(s, ((q || [])));\n                }\n            ;\n            ;\n            }.bind(this));\n        },\n        _handleInstance: function(n, o, p, q) {\n            var r = null;\n            if (o) {\n                r = function(s) {\n                    this._replaceTransportMarkers(p);\n                    var t = Object.create(s.prototype);\n                    s.apply(t, p);\n                    return t;\n                }.bind(this);\n            }\n        ;\n        ;\n            define(n, o, r, 0, null, q);\n        },\n        _handleMarkup: function(n, o, p) {\n            define(n, [\"HTML\",], function(q) {\n                return q.replaceJSONWrapper(o).getRootNode();\n            }, 0, null, p);\n        },\n        _handleElement: function(n, o, p, q) {\n            var r = ((q ? [q,] : []));\n            define(n, r, function(s) {\n                var t = j(o, s);\n                return t;\n            }, 0, null, p);\n        },\n        _replaceTransportMarkers: function(n, o) {\n            var p = ((((typeof o !== \"undefined\")) ? n[o] : n)), q;\n            if (Array.isArray(p)) {\n                for (q = 0; ((q < p.length)); q++) {\n                    this._replaceTransportMarkers(p, q);\n                ;\n                };\n            ;\n            }\n             else if (((p && ((typeof p == \"object\"))))) {\n                if (p.__m) {\n                    n[o] = b(p.__m);\n                }\n                 else if (p.__e) {\n                    n[o] = j(p.__e);\n                }\n                 else if (p.__rel) {\n                    n[o] = this._relativeTo;\n                }\n                 else for (var r in p) {\n                    this._replaceTransportMarkers(p, r);\n                ;\n                }\n                \n                \n            ;\n            }\n            \n        ;\n        ;\n        }\n    });\n    function j(n, o) {\n        var p, q, r;\n        if (o) {\n            if (((o.id == n))) {\n                p = o;\n            }\n             else if (o.getElementsByTagName) {\n                q = o.getElementsByTagName(\"*\");\n                for (r = 0; ((r < q.length)); r++) {\n                    if (((q[r].id == n))) {\n                        p = q[r];\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n            }\n             else {\n                q = o.childNodes;\n                for (r = 0; ((r < q.length)); r++) {\n                    p = j(n, q[r]);\n                    if (p) {\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n            }\n            \n        ;\n        ;\n        }\n         else p = JSBNG__document.getElementById(n);\n    ;\n    ;\n        return p;\n    };\n;\n    function k(n, o, p) {\n        for (var q = 0; ((q < n.length)); q++) {\n            o.apply(p, [].concat(n[q]));\n        ;\n        };\n    ;\n    };\n;\n    function l(n, o, p) {\n        var q = p[0];\n        if (!((q in n))) {\n            p[o] = ((((p[o] || 0)) + 1));\n        }\n    ;\n    ;\n        n[q] = true;\n    };\n;\n    function m() {\n        return {\n        };\n    };\n;\n    e.exports = i;\n});\n__d(\"invokeCallbacks\", [\"ErrorUtils\",], function(a, b, c, d, e, f) {\n    var g = b(\"ErrorUtils\");\n    function h(i, j) {\n        if (i) {\n            for (var k = 0; ((k < i.length)); k++) {\n                g.applyWithGuard(new Function(i[k]), j);\n            ;\n            };\n        }\n    ;\n    ;\n    };\n;\n    e.exports = h;\n});\n__d(\"BigPipe\", [\"Arbiter\",\"Bootloader\",\"Env\",\"JSCC\",\"OnloadEvent\",\"Run\",\"ServerJS\",\"$\",\"copyProperties\",\"ge\",\"hasArrayNature\",\"invokeCallbacks\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"Bootloader\"), i = b(\"Env\"), j = b(\"JSCC\"), k = b(\"OnloadEvent\"), l = b(\"Run\"), m = b(\"ServerJS\"), n = b(\"$\"), o = b(\"copyProperties\"), p = b(\"ge\"), q = b(\"hasArrayNature\"), r = b(\"invokeCallbacks\"), s = ((JSBNG__document.documentMode || +((/MSIE.(\\d+)/.exec(JSBNG__navigator.userAgent) || []))[1])), t = g.BEHAVIOR_STATE, u = g.BEHAVIOR_PERSISTENT;\n    function v(aa) {\n        return ((((!aa || ((q(aa) && ((aa.length === 0)))))) ? {\n        } : aa));\n    };\n;\n    function w(aa) {\n        if (((!aa || ((typeof aa === \"string\"))))) {\n            return aa;\n        }\n    ;\n    ;\n        if (aa.container_id) {\n            var ba = n(aa.container_id);\n            aa = ((x(ba) || \"\"));\n            ba.parentNode.removeChild(ba);\n            return aa;\n        }\n    ;\n    ;\n        return null;\n    };\n;\n    function x(aa) {\n        if (!aa.firstChild) {\n            h.loadModules([\"ErrorSignal\",], function(ca) {\n                ca.sendErrorSignal(\"bigpipe\", \"Pagelet markup container is empty.\");\n            });\n            return null;\n        }\n    ;\n    ;\n        if (((aa.firstChild.nodeType !== 8))) {\n            return null;\n        }\n    ;\n    ;\n        var ba = aa.firstChild.nodeValue;\n        ba = ba.substring(1, ((ba.length - 1)));\n        return ba.replace(/\\\\([\\s\\S]|$)/g, \"$1\");\n    };\n;\n    function y(aa, ba) {\n        var ca = JSBNG__document.createElement(\"div\"), da = ((s < 7));\n        if (da) {\n            aa.appendChild(ca);\n        }\n    ;\n    ;\n        ca.innerHTML = ba;\n        var ea = JSBNG__document.createDocumentFragment();\n        while (ca.firstChild) {\n            ea.appendChild(ca.firstChild);\n        ;\n        };\n    ;\n        aa.appendChild(ea);\n        if (da) {\n            aa.removeChild(ca);\n        }\n    ;\n    ;\n    };\n;\n    function z(aa) {\n        o(this, {\n            arbiter: g,\n            rootNodeID: \"JSBNG__content\",\n            lid: 0,\n            isAjax: false,\n            domContentCallback: l.__domcontentCallback,\n            JSBNG__onloadCallback: l.__onloadCallback,\n            domContentEvt: k.ONLOAD_DOMCONTENT_CALLBACK,\n            JSBNG__onloadEvt: k.ONLOAD_CALLBACK,\n            forceFinish: false,\n            _phaseDoneCallbacks: [],\n            _currentPhase: 0,\n            _lastPhase: -1\n        });\n        o(this, aa);\n        if (this.automatic) {\n            this._relevant_instance = z._current_instance;\n        }\n         else z._current_instance = this;\n    ;\n    ;\n        this._serverJS = new m();\n        g.inform(\"BigPipe/init\", {\n            lid: this.lid,\n            arbiter: this.arbiter\n        }, u);\n        this.arbiter.registerCallback(this._serverJS.cleanup.bind(this._serverJS), [\"pagelet_displayed_all\",]);\n        this.arbiter.registerCallback(this.domContentCallback, [\"pagelet_displayed_all\",]);\n        this._informEventExternal(\"phase_begin\", {\n            phase: 0\n        });\n        this.arbiter.inform(\"phase_begin_0\", true, t);\n        this.JSBNG__onloadCallback = this.arbiter.registerCallback(this.JSBNG__onloadCallback, [\"pagelet_displayed_all\",]);\n    };\n;\n    o(z.prototype, {\n        _displayPageletHandler: function(aa) {\n            if (this.displayCallback) {\n                this.displayCallback(this._displayPagelet.bind(this, aa));\n            }\n             else this._displayPagelet(aa);\n        ;\n        ;\n        },\n        _displayPagelet: function(aa) {\n            this._informPageletEvent(\"display_start\", aa.id);\n            aa.JSBNG__content = v(aa.JSBNG__content);\n            var ba = false;\n            for (var ca in aa.JSBNG__content) {\n                var da = aa.JSBNG__content[ca];\n                if (aa.append) {\n                    ca = this._getAppendTargetID(aa);\n                }\n            ;\n            ;\n                var ea = p(ca);\n                if (ea) {\n                    da = w(da);\n                    if (da) {\n                        if (((!aa.append && aa.has_inline_js))) {\n                            if (((a.DOM && a.HTML))) {\n                                DOM.setContent(ea, HTML(da));\n                            }\n                             else {\n                                ba = true;\n                                h.loadModules([\"DOM\",\"HTML\",], function(ga, ha) {\n                                    ga.setContent(ea, ha(da));\n                                    this._afterMarkupDisplayed(aa);\n                                }.bind(this));\n                            }\n                        ;\n                        ;\n                        }\n                         else if (((aa.append || ((s < 8))))) {\n                            if (!aa.append) {\n                                while (ea.firstChild) {\n                                    ea.removeChild(ea.firstChild);\n                                ;\n                                };\n                            }\n                        ;\n                        ;\n                            y(ea, da);\n                        }\n                         else ea.innerHTML = da;\n                        \n                    ;\n                    }\n                ;\n                ;\n                    var fa = ea.getAttribute(\"data-referrer\");\n                    if (!fa) {\n                        ea.setAttribute(\"data-referrer\", ca);\n                    }\n                ;\n                ;\n                    if (((aa.cache_hit && i.pc_debug))) {\n                        ea.style.border = \"1px red solid\";\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            if (!ba) {\n                this._afterMarkupDisplayed(aa);\n            }\n        ;\n        ;\n        },\n        _afterMarkupDisplayed: function(aa) {\n            if (aa.jsmods) {\n                var ba = JSON.parse(JSON.stringify(aa.jsmods));\n                this._serverJS.handlePartial(ba);\n            }\n        ;\n        ;\n            this._informPageletEvent(\"display\", aa.id);\n            this.arbiter.inform(((aa.id + \"_displayed\")), true, t);\n        },\n        _getAppendTargetID: function(aa) {\n            if (!aa.append) {\n                return null;\n            }\n        ;\n        ;\n            return ((((aa.append === \"bigpipe_root\")) ? this.rootNodeID : aa.append));\n        },\n        _downloadJsForPagelet: function(aa) {\n            this._informPageletEvent(\"jsstart\", aa.id);\n            h.loadResources(((aa.js || [])), function() {\n                this._informPageletEvent(\"jsdone\", aa.id);\n                aa.requires = ((aa.requires || []));\n                if (((!this.isAjax || ((aa.phase >= 1))))) {\n                    aa.requires.push(\"uipage_onload\");\n                }\n            ;\n            ;\n                var ba = function() {\n                    this._informPageletEvent(\"preonload\", aa.id);\n                    ((this._isRelevantPagelet(aa) && r(aa.JSBNG__onload)));\n                    this._informPageletEvent(\"JSBNG__onload\", aa.id);\n                    this.arbiter.inform(\"pagelet_onload\", true, g.BEHAVIOR_EVENT);\n                    ((aa.provides && this.arbiter.inform(aa.provides, true, t)));\n                }.bind(this), ca = function() {\n                    ((this._isRelevantPagelet(aa) && r(aa.JSBNG__onafterload)));\n                }.bind(this);\n                this.arbiter.registerCallback(ba, aa.requires);\n                this.arbiter.registerCallback(ca, [this.JSBNG__onloadEvt,]);\n            }.bind(this), false, aa.id);\n        },\n        _downloadDisplayDependenciesAndDisplayPagelet: function(aa) {\n            this._informPageletEvent(\"css\", aa.id);\n            var ba = ((aa.css || [])).concat(((aa.displayJS || [])));\n            h.loadResources(ba, function() {\n                var ca = ((aa.display_dependency || [])), da = [];\n                for (var ea = 0; ((ea < ca.length)); ea++) {\n                    da.push(((ca[ea] + \"_displayed\")));\n                ;\n                };\n            ;\n                this.arbiter.registerCallback(this._displayPageletHandler.bind(this, aa), da);\n            }.bind(this), false, aa.id);\n            this._informPageletEvent(\"css_end\", aa.id);\n        },\n        JSBNG__onPageletArrive: function(aa) {\n            this._informPageletEvent(\"arrive\", aa.id, aa.phase);\n            var ba = aa.phase;\n            if (!this._phaseDoneCallbacks[ba]) {\n                this._phaseDoneCallbacks[ba] = this.arbiter.registerCallback(this._onPhaseDone.bind(this), [((\"phase_complete_\" + ba)),]);\n            }\n        ;\n        ;\n            this.arbiter.registerCallback(this._phaseDoneCallbacks[ba], [((aa.id + \"_displayed\")),]);\n            var ca = a.PageletCache;\n            if (((ca && aa.cacheable))) {\n                if (aa.cache_hit) {\n                    aa = ca.loadFromCache(aa, this.arbiter);\n                }\n                 else ca.write(aa, this.arbiter);\n            ;\n            }\n        ;\n        ;\n            this._processPagelet(aa);\n            this._informPageletEvent(\"arrive_end\", aa.id);\n        },\n        _processPagelet: function(aa) {\n            var ba = aa.phase, ca = ((this._getAppendTargetID(aa) || aa.id));\n            z.pageletIDs[ca] = ca;\n            if (aa.the_end) {\n                this._lastPhase = aa.phase;\n            }\n        ;\n        ;\n            if (((aa.tti_phase !== undefined))) {\n                this._ttiPhase = aa.tti_phase;\n            }\n        ;\n        ;\n            if (aa.is_second_to_last_phase) {\n                this._secondToLastPhase = aa.phase;\n            }\n        ;\n        ;\n            if (aa.jscc_map) {\n                var da = (eval)(aa.jscc_map);\n                j.initForPagelet(ca, da);\n            }\n        ;\n        ;\n            h.setResourceMap(aa.resource_map);\n            h.enableBootload(v(aa.bootloadable));\n            var ea = ((\"phase_begin_\" + ba));\n            this.arbiter.registerCallback(this._downloadDisplayDependenciesAndDisplayPagelet.bind(this, aa), [ea,]);\n            var fa = [((aa.id + \"_displayed\")),];\n            if (!this.jsNonBlock) {\n                fa.push(this.domContentEvt);\n            }\n        ;\n        ;\n            this.arbiter.registerCallback(this.JSBNG__onloadCallback, [\"pagelet_onload\",]);\n            this.arbiter.registerCallback(this._downloadJsForPagelet.bind(this, aa), fa);\n            ((aa.is_last && this.arbiter.inform(((\"phase_complete_\" + ba)), true, t)));\n        },\n        _onPhaseDone: function() {\n            if (((this._currentPhase === this._ttiPhase))) {\n                this._informEventExternal(\"tti_bigpipe\", {\n                    phase: this._ttiPhase\n                });\n            }\n        ;\n        ;\n            var aa = ((this._currentPhase + 1)), ba = (function() {\n                this._informEventExternal(\"phase_begin\", {\n                    phase: aa\n                });\n                this.arbiter.inform(((\"phase_begin_\" + aa)), true, t);\n            }).bind(this);\n            if (((((this._currentPhase === this._lastPhase)) && this._isRelevant()))) {\n                this.arbiter.inform(\"pagelet_displayed_all\", true, t);\n            }\n        ;\n        ;\n            this._currentPhase++;\n            if (s) {\n                JSBNG__setTimeout(ba, 20);\n            }\n             else ba();\n        ;\n        ;\n        },\n        _isRelevant: function() {\n            return ((((((((this == z._current_instance)) || ((this.automatic && ((this._relevant_instance == z._current_instance)))))) || this.jsNonBlock)) || this.forceFinish));\n        },\n        _isRelevantPagelet: function(aa) {\n            if (!this._isRelevant()) {\n                return false;\n            }\n        ;\n        ;\n            var ba = ((this._getAppendTargetID(aa) || aa.id));\n            return z.pageletIDs.hasOwnProperty(ba);\n        },\n        _informEventExternal: function(aa, ba) {\n            ba = ((ba || {\n            }));\n            ba.ts = JSBNG__Date.now();\n            ba.lid = this.lid;\n            this.arbiter.inform(aa, ba, u);\n        },\n        _informPageletEvent: function(aa, ba, ca) {\n            var da = {\n                JSBNG__event: aa,\n                id: ba\n            };\n            if (ca) {\n                da.phase = ca;\n            }\n        ;\n        ;\n            this._informEventExternal(\"pagelet_event\", da);\n        }\n    });\n    z.pageletIDs = {\n    };\n    e.exports = z;\n});\n__d(\"legacy:bootloader\", [\"Bootloader\",], function(a, b, c, d) {\n    a.Bootloader = b(\"Bootloader\");\n}, 3);\n__d(\"Class\", [\"function-extensions\",\"Arbiter\",\"copyProperties\",\"createArrayFrom\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"copyProperties\"), i = b(\"createArrayFrom\"), j = {\n    }, k = null, l = {\n        extend: function(t, u) {\n            if (!k) {\n                k = g.subscribe(g.BOOTLOAD, n);\n            }\n        ;\n        ;\n            if (((typeof u == \"string\"))) {\n                m(t, u);\n            }\n             else o(t, u);\n        ;\n        ;\n        }\n    };\n    function m(t, u) {\n        t.__class_extending = true;\n        var v = g.registerCallback(o.curry(t, u), [((((g.FUNCTION_EXTENSION + \"/\")) + u)),g.BOOTLOAD,]);\n        if (((v !== null))) {\n            j[u] = true;\n        }\n    ;\n    ;\n    };\n;\n    function n() {\n        for (var t in j) {\n            if (!!a[t]) {\n                delete j[t];\n                if (!a[t].__class_extending) {\n                    g.inform(((((g.FUNCTION_EXTENSION + \"/\")) + t)), true, g.BEHAVIOR_STATE);\n                }\n                 else a[t].__class_name = t;\n            ;\n            ;\n            }\n        ;\n        ;\n        };\n    ;\n    };\n;\n    function o(t, u) {\n        delete t.__class_extending;\n        u = ((((typeof u == \"string\")) ? a[u] : u));\n        var v = p(u, 0), w = p(t, ((v.prototype.__level + 1)));\n        w.parent = v;\n        if (!!t.__class_name) {\n            g.inform(((((g.FUNCTION_EXTENSION + \"/\")) + t.__class_name)), true, g.BEHAVIOR_STATE);\n        }\n    ;\n    ;\n    };\n;\n    function p(t, u) {\n        if (t._metaprototype) {\n            return t._metaprototype;\n        }\n    ;\n    ;\n        var v = new Function();\n        v.construct = q;\n        v.prototype.construct = s(t, u, true);\n        v.prototype.__level = u;\n        v.base = t;\n        t.prototype.parent = v;\n        t._metaprototype = v;\n        return v;\n    };\n;\n    function q(t) {\n        r(t.parent);\n        var u = [], v = t;\n        while (v.parent) {\n            var w = new v.parent();\n            u.push(w);\n            w.__instance = t;\n            v = v.parent;\n        };\n    ;\n        t.parent = u[1];\n        u.reverse();\n        u.pop();\n        t.__parents = u;\n        t.__instance = t;\n        return t.parent.construct.apply(t.parent, arguments);\n    };\n;\n    function r(t) {\n        if (t.initialized) {\n            return;\n        }\n    ;\n    ;\n        var u = t.base.prototype;\n        if (t.parent) {\n            r(t.parent);\n            var v = t.parent.prototype;\n            for (var w in v) {\n                if (((((((w != \"__level\")) && ((w != \"construct\")))) && ((u[w] === undefined))))) {\n                    u[w] = t.prototype[w] = v[w];\n                }\n            ;\n            ;\n            };\n        ;\n        }\n    ;\n    ;\n        t.initialized = true;\n        var x = t.prototype.__level;\n        for (var w in u) {\n            if (((w != \"parent\"))) {\n                u[w] = t.prototype[w] = s(u[w], x);\n            }\n        ;\n        ;\n        };\n    ;\n    };\n;\n    function s(t, u, v) {\n        if (((((typeof t != \"function\")) || t.__prototyped))) {\n            return t;\n        }\n    ;\n    ;\n        var w = function() {\n            var x = this.__instance;\n            if (x) {\n                var y = x.parent;\n                x.parent = ((u ? x.__parents[((u - 1))] : null));\n                var z = arguments;\n                if (v) {\n                    z = [];\n                    for (var aa = 1; ((aa < arguments.length)); aa++) {\n                        z.push(arguments[aa]);\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n                var ba = t.apply(x, z);\n                x.parent = y;\n                return ba;\n            }\n             else return t.apply(this, arguments)\n        ;\n        };\n        w.__prototyped = true;\n        return w;\n    };\n;\n    e.exports = l;\n});\n__d(\"legacy:Class\", [\"Class\",], function(a, b, c, d) {\n    a.Class = b(\"Class\");\n}, 3);\n__d(\"legacy:constructor-cache\", [\"JSCC\",], function(a, b, c, d) {\n    a.JSCC = b(\"JSCC\");\n}, 3);\n__d(\"goURI\", [], function(a, b, c, d, e, f) {\n    function g(h, i) {\n        h = h.toString();\n        if (((((!i && a.PageTransitions)) && PageTransitions.isInitialized()))) {\n            PageTransitions.go(h);\n        }\n         else if (((window.JSBNG__location.href == h))) {\n            window.JSBNG__location.reload();\n        }\n         else window.JSBNG__location.href = h;\n        \n    ;\n    ;\n    };\n;\n    e.exports = g;\n});\n__d(\"legacy:goURI\", [\"goURI\",], function(a, b, c, d) {\n    a.goURI = b(\"goURI\");\n}, 3);\n__d(\"InitialJSLoader\", [\"Arbiter\",\"Bootloader\",\"OnloadEvent\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"Bootloader\"), i = b(\"OnloadEvent\"), j = {\n        INITIAL_JS_READY: \"BOOTLOAD/JSREADY\",\n        loadOnDOMContentReady: function(k, l) {\n            g.subscribe(i.ONLOAD_DOMCONTENT_CALLBACK, function() {\n                function m() {\n                    h.loadResources(k, function() {\n                        g.inform(j.INITIAL_JS_READY, true, g.BEHAVIOR_STATE);\n                    });\n                };\n            ;\n                if (l) {\n                    JSBNG__setTimeout(m, l);\n                }\n                 else m();\n            ;\n            ;\n            });\n        }\n    };\n    e.exports = j;\n});\n__d(\"lowerDomain\", [], function(a, b, c, d, e, f) {\n    if (JSBNG__document.domain.toLowerCase().match(/(^|\\.)facebook\\..*/)) {\n        JSBNG__document.domain = window.JSBNG__location.hostname.replace(/^.*(facebook\\..*)$/i, \"$1\");\n    }\n;\n;\n});\n__d(\"legacy:object-core-utils\", [\"copyProperties\",\"isEmpty\",], function(a, b, c, d) {\n    var e = b(\"copyProperties\");\n    function f(g, h) {\n        return e(((window[g] || (window[g] = {\n        }))), h);\n    };\n;\n    a.is_empty = b(\"isEmpty\");\n    a.add_properties = f;\n    a.copyProperties = e;\n}, 3);\n__d(\"PlaceholderListener\", [\"Arbiter\",\"CSS\",\"Parent\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"CSS\"), i = b(\"Parent\"), j = JSBNG__document.documentElement, k = function(l) {\n        l = ((l || window.JSBNG__event));\n        var m = ((l.target || l.srcElement)), n = m.getAttribute(\"placeholder\");\n        if (n) {\n            var o = i.byClass(m, \"focus_target\");\n            if (((((\"JSBNG__focus\" == l.type)) || ((\"focusin\" == l.type))))) {\n                var p = m.value.replace(/\\r\\n/g, \"\\u000a\"), q = n.replace(/\\r\\n/g, \"\\u000a\");\n                if (((((p == q)) && h.hasClass(m, \"DOMControl_placeholder\")))) {\n                    m.value = \"\";\n                    h.removeClass(m, \"DOMControl_placeholder\");\n                }\n            ;\n            ;\n                if (o) {\n                    h.addClass(o, \"child_is_active\");\n                    h.addClass(o, \"child_is_focused\");\n                    h.addClass(o, \"child_was_focused\");\n                    g.inform(\"reflow\");\n                }\n            ;\n            ;\n            }\n             else {\n                if (((m.value === \"\"))) {\n                    h.addClass(m, \"DOMControl_placeholder\");\n                    m.value = n;\n                    ((o && h.removeClass(o, \"child_is_active\")));\n                    m.style.direction = \"\";\n                }\n            ;\n            ;\n                ((o && h.removeClass(o, \"child_is_focused\")));\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    };\n    if (j.JSBNG__addEventListener) {\n        j.JSBNG__addEventListener(\"JSBNG__focus\", k, true);\n        j.JSBNG__addEventListener(\"JSBNG__blur\", k, true);\n    }\n     else {\n        j.JSBNG__attachEvent(\"JSBNG__onfocusin\", k);\n        j.JSBNG__attachEvent(\"JSBNG__onfocusout\", k);\n    }\n;\n;\n});\n__d(\"isInIframe\", [], function(a, b, c, d, e, f) {\n    function g() {\n        return ((window != window.JSBNG__top));\n    };\n;\n    e.exports = g;\n});\n__d(\"EagleEye\", [\"Arbiter\",\"Bootloader\",\"Env\",\"OnloadEvent\",\"isInIframe\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"Bootloader\"), i = b(\"Env\"), j = b(\"OnloadEvent\"), k = b(\"isInIframe\"), l = ((i.eagleEyeConfig || {\n    })), m = \"_e_\", n = ((window.JSBNG__name || \"\")).toString();\n    if (((((n.length == 7)) && ((n.substr(0, 3) == m))))) {\n        n = n.substr(3);\n    }\n     else {\n        n = l.seed;\n        if (!k()) {\n            window.JSBNG__name = ((m + n));\n        }\n    ;\n    ;\n    }\n;\n;\n    var o = ((((((window.JSBNG__location.protocol == \"https:\")) && JSBNG__document.cookie.match(/\\bcsm=1/))) ? \"; secure\" : \"\")), p = ((((m + n)) + \"_\")), q = new JSBNG__Date(((JSBNG__Date.now() + 604800000))).toGMTString(), r = window.JSBNG__location.hostname.replace(/^.*(facebook\\..*)$/i, \"$1\"), s = ((((((((\"; expires=\" + q)) + \";path=/; domain=\")) + r)) + o)), t = 0, u, v = ((l.JSBNG__sessionStorage && a.JSBNG__sessionStorage)), w = JSBNG__document.cookie.length, x = false, y = JSBNG__Date.now();\n    function z(ea) {\n        var fa = 2166136261;\n        for (var ga = 0, ha = ea.length; ((ga < ha)); ++ga) {\n            fa = ((((fa ^ ea.charCodeAt(ga))) * 16777619));\n        ;\n        };\n    ;\n        fa += ((fa << 13));\n        fa ^= ((fa >> 7));\n        fa += ((fa << 3));\n        fa ^= ((fa >> 17));\n        fa += ((fa << 5));\n        return ((((fa | 0)) + 2147483648));\n    };\n;\n    function aa(ea) {\n        return ((((((((p + (t++))) + \"=\")) + encodeURIComponent(ea))) + s));\n    };\n;\n    function ba() {\n        var ea = [], fa = false, ga = 0, ha = 0;\n        this.isEmpty = function() {\n            return !ea.length;\n        };\n        this.enqueue = function(ia, ja) {\n            if (ja) {\n                ea.unshift(ia);\n            }\n             else ea.push(ia);\n        ;\n        ;\n        };\n        this.dequeue = function() {\n            ea.shift();\n        };\n        this.peek = function() {\n            return ea[0];\n        };\n        this.clear = function(ia) {\n            w = Math.min(w, JSBNG__document.cookie.length);\n            if (((!x && ((((new JSBNG__Date() - y)) > 60000))))) {\n                x = true;\n            }\n        ;\n        ;\n            var ja = ((!ia && ((JSBNG__document.cookie.search(m) >= 0)))), ka = !!i.cookie_header_limit, la = ((i.cookie_count_limit || 19)), ma = ((i.cookie_header_limit || 3950)), na = ((la - 5)), oa = ((ma - 1000));\n            while (!this.isEmpty()) {\n                var pa = aa(this.peek());\n                if (((ka && ((((pa.length > ma)) || ((x && ((((pa.length + w)) > ma))))))))) {\n                    this.dequeue();\n                    continue;\n                }\n            ;\n            ;\n                if (((((ja || ka)) && ((((((JSBNG__document.cookie.length + pa.length)) > ma)) || ((JSBNG__document.cookie.split(\";\").length > la))))))) {\n                    break;\n                }\n            ;\n            ;\n                JSBNG__document.cookie = pa;\n                ja = true;\n                this.dequeue();\n            };\n        ;\n            var qa = JSBNG__Date.now();\n            if (((ia || ((((((((!fa && ja)) && ((((ha > 0)) && ((((Math.min(((10 * Math.pow(2, ((ha - 1))))), 60000) + ga)) < qa)))))) && g.query(j.ONLOAD))) && ((((!this.isEmpty() || ((JSBNG__document.cookie.length > oa)))) || ((JSBNG__document.cookie.split(\";\").length > na))))))))) {\n                var ra = new JSBNG__Image(), sa = this, ta = ((i.tracking_domain || \"\"));\n                fa = true;\n                ra.JSBNG__onload = function wa() {\n                    fa = false;\n                    ha = 0;\n                    sa.clear();\n                };\n                ra.JSBNG__onerror = ra.JSBNG__onabort = function wa() {\n                    fa = false;\n                    ga = JSBNG__Date.now();\n                    ha++;\n                };\n                var ua = ((i.fb_isb ? ((\"&fb_isb=\" + i.fb_isb)) : \"\")), va = ((\"&__user=\" + i.user));\n                ra.src = ((((((((((((((ta + \"/ajax/nectar.php?asyncSignal=\")) + ((Math.floor(((Math.JSBNG__random() * 10000))) + 1)))) + ua)) + va)) + \"&\")) + ((!ia ? \"\" : \"s=\")))) + qa));\n            }\n        ;\n        ;\n        };\n    };\n;\n    u = new ba();\n    if (v) {\n        var ca = function() {\n            var ea = 0, fa = ea;\n            function ga() {\n                var ja = JSBNG__sessionStorage.getItem(\"_e_ids\");\n                if (ja) {\n                    var ka = ((ja + \"\")).split(\";\");\n                    if (((ka.length == 2))) {\n                        ea = parseInt(ka[0], 10);\n                        fa = parseInt(ka[1], 10);\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            function ha() {\n                var ja = ((((ea + \";\")) + fa));\n                JSBNG__sessionStorage.setItem(\"_e_ids\", ja);\n            };\n        ;\n            function ia(ja) {\n                return ((\"_e_\" + ((((ja !== undefined)) ? ja : ea++))));\n            };\n        ;\n            this.isEmpty = function() {\n                return ((fa === ea));\n            };\n            this.enqueue = function(ja, ka) {\n                var la = ((ka ? ia(--fa) : ia()));\n                JSBNG__sessionStorage.setItem(la, ja);\n                ha();\n            };\n            this.dequeue = function() {\n                this.isEmpty();\n                JSBNG__sessionStorage.removeItem(ia(fa));\n                fa++;\n                ha();\n            };\n            this.peek = function() {\n                var ja = JSBNG__sessionStorage.getItem(ia(fa));\n                return ((ja ? ((ja + \"\")) : ja));\n            };\n            this.clear = u.clear;\n            ga();\n        };\n        u = new ca();\n    }\n;\n;\n    var da = {\n        log: function(ea, fa, ga) {\n            if (i.no_cookies) {\n                return;\n            }\n        ;\n        ;\n            var ha = [n,JSBNG__Date.now(),ea,].concat(fa);\n            ha.push(ha.length);\n            function ia() {\n                var ja = JSON.stringify(ha);\n                try {\n                    u.enqueue(ja, !!ga);\n                    u.clear(!!ga);\n                } catch (ka) {\n                    if (((v && ((ka.code === 1000))))) {\n                        u = new ba();\n                        v = false;\n                        ia();\n                    }\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n            ia();\n        },\n        createLogger: function(ea, fa) {\n            fa = ((((fa === undefined)) ? 1 : fa));\n            var ga = function(ha, ia) {\n                if (ga.enabled) {\n                    da.log(ea, ha, ia);\n                }\n            ;\n            ;\n            };\n            ga.enabled = false;\n            ga._key = ((((i.user || Math.JSBNG__random())) + ea));\n            ga.enabled = ((((((z(ga._key) % 65535)) / 65535)) <= fa));\n            return ga;\n        },\n        getSessionID: function() {\n            return n;\n        },\n        hash: function(ea) {\n            return z(ea);\n        }\n    };\n    a.EagleEye = e.exports = da;\n}, 3);\n__d(\"ClickRefUtils\", [], function(a, b, c, d, e, f) {\n    var g = {\n        get_intern_ref: function(h) {\n            if (!!h) {\n                var i = {\n                    profile_minifeed: 1,\n                    gb_content_and_toolbar: 1,\n                    gb_muffin_area: 1,\n                    ego: 1,\n                    bookmarks_menu: 1,\n                    jewelBoxNotif: 1,\n                    jewelNotif: 1,\n                    BeeperBox: 1,\n                    navSearch: 1\n                };\n                for (var j = h; ((j && ((j != JSBNG__document.body)))); j = j.parentNode) {\n                    if (((!j.id || ((typeof j.id !== \"string\"))))) {\n                        continue;\n                    }\n                ;\n                ;\n                    if (((j.id.substr(0, 8) == \"pagelet_\"))) {\n                        return j.id.substr(8);\n                    }\n                ;\n                ;\n                    if (((j.id.substr(0, 8) == \"box_app_\"))) {\n                        return j.id;\n                    }\n                ;\n                ;\n                    if (i[j.id]) {\n                        return j.id;\n                    }\n                ;\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            return \"-\";\n        },\n        get_href: function(h) {\n            return ((((((((((h.getAttribute && ((h.getAttribute(\"ajaxify\") || h.getAttribute(\"data-endpoint\"))))) || h.action)) || h.href)) || h.JSBNG__name)) || null));\n        },\n        should_report: function(h, i) {\n            if (((i == \"FORCE\"))) {\n                return true;\n            }\n        ;\n        ;\n            if (((i == \"INDIRECT\"))) {\n                return false;\n            }\n        ;\n        ;\n            return ((h && ((g.get_href(h) || ((h.getAttribute && h.getAttribute(\"data-ft\")))))));\n        }\n    };\n    e.exports = g;\n});\n__d(\"collectDataAttributes\", [\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"ge\");\n    function h(i, j) {\n        var k = {\n        }, l = {\n        }, m = j.length, n, o;\n        for (n = 0; ((n < m)); ++n) {\n            k[j[n]] = {\n            };\n            l[j[n]] = ((\"data-\" + j[n]));\n        };\n    ;\n        var p = {\n            tn: \"\",\n            \"tn-debug\": \",\"\n        };\n        while (i) {\n            if (i.getAttribute) {\n                for (n = 0; ((n < m)); ++n) {\n                    var q = i.getAttribute(l[j[n]]);\n                    if (q) {\n                        var r = JSON.parse(q);\n                        for (var s in r) {\n                            if (((p[s] !== undefined))) {\n                                if (((k[j[n]][s] === undefined))) {\n                                    k[j[n]][s] = [];\n                                }\n                            ;\n                            ;\n                                k[j[n]][s].push(r[s]);\n                            }\n                             else if (((k[j[n]][s] === undefined))) {\n                                k[j[n]][s] = r[s];\n                            }\n                            \n                        ;\n                        ;\n                        };\n                    ;\n                    }\n                ;\n                ;\n                };\n            }\n        ;\n        ;\n            if (((i.getAttribute && (o = i.getAttribute(\"data-ownerid\"))))) {\n                i = g(o);\n            }\n             else i = i.parentNode;\n        ;\n        ;\n        };\n    ;\n        for (var t in k) {\n            for (var u in p) {\n                if (((k[t][u] !== undefined))) {\n                    k[t][u] = k[t][u].join(p[u]);\n                }\n            ;\n            ;\n            };\n        ;\n        };\n    ;\n        return k;\n    };\n;\n    e.exports = h;\n});\n__d(\"setUECookie\", [\"Env\",], function(a, b, c, d, e, f) {\n    var g = b(\"Env\");\n    function h(i) {\n        if (!g.no_cookies) {\n            var j = 0;\n            if (a.afterloaded) {\n                j = 2;\n            }\n             else if (a.loaded) {\n                j = 1;\n            }\n            \n        ;\n        ;\n            JSBNG__document.cookie = ((((((\"act=\" + encodeURIComponent(((((i + \":\")) + j))))) + \"; path=/; domain=\")) + window.JSBNG__location.hostname.replace(/^.*(\\.facebook\\..*)$/i, \"$1\")));\n        }\n    ;\n    ;\n    };\n;\n    e.exports = h;\n});\n__d(\"ClickRef\", [\"Arbiter\",\"EagleEye\",\"ClickRefUtils\",\"collectDataAttributes\",\"copyProperties\",\"ge\",\"setUECookie\",\"$\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"EagleEye\"), i = b(\"ClickRefUtils\"), j = b(\"collectDataAttributes\"), k = b(\"copyProperties\"), l = b(\"ge\"), m = b(\"setUECookie\"), n = b(\"$\");\n    function o(q) {\n        if (!l(\"JSBNG__content\")) {\n            return [0,0,0,0,];\n        }\n    ;\n    ;\n        var r = n(\"JSBNG__content\"), s = ((a.Vector2 ? a.Vector2.getEventPosition(q) : {\n            x: 0,\n            y: 0\n        }));\n        return [s.x,s.y,r.offsetLeft,r.clientWidth,];\n    };\n;\n    function p(q, r, JSBNG__event, s) {\n        var t = (((!a.ArbiterMonitor) ? \"r\" : \"a\")), u = [0,0,0,0,], v, w, x;\n        if (!!JSBNG__event) {\n            v = JSBNG__event.type;\n            if (((((v == \"click\")) && l(\"JSBNG__content\")))) {\n                u = o(JSBNG__event);\n            }\n        ;\n        ;\n            var y = 0;\n            ((JSBNG__event.ctrlKey && (y += 1)));\n            ((JSBNG__event.shiftKey && (y += 2)));\n            ((JSBNG__event.altKey && (y += 4)));\n            ((JSBNG__event.metaKey && (y += 8)));\n            if (y) {\n                v += y;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        if (!!r) {\n            w = i.get_href(r);\n        }\n    ;\n    ;\n        var z = [];\n        if (a.ArbiterMonitor) {\n            x = a.ArbiterMonitor.getInternRef(r);\n            z = a.ArbiterMonitor.getActFields();\n        }\n    ;\n    ;\n        var aa = j(((!!JSBNG__event ? ((JSBNG__event.target || JSBNG__event.srcElement)) : r)), [\"ft\",\"gt\",]);\n        k(aa.ft, ((s.ft || {\n        })));\n        k(aa.gt, ((s.gt || {\n        })));\n        if (aa.gt.ua_id) {\n            q.set_ua_id(aa.gt.ua_id);\n        }\n    ;\n    ;\n        if (((typeof (aa.ft.ei) === \"string\"))) {\n            delete aa.ft.ei;\n        }\n    ;\n    ;\n        var ba = [q._ue_ts,q._ue_count,((w || \"-\")),q._context,((v || \"-\")),((x || i.get_intern_ref(r))),t,((a.URI ? a.URI.getRequestURI(true, true).getUnqualifiedURI().toString() : ((((JSBNG__location.pathname + JSBNG__location.search)) + JSBNG__location.hash)))),aa,].concat(u).concat(z);\n        return ba;\n    };\n;\n    g.subscribe(\"UserAction/new\", function(q, r) {\n        if (i.should_report(r.node, r.mode)) {\n            var s = p(r.ua, r.node, r.JSBNG__event, r.extra_data);\n            m(r.ua.ue);\n            h.log(\"act\", s);\n        }\n    ;\n    ;\n    });\n});\n__d(\"trackReferrer\", [\"Parent\",], function(a, b, c, d, e, f) {\n    var g = b(\"Parent\");\n    function h(i, j) {\n        i = g.byAttribute(i, \"data-referrer\");\n        if (i) {\n            var k = ((/^(?:(?:[^:\\/?#]+):)?(?:\\/\\/(?:[^\\/?#]*))?([^?#]*)(?:\\?([^#]*))?(?:#(.*))?/.exec(j)[1] || \"\"));\n            if (!k) {\n                return;\n            }\n        ;\n        ;\n            var l = ((((k + \"|\")) + i.getAttribute(\"data-referrer\"))), m = new JSBNG__Date();\n            m.setTime(((JSBNG__Date.now() + 1000)));\n            JSBNG__document.cookie = ((((((((((((\"x-src=\" + encodeURIComponent(l))) + \"; \")) + \"expires=\")) + m.toGMTString())) + \";path=/; domain=\")) + window.JSBNG__location.hostname.replace(/^.*(\\.facebook\\..*)$/i, \"$1\")));\n        }\n    ;\n    ;\n        return i;\n    };\n;\n    e.exports = h;\n});\n__d(\"debounce\", [], function(a, b, c, d, e, f) {\n    function g(h, i, j, k, l) {\n        i = ((((i != null)) ? i : 100));\n        var m, n;\n        function o() {\n            var p = arguments;\n            ((!l && o.reset()));\n            if (((((!l || !m)) || ((((n + i)) < JSBNG__Date.now()))))) {\n                m = JSBNG__setTimeout(function() {\n                    m = null;\n                    h.apply(this, p);\n                }.bind(((j || this))), i, !k);\n                n = JSBNG__Date.now();\n            }\n        ;\n        ;\n        };\n    ;\n        o.reset = function() {\n            ((m && JSBNG__clearTimeout(m)));\n            m = null;\n        };\n        return o;\n    };\n;\n    e.exports = g;\n});\n__d(\"userAction\", [\"Arbiter\",\"EagleEye\",\"copyProperties\",\"debounce\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"EagleEye\"), i = b(\"copyProperties\"), j = b(\"debounce\");\n    function k(t, u, v) {\n        var w = ((((t + \"/\")) + u));\n        i(this, {\n            ue: w,\n            _ua_id: null,\n            _ts: t,\n            _ns: null,\n            _start_ts: t,\n            _prev_event: \"s\",\n            _ue_ts: t,\n            _ue_count: u,\n            _context: v,\n            _data_version: 1,\n            _event_version: 2,\n            _info_version: 1\n        });\n        this._log(\"uan\", [1,w,]);\n        this._report = j(function x() {\n            var y = [this._info_version,this.ue,this._ns,this._ua_id,];\n            this._log(\"uai\", y);\n        }, 100, this);\n    };\n;\n    var l = [], m = {\n    }, n = {\n    };\n    i(k.prototype, {\n        _log: function(t, u) {\n            var v = ((((m[t] !== undefined)) ? m[t] : true)), w = n[t], x = ((w ? w[this._ns] : {\n            })), y = ((x ? x[this._ua_id] : undefined));\n            if (((((y !== undefined)) ? y : v))) {\n                h.log(t, u);\n            }\n        ;\n        ;\n        },\n        coalesce_ua_id: function(t) {\n            if (((this._ua_id === null))) {\n                this.set_ua_id(t);\n            }\n        ;\n        ;\n            return this;\n        },\n        set_ua_id: function(t) {\n            this._ua_id = t;\n            this._report();\n            return this;\n        },\n        coalesce_namespace: function(t) {\n            if (((this._ns === null))) {\n                this.set_namespace(t);\n            }\n        ;\n        ;\n            return this;\n        },\n        set_namespace: function(t) {\n            this._ns = t;\n            this._report();\n            return this;\n        },\n        add_event: function(t, u, v) {\n            u = ((u || 0));\n            var w = ((JSBNG__Date.now() - u)), x = ((w - this._ts)), y = ((w - ((v ? v : this._ue_ts)))), z = [this._event_version,this.ue,this._ns,this._ua_id,this._prev_event,t,x,y,];\n            if (!this._ua_id) {\n                return;\n            }\n        ;\n        ;\n            this._log(\"uae\", z);\n            this._ts = w;\n            this._prev_event = t;\n            return this;\n        },\n        add_data: function(t) {\n            var u = [this._data_version,this.ue,t,];\n            this._log(\"uad\", u);\n            return this;\n        }\n    });\n    var o = 0, p = 0, q = null, r = null;\n    function s(t, u, JSBNG__event, v, w) {\n        var x = JSBNG__Date.now(), y = ((((x + \"/\")) + o));\n        w = ((w || {\n        }));\n        if (((!u && JSBNG__event))) {\n            u = JSBNG__event.getTarget();\n        }\n    ;\n    ;\n        var z = 50;\n        if (((u && q))) {\n            if (((((((((x - p)) < z)) && ((u == q)))) && ((v != \"FORCE\"))))) {\n                return l[((l.length - 1))];\n            }\n        ;\n        }\n    ;\n    ;\n        if (((!window.JSBNG__addEventListener && JSBNG__document.createEventObject))) {\n            JSBNG__event = JSBNG__document.createEventObject(JSBNG__event);\n        }\n    ;\n    ;\n        q = u;\n        r = JSBNG__event;\n        var aa = new k(x, o, t);\n        l.push(aa);\n        while (((l.length > 10))) {\n            l.shift();\n        ;\n        };\n    ;\n        g.inform(\"UserAction/new\", {\n            ua: aa,\n            node: u,\n            mode: v,\n            JSBNG__event: JSBNG__event,\n            extra_data: w\n        });\n        p = x;\n        o++;\n        return aa;\n    };\n;\n    s.setUATypeConfig = function(t) {\n        i(m, t);\n    };\n    s.setCustomSampleConfig = function(t) {\n        i(n, t);\n    };\n    s.getCurrentUECount = function() {\n        return o;\n    };\n    e.exports = a.userAction = s;\n});\n__d(\"Primer\", [\"ClickRef\",\"function-extensions\",\"Bootloader\",\"CSS\",\"Parent\",\"trackReferrer\",\"userAction\",], function(a, b, c, d, e, f) {\n    b(\"ClickRef\");\n    b(\"function-extensions\");\n    var g = b(\"Bootloader\"), h = b(\"CSS\"), i = b(\"Parent\"), j = b(\"trackReferrer\"), k = b(\"userAction\"), l = null, m = /async(?:-post)?|dialog(?:-post)?|theater|toggle/, n = JSBNG__document.documentElement;\n    function o(r, s) {\n        r = i.byAttribute(r, s);\n        if (!r) {\n            return;\n        }\n    ;\n    ;\n        do {\n            var t = r.getAttribute(s);\n            JSON.parse(t).forEach(function(u) {\n                var v = r;\n                g.loadModules.call(g, [u[0],], function(w) {\n                    w[u[1]](v);\n                });\n            });\n        } while (r = i.byAttribute(r.parentNode, s));\n        return false;\n    };\n;\n    n.JSBNG__onclick = function(r) {\n        r = ((r || window.JSBNG__event));\n        l = ((r.target || r.srcElement));\n        var s = o(l, \"data-onclick\"), t = i.byTag(l, \"A\");\n        if (!t) {\n            return s;\n        }\n    ;\n    ;\n        var u = t.getAttribute(\"ajaxify\"), v = t.href, w = ((u || v));\n        if (w) {\n            var x = k(\"a\", t, r).coalesce_namespace(\"primer\");\n            if (a.ArbiterMonitor) {\n                a.ArbiterMonitor.initUA(x, [t,]);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        if (((((u && v)) && !(/#$/).test(v)))) {\n            var y = ((r.which && ((r.which === 2)))), z = ((((((r.altKey || r.ctrlKey)) || r.metaKey)) || r.shiftKey));\n            if (((y || z))) {\n                return;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        j(t, w);\n        var aa = ((t.rel && t.rel.match(m)));\n        aa = ((aa && aa[0]));\n        switch (aa) {\n          case \"dialog\":\n        \n          case \"dialog-post\":\n            g.loadModules([\"AsyncDialog\",], function(ba) {\n                ba.bootstrap(w, t, aa);\n            });\n            break;\n          case \"async\":\n        \n          case \"async-post\":\n            g.loadModules([\"AsyncRequest\",], function(ba) {\n                ba.bootstrap(w, t);\n            });\n            break;\n          case \"theater\":\n            g.loadModules([\"PhotoSnowlift\",], function(ba) {\n                ba.bootstrap(w, t);\n            });\n            break;\n          case \"toggle\":\n            h.toggleClass(t.parentNode, \"openToggler\");\n            g.loadModules([\"Toggler\",], function(ba) {\n                ba.bootstrap(t);\n            });\n            break;\n          default:\n            return s;\n        };\n    ;\n        return false;\n    };\n    n.JSBNG__onsubmit = function(r) {\n        r = ((r || window.JSBNG__event));\n        var s = ((r.target || r.srcElement));\n        if (((((s && ((s.nodeName == \"FORM\")))) && ((s.getAttribute(\"rel\") == \"async\"))))) {\n            var t = k(\"f\", s, r).coalesce_namespace(\"primer\");\n            if (a.ArbiterMonitor) {\n                a.ArbiterMonitor.initUA(t, [s,]);\n            }\n        ;\n        ;\n            var u = l;\n            g.loadModules([\"Form\",], function(v) {\n                v.bootstrap(s, u);\n            });\n            return false;\n        }\n    ;\n    ;\n    };\n    var p = null;\n    function q(r, s) {\n        s = ((s || window.JSBNG__event));\n        p = ((s.target || s.srcElement));\n        o(p, ((\"data-on\" + r)));\n        var t = i.byAttribute(p, \"data-hover\");\n        if (!t) {\n            return;\n        }\n    ;\n    ;\n        switch (t.getAttribute(\"data-hover\")) {\n          case \"tooltip\":\n            g.loadModules([\"Tooltip\",], function(u) {\n                u.process(t, p);\n            });\n            break;\n        };\n    ;\n    };\n;\n    n.JSBNG__onmouseover = q.curry(\"mouseover\");\n    if (n.JSBNG__addEventListener) {\n        n.JSBNG__addEventListener(\"JSBNG__focus\", q.curry(\"JSBNG__focus\"), true);\n    }\n     else n.JSBNG__attachEvent(\"JSBNG__onfocusin\", q.curry(\"JSBNG__focus\"));\n;\n;\n});\n__d(\"QuicklingPrelude\", [], function(a, b, c, d, e, f) {\n    var g = /^(?:(?:[^:\\/?#]+):)?(?:\\/\\/(?:[^\\/?#]*))?([^?#]*)(?:\\?([^#]*))?(?:#(.*))?/, h = \"\";\n    window.JSBNG__location.href.replace(g, function(i, j, k, l) {\n        var m, n, o;\n        m = n = ((j + ((k ? ((\"?\" + k)) : \"\"))));\n        if (l) {\n            l = l.replace(/^(!|%21)/, \"\");\n            o = l.charAt(0);\n            if (((((o == \"/\")) || ((o == \"\\\\\"))))) {\n                m = l.replace(/^[\\\\\\/]+/, \"/\");\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        if (((m != n))) {\n            if (window._script_path) {\n                JSBNG__document.cookie = ((((((\"rdir=\" + window._script_path)) + \"; path=/; domain=\")) + window.JSBNG__location.hostname.replace(/^.*(\\.facebook\\..*)$/i, \"$1\")));\n            }\n        ;\n        ;\n            window.JSBNG__location.replace(((h + m)));\n        }\n    ;\n    ;\n    });\n});\n__d(\"SubmitOnEnterListener\", [\"Bootloader\",\"CSS\",], function(a, b, c, d, e, f) {\n    var g = b(\"Bootloader\"), h = b(\"CSS\");\n    JSBNG__document.documentElement.JSBNG__onkeydown = function(i) {\n        i = ((i || window.JSBNG__event));\n        var j = ((i.target || i.srcElement)), k = ((((((((((((i.keyCode == 13)) && !i.altKey)) && !i.ctrlKey)) && !i.metaKey)) && !i.shiftKey)) && h.hasClass(j, \"enter_submit\")));\n        if (k) {\n            g.loadModules([\"DOM\",\"Input\",\"trackReferrer\",\"Form\",], function(l, m, n, o) {\n                if (!m.isEmpty(j)) {\n                    var p = j.form, q = ((l.scry(p, \".enter_submit_target\")[0] || l.scry(p, \"[type=\\\"submit\\\"]\")[0]));\n                    if (q) {\n                        var r = ((o.getAttribute(p, \"ajaxify\") || o.getAttribute(p, \"action\")));\n                        if (r) {\n                            n(p, r);\n                        }\n                    ;\n                    ;\n                        q.click();\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            });\n            return false;\n        }\n    ;\n    ;\n    };\n});\n__d(\"CommentPrelude\", [\"CSS\",\"Parent\",\"userAction\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"Parent\"), i = b(\"userAction\");\n    function j(n, o) {\n        i(\"ufi\", n, null, \"FORCE\");\n        return k(n, o);\n    };\n;\n    function k(n, o) {\n        var p = h.byTag(n, \"form\");\n        l(p);\n        var q = g.removeClass.curry(p, \"hidden_add_comment\");\n        if (window.ScrollAwareDOM) {\n            window.ScrollAwareDOM.monitor(p, q);\n        }\n         else q();\n    ;\n    ;\n        if (((o !== false))) {\n            ((p.add_comment_text_text || p.add_comment_text)).JSBNG__focus();\n        }\n    ;\n    ;\n        return false;\n    };\n;\n    function l(n) {\n        var o = g.removeClass.curry(n, \"collapsed_comments\");\n        if (window.ScrollAwareDOM) {\n            window.ScrollAwareDOM.monitor(n, o);\n        }\n         else o();\n    ;\n    ;\n    };\n;\n    var m = {\n        click: j,\n        expand: k,\n        uncollapse: l\n    };\n    e.exports = m;\n});\n__d(\"legacy:ufi-comment-prelude-js\", [\"CommentPrelude\",], function(a, b, c, d) {\n    var e = b(\"CommentPrelude\");\n    a.fc_click = e.click;\n    a.fc_expand = e.expand;\n}, 3);\nvoid (0);");
// 928
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"(window.Bootloader && Bootloader.done([\"NPGon\",]));");
// 929
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s8b97309988c57c6f9241dd61bd1b7d83a0c68717");
// 930
geval("((window.Bootloader && Bootloader.done([\"NPGon\",])));");
// 931
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"");
// 932
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"sda39a3ee5e6b4b0d3255bfef95601890afd80709");
// 933
geval("");
// 934
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"new (require(\"ServerJS\"))().handle({\n    require: [[\"lowerDomain\",],[\"QuicklingPrelude\",],[\"Primer\",],]\n});");
// 935
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s3d174b9270d7e2ff60463bd4a11dc1f65e251df3");
// 936
geval("new (require(\"ServerJS\"))().handle({\n    require: [[\"lowerDomain\",],[\"QuicklingPrelude\",],[\"Primer\",],]\n});");
// 949
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"function e4a14e9e942de89ae7293fdd380fa686ec8ea507e(event) {\n    (window.Toggler && Toggler.hide());\n};");
// 950
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s33bedc6b522fce4b08d1859b1d4017e4caa76d35");
// 951
geval("function e4a14e9e942de89ae7293fdd380fa686ec8ea507e(JSBNG__event) {\n    ((window.Toggler && Toggler.hide()));\n};\n;");
// 952
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"function e535a280bf4e95bbef3e78dd7b2f43e5e41fac5c3(event) {\n    return run_with(this, [\"min-notifications-jewel\",], function() {\n        MinNotifications.bootstrap(this);\n    });\n};");
// 953
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s335ddc379622f62e0c37535fdedd480924823079");
// 954
geval("function e535a280bf4e95bbef3e78dd7b2f43e5e41fac5c3(JSBNG__event) {\n    return run_with(this, [\"min-notifications-jewel\",], function() {\n        MinNotifications.bootstrap(this);\n    });\n};\n;");
// 955
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"function e1e18553c89899d471120f05ca376d6ea889ecd02(event) {\n    return Event.__inlineSubmit(this, event);\n};");
// 956
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s4595f9dff553de0e4acec013f7c94c5775aff861");
// 957
geval("function e1e18553c89899d471120f05ca376d6ea889ecd02(JSBNG__event) {\n    return JSBNG__Event.__inlineSubmit(this, JSBNG__event);\n};\n;");
// 958
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"function ef3c6de5b6248ca8b0bfdcc77a230f02c90b21b5a(event) {\n    var q = $(\"q\");\n    if ((q.value == q.getAttribute(\"placeholder\"))) {\n        q.focus();\n        return false;\n    }\n;\n};");
// 959
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"sd1fc7c58570d6b17204d66c96d6737b1b3ed299f");
// 960
geval("function ef3c6de5b6248ca8b0bfdcc77a230f02c90b21b5a(JSBNG__event) {\n    var q = $(\"q\");\n    if (((q.value == q.getAttribute(\"placeholder\")))) {\n        q.JSBNG__focus();\n        return false;\n    }\n;\n;\n};\n;");
// 961
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"function e20b7599e0ad487185257ea430c7ba91b8dde6b25(event) {\n    $(\"search_first_focus\").value = ($(\"search_first_focus\").value || +new Date());\n;\n    Bootloader.loadComponents(\"SearchBootloader\", bagofholding);\n};");
// 962
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s795035c57c2e586828c282a9893167b8b9083115");
// 963
geval("function e20b7599e0ad487185257ea430c7ba91b8dde6b25(JSBNG__event) {\n    $(\"search_first_focus\").value = (($(\"search_first_focus\").value || +new JSBNG__Date()));\n;\n    Bootloader.loadComponents(\"SearchBootloader\", bagofholding);\n};\n;");
// 964
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"function e36c889079cc436a1b792dc040228071895aafbe8(event) {\n    var q = $(\"q\");\n    if ((q.value == q.getAttribute(\"placeholder\"))) {\n        q.focus();\n        return false;\n    }\n;\n};");
// 965
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"sac219fb61859ba69eadc0965ae7a631f232ef39b");
// 966
geval("function e36c889079cc436a1b792dc040228071895aafbe8(JSBNG__event) {\n    var q = $(\"q\");\n    if (((q.value == q.getAttribute(\"placeholder\")))) {\n        q.JSBNG__focus();\n        return false;\n    }\n;\n;\n};\n;");
// 967
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"function eae6161415a31a5e8ce59bb3e8c816e1635d150b5(event) {\n    Arbiter.inform(\"PagesVoiceBar/toggle\");\n};");
// 968
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s46dd9dfc8ad54e6044ab3a20afcdb8f99bee7c8d");
// 969
geval("function eae6161415a31a5e8ce59bb3e8c816e1635d150b5(JSBNG__event) {\n    Arbiter.inform(\"PagesVoiceBar/toggle\");\n};\n;");
// 970
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"function e9e250bc7cf77fec22515f9f11d6ee7d5f23b57fa(event) {\n    return Event.__inlineSubmit(this, event);\n};");
// 971
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s7f134122edd55b9733d285fe3a4398b7baff7551");
// 972
geval("function e9e250bc7cf77fec22515f9f11d6ee7d5f23b57fa(JSBNG__event) {\n    return JSBNG__Event.__inlineSubmit(this, JSBNG__event);\n};\n;");
// 973
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"function si_cj(m) {\n    setTimeout(function() {\n        new Image().src = ((\"http://error.facebook.com/common/scribe_endpoint.php?c=si_clickjacking&t=1252\" + \"&m=\") + m);\n    }, 5000);\n};\nif (((top != self) && !false)) {\n    try {\n        if ((parent != top)) {\n            throw 1;\n        }\n    ;\n        var si_cj_d = [\"apps.facebook.com\",\"/pages/\",\"apps.beta.facebook.com\",];\n        var href = top.location.href.toLowerCase();\n        for (var i = 0; (i < si_cj_d.length); i++) {\n            if ((href.indexOf(si_cj_d[i]) >= 0)) {\n                throw 1;\n            }\n        ;\n        };\n        si_cj(\"3 http://www.facebook.com/?sk=welcome\");\n    } catch (e) {\n        si_cj(\"1 \\u0009http://www.facebook.com/?sk=welcome\");\n        window.document.write(\"\\u003Cstyle\\u003Ebody * {display:none !important;}\\u003C/style\\u003E\\u003Ca href=\\\"#\\\" onclick=\\\"top.location.href=window.location.href\\\" style=\\\"display:block !important;padding:10px\\\"\\u003E\\u003Ci class=\\\"img sp_627qpw sx_0a88a1\\\" style=\\\"display:block !important\\\"\\u003E\\u003C/i\\u003EGo to Facebook.com\\u003C/a\\u003E\");\n    };\n}\n;");
// 974
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"se49920fdbb80aabaa58b2eb7957ab610d4d9cfa7");
// 975
geval("function si_cj(m) {\n    JSBNG__setTimeout(function() {\n        new JSBNG__Image().src = ((((\"http://error.facebook.com/common/scribe_endpoint.php?c=si_clickjacking&t=1252\" + \"&m=\")) + m));\n    }, 5000);\n};\n;\nif (((((JSBNG__top != JSBNG__self)) && !false))) {\n    try {\n        if (((parent != JSBNG__top))) {\n            throw 1;\n        }\n    ;\n    ;\n        var si_cj_d = [\"apps.facebook.com\",\"/pages/\",\"apps.beta.facebook.com\",];\n        var href = JSBNG__top.JSBNG__location.href.toLowerCase();\n        for (var i = 0; ((i < si_cj_d.length)); i++) {\n            if (((href.indexOf(si_cj_d[i]) >= 0))) {\n                throw 1;\n            }\n        ;\n        ;\n        };\n    ;\n        si_cj(\"3 http://www.facebook.com/?sk=welcome\");\n    } catch (e) {\n        si_cj(\"1 \\u0009http://www.facebook.com/?sk=welcome\");\n        window.JSBNG__document.write(\"\\u003Cstyle\\u003Ebody * {display:none !important;}\\u003C/style\\u003E\\u003Ca href=\\\"#\\\" onclick=\\\"top.JSBNG__location.href=window.JSBNG__location.href\\\" style=\\\"display:block !important;padding:10px\\\"\\u003E\\u003Ci class=\\\"img sp_627qpw sx_0a88a1\\\" style=\\\"display:block !important\\\"\\u003E\\u003C/i\\u003EGo to Facebook.com\\u003C/a\\u003E\");\n    };\n;\n}\n;\n;");
// 976
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"Bootloader.setResourceMap({\n    zO4BE: {\n        type: \"css\",\n        permanent: 1,\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y_/r/9yVXpo8C3LO.css\"\n    },\n    FVdSs: {\n        type: \"css\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yF/r/Vfpxg02c5r3.css\"\n    },\n    \"X/Fq6\": {\n        type: \"css\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yM/r/BVUpc4p1Q3y.css\"\n    },\n    sT0qP: {\n        type: \"css\",\n        permanent: 1,\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yQ/r/2XbYfRObwUE.css\"\n    },\n    VDymv: {\n        type: \"css\",\n        permanent: 1,\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yP/r/Zec2-4A_H2P.css\"\n    }\n});\nBootloader.setResourceMap({\n    \"8gPM0\": {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yK/r/TQZDrgcUxbA.js\"\n    },\n    bS0QP: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yY/r/xCPq2WEDWGK.js\"\n    },\n    JOZ9R: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y1/r/GD18lh0PTJp.js\"\n    },\n    \"1zqwA\": {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yc/r/jAVvWyD8JgB.js\"\n    },\n    \"6n1TR\": {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yh/r/GfgJ_w7TcHw.js\"\n    },\n    \"28ZbA\": {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/ya/r/GBtTEkiodA0.js\"\n    },\n    C6rJk: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yk/r/mvmvxDKTeL4.js\"\n    },\n    u8TjK: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yE/r/SkoKuwEvjcd.js\"\n    },\n    oGZW7: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y4/r/noOpGIcjF1E.js\"\n    },\n    cNca2: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yT/r/7YVta2ViNbr.js\"\n    },\n    ai925: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yq/r/CYAZMUDf1xO.js\"\n    },\n    DGjNe: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y2/r/PNf0xtgirdh.js\"\n    },\n    bwsMw: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yi/r/5VR2mwxDrFF.js\"\n    },\n    C5ony: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y6/r/lEGUOQM76Fc.js\"\n    },\n    qrs0z: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yt/r/1CfNz6NKIpn.js\"\n    },\n    DI7dA: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y6/r/0xnZS4wiUdW.js\"\n    },\n    sGDQW: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yV/r/v-RRIlT3ZXH.js\"\n    },\n    zyFOp: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y-/r/0ptsa-67vx7.js\"\n    },\n    \"2ma5f\": {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yo/r/hCn6u3fXLtg.js\"\n    },\n    q1R25: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yZ/r/uVstu2bdKQl.js\"\n    },\n    H42Jh: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y3/r/ppwOo4BAmlb.js\"\n    },\n    AtxWD: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yE/r/0jGJARW_TcI.js\"\n    },\n    CJBKn: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yB/r/x5XDkud1H_O.js\"\n    },\n    Kz14F: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yN/r/IkPGluO9j5W.js\"\n    },\n    qu1rX: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y5/r/Bi5k-UD0xh1.js\"\n    },\n    \"1ud7Z\": {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yJ/r/vkTaWvceUuq.js\"\n    },\n    Emb7L: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yy/r/hBUnHOqWk7k.js\"\n    },\n    tIw4R: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yX/r/h6L-WmQ-J1H.js\"\n    },\n    hofTc: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yP/r/EKA5EzGo0o5.js\"\n    },\n    \"2DX3F\": {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y2/r/w03a5Zdm0Lg.js\"\n    }\n});\nBootloader.enableBootload({\n    ErrorSignal: {\n        resources: [\"8gPM0\",\"bS0QP\",\"cNca2\",],\n        \"module\": true\n    },\n    ConfirmationDialog: {\n        resources: [\"8gPM0\",\"bS0QP\",\"ai925\",],\n        \"module\": true\n    },\n    Dialog: {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",],\n        \"module\": true\n    },\n    DOM: {\n        resources: [\"8gPM0\",],\n        \"module\": true\n    },\n    HTML: {\n        resources: [\"8gPM0\",],\n        \"module\": true\n    },\n    \"event-extensions\": {\n        resources: [\"8gPM0\",],\n        \"module\": true\n    },\n    AsyncDialog: {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",],\n        \"module\": true\n    },\n    FbdDialogProvider: {\n        resources: [\"DGjNe\",\"8gPM0\",\"1zqwA\",\"bwsMw\",],\n        \"module\": true\n    },\n    React: {\n        resources: [\"28ZbA\",\"C5ony\",],\n        \"module\": true\n    },\n    AsyncRequest: {\n        resources: [\"8gPM0\",\"bS0QP\",],\n        \"module\": true\n    },\n    PhotoSnowlift: {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",],\n        \"module\": true\n    },\n    VaultBox: {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",\"qrs0z\",\"DI7dA\",\"sGDQW\",\"FVdSs\",],\n        \"module\": true\n    },\n    SpotlightShareViewer: {\n        resources: [\"8gPM0\",\"bS0QP\",\"X/Fq6\",\"zyFOp\",],\n        \"module\": true\n    },\n    PhotoTagger: {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",\"DI7dA\",],\n        \"module\": true\n    },\n    \"fb-photos-snowlift-css\": {\n        resources: [\"sT0qP\",\"zO4BE\",]\n    },\n    Live: {\n        resources: [\"8gPM0\",\"bS0QP\",\"1zqwA\",],\n        \"module\": true\n    },\n    PhotoTagApproval: {\n        resources: [\"8gPM0\",\"bS0QP\",\"DI7dA\",],\n        \"module\": true\n    },\n    PhotoTags: {\n        resources: [\"8gPM0\",\"bS0QP\",\"DI7dA\",],\n        \"module\": true\n    },\n    TagTokenizer: {\n        resources: [\"8gPM0\",\"bS0QP\",\"DI7dA\",\"zO4BE\",],\n        \"module\": true\n    },\n    \"fb-photos-snowlift-fullscreen-css\": {\n        resources: [\"VDymv\",]\n    },\n    PhotoPivot: {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",\"2ma5f\",],\n        \"module\": true\n    },\n    PhotosButtonTooltips: {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",\"q1R25\",],\n        \"module\": true\n    },\n    VideoRotate: {\n        resources: [\"8gPM0\",\"bS0QP\",\"H42Jh\",],\n        \"module\": true\n    },\n    AsyncResponse: {\n        resources: [\"bS0QP\",],\n        \"module\": true\n    },\n    PhotoInlineEditor: {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",\"DI7dA\",\"AtxWD\",],\n        \"module\": true\n    },\n    Form: {\n        resources: [\"8gPM0\",\"bS0QP\",],\n        \"module\": true\n    },\n    IframeShim: {\n        resources: [\"8gPM0\",\"bS0QP\",\"CJBKn\",],\n        \"module\": true\n    },\n    DOMScroll: {\n        resources: [\"8gPM0\",\"bS0QP\",],\n        \"module\": true\n    },\n    Toggler: {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",],\n        \"module\": true\n    },\n    Tooltip: {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",],\n        \"module\": true\n    },\n    Input: {\n        resources: [\"8gPM0\",\"bS0QP\",],\n        \"module\": true\n    },\n    trackReferrer: {\n        resources: [],\n        \"module\": true\n    },\n    \"detect-broken-proxy-cache\": {\n        resources: [\"8gPM0\",]\n    },\n    \"link-rel-preload\": {\n        resources: [\"8gPM0\",]\n    },\n    \"legacy:dialog\": {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",]\n    },\n    \"legacy:ajaxpipe\": {\n        resources: [\"8gPM0\",\"bS0QP\",\"Kz14F\",]\n    },\n    \"legacy:async\": {\n        resources: [\"8gPM0\",\"bS0QP\",]\n    },\n    \"legacy:PhotoSnowlift\": {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",\"q1R25\",]\n    },\n    \"legacy:Toggler\": {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",]\n    },\n    \"autoset-timezone\": {\n        resources: [\"8gPM0\",\"bS0QP\",]\n    },\n    PhotoViewer: {\n        resources: [\"bS0QP\",],\n        \"module\": true\n    },\n    \"legacy:live-timer\": {\n        resources: [\"8gPM0\",]\n    },\n    Music: {\n        resources: [\"8gPM0\",\"bS0QP\",\"1zqwA\",\"zO4BE\",\"6n1TR\",\"qu1rX\",\"1ud7Z\",],\n        \"module\": true\n    },\n    MusicLiveListen: {\n        resources: [\"8gPM0\",\"bS0QP\",\"1zqwA\",\"zO4BE\",\"6n1TR\",\"qu1rX\",\"1ud7Z\",\"Emb7L\",],\n        \"module\": true\n    },\n    SearchBootloader: {\n        resources: [\"8gPM0\",\"zO4BE\",\"bS0QP\",\"6n1TR\",]\n    },\n    \"legacy:min-notifications-jewel\": {\n        resources: [\"8gPM0\",\"bS0QP\",\"tIw4R\",\"hofTc\",]\n    },\n    \"desktop-notifications\": {\n        resources: [\"2DX3F\",]\n    },\n    ErrorDialog: {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",],\n        \"module\": true\n    }\n});");
// 977
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s1233606da41ac07be16c0bb4ca7d352cac2a3f58");
// 978
geval("Bootloader.setResourceMap({\n    zO4BE: {\n        type: \"css\",\n        permanent: 1,\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y_/r/9yVXpo8C3LO.css\"\n    },\n    FVdSs: {\n        type: \"css\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yF/r/Vfpxg02c5r3.css\"\n    },\n    \"X/Fq6\": {\n        type: \"css\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yM/r/BVUpc4p1Q3y.css\"\n    },\n    sT0qP: {\n        type: \"css\",\n        permanent: 1,\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yQ/r/2XbYfRObwUE.css\"\n    },\n    VDymv: {\n        type: \"css\",\n        permanent: 1,\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yP/r/Zec2-4A_H2P.css\"\n    }\n});\nBootloader.setResourceMap({\n    \"8gPM0\": {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yK/r/TQZDrgcUxbA.js\"\n    },\n    bS0QP: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yY/r/xCPq2WEDWGK.js\"\n    },\n    JOZ9R: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y1/r/GD18lh0PTJp.js\"\n    },\n    \"1zqwA\": {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yc/r/jAVvWyD8JgB.js\"\n    },\n    \"6n1TR\": {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yh/r/GfgJ_w7TcHw.js\"\n    },\n    \"28ZbA\": {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/ya/r/GBtTEkiodA0.js\"\n    },\n    C6rJk: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yk/r/mvmvxDKTeL4.js\"\n    },\n    u8TjK: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yE/r/SkoKuwEvjcd.js\"\n    },\n    oGZW7: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y4/r/noOpGIcjF1E.js\"\n    },\n    cNca2: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yT/r/7YVta2ViNbr.js\"\n    },\n    ai925: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yq/r/CYAZMUDf1xO.js\"\n    },\n    DGjNe: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y2/r/PNf0xtgirdh.js\"\n    },\n    bwsMw: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yi/r/5VR2mwxDrFF.js\"\n    },\n    C5ony: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y6/r/lEGUOQM76Fc.js\"\n    },\n    qrs0z: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yt/r/1CfNz6NKIpn.js\"\n    },\n    DI7dA: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y6/r/0xnZS4wiUdW.js\"\n    },\n    sGDQW: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yV/r/v-RRIlT3ZXH.js\"\n    },\n    zyFOp: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y-/r/0ptsa-67vx7.js\"\n    },\n    \"2ma5f\": {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yo/r/hCn6u3fXLtg.js\"\n    },\n    q1R25: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yZ/r/uVstu2bdKQl.js\"\n    },\n    H42Jh: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y3/r/ppwOo4BAmlb.js\"\n    },\n    AtxWD: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yE/r/0jGJARW_TcI.js\"\n    },\n    CJBKn: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yB/r/x5XDkud1H_O.js\"\n    },\n    Kz14F: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yN/r/IkPGluO9j5W.js\"\n    },\n    qu1rX: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y5/r/Bi5k-UD0xh1.js\"\n    },\n    \"1ud7Z\": {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yJ/r/vkTaWvceUuq.js\"\n    },\n    Emb7L: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yy/r/hBUnHOqWk7k.js\"\n    },\n    tIw4R: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yX/r/h6L-WmQ-J1H.js\"\n    },\n    hofTc: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yP/r/EKA5EzGo0o5.js\"\n    },\n    \"2DX3F\": {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y2/r/w03a5Zdm0Lg.js\"\n    }\n});\nBootloader.enableBootload({\n    ErrorSignal: {\n        resources: [\"8gPM0\",\"bS0QP\",\"cNca2\",],\n        \"module\": true\n    },\n    ConfirmationDialog: {\n        resources: [\"8gPM0\",\"bS0QP\",\"ai925\",],\n        \"module\": true\n    },\n    Dialog: {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",],\n        \"module\": true\n    },\n    DOM: {\n        resources: [\"8gPM0\",],\n        \"module\": true\n    },\n    HTML: {\n        resources: [\"8gPM0\",],\n        \"module\": true\n    },\n    \"event-extensions\": {\n        resources: [\"8gPM0\",],\n        \"module\": true\n    },\n    AsyncDialog: {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",],\n        \"module\": true\n    },\n    FbdDialogProvider: {\n        resources: [\"DGjNe\",\"8gPM0\",\"1zqwA\",\"bwsMw\",],\n        \"module\": true\n    },\n    React: {\n        resources: [\"28ZbA\",\"C5ony\",],\n        \"module\": true\n    },\n    AsyncRequest: {\n        resources: [\"8gPM0\",\"bS0QP\",],\n        \"module\": true\n    },\n    PhotoSnowlift: {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",],\n        \"module\": true\n    },\n    VaultBox: {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",\"qrs0z\",\"DI7dA\",\"sGDQW\",\"FVdSs\",],\n        \"module\": true\n    },\n    SpotlightShareViewer: {\n        resources: [\"8gPM0\",\"bS0QP\",\"X/Fq6\",\"zyFOp\",],\n        \"module\": true\n    },\n    PhotoTagger: {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",\"DI7dA\",],\n        \"module\": true\n    },\n    \"fb-photos-snowlift-css\": {\n        resources: [\"sT0qP\",\"zO4BE\",]\n    },\n    Live: {\n        resources: [\"8gPM0\",\"bS0QP\",\"1zqwA\",],\n        \"module\": true\n    },\n    PhotoTagApproval: {\n        resources: [\"8gPM0\",\"bS0QP\",\"DI7dA\",],\n        \"module\": true\n    },\n    PhotoTags: {\n        resources: [\"8gPM0\",\"bS0QP\",\"DI7dA\",],\n        \"module\": true\n    },\n    TagTokenizer: {\n        resources: [\"8gPM0\",\"bS0QP\",\"DI7dA\",\"zO4BE\",],\n        \"module\": true\n    },\n    \"fb-photos-snowlift-fullscreen-css\": {\n        resources: [\"VDymv\",]\n    },\n    PhotoPivot: {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",\"2ma5f\",],\n        \"module\": true\n    },\n    PhotosButtonTooltips: {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",\"q1R25\",],\n        \"module\": true\n    },\n    VideoRotate: {\n        resources: [\"8gPM0\",\"bS0QP\",\"H42Jh\",],\n        \"module\": true\n    },\n    AsyncResponse: {\n        resources: [\"bS0QP\",],\n        \"module\": true\n    },\n    PhotoInlineEditor: {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",\"DI7dA\",\"AtxWD\",],\n        \"module\": true\n    },\n    Form: {\n        resources: [\"8gPM0\",\"bS0QP\",],\n        \"module\": true\n    },\n    IframeShim: {\n        resources: [\"8gPM0\",\"bS0QP\",\"CJBKn\",],\n        \"module\": true\n    },\n    DOMScroll: {\n        resources: [\"8gPM0\",\"bS0QP\",],\n        \"module\": true\n    },\n    Toggler: {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",],\n        \"module\": true\n    },\n    Tooltip: {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",],\n        \"module\": true\n    },\n    Input: {\n        resources: [\"8gPM0\",\"bS0QP\",],\n        \"module\": true\n    },\n    trackReferrer: {\n        resources: [],\n        \"module\": true\n    },\n    \"detect-broken-proxy-cache\": {\n        resources: [\"8gPM0\",]\n    },\n    \"link-rel-preload\": {\n        resources: [\"8gPM0\",]\n    },\n    \"legacy:dialog\": {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",]\n    },\n    \"legacy:ajaxpipe\": {\n        resources: [\"8gPM0\",\"bS0QP\",\"Kz14F\",]\n    },\n    \"legacy:async\": {\n        resources: [\"8gPM0\",\"bS0QP\",]\n    },\n    \"legacy:PhotoSnowlift\": {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",\"q1R25\",]\n    },\n    \"legacy:Toggler\": {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",]\n    },\n    \"autoset-timezone\": {\n        resources: [\"8gPM0\",\"bS0QP\",]\n    },\n    PhotoViewer: {\n        resources: [\"bS0QP\",],\n        \"module\": true\n    },\n    \"legacy:live-timer\": {\n        resources: [\"8gPM0\",]\n    },\n    Music: {\n        resources: [\"8gPM0\",\"bS0QP\",\"1zqwA\",\"zO4BE\",\"6n1TR\",\"qu1rX\",\"1ud7Z\",],\n        \"module\": true\n    },\n    MusicLiveListen: {\n        resources: [\"8gPM0\",\"bS0QP\",\"1zqwA\",\"zO4BE\",\"6n1TR\",\"qu1rX\",\"1ud7Z\",\"Emb7L\",],\n        \"module\": true\n    },\n    SearchBootloader: {\n        resources: [\"8gPM0\",\"zO4BE\",\"bS0QP\",\"6n1TR\",]\n    },\n    \"legacy:min-notifications-jewel\": {\n        resources: [\"8gPM0\",\"bS0QP\",\"tIw4R\",\"hofTc\",]\n    },\n    \"desktop-notifications\": {\n        resources: [\"2DX3F\",]\n    },\n    ErrorDialog: {\n        resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",],\n        \"module\": true\n    }\n});");
// 1002
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"Bootloader.configurePage([\"zO4BE\",]);\nBootloader.done([\"jDr+c\",]);\nJSCC.init(({\n    j1JDVIO9pN6SY5oVDJ0: function() {\n        return new RequestsJewel();\n    }\n}));\nnew (require(\"ServerJS\"))().handle({\n    instances: [[\"m205505_1\",[\"AsyncLayout\",],[\"contentArea\",],1,],[\"m205506_4\",[\"Typeahead\",\"m205506_7\",\"SearchTypeaheadView\",\"SearchTypeaheadRenderer\",\"m205506_5\",\"SearchTypeaheadCore\",\"m205506_6\",],[{\n        __m: \"m205506_7\"\n    },{\n        node_id: \"\",\n        ctor: {\n            __m: \"SearchTypeaheadView\"\n        },\n        options: {\n            autoSelect: true,\n            renderer: {\n                __m: \"SearchTypeaheadRenderer\"\n            },\n            causalElement: {\n                __m: \"m205506_5\"\n            },\n            maxResults: 8,\n            typeObjects: {\n                app: {\n                    uid: \"app\",\n                    text: \"app\",\n                    type: \"header\",\n                    markup: \"Apps\"\n                },\n                event: {\n                    uid: \"event\",\n                    text: \"event\",\n                    type: \"header\",\n                    markup: \"Events\"\n                },\n                group: {\n                    uid: \"group\",\n                    text: \"group\",\n                    type: \"header\",\n                    markup: \"Groups\"\n                },\n                page: {\n                    uid: \"page\",\n                    text: \"page\",\n                    type: \"header\",\n                    markup: \"Pages\"\n                },\n                place: {\n                    uid: \"place\",\n                    text: \"place\",\n                    type: \"header\",\n                    markup: \"Places\"\n                },\n                share: {\n                    uid: \"share\",\n                    text: \"share\",\n                    type: \"header\",\n                    markup: \"Shared Links\"\n                },\n                shortcut: {\n                    uid: \"shortcut\",\n                    text: \"shortcut\",\n                    type: \"header\",\n                    markup: \"Facebook\"\n                },\n                user: {\n                    uid: \"user\",\n                    text: \"user\",\n                    type: \"header\",\n                    markup: \"People\"\n                },\n                song: {\n                    uid: \"song\",\n                    text: \"song\",\n                    type: \"header\",\n                    markup: \"Music\"\n                },\n                friendlist: {\n                    uid: \"friendlist\",\n                    text: \"friendlist\",\n                    type: \"header\",\n                    markup: \"Lists\"\n                },\n                websuggestion: {\n                    uid: \"websuggestion\",\n                    text: \"websuggestion\",\n                    type: \"header\",\n                    markup: \"Search the Web\"\n                }\n            },\n            seeMoreEndpoint: \"http://www.facebook.com/search/results.php\"\n        }\n    },{\n        ctor: {\n            __m: \"SearchTypeaheadCore\"\n        },\n        options: {\n            keepFocused: false,\n            resetOnSelect: true\n        }\n    },{\n        __m: \"m205506_6\"\n    },],4,],[\"m205506_2\",[\"JewelX\",\"m205507_10\",],[{\n        __m: \"m205507_10\"\n    },{\n        name: \"mercurymessages\",\n        fade_on_open: 0\n    },],2,],[\"m205507_9\",[\"JewelX\",\"m205507_11\",],[{\n        __m: \"m205507_11\"\n    },{\n        name: \"requests\",\n        fade_on_open: 0\n    },],2,],[\"m205507_13\",[\"JewelX\",\"m205507_12\",],[{\n        __m: \"m205507_12\"\n    },{\n        name: \"notifications\",\n        fade_on_open: 0\n    },],1,],[\"m205507_15\",[\"ScrollableArea\",\"m205507_14\",],[{\n        __m: \"m205507_14\"\n    },{\n        persistent: true\n    },],1,],[\"m205506_7\",[\"SearchDataSource\",],[{\n        0: false,\n        minWebSugg: 3,\n        maxResults: 8,\n        indexedFields: [\"text\",\"tokens\",\"alias\",],\n        queryData: {\n            viewer: 100001812504199,\n            rsp: \"search\",\n            context: \"search\"\n        },\n        queryEndpoint: \"/ajax/typeahead/search.php\",\n        bootstrapData: {\n            viewer: 100001812504199,\n            token: \"v7\"\n        },\n        bootstrapEndpoint: \"/ajax/typeahead/search/bootstrap.php\",\n        token: \"1343822055-7\",\n        genTime: 1344872055\n    },],2,],],\n    elements: [[\"m205506_6\",\"uq3j16_1\",2,],[\"m205506_5\",\"uq3j16_2\",4,],[\"m205507_10\",\"fbMessagesJewel\",2,],[\"m205507_11\",\"fbRequestsJewel\",2,],[\"m205507_12\",\"fbNotificationsJewel\",2,],[\"m205507_14\",\"uq3j16_3\",2,],[\"m205506_3\",\"navSearch\",2,],[\"m205507_8\",\"logout_form\",2,],],\n    define: [[\"BanzaiConfig\",[],{\n        MAX_SIZE: 10000,\n        MAX_WAIT: 60000,\n        gks: []\n    },],[\"MercuryConfig\",[],{\n        MessagesMercuryIntegrationGK: 0,\n        MessagingDisplayEmojiGK: 1,\n        ChatControlLanguageChangeGK: 0,\n        \"24h_times\": false,\n        \"roger.seen_delay\": 15000,\n        activity_limit: 60000,\n        idle_limit: 1800000,\n        idle_poll_interval: 300000\n    },],[\"QuicklingConfig\",[],{\n        version: \"608370;0\",\n        sessionLength: 10,\n        inactivePageRegex: \"^\\\\/(ac\\\\.php|ads\\\\/create\\\\/|ads\\\\/manage\\\\/|advertising\\\\/|ae\\\\.php|ajax\\\\/emu\\\\/end\\\\.php|ajax\\\\/emu\\\\/f\\\\.php|ajax\\\\/emu\\\\/h\\\\.php|badges\\\\/|campaign\\\\/landing\\\\.php|comments\\\\.php|connect\\\\/uiserver\\\\.php|editalbum\\\\.php.+add=1|ext\\\\/|feeds\\\\/|help(\\\\/|\\\\?|$)|identity_switch\\\\.php|intern\\\\/|login\\\\.php|logout\\\\.php|sitetour\\\\/homepage_tour\\\\.php|sorry\\\\.php|syndication\\\\.php|webmessenger)|\\\\/plugins\\\\/subscribe|\\\\.pdf$|brandpermissions\"\n    },],],\n    require: [[\"UserActionHistory\",],[\"userAction\",\"setUATypeConfig\",[],[{\n        uan: false,\n        uai: false,\n        uad: false,\n        uae: false\n    },],],[\"ScriptPathState\",\"setUserURISampleRate\",[],[3723,],],[\"userAction\",\"setCustomSampleConfig\",[],[{\n        uan: {\n            test: {\n                test: true\n            }\n        }\n    },],],[\"DimensionTracking\",],[\"DocumentTitle\",\"set\",[],[\"Facebook\",],],[\"HomeTickerFirstRightColumnController\",\"init\",[],[{\n        enableSidebar: 1,\n        fixAdsOnScroll: 1,\n        maxFixedAds: 6,\n        refreshPremiumAds: 0,\n        tickerMaxHeight: 425,\n        tickerMinHeight: 225,\n        tickerHeightRatio: 4060,\n        tickerAbsMinHeight: 120,\n        adsRefreshInterval: 60000,\n        adsRefreshDelay: 5000,\n        adsRefreshOnmove: 0\n    },],],[\"ChatSidebar\",\"setHasWideContent\",[],[false,],],[\"SidebarPrelude\",\"addSidebarMode\",[],[1225,],],[\"m205505_1\",],[\"Quickling\",],[\"MercuryJewel\",],[\"TitanLeftNav\",\"initialize\",[],[],],[\"m205506_4\",],[\"Typeahead\",\"init\",[\"m205506_5\",\"m205506_4\",],[{\n        __m: \"m205506_5\"\n    },{\n        __m: \"m205506_4\"\n    },[\"searchRecorderBasic\",\"regulateMemorializedUsers\",\"showLoadingIndicator\",\"initFilters\",],null,],],[\"PlaceholderListener\",],[\"PlaceholderOnsubmitFormListener\",],[\"FlipDirectionOnKeypress\",],[\"enforceMaxLength\",],[\"m205506_2\",],[\"m205507_9\",],[\"m205507_13\",],[\"Scrollable\",],[\"m205507_15\",],[\"TinyViewport\",],[\"PagesVoiceBar\",\"initVoiceBar\",[],[],],[\"InitialJSLoader\",\"loadOnDOMContentReady\",[],[[\"8gPM0\",\"bS0QP\",\"JOZ9R\",\"1zqwA\",\"6n1TR\",\"28ZbA\",\"C6rJk\",\"u8TjK\",\"oGZW7\",],],],]\n});\nonloadRegister_DEPRECATED(function() {\n    window.intl_locale_rewrites = {\n        meta: {\n            \"/_B/\": \"([.,!?\\\\s]|^)\",\n            \"/_E/\": \"([.,!?\\\\s]|$)\"\n        },\n        patterns: {\n            \"/\\u0001(.*)('|&#039;)s\\u0001(?:'|&#039;)s(.*)/\": \"\\u0001$1$2s\\u0001$3\",\n            \"/_\\u0001([^\\u0001]*)\\u0001/e\": \"mb_strtolower(\\\"\\u0001$1\\u0001\\\")\",\n            \"/\\\\^\\\\x01([^\\\\x01])(?=[^\\\\x01]*\\\\x01)/e\": \"mb_strtoupper(\\\"\\u0001$1\\\")\",\n            \"/_\\u0001([^\\u0001]*)\\u0001/\": \"javascript\"\n        }\n    };\n});\nonloadRegister_DEPRECATED(function() {\n    AdwareScaner.init([\".facebook.(com|net)$\",\".fbcdn.net$\",\"(^fbcdn_|^fbcdn-)(.)*.akamaihd.net$\",\".virtualearth.net$\",], {\n        pagerage: [\"AdBarAdLeft\",\"AdBarAdRight\",\"ProfileFeedAd\",\"JYRightTopCurtain\",\"JYLeftBottomFixedCurtain\",\"JYFooterBanner\",\"y2-pr-removeLayout\",\"fbPageRage\",\"facebookPageRageApp\",\"PRCookieJar\",],\n        dropdowndeals: [\"dropdowndeals\",],\n        facetheme: [\"pageFooterAd\",\"leftColAd\",\"rightColAd2\",\"homeStreamAd1\",\"homeStreamAd2\",\"homeStreamAd3\",\"homeStreamBottomAd1\",\"pfa1\",],\n        __investigate_ft: {\n            0: \"pageFooterAd\",\n            1: \"leftColAd\",\n            2: \"rightColAd2\",\n            3: \"homeStreamAd1\",\n            4: \"homeStreamAd2\",\n            5: \"homeStreamAd3\",\n            7: \"pfa1\"\n        },\n        elriel: [\"pagelet_promoskin\",\"pagelet_promoonlineonly\",\"pagelet_tuto1\",],\n        connectbar: [\"conbAd_41\",\"conbAd_42\",\"conbAd_39\",],\n        chatvibes: [\"fbchatvibesloader\",\"popUpDiv\",\"popupMenuImage\",\"LinkuryImages\",\"popupMenuVideo\",],\n        iminent: [\"imb-ad\",],\n        fbuzz: [\"mysocialfav\",\"rate-style\",\"mysocial\",],\n        buzzdock: [\"conbAd_40\",],\n        facemoods: [\"fm_swf_engine\",\"_FM_Component_Holder\",\"_FM_flashHolder\",],\n        chatsend: [\"chatsendjs\",\"tcfjquery\",\"chatsendloader\",\"chatzumjs\",],\n        \"2yourface\": [\"ChatDialog\",\"ChatDlgInside\",],\n        bflix: [\"superfishStart\",],\n        clickpotato: [\"player_iframe\",\"liframe\",],\n        zuperface: [\"topluoneri\",],\n        menutab: [\"injectScript\",],\n        lilyjade: [\"lx_inz\",]\n    }, {\n        pagerage: [\"leftCol\",]\n    }, {\n    }, {\n        youtube_ext: [\"chrome-extension://pkhidkonipdjidjglnkfcfhnkfnlefbk/manifest.json\",],\n        bflix: [\"chrome-extension://kjafndplmofcedgddaoceenkcbfankem/manifest.json\",],\n        facetheme: [\"chrome-extension://kincjchfokkeneeofpeefomkikfkiedl/manifest.json\",],\n        token_stealers: [\"chrome-extension://iejbljbhhoclgfiapmomcpkpkcmihfib/manifest.json\",],\n        turkish_malware: [\"chrome-extension://lkfhadffdnjnogmgjfihlcmmjhcfchaj/manifest.json\",\"chrome-extension://afnnkheojlgkipfabekmdkngocfhegck/manifest.json\",],\n        adobeflash: [\"chrome-extension://hkpibllecmidllaojdmkcmfnoinmejco/manifest.json\",],\n        socialcolorful: [\"chrome-extension://gpllafflnmgjjcakjloknldkndnkmcpi/manifest.json\",]\n    });\n});\nonloadRegister_DEPRECATED(function() {\n    requireLazy([\"MercuryJewel\",], function(MercuryJewel) {\n        new MercuryJewel($(\"fbMessagesFlyout\"), $(\"fbMessagesJewel\"), require(\"m205506_2\"), {\n            message_counts: [{\n                unread_count: 0,\n                unseen_count: 0,\n                seen_timestamp: 0,\n                last_action_id: 0,\n                folder: \"inbox\"\n            },],\n            payload_source: \"server_initial_data\"\n        });\n    });\n});\nonloadRegister_DEPRECATED(function() {\n    require(\"m205506_4\").getData().onLoad(false, true);\n});\nonloadRegister_DEPRECATED(function() {\n    window.presenceRequests = JSCC.get(\"j1JDVIO9pN6SY5oVDJ0\").init(require(\"m205507_9\"), \"[fb]requests\", false);\n});\nonloadRegister_DEPRECATED(function() {\n    window.presenceNotifications = new OriginalNotifications({\n        updateTime: 1344872055000,\n        latestNotif: null,\n        latestReadNotif: null,\n        updatePeriod: 480000,\n        cacheVersion: 2,\n        allowDesktopNotifications: false,\n        notifReceivedType: \"notification\",\n        wrapperID: \"fbNotificationsJewel\",\n        contentID: \"fbNotificationsList\",\n        shouldLogImpressions: 0,\n        useInfiniteScroll: 1,\n        unaggregatedBeeper: false,\n        persistUnreadColor: true,\n        unseenVsUnread: 0,\n        receiveSoundPath: null\n    });\n});\nonloadRegister_DEPRECATED(function() {\n    Arbiter.inform(\"jewel/count-initial\", {\n        jewel: \"notifications\",\n        count: 0\n    }, Arbiter.BEHAVIOR_STATE);\n});\nonafterloadRegister_DEPRECATED(function() {\n    Bootloader.loadComponents([\"detect-broken-proxy-cache\",], function() {\n        detect_broken_proxy_cache(\"100001812504199\", \"c_user\");\n    });\n});\nonafterloadRegister_DEPRECATED(function() {\n    Bootloader.loadComponents([\"link-rel-preload\",], function() {\n        link_rel_preload();\n    });\n});\nonafterloadRegister_DEPRECATED(function() {\n    Bootloader.loadComponents([\"autoset-timezone\",], function() {\n        tz_autoset(1344872055, -240);\n    });\n});\nonafterloadRegister_DEPRECATED(function() {\n    Bootloader.loadComponents([\"legacy:live-timer\",], function() {\n        LiveTimer.restart(1344872055);\n    });\n});");
// 1003
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"seb96b3c54fb5d2182ad9690a8149cf46752afc80");
// 1004
geval("Bootloader.configurePage([\"zO4BE\",]);\nBootloader.done([\"jDr+c\",]);\nJSCC.init(({\n    j1JDVIO9pN6SY5oVDJ0: function() {\n        return new RequestsJewel();\n    }\n}));\nnew (require(\"ServerJS\"))().handle({\n    instances: [[\"m205505_1\",[\"AsyncLayout\",],[\"contentArea\",],1,],[\"m205506_4\",[\"Typeahead\",\"m205506_7\",\"SearchTypeaheadView\",\"SearchTypeaheadRenderer\",\"m205506_5\",\"SearchTypeaheadCore\",\"m205506_6\",],[{\n        __m: \"m205506_7\"\n    },{\n        node_id: \"\",\n        ctor: {\n            __m: \"SearchTypeaheadView\"\n        },\n        options: {\n            autoSelect: true,\n            renderer: {\n                __m: \"SearchTypeaheadRenderer\"\n            },\n            causalElement: {\n                __m: \"m205506_5\"\n            },\n            maxResults: 8,\n            typeObjects: {\n                app: {\n                    uid: \"app\",\n                    text: \"app\",\n                    type: \"header\",\n                    markup: \"Apps\"\n                },\n                JSBNG__event: {\n                    uid: \"JSBNG__event\",\n                    text: \"JSBNG__event\",\n                    type: \"header\",\n                    markup: \"Events\"\n                },\n                group: {\n                    uid: \"group\",\n                    text: \"group\",\n                    type: \"header\",\n                    markup: \"Groups\"\n                },\n                page: {\n                    uid: \"page\",\n                    text: \"page\",\n                    type: \"header\",\n                    markup: \"Pages\"\n                },\n                place: {\n                    uid: \"place\",\n                    text: \"place\",\n                    type: \"header\",\n                    markup: \"Places\"\n                },\n                share: {\n                    uid: \"share\",\n                    text: \"share\",\n                    type: \"header\",\n                    markup: \"Shared Links\"\n                },\n                shortcut: {\n                    uid: \"shortcut\",\n                    text: \"shortcut\",\n                    type: \"header\",\n                    markup: \"Facebook\"\n                },\n                user: {\n                    uid: \"user\",\n                    text: \"user\",\n                    type: \"header\",\n                    markup: \"People\"\n                },\n                song: {\n                    uid: \"song\",\n                    text: \"song\",\n                    type: \"header\",\n                    markup: \"Music\"\n                },\n                friendlist: {\n                    uid: \"friendlist\",\n                    text: \"friendlist\",\n                    type: \"header\",\n                    markup: \"Lists\"\n                },\n                websuggestion: {\n                    uid: \"websuggestion\",\n                    text: \"websuggestion\",\n                    type: \"header\",\n                    markup: \"Search the Web\"\n                }\n            },\n            seeMoreEndpoint: \"http://www.facebook.com/search/results.php\"\n        }\n    },{\n        ctor: {\n            __m: \"SearchTypeaheadCore\"\n        },\n        options: {\n            keepFocused: false,\n            resetOnSelect: true\n        }\n    },{\n        __m: \"m205506_6\"\n    },],4,],[\"m205506_2\",[\"JewelX\",\"m205507_10\",],[{\n        __m: \"m205507_10\"\n    },{\n        JSBNG__name: \"mercurymessages\",\n        fade_on_open: 0\n    },],2,],[\"m205507_9\",[\"JewelX\",\"m205507_11\",],[{\n        __m: \"m205507_11\"\n    },{\n        JSBNG__name: \"requests\",\n        fade_on_open: 0\n    },],2,],[\"m205507_13\",[\"JewelX\",\"m205507_12\",],[{\n        __m: \"m205507_12\"\n    },{\n        JSBNG__name: \"notifications\",\n        fade_on_open: 0\n    },],1,],[\"m205507_15\",[\"ScrollableArea\",\"m205507_14\",],[{\n        __m: \"m205507_14\"\n    },{\n        persistent: true\n    },],1,],[\"m205506_7\",[\"SearchDataSource\",],[{\n        0: false,\n        minWebSugg: 3,\n        maxResults: 8,\n        indexedFields: [\"text\",\"tokens\",\"alias\",],\n        queryData: {\n            viewer: 100001812504199,\n            rsp: \"search\",\n            context: \"search\"\n        },\n        queryEndpoint: \"/ajax/typeahead/search.php\",\n        bootstrapData: {\n            viewer: 100001812504199,\n            token: \"v7\"\n        },\n        bootstrapEndpoint: \"/ajax/typeahead/search/bootstrap.php\",\n        token: \"1343822055-7\",\n        genTime: 1344872055\n    },],2,],],\n    elements: [[\"m205506_6\",\"uq3j16_1\",2,],[\"m205506_5\",\"uq3j16_2\",4,],[\"m205507_10\",\"fbMessagesJewel\",2,],[\"m205507_11\",\"fbRequestsJewel\",2,],[\"m205507_12\",\"fbNotificationsJewel\",2,],[\"m205507_14\",\"uq3j16_3\",2,],[\"m205506_3\",\"navSearch\",2,],[\"m205507_8\",\"logout_form\",2,],],\n    define: [[\"BanzaiConfig\",[],{\n        MAX_SIZE: 10000,\n        MAX_WAIT: 60000,\n        gks: []\n    },],[\"MercuryConfig\",[],{\n        MessagesMercuryIntegrationGK: 0,\n        MessagingDisplayEmojiGK: 1,\n        ChatControlLanguageChangeGK: 0,\n        \"24h_times\": false,\n        \"roger.seen_delay\": 15000,\n        activity_limit: 60000,\n        idle_limit: 1800000,\n        idle_poll_interval: 300000\n    },],[\"QuicklingConfig\",[],{\n        version: \"608370;0\",\n        sessionLength: 10,\n        inactivePageRegex: \"^\\\\/(ac\\\\.php|ads\\\\/create\\\\/|ads\\\\/manage\\\\/|advertising\\\\/|ae\\\\.php|ajax\\\\/emu\\\\/end\\\\.php|ajax\\\\/emu\\\\/f\\\\.php|ajax\\\\/emu\\\\/h\\\\.php|badges\\\\/|campaign\\\\/landing\\\\.php|comments\\\\.php|connect\\\\/uiserver\\\\.php|editalbum\\\\.php.+add=1|ext\\\\/|feeds\\\\/|help(\\\\/|\\\\?|$)|identity_switch\\\\.php|intern\\\\/|login\\\\.php|logout\\\\.php|sitetour\\\\/homepage_tour\\\\.php|sorry\\\\.php|syndication\\\\.php|webmessenger)|\\\\/plugins\\\\/subscribe|\\\\.pdf$|brandpermissions\"\n    },],],\n    require: [[\"UserActionHistory\",],[\"userAction\",\"setUATypeConfig\",[],[{\n        uan: false,\n        uai: false,\n        uad: false,\n        uae: false\n    },],],[\"ScriptPathState\",\"setUserURISampleRate\",[],[3723,],],[\"userAction\",\"setCustomSampleConfig\",[],[{\n        uan: {\n            test: {\n                test: true\n            }\n        }\n    },],],[\"DimensionTracking\",],[\"DocumentTitle\",\"set\",[],[\"Facebook\",],],[\"HomeTickerFirstRightColumnController\",\"init\",[],[{\n        enableSidebar: 1,\n        fixAdsOnScroll: 1,\n        maxFixedAds: 6,\n        refreshPremiumAds: 0,\n        tickerMaxHeight: 425,\n        tickerMinHeight: 225,\n        tickerHeightRatio: 4060,\n        tickerAbsMinHeight: 120,\n        adsRefreshInterval: 60000,\n        adsRefreshDelay: 5000,\n        adsRefreshOnmove: 0\n    },],],[\"ChatSidebar\",\"setHasWideContent\",[],[false,],],[\"SidebarPrelude\",\"addSidebarMode\",[],[1225,],],[\"m205505_1\",],[\"Quickling\",],[\"MercuryJewel\",],[\"TitanLeftNav\",\"initialize\",[],[],],[\"m205506_4\",],[\"Typeahead\",\"init\",[\"m205506_5\",\"m205506_4\",],[{\n        __m: \"m205506_5\"\n    },{\n        __m: \"m205506_4\"\n    },[\"searchRecorderBasic\",\"regulateMemorializedUsers\",\"showLoadingIndicator\",\"initFilters\",],null,],],[\"PlaceholderListener\",],[\"PlaceholderOnsubmitFormListener\",],[\"FlipDirectionOnKeypress\",],[\"enforceMaxLength\",],[\"m205506_2\",],[\"m205507_9\",],[\"m205507_13\",],[\"Scrollable\",],[\"m205507_15\",],[\"TinyViewport\",],[\"PagesVoiceBar\",\"initVoiceBar\",[],[],],[\"InitialJSLoader\",\"loadOnDOMContentReady\",[],[[\"8gPM0\",\"bS0QP\",\"JOZ9R\",\"1zqwA\",\"6n1TR\",\"28ZbA\",\"C6rJk\",\"u8TjK\",\"oGZW7\",],],],]\n});\nJSBNG__onloadRegister_DEPRECATED(function() {\n    window.intl_locale_rewrites = {\n        meta: {\n            \"/_B/\": \"([.,!?\\\\s]|^)\",\n            \"/_E/\": \"([.,!?\\\\s]|$)\"\n        },\n        patterns: {\n            \"/\\u0001(.*)('|&#039;)s\\u0001(?:'|&#039;)s(.*)/\": \"\\u0001$1$2s\\u0001$3\",\n            \"/_\\u0001([^\\u0001]*)\\u0001/e\": \"mb_strtolower(\\\"\\u0001$1\\u0001\\\")\",\n            \"/\\\\^\\\\x01([^\\\\x01])(?=[^\\\\x01]*\\\\x01)/e\": \"mb_strtoupper(\\\"\\u0001$1\\\")\",\n            \"/_\\u0001([^\\u0001]*)\\u0001/\": \"javascript\"\n        }\n    };\n});\nJSBNG__onloadRegister_DEPRECATED(function() {\n    AdwareScaner.init([\".facebook.(com|net)$\",\".fbcdn.net$\",\"(^fbcdn_|^fbcdn-)(.)*.akamaihd.net$\",\".virtualearth.net$\",], {\n        pagerage: [\"AdBarAdLeft\",\"AdBarAdRight\",\"ProfileFeedAd\",\"JYRightTopCurtain\",\"JYLeftBottomFixedCurtain\",\"JYFooterBanner\",\"y2-pr-removeLayout\",\"fbPageRage\",\"facebookPageRageApp\",\"PRCookieJar\",],\n        dropdowndeals: [\"dropdowndeals\",],\n        facetheme: [\"pageFooterAd\",\"leftColAd\",\"rightColAd2\",\"homeStreamAd1\",\"homeStreamAd2\",\"homeStreamAd3\",\"homeStreamBottomAd1\",\"pfa1\",],\n        __investigate_ft: {\n            0: \"pageFooterAd\",\n            1: \"leftColAd\",\n            2: \"rightColAd2\",\n            3: \"homeStreamAd1\",\n            4: \"homeStreamAd2\",\n            5: \"homeStreamAd3\",\n            7: \"pfa1\"\n        },\n        elriel: [\"pagelet_promoskin\",\"pagelet_promoonlineonly\",\"pagelet_tuto1\",],\n        connectbar: [\"conbAd_41\",\"conbAd_42\",\"conbAd_39\",],\n        chatvibes: [\"fbchatvibesloader\",\"popUpDiv\",\"popupMenuImage\",\"LinkuryImages\",\"popupMenuVideo\",],\n        iminent: [\"imb-ad\",],\n        fbuzz: [\"mysocialfav\",\"rate-style\",\"mysocial\",],\n        buzzdock: [\"conbAd_40\",],\n        facemoods: [\"fm_swf_engine\",\"_FM_Component_Holder\",\"_FM_flashHolder\",],\n        chatsend: [\"chatsendjs\",\"tcfjquery\",\"chatsendloader\",\"chatzumjs\",],\n        \"2yourface\": [\"ChatDialog\",\"ChatDlgInside\",],\n        bflix: [\"superfishStart\",],\n        clickpotato: [\"player_iframe\",\"liframe\",],\n        zuperface: [\"topluoneri\",],\n        menutab: [\"injectScript\",],\n        lilyjade: [\"lx_inz\",]\n    }, {\n        pagerage: [\"leftCol\",]\n    }, {\n    }, {\n        youtube_ext: [\"chrome-extension://pkhidkonipdjidjglnkfcfhnkfnlefbk/manifest.json\",],\n        bflix: [\"chrome-extension://kjafndplmofcedgddaoceenkcbfankem/manifest.json\",],\n        facetheme: [\"chrome-extension://kincjchfokkeneeofpeefomkikfkiedl/manifest.json\",],\n        token_stealers: [\"chrome-extension://iejbljbhhoclgfiapmomcpkpkcmihfib/manifest.json\",],\n        turkish_malware: [\"chrome-extension://lkfhadffdnjnogmgjfihlcmmjhcfchaj/manifest.json\",\"chrome-extension://afnnkheojlgkipfabekmdkngocfhegck/manifest.json\",],\n        adobeflash: [\"chrome-extension://hkpibllecmidllaojdmkcmfnoinmejco/manifest.json\",],\n        socialcolorful: [\"chrome-extension://gpllafflnmgjjcakjloknldkndnkmcpi/manifest.json\",]\n    });\n});\nJSBNG__onloadRegister_DEPRECATED(function() {\n    requireLazy([\"MercuryJewel\",], function(MercuryJewel) {\n        new MercuryJewel($(\"fbMessagesFlyout\"), $(\"fbMessagesJewel\"), require(\"m205506_2\"), {\n            message_counts: [{\n                unread_count: 0,\n                unseen_count: 0,\n                seen_timestamp: 0,\n                last_action_id: 0,\n                folder: \"inbox\"\n            },],\n            payload_source: \"server_initial_data\"\n        });\n    });\n});\nJSBNG__onloadRegister_DEPRECATED(function() {\n    require(\"m205506_4\").getData().JSBNG__onLoad(false, true);\n});\nJSBNG__onloadRegister_DEPRECATED(function() {\n    window.presenceRequests = JSCC.get(\"j1JDVIO9pN6SY5oVDJ0\").init(require(\"m205507_9\"), \"[fb]requests\", false);\n});\nJSBNG__onloadRegister_DEPRECATED(function() {\n    window.presenceNotifications = new OriginalNotifications({\n        updateTime: 1344872055000,\n        latestNotif: null,\n        latestReadNotif: null,\n        updatePeriod: 480000,\n        cacheVersion: 2,\n        allowDesktopNotifications: false,\n        notifReceivedType: \"notification\",\n        wrapperID: \"fbNotificationsJewel\",\n        contentID: \"fbNotificationsList\",\n        shouldLogImpressions: 0,\n        useInfiniteScroll: 1,\n        unaggregatedBeeper: false,\n        persistUnreadColor: true,\n        unseenVsUnread: 0,\n        receiveSoundPath: null\n    });\n});\nJSBNG__onloadRegister_DEPRECATED(function() {\n    Arbiter.inform(\"jewel/count-initial\", {\n        jewel: \"notifications\",\n        count: 0\n    }, Arbiter.BEHAVIOR_STATE);\n});\nJSBNG__onafterloadRegister_DEPRECATED(function() {\n    Bootloader.loadComponents([\"detect-broken-proxy-cache\",], function() {\n        detect_broken_proxy_cache(\"100001812504199\", \"c_user\");\n    });\n});\nJSBNG__onafterloadRegister_DEPRECATED(function() {\n    Bootloader.loadComponents([\"link-rel-preload\",], function() {\n        link_rel_preload();\n    });\n});\nJSBNG__onafterloadRegister_DEPRECATED(function() {\n    Bootloader.loadComponents([\"autoset-timezone\",], function() {\n        tz_autoset(1344872055, -240);\n    });\n});\nJSBNG__onafterloadRegister_DEPRECATED(function() {\n    Bootloader.loadComponents([\"legacy:live-timer\",], function() {\n        LiveTimer.restart(1344872055);\n    });\n});");
// 1035
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"var bigPipe = new (require(\"BigPipe\"))({\n    lid: 0,\n    forceFinish: true\n});");
// 1036
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"se151abf45cd37f530e5c8a27b753d912bd1be56a");
// 1037
geval("var bigPipe = new (require(\"BigPipe\"))({\n    lid: 0,\n    forceFinish: true\n});");
// 1042
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"bigPipe.onPageletArrive({\n    phase: 0,\n    id: \"first_response\",\n    is_last: true,\n    css: [\"zO4BE\",],\n    js: [\"8gPM0\",\"bS0QP\",\"JOZ9R\",\"1zqwA\",\"6n1TR\",\"28ZbA\",\"C6rJk\",\"u8TjK\",\"oGZW7\",]\n});");
// 1043
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"sb712a2e8fafff274bb15c6d579394bf0ad305a13");
// 1044
geval("bigPipe.JSBNG__onPageletArrive({\n    phase: 0,\n    id: \"first_response\",\n    is_last: true,\n    css: [\"zO4BE\",],\n    js: [\"8gPM0\",\"bS0QP\",\"JOZ9R\",\"1zqwA\",\"6n1TR\",\"28ZbA\",\"C6rJk\",\"u8TjK\",\"oGZW7\",]\n});");
// 1070
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"bigPipe.onPageletArrive({\n    phase: 1,\n    id: \"pagelet_welcome_box\",\n    css: [\"zO4BE\",],\n    js: [\"8gPM0\",\"bS0QP\",],\n    content: {\n        pagelet_welcome_box: {\n            container_id: \"uq3j16_4\"\n        }\n    }\n});");
// 1071
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"sa6985ec100ec0692a0ad7521d308eb5a14a24be2");
// 1072
geval("bigPipe.JSBNG__onPageletArrive({\n    phase: 1,\n    id: \"pagelet_welcome_box\",\n    css: [\"zO4BE\",],\n    js: [\"8gPM0\",\"bS0QP\",],\n    JSBNG__content: {\n        pagelet_welcome_box: {\n            container_id: \"uq3j16_4\"\n        }\n    }\n});");
// 1117
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"bigPipe.onPageletArrive({\n    phase: 1,\n    id: \"pagelet_navigation\",\n    css: [\"zO4BE\",],\n    bootloadable: {\n        \"legacy:UIPagelet\": {\n            resources: [\"8gPM0\",\"bS0QP\",]\n        },\n        \"legacy:uri\": {\n            resources: [\"8gPM0\",]\n        },\n        \"legacy:explicit-hover\": {\n            resources: [\"8gPM0\",\"aOO05\",\"rk7KQ\",]\n        },\n        \"sortable-side-nav-js\": {\n            resources: [\"bS0QP\",\"ggO+M\",\"8gPM0\",\"8npYi\",\"VqeSf\",\"XCIh8\",]\n        }\n    },\n    resource_map: {\n        aOO05: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yC/r/OoEdEM63foT.js\"\n        },\n        rk7KQ: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yF/r/y1sd3C7N-hO.js\"\n        },\n        \"ggO+M\": {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y8/r/aQ-TAvBkHZV.js\"\n        },\n        \"8npYi\": {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yi/r/4GXIN7nCWb3.js\"\n        },\n        VqeSf: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yH/r/A12mW7S5bty.js\"\n        },\n        XCIh8: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yo/r/CFPJZblERx9.js\"\n        }\n    },\n    js: [\"JOZ9R\",\"bS0QP\",\"8gPM0\",\"1zqwA\",\"28ZbA\",],\n    provides: [\"pagelet_controller::home_side_future_nav\",],\n    jscc_map: \"({\\\"j2DpNObe7W4zV22pf30\\\":function(){return new FutureHomeSideNav();}})\",\n    onload: [\"JSCC.get(\\\"j2DpNObe7W4zV22pf30\\\").init($(\\\"sideNav\\\"), \\\"nf\\\", false);\",],\n    content: {\n        pagelet_navigation: {\n            container_id: \"uq3j16_5\"\n        }\n    }\n});");
// 1118
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s6d3ee588a10340a45dcca6a44e12bc3d27150102");
// 1119
geval("bigPipe.JSBNG__onPageletArrive({\n    phase: 1,\n    id: \"pagelet_navigation\",\n    css: [\"zO4BE\",],\n    bootloadable: {\n        \"legacy:UIPagelet\": {\n            resources: [\"8gPM0\",\"bS0QP\",]\n        },\n        \"legacy:uri\": {\n            resources: [\"8gPM0\",]\n        },\n        \"legacy:explicit-hover\": {\n            resources: [\"8gPM0\",\"aOO05\",\"rk7KQ\",]\n        },\n        \"sortable-side-nav-js\": {\n            resources: [\"bS0QP\",\"ggO+M\",\"8gPM0\",\"8npYi\",\"VqeSf\",\"XCIh8\",]\n        }\n    },\n    resource_map: {\n        aOO05: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yC/r/OoEdEM63foT.js\"\n        },\n        rk7KQ: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yF/r/y1sd3C7N-hO.js\"\n        },\n        \"ggO+M\": {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y8/r/aQ-TAvBkHZV.js\"\n        },\n        \"8npYi\": {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yi/r/4GXIN7nCWb3.js\"\n        },\n        VqeSf: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yH/r/A12mW7S5bty.js\"\n        },\n        XCIh8: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yo/r/CFPJZblERx9.js\"\n        }\n    },\n    js: [\"JOZ9R\",\"bS0QP\",\"8gPM0\",\"1zqwA\",\"28ZbA\",],\n    provides: [\"pagelet_controller::home_side_future_nav\",],\n    jscc_map: \"({\\\"j2DpNObe7W4zV22pf30\\\":function(){return new FutureHomeSideNav();}})\",\n    JSBNG__onload: [\"JSCC.get(\\\"j2DpNObe7W4zV22pf30\\\").init($(\\\"sideNav\\\"), \\\"nf\\\", false);\",],\n    JSBNG__content: {\n        pagelet_navigation: {\n            container_id: \"uq3j16_5\"\n        }\n    }\n});");
// 1167
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"bigPipe.onPageletArrive({\n    phase: 1,\n    id: \"pagelet_composer\",\n    jsmods: {\n        instances: [[\"m205511_17\",[\"MentionsInput\",\"m205511_20\",\"m205511_22\",\"m205511_21\",\"m205511_23\",],[{\n            __m: \"m205511_20\"\n        },{\n            __m: \"m205511_22\"\n        },{\n            __m: \"m205511_21\"\n        },{\n            max: 10\n        },null,{\n            __m: \"m205511_23\"\n        },],3,],[\"m205511_22\",[\"Typeahead\",\"m205511_16\",\"ContextualTypeaheadView\",\"CompactTypeaheadRenderer\",\"m205511_21\",\"TypeaheadAreaCore\",\"m205511_24\",],[{\n            __m: \"m205511_16\"\n        },{\n            node_id: \"\",\n            ctor: {\n                __m: \"ContextualTypeaheadView\"\n            },\n            options: {\n                autoSelect: true,\n                renderer: {\n                    __m: \"CompactTypeaheadRenderer\"\n                },\n                causalElement: {\n                    __m: \"m205511_21\"\n                },\n                maxResults: 10,\n                scrollarea: true\n            }\n        },{\n            ctor: {\n                __m: \"TypeaheadAreaCore\"\n            },\n            options: []\n        },{\n            __m: \"m205511_24\"\n        },],5,],[\"m205511_16\",[\"DataSource\",],[{\n            maxResults: 10,\n            queryData: {\n                viewer: 100001812504199,\n                filter: [\"page\",\"app\",],\n                context: \"topics\",\n                rsp: \"mentions\"\n            },\n            queryEndpoint: \"/ajax/typeahead/search.php\",\n            bootstrapData: {\n                viewer: 100001812504199,\n                filter: [\"user\",\"page\",\"app\",\"group\",\"event\",],\n                options: [\"friends_only\",\"nm\",],\n                token: \"v7\",\n                context: \"mentions\",\n                rsp: \"mentions\"\n            },\n            bootstrapEndpoint: \"/ajax/typeahead/first_degree.php\",\n            token: \"1343822055-7\"\n        },],3,],[\"m205511_23\",[\"TypeaheadMetrics\",],[{\n            extraData: {\n                event_name: \"mentions\"\n            }\n        },],4,],],\n        elements: [[\"m205511_20\",\"uq3j16_10\",2,],[\"m205511_24\",\"uq3j16_11\",2,],[\"m205511_21\",\"uq3j16_12\",6,],[\"m205511_18\",\"uq3j16_14\",2,],[\"m205511_19\",\"uq3j16_15\",2,],],\n        require: [[\"m205511_17\",],[\"m205511_22\",],[\"Typeahead\",\"init\",[\"m205511_21\",\"m205511_22\",\"m205511_23\",],[{\n            __m: \"m205511_21\"\n        },{\n            __m: \"m205511_22\"\n        },[\"buildBestAvailableNames\",\"hoistFriends\",\"scrollArea\",],{\n            __m: \"m205511_23\"\n        },],],]\n    },\n    css: [\"zO4BE\",],\n    bootloadable: {\n        \"legacy:Composer\": {\n            resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",]\n        },\n        \"legacy:DataSource\": {\n            resources: [\"8gPM0\",\"bS0QP\",\"oSG4H\",]\n        },\n        \"legacy:dom\": {\n            resources: [\"8gPM0\",]\n        },\n        \"legacy:control-textarea\": {\n            resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",\"VqeSf\",]\n        }\n    },\n    resource_map: {\n        oSG4H: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y9/r/SuY8EAGJvgN.js\"\n        }\n    },\n    js: [\"8gPM0\",\"bS0QP\",],\n    jscc_map: \"({\\\"j3nzBkZS6GmXveoreu0\\\":function(){return new Composer($(\\\"uq3j16_6\\\"), {\\\"xhpc\\\":\\\"composerTourStart\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/updatestatus.php\\\",\\\"formType\\\":1,\\\"placeholder\\\":\\\"What's on your mind?\\\",\\\"buttonLabel\\\":\\\"Post\\\",\\\"autoscrape\\\":true,\\\"metaContent\\\":\\\"\\\\u003Cdiv\\u003E\\\\u003C\\\\/div\\u003E\\\",\\\"disableCache\\\":true,\\\"lazyEndpoint\\\":\\\"\\\\/ajax\\\\/metacomposer\\\\/attachment\\\\/status\\\\/status.php\\\"}, true, require(\\\"m205511_16\\\"), true);},\\\"j3nzBkZS6GmXveoreu1\\\":function(){return new MetaComposerMessageBox();}})\",\n    onload: [\"envFlush({ allowCrossOriginComposerUpload: false });\",\"JSCC.get(\\\"j3nzBkZS6GmXveoreu0\\\").init(require(\\\"m205511_17\\\"));\",\"JSCC.get(\\\"j3nzBkZS6GmXveoreu1\\\").init($(\\\"uq3j16_9\\\"), require(\\\"m205511_17\\\"));\",],\n    content: {\n        pagelet_composer: {\n            container_id: \"uq3j16_16\"\n        }\n    }\n});");
// 1168
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"sa63563732a39b4354632e709deff60de5a1061cf");
// 1169
geval("bigPipe.JSBNG__onPageletArrive({\n    phase: 1,\n    id: \"pagelet_composer\",\n    jsmods: {\n        instances: [[\"m205511_17\",[\"MentionsInput\",\"m205511_20\",\"m205511_22\",\"m205511_21\",\"m205511_23\",],[{\n            __m: \"m205511_20\"\n        },{\n            __m: \"m205511_22\"\n        },{\n            __m: \"m205511_21\"\n        },{\n            max: 10\n        },null,{\n            __m: \"m205511_23\"\n        },],3,],[\"m205511_22\",[\"Typeahead\",\"m205511_16\",\"ContextualTypeaheadView\",\"CompactTypeaheadRenderer\",\"m205511_21\",\"TypeaheadAreaCore\",\"m205511_24\",],[{\n            __m: \"m205511_16\"\n        },{\n            node_id: \"\",\n            ctor: {\n                __m: \"ContextualTypeaheadView\"\n            },\n            options: {\n                autoSelect: true,\n                renderer: {\n                    __m: \"CompactTypeaheadRenderer\"\n                },\n                causalElement: {\n                    __m: \"m205511_21\"\n                },\n                maxResults: 10,\n                scrollarea: true\n            }\n        },{\n            ctor: {\n                __m: \"TypeaheadAreaCore\"\n            },\n            options: []\n        },{\n            __m: \"m205511_24\"\n        },],5,],[\"m205511_16\",[\"DataSource\",],[{\n            maxResults: 10,\n            queryData: {\n                viewer: 100001812504199,\n                filter: [\"page\",\"app\",],\n                context: \"topics\",\n                rsp: \"mentions\"\n            },\n            queryEndpoint: \"/ajax/typeahead/search.php\",\n            bootstrapData: {\n                viewer: 100001812504199,\n                filter: [\"user\",\"page\",\"app\",\"group\",\"JSBNG__event\",],\n                options: [\"friends_only\",\"nm\",],\n                token: \"v7\",\n                context: \"mentions\",\n                rsp: \"mentions\"\n            },\n            bootstrapEndpoint: \"/ajax/typeahead/first_degree.php\",\n            token: \"1343822055-7\"\n        },],3,],[\"m205511_23\",[\"TypeaheadMetrics\",],[{\n            extraData: {\n                event_name: \"mentions\"\n            }\n        },],4,],],\n        elements: [[\"m205511_20\",\"uq3j16_10\",2,],[\"m205511_24\",\"uq3j16_11\",2,],[\"m205511_21\",\"uq3j16_12\",6,],[\"m205511_18\",\"uq3j16_14\",2,],[\"m205511_19\",\"uq3j16_15\",2,],],\n        require: [[\"m205511_17\",],[\"m205511_22\",],[\"Typeahead\",\"init\",[\"m205511_21\",\"m205511_22\",\"m205511_23\",],[{\n            __m: \"m205511_21\"\n        },{\n            __m: \"m205511_22\"\n        },[\"buildBestAvailableNames\",\"hoistFriends\",\"scrollArea\",],{\n            __m: \"m205511_23\"\n        },],],]\n    },\n    css: [\"zO4BE\",],\n    bootloadable: {\n        \"legacy:Composer\": {\n            resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",]\n        },\n        \"legacy:DataSource\": {\n            resources: [\"8gPM0\",\"bS0QP\",\"oSG4H\",]\n        },\n        \"legacy:dom\": {\n            resources: [\"8gPM0\",]\n        },\n        \"legacy:control-textarea\": {\n            resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",\"VqeSf\",]\n        }\n    },\n    resource_map: {\n        oSG4H: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y9/r/SuY8EAGJvgN.js\"\n        }\n    },\n    js: [\"8gPM0\",\"bS0QP\",],\n    jscc_map: \"({\\\"j3nzBkZS6GmXveoreu0\\\":function(){return new Composer($(\\\"uq3j16_6\\\"), {\\\"xhpc\\\":\\\"composerTourStart\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/updatestatus.php\\\",\\\"formType\\\":1,\\\"placeholder\\\":\\\"What's on your mind?\\\",\\\"buttonLabel\\\":\\\"Post\\\",\\\"autoscrape\\\":true,\\\"metaContent\\\":\\\"\\\\u003Cdiv\\u003E\\\\u003C\\\\/div\\u003E\\\",\\\"disableCache\\\":true,\\\"lazyEndpoint\\\":\\\"\\\\/ajax\\\\/metacomposer\\\\/attachment\\\\/status\\\\/status.php\\\"}, true, require(\\\"m205511_16\\\"), true);},\\\"j3nzBkZS6GmXveoreu1\\\":function(){return new MetaComposerMessageBox();}})\",\n    JSBNG__onload: [\"envFlush({ allowCrossOriginComposerUpload: false });\",\"JSCC.get(\\\"j3nzBkZS6GmXveoreu0\\\").init(require(\\\"m205511_17\\\"));\",\"JSCC.get(\\\"j3nzBkZS6GmXveoreu1\\\").init($(\\\"uq3j16_9\\\"), require(\\\"m205511_17\\\"));\",],\n    JSBNG__content: {\n        pagelet_composer: {\n            container_id: \"uq3j16_16\"\n        }\n    }\n});");
// 1218
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"bigPipe.onPageletArrive({\n    phase: 1,\n    id: \"pagelet_home_stream\",\n    jsmods: {\n        instances: [[\"m205512_1\",[\"MenuX\",\"MenuXSelectableItem\",\"m205512_2\",\"m205512_3\",],[\"uq3j2t_1\",null,[{\n            href: \"/?sk=h_nor\",\n            selected: true,\n            ctor: {\n                __m: \"MenuXSelectableItem\"\n            },\n            markup: {\n                __m: \"m205512_2\"\n            },\n            label: \"Top Stories\",\n            title: \"\",\n            className: null\n        },{\n            href: \"/?sk=h_chr\",\n            selected: false,\n            ctor: {\n                __m: \"MenuXSelectableItem\"\n            },\n            markup: {\n                __m: \"m205512_3\"\n            },\n            label: \"Most Recent\",\n            title: \"\",\n            className: null\n        },],{\n            maxheight: null\n        },],3,],[\"m205512_5\",[\"PopoverMenu\",\"m205512_6\",\"m205512_4\",\"m205512_1\",],[{\n            __m: \"m205512_6\"\n        },{\n            __m: \"m205512_4\"\n        },{\n            __m: \"m205512_1\"\n        },[],],1,],[\"m205512_6\",[\"Popover\",\"m205512_7\",\"m205512_4\",],[{\n            __m: \"m205512_7\"\n        },{\n            __m: \"m205512_4\"\n        },[],{\n            alignh: \"right\",\n            layer_content: null\n        },],3,],],\n        markup: [[\"m205512_2\",{\n            __html: \"Top Stories\"\n        },2,],[\"m205512_3\",{\n            __html: \"Most Recent\"\n        },2,],],\n        elements: [[\"m205512_7\",\"uq3j2t_2\",2,],[\"m205512_4\",\"uq3j2t_3\",4,],],\n        require: [[\"FeedTrackingAsync\",\"init\",[],[\"home_stream\",],],[\"StreamViewportTracking\",\"init\",[],[{\n            record_tn_tree: 0,\n            record_delay: 300\n        },],],[\"m205512_1\",],[\"m205512_5\",],[\"m205512_6\",],]\n    },\n    css: [\"zO4BE\",],\n    resource_map: {\n        Vitu9: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yn/r/LQPFEhGsqZz.js\"\n        }\n    },\n    js: [\"8gPM0\",\"bS0QP\",\"JOZ9R\",\"Vitu9\",\"28ZbA\",],\n    provides: [\"pagelet_controller::home_intentional_stream\",],\n    onload: [\"window.__UIControllerRegistry[\\\"c50291e771e77b1369087562\\\"] = new UIIntentionalStream($(\\\"c50291e771e77b1369087562\\\"), \\\"nile\\\", 0, 0, \\\"h_nor\\\", 10, 0, [], 0, \\\"h_nor\\\", 1344871186);; window.__UIControllerRegistry[\\\"home_intentional_stream\\\"]=window.__UIControllerRegistry[\\\"c50291e771e77b1369087562\\\"];;\",\"UIIntentionalStream.instance.setScrollLoadCount(100);\",],\n    onafterload: [\"UIIntentionalStream.instance.loadMoreOnScroll(4, 12);\",],\n    content: {\n        pagelet_home_stream: {\n            container_id: \"uq3j16_17\"\n        }\n    }\n});");
// 1219
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"sb3af92762ee2d2f1a80d7a5c5768e892b55c7f1b");
// 1220
geval("bigPipe.JSBNG__onPageletArrive({\n    phase: 1,\n    id: \"pagelet_home_stream\",\n    jsmods: {\n        instances: [[\"m205512_1\",[\"MenuX\",\"MenuXSelectableItem\",\"m205512_2\",\"m205512_3\",],[\"uq3j2t_1\",null,[{\n            href: \"/?sk=h_nor\",\n            selected: true,\n            ctor: {\n                __m: \"MenuXSelectableItem\"\n            },\n            markup: {\n                __m: \"m205512_2\"\n            },\n            label: \"Top Stories\",\n            title: \"\",\n            className: null\n        },{\n            href: \"/?sk=h_chr\",\n            selected: false,\n            ctor: {\n                __m: \"MenuXSelectableItem\"\n            },\n            markup: {\n                __m: \"m205512_3\"\n            },\n            label: \"Most Recent\",\n            title: \"\",\n            className: null\n        },],{\n            maxheight: null\n        },],3,],[\"m205512_5\",[\"PopoverMenu\",\"m205512_6\",\"m205512_4\",\"m205512_1\",],[{\n            __m: \"m205512_6\"\n        },{\n            __m: \"m205512_4\"\n        },{\n            __m: \"m205512_1\"\n        },[],],1,],[\"m205512_6\",[\"Popover\",\"m205512_7\",\"m205512_4\",],[{\n            __m: \"m205512_7\"\n        },{\n            __m: \"m205512_4\"\n        },[],{\n            alignh: \"right\",\n            layer_content: null\n        },],3,],],\n        markup: [[\"m205512_2\",{\n            __html: \"Top Stories\"\n        },2,],[\"m205512_3\",{\n            __html: \"Most Recent\"\n        },2,],],\n        elements: [[\"m205512_7\",\"uq3j2t_2\",2,],[\"m205512_4\",\"uq3j2t_3\",4,],],\n        require: [[\"FeedTrackingAsync\",\"init\",[],[\"home_stream\",],],[\"StreamViewportTracking\",\"init\",[],[{\n            record_tn_tree: 0,\n            record_delay: 300\n        },],],[\"m205512_1\",],[\"m205512_5\",],[\"m205512_6\",],]\n    },\n    css: [\"zO4BE\",],\n    resource_map: {\n        Vitu9: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yn/r/LQPFEhGsqZz.js\"\n        }\n    },\n    js: [\"8gPM0\",\"bS0QP\",\"JOZ9R\",\"Vitu9\",\"28ZbA\",],\n    provides: [\"pagelet_controller::home_intentional_stream\",],\n    JSBNG__onload: [\"window.__UIControllerRegistry[\\\"c50291e771e77b1369087562\\\"] = new UIIntentionalStream($(\\\"c50291e771e77b1369087562\\\"), \\\"nile\\\", 0, 0, \\\"h_nor\\\", 10, 0, [], 0, \\\"h_nor\\\", 1344871186);; window.__UIControllerRegistry[\\\"home_intentional_stream\\\"]=window.__UIControllerRegistry[\\\"c50291e771e77b1369087562\\\"];;\",\"UIIntentionalStream.instance.setScrollLoadCount(100);\",],\n    JSBNG__onafterload: [\"UIIntentionalStream.instance.loadMoreOnScroll(4, 12);\",],\n    JSBNG__content: {\n        pagelet_home_stream: {\n            container_id: \"uq3j16_17\"\n        }\n    }\n});");
// 1269
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"bigPipe.onPageletArrive({\n    phase: 1,\n    id: \"pagelet_pinned_nav_lite\",\n    append: \"pagelet_pinned_nav\",\n    display_dependency: [\"pagelet_navigation\",],\n    css: [\"zO4BE\",],\n    content: {\n        pagelet_pinned_nav_lite: {\n            container_id: \"uq3j16_18\"\n        }\n    }\n});");
// 1270
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"sa12652e88c1652c238ea9500391711aa701c546f");
// 1271
geval("bigPipe.JSBNG__onPageletArrive({\n    phase: 1,\n    id: \"pagelet_pinned_nav_lite\",\n    append: \"pagelet_pinned_nav\",\n    display_dependency: [\"pagelet_navigation\",],\n    css: [\"zO4BE\",],\n    JSBNG__content: {\n        pagelet_pinned_nav_lite: {\n            container_id: \"uq3j16_18\"\n        }\n    }\n});");
// 1330
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"bigPipe.onPageletArrive({\n    phase: 1,\n    id: \"pagelet_sub_stream_0\",\n    append: \"home_stream\",\n    display_dependency: [\"pagelet_home_stream\",],\n    is_last: true,\n    jsmods: {\n        instances: [[\"m205528_8\",[\"PopoverAsyncMenuLoading\",],[\"HighlightSelectorMenu\",],3,],[\"m205528_10\",[\"PopoverAsyncMenu\",\"m205528_11\",\"m205528_9\",\"m205528_8\",\"PopoverMenuOverlappingBorder\",],[{\n            __m: \"m205528_11\"\n        },{\n            __m: \"m205528_9\"\n        },{\n            __m: \"m205528_8\"\n        },\"/ajax/feed/feed_menu.php?action=hide&story_div_id=stream_story_50291e77418e06768205346&filter_key=h_nor&story_fbids\u00255B0\u00255D=1055580469\u00253A3688953136508&report_link=\u00252Fajax\u00252Freport.php\u00253Fcontent_type\u00253D2\u002526cid\u00253D3688952976504\u002526rid\u00253D1055580469\u002526h\u00253DAfi7UrqWOO7GhNRu&story_type=247&source_id=1055580469&qid=5776181494237290802&mf_story_key=-4571705487949635972&actor_id=1055580469&num_participants=1&is_highlight=0&viewstate_id=-4571705487949635972&feedback_target_id=3688952976504&tl_story_tokens\u00255B0\u00255D=1055580469\u00253A3688953136508\u00253A0\u00253A1344557647\u00253A1344557647&tl_story_tokens\u00255B1\u00255D=1055580469\u00253A3688953136508\u00253A0\u00253A1344557647\u00253A1344557647&tl_story_tokens\u00255B2\u00255D=1055580469\u00253A3690970746947\u00253A4\u00253A1344653978\u00253A1344616272&tl_story_tokens\u00255B3\u00255D=1055580469\u00253A3690970746947\u00253A4\u00253A1344653978\u00253A1344616272&tl_story_tokens\u00255B4\u00255D=1055580469\u00253A3686112385491\u00253A5\u00253A1344562882\u00253A1344482881&tl_story_tokens\u00255B5\u00255D=1055580469\u00253A3686112385491\u00253A5\u00253A1344562882\u00253A1344482881\",[{\n            __m: \"PopoverMenuOverlappingBorder\"\n        },],],1,],[\"m205528_11\",[\"Popover\",\"m205528_12\",\"m205528_9\",\"ContextualLayerAsyncRelative\",],[{\n            __m: \"m205528_12\"\n        },{\n            __m: \"m205528_9\"\n        },[{\n            __m: \"ContextualLayerAsyncRelative\"\n        },],{\n            alignh: \"right\",\n            layer_content: null\n        },],3,],[\"m205528_13\",[\"PopoverAsyncMenuLoading\",],[\"HighlightSelectorMenu\",],3,],[\"m205528_15\",[\"PopoverAsyncMenu\",\"m205528_16\",\"m205528_14\",\"m205528_13\",\"PopoverMenuOverlappingBorder\",],[{\n            __m: \"m205528_16\"\n        },{\n            __m: \"m205528_14\"\n        },{\n            __m: \"m205528_13\"\n        },\"/ajax/feed/feed_menu.php?action=hide&story_div_id=stream_story_50291e77421b58760782402&filter_key=h_nor&story_fbids\u00255B0\u00255D=1055580469\u00253A427041767338328&story_fbids\u00255B1\u00255D=1055580469\u00253A427041767338328&report_link=\u00252Fajax\u00252Freport.php\u00253Fcontent_type\u00253D5\u002526cid\u00253D427041767338328\u002526rid\u00253D1055580469\u002526profile\u00253D1055580469\u002526h\u00253DAfj19nxzGUJWqR0l&story_type=263&source_id=1055580469&qid=5776181494237290802&mf_story_key=8438955046610351598&actor_id=1055580469&num_participants=1&is_highlight=0&viewstate_id=8438955046610351598&feedback_target_id=427041767338328&tl_story_tokens\u00255B0\u00255D=1055580469\u00253A427041767338328\u00253A\u00253A1344632723\u00253A1344632723&tl_story_tokens\u00255B1\u00255D=1055580469\u00253A427041767338328\u00253A\u00253A1344632723\u00253A1344632723\",[{\n            __m: \"PopoverMenuOverlappingBorder\"\n        },],],1,],[\"m205528_16\",[\"Popover\",\"m205528_17\",\"m205528_14\",\"ContextualLayerAsyncRelative\",],[{\n            __m: \"m205528_17\"\n        },{\n            __m: \"m205528_14\"\n        },[{\n            __m: \"ContextualLayerAsyncRelative\"\n        },],{\n            alignh: \"right\",\n            layer_content: null\n        },],3,],[\"m205528_18\",[\"PopoverAsyncMenuLoading\",],[\"HighlightSelectorMenu\",],3,],[\"m205528_20\",[\"PopoverAsyncMenu\",\"m205528_21\",\"m205528_19\",\"m205528_18\",\"PopoverMenuOverlappingBorder\",],[{\n            __m: \"m205528_21\"\n        },{\n            __m: \"m205528_19\"\n        },{\n            __m: \"m205528_18\"\n        },\"/ajax/feed/feed_menu.php?action=hide&story_div_id=stream_story_50291e77423ed9900470894&filter_key=h_nor&spam_object_id=424129870965893&report_link=0&story_type=257&source_id=0&qid=5776181494237290802&mf_story_key=6023853588764622143&actor_id=1055580469&num_participants=1&is_highlight=0&viewstate_id=6023853588764622143\",[{\n            __m: \"PopoverMenuOverlappingBorder\"\n        },],],1,],[\"m205528_21\",[\"Popover\",\"m205528_22\",\"m205528_19\",\"ContextualLayerAsyncRelative\",],[{\n            __m: \"m205528_22\"\n        },{\n            __m: \"m205528_19\"\n        },[{\n            __m: \"ContextualLayerAsyncRelative\"\n        },],{\n            alignh: \"right\",\n            layer_content: null\n        },],3,],[\"m205531_39\",[\"MentionsInput\",\"m205531_37\",\"m205531_40\",\"m205531_38\",\"m205531_41\",],[{\n            __m: \"m205531_37\"\n        },{\n            __m: \"m205531_40\"\n        },{\n            __m: \"m205531_38\"\n        },{\n            max: 10\n        },null,{\n            __m: \"m205531_41\"\n        },],1,],[\"m205531_40\",[\"Typeahead\",\"m205531_43\",\"ContextualTypeaheadView\",\"CompactTypeaheadRenderer\",\"m205531_38\",\"TypeaheadAreaCore\",\"m205531_42\",],[{\n            __m: \"m205531_43\"\n        },{\n            node_id: \"\",\n            ctor: {\n                __m: \"ContextualTypeaheadView\"\n            },\n            options: {\n                autoSelect: true,\n                renderer: {\n                    __m: \"CompactTypeaheadRenderer\"\n                },\n                causalElement: {\n                    __m: \"m205531_38\"\n                },\n                maxResults: 3,\n                scrollarea: true\n            }\n        },{\n            ctor: {\n                __m: \"TypeaheadAreaCore\"\n            },\n            options: []\n        },{\n            __m: \"m205531_42\"\n        },],5,],[\"m205531_46\",[\"MentionsInput\",\"m205531_44\",\"m205531_47\",\"m205531_45\",\"m205531_48\",],[{\n            __m: \"m205531_44\"\n        },{\n            __m: \"m205531_47\"\n        },{\n            __m: \"m205531_45\"\n        },{\n            max: 10\n        },null,{\n            __m: \"m205531_48\"\n        },],1,],[\"m205531_47\",[\"Typeahead\",\"m205531_50\",\"ContextualTypeaheadView\",\"CompactTypeaheadRenderer\",\"m205531_45\",\"TypeaheadAreaCore\",\"m205531_49\",],[{\n            __m: \"m205531_50\"\n        },{\n            node_id: \"\",\n            ctor: {\n                __m: \"ContextualTypeaheadView\"\n            },\n            options: {\n                autoSelect: true,\n                renderer: {\n                    __m: \"CompactTypeaheadRenderer\"\n                },\n                causalElement: {\n                    __m: \"m205531_45\"\n                },\n                maxResults: 3,\n                scrollarea: true\n            }\n        },{\n            ctor: {\n                __m: \"TypeaheadAreaCore\"\n            },\n            options: []\n        },{\n            __m: \"m205531_49\"\n        },],5,],[\"m205531_53\",[\"MentionsInput\",\"m205531_51\",\"m205531_54\",\"m205531_52\",\"m205531_55\",],[{\n            __m: \"m205531_51\"\n        },{\n            __m: \"m205531_54\"\n        },{\n            __m: \"m205531_52\"\n        },{\n            max: 10\n        },null,{\n            __m: \"m205531_55\"\n        },],1,],[\"m205531_54\",[\"Typeahead\",\"m205531_57\",\"ContextualTypeaheadView\",\"CompactTypeaheadRenderer\",\"m205531_52\",\"TypeaheadAreaCore\",\"m205531_56\",],[{\n            __m: \"m205531_57\"\n        },{\n            node_id: \"\",\n            ctor: {\n                __m: \"ContextualTypeaheadView\"\n            },\n            options: {\n                autoSelect: true,\n                renderer: {\n                    __m: \"CompactTypeaheadRenderer\"\n                },\n                causalElement: {\n                    __m: \"m205531_52\"\n                },\n                maxResults: 3,\n                scrollarea: true\n            }\n        },{\n            ctor: {\n                __m: \"TypeaheadAreaCore\"\n            },\n            options: []\n        },{\n            __m: \"m205531_56\"\n        },],5,],[\"m205531_36\",[\"XHPTemplate\",\"m205535_58\",],[{\n            __m: \"m205535_58\"\n        },],2,],[\"m205531_41\",[\"TypeaheadMetrics\",],[{\n            extraData: {\n                event_name: \"mentions\"\n            }\n        },],4,],[\"m205531_43\",[\"MultiBootstrapDataSource\",],[{\n            maxResults: 3,\n            queryData: {\n                context: \"topics\",\n                viewer: 100001812504199,\n                filter: [\"page\",],\n                rsp: \"mentions\"\n            },\n            queryEndpoint: \"/ajax/typeahead/search.php\",\n            bootstrapData: {\n                rsp: \"mentions\"\n            },\n            bootstrapEndpoints: [{\n                endpoint: \"/ajax/typeahead/first_degree.php\",\n                data: {\n                    context: \"mentions\",\n                    viewer: 100001812504199,\n                    token: \"1343822055-7\",\n                    filter: [\"page\",\"group\",\"app\",\"event\",\"user\",],\n                    options: [\"friends_only\",\"nm\",]\n                }\n            },]\n        },],2,],[\"m205531_48\",[\"TypeaheadMetrics\",],[{\n            extraData: {\n                event_name: \"mentions\"\n            }\n        },],4,],[\"m205531_50\",[\"MultiBootstrapDataSource\",],[{\n            maxResults: 3,\n            queryData: {\n                context: \"topics\",\n                viewer: 100001812504199,\n                filter: [\"page\",],\n                rsp: \"mentions\"\n            },\n            queryEndpoint: \"/ajax/typeahead/search.php\",\n            bootstrapData: {\n                rsp: \"mentions\"\n            },\n            bootstrapEndpoints: [{\n                endpoint: \"/ajax/typeahead/first_degree.php\",\n                data: {\n                    context: \"mentions\",\n                    viewer: 100001812504199,\n                    token: \"1343822055-7\",\n                    filter: [\"page\",\"group\",\"app\",\"event\",\"user\",],\n                    options: [\"friends_only\",\"nm\",]\n                }\n            },]\n        },],2,],[\"m205531_55\",[\"TypeaheadMetrics\",],[{\n            extraData: {\n                event_name: \"mentions\"\n            }\n        },],4,],[\"m205531_57\",[\"MultiBootstrapDataSource\",],[{\n            maxResults: 3,\n            queryData: {\n                context: \"topics\",\n                viewer: 100001812504199,\n                filter: [\"page\",],\n                rsp: \"mentions\"\n            },\n            queryEndpoint: \"/ajax/typeahead/search.php\",\n            bootstrapData: {\n                rsp: \"mentions\"\n            },\n            bootstrapEndpoints: [{\n                endpoint: \"/ajax/typeahead/first_degree.php\",\n                data: {\n                    context: \"mentions\",\n                    viewer: 100001812504199,\n                    token: \"1343822055-7\",\n                    filter: [\"page\",\"group\",\"app\",\"event\",\"user\",],\n                    options: [\"friends_only\",\"nm\",]\n                }\n            },]\n        },],2,],],\n        markup: [[\"m205530_28\",{\n            __html: \"Enter Fullscreen\"\n        },2,],[\"m205530_30\",{\n            __html: \"Press Esc to exit fullscreen\"\n        },2,],[\"m205530_32\",{\n            __html: \"Press Esc to close\"\n        },2,],[\"m205530_34\",{\n            __html: \"Press Esc to exit fullscreen\"\n        },2,],[\"m205530_26\",{\n            __html: \"\\u003Cdiv id=\\\"fbPhotoSnowlift\\\" class=\\\"fbPhotoSnowlift fbxPhoto hidden_elem fbPhotoSnowliftPivotHover\\\" tabindex=\\\"0\\\" role=\\\"region\\\" aria-label=\\\"Facebook Photo Theater\\\" aria-busy=\\\"true\\\"\\u003E\\u003Cdiv class=\\\"fbPhotoSnowliftOuter\\\"\\u003E\\u003Cdiv class=\\\"fbPhotoSnowliftInner\\\"\\u003E\\u003Cdiv class=\\\"fbPhotoSnowliftContainer uiContextualLayerParent\\\"\\u003E\\u003Cdiv class=\\\"clearfix fbPhotoSnowliftPopup\\\"\\u003E\\u003Cdiv class=\\\"stageWrapper lfloat\\\"\\u003E\\u003Cdiv class=\\\"fbPhotoSnowliftFullScreen fullScreenSwitch\\\" id=\\\"fullScreenSwitch\\\"\\u003E\\u003Ca data-hover=\\\"tooltip\\\" data-tooltip-position=\\\"below\\\" data-tooltip-alignh=\\\"right\\\" href=\\\"#\\\" id=\\\"fbPhotoSnowliftFullScreenSwitch\\\"\\u003E\\u003C/a\\u003E\\u003Ca data-hover=\\\"tooltip\\\" data-tooltip-position=\\\"below\\\" data-tooltip-alignh=\\\"right\\\" href=\\\"#\\\" id=\\\"fbPhotoSnowliftFullScreenClose\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"stage\\\"\\u003E\\u003Cimg class=\\\"spotlight spotlight\\\" src=\\\"/images/spacer.gif\\\" /\\u003E\\u003Cdiv class=\\\"fbPhotosPhotoTagboxes tagContainer\\\" id=\\\"fbPhotoSnowliftTagBoxes\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbPhotoTagApproval\\\" id=\\\"fbPhotoSnowliftTagApproval\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"videoStage\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"stageActions\\\" id=\\\"snowliftStageActions\\\"\\u003E\\u003Cdiv class=\\\"clearfix snowliftOverlay snowliftOverlayBar rightButtons\\\"\\u003E\\u003Cdiv class=\\\"overlayBarButtons rfloat\\\"\\u003E\\u003Cdiv class=\\\"-cx-PRIVATE-uiInlineBlock__root -cx-PRIVATE-uiInlineBlock__middle fbPhotosPhotoActions\\\" id=\\\"fbPhotoSnowliftActions\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbPhotosPhotoButtons\\\" id=\\\"fbPhotoSnowliftButtons\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"mediaTitleInfo\\\"\\u003E\\u003Cdiv class=\\\"mediaTitleBoxFlex\\\"\\u003E\\u003Cdiv id=\\\"fbPhotoSnowliftMediaTitle\\\"\\u003E\\u003C/div\\u003E\\u003Cspan class=\\\"mlm hidden_elem\\\" id=\\\"fbPhotoSnowliftPositionAndCount\\\"\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"mediaTitleInfoSpacer\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbPhotosPhotoTagboxBase newTagBox hidden_elem\\\" style=\\\"\\\"\\u003E\\u003Cdiv class=\\\"borderTagBox\\\"\\u003E\\u003Cdiv class=\\\"innerTagBox\\\"\\u003E\\u003Cdiv class=\\\"ieContentFix\\\"\\u003E\\u00a0\\u00a0\\u00a0\\u00a0\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"tag\\\"\\u003E\\u003Cdiv class=\\\"tagPointer\\\"\\u003E\\u003Ci class=\\\"tagArrow img sp_ae80w4 sx_55a200\\\"\\u003E\\u003C/i\\u003E\\u003Cdiv class=\\\"tagName\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Ca class=\\\"snowliftPager prev\\\" title=\\\"Previous\\\"\\u003E\\u003Ci\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003Ca class=\\\"snowliftPager next\\\" title=\\\"Next\\\"\\u003E\\u003Ci\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"photoError stageError\\\" id=\\\"fbPhotoSnowliftError\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"rhc photoUfiContainer\\\"\\u003E\\u003Cdiv class=\\\"rhcHeader\\\"\\u003E\\u003Cdiv class=\\\"fbPhotoSnowliftControls\\\"\\u003E\\u003Ca data-hover=\\\"tooltip\\\" data-tooltip-position=\\\"below\\\" data-tooltip-alignh=\\\"right\\\" class=\\\"closeTheater\\\" href=\\\"#\\\" id=\\\"uq3j2t_14\\\"\\u003E\\u003C/a\\u003E\\u003Ca data-hover=\\\"tooltip\\\" data-tooltip-position=\\\"below\\\" data-tooltip-alignh=\\\"right\\\" class=\\\"closeTheater fullscreenCommentClose\\\" href=\\\"#\\\" id=\\\"uq3j2t_15\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv id=\\\"fbPhotoSnowliftInlineEditor\\\" class=\\\"fbPhotoInlineEditor\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cform rel=\\\"async\\\" class=\\\"fbPhotosSnowliftFeedbackForm rhcBody commentable_item autoexpand_mode\\\" method=\\\"post\\\" action=\\\"/ajax/ufi/modify.php\\\" onsubmit=\\\"return Event.__inlineSubmit(this,event)\\\" id=\\\"uq3j2t_16\\\"\\u003E\\u003Cinput type=\\\"hidden\\\" name=\\\"charset_test\\\" value=\\\"&euro;,&acute;,\\u20ac,\\u00b4,\\u6c34,\\u0414,\\u0404\\\" /\\u003E\\u003Cinput type=\\\"hidden\\\" name=\\\"fb_dtsg\\\" value=\\\"AQCc21Em\\\" autocomplete=\\\"off\\\" /\\u003E\\u003Cdiv class=\\\"uiScrollableArea rhcScroller native\\\" style=\\\"width:285px;\\\"\\u003E\\u003Cdiv class=\\\"uiScrollableAreaWrap scrollable\\\" tabindex=\\\"0\\\"\\u003E\\u003Cdiv class=\\\"uiScrollableAreaBody\\\"\\u003E\\u003Cdiv class=\\\"uiScrollableAreaContent\\\"\\u003E\\u003Cdiv class=\\\"clearfix fbPhotoSnowliftAuthorInfo\\\"\\u003E\\u003Cdiv class=\\\"lfloat\\\" id=\\\"fbPhotoSnowliftAuthorPic\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cdiv class=\\\"fbPhotoContributorName\\\" id=\\\"fbPhotoSnowliftAuthorName\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"mrs fsm fwn fcg\\\"\\u003E\\u003Cspan id=\\\"fbPhotoSnowliftSubscribe\\\"\\u003E\\u003C/span\\u003E\\u003Cspan id=\\\"fbPhotoSnowliftTimestamp\\\"\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"mls\\\" id=\\\"fbPhotoSnowliftAudienceSelector\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fsm fwn fcg\\\"\\u003E\\u003Cdiv class=\\\"fbPhotosOnProfile\\\" id=\\\"fbPhotoSnowliftOnProfile\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbPhotosPhotoCaption\\\" tabindex=\\\"0\\\" aria-live=\\\"polite\\\" id=\\\"fbPhotoSnowliftCaption\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbPhotoTagList\\\" id=\\\"fbPhotoSnowliftTagList\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbPhotoPagesTagList\\\" id=\\\"fbPhotoSnowliftPagesTagList\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"pts fbPhotoLegacyTagList\\\" id=\\\"fbPhotoSnowliftLegacyTagList\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbPhotosPhotoOwnerButtons stat_elem\\\" id=\\\"fbPhotoSnowliftOwnerButtons\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbPhotosSnowliftFeedback\\\" id=\\\"fbPhotoSnowliftFeedback\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbPhotosSnowboxFeedbackInput\\\" id=\\\"fbPhotoSnowliftFeedbackInput\\\"\\u003E\\u003C/div\\u003E\\u003C/form\\u003E\\u003Cdiv class=\\\"-cx-PRIVATE-snowliftAds__root rhcFooter\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },7,],[\"m205535_58\",{\n            __html: \"\\u003Cli class=\\\"uiUfiComment uiUfiPreview ufiItem\\\"\\u003E\\u003Cdiv class=\\\"UIImageBlock clearfix uiUfiActorBlock\\\"\\u003E\\u003Ca class=\\\"actorPic UIImageBlock_Image UIImageBlock_SMALL_Image\\\" href=\\\"http://www.facebook.com/javascript.testengineer\\\" tabindex=\\\"-1\\\" data-ft=\\\"&#123;&quot;type&quot;:34,&quot;tn&quot;:&quot;T&quot;&#125;\\\" data-hovercard=\\\"/ajax/hovercard/user.php?id=100001812504199\\\"\\u003E\\u003Cimg class=\\\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__medium img\\\" src=\\\"http://profile.ak.fbcdn.net/hprofile-ak-ash2/275624_100001812504199_1255023530_q.jpg\\\" alt=\\\"\\\" /\\u003E\\u003C/a\\u003E\\u003Clabel class=\\\"invisible_elem UIImageBlock_Ext uiCloseButton\\\" for=\\\"uq3j2t_33\\\"\\u003E\\u003Cinput title=\\\"Remove\\\" type=\\\"submit\\\" id=\\\"uq3j2t_33\\\" /\\u003E\\u003C/label\\u003E\\u003Cdiv data-ft=\\\"&#123;&quot;type&quot;:33,&quot;tn&quot;:&quot;K&quot;&#125;\\\" class=\\\"UIImageBlock_Content UIImageBlock_SMALL_Content\\\"\\u003E\\u003Cdiv class=\\\"commentContent\\\"\\u003E\\u003Ca class=\\\"actorName\\\" href=\\\"http://www.facebook.com/javascript.testengineer\\\" data-ft=\\\"&#123;&quot;type&quot;:35,&quot;tn&quot;:&quot;;&quot;&#125;\\\"\\u003EJavaScript TestEngineer\\u003C/a\\u003E \\u003Cspan data-jsid=\\\"text\\\" class=\\\"commentBody\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"commentActions fsm fwn fcg\\\"\\u003E\\u003Cspan class=\\\"uiUfiFailureHide\\\"\\u003E\\u003Cabbr title=\\\"Monday, August 13, 2012 at 11:34am\\\" data-utime=\\\"1344872055\\\" class=\\\"timestamp livetimestamp\\\"\\u003E2 seconds ago\\u003C/abbr\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"uiUfiFailureShow\\\"\\u003E\\u003Cspan style=\\\"padding-left: 16px;\\\" class=\\\"uiIconText uiUfiFailureMessage\\\"\\u003E\\u003Ci class=\\\"img sp_ae80w4 sx_e17869\\\" style=\\\"top: 1px;\\\"\\u003E\\u003C/i\\u003EUnable to post comment.\\u003C/span\\u003E \\u003Ca data-jsid=\\\"retry_link\\\" href=\\\"#\\\"\\u003ETry Again\\u003C/a\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/li\\u003E\"\n        },2,],],\n        elements: [[\"m205528_12\",\"uq3j2t_4\",2,],[\"m205528_9\",\"uq3j2t_5\",4,],[\"m205528_17\",\"uq3j2t_8\",2,],[\"m205528_14\",\"uq3j2t_9\",4,],[\"m205528_22\",\"uq3j2t_11\",2,],[\"m205528_19\",\"uq3j2t_12\",4,],[\"m205530_27\",\"fbPhotoSnowliftFullScreenSwitch\",2,\"m205530_26\",],[\"m205530_29\",\"fbPhotoSnowliftFullScreenClose\",2,\"m205530_26\",],[\"m205530_31\",\"uq3j2t_14\",2,\"m205530_26\",],[\"m205530_33\",\"uq3j2t_15\",2,\"m205530_26\",],[\"m205530_35\",\"uq3j2t_16\",2,\"m205530_26\",],[\"m205531_37\",\"uq3j2t_17\",2,],[\"m205531_42\",\"uq3j2t_18\",2,],[\"m205531_38\",\"uq3j2t_19\",6,],[\"m205531_44\",\"uq3j2t_21\",2,],[\"m205531_49\",\"uq3j2t_22\",2,],[\"m205531_45\",\"uq3j2t_23\",6,],[\"m205531_51\",\"uq3j2t_25\",2,],[\"m205531_56\",\"uq3j2t_26\",2,],[\"m205531_52\",\"uq3j2t_27\",6,],[\"m205529_23\",\"uq3j2t_30\",2,],[\"m205529_24\",\"uq3j2t_31\",2,],[\"m205529_25\",\"uq3j2t_32\",2,],],\n        require: [[\"Hovercard\",],[\"m205528_8\",],[\"m205528_10\",],[\"m205528_11\",],[\"m205528_13\",],[\"m205528_15\",],[\"m205528_16\",],[\"m205528_18\",],[\"m205528_20\",],[\"m205528_21\",],[\"UFIUpdate\",],[\"Tooltip\",\"set\",[\"m205530_27\",\"m205530_28\",],[{\n            __m: \"m205530_27\"\n        },{\n            __m: \"m205530_28\"\n        },],],[\"Tooltip\",\"set\",[\"m205530_29\",\"m205530_30\",],[{\n            __m: \"m205530_29\"\n        },{\n            __m: \"m205530_30\"\n        },],],[\"Tooltip\",\"set\",[\"m205530_31\",\"m205530_32\",],[{\n            __m: \"m205530_31\"\n        },{\n            __m: \"m205530_32\"\n        },],],[\"Tooltip\",\"set\",[\"m205530_33\",\"m205530_34\",],[{\n            __m: \"m205530_33\"\n        },{\n            __m: \"m205530_34\"\n        },],],[\"Scrollable\",],[\"PhotoSnowlift\",\"initInstance\",[\"m205530_26\",],[{\n            __m: \"m205530_26\"\n        },{\n            pinpagers: false,\n            showsmallerad: true,\n            hires: true,\n            refresh_fast: false,\n            refresh_rate: 20000,\n            ego_enabled: true,\n            hw_rendering: false,\n            pivot_hover: true,\n            pivot_end_metric: false,\n            og_videos: false,\n            pivot_end: false,\n            min_ads: 2\n        },],],[\"OptimisticUFI\",\"init\",[\"m205531_36\",],[{\n            __m: \"m205531_36\"\n        },],],[\"m205531_39\",],[\"m205531_40\",],[\"Typeahead\",\"init\",[\"m205531_38\",\"m205531_40\",\"m205531_41\",],[{\n            __m: \"m205531_38\"\n        },{\n            __m: \"m205531_40\"\n        },[\"buildBestAvailableNames\",\"hoistFriends\",\"scrollArea\",],{\n            __m: \"m205531_41\"\n        },],],[\"SubmitOnEnterListener\",],[\"FlipDirectionOnKeypress\",],[\"PlaceholderListener\",],[\"PlaceholderOnsubmitFormListener\",],[\"m205531_46\",],[\"m205531_47\",],[\"Typeahead\",\"init\",[\"m205531_45\",\"m205531_47\",\"m205531_48\",],[{\n            __m: \"m205531_45\"\n        },{\n            __m: \"m205531_47\"\n        },[\"buildBestAvailableNames\",\"hoistFriends\",\"scrollArea\",],{\n            __m: \"m205531_48\"\n        },],],[\"m205531_53\",],[\"m205531_54\",],[\"Typeahead\",\"init\",[\"m205531_52\",\"m205531_54\",\"m205531_55\",],[{\n            __m: \"m205531_52\"\n        },{\n            __m: \"m205531_54\"\n        },[\"buildBestAvailableNames\",\"hoistFriends\",\"scrollArea\",],{\n            __m: \"m205531_55\"\n        },],],]\n    },\n    css: [\"zO4BE\",],\n    bootloadable: {\n        PhotoCropper: {\n            resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",\"z8dwT\",\"DI7dA\",],\n            \"module\": true\n        },\n        \"legacy:live-js\": {\n            resources: [\"8gPM0\",\"bS0QP\",\"1zqwA\",]\n        },\n        \"ufi-tracking-js\": {\n            resources: [\"8gPM0\",\"bS0QP\",]\n        },\n        \"legacy:dom-collect\": {\n            resources: [\"J9ZDd\",]\n        }\n    },\n    resource_map: {\n        z8dwT: {\n            type: \"css\",\n            permanent: 1,\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y_/r/2ZKqMSAb11n.css\"\n        },\n        J9ZDd: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yK/r/uytRyIh8vJz.js\"\n        }\n    },\n    js: [\"8gPM0\",\"bS0QP\",\"JOZ9R\",],\n    requires: [\"pagelet_controller::home_intentional_stream\",],\n    provides: [\"pagelet_controller::substream_scroll_load_0\",],\n    onload: [\"Arbiter.inform(UIIntentionalStreamMessage.INSERT_STORIES);\",\"UIIntentionalStream.instance.updateTimeRange(1344870826, 1344870826);\",\"UIIntentionalStream.instance.updateOldestMR(1344557647);\",\"UIIntentionalStream.instance.updateScrollPosition(3);\",\"UIIntentionalStream.instance.updateLastViewStateID(\\\"6023853588764622143\\\");\",\"UIIntentionalStream.instance.updateCachedScrollQID(\\\"5776181494237290802\\\");\",\"StreamShareVideo.registerThumb(\\\"427041767338328\\\", \\\"uq3j2t_6\\\", \\\"feed\\\", \\\"\\\\/ajax\\\\/flash\\\\/expand_inline.php?replace=1&target_div=uq3j2t_7&context=story&bgcolor=\\\\u002523f7f7f7&share_id=427041767338328\\\")\",\"share_data={max_recipients:20};\",\"StreamShareVideo.registerThumb(\\\"454040841297040\\\", \\\"uq3j2t_29\\\", \\\"feed\\\", \\\"\\\\/ajax\\\\/flash\\\\/expand_inline.php?replace=1&target_div=uq3j2t_29&context=comment&bgcolor=\\\\u002523FFFFFF&max_width=310&max_height=310&share_id=454040841297040\\\")\",],\n    onafterload: [\"Bootloader.loadComponents([\\\"legacy:live-js\\\"], function(){ Live.startup() });\",\"Bootloader.loadComponents([\\\"legacy:live-js\\\"], function(){ Live.startup() });\",\"Bootloader.loadComponents([\\\"legacy:live-js\\\"], function(){ Live.startup() });\",\"Bootloader.loadComponents([\\\"fb-photos-snowlift-css\\\"], function(){  });\",\"Bootloader.loadComponents([\\\"ufi-tracking-js\\\"], function(){ ufi_add_all_link_data(); });\",\"Bootloader.loadComponents([\\\"legacy:live-timer\\\"], function(){ LiveTimer.restart(1344872055); });\",],\n    content: {\n        pagelet_sub_stream_0: {\n            container_id: \"uq3j16_19\"\n        }\n    },\n    tti_phase: 1\n});");
// 1331
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s6c53161bae02d65e4f0adb8619ae7e1c7f97c970");
// 1332
geval("bigPipe.JSBNG__onPageletArrive({\n    phase: 1,\n    id: \"pagelet_sub_stream_0\",\n    append: \"home_stream\",\n    display_dependency: [\"pagelet_home_stream\",],\n    is_last: true,\n    jsmods: {\n        instances: [[\"m205528_8\",[\"PopoverAsyncMenuLoading\",],[\"HighlightSelectorMenu\",],3,],[\"m205528_10\",[\"PopoverAsyncMenu\",\"m205528_11\",\"m205528_9\",\"m205528_8\",\"PopoverMenuOverlappingBorder\",],[{\n            __m: \"m205528_11\"\n        },{\n            __m: \"m205528_9\"\n        },{\n            __m: \"m205528_8\"\n        },\"/ajax/feed/feed_menu.php?action=hide&story_div_id=stream_story_50291e77418e06768205346&filter_key=h_nor&story_fbids%5B0%5D=1055580469%3A3688953136508&report_link=%2Fajax%2Freport.php%3Fcontent_type%3D2%26cid%3D3688952976504%26rid%3D1055580469%26h%3DAfi7UrqWOO7GhNRu&story_type=247&source_id=1055580469&qid=5776181494237290802&mf_story_key=-4571705487949635972&actor_id=1055580469&num_participants=1&is_highlight=0&viewstate_id=-4571705487949635972&feedback_target_id=3688952976504&tl_story_tokens%5B0%5D=1055580469%3A3688953136508%3A0%3A1344557647%3A1344557647&tl_story_tokens%5B1%5D=1055580469%3A3688953136508%3A0%3A1344557647%3A1344557647&tl_story_tokens%5B2%5D=1055580469%3A3690970746947%3A4%3A1344653978%3A1344616272&tl_story_tokens%5B3%5D=1055580469%3A3690970746947%3A4%3A1344653978%3A1344616272&tl_story_tokens%5B4%5D=1055580469%3A3686112385491%3A5%3A1344562882%3A1344482881&tl_story_tokens%5B5%5D=1055580469%3A3686112385491%3A5%3A1344562882%3A1344482881\",[{\n            __m: \"PopoverMenuOverlappingBorder\"\n        },],],1,],[\"m205528_11\",[\"Popover\",\"m205528_12\",\"m205528_9\",\"ContextualLayerAsyncRelative\",],[{\n            __m: \"m205528_12\"\n        },{\n            __m: \"m205528_9\"\n        },[{\n            __m: \"ContextualLayerAsyncRelative\"\n        },],{\n            alignh: \"right\",\n            layer_content: null\n        },],3,],[\"m205528_13\",[\"PopoverAsyncMenuLoading\",],[\"HighlightSelectorMenu\",],3,],[\"m205528_15\",[\"PopoverAsyncMenu\",\"m205528_16\",\"m205528_14\",\"m205528_13\",\"PopoverMenuOverlappingBorder\",],[{\n            __m: \"m205528_16\"\n        },{\n            __m: \"m205528_14\"\n        },{\n            __m: \"m205528_13\"\n        },\"/ajax/feed/feed_menu.php?action=hide&story_div_id=stream_story_50291e77421b58760782402&filter_key=h_nor&story_fbids%5B0%5D=1055580469%3A427041767338328&story_fbids%5B1%5D=1055580469%3A427041767338328&report_link=%2Fajax%2Freport.php%3Fcontent_type%3D5%26cid%3D427041767338328%26rid%3D1055580469%26profile%3D1055580469%26h%3DAfj19nxzGUJWqR0l&story_type=263&source_id=1055580469&qid=5776181494237290802&mf_story_key=8438955046610351598&actor_id=1055580469&num_participants=1&is_highlight=0&viewstate_id=8438955046610351598&feedback_target_id=427041767338328&tl_story_tokens%5B0%5D=1055580469%3A427041767338328%3A%3A1344632723%3A1344632723&tl_story_tokens%5B1%5D=1055580469%3A427041767338328%3A%3A1344632723%3A1344632723\",[{\n            __m: \"PopoverMenuOverlappingBorder\"\n        },],],1,],[\"m205528_16\",[\"Popover\",\"m205528_17\",\"m205528_14\",\"ContextualLayerAsyncRelative\",],[{\n            __m: \"m205528_17\"\n        },{\n            __m: \"m205528_14\"\n        },[{\n            __m: \"ContextualLayerAsyncRelative\"\n        },],{\n            alignh: \"right\",\n            layer_content: null\n        },],3,],[\"m205528_18\",[\"PopoverAsyncMenuLoading\",],[\"HighlightSelectorMenu\",],3,],[\"m205528_20\",[\"PopoverAsyncMenu\",\"m205528_21\",\"m205528_19\",\"m205528_18\",\"PopoverMenuOverlappingBorder\",],[{\n            __m: \"m205528_21\"\n        },{\n            __m: \"m205528_19\"\n        },{\n            __m: \"m205528_18\"\n        },\"/ajax/feed/feed_menu.php?action=hide&story_div_id=stream_story_50291e77423ed9900470894&filter_key=h_nor&spam_object_id=424129870965893&report_link=0&story_type=257&source_id=0&qid=5776181494237290802&mf_story_key=6023853588764622143&actor_id=1055580469&num_participants=1&is_highlight=0&viewstate_id=6023853588764622143\",[{\n            __m: \"PopoverMenuOverlappingBorder\"\n        },],],1,],[\"m205528_21\",[\"Popover\",\"m205528_22\",\"m205528_19\",\"ContextualLayerAsyncRelative\",],[{\n            __m: \"m205528_22\"\n        },{\n            __m: \"m205528_19\"\n        },[{\n            __m: \"ContextualLayerAsyncRelative\"\n        },],{\n            alignh: \"right\",\n            layer_content: null\n        },],3,],[\"m205531_39\",[\"MentionsInput\",\"m205531_37\",\"m205531_40\",\"m205531_38\",\"m205531_41\",],[{\n            __m: \"m205531_37\"\n        },{\n            __m: \"m205531_40\"\n        },{\n            __m: \"m205531_38\"\n        },{\n            max: 10\n        },null,{\n            __m: \"m205531_41\"\n        },],1,],[\"m205531_40\",[\"Typeahead\",\"m205531_43\",\"ContextualTypeaheadView\",\"CompactTypeaheadRenderer\",\"m205531_38\",\"TypeaheadAreaCore\",\"m205531_42\",],[{\n            __m: \"m205531_43\"\n        },{\n            node_id: \"\",\n            ctor: {\n                __m: \"ContextualTypeaheadView\"\n            },\n            options: {\n                autoSelect: true,\n                renderer: {\n                    __m: \"CompactTypeaheadRenderer\"\n                },\n                causalElement: {\n                    __m: \"m205531_38\"\n                },\n                maxResults: 3,\n                scrollarea: true\n            }\n        },{\n            ctor: {\n                __m: \"TypeaheadAreaCore\"\n            },\n            options: []\n        },{\n            __m: \"m205531_42\"\n        },],5,],[\"m205531_46\",[\"MentionsInput\",\"m205531_44\",\"m205531_47\",\"m205531_45\",\"m205531_48\",],[{\n            __m: \"m205531_44\"\n        },{\n            __m: \"m205531_47\"\n        },{\n            __m: \"m205531_45\"\n        },{\n            max: 10\n        },null,{\n            __m: \"m205531_48\"\n        },],1,],[\"m205531_47\",[\"Typeahead\",\"m205531_50\",\"ContextualTypeaheadView\",\"CompactTypeaheadRenderer\",\"m205531_45\",\"TypeaheadAreaCore\",\"m205531_49\",],[{\n            __m: \"m205531_50\"\n        },{\n            node_id: \"\",\n            ctor: {\n                __m: \"ContextualTypeaheadView\"\n            },\n            options: {\n                autoSelect: true,\n                renderer: {\n                    __m: \"CompactTypeaheadRenderer\"\n                },\n                causalElement: {\n                    __m: \"m205531_45\"\n                },\n                maxResults: 3,\n                scrollarea: true\n            }\n        },{\n            ctor: {\n                __m: \"TypeaheadAreaCore\"\n            },\n            options: []\n        },{\n            __m: \"m205531_49\"\n        },],5,],[\"m205531_53\",[\"MentionsInput\",\"m205531_51\",\"m205531_54\",\"m205531_52\",\"m205531_55\",],[{\n            __m: \"m205531_51\"\n        },{\n            __m: \"m205531_54\"\n        },{\n            __m: \"m205531_52\"\n        },{\n            max: 10\n        },null,{\n            __m: \"m205531_55\"\n        },],1,],[\"m205531_54\",[\"Typeahead\",\"m205531_57\",\"ContextualTypeaheadView\",\"CompactTypeaheadRenderer\",\"m205531_52\",\"TypeaheadAreaCore\",\"m205531_56\",],[{\n            __m: \"m205531_57\"\n        },{\n            node_id: \"\",\n            ctor: {\n                __m: \"ContextualTypeaheadView\"\n            },\n            options: {\n                autoSelect: true,\n                renderer: {\n                    __m: \"CompactTypeaheadRenderer\"\n                },\n                causalElement: {\n                    __m: \"m205531_52\"\n                },\n                maxResults: 3,\n                scrollarea: true\n            }\n        },{\n            ctor: {\n                __m: \"TypeaheadAreaCore\"\n            },\n            options: []\n        },{\n            __m: \"m205531_56\"\n        },],5,],[\"m205531_36\",[\"XHPTemplate\",\"m205535_58\",],[{\n            __m: \"m205535_58\"\n        },],2,],[\"m205531_41\",[\"TypeaheadMetrics\",],[{\n            extraData: {\n                event_name: \"mentions\"\n            }\n        },],4,],[\"m205531_43\",[\"MultiBootstrapDataSource\",],[{\n            maxResults: 3,\n            queryData: {\n                context: \"topics\",\n                viewer: 100001812504199,\n                filter: [\"page\",],\n                rsp: \"mentions\"\n            },\n            queryEndpoint: \"/ajax/typeahead/search.php\",\n            bootstrapData: {\n                rsp: \"mentions\"\n            },\n            bootstrapEndpoints: [{\n                endpoint: \"/ajax/typeahead/first_degree.php\",\n                data: {\n                    context: \"mentions\",\n                    viewer: 100001812504199,\n                    token: \"1343822055-7\",\n                    filter: [\"page\",\"group\",\"app\",\"JSBNG__event\",\"user\",],\n                    options: [\"friends_only\",\"nm\",]\n                }\n            },]\n        },],2,],[\"m205531_48\",[\"TypeaheadMetrics\",],[{\n            extraData: {\n                event_name: \"mentions\"\n            }\n        },],4,],[\"m205531_50\",[\"MultiBootstrapDataSource\",],[{\n            maxResults: 3,\n            queryData: {\n                context: \"topics\",\n                viewer: 100001812504199,\n                filter: [\"page\",],\n                rsp: \"mentions\"\n            },\n            queryEndpoint: \"/ajax/typeahead/search.php\",\n            bootstrapData: {\n                rsp: \"mentions\"\n            },\n            bootstrapEndpoints: [{\n                endpoint: \"/ajax/typeahead/first_degree.php\",\n                data: {\n                    context: \"mentions\",\n                    viewer: 100001812504199,\n                    token: \"1343822055-7\",\n                    filter: [\"page\",\"group\",\"app\",\"JSBNG__event\",\"user\",],\n                    options: [\"friends_only\",\"nm\",]\n                }\n            },]\n        },],2,],[\"m205531_55\",[\"TypeaheadMetrics\",],[{\n            extraData: {\n                event_name: \"mentions\"\n            }\n        },],4,],[\"m205531_57\",[\"MultiBootstrapDataSource\",],[{\n            maxResults: 3,\n            queryData: {\n                context: \"topics\",\n                viewer: 100001812504199,\n                filter: [\"page\",],\n                rsp: \"mentions\"\n            },\n            queryEndpoint: \"/ajax/typeahead/search.php\",\n            bootstrapData: {\n                rsp: \"mentions\"\n            },\n            bootstrapEndpoints: [{\n                endpoint: \"/ajax/typeahead/first_degree.php\",\n                data: {\n                    context: \"mentions\",\n                    viewer: 100001812504199,\n                    token: \"1343822055-7\",\n                    filter: [\"page\",\"group\",\"app\",\"JSBNG__event\",\"user\",],\n                    options: [\"friends_only\",\"nm\",]\n                }\n            },]\n        },],2,],],\n        markup: [[\"m205530_28\",{\n            __html: \"Enter Fullscreen\"\n        },2,],[\"m205530_30\",{\n            __html: \"Press Esc to exit fullscreen\"\n        },2,],[\"m205530_32\",{\n            __html: \"Press Esc to close\"\n        },2,],[\"m205530_34\",{\n            __html: \"Press Esc to exit fullscreen\"\n        },2,],[\"m205530_26\",{\n            __html: \"\\u003Cdiv id=\\\"fbPhotoSnowlift\\\" class=\\\"fbPhotoSnowlift fbxPhoto hidden_elem fbPhotoSnowliftPivotHover\\\" tabindex=\\\"0\\\" role=\\\"region\\\" aria-label=\\\"Facebook Photo Theater\\\" aria-busy=\\\"true\\\"\\u003E\\u003Cdiv class=\\\"fbPhotoSnowliftOuter\\\"\\u003E\\u003Cdiv class=\\\"fbPhotoSnowliftInner\\\"\\u003E\\u003Cdiv class=\\\"fbPhotoSnowliftContainer uiContextualLayerParent\\\"\\u003E\\u003Cdiv class=\\\"clearfix fbPhotoSnowliftPopup\\\"\\u003E\\u003Cdiv class=\\\"stageWrapper lfloat\\\"\\u003E\\u003Cdiv class=\\\"fbPhotoSnowliftFullScreen fullScreenSwitch\\\" id=\\\"fullScreenSwitch\\\"\\u003E\\u003Ca data-hover=\\\"tooltip\\\" data-tooltip-position=\\\"below\\\" data-tooltip-alignh=\\\"right\\\" href=\\\"#\\\" id=\\\"fbPhotoSnowliftFullScreenSwitch\\\"\\u003E\\u003C/a\\u003E\\u003Ca data-hover=\\\"tooltip\\\" data-tooltip-position=\\\"below\\\" data-tooltip-alignh=\\\"right\\\" href=\\\"#\\\" id=\\\"fbPhotoSnowliftFullScreenClose\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"stage\\\"\\u003E\\u003Cimg class=\\\"spotlight spotlight\\\" src=\\\"/images/spacer.gif\\\" /\\u003E\\u003Cdiv class=\\\"fbPhotosPhotoTagboxes tagContainer\\\" id=\\\"fbPhotoSnowliftTagBoxes\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbPhotoTagApproval\\\" id=\\\"fbPhotoSnowliftTagApproval\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"videoStage\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"stageActions\\\" id=\\\"snowliftStageActions\\\"\\u003E\\u003Cdiv class=\\\"clearfix snowliftOverlay snowliftOverlayBar rightButtons\\\"\\u003E\\u003Cdiv class=\\\"overlayBarButtons rfloat\\\"\\u003E\\u003Cdiv class=\\\"-cx-PRIVATE-uiInlineBlock__root -cx-PRIVATE-uiInlineBlock__middle fbPhotosPhotoActions\\\" id=\\\"fbPhotoSnowliftActions\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbPhotosPhotoButtons\\\" id=\\\"fbPhotoSnowliftButtons\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"mediaTitleInfo\\\"\\u003E\\u003Cdiv class=\\\"mediaTitleBoxFlex\\\"\\u003E\\u003Cdiv id=\\\"fbPhotoSnowliftMediaTitle\\\"\\u003E\\u003C/div\\u003E\\u003Cspan class=\\\"mlm hidden_elem\\\" id=\\\"fbPhotoSnowliftPositionAndCount\\\"\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"mediaTitleInfoSpacer\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbPhotosPhotoTagboxBase newTagBox hidden_elem\\\" style=\\\"\\\"\\u003E\\u003Cdiv class=\\\"borderTagBox\\\"\\u003E\\u003Cdiv class=\\\"innerTagBox\\\"\\u003E\\u003Cdiv class=\\\"ieContentFix\\\"\\u003E\\u00a0\\u00a0\\u00a0\\u00a0\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"tag\\\"\\u003E\\u003Cdiv class=\\\"tagPointer\\\"\\u003E\\u003Ci class=\\\"tagArrow img sp_ae80w4 sx_55a200\\\"\\u003E\\u003C/i\\u003E\\u003Cdiv class=\\\"tagName\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Ca class=\\\"snowliftPager prev\\\" title=\\\"Previous\\\"\\u003E\\u003Ci\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003Ca class=\\\"snowliftPager next\\\" title=\\\"Next\\\"\\u003E\\u003Ci\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"photoError stageError\\\" id=\\\"fbPhotoSnowliftError\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"rhc photoUfiContainer\\\"\\u003E\\u003Cdiv class=\\\"rhcHeader\\\"\\u003E\\u003Cdiv class=\\\"fbPhotoSnowliftControls\\\"\\u003E\\u003Ca data-hover=\\\"tooltip\\\" data-tooltip-position=\\\"below\\\" data-tooltip-alignh=\\\"right\\\" class=\\\"closeTheater\\\" href=\\\"#\\\" id=\\\"uq3j2t_14\\\"\\u003E\\u003C/a\\u003E\\u003Ca data-hover=\\\"tooltip\\\" data-tooltip-position=\\\"below\\\" data-tooltip-alignh=\\\"right\\\" class=\\\"closeTheater fullscreenCommentClose\\\" href=\\\"#\\\" id=\\\"uq3j2t_15\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv id=\\\"fbPhotoSnowliftInlineEditor\\\" class=\\\"fbPhotoInlineEditor\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cform rel=\\\"async\\\" class=\\\"fbPhotosSnowliftFeedbackForm rhcBody commentable_item autoexpand_mode\\\" method=\\\"post\\\" action=\\\"/ajax/ufi/modify.php\\\" onsubmit=\\\"return Event.__inlineSubmit(this,event)\\\" id=\\\"uq3j2t_16\\\"\\u003E\\u003Cinput type=\\\"hidden\\\" name=\\\"charset_test\\\" value=\\\"&euro;,&acute;,\\u20ac,\\u00b4,\\u6c34,\\u0414,\\u0404\\\" /\\u003E\\u003Cinput type=\\\"hidden\\\" name=\\\"fb_dtsg\\\" value=\\\"AQCc21Em\\\" autocomplete=\\\"off\\\" /\\u003E\\u003Cdiv class=\\\"uiScrollableArea rhcScroller native\\\" style=\\\"width:285px;\\\"\\u003E\\u003Cdiv class=\\\"uiScrollableAreaWrap scrollable\\\" tabindex=\\\"0\\\"\\u003E\\u003Cdiv class=\\\"uiScrollableAreaBody\\\"\\u003E\\u003Cdiv class=\\\"uiScrollableAreaContent\\\"\\u003E\\u003Cdiv class=\\\"clearfix fbPhotoSnowliftAuthorInfo\\\"\\u003E\\u003Cdiv class=\\\"lfloat\\\" id=\\\"fbPhotoSnowliftAuthorPic\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cdiv class=\\\"fbPhotoContributorName\\\" id=\\\"fbPhotoSnowliftAuthorName\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"mrs fsm fwn fcg\\\"\\u003E\\u003Cspan id=\\\"fbPhotoSnowliftSubscribe\\\"\\u003E\\u003C/span\\u003E\\u003Cspan id=\\\"fbPhotoSnowliftTimestamp\\\"\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"mls\\\" id=\\\"fbPhotoSnowliftAudienceSelector\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fsm fwn fcg\\\"\\u003E\\u003Cdiv class=\\\"fbPhotosOnProfile\\\" id=\\\"fbPhotoSnowliftOnProfile\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbPhotosPhotoCaption\\\" tabindex=\\\"0\\\" aria-live=\\\"polite\\\" id=\\\"fbPhotoSnowliftCaption\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbPhotoTagList\\\" id=\\\"fbPhotoSnowliftTagList\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbPhotoPagesTagList\\\" id=\\\"fbPhotoSnowliftPagesTagList\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"pts fbPhotoLegacyTagList\\\" id=\\\"fbPhotoSnowliftLegacyTagList\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbPhotosPhotoOwnerButtons stat_elem\\\" id=\\\"fbPhotoSnowliftOwnerButtons\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbPhotosSnowliftFeedback\\\" id=\\\"fbPhotoSnowliftFeedback\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbPhotosSnowboxFeedbackInput\\\" id=\\\"fbPhotoSnowliftFeedbackInput\\\"\\u003E\\u003C/div\\u003E\\u003C/form\\u003E\\u003Cdiv class=\\\"-cx-PRIVATE-snowliftAds__root rhcFooter\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },7,],[\"m205535_58\",{\n            __html: \"\\u003Cli class=\\\"uiUfiComment uiUfiPreview ufiItem\\\"\\u003E\\u003Cdiv class=\\\"UIImageBlock clearfix uiUfiActorBlock\\\"\\u003E\\u003Ca class=\\\"actorPic UIImageBlock_Image UIImageBlock_SMALL_Image\\\" href=\\\"http://www.facebook.com/javascript.testengineer\\\" tabindex=\\\"-1\\\" data-ft=\\\"&#123;&quot;type&quot;:34,&quot;tn&quot;:&quot;T&quot;&#125;\\\" data-hovercard=\\\"/ajax/hovercard/user.php?id=100001812504199\\\"\\u003E\\u003Cimg class=\\\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__medium img\\\" src=\\\"http://profile.ak.fbcdn.net/hprofile-ak-ash2/275624_100001812504199_1255023530_q.jpg\\\" alt=\\\"\\\" /\\u003E\\u003C/a\\u003E\\u003Clabel class=\\\"invisible_elem UIImageBlock_Ext uiCloseButton\\\" for=\\\"uq3j2t_33\\\"\\u003E\\u003Cinput title=\\\"Remove\\\" type=\\\"submit\\\" id=\\\"uq3j2t_33\\\" /\\u003E\\u003C/label\\u003E\\u003Cdiv data-ft=\\\"&#123;&quot;type&quot;:33,&quot;tn&quot;:&quot;K&quot;&#125;\\\" class=\\\"UIImageBlock_Content UIImageBlock_SMALL_Content\\\"\\u003E\\u003Cdiv class=\\\"commentContent\\\"\\u003E\\u003Ca class=\\\"actorName\\\" href=\\\"http://www.facebook.com/javascript.testengineer\\\" data-ft=\\\"&#123;&quot;type&quot;:35,&quot;tn&quot;:&quot;;&quot;&#125;\\\"\\u003EJavaScript TestEngineer\\u003C/a\\u003E \\u003Cspan data-jsid=\\\"text\\\" class=\\\"commentBody\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"commentActions fsm fwn fcg\\\"\\u003E\\u003Cspan class=\\\"uiUfiFailureHide\\\"\\u003E\\u003Cabbr title=\\\"Monday, August 13, 2012 at 11:34am\\\" data-utime=\\\"1344872055\\\" class=\\\"timestamp livetimestamp\\\"\\u003E2 seconds ago\\u003C/abbr\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"uiUfiFailureShow\\\"\\u003E\\u003Cspan style=\\\"padding-left: 16px;\\\" class=\\\"uiIconText uiUfiFailureMessage\\\"\\u003E\\u003Ci class=\\\"img sp_ae80w4 sx_e17869\\\" style=\\\"top: 1px;\\\"\\u003E\\u003C/i\\u003EUnable to post comment.\\u003C/span\\u003E \\u003Ca data-jsid=\\\"retry_link\\\" href=\\\"#\\\"\\u003ETry Again\\u003C/a\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/li\\u003E\"\n        },2,],],\n        elements: [[\"m205528_12\",\"uq3j2t_4\",2,],[\"m205528_9\",\"uq3j2t_5\",4,],[\"m205528_17\",\"uq3j2t_8\",2,],[\"m205528_14\",\"uq3j2t_9\",4,],[\"m205528_22\",\"uq3j2t_11\",2,],[\"m205528_19\",\"uq3j2t_12\",4,],[\"m205530_27\",\"fbPhotoSnowliftFullScreenSwitch\",2,\"m205530_26\",],[\"m205530_29\",\"fbPhotoSnowliftFullScreenClose\",2,\"m205530_26\",],[\"m205530_31\",\"uq3j2t_14\",2,\"m205530_26\",],[\"m205530_33\",\"uq3j2t_15\",2,\"m205530_26\",],[\"m205530_35\",\"uq3j2t_16\",2,\"m205530_26\",],[\"m205531_37\",\"uq3j2t_17\",2,],[\"m205531_42\",\"uq3j2t_18\",2,],[\"m205531_38\",\"uq3j2t_19\",6,],[\"m205531_44\",\"uq3j2t_21\",2,],[\"m205531_49\",\"uq3j2t_22\",2,],[\"m205531_45\",\"uq3j2t_23\",6,],[\"m205531_51\",\"uq3j2t_25\",2,],[\"m205531_56\",\"uq3j2t_26\",2,],[\"m205531_52\",\"uq3j2t_27\",6,],[\"m205529_23\",\"uq3j2t_30\",2,],[\"m205529_24\",\"uq3j2t_31\",2,],[\"m205529_25\",\"uq3j2t_32\",2,],],\n        require: [[\"Hovercard\",],[\"m205528_8\",],[\"m205528_10\",],[\"m205528_11\",],[\"m205528_13\",],[\"m205528_15\",],[\"m205528_16\",],[\"m205528_18\",],[\"m205528_20\",],[\"m205528_21\",],[\"UFIUpdate\",],[\"Tooltip\",\"set\",[\"m205530_27\",\"m205530_28\",],[{\n            __m: \"m205530_27\"\n        },{\n            __m: \"m205530_28\"\n        },],],[\"Tooltip\",\"set\",[\"m205530_29\",\"m205530_30\",],[{\n            __m: \"m205530_29\"\n        },{\n            __m: \"m205530_30\"\n        },],],[\"Tooltip\",\"set\",[\"m205530_31\",\"m205530_32\",],[{\n            __m: \"m205530_31\"\n        },{\n            __m: \"m205530_32\"\n        },],],[\"Tooltip\",\"set\",[\"m205530_33\",\"m205530_34\",],[{\n            __m: \"m205530_33\"\n        },{\n            __m: \"m205530_34\"\n        },],],[\"Scrollable\",],[\"PhotoSnowlift\",\"initInstance\",[\"m205530_26\",],[{\n            __m: \"m205530_26\"\n        },{\n            pinpagers: false,\n            showsmallerad: true,\n            hires: true,\n            refresh_fast: false,\n            refresh_rate: 20000,\n            ego_enabled: true,\n            hw_rendering: false,\n            pivot_hover: true,\n            pivot_end_metric: false,\n            og_videos: false,\n            pivot_end: false,\n            min_ads: 2\n        },],],[\"OptimisticUFI\",\"init\",[\"m205531_36\",],[{\n            __m: \"m205531_36\"\n        },],],[\"m205531_39\",],[\"m205531_40\",],[\"Typeahead\",\"init\",[\"m205531_38\",\"m205531_40\",\"m205531_41\",],[{\n            __m: \"m205531_38\"\n        },{\n            __m: \"m205531_40\"\n        },[\"buildBestAvailableNames\",\"hoistFriends\",\"scrollArea\",],{\n            __m: \"m205531_41\"\n        },],],[\"SubmitOnEnterListener\",],[\"FlipDirectionOnKeypress\",],[\"PlaceholderListener\",],[\"PlaceholderOnsubmitFormListener\",],[\"m205531_46\",],[\"m205531_47\",],[\"Typeahead\",\"init\",[\"m205531_45\",\"m205531_47\",\"m205531_48\",],[{\n            __m: \"m205531_45\"\n        },{\n            __m: \"m205531_47\"\n        },[\"buildBestAvailableNames\",\"hoistFriends\",\"scrollArea\",],{\n            __m: \"m205531_48\"\n        },],],[\"m205531_53\",],[\"m205531_54\",],[\"Typeahead\",\"init\",[\"m205531_52\",\"m205531_54\",\"m205531_55\",],[{\n            __m: \"m205531_52\"\n        },{\n            __m: \"m205531_54\"\n        },[\"buildBestAvailableNames\",\"hoistFriends\",\"scrollArea\",],{\n            __m: \"m205531_55\"\n        },],],]\n    },\n    css: [\"zO4BE\",],\n    bootloadable: {\n        PhotoCropper: {\n            resources: [\"8gPM0\",\"bS0QP\",\"zO4BE\",\"z8dwT\",\"DI7dA\",],\n            \"module\": true\n        },\n        \"legacy:live-js\": {\n            resources: [\"8gPM0\",\"bS0QP\",\"1zqwA\",]\n        },\n        \"ufi-tracking-js\": {\n            resources: [\"8gPM0\",\"bS0QP\",]\n        },\n        \"legacy:dom-collect\": {\n            resources: [\"J9ZDd\",]\n        }\n    },\n    resource_map: {\n        z8dwT: {\n            type: \"css\",\n            permanent: 1,\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y_/r/2ZKqMSAb11n.css\"\n        },\n        J9ZDd: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yK/r/uytRyIh8vJz.js\"\n        }\n    },\n    js: [\"8gPM0\",\"bS0QP\",\"JOZ9R\",],\n    requires: [\"pagelet_controller::home_intentional_stream\",],\n    provides: [\"pagelet_controller::substream_scroll_load_0\",],\n    JSBNG__onload: [\"Arbiter.inform(UIIntentionalStreamMessage.INSERT_STORIES);\",\"UIIntentionalStream.instance.updateTimeRange(1344870826, 1344870826);\",\"UIIntentionalStream.instance.updateOldestMR(1344557647);\",\"UIIntentionalStream.instance.updateScrollPosition(3);\",\"UIIntentionalStream.instance.updateLastViewStateID(\\\"6023853588764622143\\\");\",\"UIIntentionalStream.instance.updateCachedScrollQID(\\\"5776181494237290802\\\");\",\"StreamShareVideo.registerThumb(\\\"427041767338328\\\", \\\"uq3j2t_6\\\", \\\"feed\\\", \\\"\\\\/ajax\\\\/flash\\\\/expand_inline.php?replace=1&target_div=uq3j2t_7&context=story&bgcolor=\\\\u002523f7f7f7&share_id=427041767338328\\\")\",\"share_data={max_recipients:20};\",\"StreamShareVideo.registerThumb(\\\"454040841297040\\\", \\\"uq3j2t_29\\\", \\\"feed\\\", \\\"\\\\/ajax\\\\/flash\\\\/expand_inline.php?replace=1&target_div=uq3j2t_29&context=comment&bgcolor=\\\\u002523FFFFFF&max_width=310&max_height=310&share_id=454040841297040\\\")\",],\n    JSBNG__onafterload: [\"Bootloader.loadComponents([\\\"legacy:live-js\\\"], function(){ Live.startup() });\",\"Bootloader.loadComponents([\\\"legacy:live-js\\\"], function(){ Live.startup() });\",\"Bootloader.loadComponents([\\\"legacy:live-js\\\"], function(){ Live.startup() });\",\"Bootloader.loadComponents([\\\"fb-photos-snowlift-css\\\"], function(){  });\",\"Bootloader.loadComponents([\\\"ufi-tracking-js\\\"], function(){ ufi_add_all_link_data(); });\",\"Bootloader.loadComponents([\\\"legacy:live-timer\\\"], function(){ LiveTimer.restart(1344872055); });\",],\n    JSBNG__content: {\n        pagelet_sub_stream_0: {\n            container_id: \"uq3j16_19\"\n        }\n    },\n    tti_phase: 1\n});");
// 1414
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"bigPipe.onPageletArrive({\n    phase: 2,\n    id: \"pagelet_reminders\",\n    css: [\"zO4BE\",],\n    js: [\"8gPM0\",\"bS0QP\",],\n    content: {\n        pagelet_reminders: {\n            container_id: \"uq3j16_20\"\n        }\n    }\n});");
// 1415
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s95b0fb2dc010ef2103d65c860dfd2400c908c1dd");
// 1416
geval("bigPipe.JSBNG__onPageletArrive({\n    phase: 2,\n    id: \"pagelet_reminders\",\n    css: [\"zO4BE\",],\n    js: [\"8gPM0\",\"bS0QP\",],\n    JSBNG__content: {\n        pagelet_reminders: {\n            container_id: \"uq3j16_20\"\n        }\n    }\n});");
// 1457
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"bigPipe.onPageletArrive({\n    phase: 2,\n    id: \"pagelet_ego_pane_w\",\n    jsmods: {\n        elements: [[\"m205539_1\",\"uq3jae_1\",2,],],\n        require: [[\"Arbiter\",\"inform\",[],[\"netego_loaded\",],],[\"PhotoEverstoreLogger\",\"registerForLogging\",[\"m205539_1\",],[{\n            __m: \"m205539_1\"\n        },],],]\n    },\n    css: [\"zO4BE\",],\n    js: [\"8gPM0\",\"bS0QP\",],\n    content: {\n        pagelet_ego_pane_w: {\n            container_id: \"uq3j16_21\"\n        }\n    }\n});");
// 1458
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s26fe9d3c9264e526102a080aed0ef56a14781726");
// 1459
geval("bigPipe.JSBNG__onPageletArrive({\n    phase: 2,\n    id: \"pagelet_ego_pane_w\",\n    jsmods: {\n        elements: [[\"m205539_1\",\"uq3jae_1\",2,],],\n        require: [[\"Arbiter\",\"inform\",[],[\"netego_loaded\",],],[\"PhotoEverstoreLogger\",\"registerForLogging\",[\"m205539_1\",],[{\n            __m: \"m205539_1\"\n        },],],]\n    },\n    css: [\"zO4BE\",],\n    js: [\"8gPM0\",\"bS0QP\",],\n    JSBNG__content: {\n        pagelet_ego_pane_w: {\n            container_id: \"uq3j16_21\"\n        }\n    }\n});");
// 1501
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"bigPipe.onPageletArrive({\n    phase: 2,\n    id: \"pagelet_sidebar\",\n    jsmods: {\n        instances: [[\"m205542_30\",[\"ScrollableArea\",\"m205542_29\",],[{\n            __m: \"m205542_29\"\n        },{\n            persistent: true\n        },],1,],[\"m205542_27\",[\"Typeahead\",\"m205543_36\",\"TypeaheadView\",\"ChatTypeaheadRenderer\",\"m205543_33\",\"ChatTypeaheadCore\",\"m205543_34\",],[{\n            __m: \"m205543_36\"\n        },{\n            node_id: \"uq3j16_22\",\n            ctor: {\n                __m: \"TypeaheadView\"\n            },\n            options: {\n                autoSelect: true,\n                renderer: {\n                    __m: \"ChatTypeaheadRenderer\"\n                },\n                causalElement: {\n                    __m: \"m205543_33\"\n                }\n            }\n        },{\n            ctor: {\n                __m: \"ChatTypeaheadCore\"\n            },\n            options: {\n                keepFocused: false,\n                resetOnSelect: true,\n                setValueOnSelect: false\n            }\n        },{\n            __m: \"m205543_34\"\n        },],7,],[\"m205543_38\",[\"ChatSidebarDropdown\",\"m205543_37\",],[{\n            __m: \"m205543_37\"\n        },],1,],[\"m205543_41\",[\"ContextualDialogX\",\"AccessibleLayer\",],[{\n            buildWrapper: false,\n            causalElement: null,\n            addedBehaviors: [{\n                __m: \"AccessibleLayer\"\n            },]\n        },],5,],[\"m205542_26\",[\"ChatOrderedList\",\"m205543_43\",\"m205543_44\",\"m205543_45\",\"m205543_41\",],[{\n            __m: \"m205543_43\"\n        },{\n            __m: \"m205543_44\"\n        },{\n            __m: \"m205543_45\"\n        },{\n            __m: \"m205543_41\"\n        },],5,],[\"m205542_28\",[\"LiveBar\",\"m205542_26\",],[{\n            __m: \"m205542_26\"\n        },[],[\"music\",\"canvas\",],],1,],[\"m205543_36\",[\"ChatTypeaheadDataSource\",],[{\n            showOfflineUsers: true\n        },],2,],[\"m205543_44\",[\"XHPTemplate\",\"m205543_46\",],[{\n            __m: \"m205543_46\"\n        },],2,],[\"m205543_45\",[\"XHPTemplate\",\"m205543_47\",],[{\n            __m: \"m205543_47\"\n        },],2,],],\n        markup: [[\"m205542_32\",{\n            __html: \"Hide sidebar\"\n        },2,],[\"m205543_40\",{\n            __html: \"Options\"\n        },2,],[\"m205543_42\",{\n            __html: \"\\u003Cdiv class=\\\"uiContextualDialogPositioner\\\" id=\\\"uq3j16_30\\\" data-position=\\\"left\\\"\\u003E\\u003Cdiv class=\\\"uiOverlay uiContextualDialog\\\" data-width=\\\"300\\\" data-destroyonhide=\\\"false\\\" data-fadeonhide=\\\"false\\\"\\u003E\\u003Cdiv class=\\\"uiOverlayContent\\\"\\u003E\\u003Cdiv class=\\\"uiContextualDialogContent\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205543_46\",{\n            __html: \"\\u003Cli class=\\\"item\\\"\\u003E\\u003Ca class=\\\"clearfix\\\" href=\\\"#\\\" rel=\\\"ignore\\\" data-jsid=\\\"anchor\\\"\\u003E\\u003Cimg class=\\\"pic\\\" src=\\\"/images/spacer.gif\\\" data-jsid=\\\"profile-photo\\\" /\\u003E\\u003Cdiv class=\\\"icons\\\"\\u003E\\u003Cimg class=\\\"lb_status icon img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/y4/r/-PAXP-deijE.gif\\\" alt=\\\"\\\" width=\\\"1\\\" height=\\\"1\\\" /\\u003E\\u003Cimg class=\\\"status icon img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/y4/r/-PAXP-deijE.gif\\\" alt=\\\"\\\" width=\\\"1\\\" height=\\\"1\\\" /\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"name\\\" data-jsid=\\\"name\\\"\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\"\n        },2,],[\"m205543_47\",{\n            __html: \"\\u003Cli\\u003E\\u003Cdiv class=\\\"phs fcg\\\"\\u003E\\u003Cspan data-jsid=\\\"message\\\"\\u003ELoading...\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/li\\u003E\"\n        },2,],],\n        elements: [[\"m205542_25\",\"uq3j16_23\",2,],[\"m205542_29\",\"uq3j16_24\",2,],[\"m205543_34\",\"uq3j16_25\",2,],[\"m205543_35\",\"uq3j16_26\",2,],[\"m205543_33\",\"uq3j16_28\",4,],[\"m205543_37\",\"uq3j16_29\",2,],[\"m205543_43\",\"uq3j16_31\",2,],[\"m205543_39\",\"uq3j16_32\",2,],[\"m205542_31\",\"uq3j16_33\",2,],],\n        define: [[\"ChatConfigInitialData\",[],{\n            chat_multi_typ_send: 1,\n            chat_realtime_coefficient_impressions: 1,\n            chat_sidebar_hovercards: true,\n            chat_tab_title_link_timeline: 1,\n            sidebar_ticker: 1,\n            \"video.skype_client_log\": 1,\n            \"video.collision_connect\": 1,\n            \"sidebar.minimum_width\": 1225,\n            \"sidebar.minimum_width_wide_content\": 1225,\n            sound_enabled: true,\n            typing_notifications: true,\n            \"ordered_list.available_target\": 3235,\n            \"ordered_list.top_friends\": 5,\n            \"sidebar.min_friends\": 7,\n            \"blackbird.min_for_clear_button\": 10,\n            tab_max_load_age: 86400000,\n            tab_auto_close_timeout: 86400000,\n            activity_limit: 60000,\n            idle_limit: 1800000,\n            idle_poll_interval: 300000,\n            livebar_fetch_defer: 1000,\n            warning_countdown_threshold_msec: 15000,\n            mute_warning_time_msec: 25000,\n            channel_manual_reconnect_defer_msec: 2000,\n            \"sound.notif_ogg_url\": \"http://static.ak.fbcdn.net/rsrc.php/yT/r/q-Drar4Ade6.ogg\",\n            \"sound.notif_mp3_url\": \"http://static.ak.fbcdn.net/rsrc.php/yb/r/VBbzpp2k5li.mp3\",\n            \"sound.ringtone_mp3_url\": \"http://static.ak.fbcdn.net/rsrc.php/yq/r/Mpd0-fRgh5n.mp3\",\n            \"24h_times\": false,\n            \"roger.seen_delay\": 15000\n        },],[\"OrderedFriendsListInitialData\",[],{\n            list: [\"1055580469\",]\n        },],[\"PresencePrivacyInitialData\",[],{\n            visibility: 0,\n            onlinePolicy: 1,\n            privacyData: {\n            }\n        },],],\n        require: [[\"ChatSidebar\",\"init\",[\"m205542_25\",\"m205542_26\",\"m205542_27\",],[{\n            __m: \"m205542_25\"\n        },{\n            __m: \"m205542_26\"\n        },{\n            __m: \"m205542_27\"\n        },],],[\"m205542_28\",],[\"m205542_30\",],[\"Tooltip\",\"set\",[\"m205542_31\",\"m205542_32\",],[{\n            __m: \"m205542_31\"\n        },{\n            __m: \"m205542_32\"\n        },],],[\"m205542_27\",],[\"Typeahead\",\"init\",[\"m205543_33\",\"m205542_27\",],[{\n            __m: \"m205543_33\"\n        },{\n            __m: \"m205542_27\"\n        },[\"chatTypeahead\",\"buildBestAvailableNames\",\"showLoadingIndicator\",],null,],],[\"ClearableTypeahead\",\"resetOnCloseButtonClick\",[\"m205542_27\",\"m205543_35\",],[{\n            __m: \"m205542_27\"\n        },{\n            __m: \"m205543_35\"\n        },],],[\"m205543_38\",],[\"Selector\",],[\"Tooltip\",\"set\",[\"m205543_39\",\"m205543_40\",],[{\n            __m: \"m205543_39\"\n        },{\n            __m: \"m205543_40\"\n        },],],[\"m205543_41\",],[\"Layer\",\"init\",[\"m205543_41\",\"m205543_42\",],[{\n            __m: \"m205543_41\"\n        },{\n            __m: \"m205543_42\"\n        },],],[\"m205542_26\",],]\n    },\n    css: [\"zO4BE\",\"gDKlQ\",\"z8dwT\",],\n    resource_map: {\n        tZ04z: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/ye/r/vA-yHMsd_d7.js\"\n        },\n        gDKlQ: {\n            type: \"css\",\n            permanent: 1,\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yk/r/m662RvSEcJq.css\"\n        }\n    },\n    js: [\"8gPM0\",\"bS0QP\",\"1zqwA\",\"tZ04z\",],\n    content: {\n        pagelet_sidebar: {\n            container_id: \"uq3j16_34\"\n        }\n    }\n});");
// 1502
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"sd8099575ab844423bea0b33e08f4d56fa6c490c7");
// 1503
geval("bigPipe.JSBNG__onPageletArrive({\n    phase: 2,\n    id: \"pagelet_sidebar\",\n    jsmods: {\n        instances: [[\"m205542_30\",[\"ScrollableArea\",\"m205542_29\",],[{\n            __m: \"m205542_29\"\n        },{\n            persistent: true\n        },],1,],[\"m205542_27\",[\"Typeahead\",\"m205543_36\",\"TypeaheadView\",\"ChatTypeaheadRenderer\",\"m205543_33\",\"ChatTypeaheadCore\",\"m205543_34\",],[{\n            __m: \"m205543_36\"\n        },{\n            node_id: \"uq3j16_22\",\n            ctor: {\n                __m: \"TypeaheadView\"\n            },\n            options: {\n                autoSelect: true,\n                renderer: {\n                    __m: \"ChatTypeaheadRenderer\"\n                },\n                causalElement: {\n                    __m: \"m205543_33\"\n                }\n            }\n        },{\n            ctor: {\n                __m: \"ChatTypeaheadCore\"\n            },\n            options: {\n                keepFocused: false,\n                resetOnSelect: true,\n                setValueOnSelect: false\n            }\n        },{\n            __m: \"m205543_34\"\n        },],7,],[\"m205543_38\",[\"ChatSidebarDropdown\",\"m205543_37\",],[{\n            __m: \"m205543_37\"\n        },],1,],[\"m205543_41\",[\"ContextualDialogX\",\"AccessibleLayer\",],[{\n            buildWrapper: false,\n            causalElement: null,\n            addedBehaviors: [{\n                __m: \"AccessibleLayer\"\n            },]\n        },],5,],[\"m205542_26\",[\"ChatOrderedList\",\"m205543_43\",\"m205543_44\",\"m205543_45\",\"m205543_41\",],[{\n            __m: \"m205543_43\"\n        },{\n            __m: \"m205543_44\"\n        },{\n            __m: \"m205543_45\"\n        },{\n            __m: \"m205543_41\"\n        },],5,],[\"m205542_28\",[\"LiveBar\",\"m205542_26\",],[{\n            __m: \"m205542_26\"\n        },[],[\"music\",\"canvas\",],],1,],[\"m205543_36\",[\"ChatTypeaheadDataSource\",],[{\n            showOfflineUsers: true\n        },],2,],[\"m205543_44\",[\"XHPTemplate\",\"m205543_46\",],[{\n            __m: \"m205543_46\"\n        },],2,],[\"m205543_45\",[\"XHPTemplate\",\"m205543_47\",],[{\n            __m: \"m205543_47\"\n        },],2,],],\n        markup: [[\"m205542_32\",{\n            __html: \"Hide sidebar\"\n        },2,],[\"m205543_40\",{\n            __html: \"Options\"\n        },2,],[\"m205543_42\",{\n            __html: \"\\u003Cdiv class=\\\"uiContextualDialogPositioner\\\" id=\\\"uq3j16_30\\\" data-position=\\\"left\\\"\\u003E\\u003Cdiv class=\\\"uiOverlay uiContextualDialog\\\" data-width=\\\"300\\\" data-destroyonhide=\\\"false\\\" data-fadeonhide=\\\"false\\\"\\u003E\\u003Cdiv class=\\\"uiOverlayContent\\\"\\u003E\\u003Cdiv class=\\\"uiContextualDialogContent\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205543_46\",{\n            __html: \"\\u003Cli class=\\\"item\\\"\\u003E\\u003Ca class=\\\"clearfix\\\" href=\\\"#\\\" rel=\\\"ignore\\\" data-jsid=\\\"anchor\\\"\\u003E\\u003Cimg class=\\\"pic\\\" src=\\\"/images/spacer.gif\\\" data-jsid=\\\"profile-photo\\\" /\\u003E\\u003Cdiv class=\\\"icons\\\"\\u003E\\u003Cimg class=\\\"lb_status icon img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/y4/r/-PAXP-deijE.gif\\\" alt=\\\"\\\" width=\\\"1\\\" height=\\\"1\\\" /\\u003E\\u003Cimg class=\\\"status icon img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/y4/r/-PAXP-deijE.gif\\\" alt=\\\"\\\" width=\\\"1\\\" height=\\\"1\\\" /\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"name\\\" data-jsid=\\\"name\\\"\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\"\n        },2,],[\"m205543_47\",{\n            __html: \"\\u003Cli\\u003E\\u003Cdiv class=\\\"phs fcg\\\"\\u003E\\u003Cspan data-jsid=\\\"message\\\"\\u003ELoading...\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/li\\u003E\"\n        },2,],],\n        elements: [[\"m205542_25\",\"uq3j16_23\",2,],[\"m205542_29\",\"uq3j16_24\",2,],[\"m205543_34\",\"uq3j16_25\",2,],[\"m205543_35\",\"uq3j16_26\",2,],[\"m205543_33\",\"uq3j16_28\",4,],[\"m205543_37\",\"uq3j16_29\",2,],[\"m205543_43\",\"uq3j16_31\",2,],[\"m205543_39\",\"uq3j16_32\",2,],[\"m205542_31\",\"uq3j16_33\",2,],],\n        define: [[\"ChatConfigInitialData\",[],{\n            chat_multi_typ_send: 1,\n            chat_realtime_coefficient_impressions: 1,\n            chat_sidebar_hovercards: true,\n            chat_tab_title_link_timeline: 1,\n            sidebar_ticker: 1,\n            \"video.skype_client_log\": 1,\n            \"video.collision_connect\": 1,\n            \"sidebar.minimum_width\": 1225,\n            \"sidebar.minimum_width_wide_content\": 1225,\n            sound_enabled: true,\n            typing_notifications: true,\n            \"ordered_list.available_target\": 3235,\n            \"ordered_list.top_friends\": 5,\n            \"sidebar.min_friends\": 7,\n            \"blackbird.min_for_clear_button\": 10,\n            tab_max_load_age: 86400000,\n            tab_auto_close_timeout: 86400000,\n            activity_limit: 60000,\n            idle_limit: 1800000,\n            idle_poll_interval: 300000,\n            livebar_fetch_defer: 1000,\n            warning_countdown_threshold_msec: 15000,\n            mute_warning_time_msec: 25000,\n            channel_manual_reconnect_defer_msec: 2000,\n            \"sound.notif_ogg_url\": \"http://static.ak.fbcdn.net/rsrc.php/yT/r/q-Drar4Ade6.ogg\",\n            \"sound.notif_mp3_url\": \"http://static.ak.fbcdn.net/rsrc.php/yb/r/VBbzpp2k5li.mp3\",\n            \"sound.ringtone_mp3_url\": \"http://static.ak.fbcdn.net/rsrc.php/yq/r/Mpd0-fRgh5n.mp3\",\n            \"24h_times\": false,\n            \"roger.seen_delay\": 15000\n        },],[\"OrderedFriendsListInitialData\",[],{\n            list: [\"1055580469\",]\n        },],[\"PresencePrivacyInitialData\",[],{\n            visibility: 0,\n            JSBNG__onlinePolicy: 1,\n            privacyData: {\n            }\n        },],],\n        require: [[\"ChatSidebar\",\"init\",[\"m205542_25\",\"m205542_26\",\"m205542_27\",],[{\n            __m: \"m205542_25\"\n        },{\n            __m: \"m205542_26\"\n        },{\n            __m: \"m205542_27\"\n        },],],[\"m205542_28\",],[\"m205542_30\",],[\"Tooltip\",\"set\",[\"m205542_31\",\"m205542_32\",],[{\n            __m: \"m205542_31\"\n        },{\n            __m: \"m205542_32\"\n        },],],[\"m205542_27\",],[\"Typeahead\",\"init\",[\"m205543_33\",\"m205542_27\",],[{\n            __m: \"m205543_33\"\n        },{\n            __m: \"m205542_27\"\n        },[\"chatTypeahead\",\"buildBestAvailableNames\",\"showLoadingIndicator\",],null,],],[\"ClearableTypeahead\",\"resetOnCloseButtonClick\",[\"m205542_27\",\"m205543_35\",],[{\n            __m: \"m205542_27\"\n        },{\n            __m: \"m205543_35\"\n        },],],[\"m205543_38\",],[\"Selector\",],[\"Tooltip\",\"set\",[\"m205543_39\",\"m205543_40\",],[{\n            __m: \"m205543_39\"\n        },{\n            __m: \"m205543_40\"\n        },],],[\"m205543_41\",],[\"Layer\",\"init\",[\"m205543_41\",\"m205543_42\",],[{\n            __m: \"m205543_41\"\n        },{\n            __m: \"m205543_42\"\n        },],],[\"m205542_26\",],]\n    },\n    css: [\"zO4BE\",\"gDKlQ\",\"z8dwT\",],\n    resource_map: {\n        tZ04z: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/ye/r/vA-yHMsd_d7.js\"\n        },\n        gDKlQ: {\n            type: \"css\",\n            permanent: 1,\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yk/r/m662RvSEcJq.css\"\n        }\n    },\n    js: [\"8gPM0\",\"bS0QP\",\"1zqwA\",\"tZ04z\",],\n    JSBNG__content: {\n        pagelet_sidebar: {\n            container_id: \"uq3j16_34\"\n        }\n    }\n});");
// 1570
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"bigPipe.onPageletArrive({\n    phase: 2,\n    id: \"pagelet_pinned_nav\",\n    jsmods: {\n        instances: [[\"m205544_49\",[\"MercuryLeftNav\",\"m205544_48\",],[{\n            __m: \"m205544_48\"\n        },{\n            message_counts: [{\n                unread_count: 0,\n                unseen_count: 0,\n                seen_timestamp: 0,\n                last_action_id: null,\n                folder: \"inbox\"\n            },],\n            payload_source: \"unknown\"\n        },],1,],],\n        elements: [[\"m205544_48\",\"navItem_app_217974574879787\",2,],],\n        require: [[\"m205544_49\",],]\n    },\n    css: [\"zO4BE\",],\n    js: [\"8gPM0\",\"bS0QP\",\"JOZ9R\",\"1zqwA\",\"28ZbA\",\"tZ04z\",],\n    requires: [\"pagelet_controller::home_side_future_nav\",],\n    onload: [\"FutureSideNav.getInstance().initSection({\\\"id\\\":\\\"pinnedNav\\\",\\\"editEndpoint\\\":\\\"\\\\/ajax\\\\/bookmark\\\\/edit\\\\/\\\"}, [{\\\"id\\\":\\\"navItem_app_156203961126022\\\",\\\"key\\\":[\\\"app_156203961126022\\\",\\\"welcome\\\"],\\\"path\\\":[\\\"\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_app_4748854339\\\",\\\"key\\\":[\\\"app_4748854339\\\",\\\"nf\\\",\\\"lf\\\",\\\"h\\\",\\\"h_chr\\\",\\\"h_nor\\\",\\\"h\\\",\\\"lf\\\",\\\"app_2915120374\\\",\\\"pp\\\",\\\"app_10150110253435258\\\"],\\\"path\\\":[\\\"\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":true,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_app_217974574879787\\\",\\\"key\\\":[\\\"app_217974574879787\\\",\\\"inbox\\\"],\\\"path\\\":[\\\"\\\\/messages\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[{\\\"id\\\":\\\"navItem_other\\\",\\\"key\\\":[\\\"other\\\"],\\\"path\\\":[\\\"\\\\/messages\\\\/other\\\\/\\\"],\\\"type\\\":null,\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]}]},{\\\"id\\\":\\\"navItem_app_2344061033\\\",\\\"key\\\":[\\\"app_2344061033\\\"],\\\"path\\\":[\\\"\\\\/events\\\\/list\\\",\\\"\\\\/events\\\\/\\\",{\\\"regex\\\":\\\"\\\\\\\\\\\\/events\\\\\\\\\\\\/!(friends|create)\\\\\\\\\\\\/\\\"}],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":null,\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_app_2356318349\\\",\\\"key\\\":[\\\"app_2356318349\\\",\\\"ff\\\"],\\\"path\\\":[\\\"\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]}]);\",],\n    onafterload: [\"startMessagingNavCountUpdater(\\\"100\\\");\",],\n    content: {\n        pagelet_pinned_nav: {\n            container_id: \"uq3j16_35\"\n        }\n    }\n});");
// 1571
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"sa6fad2edb1d3296c38f9332259b8ad9171968acf");
// 1572
geval("bigPipe.JSBNG__onPageletArrive({\n    phase: 2,\n    id: \"pagelet_pinned_nav\",\n    jsmods: {\n        instances: [[\"m205544_49\",[\"MercuryLeftNav\",\"m205544_48\",],[{\n            __m: \"m205544_48\"\n        },{\n            message_counts: [{\n                unread_count: 0,\n                unseen_count: 0,\n                seen_timestamp: 0,\n                last_action_id: null,\n                folder: \"inbox\"\n            },],\n            payload_source: \"unknown\"\n        },],1,],],\n        elements: [[\"m205544_48\",\"navItem_app_217974574879787\",2,],],\n        require: [[\"m205544_49\",],]\n    },\n    css: [\"zO4BE\",],\n    js: [\"8gPM0\",\"bS0QP\",\"JOZ9R\",\"1zqwA\",\"28ZbA\",\"tZ04z\",],\n    requires: [\"pagelet_controller::home_side_future_nav\",],\n    JSBNG__onload: [\"FutureSideNav.getInstance().initSection({\\\"id\\\":\\\"pinnedNav\\\",\\\"editEndpoint\\\":\\\"\\\\/ajax\\\\/bookmark\\\\/edit\\\\/\\\"}, [{\\\"id\\\":\\\"navItem_app_156203961126022\\\",\\\"key\\\":[\\\"app_156203961126022\\\",\\\"welcome\\\"],\\\"path\\\":[\\\"\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_app_4748854339\\\",\\\"key\\\":[\\\"app_4748854339\\\",\\\"nf\\\",\\\"lf\\\",\\\"h\\\",\\\"h_chr\\\",\\\"h_nor\\\",\\\"h\\\",\\\"lf\\\",\\\"app_2915120374\\\",\\\"pp\\\",\\\"app_10150110253435258\\\"],\\\"path\\\":[\\\"\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":true,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_app_217974574879787\\\",\\\"key\\\":[\\\"app_217974574879787\\\",\\\"inbox\\\"],\\\"path\\\":[\\\"\\\\/messages\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[{\\\"id\\\":\\\"navItem_other\\\",\\\"key\\\":[\\\"other\\\"],\\\"path\\\":[\\\"\\\\/messages\\\\/other\\\\/\\\"],\\\"type\\\":null,\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]}]},{\\\"id\\\":\\\"navItem_app_2344061033\\\",\\\"key\\\":[\\\"app_2344061033\\\"],\\\"path\\\":[\\\"\\\\/events\\\\/list\\\",\\\"\\\\/events\\\\/\\\",{\\\"regex\\\":\\\"\\\\\\\\\\\\/events\\\\\\\\\\\\/!(friends|create)\\\\\\\\\\\\/\\\"}],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":null,\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_app_2356318349\\\",\\\"key\\\":[\\\"app_2356318349\\\",\\\"ff\\\"],\\\"path\\\":[\\\"\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]}]);\",],\n    JSBNG__onafterload: [\"startMessagingNavCountUpdater(\\\"100\\\");\",],\n    JSBNG__content: {\n        pagelet_pinned_nav: {\n            container_id: \"uq3j16_35\"\n        }\n    }\n});");
// 1613
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"bigPipe.onPageletArrive({\n    phase: 2,\n    id: \"pagelet_bookmark_nav\",\n    is_last: true,\n    is_second_to_last_phase: true,\n    css: [\"zO4BE\",],\n    js: [\"8gPM0\",\"bS0QP\",\"JOZ9R\",\"1zqwA\",\"28ZbA\",],\n    requires: [\"pagelet_controller::home_side_future_nav\",],\n    onload: [\"FutureSideNav.getInstance().initSection({\\\"id\\\":\\\"appsNav\\\",\\\"editEndpoint\\\":null}, [{\\\"id\\\":\\\"navItem_app_140332009231\\\",\\\"key\\\":[\\\"app_140332009231\\\",\\\"games\\\"],\\\"path\\\":[\\\"\\\\/appcenter\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":null,\\\"selected\\\":false,\\\"children\\\":[{\\\"id\\\":\\\"navItem_appsandgames\\\",\\\"key\\\":[\\\"appsandgames\\\"],\\\"path\\\":[\\\"\\\\/apps\\\\/feed\\\"],\\\"type\\\":null,\\\"endpoint\\\":null,\\\"selected\\\":false,\\\"children\\\":[]}]},{\\\"id\\\":\\\"navItem_app_2305272732\\\",\\\"key\\\":[\\\"app_2305272732\\\",\\\"app_2305272732_2392950137\\\"],\\\"path\\\":[\\\"\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_app_119960514742544\\\",\\\"key\\\":[\\\"app_119960514742544\\\",\\\"music\\\"],\\\"path\\\":[\\\"\\\\/music\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_app_2347471856\\\",\\\"key\\\":[\\\"app_2347471856\\\",\\\"notes\\\"],\\\"path\\\":[\\\"\\\\/notes\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[{\\\"id\\\":\\\"navItem_notes_pages\\\",\\\"key\\\":[\\\"notes_pages\\\"],\\\"path\\\":[\\\"\\\\/notes\\\\/pages\\\\/\\\"],\\\"type\\\":null,\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_notes_drafts\\\",\\\"key\\\":[\\\"notes_drafts\\\"],\\\"path\\\":[\\\"\\\\/notes\\\\/drafts\\\\/\\\"],\\\"type\\\":null,\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_notes_tagged\\\",\\\"key\\\":[\\\"notes_tagged\\\"],\\\"path\\\":[\\\"\\\\/notes\\\\/tagged\\\\/\\\"],\\\"type\\\":null,\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_notes_me\\\",\\\"key\\\":[\\\"notes_me\\\"],\\\"path\\\":[\\\"\\\\/notes\\\\/me\\\\/\\\"],\\\"type\\\":null,\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]}]},{\\\"id\\\":\\\"navItem_app_2309869772\\\",\\\"key\\\":[\\\"app_2309869772\\\"],\\\"path\\\":[\\\"\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":null,\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_app_183217215062060\\\",\\\"key\\\":[\\\"app_183217215062060\\\",\\\"poke\\\"],\\\"path\\\":[\\\"\\\\/pokes\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]}]);\",\"FutureSideNav.getInstance().initSection({\\\"id\\\":\\\"groupsNav\\\",\\\"editEndpoint\\\":null}, [{\\\"id\\\":\\\"navItem_app_230259100322928\\\",\\\"key\\\":[\\\"app_230259100322928\\\",\\\"addgroup\\\"],\\\"path\\\":[\\\"\\\\/ajax\\\\/groups\\\\/create_get.php\\\"],\\\"type\\\":\\\"groups\\\",\\\"endpoint\\\":null,\\\"selected\\\":false,\\\"children\\\":[]}]);\",\"FutureSideNav.getInstance().initSection({\\\"id\\\":\\\"pagesNav\\\",\\\"editEndpoint\\\":null}, []);\",\"FutureSideNav.getInstance().initSection({\\\"id\\\":\\\"listsNav\\\",\\\"editEndpoint\\\":null}, [{\\\"id\\\":\\\"navItem_fl_196338550436560\\\",\\\"key\\\":[\\\"fl_196338550436560\\\"],\\\"path\\\":[\\\"\\\\/lists\\\\/196338550436560\\\"],\\\"type\\\":\\\"lists\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_fl_196338560436559\\\",\\\"key\\\":[\\\"fl_196338560436559\\\"],\\\"path\\\":[\\\"\\\\/lists\\\\/196338560436559\\\"],\\\"type\\\":\\\"lists\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_fl_350511818352565\\\",\\\"key\\\":[\\\"fl_350511818352565\\\"],\\\"path\\\":[\\\"\\\\/lists\\\\/350511818352565\\\"],\\\"type\\\":\\\"lists\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]}]);\",\"FutureSideNav.getInstance().initSection({\\\"id\\\":\\\"interestsNav\\\",\\\"editEndpoint\\\":null}, []);\",],\n    content: {\n        pagelet_bookmark_nav: {\n            container_id: \"uq3j16_36\"\n        }\n    }\n});");
// 1614
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"sf1f19f58f4ed73f872350e6d3787b32692845ad4");
// 1615
geval("bigPipe.JSBNG__onPageletArrive({\n    phase: 2,\n    id: \"pagelet_bookmark_nav\",\n    is_last: true,\n    is_second_to_last_phase: true,\n    css: [\"zO4BE\",],\n    js: [\"8gPM0\",\"bS0QP\",\"JOZ9R\",\"1zqwA\",\"28ZbA\",],\n    requires: [\"pagelet_controller::home_side_future_nav\",],\n    JSBNG__onload: [\"FutureSideNav.getInstance().initSection({\\\"id\\\":\\\"appsNav\\\",\\\"editEndpoint\\\":null}, [{\\\"id\\\":\\\"navItem_app_140332009231\\\",\\\"key\\\":[\\\"app_140332009231\\\",\\\"games\\\"],\\\"path\\\":[\\\"\\\\/appcenter\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":null,\\\"selected\\\":false,\\\"children\\\":[{\\\"id\\\":\\\"navItem_appsandgames\\\",\\\"key\\\":[\\\"appsandgames\\\"],\\\"path\\\":[\\\"\\\\/apps\\\\/feed\\\"],\\\"type\\\":null,\\\"endpoint\\\":null,\\\"selected\\\":false,\\\"children\\\":[]}]},{\\\"id\\\":\\\"navItem_app_2305272732\\\",\\\"key\\\":[\\\"app_2305272732\\\",\\\"app_2305272732_2392950137\\\"],\\\"path\\\":[\\\"\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_app_119960514742544\\\",\\\"key\\\":[\\\"app_119960514742544\\\",\\\"music\\\"],\\\"path\\\":[\\\"\\\\/music\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_app_2347471856\\\",\\\"key\\\":[\\\"app_2347471856\\\",\\\"notes\\\"],\\\"path\\\":[\\\"\\\\/notes\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[{\\\"id\\\":\\\"navItem_notes_pages\\\",\\\"key\\\":[\\\"notes_pages\\\"],\\\"path\\\":[\\\"\\\\/notes\\\\/pages\\\\/\\\"],\\\"type\\\":null,\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_notes_drafts\\\",\\\"key\\\":[\\\"notes_drafts\\\"],\\\"path\\\":[\\\"\\\\/notes\\\\/drafts\\\\/\\\"],\\\"type\\\":null,\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_notes_tagged\\\",\\\"key\\\":[\\\"notes_tagged\\\"],\\\"path\\\":[\\\"\\\\/notes\\\\/tagged\\\\/\\\"],\\\"type\\\":null,\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_notes_me\\\",\\\"key\\\":[\\\"notes_me\\\"],\\\"path\\\":[\\\"\\\\/notes\\\\/me\\\\/\\\"],\\\"type\\\":null,\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]}]},{\\\"id\\\":\\\"navItem_app_2309869772\\\",\\\"key\\\":[\\\"app_2309869772\\\"],\\\"path\\\":[\\\"\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":null,\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_app_183217215062060\\\",\\\"key\\\":[\\\"app_183217215062060\\\",\\\"poke\\\"],\\\"path\\\":[\\\"\\\\/pokes\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]}]);\",\"FutureSideNav.getInstance().initSection({\\\"id\\\":\\\"groupsNav\\\",\\\"editEndpoint\\\":null}, [{\\\"id\\\":\\\"navItem_app_230259100322928\\\",\\\"key\\\":[\\\"app_230259100322928\\\",\\\"addgroup\\\"],\\\"path\\\":[\\\"\\\\/ajax\\\\/groups\\\\/create_get.php\\\"],\\\"type\\\":\\\"groups\\\",\\\"endpoint\\\":null,\\\"selected\\\":false,\\\"children\\\":[]}]);\",\"FutureSideNav.getInstance().initSection({\\\"id\\\":\\\"pagesNav\\\",\\\"editEndpoint\\\":null}, []);\",\"FutureSideNav.getInstance().initSection({\\\"id\\\":\\\"listsNav\\\",\\\"editEndpoint\\\":null}, [{\\\"id\\\":\\\"navItem_fl_196338550436560\\\",\\\"key\\\":[\\\"fl_196338550436560\\\"],\\\"path\\\":[\\\"\\\\/lists\\\\/196338550436560\\\"],\\\"type\\\":\\\"lists\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_fl_196338560436559\\\",\\\"key\\\":[\\\"fl_196338560436559\\\"],\\\"path\\\":[\\\"\\\\/lists\\\\/196338560436559\\\"],\\\"type\\\":\\\"lists\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_fl_350511818352565\\\",\\\"key\\\":[\\\"fl_350511818352565\\\"],\\\"path\\\":[\\\"\\\\/lists\\\\/350511818352565\\\"],\\\"type\\\":\\\"lists\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]}]);\",\"FutureSideNav.getInstance().initSection({\\\"id\\\":\\\"interestsNav\\\",\\\"editEndpoint\\\":null}, []);\",],\n    JSBNG__content: {\n        pagelet_bookmark_nav: {\n            container_id: \"uq3j16_36\"\n        }\n    }\n});");
// 1658
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"bigPipe.onPageletArrive({\n    phase: 3,\n    id: \"pagelet_friends_online\",\n    jsmods: {\n        instances: [[\"m205552_52\",[\"ChatOnlineFriends\",\"m205552_53\",\"m205552_50\",\"m205552_51\",\"m205552_54\",],[20,{\n            __m: \"m205552_53\"\n        },{\n            __m: \"m205552_50\"\n        },{\n            __m: \"m205552_51\"\n        },{\n            __m: \"m205552_54\"\n        },null,null,],1,],[\"m205552_53\",[\"Typeahead\",\"m205553_58\",\"TypeaheadView\",\"ChatTypeaheadRenderer\",\"m205553_55\",\"ChatTypeaheadCore\",\"m205553_56\",],[{\n            __m: \"m205553_58\"\n        },{\n            node_id: \"uq3j16_37\",\n            ctor: {\n                __m: \"TypeaheadView\"\n            },\n            options: {\n                autoSelect: true,\n                renderer: {\n                    __m: \"ChatTypeaheadRenderer\"\n                },\n                causalElement: {\n                    __m: \"m205553_55\"\n                },\n                maxResults: 10\n            }\n        },{\n            ctor: {\n                __m: \"ChatTypeaheadCore\"\n            },\n            options: {\n                keepFocused: false,\n                resetOnSelect: true,\n                setValueOnSelect: false\n            }\n        },{\n            __m: \"m205553_56\"\n        },],7,],[\"m205552_54\",[\"XHPTemplate\",\"m205553_59\",],[{\n            __m: \"m205553_59\"\n        },],2,],[\"m205553_58\",[\"ChatTypeaheadDataSource\",],[{\n            maxResults: 10,\n            persistOnRefresh: false,\n            showOfflineUsers: true\n        },],2,],],\n        markup: [[\"m205553_59\",{\n            __html: \"\\u003Cli class=\\\"uiFacepileItem uiListItem uiListHorizontalItemBorder uiListHorizontalItem chatOnline\\\"\\u003E\\u003Ca class=\\\"link\\\" href=\\\"#\\\" data-jsid=\\\"anchor\\\"\\u003E\\u003Cimg class=\\\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__medium img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/y4/r/-PAXP-deijE.gif\\\" alt=\\\"\\\" data-jsid=\\\"img\\\" width=\\\"1\\\" height=\\\"1\\\" /\\u003E\\u003Cdiv class=\\\"chatStatus\\\"\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\"\n        },2,],],\n        elements: [[\"m205552_51\",\"uq3j16_39\",2,],[\"m205553_56\",\"uq3j16_40\",2,],[\"m205553_57\",\"uq3j16_41\",2,],[\"m205553_55\",\"uq3j16_43\",4,],[\"m205552_50\",\"chatFriendsOnline\",2,],],\n        require: [[\"m205552_52\",],[\"m205552_53\",],[\"Typeahead\",\"init\",[\"m205553_55\",\"m205552_53\",],[{\n            __m: \"m205553_55\"\n        },{\n            __m: \"m205552_53\"\n        },[\"chatTypeahead\",\"buildBestAvailableNames\",\"showLoadingIndicator\",],null,],],[\"ClearableTypeahead\",\"resetOnCloseButtonClick\",[\"m205552_53\",\"m205553_57\",],[{\n            __m: \"m205552_53\"\n        },{\n            __m: \"m205553_57\"\n        },],],]\n    },\n    css: [\"zO4BE\",],\n    js: [\"8gPM0\",\"bS0QP\",\"1zqwA\",\"tZ04z\",],\n    content: {\n        pagelet_friends_online: {\n            container_id: \"uq3j16_44\"\n        }\n    }\n});");
// 1659
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"sd93c98181080587724d6139bb26e1147e0e531c9");
// 1660
geval("bigPipe.JSBNG__onPageletArrive({\n    phase: 3,\n    id: \"pagelet_friends_online\",\n    jsmods: {\n        instances: [[\"m205552_52\",[\"ChatOnlineFriends\",\"m205552_53\",\"m205552_50\",\"m205552_51\",\"m205552_54\",],[20,{\n            __m: \"m205552_53\"\n        },{\n            __m: \"m205552_50\"\n        },{\n            __m: \"m205552_51\"\n        },{\n            __m: \"m205552_54\"\n        },null,null,],1,],[\"m205552_53\",[\"Typeahead\",\"m205553_58\",\"TypeaheadView\",\"ChatTypeaheadRenderer\",\"m205553_55\",\"ChatTypeaheadCore\",\"m205553_56\",],[{\n            __m: \"m205553_58\"\n        },{\n            node_id: \"uq3j16_37\",\n            ctor: {\n                __m: \"TypeaheadView\"\n            },\n            options: {\n                autoSelect: true,\n                renderer: {\n                    __m: \"ChatTypeaheadRenderer\"\n                },\n                causalElement: {\n                    __m: \"m205553_55\"\n                },\n                maxResults: 10\n            }\n        },{\n            ctor: {\n                __m: \"ChatTypeaheadCore\"\n            },\n            options: {\n                keepFocused: false,\n                resetOnSelect: true,\n                setValueOnSelect: false\n            }\n        },{\n            __m: \"m205553_56\"\n        },],7,],[\"m205552_54\",[\"XHPTemplate\",\"m205553_59\",],[{\n            __m: \"m205553_59\"\n        },],2,],[\"m205553_58\",[\"ChatTypeaheadDataSource\",],[{\n            maxResults: 10,\n            persistOnRefresh: false,\n            showOfflineUsers: true\n        },],2,],],\n        markup: [[\"m205553_59\",{\n            __html: \"\\u003Cli class=\\\"uiFacepileItem uiListItem uiListHorizontalItemBorder uiListHorizontalItem chatOnline\\\"\\u003E\\u003Ca class=\\\"link\\\" href=\\\"#\\\" data-jsid=\\\"anchor\\\"\\u003E\\u003Cimg class=\\\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__medium img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/y4/r/-PAXP-deijE.gif\\\" alt=\\\"\\\" data-jsid=\\\"img\\\" width=\\\"1\\\" height=\\\"1\\\" /\\u003E\\u003Cdiv class=\\\"chatStatus\\\"\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\"\n        },2,],],\n        elements: [[\"m205552_51\",\"uq3j16_39\",2,],[\"m205553_56\",\"uq3j16_40\",2,],[\"m205553_57\",\"uq3j16_41\",2,],[\"m205553_55\",\"uq3j16_43\",4,],[\"m205552_50\",\"chatFriendsOnline\",2,],],\n        require: [[\"m205552_52\",],[\"m205552_53\",],[\"Typeahead\",\"init\",[\"m205553_55\",\"m205552_53\",],[{\n            __m: \"m205553_55\"\n        },{\n            __m: \"m205552_53\"\n        },[\"chatTypeahead\",\"buildBestAvailableNames\",\"showLoadingIndicator\",],null,],],[\"ClearableTypeahead\",\"resetOnCloseButtonClick\",[\"m205552_53\",\"m205553_57\",],[{\n            __m: \"m205552_53\"\n        },{\n            __m: \"m205553_57\"\n        },],],]\n    },\n    css: [\"zO4BE\",],\n    js: [\"8gPM0\",\"bS0QP\",\"1zqwA\",\"tZ04z\",],\n    JSBNG__content: {\n        pagelet_friends_online: {\n            container_id: \"uq3j16_44\"\n        }\n    }\n});");
// 1665
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"bigPipe.onPageletArrive({\n    phase: 3,\n    id: \"pagelet_rhc_footer\",\n    jsmods: {\n        instances: [[\"m205553_60\",[\"MenuX\",\"MenuXItem\",\"m205553_61\",\"m205553_62\",\"m205553_63\",\"m205553_64\",\"m205553_65\",\"m205553_66\",],[\"uq3j16_45\",null,[{\n            href: \"http://www.facebook.com/facebook\",\n            title: \"\",\n            ctor: {\n                __m: \"MenuXItem\"\n            },\n            markup: {\n                __m: \"m205553_61\"\n            },\n            label: \"About\",\n            className: null\n        },{\n            href: \"http://www.facebook.com/campaign/landing.php?placement=pf_rhc_more&campaign_id=136808916455473&extra_1=auto\",\n            title: \"\",\n            ctor: {\n                __m: \"MenuXItem\"\n            },\n            markup: {\n                __m: \"m205553_62\"\n            },\n            label: \"Advertising\",\n            className: null\n        },{\n            href: \"http://www.facebook.com/careers/?ref=pf\",\n            title: \"\",\n            ctor: {\n                __m: \"MenuXItem\"\n            },\n            markup: {\n                __m: \"m205553_63\"\n            },\n            label: \"Careers\",\n            className: null\n        },{\n            href: \"http://www.facebook.com/pages/create.php?ref_type=sitefooter\",\n            title: \"\",\n            ctor: {\n                __m: \"MenuXItem\"\n            },\n            markup: {\n                __m: \"m205553_64\"\n            },\n            label: \"Create a Page\",\n            className: null\n        },{\n            href: \"http://developers.facebook.com/?ref=pf\",\n            title: \"\",\n            ctor: {\n                __m: \"MenuXItem\"\n            },\n            markup: {\n                __m: \"m205553_65\"\n            },\n            label: \"Developers\",\n            className: null\n        },{\n            href: \"http://www.facebook.com/help/?ref=pf\",\n            title: \"\",\n            ctor: {\n                __m: \"MenuXItem\"\n            },\n            markup: {\n                __m: \"m205553_66\"\n            },\n            label: \"Help\",\n            className: null\n        },],{\n            maxheight: null\n        },],3,],[\"m205553_68\",[\"PopoverMenu\",\"m205553_69\",\"m205553_67\",\"m205553_60\",],[{\n            __m: \"m205553_69\"\n        },{\n            __m: \"m205553_67\"\n        },{\n            __m: \"m205553_60\"\n        },[],],1,],[\"m205553_69\",[\"Popover\",\"m205553_70\",\"m205553_67\",\"ContextualLayerAutoFlip\",\"ContextualLayerUpdateOnScroll\",],[{\n            __m: \"m205553_70\"\n        },{\n            __m: \"m205553_67\"\n        },[{\n            __m: \"ContextualLayerAutoFlip\"\n        },{\n            __m: \"ContextualLayerUpdateOnScroll\"\n        },],{\n            alignh: \"right\",\n            layer_content: null\n        },],3,],],\n        markup: [[\"m205553_61\",{\n            __html: \"About\"\n        },2,],[\"m205553_62\",{\n            __html: \"Advertising\"\n        },2,],[\"m205553_63\",{\n            __html: \"Careers\"\n        },2,],[\"m205553_64\",{\n            __html: \"Create a Page\"\n        },2,],[\"m205553_65\",{\n            __html: \"Developers\"\n        },2,],[\"m205553_66\",{\n            __html: \"Help\"\n        },2,],],\n        elements: [[\"m205553_70\",\"rhc_footer_selector\",2,],[\"m205553_67\",\"uq3j16_46\",4,],],\n        require: [[\"m205553_60\",],[\"m205553_68\",],[\"m205553_69\",],]\n    },\n    css: [\"zO4BE\",],\n    js: [\"8gPM0\",\"bS0QP\",\"JOZ9R\",],\n    content: {\n        pagelet_rhc_footer: {\n            container_id: \"uq3j16_47\"\n        }\n    }\n});");
// 1666
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s196ba6ee04e545344c0c233ace6dd3060cfbd42f");
// 1667
geval("bigPipe.JSBNG__onPageletArrive({\n    phase: 3,\n    id: \"pagelet_rhc_footer\",\n    jsmods: {\n        instances: [[\"m205553_60\",[\"MenuX\",\"MenuXItem\",\"m205553_61\",\"m205553_62\",\"m205553_63\",\"m205553_64\",\"m205553_65\",\"m205553_66\",],[\"uq3j16_45\",null,[{\n            href: \"http://www.facebook.com/facebook\",\n            title: \"\",\n            ctor: {\n                __m: \"MenuXItem\"\n            },\n            markup: {\n                __m: \"m205553_61\"\n            },\n            label: \"About\",\n            className: null\n        },{\n            href: \"http://www.facebook.com/campaign/landing.php?placement=pf_rhc_more&campaign_id=136808916455473&extra_1=auto\",\n            title: \"\",\n            ctor: {\n                __m: \"MenuXItem\"\n            },\n            markup: {\n                __m: \"m205553_62\"\n            },\n            label: \"Advertising\",\n            className: null\n        },{\n            href: \"http://www.facebook.com/careers/?ref=pf\",\n            title: \"\",\n            ctor: {\n                __m: \"MenuXItem\"\n            },\n            markup: {\n                __m: \"m205553_63\"\n            },\n            label: \"Careers\",\n            className: null\n        },{\n            href: \"http://www.facebook.com/pages/create.php?ref_type=sitefooter\",\n            title: \"\",\n            ctor: {\n                __m: \"MenuXItem\"\n            },\n            markup: {\n                __m: \"m205553_64\"\n            },\n            label: \"Create a Page\",\n            className: null\n        },{\n            href: \"http://developers.facebook.com/?ref=pf\",\n            title: \"\",\n            ctor: {\n                __m: \"MenuXItem\"\n            },\n            markup: {\n                __m: \"m205553_65\"\n            },\n            label: \"Developers\",\n            className: null\n        },{\n            href: \"http://www.facebook.com/help/?ref=pf\",\n            title: \"\",\n            ctor: {\n                __m: \"MenuXItem\"\n            },\n            markup: {\n                __m: \"m205553_66\"\n            },\n            label: \"Help\",\n            className: null\n        },],{\n            maxheight: null\n        },],3,],[\"m205553_68\",[\"PopoverMenu\",\"m205553_69\",\"m205553_67\",\"m205553_60\",],[{\n            __m: \"m205553_69\"\n        },{\n            __m: \"m205553_67\"\n        },{\n            __m: \"m205553_60\"\n        },[],],1,],[\"m205553_69\",[\"Popover\",\"m205553_70\",\"m205553_67\",\"ContextualLayerAutoFlip\",\"ContextualLayerUpdateOnScroll\",],[{\n            __m: \"m205553_70\"\n        },{\n            __m: \"m205553_67\"\n        },[{\n            __m: \"ContextualLayerAutoFlip\"\n        },{\n            __m: \"ContextualLayerUpdateOnScroll\"\n        },],{\n            alignh: \"right\",\n            layer_content: null\n        },],3,],],\n        markup: [[\"m205553_61\",{\n            __html: \"About\"\n        },2,],[\"m205553_62\",{\n            __html: \"Advertising\"\n        },2,],[\"m205553_63\",{\n            __html: \"Careers\"\n        },2,],[\"m205553_64\",{\n            __html: \"Create a Page\"\n        },2,],[\"m205553_65\",{\n            __html: \"Developers\"\n        },2,],[\"m205553_66\",{\n            __html: \"Help\"\n        },2,],],\n        elements: [[\"m205553_70\",\"rhc_footer_selector\",2,],[\"m205553_67\",\"uq3j16_46\",4,],],\n        require: [[\"m205553_60\",],[\"m205553_68\",],[\"m205553_69\",],]\n    },\n    css: [\"zO4BE\",],\n    js: [\"8gPM0\",\"bS0QP\",\"JOZ9R\",],\n    JSBNG__content: {\n        pagelet_rhc_footer: {\n            container_id: \"uq3j16_47\"\n        }\n    }\n});");
// 1672
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"bigPipe.onPageletArrive({\n    phase: 3,\n    id: \"pagelet_megaphone\",\n    css: [\"zO4BE\",\"ccqBs\",],\n    resource_map: {\n        ccqBs: {\n            type: \"css\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yc/r/SjA8cv2-xH_.css\"\n        }\n    },\n    js: [\"8gPM0\",\"bS0QP\",\"6n1TR\",],\n    content: {\n        pagelet_megaphone: {\n            container_id: \"uq3j16_48\"\n        }\n    }\n});");
// 1673
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"sc95456688f0f7ab9d7a9e91f33c54640631b5ab7");
// 1674
geval("bigPipe.JSBNG__onPageletArrive({\n    phase: 3,\n    id: \"pagelet_megaphone\",\n    css: [\"zO4BE\",\"ccqBs\",],\n    resource_map: {\n        ccqBs: {\n            type: \"css\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yc/r/SjA8cv2-xH_.css\"\n        }\n    },\n    js: [\"8gPM0\",\"bS0QP\",\"6n1TR\",],\n    JSBNG__content: {\n        pagelet_megaphone: {\n            container_id: \"uq3j16_48\"\n        }\n    }\n});");
// 1686
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"bigPipe.onPageletArrive({\n    phase: 3,\n    id: \"fbRequestsList\",\n    jsmods: {\n        instances: [[\"m205556_72\",[\"ScrollableArea\",\"m205556_71\",],[{\n            __m: \"m205556_71\"\n        },{\n            persistent: true\n        },],1,],[\"m205556_74\",[\"StickyArea\",\"m205556_73\",],[{\n            __m: \"m205556_73\"\n        },],1,],],\n        elements: [[\"m205556_71\",\"uq3j16_49\",2,],[\"m205556_73\",\"uq3j16_50\",2,],],\n        require: [[\"m205556_72\",],[\"m205556_74\",],]\n    },\n    css: [\"zO4BE\",\"z8dwT\",],\n    js: [\"8gPM0\",\"bS0QP\",\"6n1TR\",],\n    onload: [\"window.presenceRequests && window.presenceRequests.fromDom()\",],\n    content: {\n        fbRequestsList: {\n            container_id: \"uq3j16_51\"\n        }\n    }\n});");
// 1687
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"sab64f6e8a6926d6a18583231b4027f93b6af645a");
// 1688
geval("bigPipe.JSBNG__onPageletArrive({\n    phase: 3,\n    id: \"fbRequestsList\",\n    jsmods: {\n        instances: [[\"m205556_72\",[\"ScrollableArea\",\"m205556_71\",],[{\n            __m: \"m205556_71\"\n        },{\n            persistent: true\n        },],1,],[\"m205556_74\",[\"StickyArea\",\"m205556_73\",],[{\n            __m: \"m205556_73\"\n        },],1,],],\n        elements: [[\"m205556_71\",\"uq3j16_49\",2,],[\"m205556_73\",\"uq3j16_50\",2,],],\n        require: [[\"m205556_72\",],[\"m205556_74\",],]\n    },\n    css: [\"zO4BE\",\"z8dwT\",],\n    js: [\"8gPM0\",\"bS0QP\",\"6n1TR\",],\n    JSBNG__onload: [\"window.presenceRequests && window.presenceRequests.fromDom()\",],\n    JSBNG__content: {\n        fbRequestsList: {\n            container_id: \"uq3j16_51\"\n        }\n    }\n});");
// 1693
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"bigPipe.onPageletArrive({\n    phase: 3,\n    id: \"pagelet_messages_data\",\n    jsmods: {\n        instances: [[\"m205556_75\",[\"XHPTemplate\",\"m205556_98\",],[{\n            __m: \"m205556_98\"\n        },],2,],[\"m205556_76\",[\"XHPTemplate\",\"m205556_99\",],[{\n            __m: \"m205556_99\"\n        },],2,],[\"m205556_77\",[\"XHPTemplate\",\"m205556_100\",],[{\n            __m: \"m205556_100\"\n        },],2,],[\"m205556_78\",[\"XHPTemplate\",\"m205556_101\",],[{\n            __m: \"m205556_101\"\n        },],2,],[\"m205556_79\",[\"XHPTemplate\",\"m205556_102\",],[{\n            __m: \"m205556_102\"\n        },],2,],[\"m205556_80\",[\"XHPTemplate\",\"m205556_103\",],[{\n            __m: \"m205556_103\"\n        },],2,],[\"m205556_81\",[\"XHPTemplate\",\"m205557_104\",],[{\n            __m: \"m205557_104\"\n        },],2,],[\"m205556_82\",[\"XHPTemplate\",\"m205557_105\",],[{\n            __m: \"m205557_105\"\n        },],2,],[\"m205556_83\",[\"XHPTemplate\",\"m205557_106\",],[{\n            __m: \"m205557_106\"\n        },],2,],[\"m205556_84\",[\"XHPTemplate\",\"m205557_107\",],[{\n            __m: \"m205557_107\"\n        },],2,],[\"m205556_85\",[\"XHPTemplate\",\"m205557_108\",],[{\n            __m: \"m205557_108\"\n        },],2,],[\"m205556_86\",[\"XHPTemplate\",\"m205557_109\",],[{\n            __m: \"m205557_109\"\n        },],2,],[\"m205556_87\",[\"XHPTemplate\",\"m205557_110\",],[{\n            __m: \"m205557_110\"\n        },],2,],[\"m205556_88\",[\"XHPTemplate\",\"m205557_111\",],[{\n            __m: \"m205557_111\"\n        },],2,],[\"m205556_89\",[\"XHPTemplate\",\"m205557_112\",],[{\n            __m: \"m205557_112\"\n        },],2,],[\"m205556_90\",[\"XHPTemplate\",\"m205557_113\",],[{\n            __m: \"m205557_113\"\n        },],2,],[\"m205556_91\",[\"XHPTemplate\",\"m205557_114\",],[{\n            __m: \"m205557_114\"\n        },],2,],[\"m205556_92\",[\"XHPTemplate\",\"m205557_115\",],[{\n            __m: \"m205557_115\"\n        },],2,],[\"m205556_93\",[\"XHPTemplate\",\"m205557_116\",],[{\n            __m: \"m205557_116\"\n        },],2,],[\"m205556_94\",[\"XHPTemplate\",\"m205557_117\",],[{\n            __m: \"m205557_117\"\n        },],2,],[\"m205556_95\",[\"XHPTemplate\",\"m205557_118\",],[{\n            __m: \"m205557_118\"\n        },],2,],[\"m205556_96\",[\"XHPTemplate\",\"m205557_119\",],[{\n            __m: \"m205557_119\"\n        },],2,],[\"m205556_97\",[\"XHPTemplate\",\"m205557_120\",],[{\n            __m: \"m205557_120\"\n        },],2,],],\n        markup: [[\"m205556_98\",{\n            __html: \"\\u003Cli\\u003E\\u003Ca class=\\\"messagesContent\\\" data-jsid=\\\"link\\\" href=\\\"#\\\"\\u003E\\u003Cdiv class=\\\"clearfix\\\"\\u003E\\u003Cdiv class=\\\"MercuryThreadImage -cx-PRIVATE-uiImageBlock__image -cx-PRIVATE-uiImageBlock__mediumImage lfloat\\\" data-jsid=\\\"image\\\"\\u003E\\u003Cimg class=\\\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__large img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" /\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"-cx-PRIVATE-uiImageBlock__content \\\"\\u003E\\u003Cdiv class=\\\"content fsm fwn fcg\\\"\\u003E\\u003Cdiv class=\\\"author\\\"\\u003E\\u003Cstrong data-jsid=\\\"name\\\"\\u003E\\u003C/strong\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"snippet preview fsm fwn fcg\\\"\\u003E\\u003Cspan data-jsid=\\\"snippet\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"time\\\"\\u003E\\u003Cabbr title=\\\"Wednesday, December 31, 1969 at 7:00pm\\\" data-utime=\\\"0\\\" class=\\\"hidden_elem timestamp\\\" data-jsid=\\\"timestamp\\\"\\u003Eover a year ago\\u003C/abbr\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\"\n        },2,],[\"m205556_99\",{\n            __html: \"\\u003Cdiv class=\\\"attachment\\\"\\u003E\\u003Cspan class=\\\"uiIconText MercuryThreadlistIconError\\\" data-jsid=\\\"error\\\"\\u003E\\u003Ci class=\\\"img sp_627qpw sx_ca6d8d\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205556_100\",{\n            __html: \"\\u003Cdiv class=\\\"attachment\\\"\\u003E\\u003Cdiv class=\\\"clearfix MercuryExternalLink\\\"\\u003E\\u003Cdiv class=\\\"lfloat\\\" data-jsid=\\\"preview\\\"\\u003E\\u003Ca data-jsid=\\\"image-link\\\" href=\\\"#\\\" target=\\\"_blank\\\"\\u003E\\u003Cimg data-jsid=\\\"preview-image\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" class=\\\"hidden_elem\\\" /\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"MercuryLinkRight rfloat\\\"\\u003E\\u003Cdiv class=\\\"MercuryLinkTitle\\\"\\u003E\\u003Ca class=\\\"linkTitle\\\" target=\\\"_blank\\\" href=\\\"#\\\" data-jsid=\\\"name\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fsm fwn fcg\\\" data-jsid=\\\"shortLink\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205556_101\",{\n            __html: \"\\u003Cdiv class=\\\"attachment fileAttachment\\\"\\u003E\\u003Ca class=\\\"uiIconText\\\" href=\\\"#\\\" data-jsid=\\\"link\\\"\\u003E\\u003Ci class=\\\"img sp_46s4tm sx_3bc2c4\\\"\\u003E\\u003C/i\\u003E\\u003Cspan data-jsid=\\\"filename\\\" class=\\\"filename\\\"\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205556_102\",{\n            __html: \"\\u003Cdiv class=\\\"attachment fileAttachment\\\"\\u003E\\u003Cdiv class=\\\"clearfix\\\"\\u003E\\u003Ca class=\\\"uiIconText lfloat\\\" href=\\\"#\\\" data-jsid=\\\"link\\\"\\u003E\\u003Ci class=\\\"img sp_46s4tm sx_3bc2c4\\\"\\u003E\\u003C/i\\u003E\\u003Cspan class=\\\"filename\\\" data-jsid=\\\"filename\\\"\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"fileLinks rfloat\\\"\\u003E\\u003Cdiv data-jsid=\\\"openLinkContainer\\\" class=\\\"openLinkContainer hidden_elem\\\"\\u003E\\u003Ca class=\\\"openFileLink\\\" href=\\\"#\\\" data-jsid=\\\"openFile\\\"\\u003Eopen\\u003C/a\\u003E \\u00b7 \\u003C/div\\u003E\\u003Ca class=\\\"downloadFileLink\\\" href=\\\"#\\\" data-jsid=\\\"downloadFile\\\"\\u003Edownload\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205556_103\",{\n            __html: \"\\u003Cdiv class=\\\"musicAttachment\\\"\\u003E\\u003Cdiv class=\\\"attachment fileAttachment\\\" data-jsid=\\\"icon_link\\\"\\u003E\\u003Ca class=\\\"uiIconText\\\" href=\\\"#\\\" data-jsid=\\\"link\\\"\\u003E\\u003Ci class=\\\"img sp_46s4tm sx_3bc2c4\\\"\\u003E\\u003C/i\\u003E\\u003Cspan data-jsid=\\\"filename\\\" class=\\\"filename\\\"\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv data-jsid=\\\"preview\\\"\\u003E\\u003Ca data-jsid=\\\"image-link\\\" href=\\\"#\\\" target=\\\"_blank\\\"\\u003E\\u003Cimg data-jsid=\\\"preview-image\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" class=\\\"hidden_elem\\\" /\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205557_104\",{\n            __html: \"\\u003Cdiv\\u003E\\u003Ca data-jsid=\\\"image-link\\\" href=\\\"#\\\" target=\\\"_blank\\\"\\u003E\\u003Cimg data-jsid=\\\"preview-image\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" class=\\\"hidden_elem\\\" /\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205557_105\",{\n            __html: \"\\u003Cdiv class=\\\"attachment\\\"\\u003E\\u003Ca data-jsid=\\\"link\\\" target=\\\"_blank\\\" href=\\\"#\\\"\\u003E\\u003Cspan data-jsid=\\\"name\\\"\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205557_106\",{\n            __html: \"\\u003Cdiv class=\\\"attachment\\\"\\u003E\\u003Ca class=\\\"uiVideoThumb videoPreview\\\" href=\\\"#\\\" data-jsid=\\\"thumb\\\"\\u003E\\u003Cimg class=\\\"img\\\" alt=\\\"\\\" /\\u003E\\u003Ci\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205557_107\",{\n            __html: \"\\u003Cdiv class=\\\"-cx-PRIVATE-mercuryComposer__composerSupplemental -cx-PRIVATE-mercuryComposer__uploadFileRow\\\"\\u003E\\u003Cspan class=\\\"uiIconText MercuryThreadlistIconText\\\" data-jsid=\\\"iconText\\\"\\u003E\\u003Ci class=\\\"img sp_46s4tm sx_3bc2c4\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u003Cimg class=\\\"-cx-PRIVATE-mercuryComposer__uploadingIndicator img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Clabel class=\\\"-cx-PRIVATE-mercuryComposer__closeFileUpload uiCloseButton uiCloseButtonSmall uiCloseButtonSmallDark\\\" for=\\\"uq3j16_52\\\"\\u003E\\u003Cinput title=\\\"Remove\\\" type=\\\"button\\\" data-jsid=\\\"closeFileUpload\\\" id=\\\"uq3j16_52\\\" /\\u003E\\u003C/label\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205557_108\",{\n            __html: \"\\u003Cimg class=\\\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__large img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" alt=\\\"\\\" /\\u003E\"\n        },2,],[\"m205557_109\",{\n            __html: \"\\u003Cimg class=\\\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__large img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" alt=\\\"\\\" /\\u003E\"\n        },2,],[\"m205557_110\",{\n            __html: \"\\u003Cimg class=\\\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__medium img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" alt=\\\"\\\" /\\u003E\"\n        },2,],[\"m205557_111\",{\n            __html: \"\\u003Cspan class=\\\"uiSplitPics clearfix\\\"\\u003E\\u003Cspan class=\\\"uiSplitPic leftThree\\\"\\u003E\\u003Cimg class=\\\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__large img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" alt=\\\"\\\" data-jsid=\\\"left\\\" /\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"uiSplitPic rTop\\\"\\u003E\\u003Cimg class=\\\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__small img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" alt=\\\"\\\" data-jsid=\\\"topRight\\\" /\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"uiSplitPic rBottom\\\"\\u003E\\u003Cimg class=\\\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__small img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" alt=\\\"\\\" data-jsid=\\\"bottomRight\\\" /\\u003E\\u003C/span\\u003E\\u003C/span\\u003E\"\n        },2,],[\"m205557_112\",{\n            __html: \"\\u003Ci class=\\\"mrs MercuryThreadlistIcon img sp_46s4tm sx_b35b84\\\"\\u003E\\u003C/i\\u003E\"\n        },2,],[\"m205557_113\",{\n            __html: \"\\u003Cspan class=\\\"uiIconText MercuryThreadlistIconText\\\"\\u003E\\u003Ci class=\\\"img sp_46s4tm sx_3bc2c4\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\"\n        },2,],[\"m205557_114\",{\n            __html: \"\\u003Ci class=\\\"mercuryStatusIndicator mercuryErrorIndicator img sp_ae80w4 sx_e17869\\\"\\u003E\\u003C/i\\u003E\"\n        },2,],[\"m205557_115\",{\n            __html: \"\\u003Ci class=\\\"mercuryStatusIndicator img sp_46s4tm sx_93bdc2\\\"\\u003E\\u003C/i\\u003E\"\n        },2,],[\"m205557_116\",{\n            __html: \"\\u003Cdiv class=\\\"uiTypeahead\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" class=\\\"hiddenInput\\\" /\\u003E\\u003Cdiv class=\\\"innerWrap\\\"\\u003E\\u003Cinput type=\\\"text\\\" class=\\\"inputtext textInput\\\" data-jsid=\\\"textfield\\\" /\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205557_117\",{\n            __html: \"\\u003Cdiv class=\\\"clearfix uiTokenizer uiInlineTokenizer\\\"\\u003E\\u003Cdiv class=\\\"tokenarea hidden_elem\\\" data-jsid=\\\"tokenarea\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205557_118\",{\n            __html: \"\\u003Cli class=\\\"-cx-PRIVATE-mercuryTypeahead__header typeaheadHeader uiListItem uiListLight uiListVerticalItemBorder\\\"\\u003E\\u003Cdiv class=\\\"clearfix\\\"\\u003E\\u003Cdiv class=\\\"lfloat\\\"\\u003E\\u003Cspan data-jsid=\\\"text\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Ca class=\\\"showAllLink rfloat\\\" data-jsid=\\\"link\\\" href=\\\"#\\\"\\u003EShow All\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/li\\u003E\"\n        },2,],[\"m205557_119\",{\n            __html: \"\\u003Cli class=\\\"-cx-PRIVATE-mercuryTypeahead__row uiListItem  uiListVerticalItemBorder\\\"\\u003E\\u003Cdiv class=\\\"clearfix pvs\\\"\\u003E\\u003Cdiv class=\\\"MercuryThreadImage mrm lfloat\\\" data-jsid=\\\"image\\\"\\u003E\\u003Cimg class=\\\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__large img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" /\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"-cx-PRIVATE-mercuryTypeahead__rightContent\\\"\\u003E\\u003Cspan class=\\\"-cx-PRIVATE-mercuryTypeahead__name\\\" data-jsid=\\\"name\\\"\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"-cx-PRIVATE-mercuryTypeahead__snippet fsm fwn fcg\\\" data-jsid=\\\"snippet\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/li\\u003E\"\n        },2,],[\"m205557_120\",{\n            __html: \"\\u003Cdiv class=\\\"UIImageBlock clearfix\\\"\\u003E\\u003Cimg class=\\\"mrm -cx-PRIVATE-uiSquareImage__root UIImageBlock_Image UIImageBlock_ICON_Image -cx-PRIVATE-uiSquareImage__large img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" alt=\\\"\\\" data-jsid=\\\"profilePhoto\\\" /\\u003E\\u003Cdiv class=\\\"UIImageBlock_Content UIImageBlock_ICON_Content\\\"\\u003E\\u003Cdiv class=\\\"mbs fsl fwb fcb\\\" data-jsid=\\\"mainText\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"aux-message fcg\\\" data-jsid=\\\"auxMessage\\\"\\u003EVideo will start as soon as you answer.\\u003C/div\\u003E\\u003Cdiv class=\\\"mts hidden_elem fcg\\\" data-jsid=\\\"slowMessage\\\"\\u003E\\u003Cspan class=\\\"fwb fcb\\\"\\u003EHaving trouble?\\u003C/span\\u003E Your connection may be \\u003Ca href=\\\"/help/?faq=214265948627885&amp;in_context=1\\\" target=\\\"_blank\\\"\\u003Etoo slow\\u003C/a\\u003E.\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],],\n        define: [[\"MercuryJewelTemplates\",[\"m205556_75\",],{\n            \":fb:mercury:jewel:threadlist-row\": {\n                __m: \"m205556_75\"\n            }\n        },],[\"MercuryAttachmentTemplates\",[\"m205556_76\",\"m205556_77\",\"m205556_78\",\"m205556_79\",\"m205556_80\",\"m205556_81\",\"m205556_82\",\"m205556_83\",\"m205556_84\",],{\n            \":fb:mercury:attachment:error\": {\n                __m: \"m205556_76\"\n            },\n            \":fb:mercury:attachment:external-link\": {\n                __m: \"m205556_77\"\n            },\n            \":fb:mercury:attachment:file-link\": {\n                __m: \"m205556_78\"\n            },\n            \":fb:mercury:attachment:extended-file-link\": {\n                __m: \"m205556_79\"\n            },\n            \":fb:mercury:attachment:music\": {\n                __m: \"m205556_80\"\n            },\n            \":fb:mercury:attachment:preview\": {\n                __m: \"m205556_81\"\n            },\n            \":fb:mercury:attachment:share-link\": {\n                __m: \"m205556_82\"\n            },\n            \":fb:mercury:attachment:video-thumb\": {\n                __m: \"m205556_83\"\n            },\n            \":fb:mercury:upload-file-row\": {\n                __m: \"m205556_84\"\n            }\n        },],[\"MercuryImageTemplates\",[\"m205556_85\",\"m205556_86\",\"m205556_87\",\"m205556_88\",],{\n            \":fb:mercury:thread-image:single\": {\n                __m: \"m205556_85\"\n            },\n            \":fb:mercury:thread-image:single:large\": {\n                __m: \"m205556_86\"\n            },\n            \":fb:mercury:thread-image:single:medium\": {\n                __m: \"m205556_87\"\n            },\n            \":fb:mercury:thread-image:split\": {\n                __m: \"m205556_88\"\n            }\n        },],[\"MercuryThreadlistIconTemplates\",[\"m205556_89\",\"m205556_90\",],{\n            \":fb:mercury:attachment-indicator\": {\n                __m: \"m205556_89\"\n            },\n            \":fb:mercury:attachment-icon-text\": {\n                __m: \"m205556_90\"\n            }\n        },],[\"MercuryStatusTemplates\",[\"m205556_91\",\"m205556_92\",],{\n            \":fb:mercury:error-indicator\": {\n                __m: \"m205556_91\"\n            },\n            \":fb:mercury:resend-indicator\": {\n                __m: \"m205556_92\"\n            }\n        },],[\"MercuryTypeaheadTemplates\",[\"m205556_93\",\"m205556_94\",\"m205556_95\",\"m205556_96\",],{\n            \":fb:mercury:typeahead\": {\n                __m: \"m205556_93\"\n            },\n            \":fb:mercury:tokenizer\": {\n                __m: \"m205556_94\"\n            },\n            \":fb:mercury:typeahead:header\": {\n                __m: \"m205556_95\"\n            },\n            \":fb:mercury:typeahead:result\": {\n                __m: \"m205556_96\"\n            }\n        },],[\"VideoCallTemplates\",[\"m205556_97\",],{\n            \":fb:videocall:incoming-dialog\": {\n                __m: \"m205556_97\"\n            }\n        },],[\"MercuryConstants\",[],{\n            MercuryActionType: {\n                LOG_MESSAGE: \"ma-type:log-message\",\n                USER_GENERATED_MESSAGE: \"ma-type:user-generated-message\",\n                CHANGE_READ_STATUS: \"ma-type:change_read_status\",\n                CLEAR_CHAT: \"ma-type:clear_chat\",\n                SEND_MESSAGE: \"ma-type:send-message\",\n                UPDATE_ACTION_ID: \"ma-type:update-action-id\",\n                DELETE_MESSAGES: \"ma-type:delete-messages\",\n                DELETE_THREAD: \"ma-type:delete-thread\",\n                CHANGE_ARCHIVED_STATUS: \"ma-type:change-archived-status\",\n                CHANGE_FOLDER: \"ma-type:change-folder\"\n            },\n            MercuryGlobalActionType: {\n                MARK_ALL_READ: \"mga-type:mark-all-read\"\n            },\n            MercuryLogMessageType: {\n                SUBSCRIBE: \"log:subscribe\",\n                UNSUBSCRIBE: \"log:unsubscribe\",\n                VIDEO_CALL: \"log:video-call\",\n                THREAD_NAME: \"log:thread-name\",\n                THREAD_IMAGE: \"log:thread-image\",\n                SERVER_ERROR: \"log:error-msg\",\n                LIVE_LISTEN: \"log:live-listen\"\n            },\n            MercuryPayloadSource: {\n                UNKNOWN: \"unknown\",\n                CLIENT_CHANNEL_MESSAGE: \"client_channel_message\",\n                CLIENT_SEND_MESSAGE: \"client_send_message\",\n                CLIENT_CHANGE_ARCHIVED_STATUS: \"client_change-archived_status\",\n                CLIENT_CHANGE_FOLDER: \"client_change_folder\",\n                CLIENT_CHANGE_READ_STATUS: \"client_change_read_status\",\n                CLIENT_CLEAR_CHAT: \"client_clear_chat\",\n                CLIENT_DELETE_MESSAGES: \"client_delete_messages\",\n                CLIENT_DELETE_THREAD: \"client_delete_thread\",\n                CLIENT_HANDLE_ERROR: \"client_handle_error\",\n                SERVER_INITIAL_DATA: \"server_initial_data\",\n                SERVER_SEND_MESSAGE: \"server_send_message\",\n                SERVER_CONFIRM_MESSAGES: \"server_confirm_messages\",\n                SERVER_CHANGE_ARCHIVED_STATUS: \"server_change_archived_status\",\n                SERVER_CHANGE_READ_STATUS: \"server_change_read_status\",\n                SERVER_MARK_FOLDER_READ: \"server_mark_folder_read\",\n                SERVER_MARK_SEEN: \"server_mark_seen\",\n                SERVER_FETCH_THREAD_INFO: \"server_fetch_thread_info\",\n                SERVER_FETCH_THREADLIST_INFO: \"server_fetch_threadlist_info\",\n                SERVER_THREAD_SYNC: \"server_thread_sync\",\n                SERVER_TAB_PRESENCE: \"server_tab_presence\",\n                SERVER_UNREAD_THREADS: \"server_unread_threads\",\n                SERVER_SEARCH: \"server_search\"\n            },\n            MercuryMessageSourceTags: {\n                CHAT: \"source:chat\",\n                EMAIL: \"source:email\",\n                MESSENGER: \"source:messenger\",\n                MOBILE: \"source:mobile\"\n            },\n            MercurySourceType: {\n                CHAT_ORCA: \"source:chat:orca\",\n                CHAT_IPHONE: \"source:chat:iphone\",\n                CHAT_JABBER: \"source:chat:jabber\",\n                CHAT_MEEBO: \"source:chat:meebo\",\n                CHAT_WEB: \"source:chat:web\",\n                CHAT_TEST: \"source:chat:test\",\n                CHAT: \"source:chat\",\n                DESKTOP: \"source:desktop\",\n                EMAIL: \"source:email\",\n                GIGABOXX_API: \"source:gigaboxx:api\",\n                GIGABOXX_BLAST: \"source:gigaboxx:blast\",\n                GIGABOXX_EMAIL_REPLY: \"source:gigaboxx:emailreply\",\n                GIGABOXX_MOBILE: \"source:gigaboxx:mobile\",\n                GIGABOXX_WAP: \"source:gigaboxx:wap\",\n                GIGABOXX_WEB: \"source:gigaboxx:web\",\n                SHARE_DIALOG: \"source:share:dialog\",\n                SEND_PLUGIN: \"source:sendplugin\",\n                SMS: \"source:sms\",\n                TEST: \"source:test\",\n                TITAN_WAP: \"source:titan:wap\",\n                TITAN_M_AJAX: \"source:titan:m_ajax\",\n                TITAN_M_BASIC: \"source:titan:m_basic\",\n                TITAN_M_JAPAN: \"source:titan:m_japan\",\n                TITAN_M_MINI: \"source:titan:m_mini\",\n                TITAN_M_TOUCH: \"source:titan:m_touch\",\n                TITAN_M_ZERO: \"source:titan:m_zero\",\n                TITAN_WEB: \"source:titan:web\",\n                TITAN_API: \"source:titan:api\",\n                TITAN_API_MOBILE: \"source:titan:api_mobile\",\n                TITAN_ORCA: \"source:titan:orca\",\n                TITAN_EMAIL_REPLY: \"source:titan:emailreply\",\n                MOBILE: \"source:mobile\",\n                UNKNOWN: \"source:unknown\",\n                WEB: \"source:web\",\n                HELPCENTER: \"source:helpcenter\",\n                NEW_SHARE_DIALOG: \"source:share:dialog:new\",\n                PAID_PROMOTION: \"source:paid_promotion\",\n                BUFFY_SMS: \"source:buffy:sms\"\n            },\n            MercurySupportedShareType: {\n                FB_PHOTO: 2,\n                FB_ALBUM: 3,\n                FB_VIDEO: 11,\n                FB_SONG: 28,\n                FB_MUSIC_ALBUM: 30,\n                EXTERNAL: 100,\n                FB_TEMPLATE: 300\n            },\n            MercuryThreadlistConstants: {\n                RECENT_THREAD_OFFSET: 0,\n                JEWEL_THREAD_COUNT: 5,\n                WEBMESSENGER_THREAD_COUNT: 20,\n                WEBMESSENGER_MORE_COUNT: 20,\n                WEBMESSENGER_SEARCH_SNIPPET_COUNT: 5,\n                WEBMESSENGER_SEARCH_SNIPPET_LIMIT: 5,\n                WEBMESSENGER_SEARCH_SNIPPET_MORE: 5,\n                WEBMESSENGER_MORE_MESSAGES_COUNT: 20,\n                RECENT_MESSAGES_LIMIT: 10,\n                MAX_UNREAD_COUNT: 99,\n                MAX_UNSEEN_COUNT: 99,\n                GROUPING_THRESHOLD: 300000,\n                MESSAGE_TIMESTAMP_THRESHOLD: 1209600000,\n                SEARCH_TAB: \"searchtab\"\n            },\n            MessagingEventTypes: {\n                DELETE: \"delete\",\n                DELETE_MESSAGES: \"delete_messages\",\n                DELIVER: \"deliver\",\n                ERROR: \"error\",\n                READ: \"read\",\n                REPORT_SPAM: \"report_spam\",\n                UNMARK_SPAM: \"unmark_spam\",\n                SUBSCRIBE: \"subscribe\",\n                TAG: \"tag\",\n                UNREAD: \"unread\",\n                UNSUBSCRIBE: \"unsubscribe\",\n                DELIVER_LOG: \"deliver_log\",\n                MORE_THREADS: \"more_threads\",\n                READ_ALL: \"read_all\",\n                READ_RECEIPT: \"read_receipt\",\n                DELIVERY_RECEIPT: \"delivery_receipt\",\n                SENT_PUSH: \"sent_push\",\n                DELIVER_FAST_PAST: \"deliver_fast_path\"\n            },\n            MercuryActionStatus: {\n                UNSENT: 0,\n                SUCCESS: 1,\n                REQUEST_ERROR: 2,\n                UNCONFIRMED: 3,\n                FAILED_UNKNOWN_REASON: 4,\n                UNABLE_TO_CONFIRM: 5,\n                RESENT: 6,\n                RESENDING: 7,\n                REQUEST_EMPTY_MESSAGE_LIST: 8,\n                TRANSPORT_ERROR: 9\n            },\n            MessagingTag: {\n                ACTION_ARCHIVED: \"action:archived\",\n                INBOX: \"inbox\",\n                OTHER: \"other\",\n                EVENT: \"event\",\n                SENT: \"sent\",\n                SMS_MUTE: \"sms_mute\",\n                SPAM: \"spam\",\n                UPDATES: \"broadcasts_inbox\",\n                BCC: \"header:bcc\",\n                UNREAD: \"unread\",\n                ARCHIVED: \"archived\",\n                EMAIL: \"email\",\n                VOICEMAIL: \"voicemail\",\n                SPAM_SPOOFING: \"spam:spoofing\",\n                SPOOF_WARNING: \"MTA:spoof_warning\",\n                SMS_TAG_ROOT: \"SMSShortcode:\",\n                APP_ID_ROOT: \"app_id:\",\n                DOMAIN_AUTH_PASS: \"MTA:dmarc:pass\",\n                DOMAIN_AUTH_FAIL: \"MTA:dmarc:fail\",\n                MTA_SYSTEM_MESSAGE: \"MTA:system_message\"\n            },\n            VideoChatConstants: {\n                START_SESSION: 1,\n                GET_SKYPE_TOKEN: 2,\n                AWAITING_CALL: 3,\n                CANCELLED_CALL: 4,\n                CONNECTED_CALL: 5,\n                HANDLED_CALL: 6,\n                GOT_START_SESSION: 7,\n                INSTALLING: 8,\n                INSTALLED: 9,\n                INSTALL_CANCELED: 10,\n                ASSOC_CONNECTED_CALL: 118224944915447,\n                ASSOC_VIEWED_CALL_PROMO: 250568041676842,\n                MAX_VC_PROMO_VIEWS: 2,\n                MINIMUM_VC_PROMO_VIEW_INTERVAL: 5184000,\n                MINIMUM_VC_LAST_CALLED_INTERVAL: 5184000\n            },\n            MercuryAttachmentType: {\n                ERROR: \"error\",\n                FILE: \"file\",\n                SHARE: \"share\"\n            },\n            MercuryAttachmentContentType: {\n                PHOTO: \"attach:image\",\n                VIDEO: \"attach:video\",\n                MUSIC: \"attach:music\",\n                TEXT: \"attach:text\",\n                MSWORD: \"attach:ms:word\",\n                MSXLS: \"attach:ms:xls\",\n                MSPPT: \"attach:ms:ppt\",\n                UNKNOWN: \"attach:unknown\"\n            },\n            MessagingConfig: {\n                IDLE_CUTOFF: 30000\n            },\n            MercuryParticipantsConstants: {\n                UNKNOWN_GENDER: 0,\n                EMAIL_IMAGE: \"/images/messaging/threadlist/envelope.png\"\n            },\n            MercuryThreadMode: {\n                EMAIL_ORIGINATED: 1,\n                TITAN_ORIGINATED: 2,\n                OBJECT_ORIGINATED: 3\n            },\n            ChatNotificationConstants: {\n                NORMAL: 0,\n                NO_USER_MESSAGE_NOTIFICATION: 1\n            },\n            Sandbox: {\n                ORIGIN: \"http://fbsbx.com\",\n                PAGE_URL: \"http://fbsbx.com/sandbox.html?1\"\n            },\n            MercuryGenericConstants: {\n                PENDING_THREAD_ID: \"pending:pending\"\n            },\n            MercuryTypeaheadConstants: {\n                COMPOSER_FRIENDS_MAX: 4,\n                COMPOSER_NON_FRIENDS_MAX: 2,\n                COMPOSER_SHOW_MORE_LIMIT: 4,\n                COMPOSER_THREADS_INITIAL_LIMIT: 2,\n                USER_TYPE: \"user\",\n                THREAD_TYPE: \"thread\",\n                HEADER_TYPE: \"header\",\n                FRIEND_TYPE: \"friend\",\n                NON_FRIEND_TYPE: \"non_friend\",\n                VALID_EMAIL: \"^([A-Z0-9._\u0025+-]+@((?!facebook\\\\.com))[A-Z0-9.-]+\\\\.[A-Z]{2,4}|(([A-Z._\u0025+-]+[A-Z0-9._\u0025+-]*)|([A-Z0-9._\u0025+-]+[A-Z._\u0025+-]+[A-Z0-9._\u0025+-]*))@(?:facebook\\\\.com))$\"\n            }\n        },],[\"WebMessengerConstants\",[],{\n            INITIAL_MESSAGES_LIMIT: 40,\n            EXPONENTIAL_PAGER_MAX_CYCLES: 3,\n            COMPOSER_FRIENDS_MAX: 4,\n            COMPOSER_THREADS_MAX: 2,\n            COMPOSER_NON_FRIENDS_MAX: 2,\n            USER_TYPE: \"user\",\n            THREAD_TYPE: \"thread\",\n            HEADER_TYPE: \"header\",\n            FRIEND_TYPE: \"friend\",\n            NON_FRIEND_TYPE: \"non_friend\",\n            MORE_SEARCH_CONTEXT_COUNT: 5,\n            MORE_SEARCH_CONTEXT_UP: \"up\",\n            MORE_SEARCH_CONTEXT_DOWN: \"down\",\n            VALID_EMAIL: \"^([A-Z0-9._\u0025+-]+@((?!facebook\\\\.com))[A-Z0-9.-]+\\\\.[A-Z]{2,4}|(([A-Z._\u0025+-]+[A-Z0-9._\u0025+-]*)|([A-Z0-9._\u0025+-]+[A-Z._\u0025+-]+[A-Z0-9._\u0025+-]*))@(?:facebook\\\\.com))$\",\n            READ_VIEW_SEPARATOR_TIME_LIMIT: 10800000,\n            MAX_VISIBLE_IN_FLYOUT: \"7\",\n            PARTICIPANTS_FLYOUT_HEIGHT: \"303\"\n        },],[\"MessagingReliabilityLoggerInitialData\",[],{\n            enabled: false,\n            app: \"mercury\"\n        },],],\n        require: [[\"MessagingReliabilityLogger\",],]\n    },\n    css: [\"zO4BE\",\"z8dwT\",\"KOOCi\",\"8sw55\",],\n    resource_map: {\n        KOOCi: {\n            type: \"css\",\n            permanent: 1,\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y-/r/43xbci8smdA.css\"\n        },\n        \"8sw55\": {\n            type: \"css\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yu/r/2FBCaVsoeYg.css\"\n        }\n    },\n    js: [\"8gPM0\",\"bS0QP\",\"1zqwA\",\"6n1TR\",],\n    content: {\n        pagelet_messages_data: \" \"\n    }\n});");
// 1694
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s735423f7b80c9eb8a6614a31cfd1065824ea43a3");
// 1695
geval("bigPipe.JSBNG__onPageletArrive({\n    phase: 3,\n    id: \"pagelet_messages_data\",\n    jsmods: {\n        instances: [[\"m205556_75\",[\"XHPTemplate\",\"m205556_98\",],[{\n            __m: \"m205556_98\"\n        },],2,],[\"m205556_76\",[\"XHPTemplate\",\"m205556_99\",],[{\n            __m: \"m205556_99\"\n        },],2,],[\"m205556_77\",[\"XHPTemplate\",\"m205556_100\",],[{\n            __m: \"m205556_100\"\n        },],2,],[\"m205556_78\",[\"XHPTemplate\",\"m205556_101\",],[{\n            __m: \"m205556_101\"\n        },],2,],[\"m205556_79\",[\"XHPTemplate\",\"m205556_102\",],[{\n            __m: \"m205556_102\"\n        },],2,],[\"m205556_80\",[\"XHPTemplate\",\"m205556_103\",],[{\n            __m: \"m205556_103\"\n        },],2,],[\"m205556_81\",[\"XHPTemplate\",\"m205557_104\",],[{\n            __m: \"m205557_104\"\n        },],2,],[\"m205556_82\",[\"XHPTemplate\",\"m205557_105\",],[{\n            __m: \"m205557_105\"\n        },],2,],[\"m205556_83\",[\"XHPTemplate\",\"m205557_106\",],[{\n            __m: \"m205557_106\"\n        },],2,],[\"m205556_84\",[\"XHPTemplate\",\"m205557_107\",],[{\n            __m: \"m205557_107\"\n        },],2,],[\"m205556_85\",[\"XHPTemplate\",\"m205557_108\",],[{\n            __m: \"m205557_108\"\n        },],2,],[\"m205556_86\",[\"XHPTemplate\",\"m205557_109\",],[{\n            __m: \"m205557_109\"\n        },],2,],[\"m205556_87\",[\"XHPTemplate\",\"m205557_110\",],[{\n            __m: \"m205557_110\"\n        },],2,],[\"m205556_88\",[\"XHPTemplate\",\"m205557_111\",],[{\n            __m: \"m205557_111\"\n        },],2,],[\"m205556_89\",[\"XHPTemplate\",\"m205557_112\",],[{\n            __m: \"m205557_112\"\n        },],2,],[\"m205556_90\",[\"XHPTemplate\",\"m205557_113\",],[{\n            __m: \"m205557_113\"\n        },],2,],[\"m205556_91\",[\"XHPTemplate\",\"m205557_114\",],[{\n            __m: \"m205557_114\"\n        },],2,],[\"m205556_92\",[\"XHPTemplate\",\"m205557_115\",],[{\n            __m: \"m205557_115\"\n        },],2,],[\"m205556_93\",[\"XHPTemplate\",\"m205557_116\",],[{\n            __m: \"m205557_116\"\n        },],2,],[\"m205556_94\",[\"XHPTemplate\",\"m205557_117\",],[{\n            __m: \"m205557_117\"\n        },],2,],[\"m205556_95\",[\"XHPTemplate\",\"m205557_118\",],[{\n            __m: \"m205557_118\"\n        },],2,],[\"m205556_96\",[\"XHPTemplate\",\"m205557_119\",],[{\n            __m: \"m205557_119\"\n        },],2,],[\"m205556_97\",[\"XHPTemplate\",\"m205557_120\",],[{\n            __m: \"m205557_120\"\n        },],2,],],\n        markup: [[\"m205556_98\",{\n            __html: \"\\u003Cli\\u003E\\u003Ca class=\\\"messagesContent\\\" data-jsid=\\\"link\\\" href=\\\"#\\\"\\u003E\\u003Cdiv class=\\\"clearfix\\\"\\u003E\\u003Cdiv class=\\\"MercuryThreadImage -cx-PRIVATE-uiImageBlock__image -cx-PRIVATE-uiImageBlock__mediumImage lfloat\\\" data-jsid=\\\"image\\\"\\u003E\\u003Cimg class=\\\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__large img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" /\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"-cx-PRIVATE-uiImageBlock__content \\\"\\u003E\\u003Cdiv class=\\\"content fsm fwn fcg\\\"\\u003E\\u003Cdiv class=\\\"author\\\"\\u003E\\u003Cstrong data-jsid=\\\"name\\\"\\u003E\\u003C/strong\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"snippet preview fsm fwn fcg\\\"\\u003E\\u003Cspan data-jsid=\\\"snippet\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"time\\\"\\u003E\\u003Cabbr title=\\\"Wednesday, December 31, 1969 at 7:00pm\\\" data-utime=\\\"0\\\" class=\\\"hidden_elem timestamp\\\" data-jsid=\\\"timestamp\\\"\\u003Eover a year ago\\u003C/abbr\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\"\n        },2,],[\"m205556_99\",{\n            __html: \"\\u003Cdiv class=\\\"attachment\\\"\\u003E\\u003Cspan class=\\\"uiIconText MercuryThreadlistIconError\\\" data-jsid=\\\"error\\\"\\u003E\\u003Ci class=\\\"img sp_627qpw sx_ca6d8d\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205556_100\",{\n            __html: \"\\u003Cdiv class=\\\"attachment\\\"\\u003E\\u003Cdiv class=\\\"clearfix MercuryExternalLink\\\"\\u003E\\u003Cdiv class=\\\"lfloat\\\" data-jsid=\\\"preview\\\"\\u003E\\u003Ca data-jsid=\\\"image-link\\\" href=\\\"#\\\" target=\\\"_blank\\\"\\u003E\\u003Cimg data-jsid=\\\"preview-image\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" class=\\\"hidden_elem\\\" /\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"MercuryLinkRight rfloat\\\"\\u003E\\u003Cdiv class=\\\"MercuryLinkTitle\\\"\\u003E\\u003Ca class=\\\"linkTitle\\\" target=\\\"_blank\\\" href=\\\"#\\\" data-jsid=\\\"name\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fsm fwn fcg\\\" data-jsid=\\\"shortLink\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205556_101\",{\n            __html: \"\\u003Cdiv class=\\\"attachment fileAttachment\\\"\\u003E\\u003Ca class=\\\"uiIconText\\\" href=\\\"#\\\" data-jsid=\\\"link\\\"\\u003E\\u003Ci class=\\\"img sp_46s4tm sx_3bc2c4\\\"\\u003E\\u003C/i\\u003E\\u003Cspan data-jsid=\\\"filename\\\" class=\\\"filename\\\"\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205556_102\",{\n            __html: \"\\u003Cdiv class=\\\"attachment fileAttachment\\\"\\u003E\\u003Cdiv class=\\\"clearfix\\\"\\u003E\\u003Ca class=\\\"uiIconText lfloat\\\" href=\\\"#\\\" data-jsid=\\\"link\\\"\\u003E\\u003Ci class=\\\"img sp_46s4tm sx_3bc2c4\\\"\\u003E\\u003C/i\\u003E\\u003Cspan class=\\\"filename\\\" data-jsid=\\\"filename\\\"\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"fileLinks rfloat\\\"\\u003E\\u003Cdiv data-jsid=\\\"openLinkContainer\\\" class=\\\"openLinkContainer hidden_elem\\\"\\u003E\\u003Ca class=\\\"openFileLink\\\" href=\\\"#\\\" data-jsid=\\\"openFile\\\"\\u003Eopen\\u003C/a\\u003E \\u00b7 \\u003C/div\\u003E\\u003Ca class=\\\"downloadFileLink\\\" href=\\\"#\\\" data-jsid=\\\"downloadFile\\\"\\u003Edownload\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205556_103\",{\n            __html: \"\\u003Cdiv class=\\\"musicAttachment\\\"\\u003E\\u003Cdiv class=\\\"attachment fileAttachment\\\" data-jsid=\\\"icon_link\\\"\\u003E\\u003Ca class=\\\"uiIconText\\\" href=\\\"#\\\" data-jsid=\\\"link\\\"\\u003E\\u003Ci class=\\\"img sp_46s4tm sx_3bc2c4\\\"\\u003E\\u003C/i\\u003E\\u003Cspan data-jsid=\\\"filename\\\" class=\\\"filename\\\"\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv data-jsid=\\\"preview\\\"\\u003E\\u003Ca data-jsid=\\\"image-link\\\" href=\\\"#\\\" target=\\\"_blank\\\"\\u003E\\u003Cimg data-jsid=\\\"preview-image\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" class=\\\"hidden_elem\\\" /\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205557_104\",{\n            __html: \"\\u003Cdiv\\u003E\\u003Ca data-jsid=\\\"image-link\\\" href=\\\"#\\\" target=\\\"_blank\\\"\\u003E\\u003Cimg data-jsid=\\\"preview-image\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" class=\\\"hidden_elem\\\" /\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205557_105\",{\n            __html: \"\\u003Cdiv class=\\\"attachment\\\"\\u003E\\u003Ca data-jsid=\\\"link\\\" target=\\\"_blank\\\" href=\\\"#\\\"\\u003E\\u003Cspan data-jsid=\\\"name\\\"\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205557_106\",{\n            __html: \"\\u003Cdiv class=\\\"attachment\\\"\\u003E\\u003Ca class=\\\"uiVideoThumb videoPreview\\\" href=\\\"#\\\" data-jsid=\\\"thumb\\\"\\u003E\\u003Cimg class=\\\"img\\\" alt=\\\"\\\" /\\u003E\\u003Ci\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205557_107\",{\n            __html: \"\\u003Cdiv class=\\\"-cx-PRIVATE-mercuryComposer__composerSupplemental -cx-PRIVATE-mercuryComposer__uploadFileRow\\\"\\u003E\\u003Cspan class=\\\"uiIconText MercuryThreadlistIconText\\\" data-jsid=\\\"iconText\\\"\\u003E\\u003Ci class=\\\"img sp_46s4tm sx_3bc2c4\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u003Cimg class=\\\"-cx-PRIVATE-mercuryComposer__uploadingIndicator img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Clabel class=\\\"-cx-PRIVATE-mercuryComposer__closeFileUpload uiCloseButton uiCloseButtonSmall uiCloseButtonSmallDark\\\" for=\\\"uq3j16_52\\\"\\u003E\\u003Cinput title=\\\"Remove\\\" type=\\\"button\\\" data-jsid=\\\"closeFileUpload\\\" id=\\\"uq3j16_52\\\" /\\u003E\\u003C/label\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205557_108\",{\n            __html: \"\\u003Cimg class=\\\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__large img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" alt=\\\"\\\" /\\u003E\"\n        },2,],[\"m205557_109\",{\n            __html: \"\\u003Cimg class=\\\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__large img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" alt=\\\"\\\" /\\u003E\"\n        },2,],[\"m205557_110\",{\n            __html: \"\\u003Cimg class=\\\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__medium img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" alt=\\\"\\\" /\\u003E\"\n        },2,],[\"m205557_111\",{\n            __html: \"\\u003Cspan class=\\\"uiSplitPics clearfix\\\"\\u003E\\u003Cspan class=\\\"uiSplitPic leftThree\\\"\\u003E\\u003Cimg class=\\\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__large img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" alt=\\\"\\\" data-jsid=\\\"left\\\" /\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"uiSplitPic rTop\\\"\\u003E\\u003Cimg class=\\\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__small img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" alt=\\\"\\\" data-jsid=\\\"topRight\\\" /\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"uiSplitPic rBottom\\\"\\u003E\\u003Cimg class=\\\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__small img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" alt=\\\"\\\" data-jsid=\\\"bottomRight\\\" /\\u003E\\u003C/span\\u003E\\u003C/span\\u003E\"\n        },2,],[\"m205557_112\",{\n            __html: \"\\u003Ci class=\\\"mrs MercuryThreadlistIcon img sp_46s4tm sx_b35b84\\\"\\u003E\\u003C/i\\u003E\"\n        },2,],[\"m205557_113\",{\n            __html: \"\\u003Cspan class=\\\"uiIconText MercuryThreadlistIconText\\\"\\u003E\\u003Ci class=\\\"img sp_46s4tm sx_3bc2c4\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\"\n        },2,],[\"m205557_114\",{\n            __html: \"\\u003Ci class=\\\"mercuryStatusIndicator mercuryErrorIndicator img sp_ae80w4 sx_e17869\\\"\\u003E\\u003C/i\\u003E\"\n        },2,],[\"m205557_115\",{\n            __html: \"\\u003Ci class=\\\"mercuryStatusIndicator img sp_46s4tm sx_93bdc2\\\"\\u003E\\u003C/i\\u003E\"\n        },2,],[\"m205557_116\",{\n            __html: \"\\u003Cdiv class=\\\"uiTypeahead\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" class=\\\"hiddenInput\\\" /\\u003E\\u003Cdiv class=\\\"innerWrap\\\"\\u003E\\u003Cinput type=\\\"text\\\" class=\\\"inputtext textInput\\\" data-jsid=\\\"textfield\\\" /\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205557_117\",{\n            __html: \"\\u003Cdiv class=\\\"clearfix uiTokenizer uiInlineTokenizer\\\"\\u003E\\u003Cdiv class=\\\"tokenarea hidden_elem\\\" data-jsid=\\\"tokenarea\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205557_118\",{\n            __html: \"\\u003Cli class=\\\"-cx-PRIVATE-mercuryTypeahead__header typeaheadHeader uiListItem uiListLight uiListVerticalItemBorder\\\"\\u003E\\u003Cdiv class=\\\"clearfix\\\"\\u003E\\u003Cdiv class=\\\"lfloat\\\"\\u003E\\u003Cspan data-jsid=\\\"text\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Ca class=\\\"showAllLink rfloat\\\" data-jsid=\\\"link\\\" href=\\\"#\\\"\\u003EShow All\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/li\\u003E\"\n        },2,],[\"m205557_119\",{\n            __html: \"\\u003Cli class=\\\"-cx-PRIVATE-mercuryTypeahead__row uiListItem  uiListVerticalItemBorder\\\"\\u003E\\u003Cdiv class=\\\"clearfix pvs\\\"\\u003E\\u003Cdiv class=\\\"MercuryThreadImage mrm lfloat\\\" data-jsid=\\\"image\\\"\\u003E\\u003Cimg class=\\\"-cx-PRIVATE-uiSquareImage__root -cx-PRIVATE-uiSquareImage__large img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" /\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"-cx-PRIVATE-mercuryTypeahead__rightContent\\\"\\u003E\\u003Cspan class=\\\"-cx-PRIVATE-mercuryTypeahead__name\\\" data-jsid=\\\"name\\\"\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"-cx-PRIVATE-mercuryTypeahead__snippet fsm fwn fcg\\\" data-jsid=\\\"snippet\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/li\\u003E\"\n        },2,],[\"m205557_120\",{\n            __html: \"\\u003Cdiv class=\\\"UIImageBlock clearfix\\\"\\u003E\\u003Cimg class=\\\"mrm -cx-PRIVATE-uiSquareImage__root UIImageBlock_Image UIImageBlock_ICON_Image -cx-PRIVATE-uiSquareImage__large img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" alt=\\\"\\\" data-jsid=\\\"profilePhoto\\\" /\\u003E\\u003Cdiv class=\\\"UIImageBlock_Content UIImageBlock_ICON_Content\\\"\\u003E\\u003Cdiv class=\\\"mbs fsl fwb fcb\\\" data-jsid=\\\"mainText\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"aux-message fcg\\\" data-jsid=\\\"auxMessage\\\"\\u003EVideo will start as soon as you answer.\\u003C/div\\u003E\\u003Cdiv class=\\\"mts hidden_elem fcg\\\" data-jsid=\\\"slowMessage\\\"\\u003E\\u003Cspan class=\\\"fwb fcb\\\"\\u003EHaving trouble?\\u003C/span\\u003E Your connection may be \\u003Ca href=\\\"/help/?faq=214265948627885&amp;in_context=1\\\" target=\\\"_blank\\\"\\u003Etoo slow\\u003C/a\\u003E.\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],],\n        define: [[\"MercuryJewelTemplates\",[\"m205556_75\",],{\n            \":fb:mercury:jewel:threadlist-row\": {\n                __m: \"m205556_75\"\n            }\n        },],[\"MercuryAttachmentTemplates\",[\"m205556_76\",\"m205556_77\",\"m205556_78\",\"m205556_79\",\"m205556_80\",\"m205556_81\",\"m205556_82\",\"m205556_83\",\"m205556_84\",],{\n            \":fb:mercury:attachment:error\": {\n                __m: \"m205556_76\"\n            },\n            \":fb:mercury:attachment:external-link\": {\n                __m: \"m205556_77\"\n            },\n            \":fb:mercury:attachment:file-link\": {\n                __m: \"m205556_78\"\n            },\n            \":fb:mercury:attachment:extended-file-link\": {\n                __m: \"m205556_79\"\n            },\n            \":fb:mercury:attachment:music\": {\n                __m: \"m205556_80\"\n            },\n            \":fb:mercury:attachment:preview\": {\n                __m: \"m205556_81\"\n            },\n            \":fb:mercury:attachment:share-link\": {\n                __m: \"m205556_82\"\n            },\n            \":fb:mercury:attachment:video-thumb\": {\n                __m: \"m205556_83\"\n            },\n            \":fb:mercury:upload-file-row\": {\n                __m: \"m205556_84\"\n            }\n        },],[\"MercuryImageTemplates\",[\"m205556_85\",\"m205556_86\",\"m205556_87\",\"m205556_88\",],{\n            \":fb:mercury:thread-image:single\": {\n                __m: \"m205556_85\"\n            },\n            \":fb:mercury:thread-image:single:large\": {\n                __m: \"m205556_86\"\n            },\n            \":fb:mercury:thread-image:single:medium\": {\n                __m: \"m205556_87\"\n            },\n            \":fb:mercury:thread-image:split\": {\n                __m: \"m205556_88\"\n            }\n        },],[\"MercuryThreadlistIconTemplates\",[\"m205556_89\",\"m205556_90\",],{\n            \":fb:mercury:attachment-indicator\": {\n                __m: \"m205556_89\"\n            },\n            \":fb:mercury:attachment-icon-text\": {\n                __m: \"m205556_90\"\n            }\n        },],[\"MercuryStatusTemplates\",[\"m205556_91\",\"m205556_92\",],{\n            \":fb:mercury:error-indicator\": {\n                __m: \"m205556_91\"\n            },\n            \":fb:mercury:resend-indicator\": {\n                __m: \"m205556_92\"\n            }\n        },],[\"MercuryTypeaheadTemplates\",[\"m205556_93\",\"m205556_94\",\"m205556_95\",\"m205556_96\",],{\n            \":fb:mercury:typeahead\": {\n                __m: \"m205556_93\"\n            },\n            \":fb:mercury:tokenizer\": {\n                __m: \"m205556_94\"\n            },\n            \":fb:mercury:typeahead:header\": {\n                __m: \"m205556_95\"\n            },\n            \":fb:mercury:typeahead:result\": {\n                __m: \"m205556_96\"\n            }\n        },],[\"VideoCallTemplates\",[\"m205556_97\",],{\n            \":fb:videocall:incoming-dialog\": {\n                __m: \"m205556_97\"\n            }\n        },],[\"MercuryConstants\",[],{\n            MercuryActionType: {\n                LOG_MESSAGE: \"ma-type:log-message\",\n                USER_GENERATED_MESSAGE: \"ma-type:user-generated-message\",\n                CHANGE_READ_STATUS: \"ma-type:change_read_status\",\n                CLEAR_CHAT: \"ma-type:clear_chat\",\n                SEND_MESSAGE: \"ma-type:send-message\",\n                UPDATE_ACTION_ID: \"ma-type:update-action-id\",\n                DELETE_MESSAGES: \"ma-type:delete-messages\",\n                DELETE_THREAD: \"ma-type:delete-thread\",\n                CHANGE_ARCHIVED_STATUS: \"ma-type:change-archived-status\",\n                CHANGE_FOLDER: \"ma-type:change-folder\"\n            },\n            MercuryGlobalActionType: {\n                MARK_ALL_READ: \"mga-type:mark-all-read\"\n            },\n            MercuryLogMessageType: {\n                SUBSCRIBE: \"log:subscribe\",\n                UNSUBSCRIBE: \"log:unsubscribe\",\n                VIDEO_CALL: \"log:video-call\",\n                THREAD_NAME: \"log:thread-name\",\n                THREAD_IMAGE: \"log:thread-image\",\n                SERVER_ERROR: \"log:error-msg\",\n                LIVE_LISTEN: \"log:live-listen\"\n            },\n            MercuryPayloadSource: {\n                UNKNOWN: \"unknown\",\n                CLIENT_CHANNEL_MESSAGE: \"client_channel_message\",\n                CLIENT_SEND_MESSAGE: \"client_send_message\",\n                CLIENT_CHANGE_ARCHIVED_STATUS: \"client_change-archived_status\",\n                CLIENT_CHANGE_FOLDER: \"client_change_folder\",\n                CLIENT_CHANGE_READ_STATUS: \"client_change_read_status\",\n                CLIENT_CLEAR_CHAT: \"client_clear_chat\",\n                CLIENT_DELETE_MESSAGES: \"client_delete_messages\",\n                CLIENT_DELETE_THREAD: \"client_delete_thread\",\n                CLIENT_HANDLE_ERROR: \"client_handle_error\",\n                SERVER_INITIAL_DATA: \"server_initial_data\",\n                SERVER_SEND_MESSAGE: \"server_send_message\",\n                SERVER_CONFIRM_MESSAGES: \"server_confirm_messages\",\n                SERVER_CHANGE_ARCHIVED_STATUS: \"server_change_archived_status\",\n                SERVER_CHANGE_READ_STATUS: \"server_change_read_status\",\n                SERVER_MARK_FOLDER_READ: \"server_mark_folder_read\",\n                SERVER_MARK_SEEN: \"server_mark_seen\",\n                SERVER_FETCH_THREAD_INFO: \"server_fetch_thread_info\",\n                SERVER_FETCH_THREADLIST_INFO: \"server_fetch_threadlist_info\",\n                SERVER_THREAD_SYNC: \"server_thread_sync\",\n                SERVER_TAB_PRESENCE: \"server_tab_presence\",\n                SERVER_UNREAD_THREADS: \"server_unread_threads\",\n                SERVER_SEARCH: \"server_search\"\n            },\n            MercuryMessageSourceTags: {\n                CHAT: \"source:chat\",\n                EMAIL: \"source:email\",\n                MESSENGER: \"source:messenger\",\n                MOBILE: \"source:mobile\"\n            },\n            MercurySourceType: {\n                CHAT_ORCA: \"source:chat:orca\",\n                CHAT_IPHONE: \"source:chat:iphone\",\n                CHAT_JABBER: \"source:chat:jabber\",\n                CHAT_MEEBO: \"source:chat:meebo\",\n                CHAT_WEB: \"source:chat:web\",\n                CHAT_TEST: \"source:chat:test\",\n                CHAT: \"source:chat\",\n                DESKTOP: \"source:desktop\",\n                EMAIL: \"source:email\",\n                GIGABOXX_API: \"source:gigaboxx:api\",\n                GIGABOXX_BLAST: \"source:gigaboxx:blast\",\n                GIGABOXX_EMAIL_REPLY: \"source:gigaboxx:emailreply\",\n                GIGABOXX_MOBILE: \"source:gigaboxx:mobile\",\n                GIGABOXX_WAP: \"source:gigaboxx:wap\",\n                GIGABOXX_WEB: \"source:gigaboxx:web\",\n                SHARE_DIALOG: \"source:share:dialog\",\n                SEND_PLUGIN: \"source:sendplugin\",\n                SMS: \"source:sms\",\n                TEST: \"source:test\",\n                TITAN_WAP: \"source:titan:wap\",\n                TITAN_M_AJAX: \"source:titan:m_ajax\",\n                TITAN_M_BASIC: \"source:titan:m_basic\",\n                TITAN_M_JAPAN: \"source:titan:m_japan\",\n                TITAN_M_MINI: \"source:titan:m_mini\",\n                TITAN_M_TOUCH: \"source:titan:m_touch\",\n                TITAN_M_ZERO: \"source:titan:m_zero\",\n                TITAN_WEB: \"source:titan:web\",\n                TITAN_API: \"source:titan:api\",\n                TITAN_API_MOBILE: \"source:titan:api_mobile\",\n                TITAN_ORCA: \"source:titan:orca\",\n                TITAN_EMAIL_REPLY: \"source:titan:emailreply\",\n                MOBILE: \"source:mobile\",\n                UNKNOWN: \"source:unknown\",\n                WEB: \"source:web\",\n                HELPCENTER: \"source:helpcenter\",\n                NEW_SHARE_DIALOG: \"source:share:dialog:new\",\n                PAID_PROMOTION: \"source:paid_promotion\",\n                BUFFY_SMS: \"source:buffy:sms\"\n            },\n            MercurySupportedShareType: {\n                FB_PHOTO: 2,\n                FB_ALBUM: 3,\n                FB_VIDEO: 11,\n                FB_SONG: 28,\n                FB_MUSIC_ALBUM: 30,\n                EXTERNAL: 100,\n                FB_TEMPLATE: 300\n            },\n            MercuryThreadlistConstants: {\n                RECENT_THREAD_OFFSET: 0,\n                JEWEL_THREAD_COUNT: 5,\n                WEBMESSENGER_THREAD_COUNT: 20,\n                WEBMESSENGER_MORE_COUNT: 20,\n                WEBMESSENGER_SEARCH_SNIPPET_COUNT: 5,\n                WEBMESSENGER_SEARCH_SNIPPET_LIMIT: 5,\n                WEBMESSENGER_SEARCH_SNIPPET_MORE: 5,\n                WEBMESSENGER_MORE_MESSAGES_COUNT: 20,\n                RECENT_MESSAGES_LIMIT: 10,\n                MAX_UNREAD_COUNT: 99,\n                MAX_UNSEEN_COUNT: 99,\n                GROUPING_THRESHOLD: 300000,\n                MESSAGE_TIMESTAMP_THRESHOLD: 1209600000,\n                SEARCH_TAB: \"searchtab\"\n            },\n            MessagingEventTypes: {\n                DELETE: \"delete\",\n                DELETE_MESSAGES: \"delete_messages\",\n                DELIVER: \"deliver\",\n                ERROR: \"error\",\n                READ: \"read\",\n                REPORT_SPAM: \"report_spam\",\n                UNMARK_SPAM: \"unmark_spam\",\n                SUBSCRIBE: \"subscribe\",\n                TAG: \"tag\",\n                UNREAD: \"unread\",\n                UNSUBSCRIBE: \"unsubscribe\",\n                DELIVER_LOG: \"deliver_log\",\n                MORE_THREADS: \"more_threads\",\n                READ_ALL: \"read_all\",\n                READ_RECEIPT: \"read_receipt\",\n                DELIVERY_RECEIPT: \"delivery_receipt\",\n                SENT_PUSH: \"sent_push\",\n                DELIVER_FAST_PAST: \"deliver_fast_path\"\n            },\n            MercuryActionStatus: {\n                UNSENT: 0,\n                SUCCESS: 1,\n                REQUEST_ERROR: 2,\n                UNCONFIRMED: 3,\n                FAILED_UNKNOWN_REASON: 4,\n                UNABLE_TO_CONFIRM: 5,\n                RESENT: 6,\n                RESENDING: 7,\n                REQUEST_EMPTY_MESSAGE_LIST: 8,\n                TRANSPORT_ERROR: 9\n            },\n            MessagingTag: {\n                ACTION_ARCHIVED: \"action:archived\",\n                INBOX: \"inbox\",\n                OTHER: \"other\",\n                EVENT: \"JSBNG__event\",\n                SENT: \"sent\",\n                SMS_MUTE: \"sms_mute\",\n                SPAM: \"spam\",\n                UPDATES: \"broadcasts_inbox\",\n                BCC: \"header:bcc\",\n                UNREAD: \"unread\",\n                ARCHIVED: \"archived\",\n                EMAIL: \"email\",\n                VOICEMAIL: \"voicemail\",\n                SPAM_SPOOFING: \"spam:spoofing\",\n                SPOOF_WARNING: \"MTA:spoof_warning\",\n                SMS_TAG_ROOT: \"SMSShortcode:\",\n                APP_ID_ROOT: \"app_id:\",\n                DOMAIN_AUTH_PASS: \"MTA:dmarc:pass\",\n                DOMAIN_AUTH_FAIL: \"MTA:dmarc:fail\",\n                MTA_SYSTEM_MESSAGE: \"MTA:system_message\"\n            },\n            VideoChatConstants: {\n                START_SESSION: 1,\n                GET_SKYPE_TOKEN: 2,\n                AWAITING_CALL: 3,\n                CANCELLED_CALL: 4,\n                CONNECTED_CALL: 5,\n                HANDLED_CALL: 6,\n                GOT_START_SESSION: 7,\n                INSTALLING: 8,\n                INSTALLED: 9,\n                INSTALL_CANCELED: 10,\n                ASSOC_CONNECTED_CALL: 118224944915447,\n                ASSOC_VIEWED_CALL_PROMO: 250568041676842,\n                MAX_VC_PROMO_VIEWS: 2,\n                MINIMUM_VC_PROMO_VIEW_INTERVAL: 5184000,\n                MINIMUM_VC_LAST_CALLED_INTERVAL: 5184000\n            },\n            MercuryAttachmentType: {\n                ERROR: \"error\",\n                FILE: \"file\",\n                SHARE: \"share\"\n            },\n            MercuryAttachmentContentType: {\n                PHOTO: \"attach:image\",\n                VIDEO: \"attach:video\",\n                MUSIC: \"attach:music\",\n                TEXT: \"attach:text\",\n                MSWORD: \"attach:ms:word\",\n                MSXLS: \"attach:ms:xls\",\n                MSPPT: \"attach:ms:ppt\",\n                UNKNOWN: \"attach:unknown\"\n            },\n            MessagingConfig: {\n                IDLE_CUTOFF: 30000\n            },\n            MercuryParticipantsConstants: {\n                UNKNOWN_GENDER: 0,\n                EMAIL_IMAGE: \"/images/messaging/threadlist/envelope.png\"\n            },\n            MercuryThreadMode: {\n                EMAIL_ORIGINATED: 1,\n                TITAN_ORIGINATED: 2,\n                OBJECT_ORIGINATED: 3\n            },\n            ChatNotificationConstants: {\n                NORMAL: 0,\n                NO_USER_MESSAGE_NOTIFICATION: 1\n            },\n            Sandbox: {\n                ORIGIN: \"http://fbsbx.com\",\n                PAGE_URL: \"http://fbsbx.com/sandbox.html?1\"\n            },\n            MercuryGenericConstants: {\n                PENDING_THREAD_ID: \"pending:pending\"\n            },\n            MercuryTypeaheadConstants: {\n                COMPOSER_FRIENDS_MAX: 4,\n                COMPOSER_NON_FRIENDS_MAX: 2,\n                COMPOSER_SHOW_MORE_LIMIT: 4,\n                COMPOSER_THREADS_INITIAL_LIMIT: 2,\n                USER_TYPE: \"user\",\n                THREAD_TYPE: \"thread\",\n                HEADER_TYPE: \"header\",\n                FRIEND_TYPE: \"friend\",\n                NON_FRIEND_TYPE: \"non_friend\",\n                VALID_EMAIL: \"^([A-Z0-9._%+-]+@((?!facebook\\\\.com))[A-Z0-9.-]+\\\\.[A-Z]{2,4}|(([A-Z._%+-]+[A-Z0-9._%+-]*)|([A-Z0-9._%+-]+[A-Z._%+-]+[A-Z0-9._%+-]*))@(?:facebook\\\\.com))$\"\n            }\n        },],[\"WebMessengerConstants\",[],{\n            INITIAL_MESSAGES_LIMIT: 40,\n            EXPONENTIAL_PAGER_MAX_CYCLES: 3,\n            COMPOSER_FRIENDS_MAX: 4,\n            COMPOSER_THREADS_MAX: 2,\n            COMPOSER_NON_FRIENDS_MAX: 2,\n            USER_TYPE: \"user\",\n            THREAD_TYPE: \"thread\",\n            HEADER_TYPE: \"header\",\n            FRIEND_TYPE: \"friend\",\n            NON_FRIEND_TYPE: \"non_friend\",\n            MORE_SEARCH_CONTEXT_COUNT: 5,\n            MORE_SEARCH_CONTEXT_UP: \"up\",\n            MORE_SEARCH_CONTEXT_DOWN: \"down\",\n            VALID_EMAIL: \"^([A-Z0-9._%+-]+@((?!facebook\\\\.com))[A-Z0-9.-]+\\\\.[A-Z]{2,4}|(([A-Z._%+-]+[A-Z0-9._%+-]*)|([A-Z0-9._%+-]+[A-Z._%+-]+[A-Z0-9._%+-]*))@(?:facebook\\\\.com))$\",\n            READ_VIEW_SEPARATOR_TIME_LIMIT: 10800000,\n            MAX_VISIBLE_IN_FLYOUT: \"7\",\n            PARTICIPANTS_FLYOUT_HEIGHT: \"303\"\n        },],[\"MessagingReliabilityLoggerInitialData\",[],{\n            enabled: false,\n            app: \"mercury\"\n        },],],\n        require: [[\"MessagingReliabilityLogger\",],]\n    },\n    css: [\"zO4BE\",\"z8dwT\",\"KOOCi\",\"8sw55\",],\n    resource_map: {\n        KOOCi: {\n            type: \"css\",\n            permanent: 1,\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y-/r/43xbci8smdA.css\"\n        },\n        \"8sw55\": {\n            type: \"css\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yu/r/2FBCaVsoeYg.css\"\n        }\n    },\n    js: [\"8gPM0\",\"bS0QP\",\"1zqwA\",\"6n1TR\",],\n    JSBNG__content: {\n        pagelet_messages_data: \" \"\n    }\n});");
// 1707
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"bigPipe.onPageletArrive({\n    phase: 3,\n    id: \"pagelet_channel\",\n    jsmods: {\n        define: [[\"PresenceInitialData\",[],{\n            cookiePollInterval: 500,\n            cookieVersion: 2,\n            dictEncode: true,\n            serverTime: \"1344872055000\"\n        },],[\"ChannelInitialData\",[],{\n            channelConfig: {\n                IFRAME_LOAD_TIMEOUT: 30000,\n                P_TIMEOUT: 30000,\n                STREAMING_TIMEOUT: 70000,\n                PROBE_HEARTBEATS_INTERVAL_LOW: 1000,\n                PROBE_HEARTBEATS_INTERVAL_HIGH: 3000,\n                user_channel: \"p_100001812504199\",\n                seq: -1,\n                retry_interval: 0,\n                max_conn: 6,\n                forceIframe: false,\n                streamProbe: false,\n                tryStreaming: true,\n                bustIframe: false\n            },\n            state: \"reconnect!\",\n            reason: 6\n        },],[\"ChannelImplementation\",[\"ChannelConnection\",],{\n            instance: {\n                __m: \"ChannelConnection\"\n            }\n        },],],\n        require: [[\"ChannelManager\",],]\n    },\n    js: [\"8gPM0\",\"bS0QP\",\"1zqwA\",],\n    content: {\n        pagelet_channel: \" \"\n    }\n});");
// 1708
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s9784ab2d1462c407e028c29470b55478176b9fe2");
// 1709
geval("bigPipe.JSBNG__onPageletArrive({\n    phase: 3,\n    id: \"pagelet_channel\",\n    jsmods: {\n        define: [[\"PresenceInitialData\",[],{\n            cookiePollInterval: 500,\n            cookieVersion: 2,\n            dictEncode: true,\n            serverTime: \"1344872055000\"\n        },],[\"ChannelInitialData\",[],{\n            channelConfig: {\n                IFRAME_LOAD_TIMEOUT: 30000,\n                P_TIMEOUT: 30000,\n                STREAMING_TIMEOUT: 70000,\n                PROBE_HEARTBEATS_INTERVAL_LOW: 1000,\n                PROBE_HEARTBEATS_INTERVAL_HIGH: 3000,\n                user_channel: \"p_100001812504199\",\n                seq: -1,\n                retry_interval: 0,\n                max_conn: 6,\n                forceIframe: false,\n                streamProbe: false,\n                tryStreaming: true,\n                bustIframe: false\n            },\n            state: \"reconnect!\",\n            reason: 6\n        },],[\"ChannelImplementation\",[\"ChannelConnection\",],{\n            instance: {\n                __m: \"ChannelConnection\"\n            }\n        },],],\n        require: [[\"ChannelManager\",],]\n    },\n    js: [\"8gPM0\",\"bS0QP\",\"1zqwA\",],\n    JSBNG__content: {\n        pagelet_channel: \" \"\n    }\n});");
// 1714
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"bigPipe.onPageletArrive({\n    phase: 3,\n    id: \"pagelet_dock\",\n    jsmods: {\n        instances: [[\"m205558_147\",[\"BuddyListNub\",\"m205558_146\",\"m205558_148\",\"m205558_149\",],[{\n            __m: \"m205558_146\"\n        },{\n            __m: \"m205558_148\"\n        },{\n            __m: \"m205558_149\"\n        },],1,],[\"m205558_149\",[\"Typeahead\",\"m205558_153\",\"TypeaheadView\",\"ChatTypeaheadRenderer\",\"m205558_150\",\"ChatTypeaheadCore\",\"m205558_151\",],[{\n            __m: \"m205558_153\"\n        },{\n            node_id: \"uq3j16_54\",\n            ctor: {\n                __m: \"TypeaheadView\"\n            },\n            options: {\n                autoSelect: true,\n                renderer: {\n                    __m: \"ChatTypeaheadRenderer\"\n                },\n                causalElement: {\n                    __m: \"m205558_150\"\n                }\n            }\n        },{\n            ctor: {\n                __m: \"ChatTypeaheadCore\"\n            },\n            options: {\n                keepFocused: false,\n                resetOnSelect: true,\n                setValueOnSelect: false\n            }\n        },{\n            __m: \"m205558_151\"\n        },],7,],[\"m205558_155\",[\"ChatSidebarDropdown\",\"m205558_154\",],[{\n            __m: \"m205558_154\"\n        },],1,],[\"m205559_158\",[\"ContextualDialogX\",\"AccessibleLayer\",],[{\n            buildWrapper: false,\n            causalElement: null,\n            addedBehaviors: [{\n                __m: \"AccessibleLayer\"\n            },]\n        },],5,],[\"m205558_148\",[\"ChatOrderedList\",\"m205559_160\",\"m205559_161\",\"m205559_162\",\"m205559_158\",],[{\n            __m: \"m205559_160\"\n        },{\n            __m: \"m205559_161\"\n        },{\n            __m: \"m205559_162\"\n        },{\n            __m: \"m205559_158\"\n        },],3,],[\"m205558_122\",[\"DataSource\",],[{\n            maxResults: 5,\n            queryData: [],\n            bootstrapData: {\n                viewer: 100001812504199,\n                token: \"1343822055-7\",\n                filter: [\"user\",],\n                options: [\"friends_only\",]\n            },\n            bootstrapEndpoint: \"/ajax/typeahead/first_degree.php\"\n        },],1,],[\"m205558_123\",[\"XHPTemplate\",\"m205559_163\",],[{\n            __m: \"m205559_163\"\n        },],2,],[\"m205558_124\",[\"XHPTemplate\",\"m205559_164\",],[{\n            __m: \"m205559_164\"\n        },],2,],[\"m205558_125\",[\"XHPTemplate\",\"m205559_165\",],[{\n            __m: \"m205559_165\"\n        },],2,],[\"m205558_126\",[\"XHPTemplate\",\"m205559_166\",],[{\n            __m: \"m205559_166\"\n        },],2,],[\"m205558_127\",[\"XHPTemplate\",\"m205559_167\",],[{\n            __m: \"m205559_167\"\n        },],2,],[\"m205558_128\",[\"XHPTemplate\",\"m205559_168\",],[{\n            __m: \"m205559_168\"\n        },],2,],[\"m205558_129\",[\"XHPTemplate\",\"m205559_169\",],[{\n            __m: \"m205559_169\"\n        },],2,],[\"m205558_130\",[\"XHPTemplate\",\"m205559_170\",],[{\n            __m: \"m205559_170\"\n        },],2,],[\"m205558_131\",[\"XHPTemplate\",\"m205559_171\",],[{\n            __m: \"m205559_171\"\n        },],2,],[\"m205558_132\",[\"XHPTemplate\",\"m205559_172\",],[{\n            __m: \"m205559_172\"\n        },],2,],[\"m205558_133\",[\"XHPTemplate\",\"m205559_173\",],[{\n            __m: \"m205559_173\"\n        },],2,],[\"m205558_134\",[\"XHPTemplate\",\"m205559_174\",],[{\n            __m: \"m205559_174\"\n        },],2,],[\"m205558_135\",[\"XHPTemplate\",\"m205559_175\",],[{\n            __m: \"m205559_175\"\n        },],2,],[\"m205558_136\",[\"XHPTemplate\",\"m205559_176\",],[{\n            __m: \"m205559_176\"\n        },],2,],[\"m205558_137\",[\"XHPTemplate\",\"m205559_177\",],[{\n            __m: \"m205559_177\"\n        },],2,],[\"m205558_138\",[\"XHPTemplate\",\"m205559_178\",],[{\n            __m: \"m205559_178\"\n        },],2,],[\"m205558_139\",[\"XHPTemplate\",\"m205560_179\",],[{\n            __m: \"m205560_179\"\n        },],2,],[\"m205558_140\",[\"XHPTemplate\",\"m205560_182\",],[{\n            __m: \"m205560_182\"\n        },],2,],[\"m205558_141\",[\"XHPTemplate\",\"m205561_185\",],[{\n            __m: \"m205561_185\"\n        },],2,],[\"m205558_142\",[\"XHPTemplate\",\"m205561_186\",],[{\n            __m: \"m205561_186\"\n        },],2,],[\"m205558_143\",[\"XHPTemplate\",\"m205561_187\",],[{\n            __m: \"m205561_187\"\n        },],2,],[\"m205558_153\",[\"ChatTypeaheadDataSource\",],[{\n            showOfflineUsers: true\n        },],2,],[\"m205559_161\",[\"XHPTemplate\",\"m205561_188\",],[{\n            __m: \"m205561_188\"\n        },],2,],[\"m205559_162\",[\"XHPTemplate\",\"m205561_189\",],[{\n            __m: \"m205561_189\"\n        },],2,],],\n        markup: [[\"m205559_157\",{\n            __html: \"Options\"\n        },2,],[\"m205559_159\",{\n            __html: \"\\u003Cdiv class=\\\"uiContextualDialogPositioner\\\" id=\\\"uq3j16_60\\\" data-position=\\\"left\\\"\\u003E\\u003Cdiv class=\\\"uiOverlay uiContextualDialog\\\" data-width=\\\"300\\\" data-destroyonhide=\\\"false\\\" data-fadeonhide=\\\"false\\\"\\u003E\\u003Cdiv class=\\\"uiOverlayContent\\\"\\u003E\\u003Cdiv class=\\\"uiContextualDialogContent\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_163\",{\n            __html: \"\\u003Cdiv class=\\\"mhs mbs fbChatConvItem fbChatConvDateBreak fss fwb fcg\\\" data-jsid=\\\"date\\\"\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_164\",{\n            __html: \"\\u003Cdiv class=\\\"fbChatMessage fsm\\\" data-jsid=\\\"message\\\"\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_165\",{\n            __html: \"\\u003Cdiv class=\\\"mhs mbs pts fbChatConvItem fbChatEventMsg clearfix\\\"\\u003E\\u003Cdiv class=\\\"iconWrapper\\\"\\u003E\\u003Cimg class=\\\"eventIcon img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/y4/r/-PAXP-deijE.gif\\\" data-jsid=\\\"icon\\\" alt=\\\"\\\" width=\\\"1\\\" height=\\\"1\\\" /\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"messageWrapper\\\"\\u003E\\u003Cspan class=\\\"message fsm fcg\\\" data-jsid=\\\"message\\\"\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"mls timestamp rfloat fss fcg\\\" data-jsid=\\\"timestamp\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"logMessageAttachment\\\" data-jsid=\\\"attachment\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_166\",{\n            __html: \"\\u003Cdiv class=\\\"clearfix\\\"\\u003E\\u003Cdiv data-jsid=\\\"status\\\" class=\\\"rfloat\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbChatMessage fsm fcg\\\" data-jsid=\\\"message\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_167\",{\n            __html: \"\\u003Cdiv class=\\\"fbChatMessageSubject fsm fwb\\\" data-jsid=\\\"messageSubject\\\"\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_168\",{\n            __html: \"\\u003Cdiv class=\\\"mhs mbs pts fbChatConvItem fbChatMessageGroup clearfix small\\\"\\u003E\\u003Ca class=\\\"profileLink\\\" href=\\\"#\\\" data-jsid=\\\"profileLink\\\"\\u003E\\u003Cimg class=\\\"profilePhoto\\\" src=\\\"/images/spacer.gif\\\" data-jsid=\\\"profilePhoto\\\" /\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"messages\\\" data-jsid=\\\"messages\\\"\\u003E\\u003Cdiv class=\\\"metaInfoContainer fss fcg\\\"\\u003E\\u003Cspan data-jsid=\\\"reportLinkWithDot\\\" class=\\\"hidden_elem\\\"\\u003E\\u003Ca href=\\\"#\\\" rel=\\\"dialog\\\" data-jsid=\\\"reportLink\\\"\\u003E\\u003Cspan class=\\\"fcg\\\"\\u003EReport\\u003C/span\\u003E\\u003C/a\\u003E \\u00b7 \\u003C/span\\u003E\\u003Cspan class=\\\"timestamp\\\" data-jsid=\\\"timestamp\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_169\",{\n            __html: \"\\u003Cdiv class=\\\"fbNub fbChatTabSelector\\\"\\u003E\\u003Ca class=\\\"fbNubButton\\\" tabindex=\\\"0\\\" href=\\\"#\\\" rel=\\\"toggle\\\"\\u003E\\u003Ci class=\\\"messagesIcon img sp_ae80w4 sx_0ca7fd\\\"\\u003E\\u003C/i\\u003E\\u003Cspan data-jsid=\\\"numTabs\\\"\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"numMessages\\\" data-jsid=\\\"numMessages\\\"\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"fbNubFlyout uiToggleFlyout noTitlebar\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutOuter\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutInner\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutBody scrollable\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutBodyContent\\\"\\u003E\\u003Cdiv role=\\\"menu\\\" class=\\\"uiMenu\\\" data-jsid=\\\"menu\\\"\\u003E\\u003Cul class=\\\"uiMenuInner\\\"\\u003E\\u003Cli class=\\\"uiMenuItem\\\" data-label=\\\"Dummy\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"0\\\" href=\\\"#\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003E Dummy \\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_170\",{\n            __html: \"\\u003Cli class=\\\"uiMenuItem fbChatTabSelectorItem\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003E\\u003Cspan class=\\\"unreadCount\\\" data-jsid=\\\"unreadCount\\\"\\u003E\\u003C/span\\u003E\\u003Cspan data-jsid=\\\"content\\\"\\u003E\\u003C/span\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\"\n        },2,],[\"m205559_171\",{\n            __html: \"\\u003Cdiv class=\\\"addFriends\\\"\\u003E\\u003Ctable class=\\\"uiGrid\\\" cellspacing=\\\"0\\\" cellpadding=\\\"0\\\"\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"vTop\\\"\\u003E\\u003Cdiv data-jsid=\\\"participantsTypeahead\\\"\\u003E\\u003C/div\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"vTop\\\"\\u003E\\u003Clabel class=\\\"doneButton uiButton uiButtonConfirm\\\" for=\\\"uq3j16_63\\\"\\u003E\\u003Cinput value=\\\"Done\\\" data-jsid=\\\"doneButton\\\" type=\\\"submit\\\" id=\\\"uq3j16_63\\\" /\\u003E\\u003C/label\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_172\",{\n            __html: \"\\u003Cimg class=\\\"hidden_elem MercuryTabSheetLoading img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yk/r/LOOn0JtHNzb.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"16\\\" /\\u003E\"\n        },2,],[\"m205559_173\",{\n            __html: \"\\u003Cdiv class=\\\"pas\\\"\\u003E\\u003Ci class=\\\"mrs sheet_img img sp_ae80w4 sx_0ca7fd\\\" data-jsid=\\\"image\\\"\\u003E\\u003C/i\\u003E\\u003Cspan class=\\\"sheet_content fcg\\\" data-jsid=\\\"text\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_174\",{\n            __html: \"\\u003Cdiv class=\\\"pas\\\"\\u003E\\u003Ci class=\\\"sheet_img img sp_627qpw sx_c709f6\\\" data-jsid=\\\"image\\\"\\u003E\\u003C/i\\u003E\\u003Cdiv class=\\\"sheet_content\\\"\\u003E\\u003Cspan class=\\\"fcg\\\" data-jsid=\\\"text\\\"\\u003E\\u003C/span\\u003E\\u003Cdiv\\u003E\\u003Ca href=\\\"#\\\" data-jsid=\\\"actionLink\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_175\",{\n            __html: \"\\u003Cdiv\\u003E\\u003Cdiv class=\\\"clearfix mvm mrm mll videoCallPromo\\\"\\u003E\\u003Ci class=\\\"-cx-PRIVATE-uiImageBlock__image -cx-PRIVATE-uiImageBlock__mediumImage lfloat img sp_46s4tm sx_81ea1c\\\"\\u003E\\u003C/i\\u003E\\u003Cdiv class=\\\"-cx-PRIVATE-uiImageBlock__content \\\"\\u003E\\u003Cdiv class=\\\"pls\\\"\\u003E\\u003Cspan class=\\\"calloutTitle fwb\\\"\\u003ETry talking face to face\\u003C/span\\u003E\\u003Cdiv class=\\\"fsm fwn fcg\\\"\\u003EClick \\u003Cspan\\u003E ( \\u003Ci class=\\\"onlineStatusIcon img sp_46s4tm sx_31fa21\\\"\\u003E\\u003C/i\\u003E )\\u003C/span\\u003E below to start a video call.\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"uiOverlayFooter uiContextualDialogFooter uiBoxGray topborder\\\"\\u003E\\u003Ctable class=\\\"uiGrid\\\" cellspacing=\\\"0\\\" cellpadding=\\\"0\\\"\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"prs uiOverlayFooterMessage\\\"\\u003E\\u003Ca target=\\\"_blank\\\" href=\\\"/help/?page=177940565599960\\\"\\u003ELearn more\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"uiOverlayFooterButtons\\\"\\u003E\\u003Ca class=\\\"uiOverlayButton layerCancel uiButton uiButtonConfirm\\\" href=\\\"#\\\" role=\\\"button\\\" name=\\\"cancel\\\"\\u003E\\u003Cspan class=\\\"uiButtonText\\\"\\u003EClose\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_176\",{\n            __html: \"\\u003Cdiv\\u003E\\u003Cdiv class=\\\"clearfix mvm mrm mll videoCallPromo\\\"\\u003E\\u003Ci class=\\\"-cx-PRIVATE-uiImageBlock__image -cx-PRIVATE-uiImageBlock__mediumImage lfloat img sp_46s4tm sx_81ea1c\\\"\\u003E\\u003C/i\\u003E\\u003Cdiv class=\\\"-cx-PRIVATE-uiImageBlock__content \\\"\\u003E\\u003Cdiv class=\\\"pls\\\"\\u003E\\u003Cspan class=\\\"calloutTitle fwb\\\"\\u003ETalk face to face\\u003C/span\\u003E\\u003Cdiv class=\\\"fsm fwn fcg\\\"\\u003EClick \\u003Cspan\\u003E ( \\u003Ci class=\\\"onlineStatusIcon img sp_46s4tm sx_31fa21\\\"\\u003E\\u003C/i\\u003E )\\u003C/span\\u003E below to start a video call.\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"uiOverlayFooter uiContextualDialogFooter uiBoxGray topborder\\\"\\u003E\\u003Ctable class=\\\"uiGrid\\\" cellspacing=\\\"0\\\" cellpadding=\\\"0\\\"\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"prs uiOverlayFooterMessage\\\"\\u003E\\u003Ca target=\\\"_blank\\\" href=\\\"/help/?page=177940565599960\\\"\\u003ELearn more\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"uiOverlayFooterButtons\\\"\\u003E\\u003Ca class=\\\"uiOverlayButton layerCancel uiButton uiButtonConfirm\\\" href=\\\"#\\\" role=\\\"button\\\" name=\\\"cancel\\\"\\u003E\\u003Cspan class=\\\"uiButtonText\\\"\\u003EOkay\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_177\",{\n            __html: \"\\u003Cdiv class=\\\"fbNub fbMercuryChatTab user\\\"\\u003E\\u003Ca class=\\\"fbNubButton\\\" tabindex=\\\"0\\\" href=\\\"#\\\" data-jsid=\\\"dockButton\\\"\\u003E\\u003Cdiv class=\\\"clearfix fbChatTab fbChatGroupTab\\\"\\u003E\\u003Cdiv class=\\\"funhouse rfloat\\\"\\u003E\\u003Cdiv class=\\\"close\\\" title=\\\"Close\\\" data-jsid=\\\"closeButton\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"wrapWrapper\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Cdiv class=\\\"name fwb\\\" data-jsid=\\\"name\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cspan class=\\\"numMessages hidden_elem\\\" data-jsid=\\\"numMessages\\\"\\u003E0\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"fbNubFlyout fbDockChatTabFlyout\\\" data-jsid=\\\"chatWrapper\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutOuter\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutInner\\\"\\u003E\\u003Cdiv class=\\\"clearfix fbNubFlyoutTitlebar titlebar\\\" data-jsid=\\\"nubFlyoutTitlebar\\\"\\u003E\\u003Cdiv class=\\\"mls titlebarButtonWrapper rfloat\\\"\\u003E\\u003Ca data-hover=\\\"tooltip\\\" title=\\\"Press Esc to close\\\" data-tooltip-alignh=\\\"center\\\" class=\\\"close button\\\" href=\\\"#\\\" data-jsid=\\\"titlebarCloseButton\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"titlebarLabel clearfix\\\"\\u003E\\u003Cdiv class=\\\"titlebarTextWrapper\\\"\\u003E\\u003Ca class=\\\"titlebarText noLink\\\" href=\\\"#\\\" rel=\\\"none\\\" data-jsid=\\\"titlebarText\\\" aria-level=\\\"3\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutHeader\\\"\\u003E\\u003Cdiv class=\\\"sheetContainer\\\"\\u003E\\u003Cdiv class=\\\"sheet hidden_elem\\\" data-jsid=\\\"sheet\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutBody scrollable\\\" data-jsid=\\\"chatConv\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutBodyContent\\\"\\u003E\\u003Ctable class=\\\"uiGrid conversationContainer\\\" cellspacing=\\\"0\\\" cellpadding=\\\"0\\\"\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"vBot\\\"\\u003E\\u003Cdiv class=\\\"accessible_elem\\\"\\u003EChat Conversation Start\\u003C/div\\u003E\\u003Cdiv class=\\\"conversation\\\" data-jsid=\\\"conversation\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"accessible_elem\\\"\\u003EChat Conversation End\\u003C/div\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutFooter\\\"\\u003E\\u003Cdiv class=\\\"inputContainer\\\"\\u003E\\u003Ctextarea class=\\\"uiTextareaAutogrow input\\\" data-jsid=\\\"input\\\" onkeydown=\\\"Bootloader.loadComponents([&quot;control-textarea&quot;], function() &#123; TextAreaControl.getInstance(this) &#125;.bind(this)); \\\"\\u003E\\u003C/textarea\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"emoticonsPanel\\\" data-jsid=\\\"emoticons\\\"\\u003E\\u003Ca class=\\\"emoteTogglerImg\\\" rel=\\\"toggle\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"panelFlyout uiToggleFlyout\\\"\\u003E\\u003Ctable\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_smile\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: 0px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_frown\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -16px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_tongue\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -32px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_grin\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -48px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_gasp\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -64px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_wink\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -80px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_pacman\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -304px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_grumpy\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -128px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_unsure\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -144px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_cry\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -160px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_kiki\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -240px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_glasses\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -96px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_sunglasses\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -112px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_heart\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -224px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_devil\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -176px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_angel\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -192px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_squint\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -256px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_confused\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -272px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_upset\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -288px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_colonthree\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -320px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_like\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -336px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003Cdiv class=\\\"panelFlyoutArrow\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_178\",{\n            __html: \"\\u003Cdiv class=\\\"fbNub fbMercuryChatTab user\\\"\\u003E\\u003Ca class=\\\"fbNubButton\\\" tabindex=\\\"0\\\" href=\\\"#\\\" data-jsid=\\\"dockButton\\\"\\u003E\\u003Cdiv class=\\\"clearfix fbChatTab fbChatGroupTab\\\"\\u003E\\u003Cdiv class=\\\"funhouse rfloat\\\"\\u003E\\u003Cdiv class=\\\"close\\\" title=\\\"Close\\\" data-jsid=\\\"closeButton\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"wrapWrapper\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Cdiv class=\\\"name fwb\\\" data-jsid=\\\"name\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cspan class=\\\"numMessages hidden_elem\\\" data-jsid=\\\"numMessages\\\"\\u003E0\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"fbNubFlyout fbDockChatTabFlyout\\\" data-jsid=\\\"chatWrapper\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutOuter\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutInner\\\"\\u003E\\u003Cdiv class=\\\"clearfix fbNubFlyoutTitlebar titlebar\\\" data-jsid=\\\"nubFlyoutTitlebar\\\"\\u003E\\u003Cdiv class=\\\"mls titlebarButtonWrapper rfloat\\\"\\u003E\\u003Ca data-hover=\\\"tooltip\\\" title=\\\"Press Esc to close\\\" data-tooltip-alignh=\\\"center\\\" class=\\\"close button\\\" href=\\\"#\\\" data-jsid=\\\"titlebarCloseButton\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"titlebarLabel clearfix\\\"\\u003E\\u003Cdiv class=\\\"titlebarTextWrapper\\\"\\u003E\\u003Ca class=\\\"titlebarText noLink\\\" href=\\\"#\\\" rel=\\\"none\\\" data-jsid=\\\"titlebarText\\\" aria-level=\\\"3\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutHeader\\\"\\u003E\\u003Cdiv class=\\\"sheetContainer\\\"\\u003E\\u003Cdiv class=\\\"sheet hidden_elem\\\" data-jsid=\\\"sheet\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutBody scrollable\\\" data-jsid=\\\"chatConv\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutBodyContent\\\"\\u003E\\u003Ctable class=\\\"uiGrid conversationContainer\\\" cellspacing=\\\"0\\\" cellpadding=\\\"0\\\"\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"vBot\\\"\\u003E\\u003Cdiv class=\\\"accessible_elem\\\"\\u003EChat Conversation Start\\u003C/div\\u003E\\u003Cdiv class=\\\"conversation\\\" data-jsid=\\\"conversation\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"accessible_elem\\\"\\u003EChat Conversation End\\u003C/div\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutFooter\\\"\\u003E\\u003Cdiv class=\\\"inputContainer\\\"\\u003E\\u003Ctextarea class=\\\"uiTextareaAutogrow input\\\" data-jsid=\\\"input\\\" onkeydown=\\\"Bootloader.loadComponents([&quot;control-textarea&quot;], function() &#123; TextAreaControl.getInstance(this) &#125;.bind(this)); \\\"\\u003E\\u003C/textarea\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"emoticonsPanel\\\" data-jsid=\\\"emoticons\\\"\\u003E\\u003Ca class=\\\"emoteTogglerImg\\\" rel=\\\"toggle\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"panelFlyout uiToggleFlyout\\\"\\u003E\\u003Ctable\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_smile\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: 0px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_frown\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -16px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_tongue\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -32px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_grin\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -48px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_gasp\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -64px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_wink\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -80px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_pacman\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -304px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_grumpy\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -128px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_unsure\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -144px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_cry\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -160px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_kiki\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -240px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_glasses\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -96px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_sunglasses\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -112px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_heart\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -224px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_devil\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -176px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_angel\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -192px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_squint\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -256px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_confused\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -272px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_upset\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -288px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_colonthree\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -320px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_like\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -336px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003Cdiv class=\\\"panelFlyoutArrow\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205560_181\",{\n            __html: \"Options\"\n        },2,],[\"m205560_179\",{\n            __html: \"\\u003Cdiv class=\\\"fbNub fbMercuryChatTab thread\\\"\\u003E\\u003Ca class=\\\"fbNubButton\\\" tabindex=\\\"0\\\" href=\\\"#\\\" data-jsid=\\\"dockButton\\\"\\u003E\\u003Cdiv class=\\\"clearfix fbChatTab fbChatThreadTab\\\"\\u003E\\u003Cdiv class=\\\"funhouse rfloat\\\"\\u003E\\u003Cdiv class=\\\"close\\\" title=\\\"Close\\\" data-jsid=\\\"closeButton\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"wrapWrapper\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Cdiv class=\\\"name fwb\\\" data-jsid=\\\"name\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cspan class=\\\"numMessages hidden_elem\\\" data-jsid=\\\"numMessages\\\"\\u003E0\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"fbNubFlyout fbDockChatTabFlyout\\\" data-jsid=\\\"chatWrapper\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutOuter\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutInner\\\"\\u003E\\u003Cdiv class=\\\"clearfix fbNubFlyoutTitlebar titlebar\\\" data-jsid=\\\"nubFlyoutTitlebar\\\"\\u003E\\u003Cdiv class=\\\"mls titlebarButtonWrapper rfloat\\\"\\u003E\\u003Ca data-hover=\\\"tooltip\\\" title=\\\"Add more friends to chat\\\" data-tooltip-alignh=\\\"center\\\" class=\\\"addToThread button\\\" href=\\\"#\\\" data-jsid=\\\"addToThreadLink\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"uiSelector inlineBlock fbDockChatDropdown\\\" data-jsid=\\\"dropdown\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Ca data-hover=\\\"tooltip\\\" data-tooltip-alignh=\\\"center\\\" class=\\\"button uiSelectorButton\\\" href=\\\"#\\\" role=\\\"button\\\" aria-haspopup=\\\"1\\\" rel=\\\"toggle\\\" id=\\\"uq3j16_64\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"uiSelectorMenuWrapper uiToggleFlyout\\\"\\u003E\\u003Cdiv role=\\\"menu\\\" class=\\\"uiMenu uiSelectorMenu\\\"\\u003E\\u003Cul class=\\\"uiMenuInner\\\"\\u003E\\u003Cli class=\\\"uiMenuItem\\\" data-label=\\\"See Full Conversation\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"0\\\" href=\\\"#\\\" data-jsid=\\\"conversationLink\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003ESee Full Conversation\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem\\\" data-label=\\\"Add Friends to Chat...\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" data-jsid=\\\"addFriendLink\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003EAdd Friends to Chat...\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuSeparator\\\"\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem\\\" data-label=\\\"Leave Conversation...\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" data-jsid=\\\"unsubscribeLink\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003ELeave Conversation...\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Ca data-hover=\\\"tooltip\\\" title=\\\"Press Esc to close\\\" data-tooltip-alignh=\\\"center\\\" class=\\\"close button\\\" href=\\\"#\\\" data-jsid=\\\"titlebarCloseButton\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"titlebarLabel clearfix\\\"\\u003E\\u003Cdiv class=\\\"titlebarTextWrapper\\\"\\u003E\\u003Ca class=\\\"titlebarText noLink\\\" href=\\\"#\\\" rel=\\\"none\\\" data-jsid=\\\"titlebarText\\\" aria-level=\\\"3\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutHeader\\\"\\u003E\\u003Cdiv class=\\\"sheetContainer\\\"\\u003E\\u003Cdiv class=\\\"sheet hidden_elem\\\" data-jsid=\\\"sheet\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutBody scrollable\\\" data-jsid=\\\"chatConv\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutBodyContent\\\"\\u003E\\u003Ctable class=\\\"uiGrid conversationContainer\\\" cellspacing=\\\"0\\\" cellpadding=\\\"0\\\"\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"vBot\\\"\\u003E\\u003Cdiv class=\\\"accessible_elem\\\"\\u003EChat Conversation Start\\u003C/div\\u003E\\u003Cdiv class=\\\"conversation\\\" data-jsid=\\\"conversation\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"accessible_elem\\\"\\u003EChat Conversation End\\u003C/div\\u003E\\u003Cdiv class=\\\"-cx-PRIVATE-mercuryTypingIndicator__root typingIndicator\\\" data-jsid=\\\"typingIndicator\\\"\\u003E\\u003Cdiv class=\\\"-cx-PRIVATE-mercuryTypingIndicator__icon\\\"\\u003E\\u003C/div\\u003E\\u003Cspan class=\\\"-cx-PRIVATE-mercuryTypingIndicator__text\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutFooter\\\"\\u003E\\u003Cdiv class=\\\"inputContainer\\\"\\u003E\\u003Ctextarea class=\\\"uiTextareaAutogrow input\\\" data-jsid=\\\"input\\\" onkeydown=\\\"Bootloader.loadComponents([&quot;control-textarea&quot;], function() &#123; TextAreaControl.getInstance(this) &#125;.bind(this)); \\\"\\u003E\\u003C/textarea\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"emoticonsPanel\\\" data-jsid=\\\"emoticons\\\"\\u003E\\u003Ca class=\\\"emoteTogglerImg\\\" rel=\\\"toggle\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"panelFlyout uiToggleFlyout\\\"\\u003E\\u003Ctable\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_smile\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: 0px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_frown\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -16px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_tongue\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -32px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_grin\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -48px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_gasp\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -64px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_wink\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -80px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_pacman\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -304px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_grumpy\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -128px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_unsure\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -144px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_cry\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -160px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_kiki\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -240px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_glasses\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -96px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_sunglasses\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -112px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_heart\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -224px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_devil\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -176px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_angel\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -192px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_squint\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -256px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_confused\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -272px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_upset\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -288px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_colonthree\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -320px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_like\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -336px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003Cdiv class=\\\"panelFlyoutArrow\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },3,],[\"m205560_184\",{\n            __html: \"Options\"\n        },2,],[\"m205560_182\",{\n            __html: \"\\u003Cdiv class=\\\"fbNub fbMercuryChatTab user\\\"\\u003E\\u003Ca class=\\\"fbNubButton\\\" tabindex=\\\"0\\\" href=\\\"#\\\" data-jsid=\\\"dockButton\\\"\\u003E\\u003Cdiv class=\\\"clearfix fbChatTab fbChatUserTab\\\"\\u003E\\u003Cdiv class=\\\"funhouse rfloat\\\"\\u003E\\u003Cdiv class=\\\"close\\\" title=\\\"Close\\\" data-jsid=\\\"closeButton\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"wrapWrapper\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Cdiv class=\\\"name fwb\\\" data-jsid=\\\"name\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cspan class=\\\"numMessages hidden_elem\\\" data-jsid=\\\"numMessages\\\"\\u003E0\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"fbNubFlyout fbDockChatTabFlyout\\\" data-jsid=\\\"chatWrapper\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutOuter\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutInner\\\"\\u003E\\u003Cdiv class=\\\"clearfix fbNubFlyoutTitlebar titlebar\\\" data-jsid=\\\"nubFlyoutTitlebar\\\"\\u003E\\u003Cdiv class=\\\"mls titlebarButtonWrapper rfloat\\\"\\u003E\\u003Ca data-hover=\\\"tooltip\\\" title=\\\"Start a video call\\\" data-tooltip-alignh=\\\"center\\\" class=\\\"videoicon button\\\" href=\\\"#\\\" data-jsid=\\\"videoCallLink\\\" data-gt=\\\"&#123;&quot;videochat&quot;:&quot;call_clicked_chat_tab&quot;&#125;\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"uiSelector inlineBlock fbDockChatDropdown\\\" data-jsid=\\\"dropdown\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Ca data-hover=\\\"tooltip\\\" data-tooltip-alignh=\\\"center\\\" class=\\\"button uiSelectorButton\\\" href=\\\"#\\\" role=\\\"button\\\" aria-haspopup=\\\"1\\\" rel=\\\"toggle\\\" id=\\\"uq3j16_65\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"uiSelectorMenuWrapper uiToggleFlyout\\\"\\u003E\\u003Cdiv role=\\\"menu\\\" class=\\\"uiMenu uiSelectorMenu\\\"\\u003E\\u003Cul class=\\\"uiMenuInner\\\"\\u003E\\u003Cli class=\\\"uiMenuItem\\\" data-label=\\\"Add Friends to Chat...\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"0\\\" href=\\\"#\\\" data-jsid=\\\"addFriendLink\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003EAdd Friends to Chat...\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem\\\" data-label=\\\"\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" data-jsid=\\\"privacyLink\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003E \\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuSeparator\\\"\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem\\\" data-label=\\\"See Full Conversation\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" data-jsid=\\\"conversationLink\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003ESee Full Conversation\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem\\\" data-label=\\\"Clear Window\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" data-jsid=\\\"clearWindowLink\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003EClear Window\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuSeparator\\\"\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem\\\" data-label=\\\"Report as Spam\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" data-jsid=\\\"reportSpamLink\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003EReport as Spam\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Ca data-hover=\\\"tooltip\\\" title=\\\"Press Esc to close\\\" data-tooltip-alignh=\\\"center\\\" class=\\\"close button\\\" href=\\\"#\\\" data-jsid=\\\"titlebarCloseButton\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"titlebarLabel clearfix\\\"\\u003E\\u003Cdiv class=\\\"titlebarTextWrapper\\\"\\u003E\\u003Ca class=\\\"titlebarText noLink\\\" href=\\\"#\\\" rel=\\\"none\\\" data-jsid=\\\"titlebarText\\\" aria-level=\\\"3\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutHeader\\\"\\u003E\\u003Cdiv class=\\\"sheetContainer\\\"\\u003E\\u003Cdiv class=\\\"sheet hidden_elem\\\" data-jsid=\\\"sheet\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutBody scrollable\\\" data-jsid=\\\"chatConv\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutBodyContent\\\"\\u003E\\u003Ctable class=\\\"uiGrid conversationContainer\\\" cellspacing=\\\"0\\\" cellpadding=\\\"0\\\"\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"vBot\\\"\\u003E\\u003Cdiv class=\\\"accessible_elem\\\"\\u003EChat Conversation Start\\u003C/div\\u003E\\u003Cdiv class=\\\"conversation\\\" data-jsid=\\\"conversation\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"accessible_elem\\\"\\u003EChat Conversation End\\u003C/div\\u003E\\u003Cdiv class=\\\"-cx-PRIVATE-mercuryTypingIndicator__root typingIndicator\\\" data-jsid=\\\"typingIndicator\\\"\\u003E\\u003Cdiv class=\\\"-cx-PRIVATE-mercuryTypingIndicator__icon\\\"\\u003E\\u003C/div\\u003E\\u003Cspan class=\\\"-cx-PRIVATE-mercuryTypingIndicator__text\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutFooter\\\"\\u003E\\u003Cdiv class=\\\"inputContainer\\\"\\u003E\\u003Ctextarea class=\\\"uiTextareaAutogrow input\\\" data-jsid=\\\"input\\\" onkeydown=\\\"Bootloader.loadComponents([&quot;control-textarea&quot;], function() &#123; TextAreaControl.getInstance(this) &#125;.bind(this)); \\\"\\u003E\\u003C/textarea\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"emoticonsPanel\\\" data-jsid=\\\"emoticons\\\"\\u003E\\u003Ca class=\\\"emoteTogglerImg\\\" rel=\\\"toggle\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"panelFlyout uiToggleFlyout\\\"\\u003E\\u003Ctable\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_smile\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: 0px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_frown\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -16px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_tongue\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -32px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_grin\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -48px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_gasp\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -64px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_wink\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -80px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_pacman\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -304px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_grumpy\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -128px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_unsure\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -144px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_cry\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -160px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_kiki\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -240px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_glasses\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -96px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_sunglasses\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -112px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_heart\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -224px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_devil\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -176px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_angel\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -192px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_squint\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -256px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_confused\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -272px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_upset\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -288px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_colonthree\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -320px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_like\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -336px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003Cdiv class=\\\"panelFlyoutArrow\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },3,],[\"m205561_185\",{\n            __html: \"\\u003Cdiv class=\\\"clearfix mvs\\\"\\u003E\\u003Ci class=\\\"rfloat img sp_ae80w4 sx_d14d96\\\" data-jsid=\\\"icon\\\"\\u003E\\u003C/i\\u003E\\u003Cdiv data-jsid=\\\"name\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205561_186\",{\n            __html: \"\\u003Cdiv\\u003E\\u003Ca class=\\\"uiIconText\\\" href=\\\"#\\\" style=\\\"padding-left: 12px;\\\" data-jsid=\\\"forwardLink\\\"\\u003E\\u003Ci class=\\\"img sp_46s4tm sx_f93b30\\\" style=\\\"top: 3px;\\\"\\u003E\\u003C/i\\u003E\\u003Cspan data-jsid=\\\"forwardText\\\"\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205561_187\",{\n            __html: \"\\u003Cabbr title=\\\"Wednesday, December 31, 1969 at 7:00pm\\\" data-utime=\\\"0\\\" class=\\\"hidden_elem timestamp\\\" data-jsid=\\\"timestamp\\\"\\u003Eover a year ago\\u003C/abbr\\u003E\"\n        },2,],[\"m205561_188\",{\n            __html: \"\\u003Cli class=\\\"item\\\"\\u003E\\u003Ca class=\\\"clearfix\\\" href=\\\"#\\\" rel=\\\"ignore\\\" data-jsid=\\\"anchor\\\"\\u003E\\u003Cimg class=\\\"pic\\\" src=\\\"/images/spacer.gif\\\" data-jsid=\\\"profile-photo\\\" /\\u003E\\u003Cdiv class=\\\"icons\\\"\\u003E\\u003Cimg class=\\\"lb_status icon img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/y4/r/-PAXP-deijE.gif\\\" alt=\\\"\\\" width=\\\"1\\\" height=\\\"1\\\" /\\u003E\\u003Cimg class=\\\"status icon img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/y4/r/-PAXP-deijE.gif\\\" alt=\\\"\\\" width=\\\"1\\\" height=\\\"1\\\" /\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"name\\\" data-jsid=\\\"name\\\"\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\"\n        },2,],[\"m205561_189\",{\n            __html: \"\\u003Cli\\u003E\\u003Cdiv class=\\\"phs fcg\\\"\\u003E\\u003Cspan data-jsid=\\\"message\\\"\\u003ELoading...\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/li\\u003E\"\n        },2,],],\n        elements: [[\"m205558_121\",\"uq3j16_53\",2,],[\"m205558_144\",\"fbDockChat\",2,],[\"m205558_145\",\"fbDockChatTabs\",2,],[\"m205558_146\",\"fbDockChatBuddylistNub\",2,],[\"m205558_151\",\"uq3j16_55\",2,],[\"m205558_152\",\"uq3j16_56\",2,],[\"m205558_150\",\"uq3j16_58\",4,],[\"m205558_154\",\"uq3j16_59\",2,],[\"m205559_160\",\"uq3j16_61\",2,],[\"m205559_156\",\"uq3j16_62\",2,],[\"m205560_180\",\"uq3j16_64\",2,\"m205560_179\",],[\"m205560_183\",\"uq3j16_65\",2,\"m205560_182\",],],\n        define: [[\"AvailableListInitialData\",[],{\n            pollInterval: 100000,\n            lazyPollInterval: 300000,\n            lazyThreshold: 300000,\n            updateTime: 0,\n            availableList: {\n            },\n            availableCount: 0,\n            mobileFriends: null,\n            chatNotif: 0\n        },],[\"ChatOptionsInitialData\",[],{\n            sound: 1,\n            sidebar_mode: 1,\n            browser_notif: 0\n        },],[\"ChatTabTemplates\",[\"m205558_123\",\"m205558_124\",\"m205558_125\",\"m205558_126\",\"m205558_127\",\"m205558_128\",\"m205558_129\",\"m205558_130\",\"m205558_131\",\"m205558_132\",\"m205558_133\",\"m205558_134\",\"m205558_135\",\"m205558_136\",\"m205558_137\",\"m205558_138\",\"m205558_139\",\"m205558_140\",\"m205558_141\",\"m205558_142\",\"m205558_143\",],{\n            \":fb:chat:conversation:date-break\": {\n                __m: \"m205558_123\"\n            },\n            \":fb:chat:conversation:message\": {\n                __m: \"m205558_124\"\n            },\n            \":fb:chat:conversation:message:event\": {\n                __m: \"m205558_125\"\n            },\n            \":fb:chat:conversation:message:status\": {\n                __m: \"m205558_126\"\n            },\n            \":fb:chat:conversation:message:subject\": {\n                __m: \"m205558_127\"\n            },\n            \":fb:chat:conversation:message-group\": {\n                __m: \"m205558_128\"\n            },\n            \":fb:chat:tab:selector\": {\n                __m: \"m205558_129\"\n            },\n            \":fb:chat:tab:selector:item\": {\n                __m: \"m205558_130\"\n            },\n            \":fb:mercury:chat:tab-sheet:add-friends\": {\n                __m: \"m205558_131\"\n            },\n            \":fb:mercury:chat:tab-sheet:loading\": {\n                __m: \"m205558_132\"\n            },\n            \":fb:mercury:chat:tab-sheet:message-icon-sheet\": {\n                __m: \"m205558_133\"\n            },\n            \":fb:mercury:chat:tab-sheet:user-blocked\": {\n                __m: \"m205558_134\"\n            },\n            \":fb:mercury:call:promo\": {\n                __m: \"m205558_135\"\n            },\n            \":fb:mercury:call:tour\": {\n                __m: \"m205558_136\"\n            },\n            \":fb:mercury:chat:group-tab\": {\n                __m: \"m205558_137\"\n            },\n            \":fb:mercury:chat:live-listen-tab\": {\n                __m: \"m205558_138\"\n            },\n            \":fb:mercury:chat:multichat-tab\": {\n                __m: \"m205558_139\"\n            },\n            \":fb:mercury:chat:user-tab\": {\n                __m: \"m205558_140\"\n            },\n            \":fb:mercury:chat:multichat-tooltip-item\": {\n                __m: \"m205558_141\"\n            },\n            \":fb:mercury:chat:message:forward\": {\n                __m: \"m205558_142\"\n            },\n            \":fb:mercury:timestamp\": {\n                __m: \"m205558_143\"\n            }\n        },],[\"ChatSidebarCalloutData\",[],{\n            isShown: false\n        },],],\n        require: [[\"MusicButtonManager\",\"init\",[],[[\"music.song\",],],],[\"Dock\",\"init\",[\"m205558_121\",],[{\n            __m: \"m205558_121\"\n        },],],[\"AvailableList\",],[\"ChatApp\",\"init\",[\"m205558_144\",\"m205558_145\",],[{\n            __m: \"m205558_144\"\n        },{\n            __m: \"m205558_145\"\n        },{\n            payload_source: \"server_initial_data\"\n        },],],[\"m205558_147\",],[\"m205558_149\",],[\"Typeahead\",\"init\",[\"m205558_150\",\"m205558_149\",],[{\n            __m: \"m205558_150\"\n        },{\n            __m: \"m205558_149\"\n        },[\"chatTypeahead\",\"buildBestAvailableNames\",\"showLoadingIndicator\",],null,],],[\"ClearableTypeahead\",\"resetOnCloseButtonClick\",[\"m205558_149\",\"m205558_152\",],[{\n            __m: \"m205558_149\"\n        },{\n            __m: \"m205558_152\"\n        },],],[\"m205558_155\",],[\"Tooltip\",\"set\",[\"m205559_156\",\"m205559_157\",],[{\n            __m: \"m205559_156\"\n        },{\n            __m: \"m205559_157\"\n        },],],[\"m205559_158\",],[\"Layer\",\"init\",[\"m205559_158\",\"m205559_159\",],[{\n            __m: \"m205559_158\"\n        },{\n            __m: \"m205559_159\"\n        },],],[\"m205558_148\",],[\"Tooltip\",\"set\",[\"m205560_180\",\"m205560_181\",],[{\n            __m: \"m205560_180\"\n        },{\n            __m: \"m205560_181\"\n        },],],[\"Tooltip\",\"set\",[\"m205560_183\",\"m205560_184\",],[{\n            __m: \"m205560_183\"\n        },{\n            __m: \"m205560_184\"\n        },],],]\n    },\n    css: [\"zO4BE\",\"z8dwT\",],\n    bootloadable: {\n        beeper: {\n            resources: [\"8gPM0\",\"bS0QP\",\"JOZ9R\",\"v4i0/\",\"6n1TR\",\"FCMVl\",\"1zqwA\",\"C6rJk\",\"zO4BE\",\"1lJOt\",\"48vAQ\",\"+21JG\",]\n        },\n        VideoCallController: {\n            resources: [\"bS0QP\",\"8gPM0\",\"1zqwA\",\"zO4BE\",\"IZaDN\",\"3HhWt\",\"KPLqg\",\"78mGG\",],\n            \"module\": true\n        }\n    },\n    resource_map: {\n        \"v4i0/\": {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yG/r/Skc_dFkcWkO.js\"\n        },\n        FCMVl: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yU/r/Yv6SBFEngDU.js\"\n        },\n        \"1lJOt\": {\n            type: \"css\",\n            permanent: 1,\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yV/r/oO1k_VFjNKF.css\"\n        },\n        \"48vAQ\": {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yv/r/5lpXIw2-Ra7.js\"\n        },\n        \"+21JG\": {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yd/r/GPrBtdk0jHE.js\"\n        },\n        IZaDN: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/ye/r/iP4keJA_tRb.js\"\n        },\n        \"3HhWt\": {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y3/r/Ttq-aeZF5gs.js\"\n        },\n        KPLqg: {\n            type: \"css\",\n            permanent: 1,\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y_/r/seDGnw8i6fH.css\"\n        },\n        \"78mGG\": {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yC/r/t8-RMyEFiOt.js\"\n        }\n    },\n    js: [\"8gPM0\",\"bS0QP\",\"6n1TR\",\"1zqwA\",\"tZ04z\",],\n    onload: [\"init_live_message_receive({\\\"useAggregatedBottomBeeper\\\":0});\",\"define(\\\"MercuryDataSource\\\", [], require(\\\"m205558_122\\\"));\",],\n    content: {\n        pagelet_dock: {\n            container_id: \"uq3j16_66\"\n        }\n    }\n});");
// 1715
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s47b5326e975fd2bf358277a79c080b37881008dd");
// 1716
geval("bigPipe.JSBNG__onPageletArrive({\n    phase: 3,\n    id: \"pagelet_dock\",\n    jsmods: {\n        instances: [[\"m205558_147\",[\"BuddyListNub\",\"m205558_146\",\"m205558_148\",\"m205558_149\",],[{\n            __m: \"m205558_146\"\n        },{\n            __m: \"m205558_148\"\n        },{\n            __m: \"m205558_149\"\n        },],1,],[\"m205558_149\",[\"Typeahead\",\"m205558_153\",\"TypeaheadView\",\"ChatTypeaheadRenderer\",\"m205558_150\",\"ChatTypeaheadCore\",\"m205558_151\",],[{\n            __m: \"m205558_153\"\n        },{\n            node_id: \"uq3j16_54\",\n            ctor: {\n                __m: \"TypeaheadView\"\n            },\n            options: {\n                autoSelect: true,\n                renderer: {\n                    __m: \"ChatTypeaheadRenderer\"\n                },\n                causalElement: {\n                    __m: \"m205558_150\"\n                }\n            }\n        },{\n            ctor: {\n                __m: \"ChatTypeaheadCore\"\n            },\n            options: {\n                keepFocused: false,\n                resetOnSelect: true,\n                setValueOnSelect: false\n            }\n        },{\n            __m: \"m205558_151\"\n        },],7,],[\"m205558_155\",[\"ChatSidebarDropdown\",\"m205558_154\",],[{\n            __m: \"m205558_154\"\n        },],1,],[\"m205559_158\",[\"ContextualDialogX\",\"AccessibleLayer\",],[{\n            buildWrapper: false,\n            causalElement: null,\n            addedBehaviors: [{\n                __m: \"AccessibleLayer\"\n            },]\n        },],5,],[\"m205558_148\",[\"ChatOrderedList\",\"m205559_160\",\"m205559_161\",\"m205559_162\",\"m205559_158\",],[{\n            __m: \"m205559_160\"\n        },{\n            __m: \"m205559_161\"\n        },{\n            __m: \"m205559_162\"\n        },{\n            __m: \"m205559_158\"\n        },],3,],[\"m205558_122\",[\"DataSource\",],[{\n            maxResults: 5,\n            queryData: [],\n            bootstrapData: {\n                viewer: 100001812504199,\n                token: \"1343822055-7\",\n                filter: [\"user\",],\n                options: [\"friends_only\",]\n            },\n            bootstrapEndpoint: \"/ajax/typeahead/first_degree.php\"\n        },],1,],[\"m205558_123\",[\"XHPTemplate\",\"m205559_163\",],[{\n            __m: \"m205559_163\"\n        },],2,],[\"m205558_124\",[\"XHPTemplate\",\"m205559_164\",],[{\n            __m: \"m205559_164\"\n        },],2,],[\"m205558_125\",[\"XHPTemplate\",\"m205559_165\",],[{\n            __m: \"m205559_165\"\n        },],2,],[\"m205558_126\",[\"XHPTemplate\",\"m205559_166\",],[{\n            __m: \"m205559_166\"\n        },],2,],[\"m205558_127\",[\"XHPTemplate\",\"m205559_167\",],[{\n            __m: \"m205559_167\"\n        },],2,],[\"m205558_128\",[\"XHPTemplate\",\"m205559_168\",],[{\n            __m: \"m205559_168\"\n        },],2,],[\"m205558_129\",[\"XHPTemplate\",\"m205559_169\",],[{\n            __m: \"m205559_169\"\n        },],2,],[\"m205558_130\",[\"XHPTemplate\",\"m205559_170\",],[{\n            __m: \"m205559_170\"\n        },],2,],[\"m205558_131\",[\"XHPTemplate\",\"m205559_171\",],[{\n            __m: \"m205559_171\"\n        },],2,],[\"m205558_132\",[\"XHPTemplate\",\"m205559_172\",],[{\n            __m: \"m205559_172\"\n        },],2,],[\"m205558_133\",[\"XHPTemplate\",\"m205559_173\",],[{\n            __m: \"m205559_173\"\n        },],2,],[\"m205558_134\",[\"XHPTemplate\",\"m205559_174\",],[{\n            __m: \"m205559_174\"\n        },],2,],[\"m205558_135\",[\"XHPTemplate\",\"m205559_175\",],[{\n            __m: \"m205559_175\"\n        },],2,],[\"m205558_136\",[\"XHPTemplate\",\"m205559_176\",],[{\n            __m: \"m205559_176\"\n        },],2,],[\"m205558_137\",[\"XHPTemplate\",\"m205559_177\",],[{\n            __m: \"m205559_177\"\n        },],2,],[\"m205558_138\",[\"XHPTemplate\",\"m205559_178\",],[{\n            __m: \"m205559_178\"\n        },],2,],[\"m205558_139\",[\"XHPTemplate\",\"m205560_179\",],[{\n            __m: \"m205560_179\"\n        },],2,],[\"m205558_140\",[\"XHPTemplate\",\"m205560_182\",],[{\n            __m: \"m205560_182\"\n        },],2,],[\"m205558_141\",[\"XHPTemplate\",\"m205561_185\",],[{\n            __m: \"m205561_185\"\n        },],2,],[\"m205558_142\",[\"XHPTemplate\",\"m205561_186\",],[{\n            __m: \"m205561_186\"\n        },],2,],[\"m205558_143\",[\"XHPTemplate\",\"m205561_187\",],[{\n            __m: \"m205561_187\"\n        },],2,],[\"m205558_153\",[\"ChatTypeaheadDataSource\",],[{\n            showOfflineUsers: true\n        },],2,],[\"m205559_161\",[\"XHPTemplate\",\"m205561_188\",],[{\n            __m: \"m205561_188\"\n        },],2,],[\"m205559_162\",[\"XHPTemplate\",\"m205561_189\",],[{\n            __m: \"m205561_189\"\n        },],2,],],\n        markup: [[\"m205559_157\",{\n            __html: \"Options\"\n        },2,],[\"m205559_159\",{\n            __html: \"\\u003Cdiv class=\\\"uiContextualDialogPositioner\\\" id=\\\"uq3j16_60\\\" data-position=\\\"left\\\"\\u003E\\u003Cdiv class=\\\"uiOverlay uiContextualDialog\\\" data-width=\\\"300\\\" data-destroyonhide=\\\"false\\\" data-fadeonhide=\\\"false\\\"\\u003E\\u003Cdiv class=\\\"uiOverlayContent\\\"\\u003E\\u003Cdiv class=\\\"uiContextualDialogContent\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_163\",{\n            __html: \"\\u003Cdiv class=\\\"mhs mbs fbChatConvItem fbChatConvDateBreak fss fwb fcg\\\" data-jsid=\\\"date\\\"\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_164\",{\n            __html: \"\\u003Cdiv class=\\\"fbChatMessage fsm\\\" data-jsid=\\\"message\\\"\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_165\",{\n            __html: \"\\u003Cdiv class=\\\"mhs mbs pts fbChatConvItem fbChatEventMsg clearfix\\\"\\u003E\\u003Cdiv class=\\\"iconWrapper\\\"\\u003E\\u003Cimg class=\\\"eventIcon img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/y4/r/-PAXP-deijE.gif\\\" data-jsid=\\\"icon\\\" alt=\\\"\\\" width=\\\"1\\\" height=\\\"1\\\" /\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"messageWrapper\\\"\\u003E\\u003Cspan class=\\\"message fsm fcg\\\" data-jsid=\\\"message\\\"\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"mls timestamp rfloat fss fcg\\\" data-jsid=\\\"timestamp\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"logMessageAttachment\\\" data-jsid=\\\"attachment\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_166\",{\n            __html: \"\\u003Cdiv class=\\\"clearfix\\\"\\u003E\\u003Cdiv data-jsid=\\\"status\\\" class=\\\"rfloat\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbChatMessage fsm fcg\\\" data-jsid=\\\"message\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_167\",{\n            __html: \"\\u003Cdiv class=\\\"fbChatMessageSubject fsm fwb\\\" data-jsid=\\\"messageSubject\\\"\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_168\",{\n            __html: \"\\u003Cdiv class=\\\"mhs mbs pts fbChatConvItem fbChatMessageGroup clearfix small\\\"\\u003E\\u003Ca class=\\\"profileLink\\\" href=\\\"#\\\" data-jsid=\\\"profileLink\\\"\\u003E\\u003Cimg class=\\\"profilePhoto\\\" src=\\\"/images/spacer.gif\\\" data-jsid=\\\"profilePhoto\\\" /\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"messages\\\" data-jsid=\\\"messages\\\"\\u003E\\u003Cdiv class=\\\"metaInfoContainer fss fcg\\\"\\u003E\\u003Cspan data-jsid=\\\"reportLinkWithDot\\\" class=\\\"hidden_elem\\\"\\u003E\\u003Ca href=\\\"#\\\" rel=\\\"dialog\\\" data-jsid=\\\"reportLink\\\"\\u003E\\u003Cspan class=\\\"fcg\\\"\\u003EReport\\u003C/span\\u003E\\u003C/a\\u003E \\u00b7 \\u003C/span\\u003E\\u003Cspan class=\\\"timestamp\\\" data-jsid=\\\"timestamp\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_169\",{\n            __html: \"\\u003Cdiv class=\\\"fbNub fbChatTabSelector\\\"\\u003E\\u003Ca class=\\\"fbNubButton\\\" tabindex=\\\"0\\\" href=\\\"#\\\" rel=\\\"toggle\\\"\\u003E\\u003Ci class=\\\"messagesIcon img sp_ae80w4 sx_0ca7fd\\\"\\u003E\\u003C/i\\u003E\\u003Cspan data-jsid=\\\"numTabs\\\"\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"numMessages\\\" data-jsid=\\\"numMessages\\\"\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"fbNubFlyout uiToggleFlyout noTitlebar\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutOuter\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutInner\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutBody scrollable\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutBodyContent\\\"\\u003E\\u003Cdiv role=\\\"menu\\\" class=\\\"uiMenu\\\" data-jsid=\\\"menu\\\"\\u003E\\u003Cul class=\\\"uiMenuInner\\\"\\u003E\\u003Cli class=\\\"uiMenuItem\\\" data-label=\\\"Dummy\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"0\\\" href=\\\"#\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003E Dummy \\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_170\",{\n            __html: \"\\u003Cli class=\\\"uiMenuItem fbChatTabSelectorItem\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003E\\u003Cspan class=\\\"unreadCount\\\" data-jsid=\\\"unreadCount\\\"\\u003E\\u003C/span\\u003E\\u003Cspan data-jsid=\\\"content\\\"\\u003E\\u003C/span\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\"\n        },2,],[\"m205559_171\",{\n            __html: \"\\u003Cdiv class=\\\"addFriends\\\"\\u003E\\u003Ctable class=\\\"uiGrid\\\" cellspacing=\\\"0\\\" cellpadding=\\\"0\\\"\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"vTop\\\"\\u003E\\u003Cdiv data-jsid=\\\"participantsTypeahead\\\"\\u003E\\u003C/div\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"vTop\\\"\\u003E\\u003Clabel class=\\\"doneButton uiButton uiButtonConfirm\\\" for=\\\"uq3j16_63\\\"\\u003E\\u003Cinput value=\\\"Done\\\" data-jsid=\\\"doneButton\\\" type=\\\"submit\\\" id=\\\"uq3j16_63\\\" /\\u003E\\u003C/label\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_172\",{\n            __html: \"\\u003Cimg class=\\\"hidden_elem MercuryTabSheetLoading img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yk/r/LOOn0JtHNzb.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"16\\\" /\\u003E\"\n        },2,],[\"m205559_173\",{\n            __html: \"\\u003Cdiv class=\\\"pas\\\"\\u003E\\u003Ci class=\\\"mrs sheet_img img sp_ae80w4 sx_0ca7fd\\\" data-jsid=\\\"image\\\"\\u003E\\u003C/i\\u003E\\u003Cspan class=\\\"sheet_content fcg\\\" data-jsid=\\\"text\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_174\",{\n            __html: \"\\u003Cdiv class=\\\"pas\\\"\\u003E\\u003Ci class=\\\"sheet_img img sp_627qpw sx_c709f6\\\" data-jsid=\\\"image\\\"\\u003E\\u003C/i\\u003E\\u003Cdiv class=\\\"sheet_content\\\"\\u003E\\u003Cspan class=\\\"fcg\\\" data-jsid=\\\"text\\\"\\u003E\\u003C/span\\u003E\\u003Cdiv\\u003E\\u003Ca href=\\\"#\\\" data-jsid=\\\"actionLink\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_175\",{\n            __html: \"\\u003Cdiv\\u003E\\u003Cdiv class=\\\"clearfix mvm mrm mll videoCallPromo\\\"\\u003E\\u003Ci class=\\\"-cx-PRIVATE-uiImageBlock__image -cx-PRIVATE-uiImageBlock__mediumImage lfloat img sp_46s4tm sx_81ea1c\\\"\\u003E\\u003C/i\\u003E\\u003Cdiv class=\\\"-cx-PRIVATE-uiImageBlock__content \\\"\\u003E\\u003Cdiv class=\\\"pls\\\"\\u003E\\u003Cspan class=\\\"calloutTitle fwb\\\"\\u003ETry talking face to face\\u003C/span\\u003E\\u003Cdiv class=\\\"fsm fwn fcg\\\"\\u003EClick \\u003Cspan\\u003E ( \\u003Ci class=\\\"onlineStatusIcon img sp_46s4tm sx_31fa21\\\"\\u003E\\u003C/i\\u003E )\\u003C/span\\u003E below to start a video call.\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"uiOverlayFooter uiContextualDialogFooter uiBoxGray topborder\\\"\\u003E\\u003Ctable class=\\\"uiGrid\\\" cellspacing=\\\"0\\\" cellpadding=\\\"0\\\"\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"prs uiOverlayFooterMessage\\\"\\u003E\\u003Ca target=\\\"_blank\\\" href=\\\"/help/?page=177940565599960\\\"\\u003ELearn more\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"uiOverlayFooterButtons\\\"\\u003E\\u003Ca class=\\\"uiOverlayButton layerCancel uiButton uiButtonConfirm\\\" href=\\\"#\\\" role=\\\"button\\\" name=\\\"cancel\\\"\\u003E\\u003Cspan class=\\\"uiButtonText\\\"\\u003EClose\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_176\",{\n            __html: \"\\u003Cdiv\\u003E\\u003Cdiv class=\\\"clearfix mvm mrm mll videoCallPromo\\\"\\u003E\\u003Ci class=\\\"-cx-PRIVATE-uiImageBlock__image -cx-PRIVATE-uiImageBlock__mediumImage lfloat img sp_46s4tm sx_81ea1c\\\"\\u003E\\u003C/i\\u003E\\u003Cdiv class=\\\"-cx-PRIVATE-uiImageBlock__content \\\"\\u003E\\u003Cdiv class=\\\"pls\\\"\\u003E\\u003Cspan class=\\\"calloutTitle fwb\\\"\\u003ETalk face to face\\u003C/span\\u003E\\u003Cdiv class=\\\"fsm fwn fcg\\\"\\u003EClick \\u003Cspan\\u003E ( \\u003Ci class=\\\"onlineStatusIcon img sp_46s4tm sx_31fa21\\\"\\u003E\\u003C/i\\u003E )\\u003C/span\\u003E below to start a video call.\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"uiOverlayFooter uiContextualDialogFooter uiBoxGray topborder\\\"\\u003E\\u003Ctable class=\\\"uiGrid\\\" cellspacing=\\\"0\\\" cellpadding=\\\"0\\\"\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"prs uiOverlayFooterMessage\\\"\\u003E\\u003Ca target=\\\"_blank\\\" href=\\\"/help/?page=177940565599960\\\"\\u003ELearn more\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"uiOverlayFooterButtons\\\"\\u003E\\u003Ca class=\\\"uiOverlayButton layerCancel uiButton uiButtonConfirm\\\" href=\\\"#\\\" role=\\\"button\\\" name=\\\"cancel\\\"\\u003E\\u003Cspan class=\\\"uiButtonText\\\"\\u003EOkay\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_177\",{\n            __html: \"\\u003Cdiv class=\\\"fbNub fbMercuryChatTab user\\\"\\u003E\\u003Ca class=\\\"fbNubButton\\\" tabindex=\\\"0\\\" href=\\\"#\\\" data-jsid=\\\"dockButton\\\"\\u003E\\u003Cdiv class=\\\"clearfix fbChatTab fbChatGroupTab\\\"\\u003E\\u003Cdiv class=\\\"funhouse rfloat\\\"\\u003E\\u003Cdiv class=\\\"close\\\" title=\\\"Close\\\" data-jsid=\\\"closeButton\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"wrapWrapper\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Cdiv class=\\\"name fwb\\\" data-jsid=\\\"name\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cspan class=\\\"numMessages hidden_elem\\\" data-jsid=\\\"numMessages\\\"\\u003E0\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"fbNubFlyout fbDockChatTabFlyout\\\" data-jsid=\\\"chatWrapper\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutOuter\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutInner\\\"\\u003E\\u003Cdiv class=\\\"clearfix fbNubFlyoutTitlebar titlebar\\\" data-jsid=\\\"nubFlyoutTitlebar\\\"\\u003E\\u003Cdiv class=\\\"mls titlebarButtonWrapper rfloat\\\"\\u003E\\u003Ca data-hover=\\\"tooltip\\\" title=\\\"Press Esc to close\\\" data-tooltip-alignh=\\\"center\\\" class=\\\"close button\\\" href=\\\"#\\\" data-jsid=\\\"titlebarCloseButton\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"titlebarLabel clearfix\\\"\\u003E\\u003Cdiv class=\\\"titlebarTextWrapper\\\"\\u003E\\u003Ca class=\\\"titlebarText noLink\\\" href=\\\"#\\\" rel=\\\"none\\\" data-jsid=\\\"titlebarText\\\" aria-level=\\\"3\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutHeader\\\"\\u003E\\u003Cdiv class=\\\"sheetContainer\\\"\\u003E\\u003Cdiv class=\\\"sheet hidden_elem\\\" data-jsid=\\\"sheet\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutBody scrollable\\\" data-jsid=\\\"chatConv\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutBodyContent\\\"\\u003E\\u003Ctable class=\\\"uiGrid conversationContainer\\\" cellspacing=\\\"0\\\" cellpadding=\\\"0\\\"\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"vBot\\\"\\u003E\\u003Cdiv class=\\\"accessible_elem\\\"\\u003EChat Conversation Start\\u003C/div\\u003E\\u003Cdiv class=\\\"conversation\\\" data-jsid=\\\"conversation\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"accessible_elem\\\"\\u003EChat Conversation End\\u003C/div\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutFooter\\\"\\u003E\\u003Cdiv class=\\\"inputContainer\\\"\\u003E\\u003Ctextarea class=\\\"uiTextareaAutogrow input\\\" data-jsid=\\\"input\\\" onkeydown=\\\"Bootloader.loadComponents([&quot;control-textarea&quot;], function() &#123; TextAreaControl.getInstance(this) &#125;.bind(this)); \\\"\\u003E\\u003C/textarea\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"emoticonsPanel\\\" data-jsid=\\\"emoticons\\\"\\u003E\\u003Ca class=\\\"emoteTogglerImg\\\" rel=\\\"toggle\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"panelFlyout uiToggleFlyout\\\"\\u003E\\u003Ctable\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_smile\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: 0px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_frown\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -16px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_tongue\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -32px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_grin\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -48px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_gasp\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -64px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_wink\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -80px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_pacman\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -304px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_grumpy\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -128px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_unsure\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -144px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_cry\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -160px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_kiki\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -240px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_glasses\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -96px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_sunglasses\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -112px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_heart\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -224px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_devil\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -176px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_angel\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -192px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_squint\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -256px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_confused\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -272px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_upset\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -288px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_colonthree\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -320px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_like\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -336px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003Cdiv class=\\\"panelFlyoutArrow\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205559_178\",{\n            __html: \"\\u003Cdiv class=\\\"fbNub fbMercuryChatTab user\\\"\\u003E\\u003Ca class=\\\"fbNubButton\\\" tabindex=\\\"0\\\" href=\\\"#\\\" data-jsid=\\\"dockButton\\\"\\u003E\\u003Cdiv class=\\\"clearfix fbChatTab fbChatGroupTab\\\"\\u003E\\u003Cdiv class=\\\"funhouse rfloat\\\"\\u003E\\u003Cdiv class=\\\"close\\\" title=\\\"Close\\\" data-jsid=\\\"closeButton\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"wrapWrapper\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Cdiv class=\\\"name fwb\\\" data-jsid=\\\"name\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cspan class=\\\"numMessages hidden_elem\\\" data-jsid=\\\"numMessages\\\"\\u003E0\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"fbNubFlyout fbDockChatTabFlyout\\\" data-jsid=\\\"chatWrapper\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutOuter\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutInner\\\"\\u003E\\u003Cdiv class=\\\"clearfix fbNubFlyoutTitlebar titlebar\\\" data-jsid=\\\"nubFlyoutTitlebar\\\"\\u003E\\u003Cdiv class=\\\"mls titlebarButtonWrapper rfloat\\\"\\u003E\\u003Ca data-hover=\\\"tooltip\\\" title=\\\"Press Esc to close\\\" data-tooltip-alignh=\\\"center\\\" class=\\\"close button\\\" href=\\\"#\\\" data-jsid=\\\"titlebarCloseButton\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"titlebarLabel clearfix\\\"\\u003E\\u003Cdiv class=\\\"titlebarTextWrapper\\\"\\u003E\\u003Ca class=\\\"titlebarText noLink\\\" href=\\\"#\\\" rel=\\\"none\\\" data-jsid=\\\"titlebarText\\\" aria-level=\\\"3\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutHeader\\\"\\u003E\\u003Cdiv class=\\\"sheetContainer\\\"\\u003E\\u003Cdiv class=\\\"sheet hidden_elem\\\" data-jsid=\\\"sheet\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutBody scrollable\\\" data-jsid=\\\"chatConv\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutBodyContent\\\"\\u003E\\u003Ctable class=\\\"uiGrid conversationContainer\\\" cellspacing=\\\"0\\\" cellpadding=\\\"0\\\"\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"vBot\\\"\\u003E\\u003Cdiv class=\\\"accessible_elem\\\"\\u003EChat Conversation Start\\u003C/div\\u003E\\u003Cdiv class=\\\"conversation\\\" data-jsid=\\\"conversation\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"accessible_elem\\\"\\u003EChat Conversation End\\u003C/div\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutFooter\\\"\\u003E\\u003Cdiv class=\\\"inputContainer\\\"\\u003E\\u003Ctextarea class=\\\"uiTextareaAutogrow input\\\" data-jsid=\\\"input\\\" onkeydown=\\\"Bootloader.loadComponents([&quot;control-textarea&quot;], function() &#123; TextAreaControl.getInstance(this) &#125;.bind(this)); \\\"\\u003E\\u003C/textarea\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"emoticonsPanel\\\" data-jsid=\\\"emoticons\\\"\\u003E\\u003Ca class=\\\"emoteTogglerImg\\\" rel=\\\"toggle\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"panelFlyout uiToggleFlyout\\\"\\u003E\\u003Ctable\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_smile\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: 0px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_frown\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -16px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_tongue\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -32px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_grin\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -48px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_gasp\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -64px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_wink\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -80px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_pacman\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -304px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_grumpy\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -128px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_unsure\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -144px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_cry\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -160px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_kiki\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -240px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_glasses\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -96px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_sunglasses\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -112px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_heart\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -224px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_devil\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -176px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_angel\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -192px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_squint\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -256px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_confused\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -272px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_upset\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -288px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_colonthree\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -320px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_like\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -336px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003Cdiv class=\\\"panelFlyoutArrow\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205560_181\",{\n            __html: \"Options\"\n        },2,],[\"m205560_179\",{\n            __html: \"\\u003Cdiv class=\\\"fbNub fbMercuryChatTab thread\\\"\\u003E\\u003Ca class=\\\"fbNubButton\\\" tabindex=\\\"0\\\" href=\\\"#\\\" data-jsid=\\\"dockButton\\\"\\u003E\\u003Cdiv class=\\\"clearfix fbChatTab fbChatThreadTab\\\"\\u003E\\u003Cdiv class=\\\"funhouse rfloat\\\"\\u003E\\u003Cdiv class=\\\"close\\\" title=\\\"Close\\\" data-jsid=\\\"closeButton\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"wrapWrapper\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Cdiv class=\\\"name fwb\\\" data-jsid=\\\"name\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cspan class=\\\"numMessages hidden_elem\\\" data-jsid=\\\"numMessages\\\"\\u003E0\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"fbNubFlyout fbDockChatTabFlyout\\\" data-jsid=\\\"chatWrapper\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutOuter\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutInner\\\"\\u003E\\u003Cdiv class=\\\"clearfix fbNubFlyoutTitlebar titlebar\\\" data-jsid=\\\"nubFlyoutTitlebar\\\"\\u003E\\u003Cdiv class=\\\"mls titlebarButtonWrapper rfloat\\\"\\u003E\\u003Ca data-hover=\\\"tooltip\\\" title=\\\"Add more friends to chat\\\" data-tooltip-alignh=\\\"center\\\" class=\\\"addToThread button\\\" href=\\\"#\\\" data-jsid=\\\"addToThreadLink\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"uiSelector inlineBlock fbDockChatDropdown\\\" data-jsid=\\\"dropdown\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Ca data-hover=\\\"tooltip\\\" data-tooltip-alignh=\\\"center\\\" class=\\\"button uiSelectorButton\\\" href=\\\"#\\\" role=\\\"button\\\" aria-haspopup=\\\"1\\\" rel=\\\"toggle\\\" id=\\\"uq3j16_64\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"uiSelectorMenuWrapper uiToggleFlyout\\\"\\u003E\\u003Cdiv role=\\\"menu\\\" class=\\\"uiMenu uiSelectorMenu\\\"\\u003E\\u003Cul class=\\\"uiMenuInner\\\"\\u003E\\u003Cli class=\\\"uiMenuItem\\\" data-label=\\\"See Full Conversation\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"0\\\" href=\\\"#\\\" data-jsid=\\\"conversationLink\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003ESee Full Conversation\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem\\\" data-label=\\\"Add Friends to Chat...\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" data-jsid=\\\"addFriendLink\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003EAdd Friends to Chat...\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuSeparator\\\"\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem\\\" data-label=\\\"Leave Conversation...\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" data-jsid=\\\"unsubscribeLink\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003ELeave Conversation...\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Ca data-hover=\\\"tooltip\\\" title=\\\"Press Esc to close\\\" data-tooltip-alignh=\\\"center\\\" class=\\\"close button\\\" href=\\\"#\\\" data-jsid=\\\"titlebarCloseButton\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"titlebarLabel clearfix\\\"\\u003E\\u003Cdiv class=\\\"titlebarTextWrapper\\\"\\u003E\\u003Ca class=\\\"titlebarText noLink\\\" href=\\\"#\\\" rel=\\\"none\\\" data-jsid=\\\"titlebarText\\\" aria-level=\\\"3\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutHeader\\\"\\u003E\\u003Cdiv class=\\\"sheetContainer\\\"\\u003E\\u003Cdiv class=\\\"sheet hidden_elem\\\" data-jsid=\\\"sheet\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutBody scrollable\\\" data-jsid=\\\"chatConv\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutBodyContent\\\"\\u003E\\u003Ctable class=\\\"uiGrid conversationContainer\\\" cellspacing=\\\"0\\\" cellpadding=\\\"0\\\"\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"vBot\\\"\\u003E\\u003Cdiv class=\\\"accessible_elem\\\"\\u003EChat Conversation Start\\u003C/div\\u003E\\u003Cdiv class=\\\"conversation\\\" data-jsid=\\\"conversation\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"accessible_elem\\\"\\u003EChat Conversation End\\u003C/div\\u003E\\u003Cdiv class=\\\"-cx-PRIVATE-mercuryTypingIndicator__root typingIndicator\\\" data-jsid=\\\"typingIndicator\\\"\\u003E\\u003Cdiv class=\\\"-cx-PRIVATE-mercuryTypingIndicator__icon\\\"\\u003E\\u003C/div\\u003E\\u003Cspan class=\\\"-cx-PRIVATE-mercuryTypingIndicator__text\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutFooter\\\"\\u003E\\u003Cdiv class=\\\"inputContainer\\\"\\u003E\\u003Ctextarea class=\\\"uiTextareaAutogrow input\\\" data-jsid=\\\"input\\\" onkeydown=\\\"Bootloader.loadComponents([&quot;control-textarea&quot;], function() &#123; TextAreaControl.getInstance(this) &#125;.bind(this)); \\\"\\u003E\\u003C/textarea\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"emoticonsPanel\\\" data-jsid=\\\"emoticons\\\"\\u003E\\u003Ca class=\\\"emoteTogglerImg\\\" rel=\\\"toggle\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"panelFlyout uiToggleFlyout\\\"\\u003E\\u003Ctable\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_smile\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: 0px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_frown\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -16px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_tongue\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -32px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_grin\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -48px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_gasp\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -64px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_wink\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -80px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_pacman\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -304px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_grumpy\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -128px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_unsure\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -144px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_cry\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -160px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_kiki\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -240px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_glasses\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -96px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_sunglasses\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -112px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_heart\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -224px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_devil\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -176px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_angel\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -192px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_squint\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -256px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_confused\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -272px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_upset\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -288px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_colonthree\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -320px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_like\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -336px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003Cdiv class=\\\"panelFlyoutArrow\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },3,],[\"m205560_184\",{\n            __html: \"Options\"\n        },2,],[\"m205560_182\",{\n            __html: \"\\u003Cdiv class=\\\"fbNub fbMercuryChatTab user\\\"\\u003E\\u003Ca class=\\\"fbNubButton\\\" tabindex=\\\"0\\\" href=\\\"#\\\" data-jsid=\\\"dockButton\\\"\\u003E\\u003Cdiv class=\\\"clearfix fbChatTab fbChatUserTab\\\"\\u003E\\u003Cdiv class=\\\"funhouse rfloat\\\"\\u003E\\u003Cdiv class=\\\"close\\\" title=\\\"Close\\\" data-jsid=\\\"closeButton\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"wrapWrapper\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Cdiv class=\\\"name fwb\\\" data-jsid=\\\"name\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cspan class=\\\"numMessages hidden_elem\\\" data-jsid=\\\"numMessages\\\"\\u003E0\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"fbNubFlyout fbDockChatTabFlyout\\\" data-jsid=\\\"chatWrapper\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutOuter\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutInner\\\"\\u003E\\u003Cdiv class=\\\"clearfix fbNubFlyoutTitlebar titlebar\\\" data-jsid=\\\"nubFlyoutTitlebar\\\"\\u003E\\u003Cdiv class=\\\"mls titlebarButtonWrapper rfloat\\\"\\u003E\\u003Ca data-hover=\\\"tooltip\\\" title=\\\"Start a video call\\\" data-tooltip-alignh=\\\"center\\\" class=\\\"videoicon button\\\" href=\\\"#\\\" data-jsid=\\\"videoCallLink\\\" data-gt=\\\"&#123;&quot;videochat&quot;:&quot;call_clicked_chat_tab&quot;&#125;\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"uiSelector inlineBlock fbDockChatDropdown\\\" data-jsid=\\\"dropdown\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Ca data-hover=\\\"tooltip\\\" data-tooltip-alignh=\\\"center\\\" class=\\\"button uiSelectorButton\\\" href=\\\"#\\\" role=\\\"button\\\" aria-haspopup=\\\"1\\\" rel=\\\"toggle\\\" id=\\\"uq3j16_65\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"uiSelectorMenuWrapper uiToggleFlyout\\\"\\u003E\\u003Cdiv role=\\\"menu\\\" class=\\\"uiMenu uiSelectorMenu\\\"\\u003E\\u003Cul class=\\\"uiMenuInner\\\"\\u003E\\u003Cli class=\\\"uiMenuItem\\\" data-label=\\\"Add Friends to Chat...\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"0\\\" href=\\\"#\\\" data-jsid=\\\"addFriendLink\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003EAdd Friends to Chat...\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem\\\" data-label=\\\"\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" data-jsid=\\\"privacyLink\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003E \\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuSeparator\\\"\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem\\\" data-label=\\\"See Full Conversation\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" data-jsid=\\\"conversationLink\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003ESee Full Conversation\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem\\\" data-label=\\\"Clear Window\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" data-jsid=\\\"clearWindowLink\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003EClear Window\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuSeparator\\\"\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem\\\" data-label=\\\"Report as Spam\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" data-jsid=\\\"reportSpamLink\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003EReport as Spam\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Ca data-hover=\\\"tooltip\\\" title=\\\"Press Esc to close\\\" data-tooltip-alignh=\\\"center\\\" class=\\\"close button\\\" href=\\\"#\\\" data-jsid=\\\"titlebarCloseButton\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"titlebarLabel clearfix\\\"\\u003E\\u003Cdiv class=\\\"titlebarTextWrapper\\\"\\u003E\\u003Ca class=\\\"titlebarText noLink\\\" href=\\\"#\\\" rel=\\\"none\\\" data-jsid=\\\"titlebarText\\\" aria-level=\\\"3\\\"\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutHeader\\\"\\u003E\\u003Cdiv class=\\\"sheetContainer\\\"\\u003E\\u003Cdiv class=\\\"sheet hidden_elem\\\" data-jsid=\\\"sheet\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutBody scrollable\\\" data-jsid=\\\"chatConv\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutBodyContent\\\"\\u003E\\u003Ctable class=\\\"uiGrid conversationContainer\\\" cellspacing=\\\"0\\\" cellpadding=\\\"0\\\"\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"vBot\\\"\\u003E\\u003Cdiv class=\\\"accessible_elem\\\"\\u003EChat Conversation Start\\u003C/div\\u003E\\u003Cdiv class=\\\"conversation\\\" data-jsid=\\\"conversation\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"accessible_elem\\\"\\u003EChat Conversation End\\u003C/div\\u003E\\u003Cdiv class=\\\"-cx-PRIVATE-mercuryTypingIndicator__root typingIndicator\\\" data-jsid=\\\"typingIndicator\\\"\\u003E\\u003Cdiv class=\\\"-cx-PRIVATE-mercuryTypingIndicator__icon\\\"\\u003E\\u003C/div\\u003E\\u003Cspan class=\\\"-cx-PRIVATE-mercuryTypingIndicator__text\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutFooter\\\"\\u003E\\u003Cdiv class=\\\"inputContainer\\\"\\u003E\\u003Ctextarea class=\\\"uiTextareaAutogrow input\\\" data-jsid=\\\"input\\\" onkeydown=\\\"Bootloader.loadComponents([&quot;control-textarea&quot;], function() &#123; TextAreaControl.getInstance(this) &#125;.bind(this)); \\\"\\u003E\\u003C/textarea\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"emoticonsPanel\\\" data-jsid=\\\"emoticons\\\"\\u003E\\u003Ca class=\\\"emoteTogglerImg\\\" rel=\\\"toggle\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"panelFlyout uiToggleFlyout\\\"\\u003E\\u003Ctable\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_smile\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: 0px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_frown\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -16px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_tongue\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -32px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_grin\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -48px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_gasp\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -64px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_wink\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -80px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_pacman\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -304px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_grumpy\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -128px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_unsure\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -144px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_cry\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -160px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_kiki\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -240px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_glasses\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -96px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_sunglasses\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -112px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_heart\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -224px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003Ctr\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_devil\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -176px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_angel\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -192px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_squint\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -256px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_confused\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -272px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_upset\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -288px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_colonthree\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -320px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003Ctd class=\\\"panelCell\\\"\\u003E\\u003Ca class=\\\"emoteIcon name_like\\\"\\u003E\\u003Cimg class=\\\"emote_img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/yw/r/drP8vlvSl_8.gif\\\" style=\\\"background-position: -336px 0\\\" /\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003Cdiv class=\\\"panelFlyoutArrow\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },3,],[\"m205561_185\",{\n            __html: \"\\u003Cdiv class=\\\"clearfix mvs\\\"\\u003E\\u003Ci class=\\\"rfloat img sp_ae80w4 sx_d14d96\\\" data-jsid=\\\"icon\\\"\\u003E\\u003C/i\\u003E\\u003Cdiv data-jsid=\\\"name\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205561_186\",{\n            __html: \"\\u003Cdiv\\u003E\\u003Ca class=\\\"uiIconText\\\" href=\\\"#\\\" style=\\\"padding-left: 12px;\\\" data-jsid=\\\"forwardLink\\\"\\u003E\\u003Ci class=\\\"img sp_46s4tm sx_f93b30\\\" style=\\\"top: 3px;\\\"\\u003E\\u003C/i\\u003E\\u003Cspan data-jsid=\\\"forwardText\\\"\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\"\n        },2,],[\"m205561_187\",{\n            __html: \"\\u003Cabbr title=\\\"Wednesday, December 31, 1969 at 7:00pm\\\" data-utime=\\\"0\\\" class=\\\"hidden_elem timestamp\\\" data-jsid=\\\"timestamp\\\"\\u003Eover a year ago\\u003C/abbr\\u003E\"\n        },2,],[\"m205561_188\",{\n            __html: \"\\u003Cli class=\\\"item\\\"\\u003E\\u003Ca class=\\\"clearfix\\\" href=\\\"#\\\" rel=\\\"ignore\\\" data-jsid=\\\"anchor\\\"\\u003E\\u003Cimg class=\\\"pic\\\" src=\\\"/images/spacer.gif\\\" data-jsid=\\\"profile-photo\\\" /\\u003E\\u003Cdiv class=\\\"icons\\\"\\u003E\\u003Cimg class=\\\"lb_status icon img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/y4/r/-PAXP-deijE.gif\\\" alt=\\\"\\\" width=\\\"1\\\" height=\\\"1\\\" /\\u003E\\u003Cimg class=\\\"status icon img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v2/y4/r/-PAXP-deijE.gif\\\" alt=\\\"\\\" width=\\\"1\\\" height=\\\"1\\\" /\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"name\\\" data-jsid=\\\"name\\\"\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\"\n        },2,],[\"m205561_189\",{\n            __html: \"\\u003Cli\\u003E\\u003Cdiv class=\\\"phs fcg\\\"\\u003E\\u003Cspan data-jsid=\\\"message\\\"\\u003ELoading...\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/li\\u003E\"\n        },2,],],\n        elements: [[\"m205558_121\",\"uq3j16_53\",2,],[\"m205558_144\",\"fbDockChat\",2,],[\"m205558_145\",\"fbDockChatTabs\",2,],[\"m205558_146\",\"fbDockChatBuddylistNub\",2,],[\"m205558_151\",\"uq3j16_55\",2,],[\"m205558_152\",\"uq3j16_56\",2,],[\"m205558_150\",\"uq3j16_58\",4,],[\"m205558_154\",\"uq3j16_59\",2,],[\"m205559_160\",\"uq3j16_61\",2,],[\"m205559_156\",\"uq3j16_62\",2,],[\"m205560_180\",\"uq3j16_64\",2,\"m205560_179\",],[\"m205560_183\",\"uq3j16_65\",2,\"m205560_182\",],],\n        define: [[\"AvailableListInitialData\",[],{\n            pollInterval: 100000,\n            lazyPollInterval: 300000,\n            lazyThreshold: 300000,\n            updateTime: 0,\n            availableList: {\n            },\n            availableCount: 0,\n            mobileFriends: null,\n            chatNotif: 0\n        },],[\"ChatOptionsInitialData\",[],{\n            sound: 1,\n            sidebar_mode: 1,\n            browser_notif: 0\n        },],[\"ChatTabTemplates\",[\"m205558_123\",\"m205558_124\",\"m205558_125\",\"m205558_126\",\"m205558_127\",\"m205558_128\",\"m205558_129\",\"m205558_130\",\"m205558_131\",\"m205558_132\",\"m205558_133\",\"m205558_134\",\"m205558_135\",\"m205558_136\",\"m205558_137\",\"m205558_138\",\"m205558_139\",\"m205558_140\",\"m205558_141\",\"m205558_142\",\"m205558_143\",],{\n            \":fb:chat:conversation:date-break\": {\n                __m: \"m205558_123\"\n            },\n            \":fb:chat:conversation:message\": {\n                __m: \"m205558_124\"\n            },\n            \":fb:chat:conversation:message:event\": {\n                __m: \"m205558_125\"\n            },\n            \":fb:chat:conversation:message:status\": {\n                __m: \"m205558_126\"\n            },\n            \":fb:chat:conversation:message:subject\": {\n                __m: \"m205558_127\"\n            },\n            \":fb:chat:conversation:message-group\": {\n                __m: \"m205558_128\"\n            },\n            \":fb:chat:tab:selector\": {\n                __m: \"m205558_129\"\n            },\n            \":fb:chat:tab:selector:item\": {\n                __m: \"m205558_130\"\n            },\n            \":fb:mercury:chat:tab-sheet:add-friends\": {\n                __m: \"m205558_131\"\n            },\n            \":fb:mercury:chat:tab-sheet:loading\": {\n                __m: \"m205558_132\"\n            },\n            \":fb:mercury:chat:tab-sheet:message-icon-sheet\": {\n                __m: \"m205558_133\"\n            },\n            \":fb:mercury:chat:tab-sheet:user-blocked\": {\n                __m: \"m205558_134\"\n            },\n            \":fb:mercury:call:promo\": {\n                __m: \"m205558_135\"\n            },\n            \":fb:mercury:call:tour\": {\n                __m: \"m205558_136\"\n            },\n            \":fb:mercury:chat:group-tab\": {\n                __m: \"m205558_137\"\n            },\n            \":fb:mercury:chat:live-listen-tab\": {\n                __m: \"m205558_138\"\n            },\n            \":fb:mercury:chat:multichat-tab\": {\n                __m: \"m205558_139\"\n            },\n            \":fb:mercury:chat:user-tab\": {\n                __m: \"m205558_140\"\n            },\n            \":fb:mercury:chat:multichat-tooltip-item\": {\n                __m: \"m205558_141\"\n            },\n            \":fb:mercury:chat:message:forward\": {\n                __m: \"m205558_142\"\n            },\n            \":fb:mercury:timestamp\": {\n                __m: \"m205558_143\"\n            }\n        },],[\"ChatSidebarCalloutData\",[],{\n            isShown: false\n        },],],\n        require: [[\"MusicButtonManager\",\"init\",[],[[\"music.song\",],],],[\"Dock\",\"init\",[\"m205558_121\",],[{\n            __m: \"m205558_121\"\n        },],],[\"AvailableList\",],[\"ChatApp\",\"init\",[\"m205558_144\",\"m205558_145\",],[{\n            __m: \"m205558_144\"\n        },{\n            __m: \"m205558_145\"\n        },{\n            payload_source: \"server_initial_data\"\n        },],],[\"m205558_147\",],[\"m205558_149\",],[\"Typeahead\",\"init\",[\"m205558_150\",\"m205558_149\",],[{\n            __m: \"m205558_150\"\n        },{\n            __m: \"m205558_149\"\n        },[\"chatTypeahead\",\"buildBestAvailableNames\",\"showLoadingIndicator\",],null,],],[\"ClearableTypeahead\",\"resetOnCloseButtonClick\",[\"m205558_149\",\"m205558_152\",],[{\n            __m: \"m205558_149\"\n        },{\n            __m: \"m205558_152\"\n        },],],[\"m205558_155\",],[\"Tooltip\",\"set\",[\"m205559_156\",\"m205559_157\",],[{\n            __m: \"m205559_156\"\n        },{\n            __m: \"m205559_157\"\n        },],],[\"m205559_158\",],[\"Layer\",\"init\",[\"m205559_158\",\"m205559_159\",],[{\n            __m: \"m205559_158\"\n        },{\n            __m: \"m205559_159\"\n        },],],[\"m205558_148\",],[\"Tooltip\",\"set\",[\"m205560_180\",\"m205560_181\",],[{\n            __m: \"m205560_180\"\n        },{\n            __m: \"m205560_181\"\n        },],],[\"Tooltip\",\"set\",[\"m205560_183\",\"m205560_184\",],[{\n            __m: \"m205560_183\"\n        },{\n            __m: \"m205560_184\"\n        },],],]\n    },\n    css: [\"zO4BE\",\"z8dwT\",],\n    bootloadable: {\n        beeper: {\n            resources: [\"8gPM0\",\"bS0QP\",\"JOZ9R\",\"v4i0/\",\"6n1TR\",\"FCMVl\",\"1zqwA\",\"C6rJk\",\"zO4BE\",\"1lJOt\",\"48vAQ\",\"+21JG\",]\n        },\n        VideoCallController: {\n            resources: [\"bS0QP\",\"8gPM0\",\"1zqwA\",\"zO4BE\",\"IZaDN\",\"3HhWt\",\"KPLqg\",\"78mGG\",],\n            \"module\": true\n        }\n    },\n    resource_map: {\n        \"v4i0/\": {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yG/r/Skc_dFkcWkO.js\"\n        },\n        FCMVl: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yU/r/Yv6SBFEngDU.js\"\n        },\n        \"1lJOt\": {\n            type: \"css\",\n            permanent: 1,\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yV/r/oO1k_VFjNKF.css\"\n        },\n        \"48vAQ\": {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yv/r/5lpXIw2-Ra7.js\"\n        },\n        \"+21JG\": {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yd/r/GPrBtdk0jHE.js\"\n        },\n        IZaDN: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/ye/r/iP4keJA_tRb.js\"\n        },\n        \"3HhWt\": {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y3/r/Ttq-aeZF5gs.js\"\n        },\n        KPLqg: {\n            type: \"css\",\n            permanent: 1,\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/y_/r/seDGnw8i6fH.css\"\n        },\n        \"78mGG\": {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yC/r/t8-RMyEFiOt.js\"\n        }\n    },\n    js: [\"8gPM0\",\"bS0QP\",\"6n1TR\",\"1zqwA\",\"tZ04z\",],\n    JSBNG__onload: [\"init_live_message_receive({\\\"useAggregatedBottomBeeper\\\":0});\",\"define(\\\"MercuryDataSource\\\", [], require(\\\"m205558_122\\\"));\",],\n    JSBNG__content: {\n        pagelet_dock: {\n            container_id: \"uq3j16_66\"\n        }\n    }\n});");
// 1728
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"bigPipe.onPageletArrive({\n    phase: 3,\n    id: \"pagelet_privacy_widget\",\n    jsmods: {\n        instances: [[\"m205563_190\",[\"ContextualDialogX\",],[{\n            buildWrapper: false,\n            causalElement: null,\n            addedBehaviors: []\n        },],4,],],\n        markup: [[\"m205563_191\",{\n            __html: \"\\u003Cdiv class=\\\"uiContextualDialogPositioner metaComposerUserEd\\\" id=\\\"uq3j16_68\\\" data-position=\\\"below\\\" data-alignh=\\\"center\\\"\\u003E\\u003Cdiv class=\\\"uiOverlay uiContextualDialog\\\" data-width=\\\"300\\\"\\u003E\\u003Cdiv class=\\\"uiOverlayContent\\\"\\u003E\\u003Cdiv class=\\\"pam uiContextualDialogContent\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],],\n        require: [[\"m205563_190\",],[\"Layer\",\"init\",[\"m205563_190\",\"m205563_191\",],[{\n            __m: \"m205563_190\"\n        },{\n            __m: \"m205563_191\"\n        },],],[\"DynamicIconSelector\",],]\n    },\n    css: [\"zO4BE\",],\n    js: [\"8gPM0\",\"bS0QP\",\"JOZ9R\",],\n    jscc_map: \"({\\\"j4AqhjRZyWwnFxYubC0\\\":function(){return new MetaComposerEdDialog()},\\\"j4AqhjRZyWwnFxYubC1\\\":function(){return new CustomPrivacyOption();},\\\"j4AqhjRZyWwnFxYubC2\\\":function(){return new FriendsPrivacyOption()},\\\"j4AqhjRZyWwnFxYubC3\\\":function(){return new OnlyMePrivacyOption()}})\",\n    onload: [\"FriendListPrivacyOptions.listen(\\\"uq3j16_67\\\", true, true)\",\"JSCC.get(\\\"j4AqhjRZyWwnFxYubC0\\\").init(require(\\\"m205563_190\\\"), 1, 0, 0, 0, 0, 0)\",\"JSCC.get(\\\"j4AqhjRZyWwnFxYubC1\\\").init(\\\"uq3j16_69\\\", \\\"0\\\", true, \\\"\\\", true);\",\"JSCC.get(\\\"j4AqhjRZyWwnFxYubC2\\\").init($('uq3j16_70'), false)\",\"JSCC.get(\\\"j4AqhjRZyWwnFxYubC3\\\").init($('uq3j16_71'))\",],\n    content: {\n        pagelet_privacy_widget: {\n            container_id: \"uq3j16_76\"\n        }\n    }\n});");
// 1729
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"sfb8b0522a302438261c032fbf4ab9825f8b0db21");
// 1730
geval("bigPipe.JSBNG__onPageletArrive({\n    phase: 3,\n    id: \"pagelet_privacy_widget\",\n    jsmods: {\n        instances: [[\"m205563_190\",[\"ContextualDialogX\",],[{\n            buildWrapper: false,\n            causalElement: null,\n            addedBehaviors: []\n        },],4,],],\n        markup: [[\"m205563_191\",{\n            __html: \"\\u003Cdiv class=\\\"uiContextualDialogPositioner metaComposerUserEd\\\" id=\\\"uq3j16_68\\\" data-position=\\\"below\\\" data-alignh=\\\"center\\\"\\u003E\\u003Cdiv class=\\\"uiOverlay uiContextualDialog\\\" data-width=\\\"300\\\"\\u003E\\u003Cdiv class=\\\"uiOverlayContent\\\"\\u003E\\u003Cdiv class=\\\"pam uiContextualDialogContent\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n        },2,],],\n        require: [[\"m205563_190\",],[\"Layer\",\"init\",[\"m205563_190\",\"m205563_191\",],[{\n            __m: \"m205563_190\"\n        },{\n            __m: \"m205563_191\"\n        },],],[\"DynamicIconSelector\",],]\n    },\n    css: [\"zO4BE\",],\n    js: [\"8gPM0\",\"bS0QP\",\"JOZ9R\",],\n    jscc_map: \"({\\\"j4AqhjRZyWwnFxYubC0\\\":function(){return new MetaComposerEdDialog()},\\\"j4AqhjRZyWwnFxYubC1\\\":function(){return new CustomPrivacyOption();},\\\"j4AqhjRZyWwnFxYubC2\\\":function(){return new FriendsPrivacyOption()},\\\"j4AqhjRZyWwnFxYubC3\\\":function(){return new OnlyMePrivacyOption()}})\",\n    JSBNG__onload: [\"FriendListPrivacyOptions.listen(\\\"uq3j16_67\\\", true, true)\",\"JSCC.get(\\\"j4AqhjRZyWwnFxYubC0\\\").init(require(\\\"m205563_190\\\"), 1, 0, 0, 0, 0, 0)\",\"JSCC.get(\\\"j4AqhjRZyWwnFxYubC1\\\").init(\\\"uq3j16_69\\\", \\\"0\\\", true, \\\"\\\", true);\",\"JSCC.get(\\\"j4AqhjRZyWwnFxYubC2\\\").init($('uq3j16_70'), false)\",\"JSCC.get(\\\"j4AqhjRZyWwnFxYubC3\\\").init($('uq3j16_71'))\",],\n    JSBNG__content: {\n        pagelet_privacy_widget: {\n            container_id: \"uq3j16_76\"\n        }\n    }\n});");
// 1735
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"bigPipe.onPageletArrive({\n    phase: 3,\n    id: \"pagelet_sub_stream_1\",\n    append: \"home_stream\",\n    jsmods: {\n        instances: [[\"m205541_59\",[\"PopoverAsyncMenuLoading\",],[\"HighlightSelectorMenu\",],3,],[\"m205541_61\",[\"PopoverAsyncMenu\",\"m205541_62\",\"m205541_60\",\"m205541_59\",\"PopoverMenuOverlappingBorder\",],[{\n            __m: \"m205541_62\"\n        },{\n            __m: \"m205541_60\"\n        },{\n            __m: \"m205541_59\"\n        },\"/ajax/feed/feed_menu.php?action=hide&story_div_id=stream_story_50291e77633c36f83163300&filter_key=h_nor&spam_object_id=3088544471436&report_link=0&story_type=245&source_id=0&qid=5776181494237290802&mf_story_key=8878831909009365538&actor_id=1055580469&num_participants=1&is_highlight=0&viewstate_id=8878831909009365538\",[{\n            __m: \"PopoverMenuOverlappingBorder\"\n        },],],1,],[\"m205541_62\",[\"Popover\",\"m205541_63\",\"m205541_60\",\"ContextualLayerAsyncRelative\",],[{\n            __m: \"m205541_63\"\n        },{\n            __m: \"m205541_60\"\n        },[{\n            __m: \"ContextualLayerAsyncRelative\"\n        },],{\n            alignh: \"right\",\n            layer_content: null\n        },],3,],],\n        markup: [[\"m205542_66\",{\n            __html: \"Show edit history\"\n        },2,],],\n        elements: [[\"m205541_63\",\"uq3j2t_35\",2,],[\"m205541_60\",\"uq3j2t_36\",4,],[\"m205541_64\",\"uq3j2t_37\",2,],[\"m205542_65\",\"uq3j2t_38\",2,],],\n        require: [[\"m205541_59\",],[\"m205541_61\",],[\"m205541_62\",],[\"Tooltip\",\"set\",[\"m205542_65\",\"m205542_66\",],[{\n            __m: \"m205542_65\"\n        },{\n            __m: \"m205542_66\"\n        },],],]\n    },\n    css: [\"zO4BE\",],\n    js: [\"8gPM0\",\"bS0QP\",\"JOZ9R\",],\n    requires: [\"pagelet_controller::home_intentional_stream\",\"pagelet_controller::substream_scroll_load_0\",],\n    provides: [\"pagelet_controller::substream_scroll_load_1\",],\n    onload: [\"Arbiter.inform(UIIntentionalStreamMessage.INSERT_STORIES);\",\"UIIntentionalStream.instance.updateTimeRange(1344870826, 1344870826);\",\"UIIntentionalStream.instance.updateOldestMR(1344704542);\",\"UIIntentionalStream.instance.updateScrollPosition(5);\",\"UIIntentionalStream.instance.updateLastViewStateID(\\\"8878831909009365538\\\");\",],\n    onafterload: [\"Bootloader.loadComponents([\\\"legacy:live-js\\\"], function(){ Live.startup() });\",],\n    content: {\n        pagelet_sub_stream_1: {\n            container_id: \"uq3j16_77\"\n        }\n    }\n});");
// 1736
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s871660ef4d72c39586beaaf2f6b481195e077f72");
// 1737
geval("bigPipe.JSBNG__onPageletArrive({\n    phase: 3,\n    id: \"pagelet_sub_stream_1\",\n    append: \"home_stream\",\n    jsmods: {\n        instances: [[\"m205541_59\",[\"PopoverAsyncMenuLoading\",],[\"HighlightSelectorMenu\",],3,],[\"m205541_61\",[\"PopoverAsyncMenu\",\"m205541_62\",\"m205541_60\",\"m205541_59\",\"PopoverMenuOverlappingBorder\",],[{\n            __m: \"m205541_62\"\n        },{\n            __m: \"m205541_60\"\n        },{\n            __m: \"m205541_59\"\n        },\"/ajax/feed/feed_menu.php?action=hide&story_div_id=stream_story_50291e77633c36f83163300&filter_key=h_nor&spam_object_id=3088544471436&report_link=0&story_type=245&source_id=0&qid=5776181494237290802&mf_story_key=8878831909009365538&actor_id=1055580469&num_participants=1&is_highlight=0&viewstate_id=8878831909009365538\",[{\n            __m: \"PopoverMenuOverlappingBorder\"\n        },],],1,],[\"m205541_62\",[\"Popover\",\"m205541_63\",\"m205541_60\",\"ContextualLayerAsyncRelative\",],[{\n            __m: \"m205541_63\"\n        },{\n            __m: \"m205541_60\"\n        },[{\n            __m: \"ContextualLayerAsyncRelative\"\n        },],{\n            alignh: \"right\",\n            layer_content: null\n        },],3,],],\n        markup: [[\"m205542_66\",{\n            __html: \"Show edit history\"\n        },2,],],\n        elements: [[\"m205541_63\",\"uq3j2t_35\",2,],[\"m205541_60\",\"uq3j2t_36\",4,],[\"m205541_64\",\"uq3j2t_37\",2,],[\"m205542_65\",\"uq3j2t_38\",2,],],\n        require: [[\"m205541_59\",],[\"m205541_61\",],[\"m205541_62\",],[\"Tooltip\",\"set\",[\"m205542_65\",\"m205542_66\",],[{\n            __m: \"m205542_65\"\n        },{\n            __m: \"m205542_66\"\n        },],],]\n    },\n    css: [\"zO4BE\",],\n    js: [\"8gPM0\",\"bS0QP\",\"JOZ9R\",],\n    requires: [\"pagelet_controller::home_intentional_stream\",\"pagelet_controller::substream_scroll_load_0\",],\n    provides: [\"pagelet_controller::substream_scroll_load_1\",],\n    JSBNG__onload: [\"Arbiter.inform(UIIntentionalStreamMessage.INSERT_STORIES);\",\"UIIntentionalStream.instance.updateTimeRange(1344870826, 1344870826);\",\"UIIntentionalStream.instance.updateOldestMR(1344704542);\",\"UIIntentionalStream.instance.updateScrollPosition(5);\",\"UIIntentionalStream.instance.updateLastViewStateID(\\\"8878831909009365538\\\");\",],\n    JSBNG__onafterload: [\"Bootloader.loadComponents([\\\"legacy:live-js\\\"], function(){ Live.startup() });\",],\n    JSBNG__content: {\n        pagelet_sub_stream_1: {\n            container_id: \"uq3j16_77\"\n        }\n    }\n});");
// 1742
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"bigPipe.onPageletArrive({\n    phase: 3,\n    id: \"pagelet_stream_pager\",\n    css: [\"zO4BE\",],\n    bootloadable: {\n        \"legacy:UIIntentionalStreamRefresh\": {\n            resources: [\"8gPM0\",\"bS0QP\",\"JOZ9R\",\"1vNpf\",]\n        }\n    },\n    resource_map: {\n        \"1vNpf\": {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yH/r/dEe7B2P3u-H.js\"\n        }\n    },\n    js: [\"8gPM0\",\"bS0QP\",],\n    onafterload: [\"Bootloader.loadComponents([\\\"legacy:UIIntentionalStreamRefresh\\\"], function(){ new UIIntentionalStreamRefresh({\\\"allow_auto_refresh\\\":true,\\\"allow_polling\\\":true,\\\"inactive_threshold\\\":300000,\\\"fast_refresh_rate\\\":43200000,\\\"slow_refresh_rate\\\":43200000,\\\"refresh_factor\\\":1,\\\"presence_loop_per_poll\\\":1,\\\"poll_below_interval_sec\\\":1800,\\\"min_refresh_interval\\\":15000,\\\"check_active_refresh_interval\\\":300000,\\\"active_refresh_interval\\\":30000,\\\"active_refresh\\\":true,\\\"story_interval\\\":78602000}, true); });\",],\n    content: {\n        pagelet_stream_pager: {\n            container_id: \"uq3j16_78\"\n        }\n    }\n});");
// 1743
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s42d0f5f36f518411268d58b1537cfe862f14020d");
// 1744
geval("bigPipe.JSBNG__onPageletArrive({\n    phase: 3,\n    id: \"pagelet_stream_pager\",\n    css: [\"zO4BE\",],\n    bootloadable: {\n        \"legacy:UIIntentionalStreamRefresh\": {\n            resources: [\"8gPM0\",\"bS0QP\",\"JOZ9R\",\"1vNpf\",]\n        }\n    },\n    resource_map: {\n        \"1vNpf\": {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v2/yH/r/dEe7B2P3u-H.js\"\n        }\n    },\n    js: [\"8gPM0\",\"bS0QP\",],\n    JSBNG__onafterload: [\"Bootloader.loadComponents([\\\"legacy:UIIntentionalStreamRefresh\\\"], function(){ new UIIntentionalStreamRefresh({\\\"allow_auto_refresh\\\":true,\\\"allow_polling\\\":true,\\\"inactive_threshold\\\":300000,\\\"fast_refresh_rate\\\":43200000,\\\"slow_refresh_rate\\\":43200000,\\\"refresh_factor\\\":1,\\\"presence_loop_per_poll\\\":1,\\\"poll_below_interval_sec\\\":1800,\\\"min_refresh_interval\\\":15000,\\\"check_active_refresh_interval\\\":300000,\\\"active_refresh_interval\\\":30000,\\\"active_refresh\\\":true,\\\"story_interval\\\":78602000}, true); });\",],\n    JSBNG__content: {\n        pagelet_stream_pager: {\n            container_id: \"uq3j16_78\"\n        }\n    }\n});");
// 1756
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"bigPipe.onPageletArrive({\n    phase: 3,\n    id: \"\",\n    is_last: true,\n    the_end: true,\n    css: [\"zO4BE\",],\n    js: [\"8gPM0\",\"bS0QP\",\"JOZ9R\",\"1zqwA\",\"6n1TR\",\"28ZbA\",\"C6rJk\",\"u8TjK\",\"oGZW7\",]\n});");
// 1757
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"sad1fa6c6dcc66f7502a94ec4a93d183391816646");
// 1758
geval("bigPipe.JSBNG__onPageletArrive({\n    phase: 3,\n    id: \"\",\n    is_last: true,\n    the_end: true,\n    css: [\"zO4BE\",],\n    js: [\"8gPM0\",\"bS0QP\",\"JOZ9R\",\"1zqwA\",\"6n1TR\",\"28ZbA\",\"C6rJk\",\"u8TjK\",\"oGZW7\",]\n});");
// 1764
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_136[0], o0,o11);
// undefined
o0 = null;
// undefined
o11 = null;
// 2566
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"8gPM0\",]);\n}\n;\n__d(\"Cookie\", [\"Env\",], function(a, b, c, d, e, f) {\n    var g = b(\"Env\"), h = {\n        set: function(i, j, k, l, m) {\n            if ((g.no_cookies && (i != \"tpa\"))) {\n                return\n            };\n            document.cookie = (((((((((i + \"=\") + encodeURIComponent(j)) + \"; \") + ((k ? ((\"expires=\" + (new Date((Date.now() + k))).toGMTString()) + \"; \") : \"\"))) + \"path=\") + ((l || \"/\"))) + \"; domain=\") + window.location.hostname.replace(/^.*(\\.facebook\\..*)$/i, \"$1\")) + ((m ? \"; secure\" : \"\")));\n        },\n        clear: function(i, j) {\n            j = (j || \"/\");\n            document.cookie = (((((i + \"=; expires=Thu, 01-Jan-1970 00:00:01 GMT; \") + \"path=\") + j) + \"; domain=\") + window.location.hostname.replace(/^.*(\\.facebook\\..*)$/i, \"$1\"));\n        },\n        get: function(i) {\n            var j = document.cookie.match(((\"(?:^|;\\\\s*)\" + i) + \"=(.*?)(?:;|$)\"));\n            return ((j ? decodeURIComponent(j[1]) : j));\n        }\n    };\n    e.exports = h;\n});\n__d(\"legacy:cookie\", [\"Cookie\",], function(a, b, c, d) {\n    var e = b(\"Cookie\");\n    a.getCookie = e.get;\n    a.setCookie = e.set;\n    a.clearCookie = e.clear;\n}, 3);\n__d(\"QueryString\", [], function(a, b, c, d, e, f) {\n    var g = {\n        encode: function(h) {\n            var i = [];\n            Object.keys(h).forEach(function(j) {\n                var k = h[j];\n                if ((typeof k === \"undefined\")) {\n                    return\n                };\n                if ((k === null)) {\n                    i.push(j);\n                    return;\n                }\n            ;\n                i.push(((encodeURIComponent(j) + \"=\") + encodeURIComponent(k)));\n            });\n            return i.join(\"&\");\n        },\n        decode: function(h) {\n            var i = {\n            };\n            if ((h === \"\")) {\n                return i\n            };\n            var j = h.split(\"&\"), k = j.length;\n            while (k--) {\n                var l = j[k].split(\"=\", 2);\n                i[decodeURIComponent(l[0])] = ((l.length === 2) ? decodeURIComponent(l[1]) : null);\n            };\n            return i;\n        },\n        appendToUrl: function(h, i) {\n            return ((h + ((~h.indexOf(\"?\") ? \"&\" : \"?\"))) + (((typeof i === \"string\") ? i : g.encode(i))));\n        }\n    };\n    e.exports = g;\n});\n__d(\"URI\", [\"copyProperties\",\"goURI\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\"), h = b(\"goURI\");\n    function i(j) {\n        if (!((this instanceof i))) {\n            return new i((j || window.location.href))\n        };\n        this.parse((j || \"\"));\n    };\n    g(i, {\n        getRequestURI: function(j, k) {\n            j = ((j === undefined) || j);\n            var l = a.PageTransitions;\n            if (((j && l) && l.isInitialized())) {\n                return l.getCurrentURI(!!k).getQualifiedURI();\n            }\n             else return new i(window.location.href)\n        ;\n        },\n        getMostRecentURI: function() {\n            var j = a.PageTransitions;\n            if ((j && j.isInitialized())) {\n                return j.getMostRecentURI().getQualifiedURI();\n            }\n             else return new i(window.location.href)\n        ;\n        },\n        getNextURI: function() {\n            var j = a.PageTransitions;\n            if ((j && j.isInitialized())) {\n                return j.getNextURI().getQualifiedURI();\n            }\n             else return new i(window.location.href)\n        ;\n        },\n        expression: /(((\\w+):\\/\\/)([^\\/:]*)(:(\\d+))?)?([^#?]*)(\\?([^#]*))?(#(.*))?/,\n        arrayQueryExpression: /^(\\w+)((?:\\[\\w*\\])+)=?(.*)/,\n        explodeQuery: function(j) {\n            if (!j) {\n                return {\n                }\n            };\n            var k = {\n            };\n            j = j.replace(/\u00255B/gi, \"[\").replace(/\u00255D/gi, \"]\");\n            j = j.split(\"&\");\n            var l = Object.prototype.hasOwnProperty;\n            for (var m = 0, n = j.length; (m < n); m++) {\n                var o = j[m].match(i.arrayQueryExpression);\n                if (!o) {\n                    var p = j[m].split(\"=\");\n                    k[i.decodeComponent(p[0])] = ((p[1] === undefined) ? null : i.decodeComponent(p[1]));\n                }\n                 else {\n                    var q = o[2].split(/\\]\\[|\\[|\\]/).slice(0, -1), r = o[1], s = i.decodeComponent((o[3] || \"\"));\n                    q[0] = r;\n                    var t = k;\n                    for (var u = 0; (u < (q.length - 1)); u++) {\n                        if (q[u]) {\n                            if (!l.call(t, q[u])) {\n                                var v = ((q[(u + 1)] && !q[(u + 1)].match(/^\\d+$/)) ? {\n                                } : []);\n                                t[q[u]] = v;\n                                if ((t[q[u]] !== v)) {\n                                    return k\n                                };\n                            }\n                        ;\n                            t = t[q[u]];\n                        }\n                         else {\n                            if ((q[(u + 1)] && !q[(u + 1)].match(/^\\d+$/))) {\n                                t.push({\n                                });\n                            }\n                             else t.push([]);\n                        ;\n                            t = t[(t.length - 1)];\n                        }\n                    ;\n                    };\n                    if (((t instanceof Array) && (q[(q.length - 1)] === \"\"))) {\n                        t.push(s);\n                    }\n                     else t[q[(q.length - 1)]] = s;\n                ;\n                }\n            ;\n            };\n            return k;\n        },\n        implodeQuery: function(j, k, l) {\n            k = (k || \"\");\n            if ((l === undefined)) {\n                l = true;\n            };\n            var m = [];\n            if (((j === null) || (j === undefined))) {\n                m.push((l ? i.encodeComponent(k) : k));\n            }\n             else if ((j instanceof Array)) {\n                for (var n = 0; (n < j.length); ++n) {\n                    try {\n                        if ((j[n] !== undefined)) {\n                            m.push(i.implodeQuery(j[n], (k ? ((((k + \"[\") + n) + \"]\")) : n), l));\n                        };\n                    } catch (o) {\n                    \n                    };\n                };\n            }\n             else if ((typeof (j) == \"object\")) {\n                if ((((\"nodeName\" in j)) && ((\"nodeType\" in j)))) {\n                    m.push(\"{node}\");\n                }\n                 else for (var p in j) {\n                    try {\n                        if ((j[p] !== undefined)) {\n                            m.push(i.implodeQuery(j[p], (k ? ((((k + \"[\") + p) + \"]\")) : p), l));\n                        };\n                    } catch (o) {\n                    \n                    };\n                }\n            ;\n            }\n             else if (l) {\n                m.push(((i.encodeComponent(k) + \"=\") + i.encodeComponent(j)));\n            }\n             else m.push(((k + \"=\") + j));\n            \n            \n            \n        ;\n            return m.join(\"&\");\n        },\n        encodeComponent: function(j) {\n            return encodeURIComponent(j).replace(/\u00255D/g, \"]\").replace(/\u00255B/g, \"[\");\n        },\n        decodeComponent: function(j) {\n            return decodeURIComponent(j.replace(/\\+/g, \" \"));\n        },\n        INVALID_DOMAIN: \"invalid.invalid\",\n        sanitizeDomain: function(j) {\n            var k = new RegExp(((\"[\\\\x00-\\\\x2c\\\\x2f\\\\x3b-\\\\x40\\\\x5c\\\\x5e\\\\x60\\\\x7b-\\\\x7f\" + \"\\\\uFDD0-\\\\uFDEF\\\\uFFF0-\\\\uFFFF\") + \"\\\\u2047\\\\u2048\\\\uFE56\\\\uFE5F\\\\uFF03\\\\uFF0F\\\\uFF1F]\"));\n            if (k.test(j)) {\n                return i.INVALID_DOMAIN;\n            }\n             else return j\n        ;\n        }\n    });\n    g(i.prototype, {\n        parse: function(j) {\n            var k = j.toString().match(i.expression);\n            g(this, {\n                protocol: (k[3] || \"\"),\n                domain: i.sanitizeDomain((k[4] || \"\")),\n                port: (k[6] || \"\"),\n                path: (k[7] || \"\"),\n                query_s: (k[9] || \"\"),\n                fragment: (k[11] || \"\")\n            });\n            return this;\n        },\n        setProtocol: function(j) {\n            this.protocol = j;\n            return this;\n        },\n        getProtocol: function() {\n            return this.protocol;\n        },\n        setQueryData: function(j) {\n            this.query_s = i.implodeQuery(j);\n            return this;\n        },\n        addQueryData: function(j) {\n            return this.setQueryData(g(this.getQueryData(), j));\n        },\n        removeQueryData: function(j) {\n            if (!Array.isArray(j)) {\n                j = [j,];\n            };\n            var k = this.getQueryData();\n            for (var l = 0, m = j.length; (l < m); ++l) {\n                delete k[j[l]];;\n            };\n            return this.setQueryData(k);\n        },\n        getQueryData: function() {\n            return i.explodeQuery(this.query_s);\n        },\n        setFragment: function(j) {\n            this.fragment = j;\n            return this;\n        },\n        getFragment: function() {\n            return this.fragment;\n        },\n        setDomain: function(j) {\n            this.domain = i.sanitizeDomain(j);\n            return this;\n        },\n        getDomain: function() {\n            return this.domain;\n        },\n        setPort: function(j) {\n            this.port = j;\n            return this;\n        },\n        getPort: function() {\n            return this.port;\n        },\n        setPath: function(j) {\n            this.path = j;\n            return this;\n        },\n        getPath: function() {\n            return this.path.replace(/^\\/+/, \"/\");\n        },\n        isEmpty: function() {\n            return !((((((this.path || this.protocol) || this.domain) || this.port) || this.query_s) || this.fragment));\n        },\n        toString: function() {\n            var j = \"\";\n            (this.protocol && (j += (this.protocol + \"://\")));\n            (this.domain && (j += this.domain));\n            (this.port && (j += (\":\" + this.port)));\n            if ((this.domain && !this.path)) {\n                j += \"/\";\n            };\n            (this.path && (j += this.path));\n            (this.query_s && (j += (\"?\" + this.query_s)));\n            (this.fragment && (j += (\"#\" + this.fragment)));\n            return j;\n        },\n        valueOf: function() {\n            return this.toString();\n        },\n        isFacebookURI: function() {\n            if (!i._facebookURIRegex) {\n                i._facebookURIRegex = new RegExp(\"(^|\\\\.)facebook\\\\.com([^.]*)$\", \"i\");\n            };\n            return ((!this.domain || i._facebookURIRegex.test(this.domain)));\n        },\n        isQuicklingEnabled: function() {\n            var j = a.Quickling;\n            return ((j && j.isActive()) && j.isPageActive(this));\n        },\n        getRegisteredDomain: function() {\n            if (!this.domain) {\n                return \"\"\n            };\n            if (!this.isFacebookURI()) {\n                return null\n            };\n            var j = this.domain.split(\".\"), k = j.indexOf(\"facebook\");\n            return j.slice(k).join(\".\");\n        },\n        getUnqualifiedURI: function() {\n            return new i(this).setProtocol(null).setDomain(null).setPort(null);\n        },\n        getQualifiedURI: function() {\n            var j = new i(this);\n            if (!j.getDomain()) {\n                var k = i();\n                j.setProtocol(k.getProtocol()).setDomain(k.getDomain()).setPort(k.getPort());\n            }\n        ;\n            return j;\n        },\n        isSameOrigin: function(j) {\n            var k = (j || window.location.href);\n            if (!((k instanceof i))) {\n                k = new i(k.toString());\n            };\n            if ((this.getProtocol() && (this.getProtocol() != k.getProtocol()))) {\n                return false\n            };\n            if ((this.getDomain() && (this.getDomain() != k.getDomain()))) {\n                return false\n            };\n            if ((this.getPort() && (this.getPort() != k.getPort()))) {\n                return false\n            };\n            return true;\n        },\n        go: function(j) {\n            h(this, j);\n        },\n        setSubdomain: function(j) {\n            var k = new i(this).getQualifiedURI(), l = k.getDomain().split(\".\");\n            if ((l.length <= 2)) {\n                l.unshift(j);\n            }\n             else l[0] = j;\n        ;\n            return k.setDomain(l.join(\".\"));\n        },\n        getSubdomain: function() {\n            if (!this.getDomain()) {\n                return \"\"\n            };\n            var j = this.getDomain().split(\".\");\n            if ((j.length <= 2)) {\n                return \"\";\n            }\n             else return j[0]\n        ;\n        },\n        setSecure: function(j) {\n            return this.setProtocol((j ? \"https\" : \"http\"));\n        },\n        isSecure: function() {\n            return (this.getProtocol() == \"https\");\n        }\n    });\n    e.exports = i;\n});\n__d(\"XHR\", [\"Env\",], function(a, b, c, d, e, f) {\n    var g = b(\"Env\"), h = {\n        create: function() {\n            try {\n                return (a.XMLHttpRequest ? new a.XMLHttpRequest() : new ActiveXObject(\"MSXML2.XMLHTTP.3.0\"));\n            } catch (i) {\n            \n            };\n        },\n        getAsyncParams: function(i) {\n            var j = {\n                __user: g.user,\n                __a: 1\n            };\n            if (((i == \"POST\") && g.fb_dtsg)) {\n                j.fb_dtsg = g.fb_dtsg;\n            };\n            if (g.fb_isb) {\n                j.fb_isb = g.fb_isb;\n            };\n            return j;\n        }\n    };\n    e.exports = h;\n});\n__d(\"AsyncSignal\", [\"Env\",\"ErrorUtils\",\"QueryString\",\"URI\",\"XHR\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Env\"), h = b(\"ErrorUtils\"), i = b(\"QueryString\"), j = b(\"URI\"), k = b(\"XHR\"), l = b(\"copyProperties\");\n    function m(n, o) {\n        this.data = (o || {\n        });\n        if ((g.tracking_domain && (n.charAt(0) == \"/\"))) {\n            n = (g.tracking_domain + n);\n        };\n        this.uri = n;\n    };\n    m.prototype.setHandler = function(n) {\n        this.handler = n;\n        return this;\n    };\n    m.prototype.send = function() {\n        var n = this.handler, o = this.data, p = new Image();\n        if (n) {\n            p.onload = p.onerror = function() {\n                h.applyWithGuard(n, null, [(p.height == 1),]);\n            };\n        };\n        o.asyncSignal = ((((Math.random() * 10000) | 0)) + 1);\n        var q = new j(this.uri).isFacebookURI();\n        l(o, k.getAsyncParams((q ? \"POST\" : \"GET\")));\n        p.src = i.appendToUrl(this.uri, o);\n        return this;\n    };\n    e.exports = m;\n});\n__d(\"legacy:async-signal\", [\"AsyncSignal\",], function(a, b, c, d) {\n    a.AsyncSignal = b(\"AsyncSignal\");\n}, 3);\n__d(\"legacy:uri\", [\"URI\",], function(a, b, c, d) {\n    a.URI = b(\"URI\");\n}, 3);\nfunction detect_broken_proxy_cache(a, b) {\n    var c = getCookie(b);\n    if (((((c != a)) && ((c != null))) && ((a != \"0\")))) {\n        var d = {\n            c: \"si_detect_broken_proxy_cache\",\n            m: ((((b + \" \") + a) + \" \") + c)\n        }, e = new URI(\"/common/scribe_endpoint.php\").getQualifiedURI().toString();\n        new AsyncSignal(e, d).send();\n    }\n;\n};\n__d(\"LinkshimAsyncLink\", [\"$\",\"AsyncSignal\",], function(a, b, c, d, e, f) {\n    var g = b(\"$\"), h = b(\"AsyncSignal\"), i = {\n        swap: function(j, k) {\n            j.href = k;\n        },\n        referrer_log: function(j, k, l) {\n            var m = g(\"meta_referrer\");\n            m.content = \"origin\";\n            i.swap(j, k);\n            (function() {\n                m.content = \"default\";\n                new h(l, {\n                }).send();\n            }).defer(100);\n        }\n    };\n    e.exports = i;\n});\n__d(\"legacy:dom-asynclinkshim\", [\"LinkshimAsyncLink\",], function(a, b, c, d) {\n    a.LinkshimAsyncLink = b(\"LinkshimAsyncLink\");\n}, 3);\n__d(\"DataStore\", [], function(a, b, c, d, e, f) {\n    var g = {\n    }, h = 1;\n    function i(l) {\n        if ((typeof l == \"string\")) {\n            return (\"str_\" + l);\n        }\n         else return (\"elem_\" + ((l.__FB_TOKEN || (l.__FB_TOKEN = [h++,])))[0])\n    ;\n    };\n    function j(l) {\n        var m = i(l);\n        return (g[m] || (g[m] = {\n        }));\n    };\n    var k = {\n        set: function(l, m, n) {\n            if (!l) {\n                throw new TypeError((\"DataStore.set: namespace is required, got \" + (typeof l)))\n            };\n            var o = j(l);\n            o[m] = n;\n            return l;\n        },\n        get: function(l, m, n) {\n            if (!l) {\n                throw new TypeError((\"DataStore.get: namespace is required, got \" + (typeof l)))\n            };\n            var o = j(l), p = o[m];\n            if (((typeof p === \"undefined\") && l.getAttribute)) {\n                var q = l.getAttribute((\"data-\" + m));\n                p = (((null === q)) ? undefined : q);\n            }\n        ;\n            if ((((n !== undefined)) && ((p === undefined)))) {\n                p = o[m] = n;\n            };\n            return p;\n        },\n        remove: function(l, m) {\n            if (!l) {\n                throw new TypeError((\"DataStore.remove: namespace is required, got \" + (typeof l)))\n            };\n            var n = j(l), o = n[m];\n            delete n[m];\n            return o;\n        },\n        purge: function(l) {\n            delete g[i(l)];\n        }\n    };\n    e.exports = k;\n});\n__d(\"UserAgent\", [], function(a, b, c, d, e, f) {\n    var g = false, h, i, j, k, l, m, n, o, p, q, r, s, t, u;\n    function v() {\n        if (g) {\n            return\n        };\n        g = true;\n        var x = navigator.userAgent, y = /(?:MSIE.(\\d+\\.\\d+))|(?:(?:Firefox|GranParadiso|Iceweasel).(\\d+\\.\\d+))|(?:Opera(?:.+Version.|.)(\\d+\\.\\d+))|(?:AppleWebKit.(\\d+(?:\\.\\d+)?))/.exec(x), z = /(Mac OS X)|(Windows)|(Linux)/.exec(x);\n        r = /\\b(iPhone|iP[ao]d)/.exec(x);\n        s = /\\b(iP[ao]d)/.exec(x);\n        p = /Android/i.exec(x);\n        t = /FBAN\\/\\w+;/i.exec(x);\n        u = /Mobile/i.exec(x);\n        q = !!(/Win64/.exec(x));\n        if (y) {\n            h = (y[1] ? parseFloat(y[1]) : NaN);\n            if ((h && document.documentMode)) {\n                h = document.documentMode;\n            };\n            i = (y[2] ? parseFloat(y[2]) : NaN);\n            j = (y[3] ? parseFloat(y[3]) : NaN);\n            k = (y[4] ? parseFloat(y[4]) : NaN);\n            if (k) {\n                y = /(?:Chrome\\/(\\d+\\.\\d+))/.exec(x);\n                l = ((y && y[1]) ? parseFloat(y[1]) : NaN);\n            }\n             else l = NaN;\n        ;\n        }\n         else h = i = j = l = k = NaN;\n    ;\n        if (z) {\n            if (z[1]) {\n                var aa = /(?:Mac OS X (\\d+(?:[._]\\d+)?))/.exec(x);\n                m = (aa ? parseFloat(aa[1].replace(\"_\", \".\")) : true);\n            }\n             else m = false;\n        ;\n            n = !!z[2];\n            o = !!z[3];\n        }\n         else m = n = o = false;\n    ;\n    };\n    var w = {\n        ie: function() {\n            return (v() || h);\n        },\n        ie64: function() {\n            return (w.ie() && q);\n        },\n        firefox: function() {\n            return (v() || i);\n        },\n        opera: function() {\n            return (v() || j);\n        },\n        safari: function() {\n            return (v() || k);\n        },\n        chrome: function() {\n            return (v() || l);\n        },\n        windows: function() {\n            return (v() || n);\n        },\n        osx: function() {\n            return (v() || m);\n        },\n        linux: function() {\n            return (v() || o);\n        },\n        iphone: function() {\n            return (v() || r);\n        },\n        mobile: function() {\n            return (v() || ((((r || s) || p) || u)));\n        },\n        nativeApp: function() {\n            return (v() || t);\n        },\n        android: function() {\n            return (v() || p);\n        },\n        ipad: function() {\n            return (v() || s);\n        }\n    };\n    e.exports = w;\n});\n__d(\"createObjectFrom\", [\"hasArrayNature\",], function(a, b, c, d, e, f) {\n    var g = b(\"hasArrayNature\");\n    function h(i, j) {\n        var k = {\n        }, l = g(j);\n        if ((typeof j == \"undefined\")) {\n            j = true;\n        };\n        for (var m = i.length; m--; ) {\n            k[i[m]] = (l ? j[m] : j);;\n        };\n        return k;\n    };\n    e.exports = h;\n});\n__d(\"DOMQuery\", [\"CSS\",\"UserAgent\",\"createArrayFrom\",\"createObjectFrom\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"UserAgent\"), i = b(\"createArrayFrom\"), j = b(\"createObjectFrom\"), k = b(\"ge\"), l = null, m = {\n        find: function(n, o) {\n            var p = m.scry(n, o);\n            return p[0];\n        },\n        scry: function(n, o) {\n            if ((!n || !n.getElementsByTagName)) {\n                return []\n            };\n            var p = o.split(\" \"), q = [n,];\n            for (var r = 0; (r < p.length); r++) {\n                if ((q.length === 0)) {\n                    break;\n                };\n                if ((p[r] === \"\")) {\n                    continue;\n                };\n                var s = p[r], t = p[r], u = [], v = false;\n                if ((s.charAt(0) == \"^\")) {\n                    if ((r === 0)) {\n                        v = true;\n                        s = s.slice(1);\n                    }\n                     else return []\n                \n                };\n                s = s.replace(/\\./g, \" .\");\n                s = s.replace(/\\#/g, \" #\");\n                s = s.replace(/\\[/g, \" [\");\n                var w = s.split(\" \"), x = (w[0] || \"*\"), y = (x == \"*\"), z = (w[1] && (w[1].charAt(0) == \"#\"));\n                if (z) {\n                    var aa = k(w[1].slice(1), true);\n                    if ((aa && ((y || (aa.tagName.toLowerCase() == x))))) {\n                        for (var ba = 0; (ba < q.length); ba++) {\n                            if ((v && m.contains(aa, q[ba]))) {\n                                u = [aa,];\n                                break;\n                            }\n                             else if (((document == q[ba]) || m.contains(q[ba], aa))) {\n                                u = [aa,];\n                                break;\n                            }\n                            \n                        ;\n                        }\n                    };\n                }\n                 else {\n                    var ca = [], da = q.length, ea, fa = ((!v && (t.indexOf(\"[\") < 0)) && document.querySelectorAll);\n                    for (var ga = 0; (ga < da); ga++) {\n                        if (v) {\n                            ea = [];\n                            var ha = q[ga].parentNode;\n                            while (m.isElementNode(ha)) {\n                                if ((y || (ha.tagName.toLowerCase() == x))) {\n                                    ea.push(ha);\n                                };\n                                ha = ha.parentNode;\n                            };\n                        }\n                         else if (fa) {\n                            ea = q[ga].querySelectorAll(t);\n                        }\n                         else ea = q[ga].getElementsByTagName(x);\n                        \n                    ;\n                        var ia = ea.length;\n                        for (var ja = 0; (ja < ia); ja++) {\n                            ca.push(ea[ja]);;\n                        };\n                    };\n                    if (!fa) {\n                        for (var ka = 1; (ka < w.length); ka++) {\n                            var la = w[ka], ma = (la.charAt(0) == \".\"), na = la.substring(1);\n                            for (ga = 0; (ga < ca.length); ga++) {\n                                var oa = ca[ga];\n                                if (!oa) {\n                                    continue;\n                                };\n                                if (ma) {\n                                    if (!g.hasClass(oa, na)) {\n                                        delete ca[ga];\n                                    };\n                                    continue;\n                                }\n                                 else {\n                                    var pa = la.slice(1, (la.length - 1));\n                                    if ((pa.indexOf(\"=\") == -1)) {\n                                        if ((oa.getAttribute(pa) === null)) {\n                                            delete ca[ga];\n                                            continue;\n                                        }\n                                    ;\n                                    }\n                                     else {\n                                        var qa = pa.split(\"=\"), ra = qa[0], sa = qa[1];\n                                        sa = sa.slice(1, (sa.length - 1));\n                                        if ((oa.getAttribute(ra) != sa)) {\n                                            delete ca[ga];\n                                            continue;\n                                        }\n                                    ;\n                                    }\n                                ;\n                                }\n                            ;\n                            };\n                        }\n                    };\n                    for (ga = 0; (ga < ca.length); ga++) {\n                        if (ca[ga]) {\n                            u.push(ca[ga]);\n                            if (v) {\n                                break;\n                            };\n                        }\n                    ;\n                    };\n                }\n            ;\n                q = u;\n            };\n            return q;\n        },\n        getText: function(n) {\n            if (m.isTextNode(n)) {\n                return n.data;\n            }\n             else if (m.isElementNode(n)) {\n                if ((l === null)) {\n                    var o = document.createElement(\"div\");\n                    l = ((o.textContent != null) ? \"textContent\" : \"innerText\");\n                }\n            ;\n                return n[l];\n            }\n             else return \"\"\n            \n        ;\n        },\n        getSelection: function() {\n            var n = window.getSelection, o = document.selection;\n            if (n) {\n                return (n() + \"\");\n            }\n             else if (o) {\n                return o.createRange().text\n            }\n        ;\n            return null;\n        },\n        contains: function(n, o) {\n            n = k(n);\n            o = k(o);\n            if ((!n || !o)) {\n                return false;\n            }\n             else if ((n === o)) {\n                return true;\n            }\n             else if (m.isTextNode(n)) {\n                return false;\n            }\n             else if (m.isTextNode(o)) {\n                return m.contains(n, o.parentNode);\n            }\n             else if (n.contains) {\n                return n.contains(o);\n            }\n             else if (n.compareDocumentPosition) {\n                return !!((n.compareDocumentPosition(o) & 16));\n            }\n             else return false\n            \n            \n            \n            \n            \n        ;\n        },\n        getRootElement: function() {\n            var n = null;\n            if ((window.Quickling && Quickling.isActive())) {\n                n = k(\"content\");\n            };\n            return (n || document.body);\n        },\n        isNode: function(n) {\n            return !!((n && (((typeof Node == \"object\") ? (n instanceof Node) : (((typeof n == \"object\") && (typeof n.nodeType == \"number\")) && (typeof n.nodeName == \"string\"))))));\n        },\n        isNodeOfType: function(n, o) {\n            var p = i(o).join(\"|\").toUpperCase().split(\"|\"), q = j(p);\n            return (m.isNode(n) && (n.nodeName in q));\n        },\n        isElementNode: function(n) {\n            return (m.isNode(n) && (n.nodeType == 1));\n        },\n        isTextNode: function(n) {\n            return (m.isNode(n) && (n.nodeType == 3));\n        },\n        getDocumentScrollElement: function(n) {\n            n = (n || document);\n            var o = (h.chrome() || h.safari());\n            return ((!o && (n.compatMode === \"CSS1Compat\")) ? n.documentElement : n.body);\n        }\n    };\n    e.exports = m;\n});\n__d(\"DOMEvent\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\");\n    function h(i) {\n        this.event = (i || window.event);\n        this.target = (this.event.target || this.event.srcElement);\n    };\n    g(h.prototype, {\n        preventDefault: function() {\n            var i = this.event;\n            (i.preventDefault ? i.preventDefault() : i.returnValue = false);\n            return this;\n        },\n        stopPropagation: function() {\n            var i = this.event;\n            (i.stopPropagation ? i.stopPropagation() : i.cancelBubble = true);\n            return this;\n        },\n        kill: function() {\n            this.stopPropagation().preventDefault();\n            return this;\n        }\n    });\n    e.exports = h;\n});\n__d(\"getObjectValues\", [\"hasArrayNature\",], function(a, b, c, d, e, f) {\n    var g = b(\"hasArrayNature\");\n    function h(i) {\n        var j = [];\n        for (var k in i) {\n            j.push(i[k]);;\n        };\n        return j;\n    };\n    e.exports = h;\n});\n__d(\"event-extensions\", [\"event-form-bubbling\",\"DataStore\",\"DOMQuery\",\"DOMEvent\",\"ErrorUtils\",\"Parent\",\"UserAgent\",\"$\",\"copyProperties\",\"getObjectValues\",], function(a, b, c, d, e, f) {\n    b(\"event-form-bubbling\");\n    var g = b(\"DataStore\"), h = b(\"DOMQuery\"), i = b(\"DOMEvent\"), j = b(\"ErrorUtils\"), k = b(\"Parent\"), l = b(\"UserAgent\"), m = b(\"$\"), n = b(\"copyProperties\"), o = b(\"getObjectValues\");\n    Event.DATASTORE_KEY = \"Event.listeners\";\n    if (!Event.prototype) {\n        Event.prototype = {\n        };\n    };\n    function p(y, z, aa) {\n        this.target = y;\n        this.type = z;\n        this.data = aa;\n    };\n    n(p.prototype, {\n        getData: function() {\n            this.data = (this.data || {\n            });\n            return this.data;\n        },\n        stop: function() {\n            new i(this).stopPropagation();\n            return this;\n        },\n        prevent: function() {\n            new i(this).preventDefault();\n            return this;\n        },\n        kill: function() {\n            this.stop().prevent();\n            return false;\n        },\n        getTarget: function() {\n            return (new i(this).target || null);\n        }\n    });\n    function q(y) {\n        if ((y instanceof p)) {\n            return y\n        };\n        y = ((y || window.event) || {\n        });\n        if (!y._inherits_from_prototype) {\n            for (var z in Event.prototype) {\n                try {\n                    y[z] = Event.prototype[z];\n                } catch (aa) {\n                \n                };\n            }\n        };\n        return y;\n    };\n    n(Event.prototype, {\n        _inherits_from_prototype: true,\n        getRelatedTarget: function() {\n            var y = (this.relatedTarget || (((this.fromElement === this.srcElement) ? this.toElement : this.fromElement)));\n            return (y ? m(y) : null);\n        },\n        getModifiers: function() {\n            var y = {\n                control: !!this.ctrlKey,\n                shift: !!this.shiftKey,\n                alt: !!this.altKey,\n                meta: !!this.metaKey\n            };\n            y.access = (l.osx() ? y.control : y.alt);\n            y.any = (((y.control || y.shift) || y.alt) || y.meta);\n            return y;\n        },\n        isRightClick: function() {\n            if (this.which) {\n                return (this.which === 3)\n            };\n            return (this.button && (this.button === 2));\n        },\n        isMiddleClick: function() {\n            if (this.which) {\n                return (this.which === 2)\n            };\n            return (this.button && (this.button === 4));\n        },\n        isDefaultRequested: function() {\n            return ((this.getModifiers().any || this.isMiddleClick()) || this.isRightClick());\n        }\n    });\n    n(Event.prototype, p.prototype);\n    n(Event, {\n        listen: function(y, z, aa, ba) {\n            if ((typeof y == \"string\")) {\n                y = m(y);\n            };\n            if ((typeof ba == \"undefined\")) {\n                ba = Event.Priority.NORMAL;\n            };\n            if ((typeof z == \"object\")) {\n                var ca = {\n                };\n                for (var da in z) {\n                    ca[da] = Event.listen(y, da, z[da], ba);;\n                };\n                return ca;\n            }\n        ;\n            if (z.match(/^on/i)) {\n                throw new TypeError(((\"Bad event name `\" + z) + \"': use `click', not `onclick'.\"))\n            };\n            if (((y.nodeName == \"LABEL\") && (z == \"click\"))) {\n                var ea = y.getElementsByTagName(\"input\");\n                y = ((ea.length == 1) ? ea[0] : y);\n            }\n             else if (((y === window) && (z === \"scroll\"))) {\n                var fa = h.getDocumentScrollElement();\n                if (((fa !== document.documentElement) && (fa !== document.body))) {\n                    y = fa;\n                };\n            }\n            \n        ;\n            var ga = g.get(y, s, {\n            });\n            if (u[z]) {\n                var ha = u[z];\n                z = ha.base;\n                aa = ha.wrap(aa);\n            }\n        ;\n            v(y, z);\n            var ia = ga[z];\n            if (!((ba in ia))) {\n                ia[ba] = [];\n            };\n            var ja = ia[ba].length, ka = new x(aa, ia[ba], ja);\n            ia[ba].push(ka);\n            return ka;\n        },\n        stop: function(y) {\n            new i(y).stopPropagation();\n            return y;\n        },\n        prevent: function(y) {\n            new i(y).preventDefault();\n            return y;\n        },\n        kill: function(y) {\n            new i(y).kill();\n            return false;\n        },\n        getKeyCode: function(event) {\n            event = new i(event).event;\n            if (!event) {\n                return false\n            };\n            switch (event.keyCode) {\n              case 63232:\n                return 38;\n              case 63233:\n                return 40;\n              case 63234:\n                return 37;\n              case 63235:\n                return 39;\n              case 63272:\n            \n              case 63273:\n            \n              case 63275:\n                return null;\n              case 63276:\n                return 33;\n              case 63277:\n                return 34;\n            };\n            if (event.shiftKey) {\n                switch (event.keyCode) {\n                  case 33:\n                \n                  case 34:\n                \n                  case 37:\n                \n                  case 38:\n                \n                  case 39:\n                \n                  case 40:\n                    return null;\n                }\n            };\n            return event.keyCode;\n        },\n        getPriorities: function() {\n            if (!r) {\n                var y = o(Event.Priority);\n                y.sort(function(z, aa) {\n                    return (z - aa);\n                });\n                r = y;\n            }\n        ;\n            return r;\n        },\n        fire: function(y, z, aa) {\n            var ba = new p(y, z, aa), ca;\n            do {\n                var da = Event.__getHandler(y, z);\n                if (da) {\n                    ca = da(ba);\n                };\n                y = y.parentNode;\n            } while (((y && (ca !== false)) && !ba.cancelBubble));\n            return (ca !== false);\n        },\n        __fire: function(y, z, event) {\n            var aa = Event.__getHandler(y, z);\n            if (aa) {\n                return aa(q(event))\n            };\n        },\n        __getHandler: function(y, z) {\n            return g.get(y, (Event.DATASTORE_KEY + z));\n        },\n        getPosition: function(y) {\n            y = new i(y).event;\n            var z = h.getDocumentScrollElement(), aa = (y.clientX + z.scrollLeft), ba = (y.clientY + z.scrollTop);\n            return {\n                x: aa,\n                y: ba\n            };\n        }\n    });\n    var r = null, s = Event.DATASTORE_KEY, t = function(y) {\n        return function(z) {\n            if (!h.contains(this, z.getRelatedTarget())) {\n                return y.call(this, z)\n            };\n        };\n    }, u = {\n        mouseenter: {\n            base: \"mouseover\",\n            wrap: t\n        },\n        mouseleave: {\n            base: \"mouseout\",\n            wrap: t\n        }\n    }, v = function(y, z) {\n        var aa = (\"on\" + z), ba = w.bind(y), ca = g.get(y, s);\n        if ((z in ca)) {\n            return\n        };\n        ca[z] = {\n        };\n        if (y.addEventListener) {\n            y.addEventListener(z, ba, false);\n        }\n         else if (y.attachEvent) {\n            y.attachEvent(aa, ba);\n        }\n    ;\n        g.set(y, (s + z), ba);\n        if (y[aa]) {\n            var da = ((y === document.documentElement) ? Event.Priority._BUBBLE : Event.Priority.TRADITIONAL), ea = y[aa];\n            y[aa] = null;\n            Event.listen(y, z, ea, da);\n        }\n    ;\n        if (((y.nodeName === \"FORM\") && (z === \"submit\"))) {\n            Event.listen(y, z, Event.__bubbleSubmit.curry(y), Event.Priority._BUBBLE);\n        };\n    }, w = function(event) {\n        event = q(event);\n        var y = event.type;\n        if (!g.get(this, s)) {\n            throw new Error(\"Bad listenHandler context.\")\n        };\n        var z = g.get(this, s)[y];\n        if (!z) {\n            throw new Error(((\"No registered handlers for `\" + y) + \"'.\"))\n        };\n        if (((y == \"click\") && window.userAction)) {\n            var aa = k.byTag(event.getTarget(), \"a\"), ba = window.userAction(\"click\", aa, event).coalesce_namespace(\"evt_ext\");\n            if (window.ArbiterMonitor) {\n                window.ArbiterMonitor.initUA(ba, [aa,]);\n            };\n        }\n    ;\n        var ca = Event.getPriorities();\n        for (var da = 0; (da < ca.length); da++) {\n            var ea = ca[da];\n            if ((ea in z)) {\n                var fa = z[ea];\n                for (var ga = 0; (ga < fa.length); ga++) {\n                    if (!fa[ga]) {\n                        continue;\n                    };\n                    var ha = fa[ga].fire(this, event);\n                    if ((ha === false)) {\n                        return event.kill();\n                    }\n                     else if (event.cancelBubble) {\n                        event.stop();\n                    }\n                ;\n                };\n            }\n        ;\n        };\n        return event.returnValue;\n    };\n    Event.Priority = {\n        URGENT: -20,\n        TRADITIONAL: -10,\n        NORMAL: 0,\n        _BUBBLE: 1000\n    };\n    function x(y, z, aa) {\n        this._handler = y;\n        this._container = z;\n        this._index = aa;\n    };\n    n(x.prototype, {\n        remove: function() {\n            delete this._handler;\n            delete this._container[this._index];\n        },\n        fire: function(y, event) {\n            return j.applyWithGuard(this._handler, y, [event,], function(z) {\n                z.event_type = event.type;\n                z.dom_element = (y.name || y.id);\n                z.category = \"eventhandler\";\n            });\n        }\n    });\n    a.$E = f.$E = q;\n});\n__d(\"evalGlobal\", [], function(a, b, c, d, e, f) {\n    function g(h) {\n        if ((typeof h != \"string\")) {\n            throw new TypeError(\"JS sent to evalGlobal is not a string. Only strings are permitted.\")\n        };\n        if (!h) {\n            return\n        };\n        var i = document.createElement(\"script\");\n        try {\n            i.appendChild(document.createTextNode(h));\n        } catch (j) {\n            i.text = h;\n        };\n        var k = (document.getElementsByTagName(\"head\")[0] || document.documentElement);\n        k.appendChild(i);\n        k.removeChild(i);\n    };\n    e.exports = g;\n});\n__d(\"HTML\", [\"function-extensions\",\"Bootloader\",\"UserAgent\",\"copyProperties\",\"createArrayFrom\",\"evalGlobal\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"Bootloader\"), h = b(\"UserAgent\"), i = b(\"copyProperties\"), j = b(\"createArrayFrom\"), k = b(\"evalGlobal\");\n    function l(m) {\n        if ((m && m.__html)) {\n            m = m.__html;\n        };\n        if (!((this instanceof l))) {\n            if ((m instanceof l)) {\n                return m\n            };\n            return new l(m);\n        }\n    ;\n        this._content = m;\n        this._defer = false;\n        this._extra_action = \"\";\n        this._nodes = null;\n        this._inline_js = bagofholding;\n        this._rootNode = null;\n        return this;\n    };\n    l.isHTML = function(m) {\n        return (m && (((m instanceof l) || (m.__html !== undefined))));\n    };\n    l.replaceJSONWrapper = function(m) {\n        return ((m && (m.__html !== undefined)) ? new l(m.__html) : m);\n    };\n    i(l.prototype, {\n        toString: function() {\n            var m = (this._content || \"\");\n            if (this._extra_action) {\n                m += (((\"\\u003Cscript type=\\\"text/javascript\\\"\\u003E\" + this._extra_action) + \"\\u003C/scr\") + \"ipt\\u003E\");\n            };\n            return m;\n        },\n        setAction: function(m) {\n            this._extra_action = m;\n            return this;\n        },\n        getAction: function() {\n            this._fillCache();\n            var m = function() {\n                this._inline_js();\n                k(this._extra_action);\n            }.bind(this);\n            if (this.getDeferred()) {\n                return m.defer.bind(m);\n            }\n             else return m\n        ;\n        },\n        setDeferred: function(m) {\n            this._defer = !!m;\n            return this;\n        },\n        getDeferred: function() {\n            return this._defer;\n        },\n        getContent: function() {\n            return this._content;\n        },\n        getNodes: function() {\n            this._fillCache();\n            return this._nodes;\n        },\n        getRootNode: function() {\n            var m = this.getNodes();\n            if ((m.length === 1)) {\n                this._rootNode = m[0];\n            }\n             else {\n                var n = document.createDocumentFragment();\n                for (var o = 0; (o < m.length); o++) {\n                    n.appendChild(m[o]);;\n                };\n                this._rootNode = n;\n            }\n        ;\n            return this._rootNode;\n        },\n        _fillCache: function() {\n            if ((null !== this._nodes)) {\n                return\n            };\n            var m = this._content;\n            if (!m) {\n                this._nodes = [];\n                return;\n            }\n        ;\n            m = m.replace(/(<(\\w+)[^>]*?)\\/>/g, function(x, y, z) {\n                return (z.match(/^(abbr|br|col|img|input|link|meta|param|hr|area|embed)$/i) ? x : (((y + \"\\u003E\\u003C/\") + z) + \"\\u003E\"));\n            });\n            var n = m.trim().toLowerCase(), o = document.createElement(\"div\"), p = false, q = ((((((((!n.indexOf(\"\\u003Copt\") && [1,\"\\u003Cselect multiple=\\\"multiple\\\" class=\\\"__WRAPPER\\\"\\u003E\",\"\\u003C/select\\u003E\",])) || ((!n.indexOf(\"\\u003Cleg\") && [1,\"\\u003Cfieldset class=\\\"__WRAPPER\\\"\\u003E\",\"\\u003C/fieldset\\u003E\",]))) || ((n.match(/^<(thead|tbody|tfoot|colg|cap)/) && [1,\"\\u003Ctable class=\\\"__WRAPPER\\\"\\u003E\",\"\\u003C/table\\u003E\",]))) || ((!n.indexOf(\"\\u003Ctr\") && [2,\"\\u003Ctable\\u003E\\u003Ctbody class=\\\"__WRAPPER\\\"\\u003E\",\"\\u003C/tbody\\u003E\\u003C/table\\u003E\",]))) || ((((!n.indexOf(\"\\u003Ctd\") || !n.indexOf(\"\\u003Cth\"))) && [3,\"\\u003Ctable\\u003E\\u003Ctbody\\u003E\\u003Ctr class=\\\"__WRAPPER\\\"\\u003E\",\"\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\",]))) || ((!n.indexOf(\"\\u003Ccol\") && [2,\"\\u003Ctable\\u003E\\u003Ctbody\\u003E\\u003C/tbody\\u003E\\u003Ccolgroup class=\\\"__WRAPPER\\\"\\u003E\",\"\\u003C/colgroup\\u003E\\u003C/table\\u003E\",]))) || null);\n            if ((null === q)) {\n                o.className = \"__WRAPPER\";\n                if (h.ie()) {\n                    q = [0,\"\\u003Cspan style=\\\"display:none\\\"\\u003E&nbsp;\\u003C/span\\u003E\",\"\",];\n                    p = true;\n                }\n                 else q = [0,\"\",\"\",];\n            ;\n            }\n        ;\n            o.innerHTML = ((q[1] + m) + q[2]);\n            while (q[0]--) {\n                o = o.lastChild;;\n            };\n            if (p) {\n                o.removeChild(o.firstChild);\n            };\n            (o.className != \"__WRAPPER\");\n            if (h.ie()) {\n                var r;\n                if ((!n.indexOf(\"\\u003Ctable\") && (-1 == n.indexOf(\"\\u003Ctbody\")))) {\n                    r = (o.firstChild && o.firstChild.childNodes);\n                }\n                 else if (((q[1] == \"\\u003Ctable\\u003E\") && (-1 == n.indexOf(\"\\u003Ctbody\")))) {\n                    r = o.childNodes;\n                }\n                 else r = [];\n                \n            ;\n                for (var s = (r.length - 1); (s >= 0); --s) {\n                    if (((r[s].nodeName && (r[s].nodeName.toLowerCase() == \"tbody\")) && (r[s].childNodes.length == 0))) {\n                        r[s].parentNode.removeChild(r[s]);\n                    };\n                };\n            }\n        ;\n            var t = o.getElementsByTagName(\"script\"), u = [];\n            for (var v = 0; (v < t.length); v++) {\n                if (t[v].src) {\n                    u.push(g.requestResource.bind(g, \"js\", t[v].src));\n                }\n                 else u.push(k.bind(null, t[v].innerHTML));\n            ;\n            };\n            for (var v = (t.length - 1); (v >= 0); v--) {\n                t[v].parentNode.removeChild(t[v]);;\n            };\n            var w = function() {\n                for (var x = 0; (x < u.length); x++) {\n                    u[x]();;\n                };\n            };\n            this._nodes = j(o.childNodes);\n            this._inline_js = w;\n        }\n    });\n    e.exports = l;\n});\n__d(\"isScalar\", [], function(a, b, c, d, e, f) {\n    function g(h) {\n        return (/string|number|boolean/).test(typeof h);\n    };\n    e.exports = g;\n});\n__d(\"DOM\", [\"event-extensions\",\"CSS\",\"DOMQuery\",\"HTML\",\"UserAgent\",\"$\",\"copyProperties\",\"createArrayFrom\",\"isScalar\",\"tx\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"CSS\"), h = b(\"DOMQuery\"), i = b(\"HTML\"), j = b(\"UserAgent\"), k = b(\"$\"), l = b(\"copyProperties\"), m = b(\"createArrayFrom\"), n = b(\"isScalar\"), o = b(\"tx\"), p = \"js_\", q = 0, r = {\n    };\n    l(r, h);\n    l(r, {\n        create: function(u, v, w) {\n            var x = document.createElement(u);\n            if (v) {\n                r.setAttributes(x, v);\n            };\n            if ((w != null)) {\n                r.setContent(x, w);\n            };\n            return x;\n        },\n        setAttributes: function(u, v) {\n            if (v.type) {\n                u.type = v.type;\n            };\n            for (var w in v) {\n                var x = v[w], y = (/^on/i).test(w);\n                if ((w == \"type\")) {\n                    continue;\n                }\n                 else if ((w == \"style\")) {\n                    if ((typeof x == \"string\")) {\n                        u.style.cssText = x;\n                    }\n                     else l(u.style, x);\n                ;\n                }\n                 else if (y) {\n                    Event.listen(u, w.substr(2), x);\n                }\n                 else if ((w in u)) {\n                    u[w] = x;\n                }\n                 else if (u.setAttribute) {\n                    u.setAttribute(w, x);\n                }\n                \n                \n                \n            ;\n            };\n        },\n        prependContent: function(u, v) {\n            return s(v, u, function(w) {\n                (u.firstChild ? u.insertBefore(w, u.firstChild) : u.appendChild(w));\n            });\n        },\n        insertAfter: function(u, v) {\n            var w = u.parentNode;\n            return s(v, w, function(x) {\n                (u.nextSibling ? w.insertBefore(x, u.nextSibling) : w.appendChild(x));\n            });\n        },\n        insertBefore: function(u, v) {\n            var w = u.parentNode;\n            return s(v, w, function(x) {\n                w.insertBefore(x, u);\n            });\n        },\n        setContent: function(u, v) {\n            r.empty(u);\n            return r.appendContent(u, v);\n        },\n        appendContent: function(u, v) {\n            return s(v, u, function(w) {\n                u.appendChild(w);\n            });\n        },\n        replace: function(u, v) {\n            var w = u.parentNode;\n            return s(v, w, function(x) {\n                w.replaceChild(x, u);\n            });\n        },\n        remove: function(u) {\n            u = k(u);\n            if (u.parentNode) {\n                u.parentNode.removeChild(u);\n            };\n        },\n        empty: function(u) {\n            u = k(u);\n            while (u.firstChild) {\n                r.remove(u.firstChild);;\n            };\n        },\n        getID: function(u) {\n            var v = u.id;\n            if (!v) {\n                v = (p + q++);\n                u.id = v;\n            }\n        ;\n            return v;\n        }\n    });\n    function s(u, v, w) {\n        u = i.replaceJSONWrapper(u);\n        if ((((u instanceof i) && (\"\" === v.innerHTML)) && (-1 === u.toString().indexOf((\"\\u003Cscr\" + \"ipt\"))))) {\n            var x = j.ie();\n            if ((!x || (((x > 7) && !h.isNodeOfType(v, [\"table\",\"tbody\",\"thead\",\"tfoot\",\"tr\",\"select\",\"fieldset\",]))))) {\n                var y = (x ? \"\\u003Cem style=\\\"display:none;\\\"\\u003E&nbsp;\\u003C/em\\u003E\" : \"\");\n                v.innerHTML = (y + u);\n                (x && v.removeChild(v.firstChild));\n                return m(v.childNodes);\n            }\n        ;\n        }\n         else if (h.isTextNode(v)) {\n            v.data = u;\n            return [u,];\n        }\n        \n    ;\n        var z = document.createDocumentFragment(), aa, ba = [], ca = [];\n        if (!Array.isArray(u)) {\n            u = [u,];\n        };\n        for (var da = 0; (da < u.length); da++) {\n            aa = i.replaceJSONWrapper(u[da]);\n            if ((aa instanceof i)) {\n                ca.push(aa.getAction());\n                var ea = aa.getNodes();\n                for (var fa = 0; (fa < ea.length); fa++) {\n                    ba.push(ea[fa]);\n                    z.appendChild(ea[fa]);\n                };\n            }\n             else if (n(aa)) {\n                var ga = document.createTextNode(aa);\n                ba.push(ga);\n                z.appendChild(ga);\n            }\n             else if (h.isNode(aa)) {\n                ba.push(aa);\n                z.appendChild(aa);\n            }\n            \n            \n        ;\n        };\n        w(z);\n        ca.forEach(function(ha) {\n            ha();\n        });\n        return ba;\n    };\n    function t(u) {\n        function v(w) {\n            return r.create(\"div\", {\n            }, w).innerHTML;\n        };\n        return function(w, x) {\n            var y = {\n            };\n            if (x) {\n                for (var z in x) {\n                    y[z] = v(x[z]);;\n                }\n            };\n            return i(u(w, y));\n        };\n    };\n    r.tx = t(o);\n    r.tx._ = r._tx = t(o._);\n    e.exports = r;\n});\n__d(\"legacy:dom\", [\"DOM\",], function(a, b, c, d) {\n    a.DOM = b(\"DOM\");\n}, 3);\n__d(\"OnloadHooks\", [\"Arbiter\",\"ErrorUtils\",\"InitialJSLoader\",\"OnloadEvent\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ErrorUtils\"), i = b(\"InitialJSLoader\"), j = b(\"OnloadEvent\");\n    function k() {\n        var r = a.CavalryLogger;\n        if ((!window.loaded && r)) {\n            r.getInstance().setTimeStamp(\"t_prehooks\");\n        };\n        n(\"onloadhooks\");\n        if ((!window.loaded && r)) {\n            r.getInstance().setTimeStamp(\"t_hooks\");\n        };\n        window.loaded = true;\n        g.inform(\"uipage_onload\", true, g.BEHAVIOR_STATE);\n    };\n    function l() {\n        n(\"onafterloadhooks\");\n        window.afterloaded = true;\n    };\n    function m(r, s) {\n        return h.applyWithGuard(r, null, null, function(t) {\n            t.event_type = s;\n            t.category = \"runhook\";\n        });\n    };\n    function n(r) {\n        var s = (((r == \"onbeforeleavehooks\")) || ((r == \"onbeforeunloadhooks\")));\n        do {\n            var t = window[r];\n            if (!t) {\n                break;\n            };\n            if (!s) {\n                window[r] = null;\n            };\n            for (var u = 0; (u < t.length); u++) {\n                var v = m(t[u], r);\n                if ((s && v)) {\n                    return v\n                };\n            };\n        } while ((!s && window[r]));\n    };\n    function o() {\n        if (!window.loaded) {\n            window.loaded = true;\n            n(\"onloadhooks\");\n        }\n    ;\n        if (!window.afterloaded) {\n            window.afterloaded = true;\n            n(\"onafterloadhooks\");\n        }\n    ;\n    };\n    function p() {\n        g.registerCallback(k, [j.ONLOAD_DOMCONTENT_CALLBACK,i.INITIAL_JS_READY,]);\n        g.registerCallback(l, [j.ONLOAD_DOMCONTENT_CALLBACK,j.ONLOAD_CALLBACK,i.INITIAL_JS_READY,]);\n        g.subscribe(j.ONBEFOREUNLOAD, function(r, s) {\n            s.warn = (n(\"onbeforeleavehooks\") || n(\"onbeforeunloadhooks\"));\n            if (!s.warn) {\n                window.loaded = false;\n                window.afterloaded = false;\n            }\n        ;\n        }, g.SUBSCRIBE_NEW);\n        g.subscribe(j.ONUNLOAD, function(r, s) {\n            n(\"onunloadhooks\");\n        }, g.SUBSCRIBE_NEW);\n    };\n    var q = {\n        _onloadHook: k,\n        _onafterloadHook: l,\n        runHook: m,\n        runHooks: n,\n        keepWindowSetAsLoaded: o\n    };\n    p();\n    a.OnloadHooks = e.exports = q;\n});\n__d(\"legacy:onload-action\", [\"OnloadHooks\",], function(a, b, c, d) {\n    var e = b(\"OnloadHooks\");\n    a._onloadHook = e._onloadHook;\n    a._onafterloadHook = e._onafterloadHook;\n    a.runHook = e.runHook;\n    a.runHooks = e.runHooks;\n    a.keep_window_set_as_loaded = e.keepWindowSetAsLoaded;\n}, 3);\nfunction link_rel_preload() {\n    var a = /async(?:-post)?|dialog(?:-pipe|-post)?|theater|toggle/;\n    document.documentElement.onmousedown = function(b) {\n        b = (b || window.event);\n        var c = (b.target || b.srcElement), d = Parent.byTag(c, \"A\");\n        if (!d) {\n            return\n        };\n        var e = d.getAttribute(\"ajaxify\"), f = d.href, g = (e || f);\n        if (((e && f) && !(/#$/).test(f))) {\n            var h = (b.which && (b.which != 1)), i = (((b.altKey || b.ctrlKey) || b.metaKey) || b.shiftKey);\n            if ((h || i)) {\n                return\n            };\n        }\n    ;\n        var j = (d.rel && d.rel.match(a));\n        j = (j && j[0]);\n        switch (j) {\n          case \"dialog\":\n        \n          case \"dialog-post\":\n            Bootloader.loadComponents(\"dialog\");\n            break;\n          case \"dialog-pipe\":\n            Bootloader.loadComponents([\"ajaxpipe\",\"dialog\",]);\n            break;\n          case \"async\":\n        \n          case \"async-post\":\n            Bootloader.loadComponents(\"async\");\n            break;\n          case \"theater\":\n            Bootloader.loadComponents(\"PhotoSnowlift\", function() {\n                PhotoSnowlift.preload(g, d);\n            });\n            break;\n          case \"toggle\":\n            Bootloader.loadComponents(\"Toggler\");\n            break;\n        };\n        return;\n    };\n};\n__d(\"Style\", [\"DOMQuery\",\"ErrorUtils\",\"$\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOMQuery\"), h = b(\"ErrorUtils\"), i = b(\"$\");\n    function j(m) {\n        return m.replace(/([A-Z])/g, \"-$1\").toLowerCase();\n    };\n    function k(m, n) {\n        var o = l.get(m, n);\n        return (((o === \"auto\") || (o === \"scroll\")));\n    };\n    var l = {\n        set: function(m, n, o) {\n            switch (n) {\n              case \"opacity\":\n                m.style.opacity = o;\n                m.style.filter = ((o !== \"\") ? ((\"alpha(opacity=\" + (o * 100)) + \")\") : \"\");\n                break;\n              case \"float\":\n                m.style.cssFloat = m.style.styleFloat = o;\n                break;\n              case \"width\":\n            \n              case \"height\":\n                if ((parseInt(o, 10) < 0)) {\n                    h.applyWithGuard(function(q, r) {\n                        throw new Error(((((\"Style.set: \\\"\" + q) + \"\\\" argument is invalid: \\\"\") + r) + \"\\\"\"));\n                    }, l, [n,o,]);\n                };\n              default:\n                n = n.replace(/-(.)/g, function(q, r) {\n                    return r.toUpperCase();\n                });\n                try {\n                    m.style[n] = o;\n                } catch (p) {\n                    throw new Error(((((\"Style.set: \\\"\" + n) + \"\\\" argument is invalid: \\\"\") + o) + \"\\\"\"));\n                };\n            };\n            return m;\n        },\n        get: function(m, n) {\n            m = i(m);\n            n = n.replace(/-(.)/g, function(p, q) {\n                return q.toUpperCase();\n            });\n            var o;\n            if (window.getComputedStyle) {\n                o = window.getComputedStyle(m, null);\n                if (o) {\n                    return o.getPropertyValue(j(n))\n                };\n            }\n        ;\n            if ((document.defaultView && document.defaultView.getComputedStyle)) {\n                o = document.defaultView.getComputedStyle(m, null);\n                if (o) {\n                    return o.getPropertyValue(j(n))\n                };\n                if ((n == \"display\")) {\n                    return \"none\"\n                };\n            }\n        ;\n            if (m.currentStyle) {\n                return m.currentStyle[n]\n            };\n            return (m.style && m.style[n]);\n        },\n        getFloat: function(m, n) {\n            return parseFloat(l.get(m, n), 10);\n        },\n        getOpacity: function(m) {\n            m = i(m);\n            var n = l.get(m, \"filter\"), o = null;\n            if ((n && (o = /(\\d+(?:\\.\\d+)?)/.exec(n)))) {\n                return (parseFloat(o.pop()) / 100);\n            }\n             else if (n = l.get(m, \"opacity\")) {\n                return parseFloat(n);\n            }\n             else return 1\n            \n        ;\n        },\n        isFixed: function(m) {\n            while ((m && (m !== document.documentElement))) {\n                if ((l.get(m, \"position\") === \"fixed\")) {\n                    return true\n                };\n                m = m.parentNode;\n            };\n            return false;\n        },\n        getScrollParent: function(m) {\n            if (!m) {\n                return null\n            };\n            while ((m !== document.body)) {\n                if (((k(m, \"overflow\") || k(m, \"overflowY\")) || k(m, \"overflowX\"))) {\n                    return m\n                };\n                m = m.parentNode;\n            };\n            return window;\n        }\n    };\n    e.exports = l;\n});\n__d(\"legacy:animation\", [\"Animation\",], function(a, b, c, d) {\n    a.animation = b(\"Animation\");\n}, 3);\n__d(\"LiveTimer\", [\"CSS\",\"DOM\",\"UserAgent\",\"tx\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"UserAgent\"), j = b(\"tx\"), k = {\n        restart: function(l) {\n            this.serverTime = l;\n            this.localStartTime = (Date.now() / 1000);\n            this.updateTimeStamps();\n        },\n        getApproximateServerTime: function() {\n            return ((((this.serverTime - this.localStartTime)) * 1000) + Date.now());\n        },\n        updateTimeStamps: function() {\n            k.timestamps = h.scry(document.body, \"abbr.livetimestamp\");\n            k.startLoop(20000);\n        },\n        addTimeStamps: function(l) {\n            if (!l) {\n                return\n            };\n            k.timestamps = (k.timestamps || []);\n            if ((h.isNodeOfType(l, \"abbr\") && g.hasClass(l, \"livetimestamp\"))) {\n                k.timestamps.push(l);\n            }\n             else {\n                var m = h.scry(l, \"abbr.livetimestamp\");\n                for (var n = 0; (n < m.length); ++n) {\n                    k.timestamps.push(m[n]);;\n                };\n            }\n        ;\n            k.startLoop(0);\n        },\n        startLoop: function(l) {\n            this.stop();\n            this.timeout = setTimeout(function() {\n                k.loop();\n            }, l);\n        },\n        stop: function() {\n            clearTimeout(this.timeout);\n        },\n        updateNode: function(l, m) {\n            k.updateNode = (((i.ie() < 7)) ? bagofholding : h.setContent);\n            k.updateNode(l, m);\n        },\n        loop: function(l) {\n            if (l) {\n                k.updateTimeStamps();\n            };\n            var m = Math.floor((k.getApproximateServerTime() / 1000)), n = -1;\n            (k.timestamps && k.timestamps.forEach(function(p) {\n                var q = p.getAttribute(\"data-utime\"), r = k.renderRelativeTime(m, q);\n                if (r.text) {\n                    k.updateNode(p, r.text);\n                };\n                if (((r.next != -1) && (((r.next < n) || (n == -1))))) {\n                    n = r.next;\n                };\n            }));\n            if ((n != -1)) {\n                var o = Math.max(20000, (n * 1000));\n                k.timeout = setTimeout(function() {\n                    k.loop();\n                }, o);\n            }\n        ;\n        },\n        renderRelativeTime: function(l, m) {\n            var n = {\n                text: \"\",\n                next: -1\n            };\n            if ((((l - m) > ((12 * 3600))) || ((new Date((l * 1000)).getDay() != new Date((m * 1000)).getDay())))) {\n                return n\n            };\n            var o = (l - m), p = Math.floor((o / 60)), q = Math.floor((p / 60));\n            if ((p < 1)) {\n                n.text = \"a few seconds ago\";\n                n.next = (60 - (o \u0025 60));\n                return n;\n            }\n        ;\n            if ((q < 1)) {\n                if ((p == 1)) {\n                    n.text = \"about a minute ago\";\n                }\n                 else n.text = j._(\"{number} minutes ago\", {\n                    number: p\n                });\n            ;\n                n.next = (60 - (o \u0025 60));\n                return n;\n            }\n        ;\n            if ((q != 11)) {\n                n.next = (3600 - (o \u0025 3600));\n            };\n            if ((q == 1)) {\n                n.text = \"about an hour ago\";\n                return n;\n            }\n        ;\n            n.text = j._(\"{number} hours ago\", {\n                number: q\n            });\n            return n;\n        }\n    };\n    e.exports = k;\n});\n__d(\"legacy:live-timer\", [\"LiveTimer\",], function(a, b, c, d) {\n    a.LiveTimer = b(\"LiveTimer\");\n}, 3);\n__d(\"BanzaiCommon\", [\"BanzaiConfig\",], function(a, b, c, d, e, f) {\n    var g = c(\"BanzaiConfig\"), h = {\n        store: true,\n        delay: (g.MIN_WAIT || 1000)\n    }, i = {\n        store: false,\n        delay: (g.MAX_WAIT || 60000)\n    }, j, k, l, m, n;\n    function o() {\n        k = [];\n        l = [];\n    };\n    function p(v) {\n        var w = (Date.now() + v);\n        if ((!n || (w < n))) {\n            n = w;\n            clearTimeout(m);\n            m = setTimeout(r, v);\n        }\n    ;\n    };\n    function q(v, w, x) {\n        x = (x || i);\n        var y = [v,w,];\n        k.push(y);\n        if (x.store) {\n            l.push(y);\n        };\n        p((x.delay || 60000));\n    };\n    function r() {\n        n = null;\n        p(i.delay);\n        if (j.isSending()) {\n            return\n        };\n        j.inform(u.SEND);\n        if ((k.length <= 0)) {\n            j.inform(u.OK);\n            return;\n        }\n    ;\n        var v = k;\n        o();\n        j.send(v);\n    };\n    function s(v) {\n        j = v;\n        j.onUnload(function() {\n            j.inform(u.SHUTDOWN);\n            t.store();\n        });\n    };\n    var t = (a.sessionStorage ? {\n        store: function v() {\n            a.sessionStorage.setItem(\"Banzai\", JSON.stringify(k));\n        },\n        restore: function v() {\n            if ((\"Banzai\" in a.sessionStorage)) {\n                k = [].concat(JSON.parse(a.sessionStorage.getItem(\"Banzai\")));\n                l = [].concat(k);\n                a.sessionStorage.removeItem(\"Banzai\");\n            }\n        ;\n        }\n    } : {\n        store: function() {\n        \n        },\n        restore: function() {\n        \n        }\n    }), u = {\n        SEND: \"Banzai:SEND\",\n        OK: \"Banzai:OK\",\n        ERROR: \"Banzai:ERROR\",\n        SHUTDOWN: \"Banzai:SHUTDOWN\",\n        VITAL: h,\n        SEND_TIMEOUT: 15000,\n        isEnabled: function(v) {\n            return (g.gks && g.gks[v]);\n        },\n        post: q,\n        setAdapter: s,\n        subscribe: function(v, w) {\n            j.subscribe(v, w);\n        }\n    };\n    o();\n    t.restore();\n    p(i.delay);\n    e.exports = u;\n});\n__d(\"BanzaiDesktop\", [\"Arbiter\",\"BanzaiCommon\",\"QueryString\",\"Run\",\"XHR\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"BanzaiCommon\"), i = b(\"QueryString\"), j = b(\"Run\"), k = b(\"XHR\"), l = null, m = new g(), n = \"/ajax/banzai/banzai.php\", o = {\n        inform: function p(q) {\n            m.inform(q);\n        },\n        subscribe: function(p, q) {\n            m.subscribe(p, q);\n        },\n        cleanup: function p() {\n            if ((l && (l.readyState < 4))) {\n                l.abort();\n            };\n            if (l) {\n                l = l.onreadystatechange = null;\n            };\n        },\n        isSending: function p() {\n            return !!l;\n        },\n        send: function p(q) {\n            var r = \"POST\";\n            l = k.create();\n            l.open(r, n, true);\n            l.setRequestHeader(\"Content-Type\", \"application/x-www-form-urlencoded\");\n            l.onreadystatechange = function() {\n                if ((l.readyState >= 4)) {\n                    var t = l.status;\n                    o.cleanup();\n                    o.inform(((t == 200) ? h.OK : h.ERROR));\n                }\n            ;\n            };\n            setTimeout(o.cleanup, h.SEND_TIMEOUT, false);\n            var s = k.getAsyncParams(r);\n            s.q = JSON.stringify(q);\n            l.send(i.encode(s));\n        },\n        onUnload: function p(q) {\n            j.onUnload(q);\n        }\n    };\n    h.setAdapter(o);\n    e.exports = h;\n});\n__d(\"BehaviorsMixin\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\");\n    function h(l) {\n        this._behavior = l;\n        this._enabled = false;\n    };\n    g(h.prototype, {\n        enable: function() {\n            if (!this._enabled) {\n                this._enabled = true;\n                this._behavior.enable();\n            }\n        ;\n        },\n        disable: function() {\n            if (this._enabled) {\n                this._enabled = false;\n                this._behavior.disable();\n            }\n        ;\n        }\n    });\n    var i = 1;\n    function j(l) {\n        if (!l.__BEHAVIOR_ID) {\n            l.__BEHAVIOR_ID = i++;\n        };\n        return l.__BEHAVIOR_ID;\n    };\n    var k = {\n        enableBehavior: function(l) {\n            if (!this._behaviors) {\n                this._behaviors = {\n                };\n            };\n            var m = j(l);\n            if (!this._behaviors[m]) {\n                this._behaviors[m] = new h(new l(this));\n            };\n            this._behaviors[m].enable();\n            return this;\n        },\n        disableBehavior: function(l) {\n            if (this._behaviors) {\n                var m = j(l);\n                if (this._behaviors[m]) {\n                    this._behaviors[m].disable();\n                };\n            }\n        ;\n            return this;\n        },\n        enableBehaviors: function(l) {\n            l.forEach(this.enableBehavior.bind(this));\n            return this;\n        },\n        destroyBehaviors: function() {\n            if (this._behaviors) {\n                for (var l in this._behaviors) {\n                    this._behaviors[l].disable();;\n                };\n                this._behaviors = {\n                };\n            }\n        ;\n        }\n    };\n    e.exports = k;\n});\n__d(\"DOMDimensions\", [\"DOMQuery\",\"Style\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOMQuery\"), h = b(\"Style\"), i = {\n        getElementDimensions: function(j) {\n            return {\n                width: (j.offsetWidth || 0),\n                height: (j.offsetHeight || 0)\n            };\n        },\n        getViewportDimensions: function() {\n            var j = (((((window && window.innerWidth)) || (((document && document.documentElement) && document.documentElement.clientWidth))) || (((document && document.body) && document.body.clientWidth))) || 0), k = (((((window && window.innerHeight)) || (((document && document.documentElement) && document.documentElement.clientHeight))) || (((document && document.body) && document.body.clientHeight))) || 0);\n            return {\n                width: j,\n                height: k\n            };\n        },\n        getViewportWithoutScrollbarDimensions: function() {\n            var j = ((((((document && document.documentElement) && document.documentElement.clientWidth)) || ((window && window.innerWidth))) || (((document && document.body) && document.body.clientWidth))) || 0), k = ((((((document && document.documentElement) && document.documentElement.clientHeight)) || ((window && window.innerHeight))) || (((document && document.body) && document.body.clientHeight))) || 0);\n            return {\n                width: j,\n                height: k\n            };\n        },\n        getDocumentDimensions: function(j) {\n            j = (j || document);\n            var k = g.getDocumentScrollElement(j), l = (k.scrollWidth || 0), m = (k.scrollHeight || 0);\n            return {\n                width: l,\n                height: m\n            };\n        },\n        measureElementBox: function(j, k, l, m, n) {\n            var o;\n            switch (k) {\n              case \"left\":\n            \n              case \"right\":\n            \n              case \"top\":\n            \n              case \"bottom\":\n                o = [k,];\n                break;\n              case \"width\":\n                o = [\"left\",\"right\",];\n                break;\n              case \"height\":\n                o = [\"top\",\"bottom\",];\n                break;\n              default:\n                throw Error((\"Invalid plane: \" + k));\n            };\n            var p = function(q, r) {\n                var s = 0;\n                for (var t = 0; (t < o.length); t++) {\n                    s += (parseInt(h.get(j, (((q + \"-\") + o[t]) + r)), 10) || 0);;\n                };\n                return s;\n            };\n            return ((((l ? p(\"padding\", \"\") : 0)) + ((m ? p(\"border\", \"-width\") : 0))) + ((n ? p(\"margin\", \"\") : 0)));\n        }\n    };\n    e.exports = i;\n});\n__d(\"DOMEventListener\", [], function(a, b, c, d, e, f) {\n    var g, h;\n    if (window.addEventListener) {\n        g = function(j, k, l) {\n            j.addEventListener(k, l, false);\n        };\n        h = function(j, k, l) {\n            j.removeEventListener(k, l, false);\n        };\n    }\n     else if (window.attachEvent) {\n        g = function(j, k, l) {\n            j.attachEvent((\"on\" + k), l);\n        };\n        h = function(j, k, l) {\n            j.detachEvent((\"on\" + k), l);\n        };\n    }\n    \n;\n    var i = {\n        add: function(j, k, l) {\n            g(j, k, l);\n            return {\n                remove: function() {\n                    h(j, k, l);\n                    j = null;\n                }\n            };\n        },\n        remove: h\n    };\n    e.exports = i;\n});\n__d(\"DOMPosition\", [\"DOMQuery\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOMQuery\"), h = {\n        getScrollPosition: function() {\n            var i = g.getDocumentScrollElement();\n            return {\n                x: i.scrollLeft,\n                y: i.scrollTop\n            };\n        },\n        getElementPosition: function(i) {\n            if (!i) {\n                return\n            };\n            if (!((\"getBoundingClientRect\" in i))) {\n                return {\n                    x: 0,\n                    y: 0\n                }\n            };\n            var j = i.getBoundingClientRect(), k = document.documentElement, l = (Math.round(j.left) - k.clientLeft), m = (Math.round(j.top) - k.clientTop);\n            return {\n                x: l,\n                y: m\n            };\n        }\n    };\n    e.exports = h;\n});\n__d(\"DimensionTracking\", [\"event-extensions\",\"AsyncSignal\",\"Cookie\",\"DOMDimensions\",\"Run\",\"isInIframe\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"AsyncSignal\"), h = b(\"Cookie\"), i = b(\"DOMDimensions\"), j = b(\"Run\"), k = b(\"isInIframe\");\n    function l() {\n        var m = i.getViewportDimensions();\n        h.set(\"wd\", ((m.width + \"x\") + m.height));\n        if ((Math.random() < 39001)) {\n            new g(\"/ajax/dimension_context.php\", {\n                x: m.width,\n                y: m.height\n            }).send();\n        };\n    };\n    if (!k()) {\n        j.onAfterLoad(function() {\n            setTimeout(l, 100);\n            Event.listen(window, \"resize\", l);\n            Event.listen(window, \"focus\", l);\n        });\n    };\n});\n__d(\"PrivacyConst\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\"), h = {\n        FRIENDS_MINUS_ACQUAINTANCES: 127,\n        FACEBOOK_EMPLOYEES: 112,\n        CUSTOM: 111,\n        EVERYONE: 80,\n        NETWORKS_FRIENDS_OF_FRIENDS: 60,\n        NETWORKS_FRIENDS: 55,\n        FRIENDS_OF_FRIENDS: 50,\n        ALL_FRIENDS: 40,\n        SELF: 10,\n        NOBODY: 0\n    }, i = {\n        EVERYONE: 80,\n        NETWORKS_FRIENDS: 55,\n        FRIENDS_OF_FRIENDS: 50,\n        ALL_FRIENDS: 40,\n        SOME_FRIENDS: 30,\n        SELF: 10,\n        NO_FRIENDS: 0\n    }, j = {\n        BaseValue: h,\n        FriendsValue: i\n    };\n    e.exports = j;\n});\n__d(\"ScriptPathState\", [\"Arbiter\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h, i, j, k, l = 100, m = {\n        setIsUIPageletRequest: function(n) {\n            j = n;\n        },\n        setUserURISampleRate: function(n) {\n            k = n;\n        },\n        reset: function() {\n            h = null;\n            i = false;\n            j = false;\n        },\n        _shouldUpdateScriptPath: function() {\n            return ((i && !j));\n        },\n        _shouldSendURI: function() {\n            return ((Math.random() < k));\n        },\n        getParams: function() {\n            var n = {\n            };\n            if (m._shouldUpdateScriptPath()) {\n                if ((m._shouldSendURI() && (h !== null))) {\n                    n.user_uri = h.substring(0, l);\n                };\n            }\n             else n.no_script_path = 1;\n        ;\n            return n;\n        }\n    };\n    g.subscribe(\"pre_page_transition\", function(n, o) {\n        i = true;\n        h = o.to.getUnqualifiedURI().toString();\n    });\n    e.exports = a.ScriptPathState = m;\n});\n__d(\"highlight\", [\"Animation\",\"Style\",], function(a, b, c, d, e, f) {\n    var g = b(\"Animation\"), h = b(\"Style\");\n    function i(j, k, l) {\n        new g(j).from(\"background\", \"#fff9d7\").to(\"background\", (l || \"#fff\")).ease(g.ease.both).duration(2000).ondone(function() {\n            h.set(j, \"background\", \"\");\n            (k && k());\n        }).go();\n    };\n    e.exports = i;\n});\n__d(\"ScrollHighlight\", [\"DOMScroll\",\"highlight\",\"CSS\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOMScroll\"), h = b(\"highlight\"), i = b(\"CSS\"), j = {\n        actOn: function(k) {\n            g.scrollTo(k);\n            h(k, null, \"#EDEFF4\");\n            i.removeClass(k, \"highlightComment\");\n        }\n    };\n    e.exports = j;\n});\n__d(\"throttleAcrossTransitions\", [\"debounce\",], function(a, b, c, d, e, f) {\n    var g = b(\"debounce\");\n    function h(i, j, k) {\n        return g(i, j, k, true, true);\n    };\n    e.exports = h;\n});\n__d(\"UserActionHistory\", [\"Arbiter\",\"ClickRefUtils\",\"throttleAcrossTransitions\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ClickRefUtils\"), i = b(\"throttleAcrossTransitions\"), j = {\n        click: 1,\n        submit: 1\n    }, k = false, l = {\n        log: [],\n        len: 0\n    }, m = i(function() {\n        try {\n            k._ua_log = JSON.stringify(l);\n        } catch (p) {\n            k = false;\n        };\n    }, 1000);\n    function n() {\n        try {\n            if (a.sessionStorage) {\n                k = a.sessionStorage;\n                (k._ua_log && (l = JSON.parse(k._ua_log)));\n            }\n        ;\n        } catch (p) {\n            k = false;\n        };\n        l.log[(l.len \u0025 10)] = {\n            ts: Date.now(),\n            path: \"-\",\n            index: l.len,\n            type: \"init\",\n            iref: \"-\"\n        };\n        l.len++;\n        g.subscribe(\"UserAction/new\", function(q, r) {\n            var s = r.ua, t = r.node, event = r.event;\n            if ((!event || !((event.type in j)))) {\n                return\n            };\n            var u = {\n                path: window._script_path,\n                type: event.type,\n                ts: s._ue_ts,\n                iref: (h.get_intern_ref(t) || \"-\"),\n                index: l.len\n            };\n            l.log[(l.len++ \u0025 10)] = u;\n            (k && m());\n        });\n    };\n    function o() {\n        return l.log.sort(function(p, q) {\n            return (((q.ts != p.ts)) ? ((q.ts - p.ts)) : ((q.index - p.index)));\n        });\n    };\n    n();\n    e.exports = {\n        getHistory: o\n    };\n});\n__d(\"UserActivity\", [\"event-extensions\",\"Arbiter\",\"ClickRefUtils\",\"collectDataAttributes\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ClickRefUtils\"), i = b(\"collectDataAttributes\"), j = 5000, k = 500, l = Date.now(), m = l, n = {\n        subscribeOnce: function(p) {\n            var q = n.subscribe(function() {\n                n.unsubscribe(q);\n                p();\n            });\n        },\n        subscribe: function(p) {\n            return g.subscribe(\"useractivity/activity\", p);\n        },\n        unsubscribe: function(p) {\n            p.unsubscribe();\n        },\n        isActive: function(p) {\n            return (((new Date() - l) < ((p || n.DEFAULT_IDLE_MS))));\n        },\n        getLastInformTime: function() {\n            return m;\n        }\n    };\n    function o(event) {\n        l = Date.now();\n        var p = (l - m);\n        if ((p > k)) {\n            m = l;\n            g.inform(\"useractivity/activity\", {\n                event: event,\n                idleness: p\n            });\n        }\n    ;\n    };\n    Event.listen(window, \"scroll\", o);\n    Event.listen(document.documentElement, {\n        DOMMouseScroll: o,\n        mousewheel: o,\n        keydown: o,\n        mouseover: o,\n        click: o\n    });\n    e.exports = n;\n});\n__d(\"bind\", [], function(a, b, c, d, e, f) {\n    function g(h, i) {\n        var j = Array.prototype.slice.call(arguments, 2);\n        if ((typeof i != \"string\")) {\n            return Function.prototype.bind.apply(i, [h,].concat(j))\n        };\n        function k() {\n            var l = j.concat(Array.prototype.slice.call(arguments));\n            if (h[i]) {\n                return h[i].apply(h, l)\n            };\n        };\n        k.toString = function() {\n            return (\"bound lazily: \" + h[i]);\n        };\n        return k;\n    };\n    e.exports = g;\n});\n__d(\"coalesce\", [], function(a, b, c, d, e, f) {\n    function g() {\n        for (var h = 0; (h < arguments.length); ++h) {\n            if ((arguments[h] != null)) {\n                return arguments[h]\n            };\n        };\n        return null;\n    };\n    e.exports = g;\n});\n__d(\"endsWith\", [], function(a, b, c, d, e, f) {\n    function g(h, i) {\n        return (h.indexOf(i, (h.length - i.length)) > -1);\n    };\n    e.exports = g;\n});\n__d(\"curry\", [\"bind\",], function(a, b, c, d, e, f) {\n    var g = b(\"bind\"), h = g(null, g, null);\n    e.exports = h;\n});\n__d(\"reportData\", [\"EagleEye\",\"userAction\",], function(a, b, c, d, e, f) {\n    var g = b(\"EagleEye\"), h = b(\"userAction\");\n    function i(j, k) {\n        k = (k || {\n        });\n        var l = {\n            ft: ((k.ft || {\n            })),\n            gt: ((k.gt || {\n            }))\n        }, m = \"-\", n = a.ArbiterMonitor, o = ((!!n) ? n.getActFields() : []), p = ((!n) ? \"r\" : \"a\"), q = [Date.now(),h.getCurrentUECount(),m,j,m,m,p,(a.URI ? a.URI.getRequestURI(true, true).getUnqualifiedURI().toString() : ((location.pathname + location.search) + location.hash)),l,0,0,0,0,].concat(o);\n        g.log(\"act\", q);\n    };\n    e.exports = i;\n});");
// 2567
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"sec3f7c0a188503295a66a797eaa3892a5e54bc0e");
// 2568
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"8gPM0\",]);\n}\n;\n;\n__d(\"Cookie\", [\"Env\",], function(a, b, c, d, e, f) {\n    var g = b(\"Env\"), h = {\n        set: function(i, j, k, l, m) {\n            if (((g.no_cookies && ((i != \"tpa\"))))) {\n                return;\n            }\n        ;\n        ;\n            JSBNG__document.cookie = ((((((((((((((((((i + \"=\")) + encodeURIComponent(j))) + \"; \")) + ((k ? ((((\"expires=\" + (new JSBNG__Date(((JSBNG__Date.now() + k)))).toGMTString())) + \"; \")) : \"\")))) + \"path=\")) + ((l || \"/\")))) + \"; domain=\")) + window.JSBNG__location.hostname.replace(/^.*(\\.facebook\\..*)$/i, \"$1\"))) + ((m ? \"; secure\" : \"\"))));\n        },\n        clear: function(i, j) {\n            j = ((j || \"/\"));\n            JSBNG__document.cookie = ((((((((((i + \"=; expires=Thu, 01-Jan-1970 00:00:01 GMT; \")) + \"path=\")) + j)) + \"; domain=\")) + window.JSBNG__location.hostname.replace(/^.*(\\.facebook\\..*)$/i, \"$1\")));\n        },\n        get: function(i) {\n            var j = JSBNG__document.cookie.match(((((\"(?:^|;\\\\s*)\" + i)) + \"=(.*?)(?:;|$)\")));\n            return ((j ? decodeURIComponent(j[1]) : j));\n        }\n    };\n    e.exports = h;\n});\n__d(\"legacy:cookie\", [\"Cookie\",], function(a, b, c, d) {\n    var e = b(\"Cookie\");\n    a.getCookie = e.get;\n    a.setCookie = e.set;\n    a.clearCookie = e.clear;\n}, 3);\n__d(\"QueryString\", [], function(a, b, c, d, e, f) {\n    var g = {\n        encode: function(h) {\n            var i = [];\n            Object.keys(h).forEach(function(j) {\n                var k = h[j];\n                if (((typeof k === \"undefined\"))) {\n                    return;\n                }\n            ;\n            ;\n                if (((k === null))) {\n                    i.push(j);\n                    return;\n                }\n            ;\n            ;\n                i.push(((((encodeURIComponent(j) + \"=\")) + encodeURIComponent(k))));\n            });\n            return i.join(\"&\");\n        },\n        decode: function(h) {\n            var i = {\n            };\n            if (((h === \"\"))) {\n                return i;\n            }\n        ;\n        ;\n            var j = h.split(\"&\"), k = j.length;\n            while (k--) {\n                var l = j[k].split(\"=\", 2);\n                i[decodeURIComponent(l[0])] = ((((l.length === 2)) ? decodeURIComponent(l[1]) : null));\n            };\n        ;\n            return i;\n        },\n        appendToUrl: function(h, i) {\n            return ((((h + ((~h.indexOf(\"?\") ? \"&\" : \"?\")))) + ((((typeof i === \"string\")) ? i : g.encode(i)))));\n        }\n    };\n    e.exports = g;\n});\n__d(\"URI\", [\"copyProperties\",\"goURI\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\"), h = b(\"goURI\");\n    function i(j) {\n        if (!((this instanceof i))) {\n            return new i(((j || window.JSBNG__location.href)));\n        }\n    ;\n    ;\n        this.parse(((j || \"\")));\n    };\n;\n    g(i, {\n        getRequestURI: function(j, k) {\n            j = ((((j === undefined)) || j));\n            var l = a.PageTransitions;\n            if (((((j && l)) && l.isInitialized()))) {\n                return l.getCurrentURI(!!k).getQualifiedURI();\n            }\n             else return new i(window.JSBNG__location.href)\n        ;\n        },\n        getMostRecentURI: function() {\n            var j = a.PageTransitions;\n            if (((j && j.isInitialized()))) {\n                return j.getMostRecentURI().getQualifiedURI();\n            }\n             else return new i(window.JSBNG__location.href)\n        ;\n        },\n        getNextURI: function() {\n            var j = a.PageTransitions;\n            if (((j && j.isInitialized()))) {\n                return j.getNextURI().getQualifiedURI();\n            }\n             else return new i(window.JSBNG__location.href)\n        ;\n        },\n        expression: /(((\\w+):\\/\\/)([^\\/:]*)(:(\\d+))?)?([^#?]*)(\\?([^#]*))?(#(.*))?/,\n        arrayQueryExpression: /^(\\w+)((?:\\[\\w*\\])+)=?(.*)/,\n        explodeQuery: function(j) {\n            if (!j) {\n                return {\n                };\n            }\n        ;\n        ;\n            var k = {\n            };\n            j = j.replace(/%5B/gi, \"[\").replace(/%5D/gi, \"]\");\n            j = j.split(\"&\");\n            var l = Object.prototype.hasOwnProperty;\n            for (var m = 0, n = j.length; ((m < n)); m++) {\n                var o = j[m].match(i.arrayQueryExpression);\n                if (!o) {\n                    var p = j[m].split(\"=\");\n                    k[i.decodeComponent(p[0])] = ((((p[1] === undefined)) ? null : i.decodeComponent(p[1])));\n                }\n                 else {\n                    var q = o[2].split(/\\]\\[|\\[|\\]/).slice(0, -1), r = o[1], s = i.decodeComponent(((o[3] || \"\")));\n                    q[0] = r;\n                    var t = k;\n                    for (var u = 0; ((u < ((q.length - 1)))); u++) {\n                        if (q[u]) {\n                            if (!l.call(t, q[u])) {\n                                var v = ((((q[((u + 1))] && !q[((u + 1))].match(/^\\d+$/))) ? {\n                                } : []));\n                                t[q[u]] = v;\n                                if (((t[q[u]] !== v))) {\n                                    return k;\n                                }\n                            ;\n                            ;\n                            }\n                        ;\n                        ;\n                            t = t[q[u]];\n                        }\n                         else {\n                            if (((q[((u + 1))] && !q[((u + 1))].match(/^\\d+$/)))) {\n                                t.push({\n                                });\n                            }\n                             else t.push([]);\n                        ;\n                        ;\n                            t = t[((t.length - 1))];\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    if (((((t instanceof Array)) && ((q[((q.length - 1))] === \"\"))))) {\n                        t.push(s);\n                    }\n                     else t[q[((q.length - 1))]] = s;\n                ;\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            return k;\n        },\n        implodeQuery: function(j, k, l) {\n            k = ((k || \"\"));\n            if (((l === undefined))) {\n                l = true;\n            }\n        ;\n        ;\n            var m = [];\n            if (((((j === null)) || ((j === undefined))))) {\n                m.push(((l ? i.encodeComponent(k) : k)));\n            }\n             else if (((j instanceof Array))) {\n                for (var n = 0; ((n < j.length)); ++n) {\n                    try {\n                        if (((j[n] !== undefined))) {\n                            m.push(i.implodeQuery(j[n], ((k ? ((((((k + \"[\")) + n)) + \"]\")) : n)), l));\n                        }\n                    ;\n                    ;\n                    } catch (o) {\n                    \n                    };\n                ;\n                };\n            ;\n            }\n             else if (((typeof (j) == \"object\"))) {\n                if (((((\"nodeName\" in j)) && ((\"nodeType\" in j))))) {\n                    m.push(\"{node}\");\n                }\n                 else for (var p in j) {\n                    try {\n                        if (((j[p] !== undefined))) {\n                            m.push(i.implodeQuery(j[p], ((k ? ((((((k + \"[\")) + p)) + \"]\")) : p)), l));\n                        }\n                    ;\n                    ;\n                    } catch (o) {\n                    \n                    };\n                ;\n                }\n            ;\n            ;\n            }\n             else if (l) {\n                m.push(((((i.encodeComponent(k) + \"=\")) + i.encodeComponent(j))));\n            }\n             else m.push(((((k + \"=\")) + j)));\n            \n            \n            \n        ;\n        ;\n            return m.join(\"&\");\n        },\n        encodeComponent: function(j) {\n            return encodeURIComponent(j).replace(/%5D/g, \"]\").replace(/%5B/g, \"[\");\n        },\n        decodeComponent: function(j) {\n            return decodeURIComponent(j.replace(/\\+/g, \" \"));\n        },\n        INVALID_DOMAIN: \"invalid.invalid\",\n        sanitizeDomain: function(j) {\n            var k = new RegExp(((((\"[\\\\x00-\\\\x2c\\\\x2f\\\\x3b-\\\\x40\\\\x5c\\\\x5e\\\\x60\\\\x7b-\\\\x7f\" + \"\\\\uFDD0-\\\\uFDEF\\\\uFFF0-\\\\uFFFF\")) + \"\\\\u2047\\\\u2048\\\\uFE56\\\\uFE5F\\\\uFF03\\\\uFF0F\\\\uFF1F]\")));\n            if (k.test(j)) {\n                return i.INVALID_DOMAIN;\n            }\n             else return j\n        ;\n        }\n    });\n    g(i.prototype, {\n        parse: function(j) {\n            var k = j.toString().match(i.expression);\n            g(this, {\n                protocol: ((k[3] || \"\")),\n                domain: i.sanitizeDomain(((k[4] || \"\"))),\n                port: ((k[6] || \"\")),\n                path: ((k[7] || \"\")),\n                query_s: ((k[9] || \"\")),\n                fragment: ((k[11] || \"\"))\n            });\n            return this;\n        },\n        setProtocol: function(j) {\n            this.protocol = j;\n            return this;\n        },\n        getProtocol: function() {\n            return this.protocol;\n        },\n        setQueryData: function(j) {\n            this.query_s = i.implodeQuery(j);\n            return this;\n        },\n        addQueryData: function(j) {\n            return this.setQueryData(g(this.getQueryData(), j));\n        },\n        removeQueryData: function(j) {\n            if (!Array.isArray(j)) {\n                j = [j,];\n            }\n        ;\n        ;\n            var k = this.getQueryData();\n            for (var l = 0, m = j.length; ((l < m)); ++l) {\n                delete k[j[l]];\n            ;\n            };\n        ;\n            return this.setQueryData(k);\n        },\n        getQueryData: function() {\n            return i.explodeQuery(this.query_s);\n        },\n        setFragment: function(j) {\n            this.fragment = j;\n            return this;\n        },\n        getFragment: function() {\n            return this.fragment;\n        },\n        setDomain: function(j) {\n            this.domain = i.sanitizeDomain(j);\n            return this;\n        },\n        getDomain: function() {\n            return this.domain;\n        },\n        setPort: function(j) {\n            this.port = j;\n            return this;\n        },\n        getPort: function() {\n            return this.port;\n        },\n        setPath: function(j) {\n            this.path = j;\n            return this;\n        },\n        getPath: function() {\n            return this.path.replace(/^\\/+/, \"/\");\n        },\n        isEmpty: function() {\n            return !((((((((((this.path || this.protocol)) || this.domain)) || this.port)) || this.query_s)) || this.fragment));\n        },\n        toString: function() {\n            var j = \"\";\n            ((this.protocol && (j += ((this.protocol + \"://\")))));\n            ((this.domain && (j += this.domain)));\n            ((this.port && (j += ((\":\" + this.port)))));\n            if (((this.domain && !this.path))) {\n                j += \"/\";\n            }\n        ;\n        ;\n            ((this.path && (j += this.path)));\n            ((this.query_s && (j += ((\"?\" + this.query_s)))));\n            ((this.fragment && (j += ((\"#\" + this.fragment)))));\n            return j;\n        },\n        valueOf: function() {\n            return this.toString();\n        },\n        isFacebookURI: function() {\n            if (!i._facebookURIRegex) {\n                i._facebookURIRegex = new RegExp(\"(^|\\\\.)facebook\\\\.com([^.]*)$\", \"i\");\n            }\n        ;\n        ;\n            return ((!this.domain || i._facebookURIRegex.test(this.domain)));\n        },\n        isQuicklingEnabled: function() {\n            var j = a.Quickling;\n            return ((((j && j.isActive())) && j.isPageActive(this)));\n        },\n        getRegisteredDomain: function() {\n            if (!this.domain) {\n                return \"\";\n            }\n        ;\n        ;\n            if (!this.isFacebookURI()) {\n                return null;\n            }\n        ;\n        ;\n            var j = this.domain.split(\".\"), k = j.indexOf(\"facebook\");\n            return j.slice(k).join(\".\");\n        },\n        getUnqualifiedURI: function() {\n            return new i(this).setProtocol(null).setDomain(null).setPort(null);\n        },\n        getQualifiedURI: function() {\n            var j = new i(this);\n            if (!j.getDomain()) {\n                var k = i();\n                j.setProtocol(k.getProtocol()).setDomain(k.getDomain()).setPort(k.getPort());\n            }\n        ;\n        ;\n            return j;\n        },\n        isSameOrigin: function(j) {\n            var k = ((j || window.JSBNG__location.href));\n            if (!((k instanceof i))) {\n                k = new i(k.toString());\n            }\n        ;\n        ;\n            if (((this.getProtocol() && ((this.getProtocol() != k.getProtocol()))))) {\n                return false;\n            }\n        ;\n        ;\n            if (((this.getDomain() && ((this.getDomain() != k.getDomain()))))) {\n                return false;\n            }\n        ;\n        ;\n            if (((this.getPort() && ((this.getPort() != k.getPort()))))) {\n                return false;\n            }\n        ;\n        ;\n            return true;\n        },\n        go: function(j) {\n            h(this, j);\n        },\n        setSubdomain: function(j) {\n            var k = new i(this).getQualifiedURI(), l = k.getDomain().split(\".\");\n            if (((l.length <= 2))) {\n                l.unshift(j);\n            }\n             else l[0] = j;\n        ;\n        ;\n            return k.setDomain(l.join(\".\"));\n        },\n        getSubdomain: function() {\n            if (!this.getDomain()) {\n                return \"\";\n            }\n        ;\n        ;\n            var j = this.getDomain().split(\".\");\n            if (((j.length <= 2))) {\n                return \"\";\n            }\n             else return j[0]\n        ;\n        },\n        setSecure: function(j) {\n            return this.setProtocol(((j ? \"https\" : \"http\")));\n        },\n        isSecure: function() {\n            return ((this.getProtocol() == \"https\"));\n        }\n    });\n    e.exports = i;\n});\n__d(\"XHR\", [\"Env\",], function(a, b, c, d, e, f) {\n    var g = b(\"Env\"), h = {\n        create: function() {\n            try {\n                return ((a.JSBNG__XMLHttpRequest ? new a.JSBNG__XMLHttpRequest() : new ActiveXObject(\"MSXML2.XMLHTTP.3.0\")));\n            } catch (i) {\n            \n            };\n        ;\n        },\n        getAsyncParams: function(i) {\n            var j = {\n                __user: g.user,\n                __a: 1\n            };\n            if (((((i == \"POST\")) && g.fb_dtsg))) {\n                j.fb_dtsg = g.fb_dtsg;\n            }\n        ;\n        ;\n            if (g.fb_isb) {\n                j.fb_isb = g.fb_isb;\n            }\n        ;\n        ;\n            return j;\n        }\n    };\n    e.exports = h;\n});\n__d(\"AsyncSignal\", [\"Env\",\"ErrorUtils\",\"QueryString\",\"URI\",\"XHR\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Env\"), h = b(\"ErrorUtils\"), i = b(\"QueryString\"), j = b(\"URI\"), k = b(\"XHR\"), l = b(\"copyProperties\");\n    function m(n, o) {\n        this.data = ((o || {\n        }));\n        if (((g.tracking_domain && ((n.charAt(0) == \"/\"))))) {\n            n = ((g.tracking_domain + n));\n        }\n    ;\n    ;\n        this.uri = n;\n    };\n;\n    m.prototype.setHandler = function(n) {\n        this.handler = n;\n        return this;\n    };\n    m.prototype.send = function() {\n        var n = this.handler, o = this.data, p = new JSBNG__Image();\n        if (n) {\n            p.JSBNG__onload = p.JSBNG__onerror = function() {\n                h.applyWithGuard(n, null, [((p.height == 1)),]);\n            };\n        }\n    ;\n    ;\n        o.asyncSignal = ((((((Math.JSBNG__random() * 10000)) | 0)) + 1));\n        var q = new j(this.uri).isFacebookURI();\n        l(o, k.getAsyncParams(((q ? \"POST\" : \"GET\"))));\n        p.src = i.appendToUrl(this.uri, o);\n        return this;\n    };\n    e.exports = m;\n});\n__d(\"legacy:async-signal\", [\"AsyncSignal\",], function(a, b, c, d) {\n    a.AsyncSignal = b(\"AsyncSignal\");\n}, 3);\n__d(\"legacy:uri\", [\"URI\",], function(a, b, c, d) {\n    a.URI = b(\"URI\");\n}, 3);\nfunction detect_broken_proxy_cache(a, b) {\n    var c = getCookie(b);\n    if (((((((c != a)) && ((c != null)))) && ((a != \"0\"))))) {\n        var d = {\n            c: \"si_detect_broken_proxy_cache\",\n            m: ((((((((b + \" \")) + a)) + \" \")) + c))\n        }, e = new URI(\"/common/scribe_endpoint.php\").getQualifiedURI().toString();\n        new AsyncSignal(e, d).send();\n    }\n;\n;\n};\n;\n__d(\"LinkshimAsyncLink\", [\"$\",\"AsyncSignal\",], function(a, b, c, d, e, f) {\n    var g = b(\"$\"), h = b(\"AsyncSignal\"), i = {\n        swap: function(j, k) {\n            j.href = k;\n        },\n        referrer_log: function(j, k, l) {\n            var m = g(\"meta_referrer\");\n            m.JSBNG__content = \"origin\";\n            i.swap(j, k);\n            (function() {\n                m.JSBNG__content = \"default\";\n                new h(l, {\n                }).send();\n            }).defer(100);\n        }\n    };\n    e.exports = i;\n});\n__d(\"legacy:dom-asynclinkshim\", [\"LinkshimAsyncLink\",], function(a, b, c, d) {\n    a.LinkshimAsyncLink = b(\"LinkshimAsyncLink\");\n}, 3);\n__d(\"UserAgent\", [], function(a, b, c, d, e, f) {\n    var g = false, h, i, j, k, l, m, n, o, p, q, r, s, t, u;\n    function v() {\n        if (g) {\n            return;\n        }\n    ;\n    ;\n        g = true;\n        var x = JSBNG__navigator.userAgent, y = /(?:MSIE.(\\d+\\.\\d+))|(?:(?:Firefox|GranParadiso|Iceweasel).(\\d+\\.\\d+))|(?:Opera(?:.+Version.|.)(\\d+\\.\\d+))|(?:AppleWebKit.(\\d+(?:\\.\\d+)?))/.exec(x), z = /(Mac OS X)|(Windows)|(Linux)/.exec(x);\n        r = /\\b(iPhone|iP[ao]d)/.exec(x);\n        s = /\\b(iP[ao]d)/.exec(x);\n        p = /Android/i.exec(x);\n        t = /FBAN\\/\\w+;/i.exec(x);\n        u = /Mobile/i.exec(x);\n        q = !!(/Win64/.exec(x));\n        if (y) {\n            h = ((y[1] ? parseFloat(y[1]) : NaN));\n            if (((h && JSBNG__document.documentMode))) {\n                h = JSBNG__document.documentMode;\n            }\n        ;\n        ;\n            i = ((y[2] ? parseFloat(y[2]) : NaN));\n            j = ((y[3] ? parseFloat(y[3]) : NaN));\n            k = ((y[4] ? parseFloat(y[4]) : NaN));\n            if (k) {\n                y = /(?:Chrome\\/(\\d+\\.\\d+))/.exec(x);\n                l = ((((y && y[1])) ? parseFloat(y[1]) : NaN));\n            }\n             else l = NaN;\n        ;\n        ;\n        }\n         else h = i = j = l = k = NaN;\n    ;\n    ;\n        if (z) {\n            if (z[1]) {\n                var aa = /(?:Mac OS X (\\d+(?:[._]\\d+)?))/.exec(x);\n                m = ((aa ? parseFloat(aa[1].replace(\"_\", \".\")) : true));\n            }\n             else m = false;\n        ;\n        ;\n            n = !!z[2];\n            o = !!z[3];\n        }\n         else m = n = o = false;\n    ;\n    ;\n    };\n;\n    var w = {\n        ie: function() {\n            return ((v() || h));\n        },\n        ie64: function() {\n            return ((w.ie() && q));\n        },\n        firefox: function() {\n            return ((v() || i));\n        },\n        JSBNG__opera: function() {\n            return ((v() || j));\n        },\n        safari: function() {\n            return ((v() || k));\n        },\n        JSBNG__chrome: function() {\n            return ((v() || l));\n        },\n        windows: function() {\n            return ((v() || n));\n        },\n        osx: function() {\n            return ((v() || m));\n        },\n        linux: function() {\n            return ((v() || o));\n        },\n        iphone: function() {\n            return ((v() || r));\n        },\n        mobile: function() {\n            return ((v() || ((((((r || s)) || p)) || u))));\n        },\n        nativeApp: function() {\n            return ((v() || t));\n        },\n        android: function() {\n            return ((v() || p));\n        },\n        ipad: function() {\n            return ((v() || s));\n        }\n    };\n    e.exports = w;\n});\n__d(\"createObjectFrom\", [\"hasArrayNature\",], function(a, b, c, d, e, f) {\n    var g = b(\"hasArrayNature\");\n    function h(i, j) {\n        var k = {\n        }, l = g(j);\n        if (((typeof j == \"undefined\"))) {\n            j = true;\n        }\n    ;\n    ;\n        for (var m = i.length; m--; ) {\n            k[i[m]] = ((l ? j[m] : j));\n        ;\n        };\n    ;\n        return k;\n    };\n;\n    e.exports = h;\n});\n__d(\"DOMQuery\", [\"CSS\",\"UserAgent\",\"createArrayFrom\",\"createObjectFrom\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"UserAgent\"), i = b(\"createArrayFrom\"), j = b(\"createObjectFrom\"), k = b(\"ge\"), l = null, m = {\n        JSBNG__find: function(n, o) {\n            var p = m.scry(n, o);\n            return p[0];\n        },\n        scry: function(n, o) {\n            if (((!n || !n.getElementsByTagName))) {\n                return [];\n            }\n        ;\n        ;\n            var p = o.split(\" \"), q = [n,];\n            for (var r = 0; ((r < p.length)); r++) {\n                if (((q.length === 0))) {\n                    break;\n                }\n            ;\n            ;\n                if (((p[r] === \"\"))) {\n                    continue;\n                }\n            ;\n            ;\n                var s = p[r], t = p[r], u = [], v = false;\n                if (((s.charAt(0) == \"^\"))) {\n                    if (((r === 0))) {\n                        v = true;\n                        s = s.slice(1);\n                    }\n                     else return []\n                ;\n                }\n            ;\n            ;\n                s = s.replace(/\\./g, \" .\");\n                s = s.replace(/\\#/g, \" #\");\n                s = s.replace(/\\[/g, \" [\");\n                var w = s.split(\" \"), x = ((w[0] || \"*\")), y = ((x == \"*\")), z = ((w[1] && ((w[1].charAt(0) == \"#\"))));\n                if (z) {\n                    var aa = k(w[1].slice(1), true);\n                    if (((aa && ((y || ((aa.tagName.toLowerCase() == x))))))) {\n                        for (var ba = 0; ((ba < q.length)); ba++) {\n                            if (((v && m.contains(aa, q[ba])))) {\n                                u = [aa,];\n                                break;\n                            }\n                             else if (((((JSBNG__document == q[ba])) || m.contains(q[ba], aa)))) {\n                                u = [aa,];\n                                break;\n                            }\n                            \n                        ;\n                        ;\n                        };\n                    }\n                ;\n                ;\n                }\n                 else {\n                    var ca = [], da = q.length, ea, fa = ((((!v && ((t.indexOf(\"[\") < 0)))) && JSBNG__document.querySelectorAll));\n                    for (var ga = 0; ((ga < da)); ga++) {\n                        if (v) {\n                            ea = [];\n                            var ha = q[ga].parentNode;\n                            while (m.isElementNode(ha)) {\n                                if (((y || ((ha.tagName.toLowerCase() == x))))) {\n                                    ea.push(ha);\n                                }\n                            ;\n                            ;\n                                ha = ha.parentNode;\n                            };\n                        ;\n                        }\n                         else if (fa) {\n                            ea = q[ga].querySelectorAll(t);\n                        }\n                         else ea = q[ga].getElementsByTagName(x);\n                        \n                    ;\n                    ;\n                        var ia = ea.length;\n                        for (var ja = 0; ((ja < ia)); ja++) {\n                            ca.push(ea[ja]);\n                        ;\n                        };\n                    ;\n                    };\n                ;\n                    if (!fa) {\n                        for (var ka = 1; ((ka < w.length)); ka++) {\n                            var la = w[ka], ma = ((la.charAt(0) == \".\")), na = la.substring(1);\n                            for (ga = 0; ((ga < ca.length)); ga++) {\n                                var oa = ca[ga];\n                                if (!oa) {\n                                    continue;\n                                }\n                            ;\n                            ;\n                                if (ma) {\n                                    if (!g.hasClass(oa, na)) {\n                                        delete ca[ga];\n                                    }\n                                ;\n                                ;\n                                    continue;\n                                }\n                                 else {\n                                    var pa = la.slice(1, ((la.length - 1)));\n                                    if (((pa.indexOf(\"=\") == -1))) {\n                                        if (((oa.getAttribute(pa) === null))) {\n                                            delete ca[ga];\n                                            continue;\n                                        }\n                                    ;\n                                    ;\n                                    }\n                                     else {\n                                        var qa = pa.split(\"=\"), ra = qa[0], sa = qa[1];\n                                        sa = sa.slice(1, ((sa.length - 1)));\n                                        if (((oa.getAttribute(ra) != sa))) {\n                                            delete ca[ga];\n                                            continue;\n                                        }\n                                    ;\n                                    ;\n                                    }\n                                ;\n                                ;\n                                }\n                            ;\n                            ;\n                            };\n                        ;\n                        };\n                    }\n                ;\n                ;\n                    for (ga = 0; ((ga < ca.length)); ga++) {\n                        if (ca[ga]) {\n                            u.push(ca[ga]);\n                            if (v) {\n                                break;\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n                q = u;\n            };\n        ;\n            return q;\n        },\n        getText: function(n) {\n            if (m.isTextNode(n)) {\n                return n.data;\n            }\n             else if (m.isElementNode(n)) {\n                if (((l === null))) {\n                    var o = JSBNG__document.createElement(\"div\");\n                    l = ((((o.textContent != null)) ? \"textContent\" : \"innerText\"));\n                }\n            ;\n            ;\n                return n[l];\n            }\n             else return \"\"\n            \n        ;\n        },\n        JSBNG__getSelection: function() {\n            var n = window.JSBNG__getSelection, o = JSBNG__document.selection;\n            if (n) {\n                return ((n() + \"\"));\n            }\n             else if (o) {\n                return o.createRange().text;\n            }\n            \n        ;\n        ;\n            return null;\n        },\n        contains: function(n, o) {\n            n = k(n);\n            o = k(o);\n            if (((!n || !o))) {\n                return false;\n            }\n             else if (((n === o))) {\n                return true;\n            }\n             else if (m.isTextNode(n)) {\n                return false;\n            }\n             else if (m.isTextNode(o)) {\n                return m.contains(n, o.parentNode);\n            }\n             else if (n.contains) {\n                return n.contains(o);\n            }\n             else if (n.compareDocumentPosition) {\n                return !!((n.compareDocumentPosition(o) & 16));\n            }\n             else return false\n            \n            \n            \n            \n            \n        ;\n        },\n        getRootElement: function() {\n            var n = null;\n            if (((window.Quickling && Quickling.isActive()))) {\n                n = k(\"JSBNG__content\");\n            }\n        ;\n        ;\n            return ((n || JSBNG__document.body));\n        },\n        isNode: function(n) {\n            return !!((n && ((((typeof JSBNG__Node == \"object\")) ? ((n instanceof JSBNG__Node)) : ((((((typeof n == \"object\")) && ((typeof n.nodeType == \"number\")))) && ((typeof n.nodeName == \"string\"))))))));\n        },\n        isNodeOfType: function(n, o) {\n            var p = i(o).join(\"|\").toUpperCase().split(\"|\"), q = j(p);\n            return ((m.isNode(n) && ((n.nodeName in q))));\n        },\n        isElementNode: function(n) {\n            return ((m.isNode(n) && ((n.nodeType == 1))));\n        },\n        isTextNode: function(n) {\n            return ((m.isNode(n) && ((n.nodeType == 3))));\n        },\n        getDocumentScrollElement: function(n) {\n            n = ((n || JSBNG__document));\n            var o = ((h.JSBNG__chrome() || h.safari()));\n            return ((((!o && ((n.compatMode === \"CSS1Compat\")))) ? n.documentElement : n.body));\n        }\n    };\n    e.exports = m;\n});\n__d(\"DOMEvent\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\");\n    function h(i) {\n        this.JSBNG__event = ((i || window.JSBNG__event));\n        this.target = ((this.JSBNG__event.target || this.JSBNG__event.srcElement));\n    };\n;\n    g(h.prototype, {\n        preventDefault: function() {\n            var i = this.JSBNG__event;\n            ((i.preventDefault ? i.preventDefault() : i.returnValue = false));\n            return this;\n        },\n        stopPropagation: function() {\n            var i = this.JSBNG__event;\n            ((i.stopPropagation ? i.stopPropagation() : i.cancelBubble = true));\n            return this;\n        },\n        kill: function() {\n            this.stopPropagation().preventDefault();\n            return this;\n        }\n    });\n    e.exports = h;\n});\n__d(\"getObjectValues\", [\"hasArrayNature\",], function(a, b, c, d, e, f) {\n    var g = b(\"hasArrayNature\");\n    function h(i) {\n        var j = [];\n        for (var k in i) {\n            j.push(i[k]);\n        ;\n        };\n    ;\n        return j;\n    };\n;\n    e.exports = h;\n});\n__d(\"event-extensions\", [\"event-form-bubbling\",\"DataStore\",\"DOMQuery\",\"DOMEvent\",\"ErrorUtils\",\"Parent\",\"UserAgent\",\"$\",\"copyProperties\",\"getObjectValues\",], function(a, b, c, d, e, f) {\n    b(\"event-form-bubbling\");\n    var g = b(\"DataStore\"), h = b(\"DOMQuery\"), i = b(\"DOMEvent\"), j = b(\"ErrorUtils\"), k = b(\"Parent\"), l = b(\"UserAgent\"), m = b(\"$\"), n = b(\"copyProperties\"), o = b(\"getObjectValues\");\n    JSBNG__Event.DATASTORE_KEY = \"JSBNG__Event.listeners\";\n    if (!JSBNG__Event.prototype) {\n        JSBNG__Event.prototype = {\n        };\n    }\n;\n;\n    function p(y, z, aa) {\n        this.target = y;\n        this.type = z;\n        this.data = aa;\n    };\n;\n    n(p.prototype, {\n        getData: function() {\n            this.data = ((this.data || {\n            }));\n            return this.data;\n        },\n        JSBNG__stop: function() {\n            new i(this).stopPropagation();\n            return this;\n        },\n        prevent: function() {\n            new i(this).preventDefault();\n            return this;\n        },\n        kill: function() {\n            this.JSBNG__stop().prevent();\n            return false;\n        },\n        getTarget: function() {\n            return ((new i(this).target || null));\n        }\n    });\n    function q(y) {\n        if (((y instanceof p))) {\n            return y;\n        }\n    ;\n    ;\n        y = ((((y || window.JSBNG__event)) || {\n        }));\n        if (!y._inherits_from_prototype) {\n            for (var z in JSBNG__Event.prototype) {\n                try {\n                    y[z] = JSBNG__Event.prototype[z];\n                } catch (aa) {\n                \n                };\n            ;\n            };\n        }\n    ;\n    ;\n        return y;\n    };\n;\n    n(JSBNG__Event.prototype, {\n        _inherits_from_prototype: true,\n        getRelatedTarget: function() {\n            var y = ((this.relatedTarget || ((((this.fromElement === this.srcElement)) ? this.toElement : this.fromElement))));\n            return ((y ? m(y) : null));\n        },\n        getModifiers: function() {\n            var y = {\n                control: !!this.ctrlKey,\n                shift: !!this.shiftKey,\n                alt: !!this.altKey,\n                meta: !!this.metaKey\n            };\n            y.access = ((l.osx() ? y.control : y.alt));\n            y.any = ((((((y.control || y.shift)) || y.alt)) || y.meta));\n            return y;\n        },\n        isRightClick: function() {\n            if (this.which) {\n                return ((this.which === 3));\n            }\n        ;\n        ;\n            return ((this.button && ((this.button === 2))));\n        },\n        isMiddleClick: function() {\n            if (this.which) {\n                return ((this.which === 2));\n            }\n        ;\n        ;\n            return ((this.button && ((this.button === 4))));\n        },\n        isDefaultRequested: function() {\n            return ((((this.getModifiers().any || this.isMiddleClick())) || this.isRightClick()));\n        }\n    });\n    n(JSBNG__Event.prototype, p.prototype);\n    n(JSBNG__Event, {\n        listen: function(y, z, aa, ba) {\n            if (((typeof y == \"string\"))) {\n                y = m(y);\n            }\n        ;\n        ;\n            if (((typeof ba == \"undefined\"))) {\n                ba = JSBNG__Event.Priority.NORMAL;\n            }\n        ;\n        ;\n            if (((typeof z == \"object\"))) {\n                var ca = {\n                };\n                for (var da in z) {\n                    ca[da] = JSBNG__Event.listen(y, da, z[da], ba);\n                ;\n                };\n            ;\n                return ca;\n            }\n        ;\n        ;\n            if (z.match(/^on/i)) {\n                throw new TypeError(((((\"Bad event name `\" + z)) + \"': use `click', not `onclick'.\")));\n            }\n        ;\n        ;\n            if (((((y.nodeName == \"LABEL\")) && ((z == \"click\"))))) {\n                var ea = y.getElementsByTagName(\"input\");\n                y = ((((ea.length == 1)) ? ea[0] : y));\n            }\n             else if (((((y === window)) && ((z === \"JSBNG__scroll\"))))) {\n                var fa = h.getDocumentScrollElement();\n                if (((((fa !== JSBNG__document.documentElement)) && ((fa !== JSBNG__document.body))))) {\n                    y = fa;\n                }\n            ;\n            ;\n            }\n            \n        ;\n        ;\n            var ga = g.get(y, s, {\n            });\n            if (u[z]) {\n                var ha = u[z];\n                z = ha.base;\n                aa = ha.wrap(aa);\n            }\n        ;\n        ;\n            v(y, z);\n            var ia = ga[z];\n            if (!((ba in ia))) {\n                ia[ba] = [];\n            }\n        ;\n        ;\n            var ja = ia[ba].length, ka = new x(aa, ia[ba], ja);\n            ia[ba].push(ka);\n            return ka;\n        },\n        JSBNG__stop: function(y) {\n            new i(y).stopPropagation();\n            return y;\n        },\n        prevent: function(y) {\n            new i(y).preventDefault();\n            return y;\n        },\n        kill: function(y) {\n            new i(y).kill();\n            return false;\n        },\n        getKeyCode: function(JSBNG__event) {\n            JSBNG__event = new i(JSBNG__event).JSBNG__event;\n            if (!JSBNG__event) {\n                return false;\n            }\n        ;\n        ;\n            switch (JSBNG__event.keyCode) {\n              case 63232:\n                return 38;\n              case 63233:\n                return 40;\n              case 63234:\n                return 37;\n              case 63235:\n                return 39;\n              case 63272:\n            \n              case 63273:\n            \n              case 63275:\n                return null;\n              case 63276:\n                return 33;\n              case 63277:\n                return 34;\n            };\n        ;\n            if (JSBNG__event.shiftKey) {\n                switch (JSBNG__event.keyCode) {\n                  case 33:\n                \n                  case 34:\n                \n                  case 37:\n                \n                  case 38:\n                \n                  case 39:\n                \n                  case 40:\n                    return null;\n                };\n            }\n        ;\n        ;\n            return JSBNG__event.keyCode;\n        },\n        getPriorities: function() {\n            if (!r) {\n                var y = o(JSBNG__Event.Priority);\n                y.sort(function(z, aa) {\n                    return ((z - aa));\n                });\n                r = y;\n            }\n        ;\n        ;\n            return r;\n        },\n        fire: function(y, z, aa) {\n            var ba = new p(y, z, aa), ca;\n            do {\n                var da = JSBNG__Event.__getHandler(y, z);\n                if (da) {\n                    ca = da(ba);\n                }\n            ;\n            ;\n                y = y.parentNode;\n            } while (((((y && ((ca !== false)))) && !ba.cancelBubble)));\n            return ((ca !== false));\n        },\n        __fire: function(y, z, JSBNG__event) {\n            var aa = JSBNG__Event.__getHandler(y, z);\n            if (aa) {\n                return aa(q(JSBNG__event));\n            }\n        ;\n        ;\n        },\n        __getHandler: function(y, z) {\n            return g.get(y, ((JSBNG__Event.DATASTORE_KEY + z)));\n        },\n        getPosition: function(y) {\n            y = new i(y).JSBNG__event;\n            var z = h.getDocumentScrollElement(), aa = ((y.clientX + z.scrollLeft)), ba = ((y.clientY + z.scrollTop));\n            return {\n                x: aa,\n                y: ba\n            };\n        }\n    });\n    var r = null, s = JSBNG__Event.DATASTORE_KEY, t = function(y) {\n        return function(z) {\n            if (!h.contains(this, z.getRelatedTarget())) {\n                return y.call(this, z);\n            }\n        ;\n        ;\n        };\n    }, u = {\n        mouseenter: {\n            base: \"mouseover\",\n            wrap: t\n        },\n        mouseleave: {\n            base: \"mouseout\",\n            wrap: t\n        }\n    }, v = function(y, z) {\n        var aa = ((\"JSBNG__on\" + z)), ba = w.bind(y), ca = g.get(y, s);\n        if (((z in ca))) {\n            return;\n        }\n    ;\n    ;\n        ca[z] = {\n        };\n        if (y.JSBNG__addEventListener) {\n            y.JSBNG__addEventListener(z, ba, false);\n        }\n         else if (y.JSBNG__attachEvent) {\n            y.JSBNG__attachEvent(aa, ba);\n        }\n        \n    ;\n    ;\n        g.set(y, ((s + z)), ba);\n        if (y[aa]) {\n            var da = ((((y === JSBNG__document.documentElement)) ? JSBNG__Event.Priority._BUBBLE : JSBNG__Event.Priority.TRADITIONAL)), ea = y[aa];\n            y[aa] = null;\n            JSBNG__Event.listen(y, z, ea, da);\n        }\n    ;\n    ;\n        if (((((y.nodeName === \"FORM\")) && ((z === \"submit\"))))) {\n            JSBNG__Event.listen(y, z, JSBNG__Event.__bubbleSubmit.curry(y), JSBNG__Event.Priority._BUBBLE);\n        }\n    ;\n    ;\n    }, w = function(JSBNG__event) {\n        JSBNG__event = q(JSBNG__event);\n        var y = JSBNG__event.type;\n        if (!g.get(this, s)) {\n            throw new Error(\"Bad listenHandler context.\");\n        }\n    ;\n    ;\n        var z = g.get(this, s)[y];\n        if (!z) {\n            throw new Error(((((\"No registered handlers for `\" + y)) + \"'.\")));\n        }\n    ;\n    ;\n        if (((((y == \"click\")) && window.userAction))) {\n            var aa = k.byTag(JSBNG__event.getTarget(), \"a\"), ba = window.userAction(\"click\", aa, JSBNG__event).coalesce_namespace(\"evt_ext\");\n            if (window.ArbiterMonitor) {\n                window.ArbiterMonitor.initUA(ba, [aa,]);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        var ca = JSBNG__Event.getPriorities();\n        for (var da = 0; ((da < ca.length)); da++) {\n            var ea = ca[da];\n            if (((ea in z))) {\n                var fa = z[ea];\n                for (var ga = 0; ((ga < fa.length)); ga++) {\n                    if (!fa[ga]) {\n                        continue;\n                    }\n                ;\n                ;\n                    var ha = fa[ga].fire(this, JSBNG__event);\n                    if (((ha === false))) {\n                        return JSBNG__event.kill();\n                    }\n                     else if (JSBNG__event.cancelBubble) {\n                        JSBNG__event.JSBNG__stop();\n                    }\n                    \n                ;\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n        };\n    ;\n        return JSBNG__event.returnValue;\n    };\n    JSBNG__Event.Priority = {\n        URGENT: -20,\n        TRADITIONAL: -10,\n        NORMAL: 0,\n        _BUBBLE: 1000\n    };\n    function x(y, z, aa) {\n        this._handler = y;\n        this._container = z;\n        this._index = aa;\n    };\n;\n    n(x.prototype, {\n        remove: function() {\n            delete this._handler;\n            delete this._container[this._index];\n        },\n        fire: function(y, JSBNG__event) {\n            return j.applyWithGuard(this._handler, y, [JSBNG__event,], function(z) {\n                z.event_type = JSBNG__event.type;\n                z.dom_element = ((y.JSBNG__name || y.id));\n                z.category = \"eventhandler\";\n            });\n        }\n    });\n    a.$E = f.$E = q;\n});\n__d(\"evalGlobal\", [], function(a, b, c, d, e, f) {\n    function g(h) {\n        if (((typeof h != \"string\"))) {\n            throw new TypeError(\"JS sent to evalGlobal is not a string. Only strings are permitted.\");\n        }\n    ;\n    ;\n        if (!h) {\n            return;\n        }\n    ;\n    ;\n        var i = JSBNG__document.createElement(\"script\");\n        try {\n            i.appendChild(JSBNG__document.createTextNode(h));\n        } catch (j) {\n            i.text = h;\n        };\n    ;\n        var k = ((JSBNG__document.getElementsByTagName(\"head\")[0] || JSBNG__document.documentElement));\n        k.appendChild(i);\n        k.removeChild(i);\n    };\n;\n    e.exports = g;\n});\n__d(\"HTML\", [\"function-extensions\",\"Bootloader\",\"UserAgent\",\"copyProperties\",\"createArrayFrom\",\"evalGlobal\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"Bootloader\"), h = b(\"UserAgent\"), i = b(\"copyProperties\"), j = b(\"createArrayFrom\"), k = b(\"evalGlobal\");\n    function l(m) {\n        if (((m && m.__html))) {\n            m = m.__html;\n        }\n    ;\n    ;\n        if (!((this instanceof l))) {\n            if (((m instanceof l))) {\n                return m;\n            }\n        ;\n        ;\n            return new l(m);\n        }\n    ;\n    ;\n        this._content = m;\n        this._defer = false;\n        this._extra_action = \"\";\n        this._nodes = null;\n        this._inline_js = bagofholding;\n        this._rootNode = null;\n        return this;\n    };\n;\n    l.isHTML = function(m) {\n        return ((m && ((((m instanceof l)) || ((m.__html !== undefined))))));\n    };\n    l.replaceJSONWrapper = function(m) {\n        return ((((m && ((m.__html !== undefined)))) ? new l(m.__html) : m));\n    };\n    i(l.prototype, {\n        toString: function() {\n            var m = ((this._content || \"\"));\n            if (this._extra_action) {\n                m += ((((((\"\\u003Cscript type=\\\"text/javascript\\\"\\u003E\" + this._extra_action)) + \"\\u003C/scr\")) + \"ipt\\u003E\"));\n            }\n        ;\n        ;\n            return m;\n        },\n        setAction: function(m) {\n            this._extra_action = m;\n            return this;\n        },\n        getAction: function() {\n            this._fillCache();\n            var m = function() {\n                this._inline_js();\n                k(this._extra_action);\n            }.bind(this);\n            if (this.getDeferred()) {\n                return m.defer.bind(m);\n            }\n             else return m\n        ;\n        },\n        setDeferred: function(m) {\n            this._defer = !!m;\n            return this;\n        },\n        getDeferred: function() {\n            return this._defer;\n        },\n        getContent: function() {\n            return this._content;\n        },\n        getNodes: function() {\n            this._fillCache();\n            return this._nodes;\n        },\n        getRootNode: function() {\n            var m = this.getNodes();\n            if (((m.length === 1))) {\n                this._rootNode = m[0];\n            }\n             else {\n                var n = JSBNG__document.createDocumentFragment();\n                for (var o = 0; ((o < m.length)); o++) {\n                    n.appendChild(m[o]);\n                ;\n                };\n            ;\n                this._rootNode = n;\n            }\n        ;\n        ;\n            return this._rootNode;\n        },\n        _fillCache: function() {\n            if (((null !== this._nodes))) {\n                return;\n            }\n        ;\n        ;\n            var m = this._content;\n            if (!m) {\n                this._nodes = [];\n                return;\n            }\n        ;\n        ;\n            m = m.replace(/(<(\\w+)[^>]*?)\\/>/g, function(x, y, z) {\n                return ((z.match(/^(abbr|br|col|img|input|link|meta|param|hr|area|embed)$/i) ? x : ((((((y + \"\\u003E\\u003C/\")) + z)) + \"\\u003E\"))));\n            });\n            var n = m.trim().toLowerCase(), o = JSBNG__document.createElement(\"div\"), p = false, q = ((((((((((((((!n.indexOf(\"\\u003Copt\") && [1,\"\\u003Cselect multiple=\\\"multiple\\\" class=\\\"__WRAPPER\\\"\\u003E\",\"\\u003C/select\\u003E\",])) || ((!n.indexOf(\"\\u003Cleg\") && [1,\"\\u003Cfieldset class=\\\"__WRAPPER\\\"\\u003E\",\"\\u003C/fieldset\\u003E\",])))) || ((n.match(/^<(thead|tbody|tfoot|colg|cap)/) && [1,\"\\u003Ctable class=\\\"__WRAPPER\\\"\\u003E\",\"\\u003C/table\\u003E\",])))) || ((!n.indexOf(\"\\u003Ctr\") && [2,\"\\u003Ctable\\u003E\\u003Ctbody class=\\\"__WRAPPER\\\"\\u003E\",\"\\u003C/tbody\\u003E\\u003C/table\\u003E\",])))) || ((((!n.indexOf(\"\\u003Ctd\") || !n.indexOf(\"\\u003Cth\"))) && [3,\"\\u003Ctable\\u003E\\u003Ctbody\\u003E\\u003Ctr class=\\\"__WRAPPER\\\"\\u003E\",\"\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\",])))) || ((!n.indexOf(\"\\u003Ccol\") && [2,\"\\u003Ctable\\u003E\\u003Ctbody\\u003E\\u003C/tbody\\u003E\\u003Ccolgroup class=\\\"__WRAPPER\\\"\\u003E\",\"\\u003C/colgroup\\u003E\\u003C/table\\u003E\",])))) || null));\n            if (((null === q))) {\n                o.className = \"__WRAPPER\";\n                if (h.ie()) {\n                    q = [0,\"\\u003Cspan style=\\\"display:none\\\"\\u003E&nbsp;\\u003C/span\\u003E\",\"\",];\n                    p = true;\n                }\n                 else q = [0,\"\",\"\",];\n            ;\n            ;\n            }\n        ;\n        ;\n            o.innerHTML = ((((q[1] + m)) + q[2]));\n            while (q[0]--) {\n                o = o.lastChild;\n            ;\n            };\n        ;\n            if (p) {\n                o.removeChild(o.firstChild);\n            }\n        ;\n        ;\n            ((o.className != \"__WRAPPER\"));\n            if (h.ie()) {\n                var r;\n                if (((!n.indexOf(\"\\u003Ctable\") && ((-1 == n.indexOf(\"\\u003Ctbody\")))))) {\n                    r = ((o.firstChild && o.firstChild.childNodes));\n                }\n                 else if (((((q[1] == \"\\u003Ctable\\u003E\")) && ((-1 == n.indexOf(\"\\u003Ctbody\")))))) {\n                    r = o.childNodes;\n                }\n                 else r = [];\n                \n            ;\n            ;\n                for (var s = ((r.length - 1)); ((s >= 0)); --s) {\n                    if (((((r[s].nodeName && ((r[s].nodeName.toLowerCase() == \"tbody\")))) && ((r[s].childNodes.length == 0))))) {\n                        r[s].parentNode.removeChild(r[s]);\n                    }\n                ;\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            var t = o.getElementsByTagName(\"script\"), u = [];\n            for (var v = 0; ((v < t.length)); v++) {\n                if (t[v].src) {\n                    u.push(g.requestResource.bind(g, \"js\", t[v].src));\n                }\n                 else u.push(k.bind(null, t[v].innerHTML));\n            ;\n            ;\n            };\n        ;\n            for (var v = ((t.length - 1)); ((v >= 0)); v--) {\n                t[v].parentNode.removeChild(t[v]);\n            ;\n            };\n        ;\n            var w = function() {\n                for (var x = 0; ((x < u.length)); x++) {\n                    u[x]();\n                ;\n                };\n            ;\n            };\n            this._nodes = j(o.childNodes);\n            this._inline_js = w;\n        }\n    });\n    e.exports = l;\n});\n__d(\"isScalar\", [], function(a, b, c, d, e, f) {\n    function g(h) {\n        return (/string|number|boolean/).test(typeof h);\n    };\n;\n    e.exports = g;\n});\n__d(\"DOM\", [\"event-extensions\",\"CSS\",\"DOMQuery\",\"HTML\",\"UserAgent\",\"$\",\"copyProperties\",\"createArrayFrom\",\"isScalar\",\"tx\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"CSS\"), h = b(\"DOMQuery\"), i = b(\"HTML\"), j = b(\"UserAgent\"), k = b(\"$\"), l = b(\"copyProperties\"), m = b(\"createArrayFrom\"), n = b(\"isScalar\"), o = b(\"tx\"), p = \"js_\", q = 0, r = {\n    };\n    l(r, h);\n    l(r, {\n        create: function(u, v, w) {\n            var x = JSBNG__document.createElement(u);\n            if (v) {\n                r.setAttributes(x, v);\n            }\n        ;\n        ;\n            if (((w != null))) {\n                r.setContent(x, w);\n            }\n        ;\n        ;\n            return x;\n        },\n        setAttributes: function(u, v) {\n            if (v.type) {\n                u.type = v.type;\n            }\n        ;\n        ;\n            for (var w in v) {\n                var x = v[w], y = (/^on/i).test(w);\n                if (((w == \"type\"))) {\n                    continue;\n                }\n                 else if (((w == \"style\"))) {\n                    if (((typeof x == \"string\"))) {\n                        u.style.cssText = x;\n                    }\n                     else l(u.style, x);\n                ;\n                ;\n                }\n                 else if (y) {\n                    JSBNG__Event.listen(u, w.substr(2), x);\n                }\n                 else if (((w in u))) {\n                    u[w] = x;\n                }\n                 else if (u.setAttribute) {\n                    u.setAttribute(w, x);\n                }\n                \n                \n                \n                \n            ;\n            ;\n            };\n        ;\n        },\n        prependContent: function(u, v) {\n            return s(v, u, function(w) {\n                ((u.firstChild ? u.insertBefore(w, u.firstChild) : u.appendChild(w)));\n            });\n        },\n        insertAfter: function(u, v) {\n            var w = u.parentNode;\n            return s(v, w, function(x) {\n                ((u.nextSibling ? w.insertBefore(x, u.nextSibling) : w.appendChild(x)));\n            });\n        },\n        insertBefore: function(u, v) {\n            var w = u.parentNode;\n            return s(v, w, function(x) {\n                w.insertBefore(x, u);\n            });\n        },\n        setContent: function(u, v) {\n            r.empty(u);\n            return r.appendContent(u, v);\n        },\n        appendContent: function(u, v) {\n            return s(v, u, function(w) {\n                u.appendChild(w);\n            });\n        },\n        replace: function(u, v) {\n            var w = u.parentNode;\n            return s(v, w, function(x) {\n                w.replaceChild(x, u);\n            });\n        },\n        remove: function(u) {\n            u = k(u);\n            if (u.parentNode) {\n                u.parentNode.removeChild(u);\n            }\n        ;\n        ;\n        },\n        empty: function(u) {\n            u = k(u);\n            while (u.firstChild) {\n                r.remove(u.firstChild);\n            ;\n            };\n        ;\n        },\n        getID: function(u) {\n            var v = u.id;\n            if (!v) {\n                v = ((p + q++));\n                u.id = v;\n            }\n        ;\n        ;\n            return v;\n        }\n    });\n    function s(u, v, w) {\n        u = i.replaceJSONWrapper(u);\n        if (((((((u instanceof i)) && ((\"\" === v.innerHTML)))) && ((-1 === u.toString().indexOf(((\"\\u003Cscr\" + \"ipt\")))))))) {\n            var x = j.ie();\n            if (((!x || ((((x > 7)) && !h.isNodeOfType(v, [\"table\",\"tbody\",\"thead\",\"tfoot\",\"tr\",\"select\",\"fieldset\",])))))) {\n                var y = ((x ? \"\\u003Cem style=\\\"display:none;\\\"\\u003E&nbsp;\\u003C/em\\u003E\" : \"\"));\n                v.innerHTML = ((y + u));\n                ((x && v.removeChild(v.firstChild)));\n                return m(v.childNodes);\n            }\n        ;\n        ;\n        }\n         else if (h.isTextNode(v)) {\n            v.data = u;\n            return [u,];\n        }\n        \n    ;\n    ;\n        var z = JSBNG__document.createDocumentFragment(), aa, ba = [], ca = [];\n        if (!Array.isArray(u)) {\n            u = [u,];\n        }\n    ;\n    ;\n        for (var da = 0; ((da < u.length)); da++) {\n            aa = i.replaceJSONWrapper(u[da]);\n            if (((aa instanceof i))) {\n                ca.push(aa.getAction());\n                var ea = aa.getNodes();\n                for (var fa = 0; ((fa < ea.length)); fa++) {\n                    ba.push(ea[fa]);\n                    z.appendChild(ea[fa]);\n                };\n            ;\n            }\n             else if (n(aa)) {\n                var ga = JSBNG__document.createTextNode(aa);\n                ba.push(ga);\n                z.appendChild(ga);\n            }\n             else if (h.isNode(aa)) {\n                ba.push(aa);\n                z.appendChild(aa);\n            }\n            \n            \n        ;\n        ;\n        };\n    ;\n        w(z);\n        ca.forEach(function(ha) {\n            ha();\n        });\n        return ba;\n    };\n;\n    function t(u) {\n        function v(w) {\n            return r.create(\"div\", {\n            }, w).innerHTML;\n        };\n    ;\n        return function(w, x) {\n            var y = {\n            };\n            if (x) {\n                for (var z in x) {\n                    y[z] = v(x[z]);\n                ;\n                };\n            }\n        ;\n        ;\n            return i(u(w, y));\n        };\n    };\n;\n    r.tx = t(o);\n    r.tx._ = r._tx = t(o._);\n    e.exports = r;\n});\n__d(\"legacy:dom\", [\"DOM\",], function(a, b, c, d) {\n    a.DOM = b(\"DOM\");\n}, 3);\n__d(\"OnloadHooks\", [\"Arbiter\",\"ErrorUtils\",\"InitialJSLoader\",\"OnloadEvent\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ErrorUtils\"), i = b(\"InitialJSLoader\"), j = b(\"OnloadEvent\");\n    function k() {\n        var r = a.CavalryLogger;\n        if (((!window.loaded && r))) {\n            r.getInstance().setTimeStamp(\"t_prehooks\");\n        }\n    ;\n    ;\n        n(\"JSBNG__onloadhooks\");\n        if (((!window.loaded && r))) {\n            r.getInstance().setTimeStamp(\"t_hooks\");\n        }\n    ;\n    ;\n        window.loaded = true;\n        g.inform(\"uipage_onload\", true, g.BEHAVIOR_STATE);\n    };\n;\n    function l() {\n        n(\"JSBNG__onafterloadhooks\");\n        window.afterloaded = true;\n    };\n;\n    function m(r, s) {\n        return h.applyWithGuard(r, null, null, function(t) {\n            t.event_type = s;\n            t.category = \"runhook\";\n        });\n    };\n;\n    function n(r) {\n        var s = ((((r == \"JSBNG__onbeforeleavehooks\")) || ((r == \"JSBNG__onbeforeunloadhooks\"))));\n        do {\n            var t = window[r];\n            if (!t) {\n                break;\n            }\n        ;\n        ;\n            if (!s) {\n                window[r] = null;\n            }\n        ;\n        ;\n            for (var u = 0; ((u < t.length)); u++) {\n                var v = m(t[u], r);\n                if (((s && v))) {\n                    return v;\n                }\n            ;\n            ;\n            };\n        ;\n        } while (((!s && window[r])));\n    };\n;\n    function o() {\n        if (!window.loaded) {\n            window.loaded = true;\n            n(\"JSBNG__onloadhooks\");\n        }\n    ;\n    ;\n        if (!window.afterloaded) {\n            window.afterloaded = true;\n            n(\"JSBNG__onafterloadhooks\");\n        }\n    ;\n    ;\n    };\n;\n    function p() {\n        g.registerCallback(k, [j.ONLOAD_DOMCONTENT_CALLBACK,i.INITIAL_JS_READY,]);\n        g.registerCallback(l, [j.ONLOAD_DOMCONTENT_CALLBACK,j.ONLOAD_CALLBACK,i.INITIAL_JS_READY,]);\n        g.subscribe(j.ONBEFOREUNLOAD, function(r, s) {\n            s.warn = ((n(\"JSBNG__onbeforeleavehooks\") || n(\"JSBNG__onbeforeunloadhooks\")));\n            if (!s.warn) {\n                window.loaded = false;\n                window.afterloaded = false;\n            }\n        ;\n        ;\n        }, g.SUBSCRIBE_NEW);\n        g.subscribe(j.ONUNLOAD, function(r, s) {\n            n(\"JSBNG__onunloadhooks\");\n        }, g.SUBSCRIBE_NEW);\n    };\n;\n    var q = {\n        _onloadHook: k,\n        _onafterloadHook: l,\n        runHook: m,\n        runHooks: n,\n        keepWindowSetAsLoaded: o\n    };\n    p();\n    a.OnloadHooks = e.exports = q;\n});\n__d(\"legacy:onload-action\", [\"OnloadHooks\",], function(a, b, c, d) {\n    var e = b(\"OnloadHooks\");\n    a._onloadHook = e._onloadHook;\n    a._onafterloadHook = e._onafterloadHook;\n    a.runHook = e.runHook;\n    a.runHooks = e.runHooks;\n    a.keep_window_set_as_loaded = e.keepWindowSetAsLoaded;\n}, 3);\nfunction link_rel_preload() {\n    var a = /async(?:-post)?|dialog(?:-pipe|-post)?|theater|toggle/;\n    JSBNG__document.documentElement.JSBNG__onmousedown = function(b) {\n        b = ((b || window.JSBNG__event));\n        var c = ((b.target || b.srcElement)), d = Parent.byTag(c, \"A\");\n        if (!d) {\n            return;\n        }\n    ;\n    ;\n        var e = d.getAttribute(\"ajaxify\"), f = d.href, g = ((e || f));\n        if (((((e && f)) && !(/#$/).test(f)))) {\n            var h = ((b.which && ((b.which != 1)))), i = ((((((b.altKey || b.ctrlKey)) || b.metaKey)) || b.shiftKey));\n            if (((h || i))) {\n                return;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        var j = ((d.rel && d.rel.match(a)));\n        j = ((j && j[0]));\n        switch (j) {\n          case \"dialog\":\n        \n          case \"dialog-post\":\n            Bootloader.loadComponents(\"dialog\");\n            break;\n          case \"dialog-pipe\":\n            Bootloader.loadComponents([\"ajaxpipe\",\"dialog\",]);\n            break;\n          case \"async\":\n        \n          case \"async-post\":\n            Bootloader.loadComponents(\"async\");\n            break;\n          case \"theater\":\n            Bootloader.loadComponents(\"PhotoSnowlift\", function() {\n                PhotoSnowlift.preload(g, d);\n            });\n            break;\n          case \"toggle\":\n            Bootloader.loadComponents(\"Toggler\");\n            break;\n        };\n    ;\n        return;\n    };\n};\n;\n__d(\"Style\", [\"DOMQuery\",\"ErrorUtils\",\"$\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOMQuery\"), h = b(\"ErrorUtils\"), i = b(\"$\");\n    function j(m) {\n        return m.replace(/([A-Z])/g, \"-$1\").toLowerCase();\n    };\n;\n    function k(m, n) {\n        var o = l.get(m, n);\n        return ((((o === \"auto\")) || ((o === \"JSBNG__scroll\"))));\n    };\n;\n    var l = {\n        set: function(m, n, o) {\n            switch (n) {\n              case \"opacity\":\n                m.style.opacity = o;\n                m.style.filter = ((((o !== \"\")) ? ((((\"alpha(opacity=\" + ((o * 100)))) + \")\")) : \"\"));\n                break;\n              case \"float\":\n                m.style.cssFloat = m.style.styleFloat = o;\n                break;\n              case \"width\":\n            \n              case \"height\":\n                if (((parseInt(o, 10) < 0))) {\n                    h.applyWithGuard(function(q, r) {\n                        throw new Error(((((((((\"Style.set: \\\"\" + q)) + \"\\\" argument is invalid: \\\"\")) + r)) + \"\\\"\")));\n                    }, l, [n,o,]);\n                }\n            ;\n            ;\n              default:\n                n = n.replace(/-(.)/g, function(q, r) {\n                    return r.toUpperCase();\n                });\n                try {\n                    m.style[n] = o;\n                } catch (p) {\n                    throw new Error(((((((((\"Style.set: \\\"\" + n)) + \"\\\" argument is invalid: \\\"\")) + o)) + \"\\\"\")));\n                };\n            ;\n            };\n        ;\n            return m;\n        },\n        get: function(m, n) {\n            m = i(m);\n            n = n.replace(/-(.)/g, function(p, q) {\n                return q.toUpperCase();\n            });\n            var o;\n            if (window.JSBNG__getComputedStyle) {\n                o = window.JSBNG__getComputedStyle(m, null);\n                if (o) {\n                    return o.getPropertyValue(j(n));\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            if (((JSBNG__document.defaultView && JSBNG__document.defaultView.JSBNG__getComputedStyle))) {\n                o = JSBNG__document.defaultView.JSBNG__getComputedStyle(m, null);\n                if (o) {\n                    return o.getPropertyValue(j(n));\n                }\n            ;\n            ;\n                if (((n == \"display\"))) {\n                    return \"none\";\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            if (m.currentStyle) {\n                return m.currentStyle[n];\n            }\n        ;\n        ;\n            return ((m.style && m.style[n]));\n        },\n        getFloat: function(m, n) {\n            return parseFloat(l.get(m, n), 10);\n        },\n        getOpacity: function(m) {\n            m = i(m);\n            var n = l.get(m, \"filter\"), o = null;\n            if (((n && (o = /(\\d+(?:\\.\\d+)?)/.exec(n))))) {\n                return ((parseFloat(o.pop()) / 100));\n            }\n             else if (n = l.get(m, \"opacity\")) {\n                return parseFloat(n);\n            }\n             else return 1\n            \n        ;\n        },\n        isFixed: function(m) {\n            while (((m && ((m !== JSBNG__document.documentElement))))) {\n                if (((l.get(m, \"position\") === \"fixed\"))) {\n                    return true;\n                }\n            ;\n            ;\n                m = m.parentNode;\n            };\n        ;\n            return false;\n        },\n        getScrollParent: function(m) {\n            if (!m) {\n                return null;\n            }\n        ;\n        ;\n            while (((m !== JSBNG__document.body))) {\n                if (((((k(m, \"overflow\") || k(m, \"overflowY\"))) || k(m, \"overflowX\")))) {\n                    return m;\n                }\n            ;\n            ;\n                m = m.parentNode;\n            };\n        ;\n            return window;\n        }\n    };\n    e.exports = l;\n});\n__d(\"legacy:animation\", [\"Animation\",], function(a, b, c, d) {\n    a.animation = b(\"Animation\");\n}, 3);\n__d(\"LiveTimer\", [\"CSS\",\"DOM\",\"UserAgent\",\"tx\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"UserAgent\"), j = b(\"tx\"), k = {\n        restart: function(l) {\n            this.serverTime = l;\n            this.localStartTime = ((JSBNG__Date.now() / 1000));\n            this.updateTimeStamps();\n        },\n        getApproximateServerTime: function() {\n            return ((((((this.serverTime - this.localStartTime)) * 1000)) + JSBNG__Date.now()));\n        },\n        updateTimeStamps: function() {\n            k.timestamps = h.scry(JSBNG__document.body, \"abbr.livetimestamp\");\n            k.startLoop(20000);\n        },\n        addTimeStamps: function(l) {\n            if (!l) {\n                return;\n            }\n        ;\n        ;\n            k.timestamps = ((k.timestamps || []));\n            if (((h.isNodeOfType(l, \"abbr\") && g.hasClass(l, \"livetimestamp\")))) {\n                k.timestamps.push(l);\n            }\n             else {\n                var m = h.scry(l, \"abbr.livetimestamp\");\n                for (var n = 0; ((n < m.length)); ++n) {\n                    k.timestamps.push(m[n]);\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            k.startLoop(0);\n        },\n        startLoop: function(l) {\n            this.JSBNG__stop();\n            this.timeout = JSBNG__setTimeout(function() {\n                k.loop();\n            }, l);\n        },\n        JSBNG__stop: function() {\n            JSBNG__clearTimeout(this.timeout);\n        },\n        updateNode: function(l, m) {\n            k.updateNode = ((((i.ie() < 7)) ? bagofholding : h.setContent));\n            k.updateNode(l, m);\n        },\n        loop: function(l) {\n            if (l) {\n                k.updateTimeStamps();\n            }\n        ;\n        ;\n            var m = Math.floor(((k.getApproximateServerTime() / 1000))), n = -1;\n            ((k.timestamps && k.timestamps.forEach(function(p) {\n                var q = p.getAttribute(\"data-utime\"), r = k.renderRelativeTime(m, q);\n                if (r.text) {\n                    k.updateNode(p, r.text);\n                }\n            ;\n            ;\n                if (((((r.next != -1)) && ((((r.next < n)) || ((n == -1))))))) {\n                    n = r.next;\n                }\n            ;\n            ;\n            })));\n            if (((n != -1))) {\n                var o = Math.max(20000, ((n * 1000)));\n                k.timeout = JSBNG__setTimeout(function() {\n                    k.loop();\n                }, o);\n            }\n        ;\n        ;\n        },\n        renderRelativeTime: function(l, m) {\n            var n = {\n                text: \"\",\n                next: -1\n            };\n            if (((((((l - m)) > ((12 * 3600)))) || ((new JSBNG__Date(((l * 1000))).getDay() != new JSBNG__Date(((m * 1000))).getDay()))))) {\n                return n;\n            }\n        ;\n        ;\n            var o = ((l - m)), p = Math.floor(((o / 60))), q = Math.floor(((p / 60)));\n            if (((p < 1))) {\n                n.text = \"a few seconds ago\";\n                n.next = ((60 - ((o % 60))));\n                return n;\n            }\n        ;\n        ;\n            if (((q < 1))) {\n                if (((p == 1))) {\n                    n.text = \"about a minute ago\";\n                }\n                 else n.text = j._(\"{number} minutes ago\", {\n                    number: p\n                });\n            ;\n            ;\n                n.next = ((60 - ((o % 60))));\n                return n;\n            }\n        ;\n        ;\n            if (((q != 11))) {\n                n.next = ((3600 - ((o % 3600))));\n            }\n        ;\n        ;\n            if (((q == 1))) {\n                n.text = \"about an hour ago\";\n                return n;\n            }\n        ;\n        ;\n            n.text = j._(\"{number} hours ago\", {\n                number: q\n            });\n            return n;\n        }\n    };\n    e.exports = k;\n});\n__d(\"legacy:live-timer\", [\"LiveTimer\",], function(a, b, c, d) {\n    a.LiveTimer = b(\"LiveTimer\");\n}, 3);\n__d(\"BanzaiCommon\", [\"BanzaiConfig\",], function(a, b, c, d, e, f) {\n    var g = c(\"BanzaiConfig\"), h = {\n        store: true,\n        delay: ((g.MIN_WAIT || 1000))\n    }, i = {\n        store: false,\n        delay: ((g.MAX_WAIT || 60000))\n    }, j, k, l, m, n;\n    function o() {\n        k = [];\n        l = [];\n    };\n;\n    function p(v) {\n        var w = ((JSBNG__Date.now() + v));\n        if (((!n || ((w < n))))) {\n            n = w;\n            JSBNG__clearTimeout(m);\n            m = JSBNG__setTimeout(r, v);\n        }\n    ;\n    ;\n    };\n;\n    function q(v, w, x) {\n        x = ((x || i));\n        var y = [v,w,];\n        k.push(y);\n        if (x.store) {\n            l.push(y);\n        }\n    ;\n    ;\n        p(((x.delay || 60000)));\n    };\n;\n    function r() {\n        n = null;\n        p(i.delay);\n        if (j.isSending()) {\n            return;\n        }\n    ;\n    ;\n        j.inform(u.SEND);\n        if (((k.length <= 0))) {\n            j.inform(u.OK);\n            return;\n        }\n    ;\n    ;\n        var v = k;\n        o();\n        j.send(v);\n    };\n;\n    function s(v) {\n        j = v;\n        j.JSBNG__onUnload(function() {\n            j.inform(u.SHUTDOWN);\n            t.store();\n        });\n    };\n;\n    var t = ((a.JSBNG__sessionStorage ? {\n        store: function v() {\n            a.JSBNG__sessionStorage.setItem(\"Banzai\", JSON.stringify(k));\n        },\n        restore: function v() {\n            if (((\"Banzai\" in a.JSBNG__sessionStorage))) {\n                k = [].concat(JSON.parse(a.JSBNG__sessionStorage.getItem(\"Banzai\")));\n                l = [].concat(k);\n                a.JSBNG__sessionStorage.removeItem(\"Banzai\");\n            }\n        ;\n        ;\n        }\n    } : {\n        store: function() {\n        \n        },\n        restore: function() {\n        \n        }\n    })), u = {\n        SEND: \"Banzai:SEND\",\n        OK: \"Banzai:OK\",\n        ERROR: \"Banzai:ERROR\",\n        SHUTDOWN: \"Banzai:SHUTDOWN\",\n        VITAL: h,\n        SEND_TIMEOUT: 15000,\n        isEnabled: function(v) {\n            return ((g.gks && g.gks[v]));\n        },\n        post: q,\n        setAdapter: s,\n        subscribe: function(v, w) {\n            j.subscribe(v, w);\n        }\n    };\n    o();\n    t.restore();\n    p(i.delay);\n    e.exports = u;\n});\n__d(\"BanzaiDesktop\", [\"Arbiter\",\"BanzaiCommon\",\"QueryString\",\"Run\",\"XHR\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"BanzaiCommon\"), i = b(\"QueryString\"), j = b(\"Run\"), k = b(\"XHR\"), l = null, m = new g(), n = \"/ajax/banzai/banzai.php\", o = {\n        inform: function p(q) {\n            m.inform(q);\n        },\n        subscribe: function(p, q) {\n            m.subscribe(p, q);\n        },\n        cleanup: function p() {\n            if (((l && ((l.readyState < 4))))) {\n                l.abort();\n            }\n        ;\n        ;\n            if (l) {\n                l = l.JSBNG__onreadystatechange = null;\n            }\n        ;\n        ;\n        },\n        isSending: function p() {\n            return !!l;\n        },\n        send: function p(q) {\n            var r = \"POST\";\n            l = k.create();\n            l.open(r, n, true);\n            l.setRequestHeader(\"Content-Type\", \"application/x-www-form-urlencoded\");\n            l.JSBNG__onreadystatechange = function() {\n                if (((l.readyState >= 4))) {\n                    var t = l.JSBNG__status;\n                    o.cleanup();\n                    o.inform(((((t == 200)) ? h.OK : h.ERROR)));\n                }\n            ;\n            ;\n            };\n            JSBNG__setTimeout(o.cleanup, h.SEND_TIMEOUT, false);\n            var s = k.getAsyncParams(r);\n            s.q = JSON.stringify(q);\n            l.send(i.encode(s));\n        },\n        JSBNG__onUnload: function p(q) {\n            j.JSBNG__onUnload(q);\n        }\n    };\n    h.setAdapter(o);\n    e.exports = h;\n});\n__d(\"BehaviorsMixin\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\");\n    function h(l) {\n        this._behavior = l;\n        this._enabled = false;\n    };\n;\n    g(h.prototype, {\n        enable: function() {\n            if (!this._enabled) {\n                this._enabled = true;\n                this._behavior.enable();\n            }\n        ;\n        ;\n        },\n        disable: function() {\n            if (this._enabled) {\n                this._enabled = false;\n                this._behavior.disable();\n            }\n        ;\n        ;\n        }\n    });\n    var i = 1;\n    function j(l) {\n        if (!l.__BEHAVIOR_ID) {\n            l.__BEHAVIOR_ID = i++;\n        }\n    ;\n    ;\n        return l.__BEHAVIOR_ID;\n    };\n;\n    var k = {\n        enableBehavior: function(l) {\n            if (!this._behaviors) {\n                this._behaviors = {\n                };\n            }\n        ;\n        ;\n            var m = j(l);\n            if (!this._behaviors[m]) {\n                this._behaviors[m] = new h(new l(this));\n            }\n        ;\n        ;\n            this._behaviors[m].enable();\n            return this;\n        },\n        disableBehavior: function(l) {\n            if (this._behaviors) {\n                var m = j(l);\n                if (this._behaviors[m]) {\n                    this._behaviors[m].disable();\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            return this;\n        },\n        enableBehaviors: function(l) {\n            l.forEach(this.enableBehavior.bind(this));\n            return this;\n        },\n        destroyBehaviors: function() {\n            if (this._behaviors) {\n                for (var l in this._behaviors) {\n                    this._behaviors[l].disable();\n                ;\n                };\n            ;\n                this._behaviors = {\n                };\n            }\n        ;\n        ;\n        }\n    };\n    e.exports = k;\n});\n__d(\"DOMDimensions\", [\"DOMQuery\",\"Style\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOMQuery\"), h = b(\"Style\"), i = {\n        getElementDimensions: function(j) {\n            return {\n                width: ((j.offsetWidth || 0)),\n                height: ((j.offsetHeight || 0))\n            };\n        },\n        getViewportDimensions: function() {\n            var j = ((((((((window && window.JSBNG__innerWidth)) || ((((JSBNG__document && JSBNG__document.documentElement)) && JSBNG__document.documentElement.clientWidth)))) || ((((JSBNG__document && JSBNG__document.body)) && JSBNG__document.body.clientWidth)))) || 0)), k = ((((((((window && window.JSBNG__innerHeight)) || ((((JSBNG__document && JSBNG__document.documentElement)) && JSBNG__document.documentElement.clientHeight)))) || ((((JSBNG__document && JSBNG__document.body)) && JSBNG__document.body.clientHeight)))) || 0));\n            return {\n                width: j,\n                height: k\n            };\n        },\n        getViewportWithoutScrollbarDimensions: function() {\n            var j = ((((((((((JSBNG__document && JSBNG__document.documentElement)) && JSBNG__document.documentElement.clientWidth)) || ((window && window.JSBNG__innerWidth)))) || ((((JSBNG__document && JSBNG__document.body)) && JSBNG__document.body.clientWidth)))) || 0)), k = ((((((((((JSBNG__document && JSBNG__document.documentElement)) && JSBNG__document.documentElement.clientHeight)) || ((window && window.JSBNG__innerHeight)))) || ((((JSBNG__document && JSBNG__document.body)) && JSBNG__document.body.clientHeight)))) || 0));\n            return {\n                width: j,\n                height: k\n            };\n        },\n        getDocumentDimensions: function(j) {\n            j = ((j || JSBNG__document));\n            var k = g.getDocumentScrollElement(j), l = ((k.scrollWidth || 0)), m = ((k.scrollHeight || 0));\n            return {\n                width: l,\n                height: m\n            };\n        },\n        measureElementBox: function(j, k, l, m, n) {\n            var o;\n            switch (k) {\n              case \"left\":\n            \n              case \"right\":\n            \n              case \"JSBNG__top\":\n            \n              case \"bottom\":\n                o = [k,];\n                break;\n              case \"width\":\n                o = [\"left\",\"right\",];\n                break;\n              case \"height\":\n                o = [\"JSBNG__top\",\"bottom\",];\n                break;\n              default:\n                throw Error(((\"Invalid plane: \" + k)));\n            };\n        ;\n            var p = function(q, r) {\n                var s = 0;\n                for (var t = 0; ((t < o.length)); t++) {\n                    s += ((parseInt(h.get(j, ((((((q + \"-\")) + o[t])) + r))), 10) || 0));\n                ;\n                };\n            ;\n                return s;\n            };\n            return ((((((l ? p(\"padding\", \"\") : 0)) + ((m ? p(\"border\", \"-width\") : 0)))) + ((n ? p(\"margin\", \"\") : 0))));\n        }\n    };\n    e.exports = i;\n});\n__d(\"DOMEventListener\", [], function(a, b, c, d, e, f) {\n    var g, h;\n    if (window.JSBNG__addEventListener) {\n        g = function(j, k, l) {\n            j.JSBNG__addEventListener(k, l, false);\n        };\n        h = function(j, k, l) {\n            j.JSBNG__removeEventListener(k, l, false);\n        };\n    }\n     else if (window.JSBNG__attachEvent) {\n        g = function(j, k, l) {\n            j.JSBNG__attachEvent(((\"JSBNG__on\" + k)), l);\n        };\n        h = function(j, k, l) {\n            j.JSBNG__detachEvent(((\"JSBNG__on\" + k)), l);\n        };\n    }\n    \n;\n;\n    var i = {\n        add: function(j, k, l) {\n            g(j, k, l);\n            return {\n                remove: function() {\n                    h(j, k, l);\n                    j = null;\n                }\n            };\n        },\n        remove: h\n    };\n    e.exports = i;\n});\n__d(\"DOMPosition\", [\"DOMQuery\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOMQuery\"), h = {\n        getScrollPosition: function() {\n            var i = g.getDocumentScrollElement();\n            return {\n                x: i.scrollLeft,\n                y: i.scrollTop\n            };\n        },\n        getElementPosition: function(i) {\n            if (!i) {\n                return;\n            }\n        ;\n        ;\n            if (!((\"getBoundingClientRect\" in i))) {\n                return {\n                    x: 0,\n                    y: 0\n                };\n            }\n        ;\n        ;\n            var j = i.getBoundingClientRect(), k = JSBNG__document.documentElement, l = ((Math.round(j.left) - k.clientLeft)), m = ((Math.round(j.JSBNG__top) - k.clientTop));\n            return {\n                x: l,\n                y: m\n            };\n        }\n    };\n    e.exports = h;\n});\n__d(\"DimensionTracking\", [\"event-extensions\",\"AsyncSignal\",\"Cookie\",\"DOMDimensions\",\"Run\",\"isInIframe\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"AsyncSignal\"), h = b(\"Cookie\"), i = b(\"DOMDimensions\"), j = b(\"Run\"), k = b(\"isInIframe\");\n    function l() {\n        var m = i.getViewportDimensions();\n        h.set(\"wd\", ((((m.width + \"x\")) + m.height)));\n        if (((Math.JSBNG__random() < 39001))) {\n            new g(\"/ajax/dimension_context.php\", {\n                x: m.width,\n                y: m.height\n            }).send();\n        }\n    ;\n    ;\n    };\n;\n    if (!k()) {\n        j.JSBNG__onAfterLoad(function() {\n            JSBNG__setTimeout(l, 100);\n            JSBNG__Event.listen(window, \"resize\", l);\n            JSBNG__Event.listen(window, \"JSBNG__focus\", l);\n        });\n    }\n;\n;\n});\n__d(\"PrivacyConst\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\"), h = {\n        FRIENDS_MINUS_ACQUAINTANCES: 127,\n        FACEBOOK_EMPLOYEES: 112,\n        CUSTOM: 111,\n        EVERYONE: 80,\n        NETWORKS_FRIENDS_OF_FRIENDS: 60,\n        NETWORKS_FRIENDS: 55,\n        FRIENDS_OF_FRIENDS: 50,\n        ALL_FRIENDS: 40,\n        SELF: 10,\n        NOBODY: 0\n    }, i = {\n        EVERYONE: 80,\n        NETWORKS_FRIENDS: 55,\n        FRIENDS_OF_FRIENDS: 50,\n        ALL_FRIENDS: 40,\n        SOME_FRIENDS: 30,\n        SELF: 10,\n        NO_FRIENDS: 0\n    }, j = {\n        BaseValue: h,\n        FriendsValue: i\n    };\n    e.exports = j;\n});\n__d(\"ScriptPathState\", [\"Arbiter\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h, i, j, k, l = 100, m = {\n        setIsUIPageletRequest: function(n) {\n            j = n;\n        },\n        setUserURISampleRate: function(n) {\n            k = n;\n        },\n        reset: function() {\n            h = null;\n            i = false;\n            j = false;\n        },\n        _shouldUpdateScriptPath: ((window.top.JSBNG_Replay.push)((window.top.JSBNG_Replay.sec3f7c0a188503295a66a797eaa3892a5e54bc0e_273), function() {\n            return ((i && !j));\n        })),\n        _shouldSendURI: function() {\n            return ((Math.JSBNG__random() < k));\n        },\n        getParams: function() {\n            var n = {\n            };\n            if (m._shouldUpdateScriptPath()) {\n                if (((m._shouldSendURI() && ((h !== null))))) {\n                    n.user_uri = h.substring(0, l);\n                }\n            ;\n            ;\n            }\n             else n.no_script_path = 1;\n        ;\n        ;\n            return n;\n        }\n    };\n    g.subscribe(\"pre_page_transition\", function(n, o) {\n        i = true;\n        h = o.to.getUnqualifiedURI().toString();\n    });\n    e.exports = a.ScriptPathState = m;\n});\n__d(\"highlight\", [\"Animation\",\"Style\",], function(a, b, c, d, e, f) {\n    var g = b(\"Animation\"), h = b(\"Style\");\n    function i(j, k, l) {\n        new g(j).from(\"background\", \"#fff9d7\").to(\"background\", ((l || \"#fff\"))).ease(g.ease.both).duration(2000).JSBNG__ondone(function() {\n            h.set(j, \"background\", \"\");\n            ((k && k()));\n        }).go();\n    };\n;\n    e.exports = i;\n});\n__d(\"ScrollHighlight\", [\"DOMScroll\",\"highlight\",\"CSS\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOMScroll\"), h = b(\"highlight\"), i = b(\"CSS\"), j = {\n        actOn: function(k) {\n            g.JSBNG__scrollTo(k);\n            h(k, null, \"#EDEFF4\");\n            i.removeClass(k, \"highlightComment\");\n        }\n    };\n    e.exports = j;\n});\n__d(\"throttleAcrossTransitions\", [\"debounce\",], function(a, b, c, d, e, f) {\n    var g = b(\"debounce\");\n    function h(i, j, k) {\n        return g(i, j, k, true, true);\n    };\n;\n    e.exports = h;\n});\n__d(\"UserActionHistory\", [\"Arbiter\",\"ClickRefUtils\",\"throttleAcrossTransitions\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ClickRefUtils\"), i = b(\"throttleAcrossTransitions\"), j = {\n        click: 1,\n        submit: 1\n    }, k = false, l = {\n        log: [],\n        len: 0\n    }, m = i(function() {\n        try {\n            k._ua_log = JSON.stringify(l);\n        } catch (p) {\n            k = false;\n        };\n    ;\n    }, 1000);\n    function n() {\n        try {\n            if (a.JSBNG__sessionStorage) {\n                k = a.JSBNG__sessionStorage;\n                ((k._ua_log && (l = JSON.parse(k._ua_log))));\n            }\n        ;\n        ;\n        } catch (p) {\n            k = false;\n        };\n    ;\n        l.log[((l.len % 10))] = {\n            ts: JSBNG__Date.now(),\n            path: \"-\",\n            index: l.len,\n            type: \"init\",\n            iref: \"-\"\n        };\n        l.len++;\n        g.subscribe(\"UserAction/new\", function(q, r) {\n            var s = r.ua, t = r.node, JSBNG__event = r.JSBNG__event;\n            if (((!JSBNG__event || !((JSBNG__event.type in j))))) {\n                return;\n            }\n        ;\n        ;\n            var u = {\n                path: window._script_path,\n                type: JSBNG__event.type,\n                ts: s._ue_ts,\n                iref: ((h.get_intern_ref(t) || \"-\")),\n                index: l.len\n            };\n            l.log[((l.len++ % 10))] = u;\n            ((k && m()));\n        });\n    };\n;\n    function o() {\n        return l.log.sort(function(p, q) {\n            return ((((q.ts != p.ts)) ? ((q.ts - p.ts)) : ((q.index - p.index))));\n        });\n    };\n;\n    n();\n    e.exports = {\n        getHistory: o\n    };\n});\n__d(\"UserActivity\", [\"event-extensions\",\"Arbiter\",\"ClickRefUtils\",\"collectDataAttributes\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ClickRefUtils\"), i = b(\"collectDataAttributes\"), j = 5000, k = 500, l = JSBNG__Date.now(), m = l, n = {\n        subscribeOnce: function(p) {\n            var q = n.subscribe(function() {\n                n.unsubscribe(q);\n                p();\n            });\n        },\n        subscribe: function(p) {\n            return g.subscribe(\"useractivity/activity\", p);\n        },\n        unsubscribe: function(p) {\n            p.unsubscribe();\n        },\n        isActive: function(p) {\n            return ((((new JSBNG__Date() - l)) < ((p || n.DEFAULT_IDLE_MS))));\n        },\n        getLastInformTime: function() {\n            return m;\n        }\n    };\n    function o(JSBNG__event) {\n        l = JSBNG__Date.now();\n        var p = ((l - m));\n        if (((p > k))) {\n            m = l;\n            g.inform(\"useractivity/activity\", {\n                JSBNG__event: JSBNG__event,\n                idleness: p\n            });\n        }\n    ;\n    ;\n    };\n;\n    JSBNG__Event.listen(window, \"JSBNG__scroll\", o);\n    JSBNG__Event.listen(JSBNG__document.documentElement, {\n        DOMMouseScroll: o,\n        mousewheel: o,\n        keydown: o,\n        mouseover: o,\n        click: o\n    });\n    e.exports = n;\n});\n__d(\"bind\", [], function(a, b, c, d, e, f) {\n    function g(h, i) {\n        var j = Array.prototype.slice.call(arguments, 2);\n        if (((typeof i != \"string\"))) {\n            return Function.prototype.bind.apply(i, [h,].concat(j));\n        }\n    ;\n    ;\n        function k() {\n            var l = j.concat(Array.prototype.slice.call(arguments));\n            if (h[i]) {\n                return h[i].apply(h, l);\n            }\n        ;\n        ;\n        };\n    ;\n        k.toString = function() {\n            return ((\"bound lazily: \" + h[i]));\n        };\n        return k;\n    };\n;\n    e.exports = g;\n});\n__d(\"coalesce\", [], function(a, b, c, d, e, f) {\n    function g() {\n        for (var h = 0; ((h < arguments.length)); ++h) {\n            if (((arguments[h] != null))) {\n                return arguments[h];\n            }\n        ;\n        ;\n        };\n    ;\n        return null;\n    };\n;\n    e.exports = g;\n});\n__d(\"endsWith\", [], function(a, b, c, d, e, f) {\n    function g(h, i) {\n        return ((h.indexOf(i, ((h.length - i.length))) > -1));\n    };\n;\n    e.exports = g;\n});\n__d(\"curry\", [\"bind\",], function(a, b, c, d, e, f) {\n    var g = b(\"bind\"), h = g(null, g, null);\n    e.exports = h;\n});\n__d(\"reportData\", [\"EagleEye\",\"userAction\",], function(a, b, c, d, e, f) {\n    var g = b(\"EagleEye\"), h = b(\"userAction\");\n    function i(j, k) {\n        k = ((k || {\n        }));\n        var l = {\n            ft: ((k.ft || {\n            })),\n            gt: ((k.gt || {\n            }))\n        }, m = \"-\", n = a.ArbiterMonitor, o = (((!!n) ? n.getActFields() : [])), p = (((!n) ? \"r\" : \"a\")), q = [JSBNG__Date.now(),h.getCurrentUECount(),m,j,m,m,p,((a.URI ? a.URI.getRequestURI(true, true).getUnqualifiedURI().toString() : ((((JSBNG__location.pathname + JSBNG__location.search)) + JSBNG__location.hash)))),l,0,0,0,0,].concat(o);\n        g.log(\"act\", q);\n    };\n;\n    e.exports = i;\n});");
// 2604
JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_84[0](o14,false,o20);
// undefined
o14 = null;
// undefined
o20 = null;
// 2608
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"bS0QP\",]);\n}\n;\n__d(\"AsyncDOM\", [\"CSS\",\"DOM\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = {\n        invoke: function(j, k) {\n            for (var l = 0; (l < j.length); ++l) {\n                var m = j[l], n = m[0], o = m[1], p = m[2], q = m[3], r = (((p && k)) || null);\n                if (o) {\n                    r = h.scry((r || document.documentElement), o)[0];\n                };\n                switch (n) {\n                  case \"eval\":\n                    (new Function(q)).apply(r);\n                    break;\n                  case \"hide\":\n                    g.hide(r);\n                    break;\n                  case \"show\":\n                    g.show(r);\n                    break;\n                  case \"setContent\":\n                    h.setContent(r, q);\n                    break;\n                  case \"appendContent\":\n                    h.appendContent(r, q);\n                    break;\n                  case \"prependContent\":\n                    h.prependContent(r, q);\n                    break;\n                  case \"insertAfter\":\n                    h.insertAfter(r, q);\n                    break;\n                  case \"insertBefore\":\n                    h.insertBefore(r, q);\n                    break;\n                  case \"remove\":\n                    h.remove(r);\n                    break;\n                  case \"replace\":\n                    h.replace(r, q);\n                    break;\n                  default:\n                \n                };\n            };\n        }\n    };\n    e.exports = i;\n});\n__d(\"AsyncResponse\", [\"Bootloader\",\"Env\",\"copyProperties\",\"tx\",], function(a, b, c, d, e, f) {\n    var g = b(\"Bootloader\"), h = b(\"Env\"), i = b(\"copyProperties\"), j = b(\"tx\");\n    function k(l, m) {\n        i(this, {\n            error: 0,\n            errorSummary: null,\n            errorDescription: null,\n            onload: null,\n            replay: false,\n            payload: (m || null),\n            request: (l || null),\n            silentError: false,\n            is_last: true\n        });\n        return this;\n    };\n    i(k, {\n        defaultErrorHandler: function(l) {\n            try {\n                if (!l.silentError) {\n                    k.verboseErrorHandler(l);\n                }\n                 else l.logErrorByGroup(\"silent\", 10);\n            ;\n            } catch (m) {\n                alert(l);\n            };\n        },\n        verboseErrorHandler: function(l) {\n            try {\n                var n = l.getErrorSummary(), o = l.getErrorDescription();\n                l.logErrorByGroup(\"popup\", 10);\n                if ((l.silentError && (o == \"\"))) {\n                    o = \"Something went wrong. We're working on getting this fixed as soon as we can. You may be able to try again.\";\n                };\n                g.loadModules([\"Dialog\",], function(p) {\n                    new p().setTitle(n).setBody(o).setButtons([p.OK,]).setModal(true).setCausalElement(this.relativeTo).show();\n                });\n            } catch (m) {\n                alert(l);\n            };\n        }\n    });\n    i(k.prototype, {\n        getRequest: function() {\n            return this.request;\n        },\n        getPayload: function() {\n            return this.payload;\n        },\n        getError: function() {\n            return this.error;\n        },\n        getErrorSummary: function() {\n            return this.errorSummary;\n        },\n        setErrorSummary: function(l) {\n            l = (((l === undefined) ? null : l));\n            this.errorSummary = l;\n            return this;\n        },\n        getErrorDescription: function() {\n            return this.errorDescription;\n        },\n        getErrorIsWarning: function() {\n            return this.errorIsWarning;\n        },\n        logError: function(l, m) {\n            if (window.send_error_signal) {\n                var n = {\n                    err_code: this.error,\n                    vip: ((h.vip || \"-\"))\n                };\n                if (m) {\n                    n.duration = m.duration;\n                    n.xfb_ip = m.xfb_ip;\n                }\n            ;\n                var o = this.request.getURI();\n                n.path = (o || \"-\");\n                n.aid = this.request.userActionID;\n                if ((o && (o.indexOf(\"scribe_endpoint.php\") != -1))) {\n                    l = \"async_error_double\";\n                };\n                send_error_signal(l, JSON.stringify(n));\n            }\n        ;\n        },\n        logErrorByGroup: function(l, m) {\n            if ((Math.floor((Math.random() * m)) == 0)) {\n                if (((this.error == 1357010) || (this.error < 15000))) {\n                    this.logError((\"async_error_oops_\" + l));\n                }\n                 else this.logError((\"async_error_logic_\" + l));\n            \n            };\n        }\n    });\n    e.exports = k;\n});\n__d(\"HTTPErrors\", [], function(a, b, c, d, e, f) {\n    var g = {\n        get: bagofholding,\n        getAll: bagofholding\n    };\n    e.exports = g;\n});\n__d(\"AsyncRequest\", [\"event-extensions\",\"Arbiter\",\"AsyncDOM\",\"AsyncResponse\",\"Bootloader\",\"CSS\",\"Env\",\"HTTPErrors\",\"JSCC\",\"Parent\",\"Run\",\"ServerJS\",\"URI\",\"UserAgent\",\"XHR\",\"bind\",\"copyProperties\",\"evalGlobal\",\"ge\",\"goURI\",\"isEmpty\",\"tx\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"AsyncDOM\"), i = b(\"AsyncResponse\"), j = b(\"Bootloader\"), k = b(\"CSS\"), l = b(\"Env\"), m = b(\"HTTPErrors\"), n = b(\"JSCC\"), o = b(\"Parent\"), p = b(\"Run\"), q = b(\"ServerJS\"), r = b(\"URI\"), s = b(\"UserAgent\"), t = b(\"XHR\"), u = b(\"bind\"), v = b(\"copyProperties\"), w = b(\"evalGlobal\"), x = b(\"ge\"), y = b(\"goURI\"), z = b(\"isEmpty\"), aa = b(\"tx\");\n    function ba() {\n        try {\n            return !window.loaded;\n        } catch (ka) {\n            return true;\n        };\n    };\n    function ca(ka) {\n        return (((\"upload\" in ka)) && ((\"onprogress\" in ka.upload)));\n    };\n    function da(ka) {\n        return (\"withCredentials\" in ka);\n    };\n    function ea(ka) {\n        return (ka.status in {\n            0: 1,\n            12029: 1,\n            12030: 1,\n            12031: 1,\n            12152: 1\n        });\n    };\n    function fa(ka) {\n        var la = (!ka || (typeof (ka) === \"function\"));\n        return la;\n    };\n    var ga = 2, ha = ga;\n    g.subscribe(\"page_transition\", function(ka, la) {\n        ha = la.id;\n    });\n    function ia(ka) {\n        v(this, {\n            transport: null,\n            method: \"POST\",\n            uri: \"\",\n            timeout: null,\n            timer: null,\n            initialHandler: bagofholding,\n            handler: null,\n            uploadProgressHandler: null,\n            errorHandler: null,\n            transportErrorHandler: null,\n            timeoutHandler: null,\n            interceptHandler: bagofholding,\n            finallyHandler: bagofholding,\n            abortHandler: bagofholding,\n            serverDialogCancelHandler: null,\n            relativeTo: null,\n            statusElement: null,\n            statusClass: \"\",\n            data: {\n            },\n            file: null,\n            context: {\n            },\n            readOnly: false,\n            writeRequiredParams: [],\n            remainingRetries: 0,\n            userActionID: \"-\"\n        });\n        this.option = {\n            asynchronous: true,\n            suppressErrorHandlerWarning: false,\n            suppressEvaluation: false,\n            suppressErrorAlerts: false,\n            retries: 0,\n            jsonp: false,\n            bundle: false,\n            useIframeTransport: false,\n            handleErrorAfterUnload: false\n        };\n        this.errorHandler = i.defaultErrorHandler;\n        this.transportErrorHandler = u(this, \"errorHandler\");\n        if ((ka !== undefined)) {\n            this.setURI(ka);\n        };\n    };\n    v(ia, {\n        bootstrap: function(ka, la, ma) {\n            var na = \"GET\", oa = true, pa = {\n            };\n            if ((ma || (la && (((la.rel == \"async-post\") || (la.getAttribute && (la.getAttribute(\"forcemethod\") == \"post\"))))))) {\n                na = \"POST\";\n                oa = false;\n                if (ka) {\n                    ka = r(ka);\n                    pa = ka.getQueryData();\n                    ka.setQueryData({\n                    });\n                }\n            ;\n            }\n        ;\n            var qa = (o.byClass(la, \"stat_elem\") || la);\n            if ((qa && k.hasClass(qa, \"async_saving\"))) {\n                return false\n            };\n            var ra = new ia(ka).setReadOnly(oa).setMethod(na).setData(pa).setNectarModuleDataSafe(la).setRelativeTo(la);\n            if (la) {\n                ra.setHandler(function(ta) {\n                    Event.fire(la, \"success\", {\n                        response: ta\n                    });\n                });\n                ra.setErrorHandler(function(ta) {\n                    if ((Event.fire(la, \"error\", {\n                        response: ta\n                    }) !== false)) {\n                        i.defaultErrorHandler(ta);\n                    };\n                });\n            }\n        ;\n            if (qa) {\n                ra.setStatusElement(qa);\n                var sa = qa.getAttribute(\"data-status-class\");\n                (sa && ra.setStatusClass(sa));\n            }\n        ;\n            if (la) {\n                Event.fire(la, \"AsyncRequest/send\", {\n                    request: ra\n                });\n            };\n            ra.send();\n            return false;\n        },\n        post: function(ka, la) {\n            new ia(ka).setReadOnly(false).setMethod(\"POST\").setData(la).send();\n            return false;\n        },\n        getLastID: function() {\n            return ga;\n        },\n        suppressOnloadToken: {\n        },\n        _inflight: [],\n        _inflightCount: 0,\n        _inflightAdd: bagofholding,\n        _inflightPurge: bagofholding,\n        getInflightCount: function() {\n            return this._inflightCount;\n        },\n        _inflightEnable: function() {\n            if (s.ie()) {\n                v(ia, {\n                    _inflightAdd: function(ka) {\n                        this._inflight.push(ka);\n                    },\n                    _inflightPurge: function() {\n                        ia._inflight = ia._inflight.filter(function(ka) {\n                            return (ka.transport && (ka.transport.readyState < 4));\n                        });\n                    }\n                });\n                p.onUnload(function() {\n                    ia._inflight.forEach(function(ka) {\n                        if ((ka.transport && (ka.transport.readyState < 4))) {\n                            ka.transport.abort();\n                            delete ka.transport;\n                        }\n                    ;\n                    });\n                });\n            }\n        ;\n        }\n    });\n    v(ia.prototype, {\n        _dispatchResponse: function(ka) {\n            try {\n                this.clearStatusIndicator();\n                if (!this._isRelevant()) {\n                    this._invokeErrorHandler(1010);\n                    return;\n                }\n            ;\n                if ((this.initialHandler(ka) === false)) {\n                    return\n                };\n                clearTimeout(this.timer);\n                if (ka.jscc_map) {\n                    var ma = (eval)(ka.jscc_map);\n                    n.init(ma);\n                }\n            ;\n                var na;\n                if (this.handler) {\n                    try {\n                        na = this._shouldSuppressJS(this.handler(ka));\n                    } catch (oa) {\n                        (ka.is_last && this.finallyHandler(ka));\n                        throw oa;\n                    }\n                };\n                if (!na) {\n                    this._handleJSResponse(ka);\n                };\n                (ka.is_last && this.finallyHandler(ka));\n            } catch (la) {\n            \n            };\n        },\n        _shouldSuppressJS: function(ka) {\n            return (ka === ia.suppressOnloadToken);\n        },\n        _handleJSResponse: function(ka) {\n            var la = this.getRelativeTo(), ma = ka.domops, na = ka.jsmods, oa = new q().setRelativeTo(la);\n            if ((na && (((na.define || na.instances) || na.markup)))) {\n                oa.handle({\n                    define: na.define,\n                    instances: na.instances,\n                    markup: na.markup\n                });\n                delete na.define;\n                delete na.instances;\n                delete na.markup;\n            }\n        ;\n            if (ma) {\n                h.invoke(ma, la);\n            };\n            if (na) {\n                oa.handle(na);\n            };\n            this._handleJSRegisters(ka, \"onload\");\n            if (this.lid) {\n                g.inform(\"tti_ajax\", {\n                    s: this.lid,\n                    d: [(this._sendTimeStamp || 0),(((this._sendTimeStamp && this._responseTime)) ? ((this._responseTime - this._sendTimeStamp)) : 0),]\n                }, g.BEHAVIOR_EVENT);\n            };\n            this._handleJSRegisters(ka, \"onafterload\");\n        },\n        _handleJSRegisters: function(ka, la) {\n            var ma = ka[la];\n            if (!ma) {\n                return\n            };\n            for (var na = 0; (na < ma.length); na++) {\n                try {\n                    (new Function(ma[na])).apply(this);\n                } catch (oa) {\n                \n                };\n            };\n        },\n        invokeResponseHandler: function(ka) {\n            if ((typeof (ka.redirect) !== \"undefined\")) {\n                (function() {\n                    this.setURI(ka.redirect).send();\n                }).bind(this).defer();\n                return;\n            }\n        ;\n            if (((!this.handler && !this.errorHandler) && !this.transportErrorHandler)) {\n                return\n            };\n            if ((typeof (ka.asyncResponse) !== \"undefined\")) {\n                if (!this._isRelevant()) {\n                    this._invokeErrorHandler(1010);\n                    return;\n                }\n            ;\n                var la = ka.asyncResponse;\n                if (la.inlinejs) {\n                    w(la.inlinejs);\n                };\n                if (la.lid) {\n                    this._responseTime = Date.now();\n                    if (a.CavalryLogger) {\n                        this.cavalry = a.CavalryLogger.getInstance(la.lid);\n                    };\n                    this.lid = la.lid;\n                }\n            ;\n                j.setResourceMap(la.resource_map);\n                if (la.bootloadable) {\n                    j.enableBootload(la.bootloadable);\n                };\n                var ma;\n                if ((la.getError() && !la.getErrorIsWarning())) {\n                    var na = this.errorHandler.bind(this);\n                    ma = this._dispatchErrorResponse.bind(this, la, na);\n                }\n                 else ma = this._dispatchResponse.bind(this, la);\n            ;\n                ma = ma.defer.bind(ma);\n                var oa = false;\n                if (this.preBootloadHandler) {\n                    oa = this.preBootloadHandler(la);\n                };\n                la.css = (la.css || []);\n                la.js = (la.js || []);\n                j.loadResources(la.css.concat(la.js), ma, oa, this.getURI());\n            }\n             else if ((typeof (ka.transportError) !== \"undefined\")) {\n                if (this._xFbServer) {\n                    this._invokeErrorHandler(1008);\n                }\n                 else this._invokeErrorHandler(1012);\n            ;\n            }\n             else this._invokeErrorHandler(1007);\n            \n        ;\n        },\n        _invokeErrorHandler: function(ka) {\n            if ((ba() && !this.getOption(\"handleErrorAfterUnload\"))) {\n                return\n            };\n            var la;\n            if ((this.responseText === \"\")) {\n                la = 1002;\n            }\n             else if (this._requestAborted) {\n                la = 1011;\n            }\n             else {\n                try {\n                    la = ((ka || this.transport.status) || 1004);\n                } catch (ma) {\n                    la = 1005;\n                };\n                if ((false === navigator.onLine)) {\n                    la = 1006;\n                };\n            }\n            \n        ;\n            if (!this.transportErrorHandler) {\n                return\n            };\n            var na = this.transportErrorHandler.bind(this), oa, pa, qa = true;\n            if ((la === 1006)) {\n                pa = \"No Network Connection\";\n                oa = \"Your browser appears to be offline. Please check your internet connection and try again.\";\n            }\n             else if (((la >= 300) && (la <= 399))) {\n                pa = \"Redirection\";\n                oa = \"Your access to Facebook was redirected or blocked by a third party at this time, please contact your ISP or reload. \";\n                var ra = this.transport.getResponseHeader(\"Location\");\n                if (ra) {\n                    y(ra, true);\n                };\n                qa = true;\n            }\n             else {\n                pa = \"Oops\";\n                oa = \"Something went wrong. We're working on getting this fixed as soon as we can. You may be able to try again.\";\n            }\n            \n        ;\n            !this.getOption(\"suppressErrorAlerts\");\n            var sa = new i(this);\n            v(sa, {\n                error: la,\n                errorSummary: pa,\n                errorDescription: oa,\n                silentError: qa\n            });\n            this._dispatchErrorResponse(sa, na);\n        },\n        _dispatchErrorResponse: function(ka, la) {\n            var ma = ka.getError();\n            try {\n                this.clearStatusIndicator();\n                var oa = (this._sendTimeStamp && {\n                    duration: (Date.now() - this._sendTimeStamp),\n                    xfb_ip: (this._xFbServer || \"-\")\n                });\n                ka.logError(\"async_error\", oa);\n                if ((!this._isRelevant() || (ma === 1010))) {\n                    this.abort();\n                    return;\n                }\n            ;\n                if (((((ma == 1357008) || (ma == 1357007)) || (ma == 1442002)) || (ma == 1357001))) {\n                    var pa = ((ma == 1357008) || (ma == 1357007));\n                    this.interceptHandler(ka);\n                    this._displayServerDialog(ka, pa);\n                }\n                 else if ((this.initialHandler(ka) !== false)) {\n                    clearTimeout(this.timer);\n                    try {\n                        la(ka);\n                    } catch (qa) {\n                        this.finallyHandler(ka);\n                        throw qa;\n                    };\n                    this.finallyHandler(ka);\n                }\n                \n            ;\n            } catch (na) {\n            \n            };\n        },\n        _displayServerDialog: function(ka, la) {\n            var ma = ka.getPayload();\n            if ((ma.__dialog !== undefined)) {\n                this._displayServerLegacyDialog(ka, la);\n                return;\n            }\n        ;\n            var na = ma.__dialogx;\n            new q().handle(na);\n            j.loadModules([\"ConfirmationDialog\",], function(oa) {\n                oa.setupConfirmation(ka, this);\n            }.bind(this));\n        },\n        _displayServerLegacyDialog: function(ka, la) {\n            var ma = ka.getPayload().__dialog;\n            j.loadModules([\"Dialog\",], function(na) {\n                var oa = new na(ma);\n                if (la) {\n                    oa.setHandler(this._displayConfirmationHandler.bind(this, oa));\n                };\n                oa.setCancelHandler(function() {\n                    var pa = this.getServerDialogCancelHandler();\n                    try {\n                        (pa && pa(ka));\n                    } catch (qa) {\n                        throw qa;\n                    } finally {\n                        this.finallyHandler(ka);\n                    };\n                }.bind(this)).setCausalElement(this.relativeTo).show();\n            }.bind(this));\n        },\n        _displayConfirmationHandler: function(ka) {\n            this.data.confirmed = 1;\n            v(this.data, ka.getFormData());\n            this.send();\n        },\n        _handleJSONPResponse: function(ka) {\n            this.is_first = ((this.is_first === undefined));\n            var la = this._interpretResponse(ka);\n            la.asyncResponse.is_first = this.is_first;\n            la.asyncResponse.is_last = this.transport.hasFinished();\n            this.invokeResponseHandler(la);\n            if (this.transport.hasFinished()) {\n                delete this.transport;\n            };\n        },\n        _handleXHRResponse: function(ka) {\n            var la;\n            if (this.getOption(\"suppressEvaluation\")) {\n                la = {\n                    asyncResponse: new i(this, ka)\n                };\n            }\n             else {\n                var ma = ka.responseText, na = null;\n                try {\n                    var pa = this._unshieldResponseText(ma);\n                    try {\n                        var qa = (eval)(((\"(\" + pa) + \")\"));\n                        la = this._interpretResponse(qa);\n                    } catch (oa) {\n                        na = \"excep\";\n                        la = {\n                            transportError: (\"eval() failed on async to \" + this.getURI())\n                        };\n                    };\n                } catch (oa) {\n                    na = \"empty\";\n                    la = {\n                        transportError: oa.message\n                    };\n                };\n                if (na) {\n                    (a.send_error_signal && a.send_error_signal(\"async_xport_resp\", [(((this._xFbServer ? \"1008_\" : \"1012_\")) + na),(this._xFbServer || \"-\"),this.getURI(),ma.length,ma.substr(0, 1600),].join(\":\")));\n                };\n            }\n        ;\n            this.invokeResponseHandler(la);\n        },\n        _unshieldResponseText: function(ka) {\n            var la = \"for (;;);\", ma = la.length;\n            if ((ka.length <= ma)) {\n                throw new Error((\"Response too short on async to \" + this.getURI()))\n            };\n            var na = 0;\n            while (((ka.charAt(na) == \" \") || (ka.charAt(na) == \"\\u000a\"))) {\n                na++;;\n            };\n            (na && (ka.substring(na, (na + ma)) == la));\n            return ka.substring((na + ma));\n        },\n        _interpretResponse: function(ka) {\n            if (ka.redirect) {\n                return {\n                    redirect: ka.redirect\n                }\n            };\n            var la = new i(this);\n            if ((ka.__ar != 1)) {\n                la.payload = ka;\n            }\n             else v(la, ka);\n        ;\n            return {\n                asyncResponse: la\n            };\n        },\n        _onStateChange: function() {\n            try {\n                if ((this.transport.readyState == 4)) {\n                    ia._inflightCount--;\n                    ia._inflightPurge();\n                    try {\n                        if (((typeof (this.transport.getResponseHeader) !== \"undefined\") && this.transport.getResponseHeader(\"X-FB-Debug\"))) {\n                            this._xFbServer = this.transport.getResponseHeader(\"X-FB-Debug\");\n                        };\n                    } catch (la) {\n                    \n                    };\n                    if (((this.transport.status >= 200) && (this.transport.status < 300))) {\n                        ia.lastSuccessTime = Date.now();\n                        this._handleXHRResponse(this.transport);\n                    }\n                     else if ((s.safari() && ((typeof (this.transport.status) == \"undefined\")))) {\n                        this._invokeErrorHandler(1002);\n                    }\n                     else if (((l.retry_ajax_on_network_error && ea(this.transport)) && (this.remainingRetries > 0))) {\n                        this.remainingRetries--;\n                        delete this.transport;\n                        this.send(true);\n                        return;\n                    }\n                     else this._invokeErrorHandler();\n                    \n                    \n                ;\n                    if ((this.getOption(\"asynchronous\") !== false)) {\n                        delete this.transport;\n                    };\n                }\n            ;\n            } catch (ka) {\n                if (ba()) {\n                    return\n                };\n                delete this.transport;\n                if ((this.remainingRetries > 0)) {\n                    this.remainingRetries--;\n                    this.send(true);\n                }\n                 else {\n                    !this.getOption(\"suppressErrorAlerts\");\n                    (a.send_error_signal && a.send_error_signal(\"async_xport_resp\", [1007,(this._xFbServer || \"-\"),this.getURI(),ka.message,].join(\":\")));\n                    this._invokeErrorHandler(1007);\n                }\n            ;\n            };\n        },\n        _isMultiplexable: function() {\n            if ((this.getOption(\"jsonp\") || this.getOption(\"useIframeTransport\"))) {\n                return false\n            };\n            if (!this.uri.isFacebookURI()) {\n                return false\n            };\n            if (!this.getOption(\"asynchronous\")) {\n                return false\n            };\n            return true;\n        },\n        handleResponse: function(ka) {\n            var la = this._interpretResponse(ka);\n            this.invokeResponseHandler(la);\n        },\n        setMethod: function(ka) {\n            this.method = ka.toString().toUpperCase();\n            return this;\n        },\n        getMethod: function() {\n            return this.method;\n        },\n        setData: function(ka) {\n            this.data = ka;\n            return this;\n        },\n        _setDataHash: function() {\n            if (((this.method != \"POST\") || this.data.phstamp)) {\n                return\n            };\n            var ka = r.implodeQuery(this.data).length, la = \"\";\n            for (var ma = 0; (ma < this.data.fb_dtsg.length); ma++) {\n                la += this.data.fb_dtsg.charCodeAt(ma);;\n            };\n            this.data.phstamp = ((\"1\" + la) + ka);\n        },\n        setRawData: function(ka) {\n            this.rawData = ka;\n            return this;\n        },\n        getData: function() {\n            return this.data;\n        },\n        setContextData: function(ka, la, ma) {\n            ma = ((ma === undefined) ? true : ma);\n            if (ma) {\n                this.context[(\"_log_\" + ka)] = la;\n            };\n            return this;\n        },\n        _setUserActionID: function() {\n            var ka = ((a.ArbiterMonitor && a.ArbiterMonitor.getUE()) || \"-\");\n            this.userActionID = (((((a.EagleEye && a.EagleEye.getSessionID()) || \"-\")) + \"/\") + ka);\n        },\n        setURI: function(ka) {\n            var la = r(ka);\n            if ((this.getOption(\"useIframeTransport\") && !la.isFacebookURI())) {\n                return this\n            };\n            if ((((!this._allowCrossOrigin && !this.getOption(\"jsonp\")) && !this.getOption(\"useIframeTransport\")) && !la.isSameOrigin())) {\n                return this\n            };\n            this._setUserActionID();\n            if ((!ka || la.isEmpty())) {\n                if ((a.send_error_signal && a.get_error_stack)) {\n                    var ma = {\n                        err_code: 1013,\n                        vip: \"-\",\n                        duration: 0,\n                        xfb_ip: \"-\",\n                        path: window.location.href,\n                        aid: this.userActionID\n                    };\n                    a.send_error_signal(\"async_error\", JSON.stringify(ma));\n                    a.send_error_signal(\"async_xport_stack\", [1013,window.location.href,null,a.get_error_stack(),].join(\":\"));\n                }\n            ;\n                return this;\n            }\n        ;\n            this.uri = la;\n            return this;\n        },\n        getURI: function() {\n            return this.uri.toString();\n        },\n        setInitialHandler: function(ka) {\n            this.initialHandler = ka;\n            return this;\n        },\n        setHandler: function(ka) {\n            if (fa(ka)) {\n                this.handler = ka;\n            };\n            return this;\n        },\n        getHandler: function() {\n            return this.handler;\n        },\n        setUploadProgressHandler: function(ka) {\n            if (fa(ka)) {\n                this.uploadProgressHandler = ka;\n            };\n            return this;\n        },\n        setErrorHandler: function(ka) {\n            if (fa(ka)) {\n                this.errorHandler = ka;\n            };\n            return this;\n        },\n        setTransportErrorHandler: function(ka) {\n            this.transportErrorHandler = ka;\n            return this;\n        },\n        getErrorHandler: function() {\n            return this.errorHandler;\n        },\n        getTransportErrorHandler: function() {\n            return this.transportErrorHandler;\n        },\n        setTimeoutHandler: function(ka, la) {\n            if (fa(la)) {\n                this.timeout = ka;\n                this.timeoutHandler = la;\n            }\n        ;\n            return this;\n        },\n        resetTimeout: function(ka) {\n            if (!((this.timeoutHandler === null))) {\n                if ((ka === null)) {\n                    this.timeout = null;\n                    clearTimeout(this.timer);\n                    this.timer = null;\n                }\n                 else {\n                    var la = !this._allowCrossPageTransition;\n                    this.timeout = ka;\n                    clearTimeout(this.timer);\n                    this.timer = this._handleTimeout.bind(this).defer(this.timeout, la);\n                }\n            \n            };\n            return this;\n        },\n        _handleTimeout: function() {\n            this.abandon();\n            this.timeoutHandler(this);\n        },\n        setNewSerial: function() {\n            this.id = ++ga;\n            return this;\n        },\n        setInterceptHandler: function(ka) {\n            this.interceptHandler = ka;\n            return this;\n        },\n        setFinallyHandler: function(ka) {\n            this.finallyHandler = ka;\n            return this;\n        },\n        setAbortHandler: function(ka) {\n            this.abortHandler = ka;\n            return this;\n        },\n        getServerDialogCancelHandler: function() {\n            return this.serverDialogCancelHandler;\n        },\n        setServerDialogCancelHandler: function(ka) {\n            this.serverDialogCancelHandler = ka;\n            return this;\n        },\n        setPreBootloadHandler: function(ka) {\n            this.preBootloadHandler = ka;\n            return this;\n        },\n        setReadOnly: function(ka) {\n            if (!((typeof (ka) != \"boolean\"))) {\n                this.readOnly = ka;\n            };\n            return this;\n        },\n        setFBMLForm: function() {\n            this.writeRequiredParams = [\"fb_sig\",];\n            return this;\n        },\n        getReadOnly: function() {\n            return this.readOnly;\n        },\n        setRelativeTo: function(ka) {\n            this.relativeTo = ka;\n            return this;\n        },\n        getRelativeTo: function() {\n            return this.relativeTo;\n        },\n        setStatusClass: function(ka) {\n            this.statusClass = ka;\n            return this;\n        },\n        setStatusElement: function(ka) {\n            this.statusElement = ka;\n            return this;\n        },\n        getStatusElement: function() {\n            return x(this.statusElement);\n        },\n        _isRelevant: function() {\n            if (this._allowCrossPageTransition) {\n                return true\n            };\n            if (!this.id) {\n                return true\n            };\n            return (this.id > ha);\n        },\n        clearStatusIndicator: function() {\n            var ka = this.getStatusElement();\n            if (ka) {\n                k.removeClass(ka, \"async_saving\");\n                k.removeClass(ka, this.statusClass);\n            }\n        ;\n        },\n        addStatusIndicator: function() {\n            var ka = this.getStatusElement();\n            if (ka) {\n                k.addClass(ka, \"async_saving\");\n                k.addClass(ka, this.statusClass);\n            }\n        ;\n        },\n        specifiesWriteRequiredParams: function() {\n            return this.writeRequiredParams.every(function(ka) {\n                this.data[ka] = ((this.data[ka] || l[ka]) || ((x(ka) || {\n                })).value);\n                if ((this.data[ka] !== undefined)) {\n                    return true\n                };\n                return false;\n            }, this);\n        },\n        setOption: function(ka, la) {\n            if ((typeof (this.option[ka]) != \"undefined\")) {\n                this.option[ka] = la;\n            };\n            return this;\n        },\n        getOption: function(ka) {\n            (typeof (this.option[ka]) == \"undefined\");\n            return this.option[ka];\n        },\n        abort: function() {\n            if (this.transport) {\n                var ka = this.getTransportErrorHandler();\n                this.setOption(\"suppressErrorAlerts\", true);\n                this.setTransportErrorHandler(bagofholding);\n                this._requestAborted = true;\n                this.transport.abort();\n                this.setTransportErrorHandler(ka);\n            }\n        ;\n            this.abortHandler();\n        },\n        abandon: function() {\n            clearTimeout(this.timer);\n            this.setOption(\"suppressErrorAlerts\", true).setHandler(bagofholding).setErrorHandler(bagofholding).setTransportErrorHandler(bagofholding);\n            if (this.transport) {\n                this._requestAborted = true;\n                this.transport.abort();\n            }\n        ;\n        },\n        setNectarData: function(ka) {\n            if (ka) {\n                if ((this.data.nctr === undefined)) {\n                    this.data.nctr = {\n                    };\n                };\n                v(this.data.nctr, ka);\n            }\n        ;\n            return this;\n        },\n        setNectarModuleDataSafe: function(ka) {\n            if (this.setNectarModuleData) {\n                this.setNectarModuleData(ka);\n            };\n            return this;\n        },\n        setNectarImpressionIdSafe: function() {\n            if (this.setNectarImpressionId) {\n                this.setNectarImpressionId();\n            };\n            return this;\n        },\n        setAllowCrossPageTransition: function(ka) {\n            this._allowCrossPageTransition = !!ka;\n            if (this.timer) {\n                this.resetTimeout(this.timeout);\n            };\n            return this;\n        },\n        setAllowCrossOrigin: function(ka) {\n            this._allowCrossOrigin = !!ka;\n            return this;\n        },\n        send: function(ka) {\n            ka = (ka || false);\n            if (!this.uri) {\n                return false\n            };\n            (!this.errorHandler && !this.getOption(\"suppressErrorHandlerWarning\"));\n            if ((this.getOption(\"jsonp\") && (this.method != \"GET\"))) {\n                this.setMethod(\"GET\");\n            };\n            if ((this.getOption(\"useIframeTransport\") && (this.method != \"GET\"))) {\n                this.setMethod(\"GET\");\n            };\n            ((this.timeoutHandler !== null) && ((this.getOption(\"jsonp\") || this.getOption(\"useIframeTransport\"))));\n            if (!this.getReadOnly()) {\n                this.specifiesWriteRequiredParams();\n                if ((this.method != \"POST\")) {\n                    return false\n                };\n            }\n        ;\n            v(this.data, t.getAsyncParams(this.method));\n            if (!z(this.context)) {\n                v(this.data, this.context);\n                this.data.ajax_log = 1;\n            }\n        ;\n            if (l.force_param) {\n                v(this.data, l.force_param);\n            };\n            this._setUserActionID();\n            if ((this.getOption(\"bundle\") && this._isMultiplexable())) {\n                ja.schedule(this);\n                return true;\n            }\n        ;\n            this.setNewSerial();\n            if (!this.getOption(\"asynchronous\")) {\n                this.uri.addQueryData({\n                    __s: 1\n                });\n            };\n            this.finallyHandler = a.async_callback(this.finallyHandler, \"final\");\n            var la, ma;\n            if (((this.method == \"GET\") || this.rawData)) {\n                la = this.uri.addQueryData(this.data).toString();\n                ma = (this.rawData || \"\");\n            }\n             else {\n                la = this.uri.toString();\n                this._setDataHash();\n                ma = r.implodeQuery(this.data);\n            }\n        ;\n            if (this.transport) {\n                return false\n            };\n            if ((this.getOption(\"jsonp\") || this.getOption(\"useIframeTransport\"))) {\n                d([\"JSONPTransport\",], function(qa) {\n                    this.transport = new qa((this.getOption(\"jsonp\") ? \"jsonp\" : \"iframe\"), this.uri, this._handleJSONPResponse.bind(this));\n                    this.transport.send();\n                }.bind(this));\n                return true;\n            }\n        ;\n            var na = t.create();\n            if (!na) {\n                return false\n            };\n            na.onreadystatechange = a.async_callback(this._onStateChange.bind(this), \"xhr\");\n            if ((this.uploadProgressHandler && ca(na))) {\n                na.upload.onprogress = this.uploadProgressHandler.bind(this);\n            };\n            if (!ka) {\n                this.remainingRetries = this.getOption(\"retries\");\n            };\n            if ((a.send_error_signal || a.ArbiterMonitor)) {\n                this._sendTimeStamp = (this._sendTimeStamp || Date.now());\n            };\n            this.transport = na;\n            try {\n                this.transport.open(this.method, la, this.getOption(\"asynchronous\"));\n            } catch (oa) {\n                return false;\n            };\n            var pa = l.svn_rev;\n            if (pa) {\n                this.transport.setRequestHeader(\"X-SVN-Rev\", String(pa));\n            };\n            if (((!this.uri.isSameOrigin() && !this.getOption(\"jsonp\")) && !this.getOption(\"useIframeTransport\"))) {\n                if (!da(this.transport)) {\n                    return false\n                };\n                if (this.uri.isFacebookURI()) {\n                    this.transport.withCredentials = true;\n                };\n            }\n        ;\n            if (((this.method == \"POST\") && !this.rawData)) {\n                this.transport.setRequestHeader(\"Content-Type\", \"application/x-www-form-urlencoded\");\n            };\n            this.addStatusIndicator();\n            this.transport.send(ma);\n            if ((this.timeout !== null)) {\n                this.resetTimeout(this.timeout);\n            };\n            ia._inflightCount++;\n            ia._inflightAdd(this);\n            return true;\n        }\n    });\n    function ja() {\n        this._requests = [];\n    };\n    v(ja, {\n        multiplex: null,\n        schedule: function(ka) {\n            if (!ja.multiplex) {\n                ja.multiplex = new ja();\n                (function() {\n                    ja.multiplex.send();\n                    ja.multiplex = null;\n                }).defer();\n            }\n        ;\n            ja.multiplex.add(ka);\n        }\n    });\n    v(ja.prototype, {\n        add: function(ka) {\n            this._requests.push(ka);\n        },\n        send: function() {\n            var ka = this._requests;\n            if (!ka.length) {\n                return\n            };\n            var la;\n            if ((ka.length === 1)) {\n                la = ka[0];\n            }\n             else {\n                var ma = ka.map(function(na) {\n                    return [na.uri.getPath(),r.implodeQuery(na.data),];\n                });\n                la = new ia(\"/ajax/proxy.php\").setAllowCrossPageTransition(true).setData({\n                    data: ma\n                }).setHandler(this._handler.bind(this)).setTransportErrorHandler(this._transportErrorHandler.bind(this));\n            }\n        ;\n            la.setOption(\"bundle\", false).send();\n        },\n        _handler: function(ka) {\n            var la = ka.getPayload().responses;\n            if ((la.length !== this._requests.length)) {\n                return\n            };\n            for (var ma = 0; (ma < this._requests.length); ma++) {\n                var na = this._requests[ma], oa = na.uri.getPath();\n                na.id = this.id;\n                if ((la[ma][0] !== oa)) {\n                    na.invokeResponseHandler({\n                        transportError: (\"Wrong response order in bundled request to \" + oa)\n                    });\n                    continue;\n                }\n            ;\n                na.handleResponse(la[ma][1]);\n            };\n        },\n        _transportErrorHandler: function(ka) {\n            var la = {\n                transportError: ka.errorDescription\n            }, ma = this._requests.map(function(na) {\n                na.id = this.id;\n                na.invokeResponseHandler(la);\n                return na.uri.getPath();\n            });\n        }\n    });\n    e.exports = ia;\n});\n__d(\"legacy:async\", [\"AsyncRequest\",\"AsyncResponse\",], function(a, b, c, d) {\n    a.AsyncRequest = b(\"AsyncRequest\");\n    a.AsyncResponse = b(\"AsyncResponse\");\n}, 3);\n__d(\"legacy:css\", [\"CSS\",], function(a, b, c, d) {\n    a.CSS = b(\"CSS\");\n}, 3);\n__d(\"legacy:data-store\", [\"DataStore\",], function(a, b, c, d) {\n    a.DataStore = (a.DataStore || b(\"DataStore\"));\n}, 3);\nfunction EmuController(a, b) {\n    this.impression = b;\n    this.containerId = a;\n    DataStore.set($(a), \"emuController\", this);\n    return this;\n};\ncopyProperties(EmuController, {\n    fromContainer: function(a) {\n        var b = ge(a);\n        if (!b) {\n            return null\n        };\n        return DataStore.get(b, \"emuController\");\n    },\n    getEventClass: function(a) {\n        return (\"emuEvent\" + String(a).trim());\n    }\n});\ncopyProperties(EmuController.prototype, {\n    EVENT_HANDLER_PATH: \"/ajax/emu/end.php\",\n    CLICK: 1,\n    FAN: \"fad_fan\",\n    event: function(a, b, c, d) {\n        var e = {\n            eid: this.impression,\n            f: 0,\n            ui: this.containerId,\n            en: a,\n            a: 1\n        };\n        if (b) {\n            e.ed = JSON.stringify(b);\n        };\n        if (!d) {\n            var d = bagofholding\n        };\n        var f = new AsyncRequest().setURI(this.EVENT_HANDLER_PATH).setData(e).setErrorHandler(d);\n        if (c) {\n            f.setHandler(c);\n        };\n        f.send();\n    },\n    redirect: function() {\n        var a = {\n            eid: this.impression,\n            f: 0,\n            ui: this.containerId,\n            en: this.CLICK,\n            a: 0,\n            sig: (Math.floor((Math.random() * 65535)) + 65536)\n        }, b = new URI(this.EVENT_HANDLER_PATH);\n        b.setQueryData(a);\n        goURI(b);\n    }\n});\nvar ShortClickHandlers = {\n    EVENT_NAME_CAME_BACK: \"cameback\",\n    onclicked: function(a) {\n        if (this.onsite) {\n            return\n        };\n        if (((a.button !== 0) || a.getModifiers().any)) {\n            return\n        };\n        this.click_ts = (+new Date());\n        if ((this.listeners !== undefined)) {\n            for (var b in this.listeners) {\n                this.listeners[b].remove();;\n            }\n        };\n        this.listeners = {\n            focus: Event.listen(window, \"focus\", ShortClickHandlers.oncameback.bind(this))\n        };\n    },\n    oncameback: function(a) {\n        var b = ((+new Date()) - this.click_ts);\n        this.listeners[a.type].remove();\n        var c = {\n            click_ts: this.click_ts,\n            length: b,\n            trigger: a.type\n        };\n        this.sendData(ShortClickHandlers.EVENT_NAME_CAME_BACK, c);\n    }\n};\nfunction EmuTracker(a, b) {\n    this.base = EmuController.fromContainer(a);\n    !this.base;\n    this.onsite = b;\n    var c = DOM.scry($(a), (\"a.\" + EmuController.getEventClass(EmuTracker.EVENT_CLICK)));\n    c.forEach(function(d) {\n        Event.listen(d, \"click\", ShortClickHandlers.onclicked.bind(this));\n    }.bind(this));\n    return this;\n};\ncopyProperties(EmuTracker, {\n    EVENT_CLICK: 1\n});\ncopyProperties(EmuTracker.prototype, {\n    sendData: function(a, b) {\n        this.base.event(a, b);\n    }\n});\n__d(\"legacy:event-extensions\", [\"event-extensions\",], function(a, b, c, d) {\n    b(\"event-extensions\");\n}, 3);\nfunction BassWhitespaceListener(a, b) {\n    this.link = b;\n    Event.listen(a, \"click\", this.onclicked.bind(this));\n};\ncopyProperties(BassWhitespaceListener.prototype, {\n    onclicked: function(a) {\n        if (Parent.byTag(a.getTarget(), \"A\")) {\n            return\n        };\n        switch (this.link.getAttribute(\"rel\")) {\n          case \"async\":\n            Bootloader.loadComponents(\"async\", function() {\n                AsyncRequest.bootstrap(this.link.getAttribute(\"ajaxify\"), this.link);\n            }.bind(this));\n            break;\n          case \"theater\":\n            var b = Parent.byClass(a.getTarget(), \"fbPhotoSnowlift\");\n            Bootloader.loadComponents(\"PhotoViewer\", function() {\n                PhotoViewer.bootstrap(this.link.getAttribute(\"ajaxify\"), this.link);\n            }.bind(this));\n            if (b) {\n                return false\n            };\n            break;\n          default:\n            goURI(this.link.getAttribute(\"href\"));\n        };\n    }\n});\n__d(\"GenderConst\", [], function(a, b, c, d, e, f) {\n    var g = {\n        UNKNOWN: 0,\n        FEMALE_SINGULAR: 1,\n        MALE_SINGULAR: 2,\n        FEMALE_SINGULAR_GUESS: 3,\n        MALE_SINGULAR_GUESS: 4,\n        MIXED_SINGULAR: 5,\n        MIXED_PLURAL: 5,\n        NEUTER_SINGULAR: 6,\n        UNKNOWN_SINGULAR: 7,\n        FEMALE_PLURAL: 8,\n        MALE_PLURAL: 9,\n        NEUTER_PLURAL: 10,\n        UNKNOWN_PLURAL: 11\n    };\n    e.exports = g;\n});\n__d(\"Button\", [\"event-extensions\",\"CSS\",\"DataStore\",\"DOM\",\"Parent\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"CSS\"), h = b(\"DataStore\"), i = b(\"DOM\"), j = b(\"Parent\"), k = \"uiButtonDisabled\", l = \"uiButtonDepressed\", m = \"button:blocker\", n = \"href\", o = \"ajaxify\";\n    function p(t, u) {\n        var v = h.get(t, m);\n        if (u) {\n            if (v) {\n                v.remove();\n                h.remove(t, m);\n            }\n        ;\n        }\n         else if (!v) {\n            h.set(t, m, Event.listen(t, \"click\", bagof(false), Event.Priority.URGENT));\n        }\n    ;\n    };\n    function q(t) {\n        var u = j.byClass(t, \"uiButton\");\n        if (!u) {\n            throw new Error(\"invalid use case\")\n        };\n        return u;\n    };\n    function r(t) {\n        return i.isNodeOfType(t, \"a\");\n    };\n    var s = {\n        getInputElement: function(t) {\n            t = q(t);\n            if (r(t)) {\n                throw new Error(\"invalid use case\")\n            };\n            return i.find(t, \"input\");\n        },\n        isEnabled: function(t) {\n            return !g.hasClass(q(t), k);\n        },\n        setEnabled: function(t, u) {\n            t = q(t);\n            g.conditionClass(t, k, !u);\n            if (r(t)) {\n                var v = t.href, w = t.getAttribute(\"ajaxify\"), x = h.get(t, n, \"#\"), y = h.get(t, o);\n                if (u) {\n                    if (!v) {\n                        t.href = x;\n                    };\n                    if ((!w && y)) {\n                        t.setAttribute(\"ajaxify\", y);\n                    };\n                }\n                 else {\n                    if ((v && (v !== x))) {\n                        h.set(t, n, v);\n                    };\n                    if ((w && (w !== y))) {\n                        h.set(t, o, w);\n                    };\n                    t.removeAttribute(\"href\");\n                    t.removeAttribute(\"ajaxify\");\n                }\n            ;\n                p(t, u);\n            }\n             else {\n                var z = s.getInputElement(t);\n                z.disabled = !u;\n                p(z, u);\n            }\n        ;\n        },\n        setDepressed: function(t, u) {\n            g.conditionClass(q(t), l, u);\n        },\n        isDepressed: function(t) {\n            return g.hasClass(q(t), l);\n        },\n        setLabel: function(t, u) {\n            t = q(t);\n            if (r(t)) {\n                var v = i.find(t, \"span.uiButtonText\");\n                i.setContent(v, u);\n            }\n             else s.getInputElement(t).value = u;\n        ;\n            g.conditionClass(t, \"uiButtonNoText\", !u);\n        },\n        setIcon: function(t, u) {\n            if ((u && !i.isNode(u))) {\n                return\n            };\n            t = q(t);\n            var v = i.scry(t, \".img\")[0];\n            if (!u) {\n                (v && i.remove(v));\n                return;\n            }\n        ;\n            g.addClass(u, \"customimg\");\n            if ((v != u)) {\n                if (v) {\n                    i.replace(v, u);\n                }\n                 else i.prependContent(t, u);\n            \n            };\n        }\n    };\n    e.exports = s;\n});\n__d(\"DOMControl\", [\"DataStore\",\"$\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"DataStore\"), h = b(\"$\"), i = b(\"copyProperties\");\n    function j(k) {\n        this.root = h(k);\n        this.updating = false;\n        g.set(k, \"DOMControl\", this);\n    };\n    i(j.prototype, {\n        getRoot: function() {\n            return this.root;\n        },\n        beginUpdate: function() {\n            if (this.updating) {\n                return false\n            };\n            this.updating = true;\n            return true;\n        },\n        endUpdate: function() {\n            this.updating = false;\n        },\n        update: function(k) {\n            if (!this.beginUpdate()) {\n                return this\n            };\n            this.onupdate(k);\n            this.endUpdate();\n        },\n        onupdate: function(k) {\n        \n        }\n    });\n    j.getInstance = function(k) {\n        return g.get(k, \"DOMControl\");\n    };\n    e.exports = j;\n});\n__d(\"Input\", [\"CSS\",\"DOMQuery\",\"DOMControl\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"DOMQuery\"), i = b(\"DOMControl\"), j = function(l) {\n        var m = l.getAttribute(\"maxlength\");\n        if ((m && (m > 0))) {\n            d([\"enforceMaxLength\",], function(n) {\n                n(l, m);\n            });\n        };\n    }, k = {\n        focus: function(l) {\n            try {\n                l.focus();\n            } catch (m) {\n            \n            };\n        },\n        isEmpty: function(l) {\n            return (!(/\\S/).test((l.value || \"\")) || g.hasClass(l, \"DOMControl_placeholder\"));\n        },\n        getValue: function(l) {\n            return (k.isEmpty(l) ? \"\" : l.value);\n        },\n        setValue: function(l, m) {\n            g.removeClass(l, \"DOMControl_placeholder\");\n            l.value = (m || \"\");\n            j(l);\n            var n = i.getInstance(l);\n            ((n && n.resetHeight) && n.resetHeight());\n        },\n        setPlaceholder: function(l, m) {\n            l.setAttribute(\"aria-label\", m);\n            l.setAttribute(\"placeholder\", m);\n            if ((l == document.activeElement)) {\n                return\n            };\n            if (k.isEmpty(l)) {\n                g.conditionClass(l, \"DOMControl_placeholder\", m);\n                l.value = (m || \"\");\n            }\n        ;\n        },\n        reset: function(l) {\n            var m = ((l !== document.activeElement) ? ((l.getAttribute(\"placeholder\") || \"\")) : \"\");\n            l.value = m;\n            g.conditionClass(l, \"DOMControl_placeholder\", m);\n            l.style.height = \"\";\n        },\n        setSubmitOnEnter: function(l, m) {\n            g.conditionClass(l, \"enter_submit\", m);\n        },\n        getSubmitOnEnter: function(l) {\n            return g.hasClass(l, \"enter_submit\");\n        },\n        setMaxLength: function(l, m) {\n            if ((m > 0)) {\n                l.setAttribute(\"maxlength\", m);\n                j(l);\n            }\n             else l.removeAttribute(\"maxlength\");\n        ;\n        }\n    };\n    e.exports = k;\n});\n__d(\"Form\", [\"event-extensions\",\"AsyncRequest\",\"AsyncResponse\",\"CSS\",\"DOM\",\"DOMPosition\",\"DOMQuery\",\"DataStore\",\"Env\",\"Input\",\"Parent\",\"URI\",\"createArrayFrom\",\"trackReferrer\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"AsyncRequest\"), h = b(\"AsyncResponse\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"DOMPosition\"), l = b(\"DOMQuery\"), m = b(\"DataStore\"), n = b(\"Env\"), o = b(\"Input\"), p = b(\"Parent\"), q = b(\"URI\"), r = b(\"createArrayFrom\"), s = b(\"trackReferrer\"), t = (\"FileList\" in window), u = (\"FormData\" in window);\n    function v(x) {\n        var y = {\n        };\n        q.implodeQuery(x).split(\"&\").forEach(function(z) {\n            if (z) {\n                var aa = /^([^=]*)(?:=(.*))?$/.exec(z), ba = q.decodeComponent(aa[1]), ca = (aa[2] ? q.decodeComponent(aa[2]) : null);\n                y[ba] = ca;\n            }\n        ;\n        });\n        return y;\n    };\n    var w = {\n        getInputs: function(x) {\n            x = (x || document);\n            return [].concat(r(l.scry(x, \"input\")), r(l.scry(x, \"select\")), r(l.scry(x, \"textarea\")), r(l.scry(x, \"button\")));\n        },\n        getSelectValue: function(x) {\n            return x.options[x.selectedIndex].value;\n        },\n        setSelectValue: function(x, y) {\n            for (var z = 0; (z < x.options.length); ++z) {\n                if ((x.options[z].value == y)) {\n                    x.selectedIndex = z;\n                    break;\n                }\n            ;\n            };\n        },\n        getRadioValue: function(x) {\n            for (var y = 0; (y < x.length); y++) {\n                if (x[y].checked) {\n                    return x[y].value\n                };\n            };\n            return null;\n        },\n        getElements: function(x) {\n            return r(((x.tagName == \"FORM\") ? x.elements : w.getInputs(x)));\n        },\n        getAttribute: function(x, y) {\n            return (((x.getAttributeNode(y) || {\n            })).value || null);\n        },\n        setDisabled: function(x, y) {\n            w.getElements(x).forEach(function(z) {\n                if ((z.disabled !== undefined)) {\n                    var aa = m.get(z, \"origDisabledState\");\n                    if (y) {\n                        if ((aa === undefined)) {\n                            m.set(z, \"origDisabledState\", z.disabled);\n                        };\n                        z.disabled = y;\n                    }\n                     else if ((aa !== true)) {\n                        z.disabled = false;\n                    }\n                ;\n                }\n            ;\n            });\n        },\n        bootstrap: function(x, y) {\n            var z = ((w.getAttribute(x, \"method\") || \"GET\")).toUpperCase();\n            y = (p.byTag(y, \"button\") || y);\n            var aa = (p.byClass(y, \"stat_elem\") || x);\n            if (i.hasClass(aa, \"async_saving\")) {\n                return\n            };\n            if ((y && ((((y.form !== x) || (((y.nodeName != \"INPUT\") && (y.nodeName != \"BUTTON\")))) || (y.type != \"submit\"))))) {\n                var ba = l.scry(x, \".enter_submit_target\")[0];\n                (ba && (y = ba));\n            }\n        ;\n            var ca = w.serialize(x, y);\n            w.setDisabled(x, true);\n            var da = (w.getAttribute(x, \"ajaxify\") || w.getAttribute(x, \"action\"));\n            s(x, da);\n            var ea = new g(da);\n            ea.setData(ca).setNectarModuleDataSafe(x).setReadOnly((z == \"GET\")).setMethod(z).setRelativeTo(x).setStatusElement(aa).setInitialHandler(w.setDisabled.curry(x, false)).setHandler(function(fa) {\n                Event.fire(x, \"success\", {\n                    response: fa\n                });\n            }).setErrorHandler(function(fa) {\n                if ((Event.fire(x, \"error\", {\n                    response: fa\n                }) !== false)) {\n                    h.defaultErrorHandler(fa);\n                };\n            }).setFinallyHandler(w.setDisabled.curry(x, false)).send();\n        },\n        forEachValue: function(x, y, z) {\n            w.getElements(x).forEach(function(aa) {\n                if (((aa.name && !aa.disabled) && (aa.type !== \"submit\"))) {\n                    if ((((((!aa.type || (((((aa.type === \"radio\") || (aa.type === \"checkbox\"))) && aa.checked))) || (aa.type === \"text\")) || (aa.type === \"password\")) || (aa.type === \"hidden\")) || (aa.nodeName === \"TEXTAREA\"))) {\n                        z(aa.type, aa.name, o.getValue(aa));\n                    }\n                     else if ((aa.nodeName === \"SELECT\")) {\n                        for (var ba = 0, ca = aa.options.length; (ba < ca); ba++) {\n                            var da = aa.options[ba];\n                            if (da.selected) {\n                                z(\"select\", aa.name, da.value);\n                            };\n                        };\n                    }\n                     else if ((t && (aa.type === \"file\"))) {\n                        var ea = aa.files;\n                        for (var fa = 0; (fa < ea.length); fa++) {\n                            z(\"file\", aa.name, ea.item(fa));;\n                        };\n                    }\n                    \n                    \n                \n                };\n            });\n            if (((((y && y.name) && (y.type === \"submit\")) && l.contains(x, y)) && l.isNodeOfType(y, [\"input\",\"button\",]))) {\n                z(\"submit\", y.name, y.value);\n            };\n        },\n        createFormData: function(x, y) {\n            if (!u) {\n                return null\n            };\n            var z = new FormData();\n            if (x) {\n                if (l.isNode(x)) {\n                    w.forEachValue(x, y, function(ca, da, ea) {\n                        z.append(da, ea);\n                    });\n                }\n                 else {\n                    var aa = v(x);\n                    for (var ba in aa) {\n                        z.append(ba, aa[ba]);;\n                    };\n                }\n            \n            };\n            return z;\n        },\n        serialize: function(x, y) {\n            var z = {\n            };\n            w.forEachValue(x, y, function(aa, ba, ca) {\n                if ((aa === \"file\")) {\n                    return\n                };\n                w._serializeHelper(z, ba, ca);\n            });\n            return w._serializeFix(z);\n        },\n        _serializeHelper: function(x, y, z) {\n            var aa = Object.prototype.hasOwnProperty, ba = /([^\\]]+)\\[([^\\]]*)\\](.*)/.exec(y);\n            if (ba) {\n                if ((!x[ba[1]] || !aa.call(x, ba[1]))) {\n                    var ca;\n                    x[ba[1]] = ca = {\n                    };\n                    if ((x[ba[1]] !== ca)) {\n                        return\n                    };\n                }\n            ;\n                var da = 0;\n                if ((ba[2] === \"\")) {\n                    while ((x[ba[1]][da] !== undefined)) {\n                        da++;;\n                    };\n                }\n                 else da = ba[2];\n            ;\n                if ((ba[3] === \"\")) {\n                    x[ba[1]][da] = z;\n                }\n                 else w._serializeHelper(x[ba[1]], da.concat(ba[3]), z);\n            ;\n            }\n             else x[y] = z;\n        ;\n        },\n        _serializeFix: function(x) {\n            var y = [];\n            for (var z in x) {\n                if ((x[z] instanceof Object)) {\n                    x[z] = w._serializeFix(x[z]);\n                };\n                y.push(z);\n            };\n            if ((y.length > 0)) {\n                var aa = 0, ba = true;\n                y.sort().forEach(function(da) {\n                    if ((da != aa++)) {\n                        ba = false;\n                    };\n                });\n                if (ba) {\n                    var ca = [];\n                    y.forEach(function(da) {\n                        ca[da] = x[da];\n                    });\n                    return ca;\n                }\n            ;\n            }\n        ;\n            return x;\n        },\n        post: function(x, y, z) {\n            var aa = document.createElement(\"form\");\n            aa.action = x.toString();\n            aa.method = \"POST\";\n            aa.style.display = \"none\";\n            if (z) {\n                aa.target = z;\n            };\n            y.fb_dtsg = n.fb_dtsg;\n            w.createHiddenInputs(y, aa);\n            l.getRootElement().appendChild(aa);\n            aa.submit();\n            return false;\n        },\n        createHiddenInputs: function(x, y, z, aa) {\n            z = (z || {\n            });\n            var ba = v(x);\n            for (var ca in ba) {\n                if ((ba[ca] === null)) {\n                    continue;\n                };\n                if ((z[ca] && aa)) {\n                    z[ca].value = ba[ca];\n                }\n                 else {\n                    var da = j.create(\"input\", {\n                        type: \"hidden\",\n                        name: ca,\n                        value: ba[ca]\n                    });\n                    z[ca] = da;\n                    y.appendChild(da);\n                }\n            ;\n            };\n            return z;\n        },\n        getFirstElement: function(x, y) {\n            y = (y || [\"input[type=\\\"text\\\"]\",\"textarea\",\"input[type=\\\"password\\\"]\",\"input[type=\\\"button\\\"]\",\"input[type=\\\"submit\\\"]\",]);\n            var z = [];\n            for (var aa = 0; (aa < y.length); aa++) {\n                z = l.scry(x, y[aa]);\n                for (var ba = 0; (ba < z.length); ba++) {\n                    var ca = z[ba];\n                    try {\n                        var ea = k.getElementPosition(ca);\n                        if (((ea.y > 0) && (ea.x > 0))) {\n                            return ca\n                        };\n                    } catch (da) {\n                    \n                    };\n                };\n            };\n            return null;\n        },\n        focusFirst: function(x) {\n            var y = w.getFirstElement(x);\n            if (y) {\n                y.focus();\n                return true;\n            }\n        ;\n            return false;\n        }\n    };\n    e.exports = w;\n});\n__d(\"AsyncUploadBase\", [\"ArbiterMixin\",\"AsyncRequest\",\"AsyncResponse\",\"Form\",\"UserAgent\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"ArbiterMixin\"), h = b(\"AsyncRequest\"), i = b(\"AsyncResponse\"), j = b(\"Form\"), k = b(\"UserAgent\"), l = b(\"copyProperties\");\n    function m(o) {\n        this.setURI(o);\n    };\n    m.isSupported = function() {\n        if (((k.safari() && !k.chrome()) && k.windows())) {\n            return false\n        };\n        return (((\"FileList\" in window)) && ((\"FormData\" in window)));\n    };\n    l(m.prototype, g, {\n        _limit: 10,\n        setAllowCrossOrigin: function(o) {\n            this._allowCrossOrigin = !!o;\n            return this;\n        },\n        setData: function(o) {\n            this._data = o;\n            return this;\n        },\n        setLimit: function(o) {\n            this._limit = o;\n            return this;\n        },\n        setRelativeTo: function(o) {\n            this._relativeTo = o;\n            return this;\n        },\n        setStatusElement: function(o) {\n            this._statusElement = o;\n            return this;\n        },\n        setURI: function(o) {\n            this._uri = o;\n            return this;\n        },\n        _createFileUpload: function(o, p) {\n            return new n(o, p);\n        },\n        _parseFiles: function(o) {\n            var p = {\n            };\n            for (var q in o) {\n                var r = o[q];\n                if (Array.isArray(r)) {\n                    p[q] = r;\n                }\n                 else {\n                    p[q] = [];\n                    if ((r instanceof window.FileList)) {\n                        for (var s = 0; (s < r.length); s++) {\n                            p[q].push(r.item(s));;\n                        };\n                    }\n                     else if (((r instanceof window.File) || (r instanceof window.Blob))) {\n                        p[q].push(r);\n                    }\n                ;\n                }\n            ;\n            };\n            return p;\n        },\n        _processQueue: function() {\n            while ((this._pending.length < this._limit)) {\n                if (!this._waiting.length) {\n                    break;\n                };\n                var o = this._waiting.shift();\n                this._processUpload(o);\n                this._pending.push(o);\n            };\n        },\n        _processUpload: function(o) {\n            this.inform(\"start\", o);\n            var p = j.createFormData(this._data);\n            if (o.getFile()) {\n                p.append(o.getName(), o.getFile());\n            };\n            new h().setAllowCrossOrigin(this._allowCrossOrigin).setURI(this._uri).setRawData(p).setRelativeTo(this._relativeTo).setStatusElement(this._statusElement).setHandler(this._success.bind(this, o)).setErrorHandler(this._failure.bind(this, o)).setUploadProgressHandler(this._progress.bind(this, o)).setInitialHandler(this._initial.bind(this, o)).send();\n        },\n        _initial: function(o) {\n            this.inform(\"initial\", o);\n        },\n        _success: function(o, p) {\n            this.inform(\"success\", o.handleSuccess(p));\n            this._complete(o);\n        },\n        _failure: function(o, p) {\n            if ((this.inform(\"failure\", o.handleFailure(p)) !== false)) {\n                i.defaultErrorHandler(p);\n            };\n            this._complete(o);\n        },\n        _progress: function(o, event) {\n            this.inform(\"progress\", o.handleProgress(event));\n        },\n        _complete: function(o) {\n            this._pending.remove(o);\n            this._processQueue();\n            if (!this._pending.length) {\n                this._inFlight = false;\n            };\n        }\n    });\n    var n = function(o, p) {\n        this._name = o;\n        this._file = p;\n        this._success = null;\n        this._response = null;\n        this._progressEvent = null;\n    };\n    l(n.prototype, {\n        getName: function() {\n            return this._name;\n        },\n        getFile: function() {\n            return this._file;\n        },\n        isComplete: function() {\n            return (this._success !== null);\n        },\n        isSuccess: function() {\n            return (this._success === true);\n        },\n        getResponse: function() {\n            return this._response;\n        },\n        getProgressEvent: function() {\n            return this._progressEvent;\n        },\n        handleSuccess: function(o) {\n            this._success = true;\n            this._response = o;\n            this._progressEvent = null;\n            return this;\n        },\n        handleFailure: function(o) {\n            this._success = false;\n            this._response = o;\n            this._progressEvent = null;\n            return this;\n        },\n        handleProgress: function(event) {\n            this._progressEvent = event;\n            return this;\n        }\n    });\n    e.exports = m;\n});\n__d(\"AsyncUploadRequest\", [\"AsyncUploadBase\",\"Class\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncUploadBase\"), h = b(\"Class\"), i = b(\"copyProperties\");\n    function j(k) {\n        this.parent.construct(this, k);\n    };\n    j.isSupported = function() {\n        return g.isSupported();\n    };\n    h.extend(j, g);\n    i(j.prototype, {\n        setFiles: function(k) {\n            this._files = this._parseFiles(k);\n            return this;\n        },\n        send: function() {\n            if (this._inFlight) {\n                return\n            };\n            this._inFlight = true;\n            this._uploads = [];\n            for (var k in this._files) {\n                this._files[k].forEach(function(l) {\n                    this._uploads.push(this._createFileUpload(k, l));\n                }.bind(this));;\n            };\n            if (this._uploads.length) {\n                this._waiting = this._uploads.slice(0);\n                this._pending = [];\n                this._processQueue();\n            }\n             else this._processUpload(this._createFileUpload(null, null));\n        ;\n        },\n        _complete: function(k) {\n            this.parent._complete(k);\n            if (!this._pending.length) {\n                this.inform(\"complete\", this._uploads);\n            };\n        }\n    });\n    e.exports = j;\n});\n__d(\"JSONPTransport\", [\"DOM\",\"HTML\",\"URI\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"HTML\"), i = b(\"URI\"), j = b(\"copyProperties\"), k = {\n    }, l = 2, m = \"jsonp\", n = \"iframe\";\n    function o(p, q, r) {\n        this._type = p;\n        this._uri = q;\n        this._handler = r;\n        k[this.getID()] = this;\n    };\n    j(o, {\n        respond: function(p, q, r) {\n            var s = k[p];\n            if (s) {\n                if (!r) {\n                    delete k[p];\n                };\n                if ((s._type == n)) {\n                    q = JSON.parse(JSON.stringify(q));\n                };\n                a.async_callback(s.handleResponse.bind(s), \"json\")(q);\n            }\n             else if ((a.logJSError && !r)) {\n                a.logJSError(\"ajax\", {\n                    error: \"UnexpectedJsonResponse\",\n                    extra: {\n                        id: p,\n                        uri: (((q.payload && q.payload.uri)) || \"\")\n                    }\n                });\n            }\n        ;\n        }\n    });\n    j(o.prototype, {\n        getID: function() {\n            return (this._id || (this._id = l++));\n        },\n        hasFinished: function() {\n            return !((this.getID() in k));\n        },\n        getRequestURI: function() {\n            return i(this._uri).addQueryData({\n                __a: 1,\n                __adt: this.getID()\n            });\n        },\n        createTransportFrame: function() {\n            var p = (\"transport_frame_\" + this.getID()), q = h(((\"\\u003Ciframe class=\\\"hidden_elem\\\" name=\\\"\" + p) + \"\\\" src=\\\"javascript:void(0)\\\" /\\u003E\"));\n            return g.appendContent(document.body, q)[0];\n        },\n        send: function() {\n            if ((this._type === m)) {\n                (function() {\n                    g.appendContent(document.body, g.create(\"script\", {\n                        src: this.getRequestURI().toString(),\n                        type: \"text/javascript\"\n                    }));\n                }).bind(this).defer();\n            }\n             else {\n                this._iframe = this.createTransportFrame();\n                this._iframe.src = this.getRequestURI().toString();\n            }\n        ;\n        },\n        handleResponse: function(p) {\n            if (!this._aborted) {\n                this._handler(p);\n            };\n            if (this.hasFinished()) {\n                if (this._iframe) {\n                    g.remove.curry(this._iframe).defer();\n                    this._iframe = null;\n                }\n            \n            };\n        },\n        abort: function() {\n            this._aborted = true;\n        }\n    });\n    e.exports = o;\n});\n__d(\"FileForm\", [\"event-extensions\",\"ArbiterMixin\",\"AsyncRequest\",\"AsyncUploadRequest\",\"AsyncResponse\",\"BehaviorsMixin\",\"DataStore\",\"DOMQuery\",\"Env\",\"Form\",\"JSONPTransport\",\"Parent\",\"URI\",\"UserAgent\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"AsyncRequest\"), i = b(\"AsyncUploadRequest\"), j = b(\"AsyncResponse\"), k = b(\"BehaviorsMixin\"), l = b(\"DataStore\"), m = b(\"DOMQuery\"), n = b(\"Env\"), o = b(\"Form\"), p = b(\"JSONPTransport\"), q = b(\"Parent\"), r = b(\"URI\"), s = b(\"UserAgent\"), t = b(\"copyProperties\");\n    function u(w) {\n        var x = {\n        }, y = m.scry(w, \"input[type=\\\"file\\\"]\");\n        y.forEach(function(z) {\n            x[z.name] = z.files;\n        });\n        return x;\n    };\n    function v(w, x, y) {\n        if ((w.getAttribute(\"rel\") === \"async\")) {\n            throw new Error(\"FileForm cannot be used with Primer forms.\")\n        };\n        if ((w.getAttribute(\"method\").toUpperCase() !== \"POST\")) {\n            throw new Error(\"FileForm must be used with POST forms.\")\n        };\n        this._form = w;\n        this._form.enctype = this._form.encoding = \"multipart/form-data\";\n        (x && this.enableBehaviors(x));\n        this._options = (y || {\n        });\n        this.setAllowCrossOrigin(this._options.allowCrossOrigin);\n        this.setUploadInParallel(this._options.uploadInParallel);\n        this._listener = Event.listen(this._form, \"submit\", this._submit.bind(this));\n        l.set(this._form, \"FileForm\", this);\n    };\n    t(v, {\n        EVENTS: [\"submit\",\"initial\",\"progress\",\"success\",\"failure\",],\n        getInstance: function(w) {\n            return l.get(w, \"FileForm\");\n        }\n    });\n    t(v.prototype, g, k, {\n        getRoot: function() {\n            return this._form;\n        },\n        setAllowCrossOrigin: function(w) {\n            this._allowCrossOrigin = !!w;\n            return this;\n        },\n        setUploadInParallel: function(w) {\n            this._uploadInParallel = !!w;\n            return this;\n        },\n        _submit: function(event) {\n            if ((this.inform(\"submit\") === false)) {\n                event.prevent();\n                return;\n            }\n        ;\n            var w = (\"FormData\" in window);\n            if (w) {\n                if ((!r(this._form.action).isSameOrigin() && !this._allowCrossOrigin)) {\n                    w = false;\n                }\n            };\n            return (w ? this._sendViaXHR(event) : this._sendViaFrame(event));\n        },\n        _sendViaFrame: function(event) {\n            var w = new h();\n            w.setStatusElement(this._getStatusElement());\n            w.addStatusIndicator();\n            w.setOption(\"useIframeTransport\", true);\n            var x = w.handleResponse.bind(w), y = new p(\"iframe\", this._form.action, x), z = y.createTransportFrame(), aa = y.getRequestURI().addQueryData({\n                __iframe: true,\n                __user: n.user\n            });\n            this._form.setAttribute(\"action\", aa.toString());\n            this._form.setAttribute(\"target\", z.name);\n            w.setURI(aa);\n            w.setHandler(this.success.bind(this, null));\n            w.setErrorHandler(this.failure.bind(this, null));\n            w.setInitialHandler(this.initial.shield(this, null));\n        },\n        _sendViaXHR: function(event) {\n            var w;\n            if ((this._uploadInParallel && i.isSupported())) {\n                w = new i().setData(o.serialize(this._form)).setFiles(u(this._form));\n                var x = [w.subscribe(\"progress\", function(y, z) {\n                    this.progress(z, z.getProgressEvent());\n                }.bind(this)),w.subscribe(\"initial\", function(y, z) {\n                    this.initial(z, z.getResponse());\n                }.bind(this)),w.subscribe(\"success\", function(y, z) {\n                    this.success(z, z.getResponse());\n                }.bind(this)),w.subscribe(\"failure\", function(y, z) {\n                    this.failure(z, z.getResponse());\n                    return false;\n                }.bind(this)),w.subscribe(\"complete\", function() {\n                    while (x.length) {\n                        x.pop().unsubscribe();;\n                    };\n                }),];\n            }\n             else w = new h().setRawData(o.createFormData(this._form)).setHandler(this.success.bind(this, null)).setErrorHandler(this.failure.bind(this, null)).setUploadProgressHandler(this.progress.bind(this, null)).setInitialHandler(this.initial.shield(this, null));\n        ;\n            w.setAllowCrossOrigin(this._allowCrossOrigin).setRelativeTo(this._form).setStatusElement(this._getStatusElement()).setURI(this._form.action).send();\n            event.prevent();\n        },\n        initial: function(w) {\n            return this.inform(\"initial\", {\n                upload: w\n            });\n        },\n        success: function(w, x) {\n            var y = {\n                response: x,\n                upload: w\n            };\n            if ((this.inform(\"success\", y) !== false)) {\n                Event.fire(this._form, \"success\", y);\n            };\n        },\n        failure: function(w, x) {\n            var y = {\n                response: x,\n                upload: w\n            };\n            if ((this.inform(\"failure\", y) !== false)) {\n                if ((Event.fire(this._form, \"error\", y) !== false)) {\n                    j.defaultErrorHandler(x);\n                }\n            };\n        },\n        progress: function(w, event) {\n            this.inform(\"progress\", {\n                event: event,\n                upload: w\n            });\n        },\n        destroy: function() {\n            this._listener.remove();\n            this._listener = null;\n            if ((isNaN(s.ie()) || ((s.ie() > 8)))) {\n                this._form.encoding = null;\n            };\n            this._form.enctype = null;\n            l.remove(this._form, \"FileForm\");\n        },\n        _getStatusElement: function() {\n            return (q.byClass(this._form, \"stat_elem\") || this._form);\n        }\n    });\n    e.exports = v;\n});\n__d(\"goOrReplace\", [\"URI\",\"UserAgent\",], function(a, b, c, d, e, f) {\n    var g = b(\"URI\"), h = b(\"UserAgent\");\n    function i(j, k, l) {\n        var m = new g(k);\n        if ((((j.pathname == \"/\") && (m.getPath() != \"/\")) && m.isQuicklingEnabled())) {\n            var n = (j.search ? {\n            } : {\n                q: \"\"\n            });\n            m = new g().setPath(\"/\").setQueryData(n).setFragment(m.getUnqualifiedURI()).toString();\n            k = m.toString();\n        }\n    ;\n        if ((l && !((h.ie() < 8)))) {\n            j.replace(k);\n        }\n         else if ((j.href == k)) {\n            j.reload();\n        }\n         else j.href = k;\n        \n    ;\n    };\n    e.exports = i;\n});\n__d(\"AjaxPipeRequest\", [\"Arbiter\",\"AsyncRequest\",\"BigPipe\",\"DOM\",\"Env\",\"JSCC\",\"ScriptPathState\",\"copyProperties\",\"goOrReplace\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"BigPipe\"), j = b(\"DOM\"), k = b(\"Env\"), l = b(\"JSCC\"), m = b(\"ScriptPathState\"), n = b(\"copyProperties\"), o = b(\"goOrReplace\"), p = b(\"ge\"), q;\n    function r(u, v) {\n        var w = p(u);\n        if (w) {\n            if (!v) {\n                w.style.minHeight = \"600px\";\n            };\n            for (var x in i.pageletIDs) {\n                if (((u !== x) && j.contains(w, x))) {\n                    g.inform(\"ajaxpipe/clear_pagelet\", {\n                        pagelet_id: x\n                    });\n                    l.clearForPagelet(x);\n                    delete i.pageletIDs[x];\n                }\n            ;\n            };\n            j.empty(w);\n        }\n    ;\n    };\n    function s(u, v) {\n        var w = p(u);\n        if (w) {\n            if (!v) {\n                w.style.minHeight = \"100px\";\n            }\n        };\n    };\n    function t(u, v) {\n        this._uri = u;\n        this._query_data = v;\n        this._request = new h();\n        this._canvas_id = null;\n        this._allow_cross_page_transition = true;\n    };\n    n(t.prototype, {\n        setCanvasId: function(u) {\n            this._canvas_id = u;\n            return this;\n        },\n        setURI: function(u) {\n            this._uri = u;\n            return this;\n        },\n        setData: function(u) {\n            this._query_data = u;\n            return this;\n        },\n        getData: function(u) {\n            return this._query_data;\n        },\n        setAllowCrossPageTransition: function(u) {\n            this._allow_cross_page_transition = u;\n            return this;\n        },\n        setAppend: function(u) {\n            this._append = u;\n            return this;\n        },\n        send: function() {\n            var u = {\n                ajaxpipe: 1,\n                ajaxpipe_token: k.ajaxpipe_token\n            };\n            n(u, m.getParams());\n            m.reset();\n            if (this._pageletCacheMiss) {\n                u.pcmiss = 1;\n            };\n            this._request.setOption(\"useIframeTransport\", true).setURI(this._uri).setData(n(u, this._query_data)).setPreBootloadHandler(this._preBootloadHandler.bind(this)).setInitialHandler(this._onInitialResponse.bind(this)).setHandler(this._onResponse.bind(this)).setMethod(\"GET\").setReadOnly(true).setAllowCrossPageTransition(this._allow_cross_page_transition);\n            if (this._automatic) {\n                this._relevantRequest = q;\n            }\n             else q = this._request;\n        ;\n            this._request.send();\n            return this;\n        },\n        _preBootloadFirstResponse: function(u) {\n            return false;\n        },\n        _fireDomContentCallback: function() {\n            this._arbiter.inform(\"ajaxpipe/domcontent_callback\", true, g.BEHAVIOR_STATE);\n        },\n        _fireOnloadCallback: function() {\n            this._arbiter.inform(\"ajaxpipe/onload_callback\", true, g.BEHAVIOR_STATE);\n        },\n        _isRelevant: function(u) {\n            return ((((this._request == q) || ((this._automatic && (this._relevantRequest == q)))) || this._jsNonBlock) || this._forceFinish);\n        },\n        _preBootloadHandler: function(u) {\n            var v = u.getPayload();\n            if (((!v || v.redirect) || !this._isRelevant(u))) {\n                return false\n            };\n            var w = false;\n            if (u.is_first) {\n                ((!this._append && !this._displayCallback) && r(this._canvas_id, this._constHeight));\n                this._arbiter = new g();\n                w = this._preBootloadFirstResponse(u);\n                this.pipe = new i({\n                    arbiter: this._arbiter,\n                    rootNodeID: this._canvas_id,\n                    lid: this._request.lid,\n                    isAjax: true,\n                    domContentCallback: this._fireDomContentCallback.bind(this),\n                    onloadCallback: this._fireOnloadCallback.bind(this),\n                    domContentEvt: \"ajaxpipe/domcontent_callback\",\n                    onloadEvt: \"ajaxpipe/onload_callback\",\n                    jsNonBlock: this._jsNonBlock,\n                    forceFinish: this._forceFinish,\n                    automatic: this._automatic,\n                    displayCallback: this._displayCallback\n                });\n            }\n        ;\n            return w;\n        },\n        _redirect: function(u) {\n            if (u.redirect) {\n                if ((u.force || !this.isPageActive(u.redirect))) {\n                    var v = [\"ajaxpipe\",\"ajaxpipe_token\",].concat(this.getSanitizedParameters());\n                    o(window.location, URI(u.redirect).removeQueryData(v), true);\n                }\n                 else PageTransitions.go(u.redirect, true);\n            ;\n                return true;\n            }\n             else return false\n        ;\n        },\n        isPageActive: function(u) {\n            return true;\n        },\n        getSanitizedParameters: function() {\n            return [];\n        },\n        _versionCheck: function(u) {\n            return true;\n        },\n        _onInitialResponse: function(u) {\n            var v = u.getPayload();\n            if (!this._isRelevant(u)) {\n                return false\n            };\n            if (!v) {\n                return true\n            };\n            if ((this._redirect(v) || !this._versionCheck(v))) {\n                return false\n            };\n            return true;\n        },\n        _processFirstResponse: function(u) {\n            var v = u.getPayload();\n            if ((p(this._canvas_id) && (v.canvas_class !== null))) {\n                CSS.setClass(this._canvas_id, v.canvas_class);\n            };\n        },\n        setFirstResponseCallback: function(u) {\n            this._firstResponseCallback = u;\n            return this;\n        },\n        setFirstResponseHandler: function(u) {\n            this._processFirstResponse = u;\n            return this;\n        },\n        _onResponse: function(u) {\n            var v = u.payload;\n            if (!this._isRelevant(u)) {\n                return h.suppressOnloadToken\n            };\n            if (u.is_first) {\n                this._processFirstResponse(u);\n                (this._firstResponseCallback && this._firstResponseCallback());\n                v.provides = (v.provides || []);\n                v.provides.push(\"uipage_onload\");\n                if (this._append) {\n                    v.append = this._canvas_id;\n                };\n            }\n        ;\n            if (v) {\n                if ((((\"content\" in v.content) && (this._canvas_id !== null)) && (this._canvas_id != \"content\"))) {\n                    v.content[this._canvas_id] = v.content.content;\n                    delete v.content.content;\n                }\n            ;\n                if ((this._pageletCacheMiss && u.is_first)) {\n                    v.id = this._pageletCacheMiss.id;\n                    v.cacheable = true;\n                    v.cache_controller = this._pageletCacheMiss.cache_controller;\n                    v.cache_type = this._pageletCacheMiss.cache_type;\n                    v.key = this._pageletCacheMiss.key;\n                }\n            ;\n                this.pipe.onPageletArrive(v);\n            }\n        ;\n            if (u.is_last) {\n                s(this._canvas_id, this._constHeight);\n            };\n            return h.suppressOnloadToken;\n        },\n        setNectarModuleDataSafe: function(u) {\n            this._request.setNectarModuleDataSafe(u);\n            return this;\n        },\n        setFinallyHandler: function(u) {\n            this._request.setFinallyHandler(u);\n            return this;\n        },\n        setErrorHandler: function(u) {\n            this._request.setErrorHandler(u);\n            return this;\n        },\n        abort: function() {\n            this._request.abort();\n            if ((q == this._request)) {\n                q = null;\n            };\n            this._request = null;\n            return this;\n        },\n        setJSNonBlock: function(u) {\n            this._jsNonBlock = u;\n            return this;\n        },\n        setForceFinish: function(u) {\n            this._forceFinish = u;\n            return this;\n        },\n        setAutomatic: function(u) {\n            this._automatic = u;\n            return this;\n        },\n        setDisplayCallback: function(u) {\n            this._displayCallback = u;\n            return this;\n        },\n        setPageletCacheMiss: function(u) {\n            this._pageletCacheMiss = u;\n            return this;\n        },\n        setConstHeight: function(u) {\n            this._constHeight = u;\n            return this;\n        },\n        getAsyncRequest: function() {\n            return this._request;\n        }\n    });\n    n(t, {\n        getCurrentRequest: function() {\n            return q;\n        },\n        setCurrentRequest: function(u) {\n            q = u;\n        }\n    });\n    e.exports = t;\n});\n__d(\"Animation\", [\"CSS\",\"DOM\",\"Style\",\"UserAgent\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"Style\"), j = b(\"UserAgent\");\n    function k(l) {\n        if ((a == this)) {\n            return new k(l);\n        }\n         else {\n            this.obj = l;\n            this._reset_state();\n            this.queue = [];\n            this.last_attr = null;\n        }\n    ;\n    };\n    k.resolution = 20;\n    k.offset = 0;\n    k.prototype._reset_state = function() {\n        this.state = {\n            attrs: {\n            },\n            duration: 500\n        };\n    };\n    k.prototype.stop = function() {\n        this._reset_state();\n        this.queue = [];\n        return this;\n    };\n    k.prototype._build_container = function() {\n        if (this.container_div) {\n            this._refresh_container();\n            return;\n        }\n    ;\n        if ((this.obj.firstChild && this.obj.firstChild.__animation_refs)) {\n            this.container_div = this.obj.firstChild;\n            this.container_div.__animation_refs++;\n            this._refresh_container();\n            return;\n        }\n    ;\n        var l = document.createElement(\"div\");\n        l.style.padding = \"0px\";\n        l.style.margin = \"0px\";\n        l.style.border = \"0px\";\n        l.__animation_refs = 1;\n        var m = this.obj.childNodes;\n        while (m.length) {\n            l.appendChild(m[0]);;\n        };\n        this.obj.appendChild(l);\n        this._orig_overflow = this.obj.style.overflow;\n        this.obj.style.overflow = \"hidden\";\n        this.container_div = l;\n        this._refresh_container();\n    };\n    k.prototype._refresh_container = function() {\n        this.container_div.style.height = \"auto\";\n        this.container_div.style.width = \"auto\";\n        this.container_div.style.height = (this.container_div.offsetHeight + \"px\");\n        this.container_div.style.width = (this.container_div.offsetWidth + \"px\");\n    };\n    k.prototype._destroy_container = function() {\n        if (!this.container_div) {\n            return\n        };\n        if (!--this.container_div.__animation_refs) {\n            var l = this.container_div.childNodes;\n            while (l.length) {\n                this.obj.appendChild(l[0]);;\n            };\n            this.obj.removeChild(this.container_div);\n        }\n    ;\n        this.container_div = null;\n        this.obj.style.overflow = this._orig_overflow;\n    };\n    k.ATTR_TO = 1;\n    k.ATTR_BY = 2;\n    k.ATTR_FROM = 3;\n    k.prototype._attr = function(l, m, n) {\n        l = l.replace(/-[a-z]/gi, function(p) {\n            return p.substring(1).toUpperCase();\n        });\n        var o = false;\n        switch (l) {\n          case \"background\":\n            this._attr(\"backgroundColor\", m, n);\n            return this;\n          case \"margin\":\n            m = k.parse_group(m);\n            this._attr(\"marginBottom\", m[0], n);\n            this._attr(\"marginLeft\", m[1], n);\n            this._attr(\"marginRight\", m[2], n);\n            this._attr(\"marginTop\", m[3], n);\n            return this;\n          case \"padding\":\n            m = k.parse_group(m);\n            this._attr(\"paddingBottom\", m[0], n);\n            this._attr(\"paddingLeft\", m[1], n);\n            this._attr(\"paddingRight\", m[2], n);\n            this._attr(\"paddingTop\", m[3], n);\n            return this;\n          case \"backgroundColor\":\n        \n          case \"borderColor\":\n        \n          case \"color\":\n            m = k.parse_color(m);\n            break;\n          case \"opacity\":\n            m = parseFloat(m, 10);\n            break;\n          case \"height\":\n        \n          case \"width\":\n            if ((m == \"auto\")) {\n                o = true;\n            }\n             else m = parseInt(m, 10);\n        ;\n            break;\n          case \"borderWidth\":\n        \n          case \"lineHeight\":\n        \n          case \"fontSize\":\n        \n          case \"marginBottom\":\n        \n          case \"marginLeft\":\n        \n          case \"marginRight\":\n        \n          case \"marginTop\":\n        \n          case \"paddingBottom\":\n        \n          case \"paddingLeft\":\n        \n          case \"paddingRight\":\n        \n          case \"paddingTop\":\n        \n          case \"bottom\":\n        \n          case \"left\":\n        \n          case \"right\":\n        \n          case \"top\":\n        \n          case \"scrollTop\":\n        \n          case \"scrollLeft\":\n            m = parseInt(m, 10);\n            break;\n          default:\n            throw new Error((l + \" is not a supported attribute!\"));\n        };\n        if ((this.state.attrs[l] === undefined)) {\n            this.state.attrs[l] = {\n            };\n        };\n        if (o) {\n            this.state.attrs[l].auto = true;\n        };\n        switch (n) {\n          case k.ATTR_FROM:\n            this.state.attrs[l].start = m;\n            break;\n          case k.ATTR_BY:\n            this.state.attrs[l].by = true;\n          case k.ATTR_TO:\n            this.state.attrs[l].value = m;\n            break;\n        };\n    };\n    k._get_box_width = function(l) {\n        var m = parseInt(i.get(l, \"paddingLeft\"), 10), n = parseInt(i.get(l, \"paddingRight\"), 10), o = parseInt(i.get(l, \"borderLeftWidth\"), 10), p = parseInt(i.get(l, \"borderRightWidth\"), 10);\n        return ((((l.offsetWidth - ((m ? m : 0))) - ((n ? n : 0))) - ((o ? o : 0))) - ((p ? p : 0)));\n    };\n    k._get_box_height = function(l) {\n        var m = parseInt(i.get(l, \"paddingTop\"), 10), n = parseInt(i.get(l, \"paddingBottom\"), 10), o = parseInt(i.get(l, \"borderTopWidth\"), 10), p = parseInt(i.get(l, \"borderBottomWidth\"), 10);\n        return ((((l.offsetHeight - ((m ? m : 0))) - ((n ? n : 0))) - ((o ? o : 0))) - ((p ? p : 0)));\n    };\n    k.prototype.to = function(l, m) {\n        if ((m === undefined)) {\n            this._attr(this.last_attr, l, k.ATTR_TO);\n        }\n         else {\n            this._attr(l, m, k.ATTR_TO);\n            this.last_attr = l;\n        }\n    ;\n        return this;\n    };\n    k.prototype.by = function(l, m) {\n        if ((m === undefined)) {\n            this._attr(this.last_attr, l, k.ATTR_BY);\n        }\n         else {\n            this._attr(l, m, k.ATTR_BY);\n            this.last_attr = l;\n        }\n    ;\n        return this;\n    };\n    k.prototype.from = function(l, m) {\n        if ((m === undefined)) {\n            this._attr(this.last_attr, l, k.ATTR_FROM);\n        }\n         else {\n            this._attr(l, m, k.ATTR_FROM);\n            this.last_attr = l;\n        }\n    ;\n        return this;\n    };\n    k.prototype.duration = function(l) {\n        this.state.duration = (l ? l : 0);\n        return this;\n    };\n    k.prototype.checkpoint = function(l, m) {\n        if ((l === undefined)) {\n            l = 1;\n        };\n        this.state.checkpoint = l;\n        this.queue.push(this.state);\n        this._reset_state();\n        this.state.checkpointcb = m;\n        return this;\n    };\n    k.prototype.blind = function() {\n        this.state.blind = true;\n        return this;\n    };\n    k.prototype.hide = function() {\n        this.state.hide = true;\n        return this;\n    };\n    k.prototype.show = function() {\n        this.state.show = true;\n        return this;\n    };\n    k.prototype.ease = function(l) {\n        this.state.ease = l;\n        return this;\n    };\n    k.prototype.go = function() {\n        var l = (new Date()).getTime();\n        this.queue.push(this.state);\n        for (var m = 0; (m < this.queue.length); m++) {\n            this.queue[m].start = (l - k.offset);\n            if (this.queue[m].checkpoint) {\n                l += (this.queue[m].checkpoint * this.queue[m].duration);\n            };\n        };\n        k.push(this);\n        return this;\n    };\n    k.prototype._show = function() {\n        g.show(this.obj);\n    };\n    k.prototype._hide = function() {\n        g.hide(this.obj);\n    };\n    k.prototype._frame = function(l) {\n        var m = true, n = false, o = false, p;\n        function q(aa) {\n            return (document.documentElement[aa] || document.body[aa]);\n        };\n        for (var r = 0; (r < this.queue.length); r++) {\n            var s = this.queue[r];\n            if ((s.start > l)) {\n                m = false;\n                continue;\n            }\n        ;\n            if (s.checkpointcb) {\n                this._callback(s.checkpointcb, (l - s.start));\n                s.checkpointcb = null;\n            }\n        ;\n            if ((s.started === undefined)) {\n                if (s.show) {\n                    this._show();\n                };\n                for (var t in s.attrs) {\n                    if ((s.attrs[t].start !== undefined)) {\n                        continue;\n                    };\n                    switch (t) {\n                      case \"backgroundColor\":\n                    \n                      case \"borderColor\":\n                    \n                      case \"color\":\n                        p = k.parse_color(i.get(this.obj, ((t == \"borderColor\") ? \"borderLeftColor\" : t)));\n                        if (s.attrs[t].by) {\n                            s.attrs[t].value[0] = Math.min(255, Math.max(0, (s.attrs[t].value[0] + p[0])));\n                            s.attrs[t].value[1] = Math.min(255, Math.max(0, (s.attrs[t].value[1] + p[1])));\n                            s.attrs[t].value[2] = Math.min(255, Math.max(0, (s.attrs[t].value[2] + p[2])));\n                        }\n                    ;\n                        break;\n                      case \"opacity\":\n                        p = i.getOpacity(this.obj);\n                        if (s.attrs[t].by) {\n                            s.attrs[t].value = Math.min(1, Math.max(0, (s.attrs[t].value + p)));\n                        };\n                        break;\n                      case \"height\":\n                        p = k._get_box_height(this.obj);\n                        if (s.attrs[t].by) {\n                            s.attrs[t].value += p;\n                        };\n                        break;\n                      case \"width\":\n                        p = k._get_box_width(this.obj);\n                        if (s.attrs[t].by) {\n                            s.attrs[t].value += p;\n                        };\n                        break;\n                      case \"scrollLeft\":\n                    \n                      case \"scrollTop\":\n                        p = (((this.obj === document.body)) ? q(t) : this.obj[t]);\n                        if (s.attrs[t].by) {\n                            s.attrs[t].value += p;\n                        };\n                        s[(\"last\" + t)] = p;\n                        break;\n                      default:\n                        p = (parseInt(i.get(this.obj, t), 10) || 0);\n                        if (s.attrs[t].by) {\n                            s.attrs[t].value += p;\n                        };\n                        break;\n                    };\n                    s.attrs[t].start = p;\n                };\n                if ((((s.attrs.height && s.attrs.height.auto)) || ((s.attrs.width && s.attrs.width.auto)))) {\n                    if ((j.firefox() < 3)) {\n                        o = true;\n                    };\n                    this._destroy_container();\n                    for (var t in {\n                        height: 1,\n                        width: 1,\n                        fontSize: 1,\n                        borderLeftWidth: 1,\n                        borderRightWidth: 1,\n                        borderTopWidth: 1,\n                        borderBottomWidth: 1,\n                        paddingLeft: 1,\n                        paddingRight: 1,\n                        paddingTop: 1,\n                        paddingBottom: 1\n                    }) {\n                        if (s.attrs[t]) {\n                            this.obj.style[t] = (s.attrs[t].value + (((typeof s.attrs[t].value == \"number\") ? \"px\" : \"\")));\n                        };\n                    };\n                    if ((s.attrs.height && s.attrs.height.auto)) {\n                        s.attrs.height.value = k._get_box_height(this.obj);\n                    };\n                    if ((s.attrs.width && s.attrs.width.auto)) {\n                        s.attrs.width.value = k._get_box_width(this.obj);\n                    };\n                }\n            ;\n                s.started = true;\n                if (s.blind) {\n                    this._build_container();\n                };\n            }\n        ;\n            var u = (((l - s.start)) / s.duration);\n            if ((u >= 1)) {\n                u = 1;\n                if (s.hide) {\n                    this._hide();\n                };\n            }\n             else m = false;\n        ;\n            var v = (s.ease ? s.ease(u) : u);\n            if (((!n && (u != 1)) && s.blind)) {\n                n = true;\n            };\n            if ((o && this.obj.parentNode)) {\n                var w = this.obj.parentNode, x = this.obj.nextSibling;\n                w.removeChild(this.obj);\n            }\n        ;\n            for (var t in s.attrs) {\n                switch (t) {\n                  case \"backgroundColor\":\n                \n                  case \"borderColor\":\n                \n                  case \"color\":\n                    if ((s.attrs[t].start[3] != s.attrs[t].value[3])) {\n                        this.obj.style[t] = ((((((((\"rgba(\" + k.calc_tween(v, s.attrs[t].start[0], s.attrs[t].value[0], true)) + \",\") + k.calc_tween(v, s.attrs[t].start[1], s.attrs[t].value[1], true)) + \",\") + k.calc_tween(v, s.attrs[t].start[2], s.attrs[t].value[2], true)) + \",\") + k.calc_tween(v, s.attrs[t].start[3], s.attrs[t].value[3], false)) + \")\");\n                    }\n                     else this.obj.style[t] = ((((((\"rgb(\" + k.calc_tween(v, s.attrs[t].start[0], s.attrs[t].value[0], true)) + \",\") + k.calc_tween(v, s.attrs[t].start[1], s.attrs[t].value[1], true)) + \",\") + k.calc_tween(v, s.attrs[t].start[2], s.attrs[t].value[2], true)) + \")\");\n                ;\n                    break;\n                  case \"opacity\":\n                    i.set(this.obj, \"opacity\", k.calc_tween(v, s.attrs[t].start, s.attrs[t].value));\n                    break;\n                  case \"height\":\n                \n                  case \"width\":\n                    this.obj.style[t] = (((v == 1) && s.attrs[t].auto) ? \"auto\" : (k.calc_tween(v, s.attrs[t].start, s.attrs[t].value, true) + \"px\"));\n                    break;\n                  case \"scrollLeft\":\n                \n                  case \"scrollTop\":\n                    var y = (this.obj === document.body);\n                    p = (y ? q(t) : this.obj[t]);\n                    if ((s[(\"last\" + t)] !== p)) {\n                        delete s.attrs[t];\n                    }\n                     else {\n                        var z = k.calc_tween(v, s.attrs[t].start, s.attrs[t].value, true);\n                        if (!y) {\n                            z = this.obj[t] = z;\n                        }\n                         else {\n                            if ((t == \"scrollLeft\")) {\n                                a.scrollTo(z, q(\"scrollTop\"));\n                            }\n                             else a.scrollTo(q(\"scrollLeft\"), z);\n                        ;\n                            z = q(t);\n                        }\n                    ;\n                        s[(\"last\" + t)] = z;\n                    }\n                ;\n                    break;\n                  default:\n                    this.obj.style[t] = (k.calc_tween(v, s.attrs[t].start, s.attrs[t].value, true) + \"px\");\n                    break;\n                };\n            };\n            if ((u == 1)) {\n                this.queue.splice(r--, 1);\n                this._callback(s.ondone, ((l - s.start) - s.duration));\n            }\n        ;\n        };\n        if (o) {\n            w[(x ? \"insertBefore\" : \"appendChild\")](this.obj, x);\n        };\n        if ((!n && this.container_div)) {\n            this._destroy_container();\n        };\n        return !m;\n    };\n    k.prototype.ondone = function(l) {\n        this.state.ondone = l;\n        return this;\n    };\n    k.prototype._callback = function(l, m) {\n        if (l) {\n            k.offset = m;\n            l.call(this);\n            k.offset = 0;\n        }\n    ;\n    };\n    k.calc_tween = function(l, m, n, o) {\n        return ((o ? parseInt : parseFloat))(((((n - m)) * l) + m), 10);\n    };\n    k.parse_color = function(l) {\n        var m = /^#([a-f0-9]{1,2})([a-f0-9]{1,2})([a-f0-9]{1,2})$/i.exec(l);\n        if (m) {\n            return [parseInt(((m[1].length == 1) ? (m[1] + m[1]) : m[1]), 16),parseInt(((m[2].length == 1) ? (m[2] + m[2]) : m[2]), 16),parseInt(((m[3].length == 1) ? (m[3] + m[3]) : m[3]), 16),1,];\n        }\n         else {\n            var n = /^rgba? *\\(([0-9]+), *([0-9]+), *([0-9]+)(?:, *([0-9]+))?\\)$/.exec(l);\n            if (n) {\n                return [parseInt(n[1], 10),parseInt(n[2], 10),parseInt(n[3], 10),(n[4] ? parseFloat(n[4]) : 1),];\n            }\n             else if ((l == \"transparent\")) {\n                return [255,255,255,0,];\n            }\n             else throw \"Named color attributes are not supported.\"\n            \n        ;\n        }\n    ;\n    };\n    k.parse_group = function(l) {\n        l = l.trim().split(/ +/);\n        if ((l.length == 4)) {\n            return l;\n        }\n         else if ((l.length == 3)) {\n            return [l[0],l[1],l[2],l[1],];\n        }\n         else if ((l.length == 2)) {\n            return [l[0],l[1],l[0],l[1],];\n        }\n         else return [l[0],l[0],l[0],l[0],]\n        \n        \n    ;\n    };\n    k.push = function(l) {\n        if (!k.active) {\n            k.active = [];\n        };\n        k.active.push(l);\n        if ((k.active.length === 1)) {\n            if (!k.requestAnimationFrame) {\n                var m = ((a.requestAnimationFrame || a.webkitRequestAnimationFrame) || a.mozRequestAnimationFrame);\n                if (m) {\n                    k.requestAnimationFrame = m.bind(a);\n                };\n            }\n        ;\n            if (k.requestAnimationFrame) {\n                k.requestAnimationFrame(k._animate);\n            }\n             else k.timeout = setInterval(k._animate, k.resolution, false);\n        ;\n        }\n    ;\n        if (k.requestAnimationFrame) {\n            k._updateEndingTimer();\n        };\n        k._animate(Date.now(), true);\n    };\n    k._updateEndingTimer = function() {\n        if (!k.requestAnimationFrame) {\n            throw new Error(\"Ending timer only valid with requestAnimationFrame\")\n        };\n        var l = 0;\n        for (var m = 0; (m < k.active.length); m++) {\n            var n = k.active[m];\n            for (var o = 0; (o < n.queue.length); o++) {\n                var p = (n.queue[o].start + n.queue[o].duration);\n                if ((p > l)) {\n                    l = p;\n                };\n            };\n        };\n        if (k.timeout) {\n            clearTimeout(k.timeout);\n            delete k.timeout;\n        }\n    ;\n        var q = Date.now();\n        if ((l > q)) {\n            k.timeout = setTimeout(k._animate.shield(), (l - q), false);\n        };\n    };\n    k._animate = function(l, m) {\n        l = (l || Date.now());\n        for (var n = (((m === true)) ? (k.active.length - 1) : 0); (n < k.active.length); n++) {\n            try {\n                if (!k.active[n]._frame(l)) {\n                    k.active.splice(n--, 1);\n                };\n            } catch (o) {\n                k.active.splice(n--, 1);\n            };\n        };\n        if ((k.active.length === 0)) {\n            if (k.timeout) {\n                if (k.requestAnimationFrame) {\n                    clearTimeout(k.timeout);\n                }\n                 else clearInterval(k.timeout);\n            ;\n                delete k.timeout;\n            }\n        ;\n        }\n         else if (k.requestAnimationFrame) {\n            k.requestAnimationFrame(k._animate);\n        }\n    ;\n    };\n    k.ease = {\n    };\n    k.ease.begin = function(l) {\n        return (Math.sin(((Math.PI / 2) * ((l - 1)))) + 1);\n    };\n    k.ease.end = function(l) {\n        return Math.sin(((59718 * Math.PI) * l));\n    };\n    k.ease.both = function(l) {\n        return ((59765 * Math.sin((Math.PI * ((l - 59788))))) + 59793);\n    };\n    k.prependInsert = function(l, m) {\n        k.insert(l, m, h.prependContent);\n    };\n    k.appendInsert = function(l, m) {\n        k.insert(l, m, h.appendContent);\n    };\n    k.insert = function(l, m, n) {\n        i.set(m, \"opacity\", 0);\n        n(l, m);\n        new k(m).from(\"opacity\", 0).to(\"opacity\", 1).duration(400).go();\n    };\n    e.exports = k;\n});\n__d(\"CSSSupport\", [], function(a, b, c, d, e, f) {\n    var g = {\n        supportsBorderRadius: function() {\n            var h = [\"KhtmlBorderRadius\",\"OBorderRadius\",\"MozBorderRadius\",\"WebkitBorderRadius\",\"msBorderRadius\",\"borderRadius\",], i = false, j = document.createElement(\"div\");\n            for (var k = h.length; (k >= 0); k--) {\n                if (i = (j.style[h[k]] !== undefined)) {\n                    break;\n                };\n            };\n            g.supportsBorderRadius = bagof(i);\n            return i;\n        }\n    };\n    e.exports = g;\n});\n__d(\"Keys\", [], function(a, b, c, d, e, f) {\n    var g = {\n        BACKSPACE: 8,\n        TAB: 9,\n        RETURN: 13,\n        ESC: 27,\n        SPACE: 32,\n        PAGE_UP: 33,\n        PAGE_DOWN: 34,\n        END: 35,\n        HOME: 36,\n        LEFT: 37,\n        UP: 38,\n        RIGHT: 39,\n        DOWN: 40,\n        DELETE: 46,\n        COMMA: 188\n    };\n    e.exports = g;\n});\n__d(\"Locale\", [\"Style\",], function(a, b, c, d, e, f) {\n    var g = b(\"Style\"), h, i = {\n        isRTL: function() {\n            if ((h === undefined)) {\n                h = ((\"rtl\" === g.get(document.body, \"direction\")));\n            };\n            return h;\n        }\n    };\n    e.exports = i;\n});\n__d(\"Vector\", [\"event-extensions\",\"DOMDimensions\",\"DOMPosition\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"DOMDimensions\"), h = b(\"DOMPosition\"), i = b(\"copyProperties\");\n    function j(k, l, m) {\n        i(this, {\n            x: parseFloat(k),\n            y: parseFloat(l),\n            domain: (m || \"pure\")\n        });\n    };\n    i(j.prototype, {\n        toString: function() {\n            return ((((\"(\" + this.x) + \", \") + this.y) + \")\");\n        },\n        add: function(k, l) {\n            if ((arguments.length == 1)) {\n                if ((k.domain != \"pure\")) {\n                    k = k.convertTo(this.domain);\n                };\n                return this.add(k.x, k.y);\n            }\n        ;\n            var m = parseFloat(k), n = parseFloat(l);\n            return new j((this.x + m), (this.y + n), this.domain);\n        },\n        mul: function(k, l) {\n            if ((typeof l == \"undefined\")) {\n                l = k;\n            };\n            return new j((this.x * k), (this.y * l), this.domain);\n        },\n        sub: function(k, l) {\n            if ((arguments.length == 1)) {\n                return this.add(k.mul(-1));\n            }\n             else return this.add(-k, -l)\n        ;\n        },\n        distanceTo: function(k) {\n            return this.sub(k).magnitude();\n        },\n        magnitude: function() {\n            return Math.sqrt((((this.x * this.x)) + ((this.y * this.y))));\n        },\n        convertTo: function(k) {\n            if ((((k != \"pure\") && (k != \"viewport\")) && (k != \"document\"))) {\n                return new j(0, 0)\n            };\n            if ((k == this.domain)) {\n                return new j(this.x, this.y, this.domain)\n            };\n            if ((k == \"pure\")) {\n                return new j(this.x, this.y)\n            };\n            if ((this.domain == \"pure\")) {\n                return new j(0, 0)\n            };\n            var l = j.getScrollPosition(\"document\"), m = this.x, n = this.y;\n            if ((this.domain == \"document\")) {\n                m -= l.x;\n                n -= l.y;\n            }\n             else {\n                m += l.x;\n                n += l.y;\n            }\n        ;\n            return new j(m, n, k);\n        },\n        setElementPosition: function(k) {\n            var l = this.convertTo(\"document\");\n            k.style.left = (parseInt(l.x) + \"px\");\n            k.style.top = (parseInt(l.y) + \"px\");\n            return this;\n        },\n        setElementDimensions: function(k) {\n            return this.setElementWidth(k).setElementHeight(k);\n        },\n        setElementWidth: function(k) {\n            k.style.width = (parseInt(this.x, 10) + \"px\");\n            return this;\n        },\n        setElementHeight: function(k) {\n            k.style.height = (parseInt(this.y, 10) + \"px\");\n            return this;\n        },\n        scrollElementBy: function(k) {\n            if ((k == document.body)) {\n                window.scrollBy(this.x, this.y);\n            }\n             else {\n                k.scrollLeft += this.x;\n                k.scrollTop += this.y;\n            }\n        ;\n            return this;\n        }\n    });\n    i(j, {\n        getEventPosition: function(k, l) {\n            l = (l || \"document\");\n            var m = Event.getPosition(k), n = new j(m.x, m.y, \"document\");\n            return n.convertTo(l);\n        },\n        getScrollPosition: function(k) {\n            k = (k || \"document\");\n            var l = h.getScrollPosition();\n            return new j(l.x, l.y, \"document\").convertTo(k);\n        },\n        getElementPosition: function(k, l) {\n            l = (l || \"document\");\n            var m = h.getElementPosition(k);\n            return new j(m.x, m.y, \"viewport\").convertTo(l);\n        },\n        getElementDimensions: function(k) {\n            var l = g.getElementDimensions(k);\n            return new j(l.width, l.height);\n        },\n        getViewportDimensions: function() {\n            var k = g.getViewportDimensions();\n            return new j(k.width, k.height, \"viewport\");\n        },\n        getDocumentDimensions: function(k) {\n            var l = g.getDocumentDimensions(k);\n            return new j(l.width, l.height, \"document\");\n        },\n        deserialize: function(k) {\n            var l = k.split(\",\");\n            return new j(l[0], l[1]);\n        }\n    });\n    e.exports = j;\n});\n__d(\"getOverlayZIndex\", [\"Style\",], function(a, b, c, d, e, f) {\n    var g = b(\"Style\");\n    function h(i, j) {\n        j = (j || document.body);\n        var k = [];\n        while ((i && (i !== j))) {\n            k.push(i);\n            i = i.parentNode;\n        };\n        if ((i !== j)) {\n            return 0\n        };\n        for (var l = (k.length - 1); (l >= 0); l--) {\n            var m = k[l];\n            if ((g.get(m, \"position\") != \"static\")) {\n                var n = parseInt(g.get(m, \"z-index\"), 10);\n                if (!isNaN(n)) {\n                    return n\n                };\n            }\n        ;\n        };\n        return 0;\n    };\n    e.exports = h;\n});\n__d(\"Dialog\", [\"array-extensions\",\"event-extensions\",\"AjaxPipeRequest\",\"Animation\",\"Arbiter\",\"AsyncRequest\",\"Bootloader\",\"Button\",\"CSS\",\"CSSSupport\",\"DOM\",\"Form\",\"HTML\",\"Input\",\"Keys\",\"Locale\",\"Parent\",\"Run\",\"Style\",\"URI\",\"UserAgent\",\"Vector\",\"bind\",\"copyProperties\",\"createArrayFrom\",\"getObjectValues\",\"getOverlayZIndex\",\"tx\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    var g = b(\"AjaxPipeRequest\"), h = b(\"Animation\"), i = b(\"Arbiter\"), j = b(\"AsyncRequest\"), k = b(\"Bootloader\"), l = b(\"Button\"), m = b(\"CSS\"), n = b(\"CSSSupport\"), o = b(\"DOM\"), p = b(\"Form\"), q = b(\"HTML\"), r = b(\"Input\"), s = b(\"Keys\"), t = b(\"Locale\"), u = b(\"Parent\"), v = b(\"Run\"), w = b(\"Style\"), x = b(\"URI\"), y = b(\"UserAgent\"), z = b(\"Vector\"), aa = b(\"bind\"), ba = b(\"copyProperties\"), ca = b(\"createArrayFrom\"), da = b(\"getObjectValues\"), ea = b(\"getOverlayZIndex\"), fa = b(\"tx\"), ga = function() {\n        var ia = document.body, ja = document.createElement(\"div\"), ka = document.createElement(\"div\");\n        ia.insertBefore(ja, ia.firstChild);\n        ia.insertBefore(ka, ia.firstChild);\n        ja.style.position = \"fixed\";\n        ja.style.top = \"20px\";\n        var la = (ja.offsetTop !== ka.offsetTop);\n        ia.removeChild(ja);\n        ia.removeChild(ka);\n        ga = bagof(la);\n        return la;\n    };\n    function ha(ia) {\n        this._show_loading = true;\n        this._auto_focus = true;\n        this._submit_on_enter = false;\n        this._fade_enabled = true;\n        this._onload_handlers = [];\n        this._top = 125;\n        this._uniqueID = (\"dialog_\" + ha._globalCount++);\n        this._content = null;\n        this._obj = null;\n        this._popup = null;\n        this._overlay = null;\n        this._shim = null;\n        this._causal_elem = null;\n        this._previous_focus = null;\n        this._buttons = [];\n        this._buildDialog();\n        if (ia) {\n            this._setFromModel(ia);\n        };\n        ha._init();\n    };\n    ba(ha, {\n        OK: {\n            name: \"ok\",\n            label: \"Okay\"\n        },\n        CANCEL: {\n            name: \"cancel\",\n            label: \"Cancel\",\n            className: \"inputaux\"\n        },\n        CLOSE: {\n            name: \"close\",\n            label: \"Close\"\n        },\n        NEXT: {\n            name: \"next\",\n            label: \"Next\"\n        },\n        SAVE: {\n            name: \"save\",\n            label: \"Save\"\n        },\n        SUBMIT: {\n            name: \"submit\",\n            label: \"Submit\"\n        },\n        CONFIRM: {\n            name: \"confirm\",\n            label: \"Confirm\"\n        },\n        DELETE: {\n            name: \"delete\",\n            label: \"Delete\"\n        },\n        _globalCount: 0,\n        _bottoms: [0,],\n        max_bottom: 0,\n        _updateMaxBottom: function() {\n            ha.max_bottom = Math.max.apply(Math, ha._bottoms);\n        }\n    });\n    ba(ha, {\n        OK_AND_CANCEL: [ha.OK,ha.CANCEL,],\n        _STANDARD_BUTTONS: [ha.OK,ha.CANCEL,ha.CLOSE,ha.SAVE,ha.SUBMIT,ha.CONFIRM,ha.DELETE,],\n        SIZE: {\n            WIDE: 555,\n            STANDARD: 445\n        },\n        _HALO_WIDTH: 10,\n        _BORDER_WIDTH: 1,\n        _PADDING_WIDTH: 10,\n        _PAGE_MARGIN: 40,\n        _stack: [],\n        _isUsingCSSBorders: function() {\n            return (n.supportsBorderRadius() || (y.ie() < 7));\n        },\n        newButton: function(ia, ja, ka, la) {\n            var ma = {\n                name: ia,\n                label: ja\n            };\n            if (ka) {\n                ma.className = ka;\n            };\n            if (la) {\n                ma.handler = la;\n            };\n            return ma;\n        },\n        getCurrent: function() {\n            var ia = ha._stack;\n            return (ia.length ? ia[(ia.length - 1)] : null);\n        },\n        hideCurrent: function() {\n            var ia = ha.getCurrent();\n            (ia && ia.hide());\n        },\n        bootstrap: function(ia, ja, ka, la, ma, na) {\n            ja = (ja || {\n            });\n            ba(ja, new x(ia).getQueryData());\n            la = (la || ((ka ? \"GET\" : \"POST\")));\n            var oa = (u.byClass(na, \"stat_elem\") || na);\n            if ((oa && m.hasClass(oa, \"async_saving\"))) {\n                return false\n            };\n            var pa = new j().setReadOnly(!!ka).setMethod(la).setRelativeTo(na).setStatusElement(oa).setURI(ia).setNectarModuleDataSafe(na).setData(ja), qa = new ha(ma).setCausalElement(na).setAsync(pa);\n            qa.show();\n            return false;\n        },\n        showFromModel: function(ia, ja) {\n            var ka = new ha(ia).setCausalElement(ja).show();\n            if (ia.hiding) {\n                ka.hide();\n            };\n        },\n        _init: function() {\n            this._init = bagofholding;\n            v.onLeave(ha._tearDown.shield(null, false));\n            i.subscribe(\"page_transition\", ha._tearDown.shield(null, true));\n            Event.listen(document.documentElement, \"keydown\", function(event) {\n                if (((Event.getKeyCode(event) == s.ESC) && !event.getModifiers().any)) {\n                    if (ha._escape()) {\n                        event.kill();\n                    };\n                }\n                 else if (((Event.getKeyCode(event) == s.RETURN) && !event.getModifiers().any)) {\n                    if (ha._enter()) {\n                        event.kill();\n                    }\n                }\n            ;\n            });\n            Event.listen(window, \"resize\", function(event) {\n                var ia = ha.getCurrent();\n                (ia && ia._resetDialogObj());\n            });\n        },\n        _findButton: function(ia, ja) {\n            if (ia) {\n                for (var ka = 0; (ka < ia.length); ++ka) {\n                    if ((ia[ka].name == ja)) {\n                        return ia[ka]\n                    };\n                }\n            };\n            return null;\n        },\n        _tearDown: function(ia) {\n            var ja = ha._stack.slice();\n            for (var ka = (ja.length - 1); (ka >= 0); ka--) {\n                if ((((ia && !ja[ka]._cross_transition)) || ((!ia && !ja[ka]._cross_quickling)))) {\n                    ja[ka].hide();\n                };\n            };\n        },\n        _escape: function() {\n            var ia = ha.getCurrent();\n            if (!ia) {\n                return false\n            };\n            var ja = ia._semi_modal, ka = ia._buttons;\n            if ((!ka.length && !ja)) {\n                return false\n            };\n            if ((ja && !ka.length)) {\n                ia.hide();\n                return true;\n            }\n        ;\n            var la, ma = ha._findButton(ka, \"cancel\");\n            if (ia._cancelHandler) {\n                ia.cancel();\n                return true;\n            }\n             else if (ma) {\n                la = ma;\n            }\n             else if ((ka.length == 1)) {\n                la = ka[0];\n            }\n             else return false\n            \n            \n        ;\n            ia._handleButton(la);\n            return true;\n        },\n        _enter: function() {\n            var ia = ha.getCurrent();\n            if ((!ia || !ia._submit_on_enter)) {\n                return false\n            };\n            if ((document.activeElement != ia._frame)) {\n                return false\n            };\n            var ja = ia._buttons;\n            if (!ja) {\n                return false\n            };\n            ia._handleButton(ja[0]);\n            return true;\n        },\n        call_or_eval: function(ia, ja, ka) {\n            if (!ja) {\n                return undefined\n            };\n            ka = (ka || {\n            });\n            if ((typeof ja == \"string\")) {\n                var la = Object.keys(ka).join(\", \");\n                ja = (eval)(((((\"({f: function(\" + la) + \") { \") + ja) + \"}})\")).f;\n            }\n        ;\n            return ja.apply(ia, da(ka));\n        }\n    });\n    ba(ha.prototype, {\n        _cross_quickling: false,\n        _cross_transition: false,\n        _loading: false,\n        _showing: false,\n        show: function() {\n            this._showing = true;\n            if (this._async_request) {\n                if (this._show_loading) {\n                    this.showLoading();\n                };\n            }\n             else this._update();\n        ;\n            return this;\n        },\n        showLoading: function() {\n            this._loading = true;\n            m.addClass(this._frame, \"dialog_loading_shown\");\n            this._renderDialog();\n            return this;\n        },\n        hide: function() {\n            if ((!this._showing && !this._loading)) {\n                return this\n            };\n            this._showing = false;\n            if (this._autohide_timeout) {\n                clearTimeout(this._autohide_timeout);\n                this._autohide_timeout = null;\n            }\n        ;\n            if ((this._fade_enabled && (ha._stack.length <= 1))) {\n                this._fadeOut();\n            }\n             else this._hide();\n        ;\n            return this;\n        },\n        cancel: function() {\n            if ((!this._cancelHandler || (this._cancelHandler() !== false))) {\n                this.hide();\n            };\n        },\n        getRoot: function() {\n            return this._obj;\n        },\n        getBody: function() {\n            return o.scry(this._obj, \"div.dialog_body\")[0];\n        },\n        getButtonElement: function(ia) {\n            if ((typeof ia == \"string\")) {\n                ia = ha._findButton(this._buttons, ia);\n            };\n            if ((!ia || !ia.name)) {\n                return null\n            };\n            var ja = o.scry(this._popup, \"input\"), ka = function(la) {\n                return (la.name == ia.name);\n            };\n            return (ja.filter(ka)[0] || null);\n        },\n        getContentNode: function() {\n            return o.find(this._content, \"div.dialog_content\");\n        },\n        getFormData: function() {\n            return p.serialize(this.getContentNode());\n        },\n        setAllowCrossPageTransition: function(ia) {\n            this._cross_transition = ia;\n            return this;\n        },\n        setAllowCrossQuicklingNavigation: function(ia) {\n            this._cross_quickling = ia;\n            return this;\n        },\n        setShowing: function() {\n            this.show();\n            return this;\n        },\n        setHiding: function() {\n            this.hide();\n            return this;\n        },\n        setTitle: function(ia) {\n            var ja = this._nodes.title, ka = this._nodes.title_inner, la = this._nodes.content;\n            o.setContent(ka, this._format((ia || \"\")));\n            m.conditionShow(ja, !!ia);\n            m.conditionClass(la, \"dialog_content_titleless\", !ia);\n            return this;\n        },\n        setBody: function(ia) {\n            o.setContent(this._nodes.body, this._format(ia));\n            return this;\n        },\n        setExtraData: function(ia) {\n            this._extra_data = ia;\n            return this;\n        },\n        setReturnData: function(ia) {\n            this._return_data = ia;\n            return this;\n        },\n        setShowLoading: function(ia) {\n            this._show_loading = ia;\n            return this;\n        },\n        setFullBleed: function(ia) {\n            this._full_bleed = ia;\n            this._updateWidth();\n            m.conditionClass(this._obj, \"full_bleed\", ia);\n            return this;\n        },\n        setCausalElement: function(ia) {\n            this._causal_elem = ia;\n            return this;\n        },\n        setUserData: function(ia) {\n            this._user_data = ia;\n            return this;\n        },\n        getUserData: function() {\n            return this._user_data;\n        },\n        setAutohide: function(ia) {\n            if (ia) {\n                if (this._showing) {\n                    this._autohide_timeout = setTimeout(this.hide.shield(this), ia);\n                }\n                 else this._autohide = ia;\n            ;\n            }\n             else {\n                this._autohide = null;\n                if (this._autohide_timeout) {\n                    clearTimeout(this._autohide_timeout);\n                    this._autohide_timeout = null;\n                }\n            ;\n            }\n        ;\n            return this;\n        },\n        setSummary: function(ia) {\n            var ja = this._nodes.summary;\n            o.setContent(ja, this._format((ia || \"\")));\n            m.conditionShow(ja, !!ia);\n            return this;\n        },\n        setButtons: function(ia) {\n            var ja, ka;\n            if (!((ia instanceof Array))) {\n                ja = ca(arguments);\n            }\n             else ja = ia;\n        ;\n            for (var la = 0; (la < ja.length); ++la) {\n                if ((typeof ja[la] == \"string\")) {\n                    ka = ha._findButton(ha._STANDARD_BUTTONS, ja[la]);\n                    ja[la] = ka;\n                }\n            ;\n            };\n            this._buttons = ja;\n            var ma = [];\n            if ((ja && (ja.length > 0))) {\n                for (var na = 0; (na < ja.length); na++) {\n                    ka = ja[na];\n                    var oa = o.create(\"input\", {\n                        type: \"button\",\n                        name: (ka.name || \"\"),\n                        value: ka.label\n                    }), pa = o.create(\"label\", {\n                        className: \"uiButton uiButtonLarge uiButtonConfirm\"\n                    }, oa);\n                    if (ka.className) {\n                        ka.className.split(/\\s+/).forEach(function(ra) {\n                            m.addClass(pa, ra);\n                        });\n                        if (m.hasClass(pa, \"inputaux\")) {\n                            m.removeClass(pa, \"inputaux\");\n                            m.removeClass(pa, \"uiButtonConfirm\");\n                        }\n                    ;\n                        if (m.hasClass(pa, \"uiButtonSpecial\")) {\n                            m.removeClass(pa, \"uiButtonConfirm\");\n                        };\n                    }\n                ;\n                    if (ka.icon) {\n                        o.prependContent(pa, o.create(\"img\", {\n                            src: ka.icon,\n                            className: \"img mrs\"\n                        }));\n                    };\n                    if (ka.disabled) {\n                        l.setEnabled(pa, false);\n                    };\n                    Event.listen(oa, \"click\", this._handleButton.bind(this, ka.name));\n                    for (var qa in ka) {\n                        if (((qa.indexOf(\"data-\") === 0) && (qa.length > 5))) {\n                            oa.setAttribute(qa, ka[qa]);\n                        };\n                    };\n                    ma.push(pa);\n                }\n            };\n            o.setContent(this._nodes.buttons, ma);\n            this._updateButtonVisibility();\n            return this;\n        },\n        setButtonsMessage: function(ia) {\n            o.setContent(this._nodes.button_message, this._format((ia || \"\")));\n            this._has_button_message = !!ia;\n            this._updateButtonVisibility();\n            return this;\n        },\n        _updateButtonVisibility: function() {\n            var ia = ((this._buttons.length > 0) || this._has_button_message);\n            m.conditionShow(this._nodes.button_wrapper, ia);\n            m.conditionClass(this._obj, \"omitDialogFooter\", !ia);\n        },\n        setClickButtonOnEnter: function(ia, ja) {\n            this._clickOnEnterTarget = ia;\n            if (!this._clickOnEnterListener) {\n                this._clickOnEnterListener = Event.listen(this._nodes.body, \"keypress\", function(event) {\n                    var ka = event.getTarget();\n                    if ((ka && (ka.id === this._clickOnEnterTarget))) {\n                        if ((Event.getKeyCode(event) == s.RETURN)) {\n                            this._handleButton(ja);\n                            event.kill();\n                        }\n                    \n                    };\n                    return true;\n                }.bind(this));\n            };\n            return this;\n        },\n        setStackable: function(ia, ja) {\n            this._is_stackable = ia;\n            this._shown_while_stacked = (ia && ja);\n            return this;\n        },\n        setHandler: function(ia) {\n            this._handler = ia;\n            return this;\n        },\n        setCancelHandler: function(ia) {\n            this._cancelHandler = ha.call_or_eval.bind(null, this, ia);\n            return this;\n        },\n        setCloseHandler: function(ia) {\n            this._close_handler = ha.call_or_eval.bind(null, this, ia);\n            return this;\n        },\n        clearHandler: function() {\n            return this.setHandler(null);\n        },\n        setPostURI: function(ia, ja) {\n            if ((ja === undefined)) {\n                ja = true;\n            };\n            if (ja) {\n                this.setHandler(this._submitForm.bind(this, \"POST\", ia));\n            }\n             else this.setHandler(function() {\n                p.post(ia, this.getFormData());\n                this.hide();\n            }.bind(this));\n        ;\n            return this;\n        },\n        setGetURI: function(ia) {\n            this.setHandler(this._submitForm.bind(this, \"GET\", ia));\n            return this;\n        },\n        setModal: function(ia) {\n            this._modal = ia;\n            m.conditionClass(this._obj, \"generic_dialog_modal\", ia);\n            return this;\n        },\n        setSemiModal: function(ia) {\n            if (ia) {\n                this.setModal(true);\n                this._semiModalListener = Event.listen(this._obj, \"click\", function(ja) {\n                    if (!o.contains(this._popup, ja.getTarget())) {\n                        this.hide();\n                    };\n                }.bind(this));\n            }\n             else (this._semiModalListener && this._semiModalListener.remove());\n        ;\n            this._semi_modal = ia;\n            return this;\n        },\n        setWideDialog: function(ia) {\n            this._wide_dialog = ia;\n            this._updateWidth();\n            return this;\n        },\n        setContentWidth: function(ia) {\n            this._content_width = ia;\n            this._updateWidth();\n            return this;\n        },\n        setTitleLoading: function(ia) {\n            if ((ia === undefined)) {\n                ia = true;\n            };\n            var ja = o.find(this._popup, \"h2.dialog_title\");\n            if (ja) {\n                m.conditionClass(ja, \"loading\", ia);\n            };\n            return this;\n        },\n        setSecure: function(ia) {\n            m.conditionClass(this._nodes.title, \"secure\", ia);\n            return this;\n        },\n        setClassName: function(ia) {\n            ia.split(/\\s+/).forEach(m.addClass.bind(m, this._obj));\n            return this;\n        },\n        setFadeEnabled: function(ia) {\n            this._fade_enabled = ia;\n            return this;\n        },\n        setFooter: function(ia) {\n            var ja = this._nodes.footer;\n            o.setContent(ja, this._format((ia || \"\")));\n            m.conditionShow(ja, !!ia);\n            return this;\n        },\n        setAutoFocus: function(ia) {\n            this._auto_focus = ia;\n            return this;\n        },\n        setTop: function(ia) {\n            this._top = ia;\n            this._resetDialogObj();\n            return this;\n        },\n        onloadRegister: function(ia) {\n            ca(ia).forEach(function(ja) {\n                if ((typeof ja == \"string\")) {\n                    ja = new Function(ja);\n                };\n                this._onload_handlers.push(ja.bind(this));\n            }.bind(this));\n            return this;\n        },\n        setAsyncURL: function(ia) {\n            return this.setAsync(new j(ia));\n        },\n        setAsync: function(ia) {\n            var ja = function(ra) {\n                if ((this._async_request != ia)) {\n                    return\n                };\n                this._async_request = null;\n                var sa = ra.getPayload(), ta = sa;\n                if (this._loading) {\n                    this._showing = true;\n                };\n                if ((typeof ta == \"string\")) {\n                    this.setBody(ta);\n                }\n                 else this._setFromModel(ta);\n            ;\n                this._update();\n            }.bind(this), ka = ia.getData();\n            ka.__d = 1;\n            ia.setData(ka);\n            var la = (ia.getHandler() || bagofholding);\n            ia.setHandler(function(ra) {\n                la(ra);\n                ja(ra);\n            });\n            var ma = ia, na = (ma.getErrorHandler() || bagofholding), oa = (ma.getTransportErrorHandler() || bagofholding), pa = function() {\n                this._async_request = null;\n                this._loading = false;\n                if ((this._showing && this._shown_while_stacked)) {\n                    this._update();\n                }\n                 else this._hide(this._is_stackable);\n            ;\n            }.bind(this), qa = (ma.getServerDialogCancelHandler() || pa);\n            ma.setAllowCrossPageTransition(this._cross_transition).setErrorHandler(function(ra) {\n                pa();\n                na(ra);\n            }).setTransportErrorHandler(function(ra) {\n                pa();\n                oa(ra);\n            }).setServerDialogCancelHandler(qa);\n            ia.send();\n            this._async_request = ia;\n            if (this._showing) {\n                this.show();\n            };\n            return this;\n        },\n        _format: function(ia) {\n            if ((typeof ia == \"string\")) {\n                ia = q(ia);\n            }\n             else ia = q.replaceJSONWrapper(ia);\n        ;\n            if ((ia instanceof q)) {\n                ia.setDeferred(true);\n            };\n            return ia;\n        },\n        _update: function() {\n            if (!this._showing) {\n                return\n            };\n            if (((this._autohide && !this._async_request) && !this._autohide_timeout)) {\n                this._autohide_timeout = setTimeout(aa(this, \"hide\"), this._autohide);\n            };\n            m.removeClass(this._frame, \"dialog_loading_shown\");\n            this._loading = false;\n            this._renderDialog();\n            this._runOnloads();\n            this._previous_focus = document.activeElement;\n            r.focus(this._frame);\n        },\n        _runOnloads: function() {\n            for (var ia = 0; (ia < this._onload_handlers.length); ++ia) {\n                try {\n                    this._onload_handlers[ia]();\n                } catch (ja) {\n                \n                };\n            };\n            this._onload_handlers = [];\n        },\n        _updateWidth: function() {\n            var ia = (2 * ha._BORDER_WIDTH);\n            if (ha._isUsingCSSBorders()) {\n                ia += (2 * ha._HALO_WIDTH);\n            };\n            if (this._content_width) {\n                ia += this._content_width;\n                if (!this._full_bleed) {\n                    ia += (2 * ha._PADDING_WIDTH);\n                };\n            }\n             else if (this._wide_dialog) {\n                ia += ha.SIZE.WIDE;\n            }\n             else ia += ha.SIZE.STANDARD;\n            \n        ;\n            this._popup.style.width = (ia + \"px\");\n        },\n        _updateZIndex: function() {\n            if ((!this._hasSetZIndex && this._causal_elem)) {\n                var ia = ea(this._causal_elem);\n                this._hasSetZIndex = (ia > ((this._modal ? 400 : 200)));\n                w.set(this._obj, \"z-index\", (this._hasSetZIndex ? ia : \"\"));\n            }\n        ;\n        },\n        _renderDialog: function() {\n            this._updateZIndex();\n            this._pushOntoStack();\n            this._obj.style.height = (((this._modal && (y.ie() < 7))) ? (z.getDocumentDimensions().y + \"px\") : null);\n            if ((this._obj && this._obj.style.display)) {\n                this._obj.style.visibility = \"hidden\";\n                this._obj.style.display = \"\";\n                this.resetDialogPosition();\n                this._obj.style.visibility = \"\";\n                this._obj.dialog = this;\n            }\n             else this.resetDialogPosition();\n        ;\n            clearInterval(this.active_hiding);\n            this.active_hiding = setInterval(this._activeResize.bind(this), 500);\n            this._submit_on_enter = false;\n            if (this._auto_focus) {\n                var ia = p.getFirstElement(this._content, [\"input[type=\\\"text\\\"]\",\"textarea\",\"input[type=\\\"password\\\"]\",]);\n                if (ia) {\n                    p.focusFirst.bind(this, this._content).defer();\n                }\n                 else this._submit_on_enter = true;\n            ;\n            }\n        ;\n            var ja = (z.getElementDimensions(this._content).y + z.getElementPosition(this._content).y);\n            ha._bottoms.push(ja);\n            this._bottom = ja;\n            ha._updateMaxBottom();\n            return this;\n        },\n        _buildDialog: function() {\n            this._obj = o.create(\"div\", {\n                className: \"generic_dialog\",\n                id: this._uniqueID\n            });\n            this._obj.style.display = \"none\";\n            o.appendContent(document.body, this._obj);\n            if (!this._popup) {\n                this._popup = o.create(\"div\", {\n                    className: \"generic_dialog_popup\"\n                });\n            };\n            this._obj.appendChild(this._popup);\n            if (((y.ie() < 7) && !this._shim)) {\n                k.loadModules([\"IframeShim\",], function(ua) {\n                    this._shim = new ua(this._popup);\n                });\n            };\n            m.addClass(this._obj, \"pop_dialog\");\n            if (t.isRTL()) {\n                m.addClass(this._obj, \"pop_dialog_rtl\");\n            };\n            var ia;\n            if (ha._isUsingCSSBorders()) {\n                ia = ((\"\\u003Cdiv class=\\\"pop_container_advanced\\\"\\u003E\" + \"\\u003Cdiv class=\\\"pop_content\\\" id=\\\"pop_content\\\"\\u003E\\u003C/div\\u003E\") + \"\\u003C/div\\u003E\");\n            }\n             else ia = ((((((((\"\\u003Cdiv class=\\\"pop_container\\\"\\u003E\" + \"\\u003Cdiv class=\\\"pop_verticalslab\\\"\\u003E\\u003C/div\\u003E\") + \"\\u003Cdiv class=\\\"pop_horizontalslab\\\"\\u003E\\u003C/div\\u003E\") + \"\\u003Cdiv class=\\\"pop_topleft\\\"\\u003E\\u003C/div\\u003E\") + \"\\u003Cdiv class=\\\"pop_topright\\\"\\u003E\\u003C/div\\u003E\") + \"\\u003Cdiv class=\\\"pop_bottomright\\\"\\u003E\\u003C/div\\u003E\") + \"\\u003Cdiv class=\\\"pop_bottomleft\\\"\\u003E\\u003C/div\\u003E\") + \"\\u003Cdiv class=\\\"pop_content pop_content_old\\\" id=\\\"pop_content\\\"\\u003E\\u003C/div\\u003E\") + \"\\u003C/div\\u003E\");\n        ;\n            o.setContent(this._popup, q(ia));\n            var ja = o.find(this._popup, \"div.pop_content\");\n            ja.setAttribute(\"tabIndex\", \"0\");\n            ja.setAttribute(\"role\", \"alertdialog\");\n            this._frame = this._content = ja;\n            var ka = o.create(\"div\", {\n                className: \"dialog_loading\"\n            }, \"Loading...\"), la = o.create(\"span\"), ma = o.create(\"h2\", {\n                className: \"dialog_title hidden_elem\",\n                id: (\"title_\" + this._uniqueID)\n            }, la), na = o.create(\"div\", {\n                className: \"dialog_summary hidden_elem\"\n            }), oa = o.create(\"div\", {\n                className: \"dialog_body\"\n            }), pa = o.create(\"div\"), qa = o.create(\"div\", {\n                className: \"dialog_buttons_msg\"\n            }), ra = o.create(\"div\", {\n                className: \"dialog_buttons clearfix hidden_elem\"\n            }, [qa,pa,]), sa = o.create(\"div\", {\n                className: \"dialog_footer hidden_elem\"\n            }), ta = o.create(\"div\", {\n                className: \"dialog_content\"\n            }, [na,oa,ra,sa,]);\n            this._nodes = {\n                summary: na,\n                body: oa,\n                buttons: pa,\n                button_message: qa,\n                button_wrapper: ra,\n                footer: sa,\n                content: ta,\n                title: ma,\n                title_inner: la\n            };\n            o.setContent(this._frame, [ma,ta,ka,]);\n        },\n        _updateShim: function() {\n            return (this._shim && this._shim.show());\n        },\n        _activeResize: function() {\n            if ((this.last_offset_height != this._content.offsetHeight)) {\n                this.last_offset_height = this._content.offsetHeight;\n                this.resetDialogPosition();\n            }\n        ;\n        },\n        resetDialogPosition: function() {\n            if (!this._popup) {\n                return\n            };\n            this._resetDialogObj();\n            this._updateShim();\n        },\n        _resetDialogObj: function() {\n            var ia = (2 * ha._PAGE_MARGIN), ja = z.getViewportDimensions(), ka = (ja.x - ia), la = (ja.y - ia), ma = (2 * ha._HALO_WIDTH), na = z.getElementDimensions(this._content), oa = (na.x + ma), pa = (na.y + ma), qa = this._top, ra = (ka - oa), sa = (la - pa);\n            if ((sa < 0)) {\n                qa = ha._PAGE_MARGIN;\n            }\n             else if ((qa > sa)) {\n                qa = (ha._PAGE_MARGIN + ((Math.max(sa, 0) / 2)));\n            }\n        ;\n            var ta = ga();\n            if (!ta) {\n                qa += z.getScrollPosition().y;\n            };\n            w.set(this._popup, \"marginTop\", (qa + \"px\"));\n            var ua = (ta && (((ra < 0) || (sa < 0))));\n            m.conditionClass(this._obj, \"generic_dialog_fixed_overflow\", ua);\n            m.conditionClass(document.documentElement, \"generic_dialog_overflow_mode\", ua);\n        },\n        _fadeOut: function(ia) {\n            if (!this._popup) {\n                return\n            };\n            try {\n                new h(this._obj).duration(0).checkpoint().to(\"opacity\", 0).hide().duration(250).ondone(this._hide.bind(this, ia)).go();\n            } catch (ja) {\n                this._hide(ia);\n            };\n        },\n        _hide: function(ia) {\n            if (this._obj) {\n                this._obj.style.display = \"none\";\n            };\n            m.removeClass(document.documentElement, \"generic_dialog_overflow_mode\");\n            this._updateShim();\n            clearInterval(this.active_hiding);\n            if (this._bottom) {\n                var ja = ha._bottoms;\n                ja.splice(ja.indexOf(this._bottom), 1);\n                ha._updateMaxBottom();\n            }\n        ;\n            if (((this._previous_focus && document.activeElement) && o.contains(this._obj, document.activeElement))) {\n                r.focus(this._previous_focus);\n            };\n            if (ia) {\n                return\n            };\n            this.destroy();\n        },\n        destroy: function() {\n            this._popFromStack();\n            if (this._obj) {\n                o.remove(this._obj);\n                this._obj = null;\n                (this._shim && this._shim.hide());\n                this._shim = null;\n            }\n        ;\n            (this._clickOnEnterListener && this._clickOnEnterListener.remove());\n            if (this._close_handler) {\n                this._close_handler({\n                    return_data: this._return_data\n                });\n            };\n        },\n        _handleButton: function(ia) {\n            if ((typeof ia == \"string\")) {\n                ia = ha._findButton(this._buttons, ia);\n            };\n            var ja = ha.call_or_eval(ia, ia.handler);\n            if ((ja === false)) {\n                return\n            };\n            if ((ia.name == \"cancel\")) {\n                this.cancel();\n            }\n             else if ((ha.call_or_eval(this, this._handler, {\n                button: ia\n            }) !== false)) {\n                this.hide();\n            }\n        ;\n        },\n        _submitForm: function(ia, ja, ka) {\n            var la = this.getFormData();\n            if (ka) {\n                la[ka.name] = ka.label;\n            };\n            if (this._extra_data) {\n                ba(la, this._extra_data);\n            };\n            var ma = new j().setURI(ja).setData(la).setMethod(ia).setNectarModuleDataSafe(this._causal_elem).setReadOnly((ia == \"GET\"));\n            this.setAsync(ma);\n            return false;\n        },\n        _setFromModel: function(ia) {\n            var ja = {\n            };\n            ba(ja, ia);\n            for (var ka in ja) {\n                if ((ka == \"onloadRegister\")) {\n                    this.onloadRegister(ja[ka]);\n                    continue;\n                }\n            ;\n                var la = this[((\"set\" + ka.substr(0, 1).toUpperCase()) + ka.substr(1))];\n                la.apply(this, ca(ja[ka]));\n            };\n        },\n        _updateBottom: function() {\n            var ia = (z.getElementDimensions(this._content).y + z.getElementPosition(this._content).y);\n            ha._bottoms[(ha._bottoms.length - 1)] = ia;\n            ha._updateMaxBottom();\n        },\n        _pushOntoStack: function() {\n            var ia = ha._stack;\n            if (!ia.length) {\n                i.inform(\"layer_shown\", {\n                    type: \"Dialog\"\n                });\n            };\n            ia.remove(this);\n            ia.push(this);\n            for (var ja = (ia.length - 2); (ja >= 0); ja--) {\n                var ka = ia[ja];\n                if ((!ka._is_stackable && !ka._async_request)) {\n                    ka._hide();\n                }\n                 else if (!ka._shown_while_stacked) {\n                    ka._hide(true);\n                }\n            ;\n            };\n        },\n        _popFromStack: function() {\n            var ia = ha._stack, ja = ((ia[(ia.length - 1)] === this));\n            ia.remove(this);\n            if (ia.length) {\n                if (ja) {\n                    ia[(ia.length - 1)].show();\n                };\n            }\n             else i.inform(\"layer_hidden\", {\n                type: \"Dialog\"\n            });\n        ;\n        }\n    });\n    e.exports = ha;\n});\n__d(\"ViewportBounds\", [\"Style\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"Style\"), h = b(\"ge\"), i = {\n        top: [],\n        right: [],\n        bottom: [],\n        left: []\n    };\n    function j(n) {\n        return function() {\n            var o = 0;\n            i[n].forEach(function(p) {\n                o = Math.max(o, p.getSize());\n            });\n            return o;\n        };\n    };\n    function k(n) {\n        return function(o) {\n            return new l(n, o);\n        };\n    };\n    function l(n, o) {\n        this.getSide = bagof(n);\n        this.getSize = function() {\n            return ((typeof o === \"function\") ? o() : o);\n        };\n        i[n].push(this);\n    };\n    l.prototype.remove = function() {\n        i[this.getSide()].remove(this);\n    };\n    var m = {\n        getTop: j(\"top\"),\n        getRight: j(\"right\"),\n        getBottom: j(\"bottom\"),\n        getLeft: j(\"left\"),\n        addTop: k(\"top\"),\n        addRight: k(\"right\"),\n        addBottom: k(\"bottom\"),\n        addLeft: k(\"left\")\n    };\n    m.addTop(function() {\n        var n = h(\"blueBar\");\n        if ((n && g.isFixed(n))) {\n            return h(\"blueBarHolder\").offsetHeight\n        };\n        return 0;\n    });\n    e.exports = m;\n});\n__d(\"DOMScroll\", [\"Animation\",\"Arbiter\",\"DOM\",\"DOMQuery\",\"Vector\",\"ViewportBounds\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"Animation\"), h = b(\"Arbiter\"), i = b(\"DOM\"), j = b(\"DOMQuery\"), k = b(\"Vector\"), l = b(\"ViewportBounds\"), m = b(\"ge\"), n = {\n        SCROLL: \"dom-scroll\",\n        getScrollState: function() {\n            var o = k.getViewportDimensions(), p = k.getDocumentDimensions(), q = ((p.x > o.x)), r = ((p.y > o.y));\n            q += 0;\n            r += 0;\n            return new k(q, r);\n        },\n        _scrollbarSize: null,\n        _initScrollbarSize: function() {\n            var o = i.create(\"p\");\n            o.style.width = \"100\u0025\";\n            o.style.height = \"200px\";\n            var p = i.create(\"div\");\n            p.style.position = \"absolute\";\n            p.style.top = \"0px\";\n            p.style.left = \"0px\";\n            p.style.visibility = \"hidden\";\n            p.style.width = \"200px\";\n            p.style.height = \"150px\";\n            p.style.overflow = \"hidden\";\n            p.appendChild(o);\n            document.body.appendChild(p);\n            var q = o.offsetWidth;\n            p.style.overflow = \"scroll\";\n            var r = o.offsetWidth;\n            if ((q == r)) {\n                r = p.clientWidth;\n            };\n            document.body.removeChild(p);\n            n._scrollbarSize = (q - r);\n        },\n        getScrollbarSize: function() {\n            if ((n._scrollbarSize === null)) {\n                n._initScrollbarSize();\n            };\n            return n._scrollbarSize;\n        },\n        scrollTo: function(o, p, q, r, s) {\n            if (((typeof p == \"undefined\") || (p === true))) {\n                p = 750;\n            };\n            if (!((o instanceof k))) {\n                var t = k.getScrollPosition().x, u = k.getElementPosition(m(o)).y;\n                o = new k(t, u, \"document\");\n                if (!r) {\n                    o.y -= (l.getTop() / ((q ? 2 : 1)));\n                };\n            }\n        ;\n            if (q) {\n                o.y -= (k.getViewportDimensions().y / 2);\n            }\n             else if (r) {\n                o.y -= k.getViewportDimensions().y;\n                o.y += r;\n            }\n            \n        ;\n            o = o.convertTo(\"document\");\n            if (p) {\n                return new g(document.body).to(\"scrollTop\", o.y).to(\"scrollLeft\", o.x).ease(g.ease.end).duration(p).ondone(s).go();\n            }\n             else if (window.scrollTo) {\n                window.scrollTo(o.x, o.y);\n                (s && s());\n            }\n            \n        ;\n            h.inform(n.SCROLL);\n        },\n        ensureVisible: function(o, p, q, r, s) {\n            if ((q === undefined)) {\n                q = 10;\n            };\n            o = m(o);\n            if (p) {\n                o = j.find(o, p);\n            };\n            var t = k.getScrollPosition().x, u = k.getScrollPosition().y, v = (u + k.getViewportDimensions().y), w = k.getElementPosition(o).y, x = (w + k.getElementDimensions(o).y);\n            w -= l.getTop();\n            w -= q;\n            x += q;\n            if ((w < u)) {\n                n.scrollTo(new k(t, w, \"document\"), r, false, false, s);\n            }\n             else if ((x > v)) {\n                if (((w - ((x - v))) < u)) {\n                    n.scrollTo(new k(t, w, \"document\"), r, false, false, s);\n                }\n                 else n.scrollTo(new k(t, x, \"document\"), r, false, true, s);\n            \n            }\n        ;\n        },\n        scrollToTop: function(o) {\n            var p = k.getScrollPosition();\n            n.scrollTo(new k(p.x, 0, \"document\"), (o !== false));\n        }\n    };\n    e.exports = n;\n});\n__d(\"HistoryManager\", [\"event-extensions\",\"function-extensions\",\"Cookie\",\"Env\",\"URI\",\"UserAgent\",\"copyProperties\",\"goOrReplace\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Cookie\"), h = b(\"Env\"), i = b(\"URI\"), j = b(\"UserAgent\"), k = b(\"copyProperties\"), l = b(\"goOrReplace\"), m = {\n        _IFRAME_BASE_URI: \"http://static.ak.facebook.com/common/history_manager.php\",\n        history: null,\n        current: 0,\n        fragment: null,\n        _setIframeSrcFragment: function(n) {\n            n = n.toString();\n            var o = (m.history.length - 1);\n            m.iframe.src = ((((m._IFRAME_BASE_URI + \"?|index=\") + o) + \"#\") + encodeURIComponent(n));\n            return m;\n        },\n        getIframeSrcFragment: function() {\n            return decodeURIComponent(i(m.iframe.contentWindow.document.location.href).getFragment());\n        },\n        nextframe: function(n, o) {\n            if (o) {\n                m._setIframeSrcFragment(n);\n                return;\n            }\n        ;\n            if ((n !== undefined)) {\n                m.iframeQueue.push(n);\n            }\n             else {\n                m.iframeQueue.splice(0, 1);\n                m.iframeTimeout = null;\n                m.checkURI();\n            }\n        ;\n            if ((m.iframeQueue.length && !m.iframeTimeout)) {\n                var p = m.iframeQueue[0];\n                m.iframeTimeout = setTimeout(function() {\n                    m._setIframeSrcFragment(p);\n                }, 100, false);\n            }\n        ;\n        },\n        isInitialized: function() {\n            return !!m._initialized;\n        },\n        init: function() {\n            if ((!h.ALLOW_TRANSITION_IN_IFRAME && (window != window.top))) {\n                return\n            };\n            if (m._initialized) {\n                return m\n            };\n            var n = i(), o = (n.getFragment() || \"\");\n            if ((o.charAt(0) === \"!\")) {\n                o = o.substr(1);\n                n.setFragment(o);\n            }\n        ;\n            if ((i.getRequestURI(false).getProtocol().toLowerCase() == \"https\")) {\n                m._IFRAME_BASE_URI = \"https://s-static.ak.facebook.com/common/history_manager.php\";\n            };\n            k(m, {\n                _initialized: true,\n                fragment: o,\n                orig_fragment: o,\n                history: [n,],\n                callbacks: [],\n                lastChanged: Date.now(),\n                canonical: i(\"#\"),\n                fragmentTimeout: null,\n                user: 0,\n                iframeTimeout: null,\n                iframeQueue: [],\n                enabled: true,\n                debug: bagofholding\n            });\n            if ((window.history && history.pushState)) {\n                this.lastURI = document.URL;\n                window.history.replaceState(this.lastURI, null);\n                Event.listen(window, \"popstate\", function(p) {\n                    if (((p && p.state) && (m.lastURI != p.state))) {\n                        m.lastURI = p.state;\n                        m.lastChanged = Date.now();\n                        m.notify(i(p.state).getUnqualifiedURI().toString());\n                    }\n                ;\n                }.bind(m));\n                if (((j.safari() < 534) || (j.chrome() <= 13))) {\n                    setInterval(m.checkURI, 42, false);\n                    m._updateRefererURI(this.lastURI);\n                }\n            ;\n                return m;\n            }\n        ;\n            m._updateRefererURI(i.getRequestURI(false));\n            if (((j.safari() < 500) || (j.firefox() < 2))) {\n                m.enabled = false;\n                return m;\n            }\n        ;\n            if ((j.ie() < 8)) {\n                m.iframe = document.createElement(\"iframe\");\n                k(m.iframe.style, {\n                    width: \"0\",\n                    height: \"0\",\n                    frameborder: \"0\",\n                    left: \"0\",\n                    top: \"0\",\n                    position: \"absolute\"\n                });\n                m._setIframeSrcFragment(o);\n                document.body.insertBefore(m.iframe, document.body.firstChild);\n            }\n             else if ((\"onhashchange\" in window)) {\n                Event.listen(window, \"hashchange\", function() {\n                    m.checkURI.bind(m).defer();\n                });\n            }\n             else setInterval(m.checkURI, 42, false);\n            \n        ;\n            return m;\n        },\n        registerURIHandler: function(n) {\n            m.callbacks.push(n);\n            return m;\n        },\n        setCanonicalLocation: function(n) {\n            m.canonical = i(n);\n            return m;\n        },\n        notify: function(n) {\n            if ((n == m.orig_fragment)) {\n                n = m.canonical.getFragment();\n            };\n            for (var o = 0; (o < m.callbacks.length); o++) {\n                try {\n                    if (m.callbacks[o](n)) {\n                        return true\n                    };\n                } catch (p) {\n                \n                };\n            };\n            return false;\n        },\n        checkURI: function() {\n            if (((Date.now() - m.lastChanged) < 400)) {\n                return\n            };\n            if ((window.history && history.pushState)) {\n                var n = i(document.URL).removeQueryData(\"ref\").toString(), o = i(m.lastURI).removeQueryData(\"ref\").toString();\n                if ((n != o)) {\n                    m.lastChanged = Date.now();\n                    m.lastURI = n;\n                    if ((j.safari() < 534)) {\n                        m._updateRefererURI(n);\n                    };\n                    m.notify(i(n).getUnqualifiedURI().toString());\n                }\n            ;\n                return;\n            }\n        ;\n            if (((j.ie() < 8) && m.iframeQueue.length)) {\n                return\n            };\n            if ((j.safari() && (window.history.length == 200))) {\n                if (!m.warned) {\n                    m.warned = true;\n                };\n                return;\n            }\n        ;\n            var p = i().getFragment();\n            if ((p.charAt(0) == \"!\")) {\n                p = p.substr(1);\n            };\n            if ((j.ie() < 8)) {\n                p = m.getIframeSrcFragment();\n            };\n            p = p.replace(/\u002523/g, \"#\");\n            if ((p != m.fragment.replace(/\u002523/g, \"#\"))) {\n                m.debug([p,\" vs \",m.fragment,\"whl: \",window.history.length,\"QHL: \",m.history.length,].join(\" \"));\n                for (var q = (m.history.length - 1); (q >= 0); --q) {\n                    if ((m.history[q].getFragment().replace(/\u002523/g, \"#\") == p)) {\n                        break;\n                    };\n                };\n                ++m.user;\n                if ((q >= 0)) {\n                    m.go((q - m.current));\n                }\n                 else m.go((\"#\" + p));\n            ;\n                --m.user;\n            }\n        ;\n        },\n        _updateRefererURI: function(n) {\n            n = n.toString();\n            if (((n.charAt(0) != \"/\") && (n.indexOf(\"//\") == -1))) {\n                return\n            };\n            var o = new i(window.location);\n            if (o.isFacebookURI()) {\n                var p = (o.getPath() + window.location.search);\n            }\n             else var p = \"\"\n        ;\n            var q = i(n).getQualifiedURI().setFragment(p).toString(), r = 2048;\n            if ((q.length > r)) {\n                q = (q.substring(0, r) + \"...\");\n            };\n            g.set(\"x-referer\", q);\n        },\n        go: function(n, o, p) {\n            if ((window.history && history.pushState)) {\n                (o || (typeof (n) == \"number\"));\n                var q = i(n).removeQueryData(\"ref\").toString();\n                m.lastChanged = Date.now();\n                this.lastURI = q;\n                if (p) {\n                    window.history.replaceState(n, null, q);\n                }\n                 else window.history.pushState(n, null, q);\n            ;\n                if ((j.safari() < 534)) {\n                    m._updateRefererURI(n);\n                };\n                return false;\n            }\n        ;\n            m.debug((\"go: \" + n));\n            if ((o === undefined)) {\n                o = true;\n            };\n            if (!m.enabled) {\n                if (!o) {\n                    return false\n                }\n            };\n            if ((typeof (n) == \"number\")) {\n                if (!n) {\n                    return false\n                };\n                var r = (n + m.current), s = Math.max(0, Math.min((m.history.length - 1), r));\n                m.current = s;\n                r = (m.history[s].getFragment() || m.orig_fragment);\n                r = i(r).removeQueryData(\"ref\").getUnqualifiedURI().toString();\n                m.fragment = r;\n                m.lastChanged = Date.now();\n                if ((j.ie() < 8)) {\n                    if (m.fragmentTimeout) {\n                        clearTimeout(m.fragmentTimeout);\n                    };\n                    m._temporary_fragment = r;\n                    m.fragmentTimeout = setTimeout(function() {\n                        window.location.hash = (\"#!\" + r);\n                        delete m._temporary_fragment;\n                    }, 750, false);\n                    if (!m.user) {\n                        m.nextframe(r, p);\n                    };\n                }\n                 else if (!m.user) {\n                    l(window.location, ((window.location.href.split(\"#\")[0] + \"#!\") + r), p);\n                }\n            ;\n                if (o) {\n                    m.notify(r);\n                };\n                m._updateRefererURI(r);\n                return false;\n            }\n        ;\n            n = i(n);\n            if ((n.getDomain() == i().getDomain())) {\n                n = i((\"#\" + n.getUnqualifiedURI()));\n            };\n            var t = m.history[m.current].getFragment(), u = n.getFragment();\n            if (((u == t) || (((t == m.orig_fragment) && (u == m.canonical.getFragment()))))) {\n                if (o) {\n                    m.notify(u);\n                };\n                m._updateRefererURI(u);\n                return false;\n            }\n        ;\n            if (p) {\n                m.current--;\n            };\n            var v = (((m.history.length - m.current)) - 1);\n            m.history.splice((m.current + 1), v);\n            m.history.push(i(n));\n            return m.go(1, o, p);\n        },\n        getCurrentFragment: function() {\n            var n = ((m._temporary_fragment !== undefined) ? m._temporary_fragment : i.getRequestURI(false).getFragment());\n            return ((n == m.orig_fragment) ? m.canonical.getFragment() : n);\n        }\n    };\n    e.exports = m;\n});\n__d(\"JSLogger\", [], function(a, b, c, d, e, f) {\n    var g = {\n        MAX_HISTORY: 500,\n        counts: {\n        },\n        categories: {\n        },\n        seq: 0,\n        pageId: (((Math.random() * 2147483648) | 0)).toString(36)\n    };\n    function h(l) {\n        if (((l instanceof Error) && a.ErrorUtils)) {\n            l = a.ErrorUtils.normalizeError(l);\n        };\n        try {\n            return JSON.stringify(l);\n        } catch (m) {\n            return \"{}\";\n        };\n    };\n    function i(l, event, m) {\n        if (!g.counts[l]) {\n            g.counts[l] = {\n            };\n        };\n        if (!g.counts[l][event]) {\n            g.counts[l][event] = 0;\n        };\n        m = ((m == null) ? 1 : Number(m));\n        g.counts[l][event] += (isFinite(m) ? m : 0);\n    };\n    g.logAction = function(event, l, m) {\n        if ((this.type == \"bump\")) {\n            i(this.cat, event, l);\n        }\n         else if ((this.type == \"rate\")) {\n            ((l && i(this.cat, (event + \"_n\"), m)));\n            i(this.cat, (event + \"_d\"), m);\n        }\n         else {\n            var n = {\n                cat: this.cat,\n                type: this.type,\n                event: event,\n                data: ((l != null) ? h(l) : null),\n                date: Date.now(),\n                seq: g.seq++\n            };\n            g.head = (g.head ? (g.head.next = n) : (g.tail = n));\n            while (((g.head.seq - g.tail.seq) > g.MAX_HISTORY)) {\n                g.tail = g.tail.next;;\n            };\n            return n;\n        }\n        \n    ;\n    };\n    function j(l) {\n        if (!g.categories[l]) {\n            g.categories[l] = {\n            };\n            var m = function(n) {\n                var o = {\n                    cat: l,\n                    type: n\n                };\n                g.categories[l][n] = function() {\n                    if ((document.domain != \"facebook.com\")) {\n                        return\n                    };\n                    var p;\n                    try {\n                        p = (a.top.require && a.top.require(\"JSLogger\")._.logAction);\n                    } catch (q) {\n                    \n                    };\n                    ((p && p.apply(o, arguments)));\n                };\n            };\n            m(\"debug\");\n            m(\"log\");\n            m(\"warn\");\n            m(\"error\");\n            m(\"bump\");\n            m(\"rate\");\n        }\n    ;\n        return g.categories[l];\n    };\n    function k(l, m) {\n        var n = [];\n        for (var o = (m || g.tail); o; o = o.next) {\n            if ((!l || l(o))) {\n                var p = {\n                    type: o.type,\n                    cat: o.cat,\n                    date: o.date,\n                    event: o.event,\n                    seq: o.seq\n                };\n                if (o.data) {\n                    p.data = JSON.parse(o.data);\n                };\n                n.push(p);\n            }\n        ;\n        };\n        return n;\n    };\n    e.exports = {\n        _: g,\n        DUMP_EVENT: \"jslogger/dump\",\n        create: j,\n        getEntries: k\n    };\n});\n__d(\"LinkController\", [\"event-extensions\",\"DataStore\",\"Parent\",\"trackReferrer\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"DataStore\"), h = b(\"Parent\"), i = b(\"trackReferrer\"), j = \"LinkControllerHandler\", k = [], l = [];\n    function m(event) {\n        var q = h.byTag(event.getTarget(), \"a\"), r = (q && q.getAttribute(\"href\", 2));\n        if ((((!r || q.rel) || !o(r)) || g.get(q, j))) {\n            return\n        };\n        var s = Event.listen(q, \"click\", function(t) {\n            if ((r.charAt((r.length - 1)) == \"#\")) {\n                t.prevent();\n                return;\n            }\n        ;\n            i(q, r);\n            n(q, t);\n        });\n        g.set(q, j, s);\n    };\n    function n(q, event) {\n        if (((q.target || event.getModifiers().any) || ((event.which && (event.which != 1))))) {\n            return\n        };\n        var r = k.concat(l);\n        for (var s = 0, t = r.length; (s < t); s++) {\n            if ((r[s](q, event) === false)) {\n                return event.kill()\n            };\n        };\n    };\n    function o(q) {\n        var r = q.match(/^(\\w+):/);\n        return (!r || r[1].match(/^http/i));\n    };\n    var p = {\n        registerHandler: function(q) {\n            k.push(q);\n        },\n        registerFallbackHandler: function(q) {\n            l.push(q);\n        }\n    };\n    Event.listen(document.documentElement, \"mousedown\", m);\n    Event.listen(document.documentElement, \"keydown\", m);\n    e.exports = p;\n});\n__d(\"htmlSpecialChars\", [], function(a, b, c, d, e, f) {\n    function g(h) {\n        if ((((typeof h == \"undefined\") || (h === null)) || !h.toString)) {\n            return \"\"\n        };\n        if ((h === false)) {\n            return \"0\";\n        }\n         else if ((h === true)) {\n            return \"1\"\n        }\n    ;\n        return h.toString().replace(/&/g, \"&amp;\").replace(/\"/g, \"&quot;\").replace(/'/g, \"&#039;\").replace(/</g, \"&lt;\").replace(/>/g, \"&gt;\");\n    };\n    e.exports = g;\n});\n__d(\"htmlize\", [\"htmlSpecialChars\",], function(a, b, c, d, e, f) {\n    var g = b(\"htmlSpecialChars\");\n    function h(i) {\n        return g(i).replace(/\\r\\n|[\\r\\n]/g, \"\\u003Cbr /\\u003E\");\n    };\n    e.exports = h;\n});\n__d(\"escapeJSQuotes\", [], function(a, b, c, d, e, f) {\n    function g(h) {\n        if ((((typeof h == \"undefined\") || (h == null)) || !h.valueOf())) {\n            return \"\"\n        };\n        return h.toString().replace(/\\\\/g, \"\\\\\\\\\").replace(/\\n/g, \"\\\\n\").replace(/\\r/g, \"\\\\r\").replace(/\"/g, \"\\\\x22\").replace(/'/g, \"\\\\'\").replace(/</g, \"\\\\x3c\").replace(/>/g, \"\\\\x3e\").replace(/&/g, \"\\\\x26\");\n    };\n    e.exports = g;\n});\n__d(\"areObjectsEqual\", [], function(a, b, c, d, e, f) {\n    function g(h, i) {\n        return (JSON.stringify(h) == JSON.stringify(i));\n    };\n    e.exports = g;\n});\n__d(\"computeRelativeURI\", [\"URI\",\"isEmpty\",], function(a, b, c, d, e, f) {\n    var g = b(\"URI\"), h = b(\"isEmpty\");\n    function i(k, l) {\n        if (!l) {\n            return k\n        };\n        if ((l.charAt(0) == \"/\")) {\n            return l\n        };\n        var m = k.split(\"/\").slice(0, -1);\n        (m[0] !== \"\");\n        l.split(\"/\").forEach(function(n) {\n            if (!((n == \".\"))) {\n                if ((n == \"..\")) {\n                    if ((m.length > 1)) {\n                        m = m.slice(0, -1);\n                    };\n                }\n                 else m.push(n);\n            \n            };\n        });\n        return m.join(\"/\");\n    };\n    function j(k, l) {\n        var m = new g(), n = l;\n        k = new g(k);\n        l = new g(l);\n        if ((l.getDomain() && !l.isFacebookURI())) {\n            return n\n        };\n        var o = k, p = [\"Protocol\",\"Domain\",\"Port\",\"Path\",\"QueryData\",\"Fragment\",];\n        p.forEach(function(q) {\n            var r = ((q == \"Path\") && (o === k));\n            if (r) {\n                m.setPath(i(k.getPath(), l.getPath()));\n            };\n            if (!h(l[(\"get\" + q)]())) {\n                o = l;\n            };\n            if (!r) {\n                m[(\"set\" + q)](o[(\"get\" + q)]());\n            };\n        });\n        return m;\n    };\n    e.exports = j;\n});\n__d(\"startsWith\", [], function(a, b, c, d, e, f) {\n    function g(h, i, j) {\n        var k = String(h);\n        j = Math.min(Math.max((j || 0), 0), k.length);\n        return (k.lastIndexOf(String(i), j) === j);\n    };\n    e.exports = g;\n});\n__d(\"PageTransitions\", [\"event-extensions\",\"Arbiter\",\"Dialog\",\"DOM\",\"DOMScroll\",\"Env\",\"Form\",\"HistoryManager\",\"JSLogger\",\"LinkController\",\"OnloadHooks\",\"htmlize\",\"escapeJSQuotes\",\"URI\",\"UserAgent\",\"Vector\",\"areObjectsEqual\",\"computeRelativeURI\",\"copyProperties\",\"ge\",\"goOrReplace\",\"startsWith\",\"tx\",\"userAction\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"Dialog\"), i = b(\"DOM\"), j = b(\"DOMScroll\"), k = b(\"Env\"), l = b(\"Form\"), m = b(\"HistoryManager\"), n = b(\"JSLogger\"), o = b(\"LinkController\"), p = b(\"OnloadHooks\"), q = b(\"htmlize\"), r = b(\"escapeJSQuotes\"), s = b(\"URI\"), t = b(\"UserAgent\"), u = b(\"Vector\"), v = b(\"areObjectsEqual\"), w = b(\"computeRelativeURI\"), x = b(\"copyProperties\"), y = b(\"ge\"), z = b(\"goOrReplace\"), aa = b(\"startsWith\"), ba = b(\"tx\"), ca = b(\"userAction\"), da = {\n        _transition_handlers: [],\n        _scroll_positions: {\n        },\n        _scroll_locked: false,\n        isInitialized: function() {\n            return !!da._initialized;\n        },\n        _init: function() {\n            if ((!k.ALLOW_TRANSITION_IN_IFRAME && (window != window.top))) {\n                return\n            };\n            if (da._initialized) {\n                return da\n            };\n            da._initialized = true;\n            var fa = s.getRequestURI(false), ga = fa.getUnqualifiedURI(), ha = s(ga).setFragment(null), ia = ga.getFragment();\n            if (((ia.charAt(0) === \"!\") && (ha.toString() === ia.substr(1)))) {\n                ga = ha;\n            };\n            x(da, {\n                _current_uri: ga,\n                _most_recent_uri: ga,\n                _next_uri: ga\n            });\n            var ja;\n            if (aa(fa.getFragment(), \"/\")) {\n                ja = fa.getFragment();\n            }\n             else ja = ga;\n        ;\n            m.init().setCanonicalLocation((\"#\" + ja)).registerURIHandler(da._historyManagerHandler);\n            o.registerFallbackHandler(da._rewriteHref);\n            o.registerFallbackHandler(da._onlinkclick);\n            Event.listen(document.documentElement, \"submit\", da._onformsubmit);\n            Event.listen(window, \"scroll\", function() {\n                if (!da._scroll_locked) {\n                    da._scroll_positions[da._current_uri] = u.getScrollPosition();\n                };\n            });\n            return da;\n        },\n        registerHandler: function(fa, ga) {\n            da._init();\n            ga = (ga || 5);\n            if (!da._transition_handlers[ga]) {\n                da._transition_handlers[ga] = [];\n            };\n            da._transition_handlers[ga].push(fa);\n        },\n        getCurrentURI: function(fa) {\n            if ((!da._current_uri && !fa)) {\n                return new s(da._most_recent_uri)\n            };\n            return new s(da._current_uri);\n        },\n        getMostRecentURI: function() {\n            return new s(da._most_recent_uri);\n        },\n        getNextURI: function() {\n            return new s(da._next_uri);\n        },\n        _rewriteHref: function(fa) {\n            var ga = fa.getAttribute(\"href\"), ha = w(da._most_recent_uri.getQualifiedURI(), ga).toString();\n            if ((ga != ha)) {\n                fa.setAttribute(\"href\", ha);\n            };\n        },\n        _onlinkclick: function(fa) {\n            ea.lookBusy(fa);\n            da.go(fa.getAttribute(\"href\"));\n            return false;\n        },\n        _onformsubmit: function(event) {\n            var fa = event.getTarget();\n            if ((l.getAttribute(fa, \"rel\") || l.getAttribute(fa, \"target\"))) {\n                return\n            };\n            var ga = ca(\"form\", fa, event).set_namespace(\"page_transition\"), ha = a.ArbiterMonitor;\n            if (ha) {\n                ha.initUA(ga, [fa,]);\n            };\n            var ia = new s((l.getAttribute(fa, \"action\") || \"\")), ja = w(da._most_recent_uri, ia);\n            fa.setAttribute(\"action\", ja.toString());\n            if ((((l.getAttribute(fa, \"method\") || \"GET\")).toUpperCase() === \"GET\")) {\n                da.go(ja.addQueryData(l.serialize(fa)));\n                event.kill();\n            }\n        ;\n        },\n        go: function(fa, ga) {\n            var ha = new s(fa).removeQueryData(\"quickling\").getQualifiedURI();\n            n.create(\"pagetransition\").debug(\"go\", {\n                uri: ha.toString()\n            });\n            var ia = ha.getUnqualifiedURI();\n            delete da._scroll_positions[ia];\n            (!ga && ca(\"uri\", {\n                href: ha.toString()\n            }, null, \"INDIRECT\"));\n            ea.lookBusy();\n            da._loadPage(ha, function(ja) {\n                if (ja) {\n                    m.go(ha.toString(), false, ga);\n                }\n                 else z(window.location, ha, ga);\n            ;\n            });\n        },\n        _historyManagerHandler: function(fa) {\n            if ((fa.charAt(0) != \"/\")) {\n                return false\n            };\n            ca(\"h\", {\n                href: fa\n            }, null);\n            da._loadPage(new s(fa), function(ga) {\n                if (!ga) {\n                    z(window.location, fa, true);\n                };\n            });\n            return true;\n        },\n        _loadPage: function(fa, ga) {\n            if ((s(fa).getFragment() && v(s(fa).setFragment(null).getQualifiedURI(), s(da._current_uri).setFragment(null).getQualifiedURI()))) {\n                da._current_uri = da._most_recent_uri = fa;\n                da.restoreScrollPosition();\n                ea.stopLookingBusy();\n                return;\n            }\n        ;\n            var ha = da._scroll_positions[da._current_uri];\n            da._current_uri = null;\n            da._next_uri = fa;\n            if (ha) {\n                j.scrollTo(ha, false);\n            };\n            var ia = function() {\n                da._scroll_locked = true;\n                var ka = da._handleTransition(fa);\n                (ga && ga(ka));\n            }, ja = p.runHooks(\"onbeforeleavehooks\");\n            if (ja) {\n                ea.stopLookingBusy();\n                da._warnBeforeLeaving(ja, ia);\n            }\n             else ia();\n        ;\n        },\n        _handleTransition: function(fa) {\n            window.onbeforeleavehooks = undefined;\n            ea.lookBusy();\n            if (!fa.isSameOrigin()) {\n                return false\n            };\n            var ga = (window.AsyncRequest && window.AsyncRequest.getLastID());\n            g.inform(\"pre_page_transition\", {\n                from: da.getMostRecentURI(),\n                to: fa\n            });\n            for (var ha = (da._transition_handlers.length - 1); (ha >= 0); --ha) {\n                var ia = da._transition_handlers[ha];\n                if (!ia) {\n                    continue;\n                };\n                for (var ja = (ia.length - 1); (ja >= 0); --ja) {\n                    if ((ia[ja](fa) === true)) {\n                        var ka = {\n                            sender: this,\n                            uri: fa,\n                            id: ga\n                        };\n                        try {\n                            g.inform(\"page_transition\", ka);\n                        } catch (la) {\n                        \n                        };\n                        return true;\n                    }\n                     else ia.splice(ja, 1);\n                ;\n                };\n            };\n            return false;\n        },\n        unifyURI: function() {\n            da._current_uri = da._most_recent_uri = da._next_uri;\n        },\n        transitionComplete: function(fa) {\n            da._executeCompletionCallback();\n            ea.stopLookingBusy();\n            da.unifyURI();\n            if (!fa) {\n                da.restoreScrollPosition();\n            };\n            try {\n                if ((document.activeElement && (document.activeElement.nodeName === \"A\"))) {\n                    document.activeElement.blur();\n                };\n            } catch (ga) {\n            \n            };\n        },\n        _executeCompletionCallback: function() {\n            if (da._completionCallback) {\n                da._completionCallback();\n            };\n            da._completionCallback = null;\n        },\n        setCompletionCallback: function(fa) {\n            da._completionCallback = fa;\n        },\n        rewriteCurrentURI: function(fa, ga) {\n            da.registerHandler(function() {\n                if ((fa == da.getMostRecentURI().getUnqualifiedURI().toString())) {\n                    da.transitionComplete();\n                    return true;\n                }\n            ;\n            });\n            da.go(ga, true);\n        },\n        _warnBeforeLeaving: function(fa, ga) {\n            new h().setTitle(\"Are you sure you want to leave this page?\").setBody(q(fa)).setButtons([{\n                name: \"leave_page\",\n                label: \"Leave this Page\",\n                handler: ga\n            },{\n                name: \"continue_editing\",\n                label: \"Stay on this Page\",\n                className: \"inputaux\"\n            },]).setModal(true).show();\n        },\n        restoreScrollPosition: function() {\n            da._scroll_locked = false;\n            var fa = da._current_uri, ga = da._scroll_positions[fa];\n            if (ga) {\n                j.scrollTo(ga, false);\n                return;\n            }\n        ;\n            function ha(ka) {\n                if (!ka) {\n                    return null\n                };\n                var la = ((\"a[name='\" + r(ka)) + \"']\");\n                return (i.scry(document.body, la)[0] || y(ka));\n            };\n            var ia = ha(s(fa).getFragment());\n            if (ia) {\n                var ja = u.getElementPosition(ia);\n                ja.x = 0;\n                j.scrollTo(ja);\n            }\n        ;\n        }\n    }, ea = (window._BusyUIManager || {\n        _looking_busy: false,\n        _original_cursors: [],\n        lookBusy: function(fa) {\n            if (fa) {\n                ea._giveProgressCursor(fa);\n            };\n            if (ea._looking_busy) {\n                return\n            };\n            ea._looking_busy = true;\n            ea._giveProgressCursor(document.documentElement);\n        },\n        stopLookingBusy: function() {\n            if (!ea._looking_busy) {\n                return\n            };\n            ea._looking_busy = false;\n            while (ea._original_cursors.length) {\n                var fa = ea._original_cursors.pop(), ga = fa[0], ha = fa[1];\n                if (ga.style) {\n                    ga.style.cursor = (ha || \"\");\n                };\n            };\n        },\n        _giveProgressCursor: function(fa) {\n            if (!t.safari()) {\n                ea._original_cursors.push([fa,fa.style.cursor,]);\n                fa.style.cursor = \"progress\";\n            }\n        ;\n        }\n    });\n    e.exports = da;\n});\n__d(\"TextInputControl\", [\"event-extensions\",\"function-extensions\",\"Class\",\"DOMControl\",\"Input\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Class\"), h = b(\"DOMControl\"), i = b(\"Input\"), j = b(\"copyProperties\");\n    function k(l) {\n        this.parent.construct(this, l);\n        var m = this.getRoot(), n = function() {\n            this.update.bind(this).defer();\n        }.bind(this);\n        Event.listen(m, {\n            keydown: n,\n            paste: n\n        });\n    };\n    g.extend(k, h);\n    j(k.prototype, {\n        setMaxLength: function(l) {\n            i.setMaxLength(this.getRoot(), l);\n            return this;\n        },\n        getValue: function() {\n            return i.getValue(this.getRoot());\n        },\n        isEmpty: function() {\n            return i.isEmpty(this.getRoot());\n        },\n        setValue: function(l) {\n            i.setValue(this.getRoot(), l);\n            this.update();\n            return this;\n        },\n        clear: function() {\n            return this.setValue(\"\");\n        },\n        setPlaceholderText: function(l) {\n            i.setPlaceholder(this.getRoot(), l);\n            return this;\n        }\n    });\n    e.exports = k;\n});\n__d(\"TextMetrics\", [\"array-extensions\",\"event-extensions\",\"DOM\",\"Style\",\"UserAgent\",\"debounce\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    var g = b(\"DOM\"), h = b(\"Style\"), i = b(\"UserAgent\"), j = b(\"debounce\"), k;\n    function l() {\n        if ((typeof k === \"undefined\")) {\n            var n = g.create(\"div\", {\n                className: \"webkitZoomTest\"\n            }), o = function() {\n                g.appendContent(document.body, n);\n                k = (100 / n.clientHeight);\n                g.remove(n);\n            };\n            Event.listen(window, \"resize\", j(o, 100));\n            o();\n        }\n    ;\n        return k;\n    };\n    function m(n, o) {\n        this._node = n;\n        this._flexible = !!o;\n        var p = \"textarea\", q = \"textMetrics\";\n        if (this._flexible) {\n            p = \"div\";\n            q += \" textMetricsInline\";\n        }\n    ;\n        this._shadow = g.create(p, {\n            className: q\n        });\n        var r = [\"fontSize\",\"fontStyle\",\"fontWeight\",\"fontFamily\",\"wordWrap\",];\n        r.forEach(function(t) {\n            h.set(this._shadow, t, h.get(n, t));\n        }.bind(this));\n        var s = h.get(n, \"lineHeight\");\n        if ((i.chrome() || i.safari())) {\n            s = (Math.round((parseInt(s, 10) * l())) + \"px\");\n        };\n        h.set(this._shadow, \"lineHeight\", s);\n        document.body.appendChild(this._shadow);\n    };\n    m.prototype.measure = function(n) {\n        var o = this._node, p = this._shadow;\n        n = (((n || o.value)) + \"...\");\n        if (!this._flexible) {\n            var q = ((o.clientWidth - h.getFloat(o, \"paddingLeft\")) - h.getFloat(o, \"paddingRight\"));\n            h.set(p, \"width\", (Math.max(q, 0) + \"px\"));\n        }\n    ;\n        g.setContent(p, n);\n        return {\n            width: p.scrollWidth,\n            height: p.scrollHeight\n        };\n    };\n    m.prototype.destroy = function() {\n        g.remove(this._shadow);\n    };\n    e.exports = m;\n});\n__d(\"TextAreaControl\", [\"event-extensions\",\"Arbiter\",\"ArbiterMixin\",\"Class\",\"CSS\",\"DOMControl\",\"Style\",\"TextInputControl\",\"TextMetrics\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"Class\"), j = b(\"CSS\"), k = b(\"DOMControl\"), l = b(\"Style\"), m = b(\"TextInputControl\"), n = b(\"TextMetrics\"), o = b(\"copyProperties\");\n    function p(q) {\n        this.autogrow = j.hasClass(q, \"uiTextareaAutogrow\");\n        this.parent.construct(this, q);\n        this.width = null;\n        Event.listen(q, \"focus\", this._handleFocus.bind(this));\n    };\n    i.extend(p, m);\n    o(p.prototype, h, {\n        setAutogrow: function(q) {\n            this.autogrow = q;\n            return this;\n        },\n        onupdate: function() {\n            this.parent.onupdate();\n            if (this.autogrow) {\n                var q = this.getRoot();\n                if (!this.metrics) {\n                    this.metrics = new n(q);\n                };\n                if ((typeof this.initialHeight === \"undefined\")) {\n                    this.isBorderBox = (((l.get(q, \"box-sizing\") === \"border-box\") || (l.get(q, \"-moz-box-sizing\") === \"border-box\")) || (l.get(q, \"-webkit-box-sizing\") === \"border-box\"));\n                    this.borderBoxOffset = (((l.getFloat(q, \"padding-top\") + l.getFloat(q, \"padding-bottom\")) + l.getFloat(q, \"border-top-width\")) + l.getFloat(q, \"border-bottom-width\"));\n                    this.initialHeight = (q.offsetHeight - this.borderBoxOffset);\n                }\n            ;\n                var r = this.metrics.measure(), s = Math.max(this.initialHeight, r.height);\n                if (this.isBorderBox) {\n                    s += this.borderBoxOffset;\n                };\n                if ((s !== this.height)) {\n                    this.height = s;\n                    l.set(q, \"height\", (s + \"px\"));\n                    g.inform(\"reflow\");\n                    this.inform(\"resize\");\n                }\n            ;\n            }\n             else if (this.metrics) {\n                this.metrics.destroy();\n                this.metrics = null;\n            }\n            \n        ;\n        },\n        resetHeight: function() {\n            this.height = -1;\n            this.update();\n        },\n        _handleFocus: function() {\n            this.width = null;\n        }\n    });\n    p.getInstance = function(q) {\n        return (k.getInstance(q) || new p(q));\n    };\n    e.exports = p;\n});\n__d(\"URLScraper\", [\"event-extensions\",\"ArbiterMixin\",\"Class\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"Class\"), i = b(\"copyProperties\");\n    function j(ga) {\n        this.input = ga;\n        this.enable();\n    };\n    i(j.prototype, g, {\n        reset: function() {\n            this.lastPermissiveMatch = null;\n        },\n        enable: function() {\n            if (this.events) {\n                return\n            };\n            var ga = function(ha) {\n                setTimeout(this.check.bind(this, ha), 30);\n            };\n            this.events = Event.listen(this.input, {\n                paste: ga.bind(this, false),\n                keydown: ga.bind(this, true)\n            });\n        },\n        disable: function() {\n            if (!this.events) {\n                return\n            };\n            for (var event in this.events) {\n                this.events[event].remove();;\n            };\n            this.events = null;\n        },\n        check: function(ga) {\n            var ha = this.input.value;\n            if ((ga && j.trigger(ha))) {\n                return\n            };\n            var ia = j.match(ha), ja = j.permissiveMatch(ha);\n            if ((ja && ((ja != this.lastPermissiveMatch)))) {\n                this.lastPermissiveMatch = ja;\n                this.inform(\"match\", {\n                    url: ia,\n                    alt_url: ja\n                });\n            }\n        ;\n        }\n    });\n    var k = \"!\\\"#\u0025&'()*,-./:;\\u003C\\u003E?@[\\\\]^_`{|}\", l = \"\\u2000-\\u206f\\u00ab\\u00bb\", m = \"(?:25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9]?[0-9])\", n = \"(?:(?:ht|f)tps?)://\", o = ((((\"(?:(?:\" + m) + \"[.]){3}\") + m) + \")\"), p = \"(?:\\\\b)www\\\\d{0,3}[.]\", q = (((\"[^\\\\s\" + k) + l) + \"]\"), r = ((((\"(?:(?:[.:\\\\-_\u0025@]|\" + q) + \")*\") + q) + \")\"), s = \"(?:[.][a-z]{2,4})\", t = \"(?::\\\\d+){0,1}\", u = \"(?=[/?#])\", v = ((((((((((((((((((((((\"(?:\" + \"(?:\") + n) + r) + t) + \")|\") + \"(?:\") + o) + t) + \")|\") + \"(?:\") + p) + r) + s) + t) + \")|\") + \"(?:\") + r) + s) + t) + u) + \")\") + \")\"), w = \"[/#?]\", x = \"\\\\([^\\\\s()\\u003C\\u003E]+\\\\)\", y = \"[^\\\\s()\\u003C\\u003E?#]+\", z = (((\"[^\\\\s\" + k) + l) + \"]\"), aa = ((((((((((((((((\"(?:\" + \"(?:\") + w) + \")\") + \"(?:\") + \"(?:\") + x) + \"|\") + y) + \")*\") + \"(?:\") + x) + \"|\") + z) + \")\") + \")*\") + \")*\"), ba = new RegExp((((((((\"(\" + \"(?:\") + v) + \")\") + \"(?:\") + aa) + \")\") + \")\"), \"im\"), ca = (((((((((((\"(?:\" + \"(?:\") + w) + \")\") + \"(?:\") + \"(?:\") + x) + \"|\") + y) + \")*\") + \")*\") + \")*\"), da = new RegExp((((((((\"(\" + \"(?:\") + v) + \")\") + \"(?:\") + ca) + \")\") + \")\"), \"im\"), ea = new RegExp(((((((((((((\"(\" + \"(?:\") + n) + r) + t) + \")|\") + \"(?:\") + p) + r) + s) + t) + \")\") + \")\")), fa = /[\\s'\";]/;\n    j.match = function(ga) {\n        return j.matchToPattern(ga, ba);\n    };\n    j.permissiveMatch = function(ga) {\n        return j.matchToPattern(ga, da);\n    };\n    j.matchToPattern = function(ga, ha) {\n        var ia = (((ha.exec(ga) || []))[1] || null);\n        if ((ia && (ia.indexOf(\"@\") != -1))) {\n            return ((ea.exec(ia)) ? ia : null);\n        }\n         else return ia\n    ;\n    };\n    j.trigger = function(ga) {\n        return !fa.test(ga.charAt((ga.length - 1)));\n    };\n    e.exports = j;\n});\n__d(\"Composer\", [\"function-extensions\",\"Arbiter\",\"ArbiterMixin\",\"Button\",\"Class\",\"CSS\",\"DOM\",\"Env\",\"FileForm\",\"HTML\",\"Input\",\"PageTransitions\",\"Parent\",\"Run\",\"ServerJS\",\"TextAreaControl\",\"URI\",\"URLScraper\",\"$\",\"copyProperties\",\"ge\",\"tx\",\"event-extensions\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"Button\"), j = b(\"Class\"), k = b(\"CSS\"), l = b(\"DOM\"), m = b(\"Env\"), n = b(\"FileForm\"), o = b(\"HTML\"), p = b(\"Input\"), q = b(\"PageTransitions\"), r = b(\"Parent\"), s = b(\"Run\"), t = b(\"ServerJS\"), u = b(\"TextAreaControl\"), v = b(\"URI\"), w = b(\"URLScraper\"), x = b(\"$\"), y = b(\"copyProperties\"), z = b(\"ge\"), aa = b(\"tx\");\n    b(\"event-extensions\");\n    var ba = b(\"event-extensions\").$E, ca = 1, da = 4, ea = {\n    }, fa = function() {\n        var ja = l.scry(this.root, \"span.linkAttachment\")[0];\n        if ((!ja && this.isMetaComposer)) {\n            ja = l.scry(this.root, \"span.attachmentAcceptsLink\")[0];\n        };\n        if (!ja) {\n            return\n        };\n        var ka = r.byTag(ja, \"form\");\n        this.scraper = new w(this.input);\n        this.scraper.subscribe(\"match\", function(la, ma) {\n            if (this.isMetaComposer) {\n                var na = this.form.xhpc_targetid, oa = new v(\"/ajax/metacomposer/attachment/link/scraper.php\");\n                oa.addQueryData({\n                    scrape_url: encodeURIComponent(ma.url),\n                    alt_scrape_url: encodeURIComponent(ma.alt_url),\n                    targetid: na.value\n                });\n                ka.action = oa.toString();\n            }\n             else {\n                k.show(ja);\n                ka.action = (\"/ajax/composer/attachment/link/scraper.php?scrape_url=\" + encodeURIComponent(ma.url));\n            }\n        ;\n            ka.xhpc.value = ja.id;\n            ka.xhpc.disabled = false;\n            ka.xhpc.click();\n        }.bind(this));\n        (this.isMetaComposer && this.scraper.check());\n    }, ga = function(ja) {\n        if ((this.inform(\"submit\") === false)) {\n            ja.kill();\n            return false;\n        }\n    ;\n        if (this.submitHandler) {\n            return (new Function(this.submitHandler)).apply(this.form)\n        };\n    };\n    function ha(ja, ka, la, ma, na) {\n        ea[ja.id] = this;\n        this.root = ja;\n        this.resetCfg = ka;\n        this.dataSource = ma;\n        this.lazyEndpoint = (this.resetCfg && this.resetCfg.lazyEndpoint);\n        this.focus = l.find(ja, \"div.focus_target\");\n        this.form = l.find(ja, \"form.attachmentForm\");\n        this.content = l.find(ja, \"div.attachmentContent\");\n        this.isMetaComposer = la;\n        if (this.isMetaComposer) {\n            this.messageBox = l.find(ja, \"div.uiMetaComposerMessageBox\");\n            this.metaArea = l.find(ja, \"div.attachmentMetaArea\");\n            this.bottomArea = l.find(ja, \"div.attachmentBottomArea\");\n            this.barArea = l.find(ja, \"div.attachmentBarArea\");\n            this.auxBarArea = l.find(ja, \".attachmentAuxBarArea\");\n            this.blurb = l.find(ja, \"div.uiMetaComposerMessageBox div.textBlurb\");\n            this.input = l.find(ja, \"div.uiMetaComposerMessageBox textarea.input\");\n            this.button = l.find(ja, \"div.uiMetaComposerMessageBox label.submitBtn\");\n            this.privacy = l.find(ja, \"div.uiMetaComposerMessageBox li.privacyWidget\");\n            this.boosting = l.scry(ja, \"div.uiMetaComposerMessageBox li.boostingWidget\");\n        }\n         else {\n            this.blurb = l.find(ja, \"div.uiComposerMessageBox div.textBlurb\");\n            this.input = l.find(ja, \"div.uiComposerMessageBox textarea.input\");\n            this.button = l.find(ja, \"div.uiComposerMessageBox label.submitBtn\");\n            this.privacy = l.find(ja, \"div.uiComposerMessageBox li.privacyWidget\");\n            this.boosting = [];\n        }\n    ;\n        Event.listen(this.form, \"submit\", ga.bind(this));\n        if (this.isMetaComposer) {\n            Event.listen(this.input, \"focus\", this.onFocus.bind(this));\n            if (na) {\n                if ((document.activeElement === this.input)) {\n                    this.onFocus.bind(this).defer();\n                };\n            }\n             else if (r.byClass(this.input, \"child_was_focused\")) {\n                this.onFocus.bind(this).defer();\n            }\n        ;\n        }\n    ;\n        g.inform((\"xhpc/construct/\" + ja.id), this, g.BEHAVIOR_STATE);\n    };\n    y(ha.prototype, h, {\n        init: function(ja) {\n            this.mentionsInput = ja;\n            if (this.mentionsInput) {\n                this.mentionsInput.subscribe(\"init\", function() {\n                    var ka = this.mentionsInput.getTypeahead().getView();\n                    ka.subscribe([\"reset\",\"render\",], function(la) {\n                        k.conditionClass(this.root, \"uiComposerMention\", ((la == \"render\")));\n                    }.bind(this));\n                }.bind(this));\n            };\n            fa.call(this);\n            this.inform(\"init\", null, g.BEHAVIOR_PERSISTENT);\n            this.setupListen();\n            s.onBeforeUnload(this._handleUnsavedChanges.bind(this));\n        },\n        setupListen: function() {\n            Event.listen(this.root, \"click\", this.clickHandler.bind(this));\n        },\n        clickHandler: function(event) {\n            var ja = event.getTarget();\n            if (r.byClass(ja, \"collapsedPostButton\")) {\n                this.focusInput.bind(this).defer();\n            };\n        },\n        setBlurb: function(ja) {\n            l.setContent(this.blurb, ja);\n        },\n        setEnabled: function(ja) {\n            i.setEnabled(this.button, ja);\n        },\n        getEndpoint: function() {\n            return this.form.getAttribute(\"action\");\n        },\n        setEndpoint: function(ja) {\n            this.form.setAttribute(\"action\", ja);\n        },\n        setLoading: function(ja) {\n            k.conditionClass(this.root, \"async_saving\", !!ja);\n        },\n        setContentVisible: function(ja) {\n            k.conditionClass(this.root, \"uiComposerHideContent\", !ja);\n        },\n        setMessageBoxVisible: function(ja) {\n            k.conditionClass(this.root, \"uiComposerHideMessageBox\", !ja);\n        },\n        setInputVisible: function(ja) {\n            k.conditionClass(this.root, \"uiComposerHideInput\", !ja);\n        },\n        setStatusBoxVisible: function(ja) {\n            k.conditionClass(this.root, \"uiComposerHideStatusBox\", !ja);\n        },\n        setTopicTaggerVisible: function(ja) {\n            k.conditionClass(this.root, \"uiTagComposerHidden\", !ja);\n        },\n        mutate: function(ja) {\n            if (this.lastComposerInput) {\n                p.setValue(this.input, p.getValue(z(this.lastComposerInput)));\n            };\n            var ka = z(ja.xhpc);\n            if (ka) {\n                var la = l.scry(this.root, \".uiComposerAttachmentSelected\")[0];\n                if ((ja.confirmAugmentation && (la !== ka))) {\n                    return\n                };\n                (la && k.removeClass(la, \"uiComposerAttachmentSelected\"));\n                k.addClass(ka, \"uiComposerAttachmentSelected\");\n                if (!ja.disableCache) {\n                    Event.listen(ka, \"click\", function(na) {\n                        ba(na).stop();\n                        ja.disableCache = true;\n                        this.mutate(ja);\n                    }.bind(this));\n                };\n            }\n        ;\n            if (!ja.keepContentAreas) {\n                this.setContentVisible(false);\n                l.empty(this.content);\n                if (this.isMetaComposer) {\n                    (this.mentionsInput && this.mentionsInput.setAuxContent(null));\n                    l.empty(this.metaArea);\n                    l.empty(this.bottomArea);\n                    l.empty(this.barArea);\n                    l.empty(this.auxBarArea);\n                }\n            ;\n            }\n        ;\n            if (ja.content) {\n                l.setContent(this.content, o(ja.content));\n                this.setContentVisible(true);\n            }\n        ;\n            if (this.isMetaComposer) {\n                (ja.metaContent && l.setContent(this.metaArea, o(ja.metaContent)));\n                (ja.bottomContent && l.setContent(this.bottomArea, o(ja.bottomContent)));\n                (ja.barContent && l.setContent(this.barArea, o(ja.barContent)));\n                (ja.auxBarContent && l.setContent(this.auxBarArea, o(ja.auxBarContent)));\n            }\n        ;\n            this.setMessageBoxVisible(!ja.messageBoxHidden);\n            k.conditionClass(this.root, \"uiComposerWhiteMessageBox\", ((!ja.messageBoxHidden && !ja.inputHidden) && !ja.content));\n            this.setInputVisible(!ja.inputHidden);\n            this.setStatusBoxVisible(!ja.statusBoxHidden);\n            k.conditionShow(this.privacy, !ja.privacyWidgetHidden);\n            if ((this.boosting.length > 0)) {\n                k.conditionShow(this.boosting[0], !ja.boostingWidgetHidden);\n            };\n            if (!ja.keepContentAreas) {\n                p.setPlaceholder(this.input, ja.placeholder);\n                i.setLabel(this.button, ja.buttonLabel);\n            }\n        ;\n            this.setBlurb(o(ja.blurb));\n            if (ja.autoscrape) {\n                (this.scraper && this.scraper.enable());\n            }\n             else (this.scraper && this.scraper.disable());\n        ;\n            this.setEnabled(!ja.disabled);\n            this.setTopicTaggerVisible(!ja.hideTopicTagger);\n            this.setEndpoint(ja.endpoint);\n            if ((ja.formType == ca)) {\n                this.form.setAttribute(\"rel\", \"async\");\n            }\n             else this.form.removeAttribute(\"rel\");\n        ;\n            this.form.removeAttribute(\"target\");\n            if ((ja.formType == da)) {\n                if (!this._fileForm) {\n                    this._fileForm = new n(this.form);\n                    this._fileForm.setAllowCrossOrigin(m.allowCrossOriginComposerUpload);\n                    this._fileForm.subscribe(\"submit\", this.setLoading.bind(this, true));\n                    this._fileForm.subscribe(\"failure\", this.setLoading.bind(this, false));\n                }\n            ;\n            }\n             else if (this._fileForm) {\n                this._fileForm.destroy();\n                this._fileForm = null;\n            }\n            \n        ;\n            this.submitHandler = ja.submitHandler;\n            this.lazyEndpoint = ja.lazyEndpoint;\n            k.addClass(this.root, \"uiComposerInteracted\");\n            k.addClass(this.root, \"uiComposerOpen\");\n            if (ja.messageBoxFocused) {\n                var ma = document.activeElement;\n                if (((ma === document.body) || r.byClass(ma, \"attachmentLink\"))) {\n                    this.focusInput.bind(this).defer();\n                };\n            }\n        ;\n            if (ja.inputElement) {\n                p.setValue(z(ja.inputElement), p.getValue(this.input));\n                u.getInstance(z(ja.inputElement)).update();\n            }\n             else u.getInstance(this.input).update();\n        ;\n            this.lastComposerInput = ja.inputElement;\n            g.inform(\"composer/mutate\", this);\n        },\n        subscribeToMutate: function(ja) {\n            return g.subscribe(\"composer/mutate\", function(ka, la) {\n                if ((la === this)) {\n                    ja();\n                };\n            }.bind(this));\n        },\n        unsubscribeFromMutate: function(ja) {\n            ja.unsubscribe();\n        },\n        reset: function(ja) {\n            if (this.isMetaComposer) {\n                l.empty(this.metaArea);\n                l.empty(this.bottomArea);\n                l.empty(this.barArea);\n                l.empty(this.auxBarArea);\n            }\n        ;\n            if (this.resetCfg) {\n                this.mutate(this.resetCfg);\n            }\n             else {\n                var ka = l.scry(this.root, \".uiComposerAttachmentSelected\")[0];\n                if (ka) {\n                    k.removeClass(ka, \"uiComposerAttachmentSelected\");\n                };\n            }\n        ;\n            if (!ja) {\n                p.reset(this.input);\n                (this.mentionsInput && this.mentionsInput.reset());\n                (this.scraper && this.scraper.reset());\n            }\n        ;\n            k.removeClass(this.root, \"uiComposerInteracted\");\n            k.setClass(this.focus, \"focus_target\");\n            this.setLoading(false);\n            g.inform(\"composer/reset\");\n        },\n        onFocus: function() {\n            if (this.lazyEndpoint) {\n                var ja = l.find(this.root, \"form.attachmentSelectForm\"), ka = new v(this.lazyEndpoint);\n                ka.addQueryData({\n                    isAugmentation: true\n                });\n                ja.action = ka.toString();\n                var la = l.scry(this.root, \".uiComposerAttachmentSelected\")[0];\n                ja.xhpc.value = (la && la.id);\n                ja.xhpc.click();\n                k.removeClass.curry(this.root, \"async_saving\").defer();\n            }\n        ;\n            this.inform(\"focus\");\n        },\n        focusInput: function() {\n            p.focus(this.input);\n        },\n        getInput: function() {\n            return this.input;\n        },\n        updateDataSourceToken: function(ja) {\n            if (this.dataSource) {\n                this.dataSource.updateToken(ja);\n            };\n        },\n        _handleUnsavedChanges: function() {\n            var ja = q.getNextURI();\n            if (ja.getQueryData().hasOwnProperty(\"theater\")) {\n                return\n            };\n            if ((((this.input.offsetParent !== null) && !p.isEmpty(this.input)) && !((a.Dialog && a.Dialog.getCurrent())))) {\n                return \"You haven't finished your post yet. Do you want to leave without finishing?\"\n            };\n        }\n    });\n    var ia;\n    y(ha, {\n        setNodeToConfigure: function(ja) {\n            ia = ja;\n        },\n        configure: function(ja, ka, la) {\n            var ma = r.byClass(ia, \"uiComposer\").id, na = g.subscribe((\"xhpc/construct/\" + ma), function(oa, pa) {\n                (function() {\n                    na.unsubscribe();\n                }).defer();\n                pa.mutate(ja);\n                pa.subscribe(\"init\", function() {\n                    new t().handle(ka);\n                    new Function(la)();\n                    if (ja.attachmentJS) {\n                        new Function(ja.attachmentJS).call(pa);\n                    };\n                });\n            });\n        },\n        publish: function(ja, ka) {\n            ka = (ka || {\n            });\n            ka.composer_id = ja;\n            ka.composer = ha.getInstance(ja);\n            (ka.composer && ka.composer.reset(false));\n            if (ka.streamNode) {\n                ka.streamStory = ka.streamNode;\n            }\n             else if (ka.streamMarkup) {\n                ka.streamStory = o(ka.streamMarkup).getRootNode();\n            }\n        ;\n            g.inform(\"composer/publish\", ka);\n        },\n        finish: function(ja) {\n            ha.getInstance(ja).setLoading(false);\n        },\n        getInstance: function(ja) {\n            var ka = r.byClass(x(ja), \"uiComposer\");\n            return (ka ? ea[ka.id] : null);\n        }\n    });\n    e.exports = ha;\n});\n__d(\"legacy:Composer\", [\"Composer\",], function(a, b, c, d) {\n    a.Composer = b(\"Composer\");\n}, 3);\nfunction MetaComposerMessageBox() {\n\n};\ncopyProperties(MetaComposerMessageBox.prototype, {\n    init: function(a, b) {\n        this.inputContainer = DOM.scry(a, \"div.inputContainer\")[0];\n        this.textInput = DOM.scry(a, \"textarea.mentionsTextarea\")[0];\n        this.metaArea = DOM.scry(a, \"div.attachmentMetaArea\")[0];\n        this.bottomArea = DOM.scry(a, \"div.attachmentBottomArea\")[0];\n        this.barArea = DOM.scry(a, \"div.attachmentBarArea\")[0];\n        Event.listen(this.inputContainer, \"click\", function(c) {\n            var d = c.getTarget();\n            if ((!DOM.contains(this.metaArea, d) && (d !== this.textInput))) {\n                this.textInput.focus();\n            };\n        }.bind(this));\n    }\n});\n__d(\"FBDesktopDetect\", [\"UserAgent\",], function(a, b, c, d, e, f) {\n    var g = b(\"UserAgent\"), h = \"facebook.desktopplugin\", i = {\n        mimeType: \"application/x-facebook-desktop-1\",\n        isPluginInstalled: function() {\n            if (g.osx()) {\n                return false\n            };\n            var j = null;\n            if (a.ActiveXObject) {\n                try {\n                    j = new a.ActiveXObject(h);\n                    if (j) {\n                        return true\n                    };\n                } catch (k) {\n                \n                };\n            }\n             else if ((a.navigator && a.navigator.plugins)) {\n                a.navigator.plugins.refresh(false);\n                for (var l = 0, m = a.navigator.plugins.length; (l < m); l++) {\n                    j = a.navigator.plugins[l];\n                    if ((j.length && (j[0].type === this.mimeType))) {\n                        return true\n                    };\n                };\n            }\n            \n        ;\n            return false;\n        }\n    };\n    e.exports = i;\n});\n__d(\"CacheStorage\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\"), h = {\n        localstorage: i\n    };\n    function i() {\n        this._store = a.localStorage;\n    };\n    i.available = function() {\n        return !!a.localStorage;\n    };\n    g(i.prototype, {\n        keys: function() {\n            var k = [];\n            for (var l = 0; (l < this._store.length); l++) {\n                k.push(this._store.key(l));;\n            };\n            return k;\n        },\n        get: function(k) {\n            return this._store.getItem(k);\n        },\n        set: function(k, l) {\n            this._store.setItem(k, l);\n        },\n        remove: function(k) {\n            this._store.removeItem(k);\n        },\n        clear: function() {\n            this._store.clear();\n        }\n    });\n    function j(k, l) {\n        this._key_prefix = (l || \"_cs_\");\n        this._magic_prefix = \"_@_\";\n        if ((k == \"AUTO\")) {\n            for (var m in h) {\n                var n = h[m];\n                if (n.available()) {\n                    k = m;\n                    break;\n                }\n            ;\n            }\n        };\n        if (k) {\n            if ((!h[k] || !h[k].available())) {\n                this._backend = null;\n            }\n             else this._backend = new h[k]();\n        \n        };\n        this._memcache = {\n        };\n    };\n    g(j.prototype, {\n        keys: function() {\n            var k = [];\n            if (this._backend) {\n                var l = this._backend.keys();\n                for (var m = 0; (m < l.length); m++) {\n                    if ((l[m].substr(0, this._key_prefix.length) == this._key_prefix)) {\n                        k.push(l[m].substr(this._key_prefix.length));\n                    };\n                };\n                return k;\n            }\n        ;\n            for (var n in this._memcache) {\n                k.push(n);;\n            };\n            return k;\n        },\n        set: function(k, l) {\n            this._memcache[k] = l;\n            if (this._backend) {\n                if ((typeof l == \"string\")) {\n                    l = (this._magic_prefix + l);\n                }\n                 else l = JSON.stringify(l);\n            ;\n                this._backend.set((this._key_prefix + k), l);\n            }\n        ;\n        },\n        get: function(k, l) {\n            if ((this._memcache[k] !== undefined)) {\n                return this._memcache[k]\n            };\n            var m;\n            if (this._backend) {\n                m = this._backend.get((this._key_prefix + k));\n                if ((m !== null)) {\n                    if ((m.substr(0, this._magic_prefix.length) == this._magic_prefix)) {\n                        m = m.substr(this._magic_prefix.length);\n                    }\n                     else try {\n                        m = JSON.parse(m);\n                    } catch (n) {\n                        m = undefined;\n                    }\n                ;\n                    if ((m !== undefined)) {\n                        this._memcache[k] = m;\n                    };\n                }\n                 else m = undefined;\n            ;\n            }\n        ;\n            if (((m === undefined) && (l !== undefined))) {\n                m = l;\n                this._memcache[k] = m;\n                if (this._backend) {\n                    var o;\n                    if ((typeof m == \"string\")) {\n                        o = (this._magic_prefix + m);\n                    }\n                     else o = JSON.stringify(m);\n                ;\n                    this._backend.set((this._key_prefix + k), o);\n                }\n            ;\n            }\n        ;\n            return m;\n        },\n        remove: function(k) {\n            delete this._memcache[k];\n            if (this._backend) {\n                this._backend.remove((this._key_prefix + k));\n            };\n        }\n    });\n    e.exports = j;\n});\n__d(\"FBDesktopPlugin\", [\"CacheStorage\",\"DOM\",\"Env\",\"FBDesktopDetect\",\"HTML\",\"URI\",\"$\",], function(a, b, c, d, e, f) {\n    var g = b(\"CacheStorage\"), h = b(\"DOM\"), i = b(\"Env\"), j = b(\"FBDesktopDetect\"), k = b(\"HTML\"), l = b(\"URI\"), m = b(\"$\"), n = new g(\"localstorage\", \"_socialfox_\"), o = {\n        _plugin: \"_not_checked\",\n        arbiterInform: function(p, q) {\n            var r = JSON.stringify({\n                name: p,\n                payload: q\n            });\n            this._transmitCommand(\"arbiterinform\", r);\n        },\n        bringToFront: function() {\n            this._transmitCommand(\"bringtofront\");\n        },\n        dock: function() {\n            this._transmitCommand(\"dock\");\n        },\n        getPlugin: function() {\n            if ((this._plugin === \"_not_checked\")) {\n                this._plugin = null;\n                if (j.isPluginInstalled()) {\n                    var p = h.create(\"div\");\n                    document.body.appendChild(p);\n                    h.setContent(p, k(((((\"\\u003Cobject id=\\\"kiwi_plugin\\\" \" + \"type=\\\"\") + j.mimeType) + \"\\\" width=\\\"0\\\" height=\\\"0\\\"\\u003E\") + \"\\u003C/object\\u003E\")));\n                    this._plugin = m(\"kiwi_plugin\");\n                }\n            ;\n            }\n        ;\n            return this._plugin;\n        },\n        getUserID: function() {\n            var p = this.getPlugin();\n            return ((p && (\"getUserID\" in p)) && p.getUserID());\n        },\n        isAppRunning: function() {\n            var p = this.getPlugin();\n            return ((p && (\"isAppRunning\" in p)) && p.isAppRunning());\n        },\n        launchApp: function() {\n            var p = this.getPlugin();\n            return ((p && (\"launchApp\" in p)) && p.launchApp());\n        },\n        logout: function(p) {\n            p = (p || \"0\");\n            var q = this.getPlugin();\n            if (q) {\n                q.logout(p);\n            };\n        },\n        recheck: function() {\n            if ((this._plugin === null)) {\n                this._plugin = \"_not_checked\";\n            };\n        },\n        shouldSuppressBeeper: function() {\n            return this.isAppRunning();\n        },\n        shouldSuppressMessages: function() {\n            var p = this.getUserID();\n            if (p) {\n                return (p === i.user);\n            }\n             else return this.isAppRunning()\n        ;\n        },\n        shouldSuppressSidebar: function() {\n            var p = this.getPlugin(), q = ((p && (\"isAppDocked\" in p)) && p.isAppDocked()), r = (n && (n.get(\"active\") === \"true\"));\n            return (q || r);\n        },\n        transferAuthToken: function(p, q) {\n            if ((p && (p.length > 0))) {\n                var r = this.getPlugin();\n                if (r) {\n                    r.setAccessToken(p, q);\n                    var s = setInterval(function() {\n                        r.setAccessToken(p, q);\n                    }, 500);\n                    setTimeout(function() {\n                        clearInterval(s);\n                    }, (10 * 1000));\n                }\n            ;\n            }\n        ;\n            if (this.redirectHome) {\n                window.location.href = l().setPath().toString();\n            };\n        },\n        _transmitCommand: function(p, q) {\n            q = (q || \"\");\n            var r = this.getPlugin();\n            if ((r && (\"transmitCommand\" in r))) {\n                r.transmitCommand(p, q);\n            };\n        }\n    };\n    e.exports = o;\n});\n__d(\"ARIA\", [\"DOM\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"ge\"), i, j, k = function() {\n        i = h(\"ariaAssertiveAlert\");\n        if (!i) {\n            i = g.create(\"div\", {\n                id: \"ariaAssertiveAlert\",\n                className: \"accessible_elem\",\n                role: \"alert\",\n                \"aria-live\": \"assertive\"\n            });\n            g.appendContent(document.body, i);\n        }\n    ;\n        j = h(\"ariaPoliteAlert\");\n        if (!j) {\n            j = i.cloneNode(false);\n            j.setAttribute(\"id\", \"ariaPoliteAlert\");\n            j.setAttribute(\"aria-live\", \"polite\");\n            g.appendContent(document.body, j);\n        }\n    ;\n        k = bagofholding;\n    };\n    function l(n, o) {\n        k();\n        var p = (o ? i : j);\n        g.setContent(p, n);\n    };\n    var m = {\n        owns: function(n, o) {\n            n.setAttribute(\"aria-owns\", g.getID(o));\n        },\n        setPopup: function(n, o) {\n            var p = g.getID(o);\n            n.setAttribute(\"aria-owns\", p);\n            n.setAttribute(\"aria-controls\", p);\n            n.setAttribute(\"aria-haspopup\", \"true\");\n            if ((n.tabIndex == -1)) {\n                n.tabIndex = 0;\n            };\n        },\n        announce: function(n) {\n            l(n, true);\n        },\n        notify: function(n) {\n            l(n);\n        }\n    };\n    e.exports = m;\n});\n__d(\"ContextualDialogFooterLink\", [\"event-extensions\",\"copyProperties\",\"CSS\",\"DOM\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"copyProperties\"), h = b(\"CSS\"), i = b(\"DOM\");\n    function j(k) {\n        this._layer = k;\n    };\n    g(j.prototype, {\n        _subscriptions: null,\n        enable: function() {\n            var k = this._layer.getRoot(), l = i.scry(k, \".uiContextualDialogFooterLink\")[0], m = \"uiContextualDialogHoverFooterArrow\";\n            this._subscriptions = [Event.listen(l, \"mouseenter\", h.addClass.curry(k, m)),Event.listen(l, \"mouseleave\", h.removeClass.curry(k, m)),];\n        },\n        disable: function() {\n            this._subscriptions.forEach(function(k) {\n                k.remove();\n            });\n            this._subscriptions = null;\n        }\n    });\n    e.exports = j;\n});\n__d(\"ContextualThing\", [\"DOM\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"ge\");\n    function i(k) {\n        var l;\n        while (k) {\n            if ((k.getAttribute && (l = k.getAttribute(\"data-ownerid\")))) {\n                return h(l)\n            };\n            k = k.parentNode;\n        };\n        return null;\n    };\n    var j = {\n        register: function(k, l) {\n            k.setAttribute(\"data-ownerid\", g.getID(l));\n        },\n        remove: function(k) {\n            k.removeAttribute(\"data-ownerid\");\n        },\n        containsIncludingLayers: function(k, l) {\n            while (l) {\n                if (g.contains(k, l)) {\n                    return true\n                };\n                l = i(l);\n            };\n            return false;\n        }\n    };\n    e.exports = j;\n});\n__d(\"BootloadedReact\", [\"Bootloader\",], function(a, b, c, d, e, f) {\n    var g = b(\"Bootloader\"), h = function(j) {\n        g.loadModules([\"React\",], j);\n    }, i = {\n        isValidComponent: function(j) {\n            return (((j && (typeof j.genMarkup === \"function\")) && (typeof j.handleUpdateProps === \"function\")));\n        },\n        initializeTouchEvents: function(j, k) {\n            h(function(l) {\n                l.initializeTouchEvents(j);\n                (k && k());\n            });\n        },\n        createComponent: function(j, k) {\n            h(function(l) {\n                var m = l.createComponent(j);\n                (k && k(m));\n            });\n        },\n        renderComponent: function(j, k, l) {\n            h(function(m) {\n                var n = m.renderComponent(j, k);\n                (l && l(n));\n            });\n        },\n        renderOrUpdateComponent: function(j, k, l) {\n            h(function(m) {\n                var n = m.renderOrUpdateComponent(j, k);\n                (l && l(n));\n            });\n        },\n        destroyAndReleaseReactRootNode: function(j, k) {\n            h(function(l) {\n                l.destroyAndReleaseReactRootNode(j);\n                (k && k());\n            });\n        }\n    };\n    e.exports = i;\n});\n__d(\"KeyEventController\", [\"event-extensions\",\"DOM\",\"Run\",\"copyProperties\",\"isEmpty\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"DOM\"), h = b(\"Run\"), i = b(\"event-extensions\").$E, j = b(\"copyProperties\"), k = b(\"isEmpty\");\n    function l() {\n        this.handlers = {\n        };\n        document.onkeyup = this.onkeyevent.bind(this, \"onkeyup\");\n        document.onkeydown = this.onkeyevent.bind(this, \"onkeydown\");\n        document.onkeypress = this.onkeyevent.bind(this, \"onkeypress\");\n    };\n    j(l, {\n        instance: null,\n        getInstance: function() {\n            return (l.instance || (l.instance = new l()));\n        },\n        defaultFilter: function(event, m) {\n            event = i(event);\n            return ((l.filterEventTypes(event, m) && l.filterEventTargets(event, m)) && l.filterEventModifiers(event, m));\n        },\n        filterEventTypes: function(event, m) {\n            if ((m === \"onkeydown\")) {\n                return true\n            };\n            return false;\n        },\n        filterEventTargets: function(event, m) {\n            var n = event.getTarget();\n            if ((n.contentEditable === \"true\")) {\n                return false\n            };\n            return ((!g.isNodeOfType(n, l._interactiveElements) || ((n.type in l._uninterestingTypes))) || (((g.isNodeOfType(n, [\"input\",\"textarea\",]) && (n.value.length === 0)) && (event.keyCode in l._controlKeys))));\n        },\n        filterEventModifiers: function(event, m) {\n            if ((((event.ctrlKey || event.altKey) || event.metaKey) || event.repeat)) {\n                return false\n            };\n            return true;\n        },\n        registerKey: function(m, n, o, p) {\n            if ((o === undefined)) {\n                o = l.defaultFilter;\n            };\n            var q = l.getInstance(), r = q.mapKey(m);\n            if (k(q.handlers)) {\n                h.onLeave(q.resetHandlers.bind(q));\n            };\n            var s = {\n            };\n            for (var t = 0; (t < r.length); t++) {\n                m = r[t];\n                if ((!q.handlers[m] || p)) {\n                    q.handlers[m] = [];\n                };\n                var u = {\n                    callback: n,\n                    filter: o\n                };\n                s[m] = u;\n                q.handlers[m].push(u);\n            };\n            return {\n                remove: function() {\n                    for (var v in s) {\n                        if ((q.handlers[v] && q.handlers[v].length)) {\n                            var w = q.handlers[v].indexOf(s[v]);\n                            ((w >= 0) && q.handlers[v].splice(w, 1));\n                        }\n                    ;\n                        delete s[v];\n                    };\n                }\n            };\n        },\n        keyCodeMap: {\n            BACKSPACE: [8,],\n            TAB: [9,],\n            RETURN: [13,],\n            ESCAPE: [27,],\n            LEFT: [37,63234,],\n            UP: [38,63232,],\n            RIGHT: [39,63235,],\n            DOWN: [40,63233,],\n            DELETE: [46,],\n            COMMA: [188,],\n            PERIOD: [190,],\n            \"`\": [192,],\n            \"[\": [219,],\n            \"]\": [221,]\n        },\n        _interactiveElements: [\"input\",\"select\",\"textarea\",\"object\",\"embed\",],\n        _uninterestingTypes: {\n            checkbox: 1,\n            radio: 1,\n            submit: 1\n        },\n        _controlKeys: {\n            8: 1,\n            9: 1,\n            13: 1,\n            27: 1,\n            37: 1,\n            63234: 1,\n            38: 1,\n            63232: 1,\n            39: 1,\n            63235: 1,\n            40: 1,\n            63233: 1,\n            46: 1\n        }\n    });\n    j(l.prototype, {\n        mapKey: function(m) {\n            if (((m >= 0) && (m <= 9))) {\n                if ((typeof (m) != \"number\")) {\n                    m = (m.charCodeAt(0) - 48);\n                };\n                return [(48 + m),(96 + m),];\n            }\n        ;\n            var n = l.keyCodeMap[m.toUpperCase()];\n            if (n) {\n                return n\n            };\n            return [m.toUpperCase().charCodeAt(0),];\n        },\n        onkeyevent: function(m, n) {\n            n = i(n);\n            var o = (this.handlers[n.keyCode] || this.handlers[n.which]), p, q, r;\n            if (o) {\n                for (var s = 0; (s < o.length); s++) {\n                    p = o[s].callback;\n                    q = o[s].filter;\n                    try {\n                        if ((!q || q(n, m))) {\n                            r = p(n, m);\n                            if ((r === false)) {\n                                return Event.kill(n)\n                            };\n                        }\n                    ;\n                    } catch (t) {\n                    \n                    };\n                }\n            };\n            return true;\n        },\n        resetHandlers: function() {\n            this.handlers = {\n            };\n        }\n    });\n    e.exports = l;\n});\n__d(\"Layer\", [\"event-extensions\",\"ArbiterMixin\",\"BehaviorsMixin\",\"BootloadedReact\",\"Class\",\"ContextualThing\",\"CSS\",\"DataStore\",\"DOM\",\"HTML\",\"KeyEventController\",\"Style\",\"$\",\"copyProperties\",\"ge\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"BehaviorsMixin\"), i = b(\"BootloadedReact\"), j = b(\"Class\"), k = b(\"ContextualThing\"), l = b(\"CSS\"), m = b(\"DataStore\"), n = b(\"DOM\"), o = b(\"HTML\"), p = b(\"KeyEventController\"), q = b(\"Style\"), r = b(\"$\"), s = b(\"copyProperties\"), t = b(\"ge\"), u = [];\n    function v(w, x) {\n        this._config = (w || {\n        });\n        if (x) {\n            this._configure(this._config, x);\n            var y = (this._config.addedBehaviors || []);\n            this.enableBehaviors(this._getDefaultBehaviors().concat(y));\n        }\n    ;\n    };\n    s(v, g);\n    s(v, {\n        init: function(w, x) {\n            w.init(x);\n        },\n        initAndShow: function(w, x) {\n            w.init(x).show();\n        },\n        show: function(w) {\n            w.show();\n        }\n    });\n    s(v.prototype, g, h, {\n        _initialized: false,\n        _root: null,\n        _shown: false,\n        _hiding: false,\n        _causalElement: null,\n        _reactContainer: null,\n        init: function(w) {\n            this._configure(this._config, w);\n            var x = (this._config.addedBehaviors || []);\n            this.enableBehaviors(this._getDefaultBehaviors().concat(x));\n            this._initialized = true;\n            return this;\n        },\n        _configure: function(w, x) {\n            if (x) {\n                var y = n.isNode(x), z = ((typeof x === \"string\") || o.isHTML(x));\n                this.containsReactComponent = i.isValidComponent(x);\n                if (z) {\n                    x = o(x).getRootNode();\n                }\n                 else if (this.containsReactComponent) {\n                    var aa = document.createElement(\"div\");\n                    i.renderComponent(x, aa);\n                    x = this._reactContainer = aa;\n                }\n                \n            ;\n            }\n        ;\n            this._root = this._buildWrapper(w, x);\n            l.addClass(this._root, \"uiLayer\");\n            if (w.causalElement) {\n                this._causalElement = t(w.causalElement);\n            };\n            m.set(this._root, \"layer\", this);\n        },\n        _getDefaultBehaviors: function() {\n            return [];\n        },\n        getCausalElement: function() {\n            return this._causalElement;\n        },\n        setCausalElement: function(w) {\n            this._causalElement = w;\n        },\n        getInsertParent: function() {\n            return (this._insertParent || document.body);\n        },\n        getRoot: function() {\n            return this._root;\n        },\n        _getContentRoot: function() {\n            return this._root;\n        },\n        _buildWrapper: function(w, x) {\n            return x;\n        },\n        setInsertParent: function(w) {\n            if (w) {\n                if ((this._shown && (w !== this.getInsertParent()))) {\n                    n.appendContent(w, this.getRoot());\n                    this.updatePosition();\n                }\n            ;\n                this._insertParent = w;\n            }\n        ;\n            return this;\n        },\n        show: function() {\n            if (this._shown) {\n                return this\n            };\n            var w = this.getRoot();\n            this.inform(\"beforeshow\");\n            q.set(w, \"visibility\", \"hidden\");\n            q.set(w, \"overflow\", \"hidden\");\n            l.show(w);\n            n.appendContent(this.getInsertParent(), w);\n            if ((this.updatePosition() !== false)) {\n                u.push(this);\n                this._shown = true;\n                this.inform(\"show\");\n                v.inform(\"show\", this);\n            }\n             else n.remove(w);\n        ;\n            q.set(w, \"visibility\", \"\");\n            q.set(w, \"overflow\", \"\");\n            this.inform(\"aftershow\");\n            return this;\n        },\n        hide: function() {\n            if (((this._hiding || !this._shown) || (this.inform(\"beforehide\") === false))) {\n                return this\n            };\n            this._hiding = true;\n            if ((this.inform(\"starthide\") !== false)) {\n                this.finishHide();\n            };\n            return this;\n        },\n        finishHide: function() {\n            if (this._shown) {\n                u.remove(this);\n                this._hiding = false;\n                this._shown = false;\n                n.remove(this.getRoot());\n                this.inform(\"hide\");\n                v.inform(\"hide\", this);\n            }\n        ;\n        },\n        isShown: function() {\n            return this._shown;\n        },\n        updatePosition: function() {\n            return true;\n        },\n        destroy: function() {\n            if (this.containsReactComponent) {\n                i.destroyAndReleaseReactRootNode(this._reactContainer);\n            };\n            this.finishHide();\n            this.destroyBehaviors();\n            this.inform(\"destroy\");\n            v.inform(\"destroy\", this);\n            m.remove(this._root, \"layer\");\n            this._root = this._causalElement = null;\n        }\n    });\n    Event.listen(document.documentElement, \"keydown\", function(event) {\n        if (p.filterEventTargets(event, \"keydown\")) {\n            for (var w = (u.length - 1); (w >= 0); w--) {\n                if ((u[w].inform(\"key\", event) === false)) {\n                    return false\n                };\n            }\n        };\n    }, Event.Priority.URGENT);\n    Event.listen(document.documentElement, \"click\", function(event) {\n        var w = event.getTarget(), x, y;\n        for (var z = (u.length - 1); (z >= 0); z--) {\n            x = u[z];\n            y = x._getContentRoot();\n            if (k.containsIncludingLayers(y, w)) {\n                return\n            };\n            if ((x.inform(\"blur\", event) === false)) {\n                return\n            };\n        };\n    });\n    e.exports = v;\n});\n__d(\"LayerAutoFocus\", [\"function-extensions\",\"copyProperties\",\"DOMQuery\",\"Input\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"copyProperties\"), h = b(\"DOMQuery\"), i = b(\"Input\");\n    function j(k) {\n        this._layer = k;\n    };\n    g(j.prototype, {\n        _subscription: null,\n        enable: function() {\n            this._subscription = this._layer.subscribe(\"aftershow\", this._focus.bind(this));\n        },\n        disable: function() {\n            this._subscription.unsubscribe();\n            this._subscription = null;\n        },\n        _focus: function() {\n            var k = h.scry(this._layer.getRoot(), \".autofocus\")[0];\n            (k && i.focus(k));\n        }\n    });\n    e.exports = j;\n});\n__d(\"LayerButtons\", [\"event-extensions\",\"Parent\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Parent\"), h = b(\"copyProperties\");\n    function i(j) {\n        this._layer = j;\n    };\n    h(i.prototype, {\n        _listener: null,\n        enable: function() {\n            this._listener = Event.listen(this._layer.getRoot(), \"click\", this._handle.bind(this));\n        },\n        disable: function() {\n            this._listener.remove();\n            this._listener = null;\n        },\n        _handle: function(j) {\n            var k = j.getTarget(), l = g.byClass(k, \"layerConfirm\");\n            if (l) {\n                if ((this._layer.inform(\"confirm\", l) === false)) {\n                    j.prevent();\n                };\n                return;\n            }\n        ;\n            var m = g.byClass(k, \"layerCancel\");\n            if (m) {\n                if ((this._layer.inform(\"cancel\", m) !== false)) {\n                    this._layer.hide();\n                };\n                j.prevent();\n                return;\n            }\n        ;\n            var n = g.byClass(k, \"layerButton\");\n            if (n) {\n                if ((this._layer.inform(\"button\", n) === false)) {\n                    j.prevent();\n                }\n            };\n        }\n    });\n    e.exports = i;\n});\n__d(\"LayerDestroyOnHide\", [\"function-extensions\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"copyProperties\");\n    function h(i) {\n        this._layer = i;\n    };\n    g(h.prototype, {\n        _subscription: null,\n        enable: function() {\n            this._subscription = this._layer.subscribe(\"hide\", Function.prototype.defer.shield(this._layer.destroy.bind(this._layer)));\n        },\n        disable: function() {\n            if (this._subscription) {\n                this._subscription.unsubscribe();\n                this._subscription = null;\n            }\n        ;\n        }\n    });\n    e.exports = h;\n});\n__d(\"LayerFadeOnHide\", [\"Animation\",\"Layer\",\"Style\",\"UserAgent\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Animation\"), h = b(\"Layer\"), i = b(\"Style\"), j = b(\"UserAgent\"), k = b(\"copyProperties\");\n    function l(m) {\n        this._layer = m;\n    };\n    k(l.prototype, {\n        _subscription: null,\n        enable: function() {\n            if ((j.ie() < 9)) {\n                return\n            };\n            this._subscription = this._layer.subscribe(\"starthide\", this._handleStartHide.bind(this));\n        },\n        disable: function() {\n            if (this._subscription) {\n                this._subscription.unsubscribe();\n                this._subscription = null;\n            }\n        ;\n        },\n        _handleStartHide: function() {\n            var m = true, n = h.subscribe(\"show\", function() {\n                n.unsubscribe();\n                m = false;\n            });\n            (function() {\n                n.unsubscribe();\n                n = null;\n                if (m) {\n                    this._animate();\n                }\n                 else this._layer.finishHide();\n            ;\n            }).bind(this).defer();\n            return false;\n        },\n        _animate: function() {\n            new g(this._layer.getRoot()).from(\"opacity\", 1).to(\"opacity\", 0).duration(150).ondone(this._finish.bind(this)).go();\n        },\n        _finish: function() {\n            i.set(this._layer.getRoot(), \"opacity\", \"\");\n            this._layer.finishHide();\n        }\n    });\n    e.exports = l;\n});\n__d(\"LayerFadeOnShow\", [\"Animation\",\"Style\",\"UserAgent\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Animation\"), h = b(\"Style\"), i = b(\"UserAgent\"), j = b(\"copyProperties\");\n    function k(l) {\n        this._layer = l;\n    };\n    j(k.prototype, {\n        _subscriptions: null,\n        enable: function() {\n            if ((i.ie() < 9)) {\n                return\n            };\n            this._subscriptions = [this._layer.subscribe(\"beforeshow\", function() {\n                h.set(this._layer.getRoot(), \"opacity\", 0);\n            }.bind(this)),this._layer.subscribe(\"show\", this._animate.bind(this)),];\n        },\n        disable: function() {\n            if (this._subscriptions) {\n                while (this._subscriptions.length) {\n                    this._subscriptions.pop().unsubscribe();;\n                };\n                this._subscriptions = null;\n            }\n        ;\n        },\n        _animate: function() {\n            var l = this._layer.getRoot();\n            new g(l).from(\"opacity\", 0).to(\"opacity\", 1).duration(100).ondone(h.set.curry(l, \"opacity\", \"\")).go();\n        }\n    });\n    e.exports = k;\n});\n__d(\"LayerFormHooks\", [\"event-extensions\",\"Form\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Form\"), h = b(\"copyProperties\");\n    function i(j) {\n        this._layer = j;\n    };\n    h(i.prototype, {\n        _subscriptions: null,\n        enable: function() {\n            var j = this._layer.getRoot();\n            this._subscriptions = [Event.listen(j, \"submit\", this._onSubmit.bind(this)),Event.listen(j, \"success\", this._onSuccess.bind(this)),Event.listen(j, \"error\", this._onError.bind(this)),];\n        },\n        disable: function() {\n            this._subscriptions.forEach(function(j) {\n                j.remove();\n            });\n            this._subscriptions = null;\n        },\n        _onSubmit: function(event) {\n            if ((this._layer.inform(\"submit\", event) === false)) {\n                event.kill();\n            };\n        },\n        _onSuccess: function(event) {\n            if ((this._layer.inform(\"success\", event) === false)) {\n                event.kill();\n            };\n        },\n        _onError: function(event) {\n            var j = event.getData();\n            if ((this._layer.inform(\"error\", {\n                response: j.response\n            }) === false)) {\n                event.kill();\n            };\n        }\n    });\n    e.exports = i;\n});\n__d(\"LayerHideOnBlur\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\");\n    function h(i) {\n        this._layer = i;\n    };\n    g(h.prototype, {\n        _subscriptions: null,\n        _onBlur: null,\n        enable: function() {\n            this._subscriptions = [this._layer.subscribe(\"show\", this._attach.bind(this)),this._layer.subscribe(\"hide\", this._detach.bind(this)),];\n            if (this._layer.isShown()) {\n                this._attach();\n            };\n        },\n        disable: function() {\n            this._detach();\n            while (this._subscriptions.length) {\n                this._subscriptions.pop().unsubscribe();;\n            };\n            this._subscriptions = null;\n        },\n        _detach: function() {\n            (this._onBlur && this._onBlur.unsubscribe());\n            this._onBlur = null;\n        },\n        _attach: function() {\n            (function() {\n                this._onBlur = this._layer.subscribe(\"blur\", this._layer.hide.shield(this._layer));\n            }).bind(this).defer();\n        }\n    });\n    e.exports = h;\n});\n__d(\"LayerHideOnEscape\", [\"event-extensions\",\"copyProperties\",\"Input\",\"Keys\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"copyProperties\"), h = b(\"Input\"), i = b(\"Keys\");\n    function j(k) {\n        this._layer = k;\n    };\n    g(j.prototype, {\n        _subscription: null,\n        enable: function() {\n            this._subscription = this._layer.subscribe(\"key\", this._handle.bind(this));\n        },\n        disable: function() {\n            this._subscription.unsubscribe();\n            this._subscription = null;\n        },\n        _handle: function(k, event) {\n            if ((Event.getKeyCode(event) === i.ESC)) {\n                var l = this._layer.getCausalElement();\n                if (l) {\n                    if ((l.tabIndex != -1)) {\n                        h.focus(l);\n                    }\n                };\n                this._layer.hide();\n                return false;\n            }\n        ;\n        }\n    });\n    e.exports = j;\n});\n__d(\"LayerHideOnSuccess\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\");\n    function h(i) {\n        this._layer = i;\n    };\n    g(h.prototype, {\n        _subscription: null,\n        enable: function() {\n            this._subscription = this._layer.subscribe(\"success\", this._layer.hide.bind(this._layer));\n        },\n        disable: function() {\n            if (this._subscription) {\n                this._subscription.unsubscribe();\n                this._subscription = null;\n            }\n        ;\n        }\n    });\n    e.exports = h;\n});\n__d(\"LayerHideOnTransition\", [\"Arbiter\",\"Class\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"Class\"), i = b(\"copyProperties\");\n    function j(k) {\n        this._layer = k;\n    };\n    i(j.prototype, {\n        _subscription: null,\n        enable: function() {\n            this._subscription = g.subscribe(\"page_transition\", this._layer.hide.shield(this._layer), g.SUBSCRIBE_NEW);\n        },\n        disable: function() {\n            if (this._subscription) {\n                this._subscription.unsubscribe();\n                this._subscription = null;\n            }\n        ;\n        }\n    });\n    e.exports = j;\n});\n__d(\"TabbableElements\", [\"Style\",\"createArrayFrom\",], function(a, b, c, d, e, f) {\n    var g = b(\"Style\"), h = b(\"createArrayFrom\"), i = {\n        find: function(j) {\n            function k(n) {\n                if ((n.tabIndex > 0)) {\n                    return true\n                };\n                switch (n.tagName) {\n                  case \"A\":\n                    return (n.href && (n.rel != \"ignore\"));\n                  case \"INPUT\":\n                    return (((n.type != \"hidden\") && (n.type != \"file\")) && !n.disabled);\n                  case \"SELECT\":\n                    return !n.disabled;\n                  case \"TEXTAREA\":\n                    return !n.disabled;\n                  default:\n                    return false;\n                };\n            };\n            function l(n) {\n                if (((n.offsetHeight === 0) && (n.offsetWidth === 0))) {\n                    return true\n                };\n                var o = n;\n                while (((o && (o != j)) && (g.get(o, \"visibility\") !== \"hidden\"))) {\n                    o = o.parentNode;;\n                };\n                return (o !== j);\n            };\n            var m = h(j.getElementsByTagName(\"*\"));\n            return m.filter(function(n) {\n                return (k(n) && !l(n));\n            });\n        }\n    };\n    e.exports = i;\n});\n__d(\"LayerTabIsolation\", [\"event-extensions\",\"copyProperties\",\"TabbableElements\",\"Keys\",\"Input\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"copyProperties\"), h = b(\"TabbableElements\"), i = b(\"Keys\"), j = b(\"Input\");\n    function k(l) {\n        this._layer = l;\n    };\n    g(k.prototype, {\n        _tabHandler: null,\n        _subscriptions: [],\n        enable: function() {\n            this._subscriptions = [this._layer.subscribe(\"show\", this._attachHandler.bind(this)),this._layer.subscribe(\"hide\", this._detachHandler.bind(this)),];\n        },\n        disable: function() {\n            while (this._subscriptions.length) {\n                this._subscriptions.pop().unsubscribe();;\n            };\n            this._detachHandler();\n        },\n        _attachHandler: function() {\n            var l = this._layer.getRoot();\n            this._tabHandler = Event.listen(l, \"keydown\", function(m) {\n                if ((Event.getKeyCode(m) == i.TAB)) {\n                    var n = m.getTarget();\n                    if (n) {\n                        var o = h.find(l), p = o[0], q = o[(o.length - 1)], r = m.getModifiers().shift;\n                        if ((r && (n == p))) {\n                            m.preventDefault();\n                            j.focus(q);\n                        }\n                         else if ((!r && (n == q))) {\n                            m.preventDefault();\n                            j.focus(p);\n                        }\n                        \n                    ;\n                    }\n                ;\n                }\n            ;\n            });\n        },\n        _detachHandler: function() {\n            if (this._tabHandler) {\n                this._tabHandler.remove();\n                this._tabHandler = null;\n            }\n        ;\n        }\n    });\n    e.exports = k;\n});\n__d(\"LayerMouseHooks\", [\"event-extensions\",\"function-extensions\",\"ContextualThing\",\"DOM\",\"Layer\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"ContextualThing\"), h = b(\"DOM\"), i = b(\"Layer\"), j = b(\"copyProperties\");\n    function k(l) {\n        this._layer = l;\n    };\n    j(k.prototype, {\n        _mouseSubscriptions: [],\n        _layerSubscriptions: [],\n        enable: function() {\n            var l = this._layer.getRoot();\n            this._mouseSubscriptions = [Event.listen(l, \"mouseenter\", this._onMouseEnter.bind(this)),Event.listen(l, \"mouseleave\", this._onMouseLeave.bind(this)),];\n            this._layerSubscriptions = [i.subscribe(\"show\", this._onLayerShow.bind(this)),i.subscribe(\"hide\", this._onLayerHide.bind(this)),];\n        },\n        disable: function() {\n            this._mouseSubscriptions.forEach(function(l) {\n                l.remove();\n            });\n            this._mouseSubscriptions = [];\n            this._layerSubscriptions.forEach(function(l) {\n                i.unsubscribe(l);\n            });\n            this._layerSubscriptions = [];\n        },\n        _onMouseEnter: function(l) {\n            this._fireMouseLeaveOnLayerHide = false;\n            if (!this._spawnedLayer) {\n                this._layer.inform(\"mouseenter\");\n            };\n        },\n        _onMouseLeave: function(l) {\n            if (!this._spawnedLayer) {\n                this._layer.inform(\"mouseleave\");\n            };\n            this._fireMouseLeaveOnLayerHide = !!this._spawnedLayer;\n        },\n        _onLayerShow: function(l, m) {\n            var n = (m.getContext && m.getContext());\n            if (n) {\n                if (h.contains(this._layer.getRoot(), n)) {\n                    this._spawnedLayer = m;\n                }\n            };\n        },\n        _onLayerHide: function(l, m) {\n            if ((m === this._spawnedLayer)) {\n                this._spawnedLayer = null;\n                if (this._fireMouseLeaveOnLayerHide) {\n                    this._onMouseLeave.bind(this).defer();\n                };\n            }\n        ;\n        }\n    });\n    e.exports = k;\n});\n__d(\"Overlay\", [\"Arbiter\",\"Class\",\"CSS\",\"DataStore\",\"DOM\",\"Layer\",\"LayerAutoFocus\",\"LayerButtons\",\"LayerDestroyOnHide\",\"LayerFadeOnHide\",\"LayerFadeOnShow\",\"LayerFormHooks\",\"LayerHideOnBlur\",\"LayerHideOnEscape\",\"LayerHideOnSuccess\",\"LayerHideOnTransition\",\"LayerTabIsolation\",\"LayerMouseHooks\",\"$\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"Class\"), i = b(\"CSS\"), j = b(\"DataStore\"), k = b(\"DOM\"), l = b(\"Layer\"), m = b(\"LayerAutoFocus\"), n = b(\"LayerButtons\"), o = b(\"LayerDestroyOnHide\"), p = b(\"LayerFadeOnHide\"), q = b(\"LayerFadeOnShow\"), r = b(\"LayerFormHooks\"), s = b(\"LayerHideOnBlur\"), t = b(\"LayerHideOnEscape\"), u = b(\"LayerHideOnSuccess\"), v = b(\"LayerHideOnTransition\"), w = b(\"LayerTabIsolation\"), x = b(\"LayerMouseHooks\"), y = b(\"$\"), z = b(\"copyProperties\");\n    function aa(ba, ca) {\n        ba = z({\n            buildWrapper: true\n        }, (ba || {\n        }));\n        this._shouldBuildWrapper = ba.buildWrapper;\n        this.parent.construct(this, ba, ca);\n    };\n    h.extend(aa, l);\n    z(aa.prototype, {\n        _configure: function(ba, ca) {\n            this.parent._configure(ba, ca);\n            var da = this.getRoot();\n            this._overlay = (k.scry(da, \"div.uiOverlay\")[0] || da);\n            i.hide(da);\n            k.appendContent(this.getInsertParent(), da);\n            j.set(this._overlay, \"overlay\", this);\n            var ea = j.get(this._overlay, \"width\");\n            (ea && this.setWidth(ea));\n            if (this.setFixed) {\n                this.setFixed((j.get(this._overlay, \"fixed\") == \"true\"));\n            };\n            if ((j.get(this._overlay, \"fadeonshow\") != \"false\")) {\n                this.enableBehavior(q);\n            };\n            if ((j.get(this._overlay, \"fadeonhide\") != \"false\")) {\n                this.enableBehavior(p);\n            };\n            if ((j.get(this._overlay, \"hideonsuccess\") != \"false\")) {\n                this.enableBehavior(u);\n            };\n            if ((j.get(this._overlay, \"hideonblur\") == \"true\")) {\n                this.enableBehavior(s);\n            };\n            if ((j.get(this._overlay, \"destroyonhide\") != \"false\")) {\n                this.enableBehavior(o);\n            };\n            return this;\n        },\n        _getDefaultBehaviors: function() {\n            return this.parent._getDefaultBehaviors().concat([m,n,r,x,t,v,w,]);\n        },\n        initWithoutBuildingWrapper: function() {\n            this._shouldBuildWrapper = false;\n            return this.init.apply(this, arguments);\n        },\n        _buildWrapper: function(ba, ca) {\n            ca = this.parent._buildWrapper(ba, ca);\n            if (!this._shouldBuildWrapper) {\n                this._contentRoot = ca;\n                return ca;\n            }\n        ;\n            this._contentRoot = k.create(\"div\", {\n                className: \"uiOverlayContent\"\n            }, ca);\n            return k.create(\"div\", {\n                className: \"uiOverlay\"\n            }, this._contentRoot);\n        },\n        _getContentRoot: function() {\n            return this._contentRoot;\n        },\n        destroy: function() {\n            j.remove(this.getRoot(), \"overlay\");\n            this.parent.destroy();\n        }\n    });\n    e.exports = aa;\n});\n__d(\"ContextualDialogX\", [\"event-extensions\",\"ARIA\",\"Arbiter\",\"ArbiterMixin\",\"Bootloader\",\"Class\",\"ContextualDialogFooterLink\",\"ContextualThing\",\"CSS\",\"DataStore\",\"DOM\",\"Locale\",\"Overlay\",\"Parent\",\"Style\",\"Vector\",\"$\",\"copyProperties\",\"getOverlayZIndex\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ARIA\"), h = b(\"Arbiter\"), i = b(\"ArbiterMixin\"), j = b(\"Bootloader\"), k = b(\"Class\"), l = b(\"ContextualDialogFooterLink\"), m = b(\"ContextualThing\"), n = b(\"CSS\"), o = b(\"DataStore\"), p = b(\"DOM\"), q = b(\"Locale\"), r = b(\"Overlay\"), s = b(\"Parent\"), t = b(\"Style\"), u = b(\"Vector\"), v = b(\"$\"), w = b(\"copyProperties\"), x = b(\"getOverlayZIndex\");\n    function y(z, aa) {\n        this.parent.construct(this, z, aa);\n    };\n    k.extend(y, r);\n    w(y, i, {\n        ARROW_OFFSET: 15,\n        ARROW_LENGTH: 16,\n        ARROW_INSET: 22,\n        TOP_MARGIN: 8,\n        BOTTOM_MARGIN: 30,\n        LEFT_MARGIN: 15,\n        RIGHT_MARGIN: 30,\n        POSITION_TO_CLASS: {\n            above: \"uiContextualDialogAbove\",\n            below: \"uiContextualDialogBelow\",\n            left: \"uiContextualDialogLeft\",\n            right: \"uiContextualDialogRight\"\n        },\n        RIGHT_ALIGNED_CLASS: \"uiContextualDialogRightAligned\",\n        ARROW_CLASS: {\n            bottom: \"uiContextualDialogArrowBottom\",\n            top: \"uiContextualDialogArrowTop\",\n            right: \"uiContextualDialogArrowRight\",\n            left: \"uiContextualDialogArrowLeft\"\n        },\n        POSITION_TO_ARROW: {\n            above: \"bottom\",\n            below: \"top\",\n            left: \"right\",\n            right: \"left\"\n        },\n        getInstance: function(z) {\n            var aa = o.get(z, \"ContextualDialogX\");\n            if (!aa) {\n                var ba = s.byClass(z, \"uiOverlay\");\n                if (ba) {\n                    aa = o.get(ba, \"overlay\");\n                };\n            }\n        ;\n            return aa;\n        }\n    });\n    w(y.prototype, {\n        _scrollListener: null,\n        _scrollParent: null,\n        _width: null,\n        _fixed: false,\n        _hasCustomArrow: false,\n        _hasFooter: false,\n        _showSubscription: null,\n        _hideSubscription: null,\n        _hovercardSubscription: null,\n        _setContextSubscription: null,\n        _resizeListener: null,\n        _reflowSubscription: null,\n        _configure: function(z, aa) {\n            this.parent._configure(z, aa);\n            var ba = this.getRoot(), ca = o.get.curry(ba);\n            this.setAlignH(ca(\"alignh\", \"left\"));\n            this.setOffsetX(ca(\"offsetx\", 0));\n            this.setOffsetY(ca(\"offsety\", 0));\n            this.setPosition(ca(\"position\", \"above\"));\n            this._hasCustomArrow = ca(\"hascustomarrow\", false);\n            this._hasFooter = ca(\"hasfooter\", false);\n            if (this._hasFooter) {\n                var da = p.scry(ba, \".uiContextualDialogFooterLink\")[0];\n                (da && this.enableBehavior(l));\n            }\n        ;\n            this._setContextSubscription = this.subscribe(\"beforeshow\", function() {\n                this.unsubscribe(this._setContextSubscription);\n                this._setContextSubscription = null;\n                var ea = ca(\"context\");\n                if (ea) {\n                    this.setContext(v(ea));\n                }\n                 else {\n                    ea = ca(\"contextselector\");\n                    if (ea) {\n                        this.setContext(p.find(document, ea));\n                    };\n                }\n            ;\n            }.bind(this));\n            this._content = p.scry(ba, \".uiContextualDialogContent\")[0];\n            this._showSubscription = this.subscribe(\"show\", function() {\n                var ea = this.updatePosition.shield(this);\n                this._resizeListener = Event.listen(window, \"resize\", ea);\n                this._reflowSubscription = h.subscribe(\"reflow\", ea);\n                this._setupScrollListener(this._scrollParent);\n                m.register(ba, this.context);\n                h.inform(\"layer_shown\", {\n                    type: \"ContextualDialog\"\n                });\n            }.bind(this));\n            this._hideSubscription = this.subscribe(\"hide\", function() {\n                this._teardownResizeAndReflowListeners();\n                this._teardownScrollListener();\n                m.remove(ba);\n                h.inform(\"layer_hidden\", {\n                    type: \"ContextualDialog\"\n                });\n            }.bind(this));\n            this._hovercardSubscription = h.subscribe(\"Hovercard/hide\", function(ea, fa) {\n                if (a.Hovercard.contains(this.getContext())) {\n                    this.hide();\n                };\n            }.bind(this));\n            return this;\n        },\n        _buildWrapper: function(z, aa) {\n            var ba = this.parent._buildWrapper(z, aa);\n            if (!this._shouldBuildWrapper) {\n                return ba\n            };\n            n.addClass(ba, \"uiContextualDialog\");\n            return p.create(\"div\", {\n                className: \"uiContextualDialogPositioner\"\n            }, ba);\n        },\n        setWidth: function(z) {\n            this._width = Math.floor(z);\n            return this;\n        },\n        setFixed: function(z) {\n            z = !!z;\n            n.conditionClass(this.getRoot(), \"uiContextualDialogFixed\", z);\n            this._fixed = z;\n            return this;\n        },\n        setAlignH: function(z) {\n            this.alignH = z;\n            this._updateAlignmentClass();\n            (this._shown && this.updatePosition());\n            (this.position && this._updateArrow());\n            return this;\n        },\n        getContent: function() {\n            return this._content;\n        },\n        getContext: function() {\n            return this.context;\n        },\n        setContext: function(z) {\n            if (this._setContextSubscription) {\n                this.unsubscribe(this._setContextSubscription);\n                this._setContextSubscription = null;\n            }\n        ;\n            z = v(z);\n            if ((this.context && (this.context != z))) {\n                o.remove(this.context, \"ContextualDialogX\");\n            };\n            this.context = z;\n            g.setPopup(this.getCausalElement(), this.getRoot());\n            var aa = s.byClass(z, \"fbPhotoSnowlift\");\n            this.setInsertParent((aa || document.body));\n            if ((this._scrollListener && (this._scrollParent !== aa))) {\n                this._teardownScrollListener();\n                this._setupScrollListener(aa);\n            }\n        ;\n            this._scrollParent = aa;\n            var ba = x(z, this._insertParent);\n            t.set(this.getRoot(), \"z-index\", ((ba > 200) ? ba : \"\"));\n            o.set(this.context, \"ContextualDialogX\", this);\n            return this;\n        },\n        getCausalElement: function() {\n            return (this.parent.getCausalElement() || this.context);\n        },\n        listen: function(z, aa) {\n            return Event.listen(this.getRoot(), z, aa);\n        },\n        setOffsetX: function(z) {\n            this.offsetX = (parseInt(z, 10) || 0);\n            (this._shown && this.updatePosition());\n            return this;\n        },\n        setOffsetY: function(z) {\n            this.offsetY = (parseInt(z, 10) || 0);\n            (this._shown && this.updatePosition());\n            return this;\n        },\n        setPosition: function(z) {\n            this.position = z;\n            for (var aa in y.POSITION_TO_CLASS) {\n                n.conditionClass(this.getRoot(), y.POSITION_TO_CLASS[aa], (z == aa));;\n            };\n            this._updateAlignmentClass();\n            (this._shown && this.updatePosition());\n            this._updateArrow();\n            return this;\n        },\n        updatePosition: function() {\n            if (!this.context) {\n                return false\n            };\n            if (this._width) {\n                t.set(this._overlay, \"width\", (this._width + \"px\"));\n            };\n            var z = (this._fixed ? \"viewport\" : \"document\"), aa = u.getElementPosition(this.context, z), ba = this._scrollParent;\n            if (ba) {\n                aa = aa.sub(u.getElementPosition(ba, \"document\")).add(ba.scrollLeft, ba.scrollTop);\n            };\n            var ca = u.getElementDimensions(this.context), da = ((this.position == \"above\") || (this.position == \"below\")), ea = q.isRTL();\n            if (((((this.position == \"right\") || ((da && (this.alignH == \"right\"))))) != ea)) {\n                aa = aa.add(ca.x, 0);\n            };\n            if ((this.position == \"below\")) {\n                aa = aa.add(0, ca.y);\n            };\n            var fa = new u(0, 0);\n            if ((da && (this.alignH == \"center\"))) {\n                fa = fa.add((((ca.x - this._width)) / 2), 0);\n            }\n             else {\n                var ga = (da ? ca.x : ca.y), ha = (2 * y.ARROW_INSET);\n                if ((ga < ha)) {\n                    var ia = ((ga / 2) - y.ARROW_INSET);\n                    if ((da && (((this.alignH == \"right\") != ea)))) {\n                        ia = -ia;\n                    };\n                    fa = fa.add((da ? ia : 0), (da ? 0 : ia));\n                }\n            ;\n            }\n        ;\n            fa = fa.add(this.offsetX, this.offsetY);\n            if (ea) {\n                fa = fa.mul(-1, 1);\n            };\n            aa = aa.add(fa);\n            if (this._fixed) {\n                aa = new u(aa.x, aa.y, \"document\");\n            };\n            aa.setElementPosition(this.getRoot());\n            this._adjustVerticalPosition();\n            this._adjustHorizontalPosition();\n            return true;\n        },\n        scrollTo: function() {\n            if (this.context) {\n                j.loadModules([\"DOMScroll\",], function(z) {\n                    z.scrollTo(this.context, true, true);\n                }.bind(this));\n            };\n        },\n        destroy: function() {\n            this.unsubscribe(this._showSubscription);\n            this.unsubscribe(this._hideSubscription);\n            this._hovercardSubscription.unsubscribe();\n            if (this._setContextSubscription) {\n                this.unsubscribe(this._setContextSubscription);\n                this._setContextSubscription = null;\n            }\n        ;\n            this._teardownScrollListener();\n            this._teardownResizeAndReflowListeners();\n            (this.context && o.remove(this.context, \"ContextualDialogX\"));\n            this.parent.destroy();\n        },\n        _adjustVerticalPosition: function() {\n            if (((this.position != \"left\") && (this.position != \"right\"))) {\n                t.set(this._overlay, \"top\", \"\");\n                return;\n            }\n        ;\n            var z = this.getRoot(), aa = u.getElementPosition(z, \"viewport\").y, ba = u.getElementDimensions(this._overlay).y, ca = u.getViewportDimensions().y, da = y.TOP_MARGIN, ea = Math.min(Math.max(0, (((aa + ba) + y.BOTTOM_MARGIN) - ca)), Math.max(-da, (aa - da)), (ba - (2 * y.ARROW_INSET)));\n            t.set(this._overlay, \"top\", (((-1 * ea)) + \"px\"));\n            t.set(this._arrow, \"top\", (y.ARROW_OFFSET + \"px\"));\n            t.set(this._arrow, \"marginTop\", (ea + \"px\"));\n        },\n        _adjustHorizontalPosition: function() {\n            if (((((this.position != \"above\") && (this.position != \"below\"))) || (this.alignH != \"left\"))) {\n                t.set(this._overlay, \"left\", \"\");\n                t.set(this._overlay, \"right\", \"\");\n                return;\n            }\n        ;\n            var z = this.getRoot(), aa = u.getElementPosition(z, \"viewport\").x, ba = u.getElementDimensions(this._overlay).x, ca = u.getViewportDimensions().x, da = q.isRTL(), ea;\n            if (!da) {\n                ea = (((aa + ba) + y.RIGHT_MARGIN) - ca);\n            }\n             else ea = ((y.LEFT_MARGIN + ba) - aa);\n        ;\n            ea = Math.min(Math.max(0, ea), (ba - (2 * y.ARROW_INSET)));\n            t.set(this._overlay, (da ? \"right\" : \"left\"), ((-1 * ea) + \"px\"));\n            t.set(this._arrow, (da ? \"right\" : \"left\"), (y.ARROW_OFFSET + \"px\"));\n            t.set(this._arrow, (da ? \"marginRight\" : \"marginLeft\"), (ea + \"px\"));\n        },\n        _updateArrow: function() {\n            var z = 0;\n            if (((this.position == \"above\") || (this.position == \"below\"))) {\n                switch (this.alignH) {\n                  case \"center\":\n                    z = 50;\n                    break;\n                  case \"right\":\n                    z = 100;\n                    break;\n                }\n            };\n            this._renderArrow(y.POSITION_TO_ARROW[this.position], z);\n        },\n        _renderArrow: function(z, aa) {\n            for (var ba in y.ARROW_CLASS) {\n                n.conditionClass(this._overlay, y.ARROW_CLASS[ba], (z == ba));;\n            };\n            n.conditionClass(this._overlay, \"uiContextualDialogWithFooterArrowBottom\", ((z == \"bottom\") && this._hasFooter));\n            if ((z == \"none\")) {\n                return\n            };\n            if (!this._arrow) {\n                this._arrow = p.create(\"i\", {\n                    className: \"uiContextualDialogArrow\"\n                });\n                p.appendContent(this._overlay, this._arrow);\n            }\n        ;\n            t.set(this._arrow, \"top\", \"\");\n            t.set(this._arrow, \"left\", \"\");\n            t.set(this._arrow, \"right\", \"\");\n            t.set(this._arrow, \"margin\", \"\");\n            var ca = ((z == \"top\") || (z == \"bottom\")), da = (ca ? ((q.isRTL() ? \"right\" : \"left\")) : \"top\");\n            aa = (aa || 0);\n            t.set(this._arrow, da, (aa + \"\u0025\"));\n            var ea = (y.ARROW_LENGTH + (y.ARROW_OFFSET * 2)), fa = -((((ea * aa) / 100) - y.ARROW_OFFSET));\n            t.set(this._arrow, (\"margin-\" + da), (fa + \"px\"));\n            if (this._hasCustomArrow) {\n                y.inform(\"arrow_rendered\", {\n                    type: \"ContextualDialog\",\n                    root: this._root,\n                    position: z,\n                    side: da,\n                    offset_percent: aa,\n                    side_margin: fa\n                });\n            };\n        },\n        _updateAlignmentClass: function() {\n            n.conditionClass(this.getRoot(), y.RIGHT_ALIGNED_CLASS, ((((this.position == \"above\") || (this.position == \"below\"))) && (this.alignH == \"right\")));\n        },\n        _setupScrollListener: function(z) {\n            this._scrollListener = Event.listen((z || window), \"scroll\", this._adjustVerticalPosition.shield(this));\n        },\n        _teardownScrollListener: function() {\n            if (this._scrollListener) {\n                this._scrollListener.remove();\n                this._scrollListener = null;\n            }\n        ;\n        },\n        _teardownResizeAndReflowListeners: function() {\n            if (this._resizeListener) {\n                this._resizeListener.remove();\n                this._resizeListener = null;\n            }\n        ;\n            if (this._reflowSubscription) {\n                this._reflowSubscription.unsubscribe();\n                this._reflowSubscription = null;\n            }\n        ;\n        }\n    });\n    e.exports = y;\n});\n__d(\"Toggler\", [\"array-extensions\",\"event-extensions\",\"Arbiter\",\"ArbiterMixin\",\"Class\",\"ContextualDialogX\",\"ContextualThing\",\"CSS\",\"DataStore\",\"Dialog\",\"DOM\",\"copyProperties\",\"createArrayFrom\",\"ge\",\"getObjectValues\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"Class\"), j = b(\"ContextualDialogX\"), k = b(\"ContextualThing\"), l = b(\"CSS\"), m = b(\"DataStore\"), n = b(\"Dialog\"), o = b(\"DOM\"), p = b(\"copyProperties\"), q = b(\"createArrayFrom\"), r = b(\"ge\"), s = b(\"getObjectValues\"), t = [], u;\n    function v() {\n        v = bagofholding;\n        Event.listen(document.documentElement, \"click\", function(event) {\n            var z = event.getTarget();\n            t.forEach(function(aa) {\n                aa.clickedTarget = z;\n                (((((aa.active && !aa.sticky) && !k.containsIncludingLayers(aa.getActive(), z)) && !aa.inTargetFlyout(z)) && aa.inActiveDialog()) && aa.hide());\n            });\n        }, Event.Priority.URGENT);\n    };\n    var w = function() {\n        this.active = null;\n        this.togglers = {\n        };\n        this.setSticky(false);\n        t.push(this);\n        this.subscribe([\"show\",\"hide\",], w.inform.bind(w));\n        return v();\n    };\n    p(w.prototype, h, {\n        show: function(z) {\n            var aa = x(this, z), ba = aa.active;\n            if ((z !== ba)) {\n                (ba && aa.hide());\n                aa.active = z;\n                l.addClass(z, \"openToggler\");\n                var ca = o.scry(z, \"a[rel=\\\"toggle\\\"]\");\n                if (((ca.length > 0) && ca[0].getAttribute(\"data-target\"))) {\n                    l.removeClass(r(ca[0].getAttribute(\"data-target\")), \"toggleTargetClosed\");\n                };\n                o.appendContent(z, aa.getToggler(\"next\"));\n                o.prependContent(z, aa.getToggler(\"prev\"));\n                aa.inform(\"show\", aa);\n            }\n        ;\n        },\n        hide: function(z) {\n            var aa = x(this, z), ba = aa.active;\n            if ((ba && ((!z || (z === ba))))) {\n                l.removeClass(ba, \"openToggler\");\n                var ca = o.scry(ba, \"a[rel=\\\"toggle\\\"]\");\n                if (((ca.length > 0) && ca[0].getAttribute(\"data-target\"))) {\n                    l.addClass(r(ca[0].getAttribute(\"data-target\")), \"toggleTargetClosed\");\n                };\n                s(aa.togglers).forEach(o.remove);\n                aa.inform(\"hide\", aa);\n                aa.active = null;\n            }\n        ;\n        },\n        toggle: function(z) {\n            var aa = x(this, z);\n            if ((aa.active === z)) {\n                aa.hide();\n            }\n             else aa.show(z);\n        ;\n        },\n        getActive: function() {\n            return x(this).active;\n        },\n        isShown: function() {\n            return (x(this).active && l.hasClass(x(this).active, \"openToggler\"));\n        },\n        inTargetFlyout: function(z) {\n            var aa = y(this.getActive());\n            return (aa && k.containsIncludingLayers(aa, z));\n        },\n        inActiveDialog: function() {\n            var z = n.getCurrent();\n            return (!z || o.contains(z.getRoot(), this.getActive()));\n        },\n        getToggler: function(z) {\n            var aa = x(this);\n            if (!aa.togglers[z]) {\n                aa.togglers[z] = o.create(\"button\", {\n                    className: \"hideToggler\",\n                    onfocus: function() {\n                        var ba = o.scry(aa.active, \"a[rel=\\\"toggle\\\"]\")[0];\n                        (ba && ba.focus());\n                        aa.hide();\n                    }\n                });\n                aa.togglers[z].setAttribute(\"type\", \"button\");\n            }\n        ;\n            return this.togglers[z];\n        },\n        setSticky: function(z) {\n            var aa = x(this);\n            z = (z !== false);\n            if ((z !== aa.sticky)) {\n                aa.sticky = z;\n                if (z) {\n                    (aa._pt && aa._pt.unsubscribe());\n                }\n                 else aa._pt = g.subscribe(\"page_transition\", aa.hide.bind(aa, null));\n            ;\n            }\n        ;\n            return aa;\n        }\n    });\n    p(w, w.prototype);\n    p(w, {\n        bootstrap: function(z) {\n            var aa = z.parentNode;\n            w.getInstance(aa).toggle(aa);\n        },\n        createInstance: function(z) {\n            var aa = new w().setSticky(true);\n            m.set(z, \"toggler\", aa);\n            return aa;\n        },\n        getInstance: function(z) {\n            while (z) {\n                var aa = m.get(z, \"toggler\");\n                if (aa) {\n                    return aa\n                };\n                if (l.hasClass(z, \"uiToggleContext\")) {\n                    return w.createInstance(z)\n                };\n                z = z.parentNode;\n            };\n            return (u = (u || new w()));\n        },\n        listen: function(z, aa, ba) {\n            return w.subscribe(q(z), function(ca, da) {\n                if ((da.getActive() === aa)) {\n                    return ba(ca, da)\n                };\n            });\n        },\n        subscribe: (function(z) {\n            return function(aa, ba) {\n                aa = q(aa);\n                if (aa.contains(\"show\")) {\n                    t.forEach(function(ca) {\n                        if (ca.getActive()) {\n                            ba.curry(\"show\", ca).defer();\n                        };\n                    });\n                };\n                return z(aa, ba);\n            };\n        })(w.subscribe.bind(w))\n    });\n    function x(z, aa) {\n        if ((z instanceof w)) {\n            return z\n        };\n        return w.getInstance(aa);\n    };\n    function y(z) {\n        var aa = o.scry(z, \"a[rel=\\\"toggle\\\"]\");\n        if (((aa.length > 0) && aa[0].getAttribute(\"data-target\"))) {\n            return r(aa[0].getAttribute(\"data-target\"))\n        };\n    };\n    e.exports = w;\n});\n__d(\"Dock\", [\"event-extensions\",\"function-extensions\",\"Arbiter\",\"ArbiterMixin\",\"ChatQuietLinks\",\"CSS\",\"DataStore\",\"DOM\",\"Parent\",\"Style\",\"Toggler\",\"Vector\",\"copyProperties\",\"ge\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"ChatQuietLinks\"), j = b(\"CSS\"), k = b(\"DataStore\"), l = b(\"DOM\"), m = b(\"Parent\"), n = b(\"Style\"), o = b(\"Toggler\"), p = b(\"Vector\"), q = b(\"copyProperties\"), r = b(\"ge\");\n    function s() {\n    \n    };\n    q(s, h, {\n        MIN_HEIGHT: 140,\n        INITIAL_FLYOUT_HEIGHT_OFFSET: 10,\n        init: function(t) {\n            this.init = bagofholding;\n            this.rootEl = t;\n            this.calculateViewportDimensions();\n            this.calculateFlyoutHeightOffset();\n            i.removeEmptyHrefs(this.rootEl);\n            Event.listen(t, \"click\", this._onClick.bind(this));\n            Event.listen(window, \"resize\", this._onWindowResize.bind(this));\n            o.subscribe([\"show\",\"hide\",], function(u, v) {\n                var w = v.getActive();\n                if (!l.contains(t, w)) {\n                    return\n                };\n                if (j.hasClass(w, \"fbNub\")) {\n                    this.notifyNub(w, u);\n                    if ((u === \"show\")) {\n                        this._resizeNubFlyout(w);\n                    };\n                }\n                 else {\n                    var x = m.byClass(w, \"fbNubFlyout\");\n                    if (x) {\n                        j.conditionClass(x, \"menuOpened\", (u === \"show\"));\n                    };\n                }\n            ;\n            }.bind(this));\n            this.inform(\"init\", {\n            }, g.BEHAVIOR_PERSISTENT);\n        },\n        calculateViewportDimensions: function() {\n            return (this.viewportDimensions = p.getViewportDimensions());\n        },\n        calculateFlyoutHeightOffset: function() {\n            this.flyoutHeightOffset = (this.INITIAL_FLYOUT_HEIGHT_OFFSET + p.getElementDimensions(this.rootEl).y);\n            var t = r(\"blueBar\");\n            if (t) {\n                var u = (n.isFixed(t) ? \"viewport\" : \"document\");\n                this.flyoutHeightOffset += (p.getElementPosition(t, u).y + p.getElementDimensions(t).y);\n            }\n        ;\n        },\n        toggle: function(t) {\n            var u = this._findFlyout(t);\n            if (!u) {\n                return\n            };\n            this.subscribe(\"init\", function() {\n                o.toggle(t);\n            });\n        },\n        show: function(t) {\n            this.subscribe(\"init\", function() {\n                o.show(t);\n            });\n        },\n        showNub: function(t) {\n            j.show(t);\n        },\n        hide: function(t) {\n            this.subscribe(\"init\", function() {\n                var u = o.getInstance(t);\n                (l.contains(t, u.getActive()) && u.hide());\n            });\n        },\n        hideNub: function(t) {\n            j.hide(t);\n            this.hide(t);\n        },\n        setUseMaxHeight: function(t, u) {\n            j.conditionClass(t, \"maxHeight\", (u !== false));\n            this._resizeNubFlyout(t);\n        },\n        _resizeNubFlyout: function(t) {\n            var u = this._findFlyout(t);\n            if ((!u || !((j.hasClass(t, \"openToggler\") || j.hasClass(t, \"opened\"))))) {\n                return\n            };\n            var v = l.find(u, \"div.fbNubFlyoutOuter\"), w = l.find(v, \"div.fbNubFlyoutInner\"), x = l.find(w, \"div.fbNubFlyoutBody\"), y = x.scrollTop, z = x.offsetHeight;\n            n.set(x, \"height\", \"auto\");\n            var aa = p.getElementPosition(u, \"viewport\"), ba = p.getElementDimensions(u), ca = p.getElementDimensions(x), da = (Math.max(this.MIN_HEIGHT, (this.viewportDimensions.y - this.flyoutHeightOffset)) - (((this.viewportDimensions.y - aa.y) - ba.y)));\n            da = Math.max(da, 0);\n            n.set(u, \"max-height\", (da + \"px\"));\n            n.set(v, \"max-height\", (da + \"px\"));\n            ba = p.getElementDimensions(u);\n            var ea = p.getElementDimensions(w), fa = (ea.y - ca.y);\n            if ((ba.y > fa)) {\n                n.set(x, \"height\", (((ba.y - fa)) + \"px\"));\n            };\n            j.removeClass(u, \"swapDirection\");\n            var ga = p.getElementPosition(u).x;\n            j.conditionClass(u, \"swapDirection\", function() {\n                if ((ga < 0)) {\n                    return true\n                };\n                return (((ga + ba.x) > this.viewportDimensions.x));\n            }.bind(this)());\n            if (((y + z) >= ca.y)) {\n                x.scrollTop = ca.y;\n            }\n             else x.scrollTop = y;\n        ;\n            this.notifyNub(t, \"resize\");\n        },\n        resizeAllFlyouts: function() {\n            var t = l.scry(this.rootEl, \"div.fbNub.openToggler\");\n            t = t.concat(l.scry(this.rootEl, \"div.fbNub.opened\"));\n            var u = t.length;\n            while (u--) {\n                this._resizeNubFlyout(t[u]);;\n            };\n        },\n        _onClick: function(event) {\n            var t = event.getTarget(), u = m.byClass(t, \"fbNub\");\n            if (u) {\n                if (m.byClass(t, \"fbNubFlyoutTitlebar\")) {\n                    var v = m.byTag(t, \"a\");\n                    if (!v) {\n                        this.hide(u);\n                        return false;\n                    }\n                ;\n                }\n            ;\n                this.notifyNub(u, \"click\");\n            }\n        ;\n        },\n        _onWindowResize: function(event) {\n            this.calculateViewportDimensions();\n            this.resizeAllFlyouts();\n        },\n        _findFlyout: function(t) {\n            return (j.hasClass(t, \"fbNubFlyout\") ? t : (l.scry(t, \"div.fbNubFlyout\")[0] || null));\n        },\n        registerNubController: function(t, u) {\n            k.set(t, \"dock:nub:controller\", u);\n            u.subscribe(\"nub/button/content-changed\", this.inform.shield(this, \"resize\", t));\n            u.subscribe(\"nub/flyout/content-changed\", this._resizeNubFlyout.shield(this, t));\n        },\n        unregisterNubController: function(t) {\n            k.remove(t, \"dock:nub:controller\");\n        },\n        notifyNub: function(t, u, v) {\n            var w = k.get(t, \"dock:nub:controller\");\n            (w && w.inform(u, v));\n        }\n    });\n    e.exports = (a.Dock || s);\n});\n__d(\"NubController\", [\"ArbiterMixin\",\"Class\",\"Dock\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"ArbiterMixin\"), h = b(\"Class\"), i = b(\"Dock\"), j = b(\"copyProperties\");\n    function k() {\n    \n    };\n    j(k.prototype, g, {\n        init: function(l) {\n            this.el = l;\n            i.registerNubController(l, this);\n            return this;\n        },\n        buttonContentChanged: function() {\n            this.inform(\"nub/button/content-changed\");\n        },\n        flyoutContentChanged: function() {\n            this.inform(\"nub/flyout/content-changed\");\n        },\n        hide: function() {\n            i.hide(this.el);\n        },\n        show: function() {\n            i.show(this.el);\n        }\n    });\n    e.exports = k;\n});\n__d(\"NavigationMessage\", [], function(a, b, c, d, e, f) {\n    var g = {\n        NAVIGATION_BEGIN: \"NavigationMessage/navigationBegin\",\n        NAVIGATION_SELECT: \"NavigationMessage/navigationSelect\",\n        NAVIGATION_FIRST_RESPONSE: \"NavigationMessage/navigationFirstResponse\",\n        NAVIGATION_COMPLETED: \"NavigationMessage/navigationCompleted\",\n        NAVIGATION_FAILED: \"NavigationMessage/navigationFailed\",\n        NAVIGATION_COUNT_UPDATE: \"NavigationMessage/navigationCount\",\n        NAVIGATION_FAVORITE_UPDATE: \"NavigationMessage/navigationFavoriteUpdate\",\n        NAVIGATION_ITEM_REMOVED: \"NavigationMessage/navigationItemRemoved\",\n        NAVIGATION_ITEM_HIDDEN: \"NavigationMessage/navigationItemHidden\",\n        INTERNAL_LOADING_BEGIN: \"NavigationMessage/internalLoadingBegin\",\n        INTERNAL_LOADING_COMPLETED: \"NavigationMessage/internalLoadingCompleted\"\n    };\n    e.exports = g;\n});\n__d(\"legacy:ui-side-nav-message\", [\"NavigationMessage\",], function(a, b, c, d) {\n    a.NavigationMessage = b(\"NavigationMessage\");\n}, 3);\n__d(\"DropdownContextualHelpLink\", [\"copyProperties\",\"DOM\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\"), h = b(\"DOM\"), i = b(\"ge\"), j = {\n        set: function(k) {\n            var l = i(\"navHelpCenter\");\n            if ((l !== null)) {\n                h.replace(l, k);\n            };\n        }\n    };\n    e.exports = j;\n});\n__d(\"SimpleDrag\", [\"event-extensions\",\"ArbiterMixin\",\"Class\",\"UserAgent\",\"Vector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"Class\"), i = b(\"UserAgent\"), j = b(\"Vector\"), k = b(\"copyProperties\");\n    function l(m) {\n        this.minDragDistance = 0;\n        Event.listen(m, \"mousedown\", this._start.bind(this));\n    };\n    k(l.prototype, g, {\n        setMinDragDistance: function(m) {\n            this.minDragDistance = m;\n        },\n        _start: function(event) {\n            var m = false, n = true, o = null;\n            if (this.inform(\"mousedown\", event)) {\n                n = false;\n            };\n            if (this.minDragDistance) {\n                o = j.getEventPosition(event);\n            }\n             else {\n                m = true;\n                if (this.inform(\"start\", event)) {\n                    n = false;\n                };\n            }\n        ;\n            var p = ((i.ie() < 9) ? document.documentElement : window), q = Event.listen(p, {\n                selectstart: (n ? Event.prevent : bagofholding),\n                mousemove: function(event) {\n                    if (!m) {\n                        var r = j.getEventPosition(event);\n                        if ((o.distanceTo(r) < this.minDragDistance)) {\n                            return\n                        };\n                        m = true;\n                        this.inform(\"start\", event);\n                    }\n                ;\n                    this.inform(\"update\", event);\n                }.bind(this),\n                mouseup: function(event) {\n                    for (var r in q) {\n                        q[r].remove();;\n                    };\n                    if (m) {\n                        this.inform(\"end\", event);\n                    }\n                     else this.inform(\"click\", event);\n                ;\n                }.bind(this)\n            });\n            return !n;\n        }\n    });\n    e.exports = l;\n});\n__d(\"isRTL\", [], function(a, b, c, d, e, f) {\n    function g(i) {\n        for (var j = 0, k = i.length; (j < k); j++) {\n            var l = i.charCodeAt(j);\n            if (((l >= 1470) && (l <= 1920))) {\n                return true\n            };\n        };\n        return false;\n    };\n    function h(i) {\n        var j = 0, k = 0;\n        i.split(/\\s/, 10).forEach(function(l) {\n            j++;\n            (g(l) && k++);\n        });\n        return (j && (((k / j) >= 162025)));\n    };\n    e.exports = h;\n});\n__d(\"legacy:bind\", [\"bind\",], function(a, b, c, d) {\n    a.bind = b(\"bind\");\n}, 3);\n__d(\"ScrollAwareDOM\", [\"ArbiterMixin\",\"CSS\",\"DOM\",\"DOMDimensions\",\"DOMPosition\",\"DOMQuery\",\"HTML\",\"Vector\",\"ViewportBounds\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"ArbiterMixin\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"DOMDimensions\"), k = b(\"DOMPosition\"), l = b(\"DOMQuery\"), m = b(\"HTML\"), n = b(\"Vector\"), o = b(\"ViewportBounds\"), p = b(\"copyProperties\");\n    function q(v, w) {\n        return function() {\n            u.monitor(arguments[v], w.curry.apply(w, arguments));\n        };\n    };\n    function r(v) {\n        if (!((v instanceof Array))) {\n            v = [v,];\n        };\n        for (var w = 0; (w < v.length); w++) {\n            var x = m.replaceJSONWrapper(v[w]);\n            if ((x instanceof m)) {\n                return x.getRootNode();\n            }\n             else if (i.isNode(x)) {\n                return x\n            }\n        ;\n        };\n        return null;\n    };\n    function s(v) {\n        return (k.getElementPosition(v).y >= o.getTop());\n    };\n    function t(v) {\n        var w = (k.getElementPosition(v).y + j.getElementDimensions(v).height), x = (j.getViewportDimensions().height - o.getBottom());\n        return (w >= x);\n    };\n    var u = p({\n        monitor: function(v, w) {\n            var x = r(v);\n            if (x) {\n                var y = !!x.offsetParent;\n                if ((y && ((s(x) || t(x))))) {\n                    return w()\n                };\n                var z = n.getDocumentDimensions(), aa = w();\n                if ((y || ((x.offsetParent && !s(x))))) {\n                    var ba = n.getDocumentDimensions().sub(z), ca = {\n                        delta: ba,\n                        target: x\n                    };\n                    if ((u.inform(\"scroll\", ca) !== false)) {\n                        ba.scrollElementBy(l.getDocumentScrollElement());\n                    };\n                }\n            ;\n                return aa;\n            }\n             else return w()\n        ;\n        },\n        replace: function(v, w) {\n            var x = r(w);\n            if ((!x || h.hasClass(x, \"hidden_elem\"))) {\n                x = v;\n            };\n            return u.monitor(x, function() {\n                i.replace(v, w);\n            });\n        },\n        prependContent: q(1, i.prependContent),\n        insertAfter: q(1, i.insertAfter),\n        insertBefore: q(1, i.insertBefore),\n        setContent: q(0, i.setContent),\n        appendContent: q(1, i.appendContent),\n        remove: q(0, i.remove),\n        empty: q(0, i.empty)\n    }, g);\n    e.exports = u;\n});\n__d(\"legacy:ScrollAwareDOM\", [\"ScrollAwareDOM\",], function(a, b, c, d) {\n    a.ScrollAwareDOM = b(\"ScrollAwareDOM\");\n}, 3);\n__d(\"legacy:Style\", [\"Style\",], function(a, b, c, d) {\n    a.Style = b(\"Style\");\n}, 3);\n__d(\"legacy:dom-form\", [\"Form\",], function(a, b, c, d) {\n    a.Form = b(\"Form\");\n}, 3);\n__d(\"legacy:dom-html\", [\"HTML\",], function(a, b, c, d) {\n    a.HTML = b(\"HTML\");\n}, 3);\nfunction show() {\n    for (var a = 0; (a < arguments.length); a++) {\n        var b = ge(arguments[a]);\n        if ((b && b.style)) {\n            b.style.display = \"\";\n        };\n    };\n    return false;\n};\nfunction hide() {\n    for (var a = 0; (a < arguments.length); a++) {\n        var b = ge(arguments[a]);\n        if ((b && b.style)) {\n            b.style.display = \"none\";\n        };\n    };\n    return false;\n};\nfunction shown(a) {\n    a = ge(a);\n    return (((a.style.display != \"none\") && !(((a.style.display == \"\") && (a.offsetWidth == 0)))));\n};\nfunction toggle() {\n    for (var a = 0; (a < arguments.length); a++) {\n        var b = $(arguments[a]);\n        b.style.display = ((Style.get(b, \"display\") == \"block\") ? \"none\" : \"block\");\n    };\n    return false;\n};\nfunction toggleDisplayNone() {\n    for (var a = 0; (a < arguments.length); a++) {\n        var b = $(arguments[a]);\n        if (shown(b)) {\n            hide(b);\n        }\n         else show(b);\n    ;\n    };\n    return false;\n};\n__d(\"legacy:dom-scroll\", [\"DOMScroll\",], function(a, b, c, d) {\n    a.DOMScroll = b(\"DOMScroll\");\n}, 3);\n__d(\"SystemEvents\", [\"Arbiter\",\"Env\",\"ErrorUtils\",\"UserAgent\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"Env\"), i = b(\"ErrorUtils\"), j = b(\"UserAgent\"), k = b(\"copyProperties\"), l = new g(), m = [], n = 1000;\n    setInterval(function() {\n        for (var w = 0; (w < m.length); w++) {\n            m[w]();;\n        };\n    }, n, false);\n    function o() {\n        return (((/c_user=(\\d+)/.test(document.cookie) && RegExp.$1)) || 0);\n    };\n    var p = h.user, q = navigator.onLine;\n    function r() {\n        if (!q) {\n            q = true;\n            l.inform(l.ONLINE, q);\n        }\n    ;\n    };\n    function s() {\n        if (q) {\n            q = false;\n            l.inform(l.ONLINE, q);\n        }\n    ;\n    };\n    if (j.ie()) {\n        if ((j.ie() >= 8)) {\n            window.attachEvent(\"onload\", function() {\n                document.body.ononline = r;\n                document.body.onoffline = s;\n            });\n        }\n         else m.push(function() {\n            ((navigator.onLine ? r : s))();\n        });\n    ;\n    }\n     else if (window.addEventListener) {\n        if (!j.chrome()) {\n            window.addEventListener(\"online\", r, false);\n            window.addEventListener(\"offline\", s, false);\n        }\n    \n    }\n;\n    var t = p;\n    m.push(function() {\n        var w = o();\n        if ((t != w)) {\n            l.inform(l.USER, w);\n            t = w;\n        }\n    ;\n    });\n    var u = Date.now();\n    function v() {\n        var w = Date.now(), x = (w - u), y = ((x < 0) || (x > 10000));\n        u = w;\n        if (y) {\n            l.inform(l.TIME_TRAVEL, x);\n        };\n        return y;\n    };\n    m.push(v);\n    m.push(function() {\n        if ((window.onerror != i.onerror)) {\n            window.onerror = i.onerror;\n        };\n    });\n    a.SystemEvents = e.exports = k(l, {\n        USER: \"SystemEvents/USER\",\n        ONLINE: \"SystemEvents/ONLINE\",\n        TIME_TRAVEL: \"SystemEvents/TIME_TRAVEL\",\n        isPageOwner: function(w) {\n            return (((w || o())) == p);\n        },\n        isOnline: function() {\n            return (j.chrome() || q);\n        },\n        checkTimeTravel: v\n    });\n}, 3);\n__d(\"legacy:link-controller\", [\"LinkController\",], function(a, b, c, d) {\n    a.LinkController = b(\"LinkController\");\n}, 3);\n__d(\"IntlDateFormats\", [], function(a, b, c, d, e, f) {\n    var g = {\n    }, h = {\n        setFormats: function(i, j) {\n            g = j;\n        },\n        getFormat: function(i) {\n            if (!((i in g))) {\n                return i\n            };\n            return g[i];\n        }\n    };\n    e.exports = h;\n});\n__d(\"legacy:vector\", [\"Vector\",], function(a, b, c, d) {\n    a.Vector2 = b(\"Vector\");\n}, 3);\n__d(\"AsyncRequestNectarLogging\", [\"AsyncRequest\",\"Env\",\"copyProperties\",\"startsWith\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncRequest\"), h = b(\"Env\"), i = b(\"copyProperties\"), j = b(\"startsWith\");\n    i(g.prototype, {\n        setNectarModuleData: function(k) {\n            if ((this.method == \"POST\")) {\n                var l = h.module;\n                if ((k && (l === undefined))) {\n                    var m = {\n                        fbpage_fan_confirm: 1\n                    }, n = null;\n                    for (var o = k; (o && (o != document.body)); o = o.parentNode) {\n                        if ((!o.id || (typeof o.id !== \"string\"))) {\n                            continue;\n                        };\n                        if (j(o.id, \"pagelet_\")) {\n                            l = o.id;\n                            break;\n                        }\n                    ;\n                        if ((!n && m[o.id])) {\n                            n = o.id;\n                        };\n                    };\n                    if (((l === undefined) && n)) {\n                        l = n;\n                    };\n                }\n            ;\n                if ((l !== undefined)) {\n                    if ((this.data.nctr === undefined)) {\n                        this.data.nctr = {\n                        };\n                    };\n                    this.data.nctr._mod = l;\n                }\n            ;\n            }\n        ;\n        },\n        setNectarImpressionId: function() {\n            if ((this.method == \"POST\")) {\n                var k = h.impid;\n                if ((k !== undefined)) {\n                    if ((this.data.nctr === undefined)) {\n                        this.data.nctr = {\n                        };\n                    };\n                    this.data.nctr._impid = k;\n                }\n            ;\n            }\n        ;\n        }\n    });\n});\n__d(\"legacy:async-postlude\", [\"AsyncRequestNectarLogging\",], function(a, b, c, d) {\n    b(\"AsyncRequestNectarLogging\");\n}, 3);\n__d(\"Base64\", [], function(a, b, c, d, e, f) {\n    var g = \"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/\";\n    function h(l) {\n        l = ((((l.charCodeAt(0) << 16)) | ((l.charCodeAt(1) << 8))) | l.charCodeAt(2));\n        return String.fromCharCode(g.charCodeAt((l >>> 18)), g.charCodeAt((((l >>> 12)) & 63)), g.charCodeAt((((l >>> 6)) & 63)), g.charCodeAt((l & 63)));\n    };\n    var i = ((\"\\u003E___?456789:;\\u003C=_______\" + \"\\u0000\\u0001\\u0002\\u0003\\u0004\\u0005\\u0006\\u0007\\u0008\\u0009\\u000a\\u000b\\u000c\\u000d\\u000e\\u000f\\u0010\\u0011\\u0012\\u0013\\u0014\\u0015\\u0016\\u0017\\u0018\\u0019\") + \"______\\u001a\\u001b\\u001c\\u001d\\u001e\\u001f !\\\"#$\u0025&'()*+,-./0123\");\n    function j(l) {\n        l = (((((i.charCodeAt((l.charCodeAt(0) - 43)) << 18)) | ((i.charCodeAt((l.charCodeAt(1) - 43)) << 12))) | ((i.charCodeAt((l.charCodeAt(2) - 43)) << 6))) | i.charCodeAt((l.charCodeAt(3) - 43)));\n        return String.fromCharCode((l >>> 16), (((l >>> 8)) & 255), (l & 255));\n    };\n    var k = {\n        encode: function(l) {\n            l = unescape(encodeURI(l));\n            var m = (((l.length + 2)) \u0025 3);\n            l = ((l + \"\\u0000\\u0000\".slice(m))).replace(/[\\s\\S]{3}/g, h);\n            return (l.slice(0, ((l.length + m) - 2)) + \"==\".slice(m));\n        },\n        decode: function(l) {\n            l = l.replace(/[^A-Za-z0-9+\\/]/g, \"\");\n            var m = (((l.length + 3)) & 3);\n            l = ((l + \"AAA\".slice(m))).replace(/..../g, j);\n            l = l.slice(0, ((l.length + m) - 3));\n            try {\n                return decodeURIComponent(escape(l));\n            } catch (n) {\n                throw new Error(\"Not valid UTF-8\");\n            };\n        },\n        encodeObject: function(l) {\n            return k.encode(JSON.stringify(l));\n        },\n        decodeObject: function(l) {\n            return JSON.parse(k.decode(l));\n        },\n        encodeNums: function(l) {\n            return String.fromCharCode.apply(String, l.map(function(m) {\n                return g.charCodeAt(((((m | -((m > 63)))) & -((m > 0))) & 63));\n            }));\n        }\n    };\n    e.exports = k;\n});\n__d(\"legacy:base64\", [\"Base64\",], function(a, b, c, d) {\n    a.Base64 = b(\"Base64\");\n}, 3);\n__d(\"date-extensions\", [\"IntlDateFormats\",\"copyProperties\",\"tx\",], function(a, b, c, d, e, f) {\n    var g = b(\"IntlDateFormats\"), h = b(\"copyProperties\"), i = b(\"tx\"), j = [\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\",], k = [\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\",], l = [\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\",], m = [\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\",];\n    function n(o, p) {\n        p = (p || 2);\n        o = (\"\" + o);\n        while ((o.length < p)) {\n            o = (\"0\" + o);;\n        };\n        return o;\n    };\n    Date.format = function(o, p, q) {\n        var r = (p ? new Date((p * 1000)) : new Date());\n        return r.format(o, q);\n    };\n    h(Date.prototype, {\n        format: function(o, p) {\n            if (!o) {\n                return \"\"\n            };\n            var q = [], r = null, s = null, t = ((p ? \"getUTC\" : \"get\")), u = this[(t + \"Date\")](), v = this[(t + \"Day\")](), w = this[(t + \"Month\")](), x = this[(t + \"FullYear\")](), y = this[(t + \"Hours\")](), z = this[(t + \"Minutes\")](), aa = this[(t + \"Seconds\")](), ba = this[(t + \"Milliseconds\")]();\n            for (var ca = 0; (ca < o.length); ca++) {\n                s = o.charAt(ca);\n                if ((s == \"\\\\\")) {\n                    ca++;\n                    q.push(o.charAt(ca));\n                    continue;\n                }\n            ;\n                switch (s) {\n                  case \"d\":\n                    r = n(u);\n                    break;\n                  case \"D\":\n                    r = j[v];\n                    break;\n                  case \"j\":\n                    r = u;\n                    break;\n                  case \"l\":\n                    r = k[v];\n                    break;\n                  case \"F\":\n                    r = m[w];\n                    break;\n                  case \"m\":\n                    r = n((w + 1));\n                    break;\n                  case \"M\":\n                    r = l[w];\n                    break;\n                  case \"n\":\n                    r = (w + 1);\n                    break;\n                  case \"Y\":\n                    r = x;\n                    break;\n                  case \"y\":\n                    r = ((\"\" + x)).slice(2);\n                    break;\n                  case \"a\":\n                    r = ((y < 12) ? \"am\" : \"pm\");\n                    break;\n                  case \"A\":\n                    r = ((y < 12) ? \"AM\" : \"PM\");\n                    break;\n                  case \"g\":\n                    r = ((((y == 0) || (y == 12))) ? 12 : (y \u0025 12));\n                    break;\n                  case \"G\":\n                    r = y;\n                    break;\n                  case \"h\":\n                    r = ((((y == 0) || (y == 12))) ? 12 : n((y \u0025 12)));\n                    break;\n                  case \"H\":\n                    r = n(y);\n                    break;\n                  case \"i\":\n                    r = n(z);\n                    break;\n                  case \"s\":\n                    r = n(aa);\n                    break;\n                  case \"S\":\n                    r = n(ba, 3);\n                    break;\n                  default:\n                    r = s;\n                };\n                q.push(r);\n            };\n            return q.join(\"\");\n        }\n    });\n    a.IntlDateFormats = g;\n}, 3);\n__d(\"legacy:ua\", [\"UserAgent\",], function(a, b, c, d) {\n    a.ua = b(\"UserAgent\");\n}, 3);\n__d(\"legacy:dialog\", [\"Dialog\",], function(a, b, c, d) {\n    var e = b(\"Dialog\");\n    a.Dialog = e;\n}, 3);\n__d(\"csx\", [], function(a, b, c, d, e, f) {\n    function g(h) {\n        throw new Error(\"csx(...): Unexpected class selector transformation.\");\n    };\n    e.exports = g;\n});\n__d(\"AccessibleLayer\", [\"event-extensions\",\"CSS\",\"DOM\",\"Input\",\"copyProperties\",\"csx\",\"tx\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"Input\"), j = b(\"copyProperties\"), k = b(\"csx\"), l = b(\"tx\");\n    function m(n) {\n        this._layer = n;\n    };\n    j(m.prototype, {\n        enable: function() {\n            var n = this._layer.getRoot();\n            if ((n.tabIndex == -1)) {\n                n.tabIndex = 0;\n            };\n            var o = h.create(\"a\", {\n                className: \"accessible_elem\",\n                href: \"#\"\n            }, [\"Close popup and return\",]);\n            h.appendContent(n, o);\n            this._listener = Event.listen(o, \"click\", this._closeListener.bind(this));\n            this._afterShowSubscription = this._layer.subscribe(\"aftershow\", this._onAfterShow.bind(this));\n        },\n        disable: function() {\n            this._listener.remove();\n            this._afterShowSubscription.unsubscribe();\n            this._listener = this._afterShowSubscription = null;\n        },\n        _closeListener: function(event) {\n            var n = this._layer.getCausalElement();\n            if (n) {\n                if ((n.tabIndex == -1)) {\n                    n.tabIndex = 0;\n                    g.addClass(n, \"-cx-PRIVATE-accessibleLayer__noOutline\");\n                }\n            ;\n                i.focus(n);\n            }\n        ;\n            this._layer.hide();\n        },\n        _onAfterShow: function() {\n            var n = document.activeElement, o = this._layer.getRoot();\n            if ((!h.isNodeOfType(n, [\"input\",\"textarea\",]) && !h.contains(o, n))) {\n                i.focus(o);\n            };\n        }\n    });\n    e.exports = m;\n});\n__d(\"Rect\", [\"Vector\",\"$\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Vector\"), h = b(\"$\"), i = b(\"copyProperties\");\n    function j(k, l, m, n, o) {\n        if ((arguments.length === 1)) {\n            if ((k instanceof j)) {\n                return k\n            };\n            if ((k instanceof g)) {\n                return new j(k.y, k.x, k.y, k.x, k.domain)\n            };\n            return j.getElementBounds(h(k));\n        }\n    ;\n        i(this, {\n            t: k,\n            r: l,\n            b: m,\n            l: n,\n            domain: (o || \"pure\")\n        });\n    };\n    i(j.prototype, {\n        w: function() {\n            return (this.r - this.l);\n        },\n        h: function() {\n            return (this.b - this.t);\n        },\n        toString: function() {\n            return ((((((((\"((\" + this.l) + \", \") + this.t) + \"), (\") + this.r) + \", \") + this.b) + \"))\");\n        },\n        contains: function(k) {\n            k = new j(k).convertTo(this.domain);\n            var l = this;\n            return (((((l.l <= k.l) && (l.r >= k.r)) && (l.t <= k.t)) && (l.b >= k.b)));\n        },\n        add: function(k, l) {\n            if ((arguments.length == 1)) {\n                if ((k.domain != \"pure\")) {\n                    k = k.convertTo(this.domain);\n                };\n                return this.add(k.x, k.y);\n            }\n        ;\n            var m = parseFloat(k), n = parseFloat(l);\n            return new j((this.t + n), (this.r + m), (this.b + n), (this.l + m), this.domain);\n        },\n        sub: function(k, l) {\n            if ((arguments.length == 1)) {\n                return this.add(k.mul(-1));\n            }\n             else return this.add(-k, -l)\n        ;\n        },\n        boundWithin: function(k) {\n            var l = 0, m = 0;\n            if ((this.l < k.l)) {\n                l = (k.l - this.l);\n            }\n             else if ((this.r > k.r)) {\n                l = (k.r - this.r);\n            }\n        ;\n            if ((this.t < k.t)) {\n                m = (k.t - this.t);\n            }\n             else if ((this.b > k.b)) {\n                m = (k.b - this.b);\n            }\n        ;\n            return this.add(l, m);\n        },\n        getCenter: function() {\n            return new g((this.l + (this.w() / 2)), (this.t + (this.h() / 2)), this.domain);\n        },\n        getPositionVector: function() {\n            return new g(this.l, this.t, this.domain);\n        },\n        getDimensionVector: function() {\n            return new g(this.w(), this.h(), \"pure\");\n        },\n        convertTo: function(k) {\n            if ((this.domain == k)) {\n                return this\n            };\n            if ((k == \"pure\")) {\n                return new j(this.t, this.r, this.b, this.l, \"pure\")\n            };\n            if ((this.domain == \"pure\")) {\n                return new j(0, 0, 0, 0)\n            };\n            var l = new g(this.l, this.t, this.domain).convertTo(k);\n            return new j(l.y, (l.x + this.w()), (l.y + this.h()), l.x, k);\n        }\n    });\n    i(j, {\n        deserialize: function(k) {\n            var l = k.split(\":\");\n            return new j(parseFloat(l[1]), parseFloat(l[2]), parseFloat(l[3]), parseFloat(l[0]));\n        },\n        newFromVectors: function(k, l) {\n            return new j(k.y, (k.x + l.x), (k.y + l.y), k.x, k.domain);\n        },\n        getElementBounds: function(k) {\n            return j.newFromVectors(g.getElementPosition(k), g.getElementDimensions(k));\n        },\n        getViewportBounds: function() {\n            return j.newFromVectors(g.getScrollPosition(), g.getViewportDimensions());\n        },\n        minimumBoundingBox: function(k) {\n            var l = new j(Math.min(), Math.max(), Math.max(), Math.min()), m;\n            for (var n = 0; (n < k.length); n++) {\n                m = k[n];\n                l.t = Math.min(l.t, m.t);\n                l.r = Math.max(l.r, m.r);\n                l.b = Math.max(l.b, m.b);\n                l.l = Math.min(l.l, m.l);\n            };\n            return l;\n        }\n    });\n    e.exports = j;\n});\n__d(\"Hovercard\", [\"ClickRef\",\"event-extensions\",\"function-extensions\",\"AccessibleLayer\",\"Arbiter\",\"AsyncRequest\",\"AsyncSignal\",\"ContextualDialogX\",\"CSS\",\"DOM\",\"DOMQuery\",\"LayerDestroyOnHide\",\"LayerFadeOnHide\",\"LayerFadeOnShow\",\"Parent\",\"Rect\",\"UserAgent\",\"URI\",\"Vector\",\"ViewportBounds\",\"tx\",\"userAction\",], function(a, b, c, d, e, f) {\n    b(\"ClickRef\");\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"AccessibleLayer\"), h = b(\"Arbiter\"), i = b(\"AsyncRequest\"), j = b(\"AsyncSignal\"), k = b(\"ContextualDialogX\"), l = b(\"CSS\"), m = b(\"DOM\"), n = b(\"DOMQuery\"), o = b(\"LayerDestroyOnHide\"), p = b(\"LayerFadeOnHide\"), q = b(\"LayerFadeOnShow\"), r = b(\"Parent\"), s = b(\"Rect\"), t = b(\"UserAgent\"), u = b(\"URI\"), v = b(\"Vector\"), w = b(\"ViewportBounds\"), x = b(\"tx\"), y = b(\"userAction\"), z = 450, aa = 385, ba = {\n    }, ca = {\n    }, da = null, ea = null, fa = null, ga = 150, ha = 700, ia = 1000, ja = 250, ka = null, la = null, ma = null, na = null;\n    function oa() {\n        if ((t.ie() < 7)) {\n            return\n        };\n        Event.listen(document.documentElement, \"mouseover\", pa);\n        Event.listen(window, \"scroll\", function() {\n            kb.hide(true);\n        });\n        h.subscribe(\"page_transition\", function() {\n            va();\n            kb.dirtyAll();\n        }, h.SUBSCRIBE_NEW);\n        h.subscribe(\"layer_shown\", function(lb, mb) {\n            if (((mb.type != \"Hovercard\") && (mb.type != \"ContextualDialog\"))) {\n                va();\n            };\n        }, h.SUBSCRIBE_NEW);\n        k.subscribe(\"arrow_rendered\", xa, h.SUBSCRIBE_NEW);\n    };\n    function pa(event) {\n        var lb = r.byTag(event.getTarget(), \"a\");\n        (kb.processNode(lb) && event.stop());\n    };\n    function qa(lb) {\n        ea = lb;\n        if (!ra(lb)) {\n            var mb;\n            if ((!lb || !(mb = sa(lb)))) {\n                (ca.moveToken && ca.moveToken.remove());\n                ca = {\n                };\n                return false;\n            }\n        ;\n            if ((ca.node != lb)) {\n                (ca.moveToken && ca.moveToken.remove());\n                ca = {\n                    node: lb,\n                    endpoint: mb,\n                    pos: null\n                };\n            }\n        ;\n        }\n    ;\n        return true;\n    };\n    function ra(lb) {\n        return ((lb && da) && (ca.node == lb));\n    };\n    function sa(lb) {\n        return lb.getAttribute(\"data-hovercard\");\n    };\n    function ta(lb) {\n        var mb = Event.listen(lb, \"mouseout\", function() {\n            clearTimeout(ka);\n            clearTimeout(la);\n            mb.remove();\n            ea = null;\n            kb.hide();\n        });\n        if (!ca.moveToken) {\n            ca.moveToken = Event.listen(lb, \"mousemove\", function(event) {\n                ca.pos = v.getEventPosition(event);\n            });\n        };\n        clearTimeout(ka);\n        clearTimeout(la);\n        clearTimeout(na);\n        var nb = ga, ob = (da ? ja : ha);\n        if (lb.getAttribute(\"data-hovercard-instant\")) {\n            nb = ob = 50;\n        };\n        ka = setTimeout(gb.curry(lb), nb);\n        la = setTimeout(ua.curry(lb), ob);\n    };\n    function ua(lb, mb) {\n        if ((ca.node != lb)) {\n            return\n        };\n        var nb = ba[sa(lb)];\n        if (nb) {\n            wa(nb);\n        }\n         else if (mb) {\n            wa(ib());\n        }\n         else {\n            var ob = (da ? ja : ha);\n            ma = setTimeout(ua.curry(lb, true), (ia - ob));\n        }\n        \n    ;\n    };\n    function va() {\n        kb.hide(true);\n        clearTimeout(la);\n    };\n    function wa(lb) {\n        var mb = ca.node, nb = da, ob = (nb != mb);\n        if (da) {\n            var pb = k.getInstance(da);\n            (pb && pb.hide());\n        }\n    ;\n        if (!m.contains(document.body, mb)) {\n            kb.hide(true);\n            return;\n        }\n    ;\n        da = mb;\n        fa = lb;\n        cb();\n        lb.setContext(mb).show();\n        if (ob) {\n            (function() {\n                new j(\"/ajax/hovercard/shown.php\").send();\n                y(\"himp\", da, null, \"FORCE\", {\n                    ft: {\n                        evt: 39\n                    }\n                });\n            }).defer();\n            if (nb) {\n                h.inform(\"Hovercard/hide\", {\n                    node: nb\n                });\n            }\n             else h.inform(\"layer_shown\", {\n                type: \"Hovercard\"\n            });\n        ;\n            h.inform(\"Hovercard/show\", {\n                node: mb\n            });\n        }\n    ;\n    };\n    function xa(lb, mb) {\n        var nb = ba[ca.endpoint];\n        if (((((mb.type !== \"ContextualDialog\") || !nb) || !mb.root) || (mb.position !== \"top\"))) {\n            return\n        };\n        var ob = n.scry(mb.root, \".CustomArrow\")[0];\n        if (!ob) {\n            return\n        };\n        var pb = n.scry(ob, \".ArrowShadow\")[0];\n        if (!pb) {\n            return\n        };\n        var qb = null;\n        if ((ob.style.webkitMaskPosition !== undefined)) {\n            qb = ab;\n        }\n         else if (ya(ob)) {\n            qb = bb;\n        }\n    ;\n        if (qb) {\n            l.addClass(mb.root, \"withCustomArrow\");\n            setTimeout(function() {\n                qb(ob, pb, mb);\n            }, 0);\n        }\n    ;\n    };\n    function ya(lb) {\n        if (!lb) {\n            lb = document.body;\n        };\n        var mb = [\"transform\",\"WebkitTransform\",\"msTransform\",\"MozTransform\",\"OTransform\",], nb;\n        while (nb = mb.shift()) {\n            if ((lb.style[nb] !== undefined)) {\n                return nb\n            };\n        };\n        return null;\n    };\n    function za(lb, mb, nb) {\n        var ob = lb.parentNode.offsetWidth, pb = Math.round(((ob * nb.offset_percent) / 100));\n        if ((nb.side === \"left\")) {\n            pb = (pb + nb.side_margin);\n        }\n         else if ((nb.side === \"right\")) {\n            pb = (((ob - pb) - nb.side_margin) - 18);\n        }\n    ;\n        return pb;\n    };\n    function ab(lb, mb, nb) {\n        l.addClass(nb.root, \"usingMask\");\n        var ob = za(lb, mb, nb);\n        lb.style.webkitMaskPositionX = (ob + \"px\");\n        mb.style.left = (ob + \"px\");\n    };\n    function bb(lb, mb, nb) {\n        var ob = n.scry(lb, \".CoverPhoto\")[0];\n        if (!ob) {\n            return\n        };\n        var pb = ya(lb);\n        if (!pb) {\n            return\n        };\n        l.addClass(nb.root, \"usingRotate\");\n        var qb = (za(lb, mb, nb) + 9), rb = Math.ceil((qb / Math.SQRT2));\n        ob.style[pb] = ((((\"translate(\" + (-rb)) + \"px, \") + rb) + \"px) rotate(-45deg)\");\n        lb.style[pb] = ((\"translate(\" + qb) + \"px, 0) rotate(45deg)\");\n    };\n    function cb() {\n        var lb = v.getViewportDimensions(), mb = v.getElementPosition(da, \"viewport\"), nb = mb.convertTo(\"document\"), ob = fb(da), pb = \"above\", qb = \"left\", rb = eb(nb, ob, \"above\");\n        if (((mb.y + rb) <= aa)) {\n            var sb = eb(nb, ob, \"below\");\n            if (((((mb.y + sb) + da.offsetHeight) + aa) < lb.y)) {\n                pb = \"below\";\n                rb = sb;\n            }\n        ;\n        }\n    ;\n        var tb = (lb.x - w.getRight()), ub = db(nb, ob, \"left\");\n        if ((((mb.x + ub) + z) >= tb)) {\n            var vb = db(nb, ob, \"right\");\n            if ((((mb.x + vb) + da.offsetWidth) > z)) {\n                qb = \"right\";\n                ub = vb;\n            }\n        ;\n        }\n    ;\n        fa.setPosition(pb).setAlignH(qb).setOffsetX(ub).setOffsetY(rb);\n    };\n    function db(lb, mb, nb) {\n        if ((nb == \"left\")) {\n            return (mb.l - lb.x)\n        };\n        return (mb.r - ((lb.x + da.offsetWidth)));\n    };\n    function eb(lb, mb, nb) {\n        if ((nb == \"above\")) {\n            return (mb.t - lb.y)\n        };\n        return (mb.b - ((lb.y + da.offsetHeight)));\n    };\n    function fb(lb) {\n        var mb = ca.pos, nb = lb.getClientRects();\n        if ((!mb || (nb.length === 0))) {\n            return s.getElementBounds(lb)\n        };\n        var ob, pb = false;\n        for (var qb = 0; (qb < nb.length); qb++) {\n            var rb = new s(Math.round(nb[qb].top), Math.round(nb[qb].right), Math.round(nb[qb].bottom), Math.round(nb[qb].left), \"viewport\").convertTo(\"document\"), sb = rb.getPositionVector(), tb = sb.add(rb.getDimensionVector());\n            if ((!ob || (((sb.x <= ob.l) && (sb.y > ob.t))))) {\n                if (pb) {\n                    break;\n                };\n                ob = new s(sb.y, tb.x, tb.y, sb.x, \"document\");\n            }\n             else {\n                ob.t = Math.min(ob.t, sb.y);\n                ob.b = Math.max(ob.b, tb.y);\n                ob.r = tb.x;\n            }\n        ;\n            if (rb.contains(mb)) {\n                pb = true;\n            };\n        };\n        return ob;\n    };\n    function gb(lb) {\n        if ((lb.id && (ba[lb.id] != null))) {\n            return\n        };\n        var mb = sa(lb);\n        if ((ba[mb] != null)) {\n            return\n        };\n        hb(mb);\n        var nb = function() {\n            kb.dirty(mb);\n            va();\n        };\n        new i(mb).setData({\n            endpoint: mb\n        }).setMethod(\"GET\").setReadOnly(true).setErrorHandler(nb).setTransportErrorHandler(nb).send();\n    };\n    function hb(lb) {\n        ba[lb] = false;\n    };\n    var ib = function() {\n        var lb = new k({\n        }, m.create(\"div\", {\n            className: \"HovercardLoading\"\n        }, \"Loading...\"));\n        lb.disableBehavior(g).disableBehavior(o).disableBehavior(q).disableBehavior(p);\n        jb(lb);\n        ib = bagof(lb);\n        return lb;\n    };\n    function jb(lb) {\n        lb.subscribe(\"mouseenter\", function() {\n            clearTimeout(na);\n            ea = ca.node;\n        });\n        lb.subscribe(\"mouseleave\", function() {\n            kb.hide(false);\n            ea = null;\n        });\n    };\n    var kb = {\n        hide: function(lb) {\n            if (!da) {\n                return\n            };\n            if (lb) {\n                if (fa) {\n                    h.inform(\"layer_hidden\", {\n                        type: \"Hovercard\"\n                    });\n                    h.inform(\"Hovercard/hide\", {\n                        node: da\n                    });\n                    fa.hide();\n                }\n            ;\n                ea = null;\n                da = null;\n                fa = null;\n            }\n             else na = setTimeout(kb.hide.curry(true), ja);\n        ;\n        },\n        setDialog: function(lb, mb) {\n            mb.disableBehavior(g);\n            ba[lb] = mb;\n            jb(mb);\n            if (((ca.endpoint == lb) && (ea == ca.node))) {\n                wa(mb);\n            };\n        },\n        getDialog: function(lb) {\n            return ba[lb];\n        },\n        contains: function(lb) {\n            if (fa) {\n                return m.contains(fa.getRoot(), lb)\n            };\n            return false;\n        },\n        dirty: function(lb) {\n            var mb = ba[lb];\n            if (mb) {\n                mb.destroy();\n                delete ba[lb];\n            }\n        ;\n        },\n        dirtyAll: function() {\n            for (var lb in ba) {\n                var mb = ba[lb];\n                (mb && kb.dirty(lb));\n            };\n            h.inform(\"Hovercard/dirty\");\n        },\n        processNode: function(lb) {\n            if ((lb && qa(lb))) {\n                ta(lb);\n                return true;\n            }\n        ;\n            return false;\n        }\n    };\n    if (!a.Hovercard) {\n        oa();\n    }\n     else kb = a.Hovercard;\n;\n    e.exports = kb;\n    a.Hovercard = e.exports;\n});\n__d(\"legacy:array-utils\", [\"createArrayFrom\",\"hasArrayNature\",], function(a, b, c, d) {\n    a.$A = b(\"createArrayFrom\");\n    a.hasArrayNature = b(\"hasArrayNature\");\n}, 3);\n__d(\"legacy:env\", [\"Env\",], function(a, b, c, d) {\n    var e = b(\"Env\");\n    a.Env = e;\n}, 3);\n__d(\"legacy:page-transitions\", [\"computeRelativeURI\",\"HistoryManager\",\"PageTransitions\",], function(a, b, c, d) {\n    a.computeRelativeURI = b(\"computeRelativeURI\");\n    a.HistoryManager = (a.HistoryManager || b(\"HistoryManager\"));\n    a.PageTransitions = (a.PageTransitions || b(\"PageTransitions\"));\n}, 3);\n__d(\"FlipDirectionOnKeypress\", [\"event-extensions\",\"DOM\",\"Input\",\"Style\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"DOM\"), h = b(\"Input\"), i = b(\"Style\");\n    Event.listen(document.documentElement, \"keyup\", function(event) {\n        var j = event.getTarget();\n        if (!g.isNodeOfType(j, [\"input\",\"textarea\",])) {\n            return\n        };\n        if ((g.isNodeOfType(j, \"input\") && (j.type == \"password\"))) {\n            return\n        };\n        if (j.getAttribute(\"data-prevent-auto-flip\")) {\n            return\n        };\n        var k = h.getValue(j), l = ((j.style && j.style.direction));\n        if (!l) {\n            var m = 0, n = true;\n            for (var o = 0; (o < k.length); o++) {\n                var p = k.charCodeAt(o);\n                if ((p >= 48)) {\n                    if (n) {\n                        n = false;\n                        m++;\n                    }\n                ;\n                    if (((p >= 1470) && (p <= 1920))) {\n                        i.set(j, \"direction\", \"rtl\");\n                        return;\n                    }\n                ;\n                    if ((m == 5)) {\n                        i.set(j, \"direction\", \"ltr\");\n                        return;\n                    }\n                ;\n                }\n                 else n = true;\n            ;\n            };\n        }\n         else if ((k.length === 0)) {\n            i.set(j, \"direction\", \"\");\n        }\n    ;\n    });\n});\n__d(\"PlaceholderOnsubmitFormListener\", [\"event-extensions\",\"Input\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Input\");\n    Event.listen(document.documentElement, \"submit\", function(h) {\n        var i = h.getTarget().getElementsByTagName(\"*\");\n        for (var j = 0; (j < i.length); j++) {\n            if ((i[j].getAttribute(\"placeholder\") && g.isEmpty(i[j]))) {\n                g.setValue(i[j], \"\");\n            };\n        };\n    });\n});\n__d(\"RequiredFormListener\", [\"event-extensions\",\"Input\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Input\");\n    Event.listen(document.documentElement, \"submit\", function(h) {\n        var i = h.getTarget().getElementsByTagName(\"*\");\n        for (var j = 0; (j < i.length); j++) {\n            if ((i[j].getAttribute(\"required\") && g.isEmpty(i[j]))) {\n                i[j].focus();\n                return false;\n            }\n        ;\n        };\n    }, Event.Priority.URGENT);\n});\n__d(\"Live\", [\"Arbiter\",\"AsyncDOM\",\"AsyncSignal\",\"ChannelConstants\",\"DOM\",\"DataStore\",\"ServerJS\",\"createArrayFrom\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AsyncDOM\"), i = b(\"AsyncSignal\"), j = b(\"ChannelConstants\"), k = b(\"DOM\"), l = b(\"DataStore\"), m = b(\"ServerJS\"), n = b(\"createArrayFrom\");\n    function o(q, r) {\n        r = JSON.parse(JSON.stringify(r));\n        new m().setRelativeTo(q).handle(r);\n    };\n    var p = {\n        logAll: false,\n        startup: function() {\n            p.startup = bagofholding;\n            g.subscribe(j.getArbiterType(\"live\"), p.handleMessage.bind(p));\n        },\n        lookupLiveNode: function(q, r) {\n            var s = k.scry(document.body, (((\".live_\" + q) + \"_\") + r));\n            s.forEach(function(t) {\n                if ((l.get(t, \"seqnum\") === undefined)) {\n                    var u = JSON.parse(t.getAttribute(\"data-live\"));\n                    l.set(t, \"seqnum\", u.seq);\n                }\n            ;\n            });\n            return s;\n        },\n        handleMessage: function(q, r) {\n            var s = r.obj, t = s.fbid, u = s.assoc, v = this.lookupLiveNode(t, u);\n            if (!v) {\n                return false\n            };\n            v.forEach(function(w) {\n                if (s.expseq) {\n                    var x = l.get(w, \"seqnum\"), y = l.get(w, \"message_buffer\");\n                    if ((y === undefined)) {\n                        y = {\n                        };\n                        l.set(w, \"message_buffer\", y);\n                    }\n                ;\n                    var z = {\n                        obj: s\n                    };\n                    y[s.expseq] = z;\n                    if ((s.expseq != x)) {\n                        p.log(\"mismatch\", s.fbid, s.expseq, x);\n                        return false;\n                    }\n                ;\n                    while (true) {\n                        x = l.get(w, \"seqnum\");\n                        var aa = y[x];\n                        if (aa) {\n                            h.invoke(aa.obj.updates, w);\n                            if (aa.obj.js) {\n                                o(w, aa.obj.js);\n                            };\n                            p.log(\"seqmatch\", s.fbid, \"exp\", s.expseq, \"cur\", x);\n                            delete y[x];\n                        }\n                         else break;\n                    ;\n                    };\n                }\n                 else {\n                    h.invoke(s.updates, w);\n                    if (s.js) {\n                        o(w, s.js);\n                    };\n                }\n            ;\n            });\n        },\n        log: function() {\n            if (p.logAll) {\n                var q = n(arguments).join(\":\");\n                new i(\"/common/scribe_endpoint.php\", {\n                    c: \"live_sequence\",\n                    m: q\n                }).send();\n            }\n        ;\n        }\n    };\n    e.exports = p;\n});\n__d(\"legacy:live-js\", [\"Live\",], function(a, b, c, d) {\n    a.Live = b(\"Live\");\n}, 3);\n__d(\"legacy:JSLogger\", [\"JSLogger\",], function(a, b, c, d) {\n    a.JSLogger = b(\"JSLogger\");\n}, 3);\n__d(\"RenderManager\", [\"function-extensions\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"copyProperties\");\n    function h(i) {\n        this._isDirty = false;\n        this._obj = i;\n    };\n    g(h.prototype, {\n        dirty: function() {\n            if (!this._isDirty) {\n                this._isDirty = true;\n                this._doPaint.bind(this).defer();\n            }\n        ;\n        },\n        _doPaint: function() {\n            this._isDirty = false;\n            this._obj.paint();\n        }\n    });\n    e.exports = h;\n});\n__d(\"CounterDisplay\", [\"Arbiter\",\"CSS\",\"DOM\",\"RenderManager\",\"Run\",\"$\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"RenderManager\"), k = b(\"Run\"), l = b(\"$\"), m = b(\"copyProperties\");\n    function n(o, p, q, r, s, t) {\n        m(this, {\n            _name: o,\n            _valueNode: l(p),\n            _wrapperNode: (l(q) || null),\n            _statusClass: s,\n            _rm: new j(this),\n            _arbiterSubscription: null,\n            _count: 0\n        });\n        var u = this._valueNode.firstChild;\n        if (u) {\n            var v = parseInt(u.nodeValue, 10);\n            if (!isNaN(v)) {\n                this._count = v;\n            };\n        }\n    ;\n        this._statusNode = (r ? l(r) : null);\n        this._subscribeAll();\n        n.instances.push(this);\n        if (!t) {\n            k.onLeave(this._destroy.bind(this), true);\n        };\n    };\n    m(n, {\n        EVENT_TYPE_ADJUST: \"CounterDisplay/adjust\",\n        EVENT_TYPE_UPDATE: \"CounterDisplay/update\",\n        instances: [],\n        adjustCount: function(o, p) {\n            g.inform(((n.EVENT_TYPE_ADJUST + \"/\") + o), p);\n        },\n        setCount: function(o, p) {\n            g.inform(((n.EVENT_TYPE_UPDATE + \"/\") + o), p);\n        }\n    });\n    m(n.prototype, {\n        _destroy: function() {\n            delete this._valueNode;\n            delete this._wrapperNode;\n            if (this._arbiterSubscription) {\n                this._arbiterSubscription.unsubscribe();\n                delete this._arbiterSubscription;\n            }\n        ;\n            n.instances.remove(this);\n        },\n        adjustCount: function(o) {\n            this._count = Math.max(0, (this._count + o));\n            this._rm.dirty();\n            return this;\n        },\n        setCount: function(o) {\n            this._count = Math.max(0, o);\n            this._rm.dirty();\n            return this;\n        },\n        paint: function() {\n            i.setContent(this._valueNode, this._count);\n            this._toggleNodes();\n        },\n        _toggleNodes: function() {\n            if (this._wrapperNode) {\n                h.conditionClass(this._wrapperNode, \"hidden_elem\", (this._count <= 0));\n            };\n            if ((this._statusClass && this._statusNode)) {\n                h.conditionClass(this._statusNode, this._statusClass, (this._count > 0));\n            };\n        },\n        _subscribeAll: function() {\n            var o = [((n.EVENT_TYPE_ADJUST + \"/\") + this._name),((n.EVENT_TYPE_UPDATE + \"/\") + this._name),];\n            this._arbiterSubscription = g.subscribe(o, this._onInform.bind(this), g.SUBSCRIBE_NEW);\n        },\n        _onInform: function(o, p) {\n            p = parseInt(p);\n            if (isNaN(p)) {\n                return\n            };\n            if ((o.indexOf(n.EVENT_TYPE_ADJUST) != -1)) {\n                this.adjustCount(p);\n            }\n             else if ((o.indexOf(n.EVENT_TYPE_UPDATE) != -1)) {\n                this.setCount(p);\n            }\n             else return\n            \n        ;\n            return;\n        }\n    });\n    e.exports = n;\n});\n__d(\"Amoeba\", [\"Run\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Run\"), h = b(\"copyProperties\"), i = {\n    };\n    h(i, {\n        _instrumentQueue: [],\n        _logger: null,\n        instrument: function(j, k) {\n            if (i._logger) {\n                i._logger.instrument(j, k);\n            }\n             else i._instrumentQueue.push([j,k,]);\n        ;\n        },\n        flushQueue: function(j) {\n            if (j) {\n                i._instrumentQueue.map(j);\n            };\n            i._instrumentQueue = [];\n        },\n        setLogger: function(j) {\n            i._logger = j;\n        }\n    });\n    g.onLeave(function() {\n        i.flushQueue(null);\n    });\n    e.exports = i;\n});\n__d(\"cx\", [], function(a, b, c, d, e, f) {\n    function g(h) {\n        throw new Error(\"cx(...): Unexpected class transformation.\");\n    };\n    e.exports = g;\n});\n__d(\"ModalLayer\", [\"event-extensions\",\"CSS\",\"DOMQuery\",\"ScrollAwareDOM\",\"Style\",\"URI\",\"UserAgent\",\"Vector\",\"copyProperties\",\"csx\",\"debounce\",\"ge\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"CSS\"), h = b(\"DOMQuery\"), i = b(\"ScrollAwareDOM\"), j = b(\"Style\"), k = b(\"URI\"), l = b(\"UserAgent\"), m = b(\"Vector\"), n = b(\"copyProperties\"), o = b(\"csx\"), p = b(\"debounce\"), q = b(\"ge\"), r = 0, s = null, t = null;\n    function u() {\n        if (!t) {\n            t = h.scry(document.body, \".-cx-PRIVATE-fbLayout__root\")[0];\n        };\n        return t;\n    };\n    function v() {\n        h.scry(document.body, \"div.swfObject\").forEach(function(x) {\n            var y = x.getAttribute(\"data-swfid\");\n            if ((y && window[y])) {\n                var z = window[y];\n                z.addParam(\"autostart\", \"false\");\n                z.addParam(\"autoplay\", \"false\");\n                z.addParam(\"play\", \"false\");\n                z.addVariable(\"video_autoplay\", \"0\");\n                z.addVariable(\"autoplay\", \"0\");\n                z.addVariable(\"play\", \"0\");\n                var aa = k(z.getAttribute(\"swf\"));\n                aa.addQueryData({\n                    autoplay: \"0\"\n                });\n                aa.setPath(aa.getPath().replace(\"autoplay=1\", \"autoplay=0\"));\n                z.setAttribute(\"swf\", aa.toString());\n                z.write(x);\n            }\n        ;\n        });\n    };\n    function w(x) {\n        this._layer = x;\n    };\n    n(w.prototype, {\n        _subscription: null,\n        _resizeListener: null,\n        enable: function() {\n            if (!u()) {\n                return\n            };\n            this._subscription = this._layer.subscribe([\"show\",\"hide\",], function(x) {\n                ((x == \"show\") ? this._addModal() : this._removeModal());\n            }.bind(this));\n            if (this._layer.isShown()) {\n                this._addModal();\n            };\n        },\n        disable: function() {\n            if (!u()) {\n                return\n            };\n            this._subscription.unsubscribe();\n            this._subscription = null;\n            if (this._layer.isShown()) {\n                this._removeModal();\n            };\n        },\n        _addModal: function() {\n            g.addClass(this._layer.getRoot(), \"modalWrapper\");\n            if ((r++ === 0)) {\n                s = m.getScrollPosition();\n                var x = u(), y = (x.offsetTop - s.y);\n                j.set(x, \"top\", (y + \"px\"));\n                g.addClass(document.documentElement, \"modalOpen\");\n                if ((l.ie() < 7)) {\n                    var z = this._layer.getRoot(), aa = function() {\n                        var ca = (-y + Math.max(z.offsetHeight, z.scrollHeight));\n                        j.set(x, \"height\", (ca + \"px\"));\n                    };\n                    aa();\n                    this._resizeListener = Event.listen(window, \"resize\", p(aa, 100));\n                }\n            ;\n                var ba = h.getDocumentScrollElement();\n                ba.scrollTop = 0;\n                this._scrollSubscription = i.subscribe(\"scroll\", function(ca, da) {\n                    var ea = (x.offsetTop - da.delta.y);\n                    j.set(x, \"top\", (ea + \"px\"));\n                    s = s.add(da.delta);\n                    return false;\n                });\n                if ((l.firefox() < 13)) {\n                    v.defer();\n                };\n            }\n        ;\n        },\n        _removeModal: function() {\n            g.removeClass(this._layer.getRoot(), \"modalWrapper\");\n            if ((--r === 0)) {\n                g.removeClass(document.documentElement, \"modalOpen\");\n                var x = u();\n                j.set(x, \"top\", \"\");\n                if ((l.ie() < 7)) {\n                    j.set(x, \"height\", \"\");\n                    this._resizeListener.remove();\n                    this._resizeListener = null;\n                }\n            ;\n                var y = h.getDocumentScrollElement();\n                y.scrollTop = s.y;\n                this._scrollSubscription.unsubscribe();\n                this._scrollSubscription = null;\n            }\n        ;\n        }\n    });\n    e.exports = w;\n});\n__d(\"DialogX\", [\"event-extensions\",\"function-extensions\",\"AccessibleLayer\",\"Arbiter\",\"ArbiterMixin\",\"Class\",\"DOM\",\"Layer\",\"LayerButtons\",\"LayerFormHooks\",\"ModalLayer\",\"Parent\",\"Style\",\"UserAgent\",\"Vector\",\"copyProperties\",\"cx\",\"debounce\",\"getOverlayZIndex\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"AccessibleLayer\"), h = b(\"Arbiter\"), i = b(\"ArbiterMixin\"), j = b(\"Class\"), k = b(\"DOM\"), l = b(\"Layer\"), m = b(\"LayerButtons\"), n = b(\"LayerFormHooks\"), o = b(\"ModalLayer\"), p = b(\"Parent\"), q = b(\"Style\"), r = b(\"UserAgent\"), s = b(\"Vector\"), t = b(\"copyProperties\"), u = b(\"cx\"), v = b(\"debounce\"), w = b(\"getOverlayZIndex\");\n    function x(z, aa) {\n        this.parent.construct(this, z, aa);\n    };\n    j.extend(x, l);\n    t(x, i);\n    t(x.prototype, {\n        _modal: false,\n        _ie: null,\n        _wrapper: null,\n        _configure: function(z, aa) {\n            this.parent._configure(z, aa);\n            if (z.modal) {\n                this._modal = true;\n                this.enableBehavior(o);\n            }\n        ;\n            if (z.autohide) {\n                var ba = this.subscribe(\"show\", function() {\n                    ba.unsubscribe();\n                    this.hide.shield(this).defer(z.autohide);\n                }.bind(this))\n            };\n        },\n        _getDefaultBehaviors: function() {\n            return this.parent._getDefaultBehaviors().concat([y,g,m,n,]);\n        },\n        _buildWrapper: function(z, aa) {\n            var ba = k.create(\"div\", {\n                className: \"-cx-PRIVATE-uiDialog__content\"\n            }, aa), ca;\n            this._ie = r.ie();\n            if (((this._ie > 6) && (this._ie < 9))) {\n                ca = [k.create(\"div\", {\n                    className: \"-cx-PRIVATE-uiDialog__vertical\"\n                }),k.create(\"div\", {\n                    className: \"-cx-PRIVATE-uiDialog__horizontal\"\n                }),k.create(\"div\", {\n                    className: \"-cx-PRIVATE-uiDialog__topLeft\"\n                }),k.create(\"div\", {\n                    className: \"-cx-PRIVATE-uiDialog__topRight\"\n                }),k.create(\"div\", {\n                    className: \"-cx-PRIVATE-uiDialog__bottomLeft\"\n                }),k.create(\"div\", {\n                    className: \"-cx-PRIVATE-uiDialog__bottomRight\"\n                }),ba,];\n            }\n             else ca = k.create(\"div\", {\n                className: \"-cx-PUBLIC-uiDialog__border\"\n            }, ba);\n        ;\n            this._wrapper = k.create(\"div\", {\n                className: \"-cx-PUBLIC-uiDialog__wrapper\"\n            }, ca);\n            this.setWidth(z.width);\n            var da = \"-cx-PRIVATE-uiDialog__positioner\";\n            if (z.className) {\n                da += (\" \" + z.className);\n            };\n            var ea = k.create(\"div\", {\n                className: da\n            }, this._wrapper);\n            if (z.id) {\n                ea.id = z.id;\n            };\n            return ea;\n        },\n        _getContentRoot: function() {\n            return this._wrapper;\n        },\n        updatePosition: function() {\n            var z = (s.getViewportDimensions().y - s.getElementDimensions(this._wrapper).y), aa;\n            if ((z < 250)) {\n                if ((z > 80)) {\n                    aa = (z / 2);\n                }\n                 else aa = 40;\n            ;\n            }\n             else aa = 125;\n        ;\n            if ((!this._modal && ((!this._ie || (this._ie < 7))))) {\n                if ((aa <= 40)) {\n                    this.enableBehavior(o);\n                }\n                 else this.disableBehavior(o);\n            \n            };\n            if ((this._ie < 7)) {\n                var ba = s.getScrollPosition().y;\n                q.set(this._wrapper, \"top\", ((aa + ba) + \"px\"));\n            }\n             else q.set(this._wrapper, \"margin-top\", (aa + \"px\"));\n        ;\n            if (this._causalElement) {\n                var ca = w(this._causalElement, this.getInsertParent());\n                q.set(this.getRoot(), \"z-index\", ((ca > 200) ? ca : \"\"));\n            }\n        ;\n        },\n        setWidth: function(z) {\n            z = Math.floor(z);\n            if (((this._ie > 6) && (this._ie < 9))) {\n                z -= 20;\n            };\n            q.set(this._wrapper, \"width\", (z + \"px\"));\n        }\n    });\n    function y(z) {\n        this._layer = z;\n    };\n    t(y.prototype, {\n        _subscription: null,\n        _resize: null,\n        enable: function() {\n            this._subscription = this._layer.subscribe([\"show\",\"hide\",], function(z) {\n                if ((z === \"show\")) {\n                    this._attach();\n                    h.inform(\"layer_shown\", {\n                        type: \"DialogX\"\n                    });\n                }\n                 else {\n                    this._detach();\n                    h.inform(\"layer_hidden\", {\n                        type: \"DialogX\"\n                    });\n                }\n            ;\n            }.bind(this));\n        },\n        disable: function() {\n            this._subscription.unsubscribe();\n            this._subscription = null;\n            (this._resize && this._detach());\n        },\n        _attach: function() {\n            this._layer.updatePosition();\n            this._resize = Event.listen(window, \"resize\", v(this._layer.updatePosition.bind(this._layer)));\n        },\n        _detach: function() {\n            this._resize.remove();\n            this._resize = null;\n        }\n    });\n    e.exports = x;\n});\n__d(\"AsyncDialog\", [\"AsyncRequest\",\"Bootloader\",\"copyProperties\",\"CSS\",\"cx\",\"DialogX\",\"DOM\",\"Env\",\"Parent\",\"tx\",\"URI\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncRequest\"), h = b(\"Bootloader\"), i = b(\"copyProperties\"), j = b(\"CSS\"), k = b(\"cx\"), l = b(\"DialogX\"), m = b(\"DOM\"), n = b(\"Env\"), o = b(\"Parent\"), p = b(\"tx\"), q = b(\"URI\"), r = new l({\n        width: 465,\n        className: \"-cx-PRIVATE-uiDialog__loadingDialog\"\n    }, m.create(\"div\", {\n        className: \"-cx-PRIVATE-uiDialog__loadingText\"\n    }, \"Loading...\")), s = 1, t = [], u = 0;\n    function v() {\n        u--;\n        if (!u) {\n            r.hide();\n        };\n    };\n    function w(y, z) {\n        var aa = s++;\n        t[aa] = z;\n        i(y.getData(), {\n            __asyncDialog: aa\n        });\n        var ba = false;\n        u++;\n        r.show();\n        function ca() {\n            if (!ba) {\n                v();\n            };\n        };\n        y.setInterceptHandler(function(da) {\n            ba = true;\n            v();\n        });\n        y.setFinallyHandler(function(da) {\n            var ea = da.getPayload();\n            if ((ea && ea.asyncURL)) {\n                x.send(new g(ea.asyncURL));\n            };\n            ca();\n        });\n        y.setAbortHandler(ca);\n        y.send();\n    };\n    var x = {\n        send: function(y, z) {\n            w(y, (z || bagofholding));\n        },\n        bootstrap: function(y, z, aa) {\n            if (!y) {\n                return\n            };\n            var ba = (o.byClass(z, \"stat_elem\") || z);\n            if ((ba && j.hasClass(ba, \"async_saving\"))) {\n                return false\n            };\n            var ca = new q(y).getQueryData();\n            ca.causal_element = (z ? m.getID(z) : null);\n            var da = (aa === \"dialog\"), ea = new g().setURI(y).setData(ca).setMethod((da ? \"GET\" : \"POST\")).setReadOnly(da).setRelativeTo(z).setStatusElement(ba).setNectarModuleDataSafe(z);\n            if (n.is_desktop) {\n                h.loadModules([\"FbdDialogProvider\",], function(fa) {\n                    fa.sendDialog(ea, x.send);\n                });\n                return;\n            }\n        ;\n            x.send(ea);\n        },\n        respond: function(y, z) {\n            var aa = t[y];\n            if (aa) {\n                aa(z);\n                delete t[y];\n            }\n        ;\n        },\n        getLoadingDialog: function() {\n            return r;\n        }\n    };\n    e.exports = x;\n});\n__d(\"AsyncLayout\", [\"AjaxPipeRequest\",\"Arbiter\",\"AsyncResponse\",\"AsyncRequest\",\"CSS\",\"DOM\",\"HTML\",\"NavigationMessage\",\"PageTransitions\",\"URI\",\"$\",\"copyProperties\",\"ge\",\"goURI\",], function(a, b, c, d, e, f) {\n    var g = b(\"AjaxPipeRequest\"), h = b(\"Arbiter\"), i = b(\"AsyncResponse\"), j = b(\"AsyncRequest\"), k = b(\"CSS\"), l = b(\"DOM\"), m = b(\"HTML\"), n = b(\"NavigationMessage\"), o = b(\"PageTransitions\"), p = b(\"URI\"), q = b(\"$\"), r = b(\"copyProperties\"), s = b(\"ge\"), t = b(\"goURI\");\n    function u(v) {\n        this.canvasID = v;\n        if (s(\"rightCol\")) {\n            this.auxiliaryID = \"rightCol\";\n        };\n        if (s(\"headerArea\")) {\n            this.headerID = \"headerArea\";\n        };\n        if (s(\"toolbarContainer\")) {\n            this.toolbarID = \"toolbarContainer\";\n        };\n        this.waitingForAux = false;\n        o.registerHandler(this.catchPageTransition.bind(this));\n        this.subscription = h.subscribe(n.NAVIGATION_BEGIN, this.onNavigate.bind(this));\n    };\n    r(u.prototype, {\n        catchPageTransition: function(v) {\n            this.subscription.unsubscribe();\n            return false;\n        },\n        getCanvasID: function(v) {\n            return (v.sidecol ? \"contentCol\" : \"contentArea\");\n        },\n        onNavigate: function(v, w) {\n            var x = w.useAjaxPipe;\n            w = w.params;\n            if (w.endpoint) {\n                if (this.request) {\n                    this.request.setFinallyHandler(bagofholding);\n                    this.request.abort();\n                }\n            ;\n                if (this.sideRequest) {\n                    this.sideRequest.abort();\n                };\n                if (x) {\n                    this.request = new g().setURI(w.endpoint).setData(w).setCanvasId(this.getCanvasID(w)).setFinallyHandler(this.finallyHandler.bind(this)).setErrorHandler(this.errorHandler.bind(this)).setFirstResponseCallback(this.firstResponseCallback.bind(this)).send();\n                }\n                 else {\n                    w.handled = true;\n                    this.waitingForAux = w.sidecol;\n                    var y = !!w.iframe, z = new j().setOption(\"useIframeTransport\", y).setURI(new p(w.endpoint)).setReadOnly(true).setMethod(\"GET\").setData(w).setHandler(this.onResponse.bind(this)).setErrorHandler(this.errorHandler.bind(this)).setFinallyHandler(this.finallyHandler.bind(this));\n                    this.request = z;\n                    z.send();\n                }\n            ;\n            }\n        ;\n        },\n        onSideResponse: function(v) {\n            var w = v.getPayload();\n            if ((w && this.auxiliaryID)) {\n                this.receivedAux(w);\n            };\n        },\n        receivedAux: function(v) {\n            !this.waitingForAux;\n            this.waitingForAux = false;\n            l.setContent(q(this.auxiliaryID), m(v));\n        },\n        onResponse: function(v) {\n            var w = v.getPayload();\n            if (w.redirect) {\n                t(w.redirect);\n            }\n             else {\n                var x = (w.html || w);\n                l.setContent(q(this.canvasID), m(x));\n                if ((w.side_html && this.auxiliaryID)) {\n                    this.receivedAux(w.side_html);\n                };\n                if ((this.headerID && !w.keep_header)) {\n                    var y = q(this.headerID);\n                    l.setContent(y, m((w.header_html || \"\")));\n                    k.conditionShow(y, w.header_html);\n                }\n            ;\n                if ((w.toolbar_html && this.toolbarID)) {\n                    l.setContent(q(this.toolbarID), m(w.toolbar_html));\n                };\n                if (w.js) {\n                    (new Function(w.js))();\n                };\n                k.conditionClass(\"contentCol\", \"hasRightCol\", (this.auxiliaryID && !w.noRightSide));\n                var z = s(\"rightCol\");\n                if ((z && w.noRightSide)) {\n                    l.empty(z);\n                };\n            }\n        ;\n            var aa = v.getRequest().getData();\n            h.inform(n.NAVIGATION_COMPLETED, aa.key);\n        },\n        errorHandler: function(v) {\n            i.verboseErrorHandler(v);\n            h.inform(n.NAVIGATION_FAILED);\n            this.request = null;\n        },\n        firstResponseCallback: function(v) {\n            window.scrollTo(0, 0);\n            h.inform(n.NAVIGATION_FIRST_RESPONSE);\n        },\n        finallyHandler: function(v) {\n            this.request = null;\n            o.transitionComplete(true);\n            h.inform(n.NAVIGATION_COMPLETED);\n        }\n    });\n    e.exports = u;\n});\n__d(\"ContextualLayer\", [\"array-extensions\",\"event-extensions\",\"Arbiter\",\"ARIA\",\"Class\",\"ContextualThing\",\"CSS\",\"DataStore\",\"DOM\",\"Layer\",\"LayerHideOnTransition\",\"Locale\",\"Parent\",\"Style\",\"Vector\",\"copyProperties\",\"getOverlayZIndex\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ARIA\"), i = b(\"Class\"), j = b(\"ContextualThing\"), k = b(\"CSS\"), l = b(\"DataStore\"), m = b(\"DOM\"), n = b(\"Layer\"), o = b(\"LayerHideOnTransition\"), p = b(\"Locale\"), q = b(\"Parent\"), r = b(\"Style\"), s = b(\"Vector\"), t = b(\"copyProperties\"), u = b(\"getOverlayZIndex\");\n    function v(aa) {\n        return ((aa.getPosition() === \"left\") || ((aa.isVertical() && (aa.getAlignment() === \"right\"))));\n    };\n    function w(aa) {\n        var ba = aa.offsetParent;\n        if (((ba === document.body) && (r.get(ba, \"position\") === \"static\"))) {\n            ba = document.documentElement;\n        };\n        return ba;\n    };\n    function x(aa, ba) {\n        this.parent.construct(this, aa, ba);\n    };\n    var y = [];\n    g.subscribe(\"reflow\", function() {\n        y.forEach(function(aa) {\n            if ((aa.updatePosition() === false)) {\n                aa.hide();\n            };\n        });\n    });\n    i.extend(x, n);\n    t(x.prototype, {\n        _contentWrapper: null,\n        _content: null,\n        _contextNode: null,\n        _contextSelector: null,\n        _parentLayer: null,\n        _parentSubscription: null,\n        _orientation: null,\n        _orientationClass: null,\n        _configure: function(aa, ba) {\n            this.parent._configure(aa, ba);\n            if (aa.context) {\n                this.setContext(aa.context);\n            }\n             else if (aa.contextID) {\n                this._setContextID(aa.contextID);\n            }\n             else if (aa.contextSelector) {\n                this._setContextSelector(aa.contextSelector);\n            }\n            \n        ;\n            (aa.position && this.setPosition(aa.position));\n            (aa.alignment && this.setAlignment(aa.alignment));\n            (aa.offsetX && this.setOffsetX(aa.offsetX));\n            (aa.offsetY && this.setOffsetY(aa.offsetY));\n            this._content = ba;\n        },\n        _getDefaultBehaviors: function() {\n            return this.parent._getDefaultBehaviors().concat([o,]);\n        },\n        _buildWrapper: function(aa, ba) {\n            this._contentWrapper = m.create(\"div\", {\n                className: \"uiContextualLayer\"\n            }, ba);\n            return m.create(\"div\", {\n                className: \"uiContextualLayerPositioner\"\n            }, this._contentWrapper);\n        },\n        getInsertParent: function() {\n            var aa = this._insertParent;\n            if (!aa) {\n                var ba = this.getContext();\n                if (ba) {\n                    aa = q.byClass(ba, \"uiContextualLayerParent\");\n                };\n            }\n        ;\n            return (aa || this.parent.getInsertParent());\n        },\n        setContent: function(aa) {\n            this._content = aa;\n            m.setContent(this._contentWrapper, this._content);\n            (this._shown && this.updatePosition());\n            return this;\n        },\n        setContext: function(aa) {\n            this._contextNode = aa;\n            this._contextSelector = this._contextScrollParent = null;\n            if (this._shown) {\n                j.register(this.getRoot(), this._contextNode);\n                this.updatePosition();\n            }\n        ;\n            this._setParentSubscription();\n            h.setPopup(this.getCausalElement(), this.getRoot());\n            return this;\n        },\n        _setContextID: function(aa) {\n            this._contextSelector = (\"#\" + aa);\n            this._contextNode = null;\n        },\n        _setContextSelector: function(aa) {\n            this._contextSelector = aa;\n            this._contextNode = null;\n        },\n        getCausalElement: function() {\n            return (this.parent.getCausalElement() || this.getContext());\n        },\n        _setParentSubscription: function() {\n            var aa = this.getContext(), ba = null;\n            while ((aa !== null)) {\n                ba = l.get(aa, \"layer\");\n                if (ba) {\n                    break;\n                };\n                aa = aa.parentNode;\n            };\n            if ((ba === this._parentLayer)) {\n                return\n            };\n            if ((this._parentLayer && this._parentSubscription)) {\n                this._parentLayer.unsubscribe(this._parentSubscription);\n                this._parentSubscription = null;\n            }\n        ;\n            if (ba) {\n                this._parentSubscription = ba.subscribe(\"hide\", this.hide.bind(this));\n            };\n            this._parentLayer = ba;\n        },\n        setPosition: function(aa) {\n            this._getOrientation().setDefaultPosition(aa);\n            (this._shown && this.updatePosition());\n            return this;\n        },\n        setAlignment: function(aa) {\n            this._getOrientation().setDefaultAlignment(aa);\n            (this._shown && this.updatePosition());\n            return this;\n        },\n        setOffsetX: function(aa) {\n            this._getOrientation().setDefaultOffsetX(aa);\n            (this._shown && this.updatePosition());\n            return this;\n        },\n        setOffsetY: function(aa) {\n            this._getOrientation().setDefaultOffsetY(aa);\n            (this._shown && this.updatePosition());\n            return this;\n        },\n        _getOrientation: function() {\n            if (!this._orientation) {\n                this._orientation = new z();\n            };\n            return this._orientation;\n        },\n        _getContentRoot: function() {\n            return this._contentWrapper;\n        },\n        getContent: function() {\n            return this._content;\n        },\n        getContext: function() {\n            if (!this._contextNode) {\n                this._contextNode = m.find(document, this._contextSelector);\n            };\n            return this._contextNode;\n        },\n        getContextScrollParent: function() {\n            if (!this._contextScrollParent) {\n                this._contextScrollParent = r.getScrollParent(this.getContext());\n            };\n            return this._contextScrollParent;\n        },\n        setInsertParent: function(aa) {\n            this._insertScrollParent = null;\n            return this.parent.setInsertParent(aa);\n        },\n        getInsertScrollParent: function() {\n            if (!this._insertScrollParent) {\n                this._insertScrollParent = r.getScrollParent(this.getInsertParent());\n            };\n            return this._insertScrollParent;\n        },\n        show: function() {\n            this.parent.show();\n            if (this._shown) {\n                j.register(this.getRoot(), this.getContext());\n                y.push(this);\n                this._resizeListener = (this._resizeListener || Event.listen(window, \"resize\", this.updatePosition.bind(this)));\n            }\n        ;\n            return this;\n        },\n        hide: function() {\n            j.remove(this.getRoot());\n            y.remove(this);\n            (this._resizeListener && this._resizeListener.remove());\n            this._resizeListener = null;\n            return this.parent.hide();\n        },\n        updatePosition: function() {\n            var aa = this.getContext();\n            if (!aa) {\n                return false\n            };\n            var ba = (r.isFixed(aa) && !r.isFixed(this.getInsertParent()));\n            if ((!ba && !aa.offsetParent)) {\n                return false\n            };\n            var ca = this._getOrientation();\n            this.inform(\"adjust\", ca.reset());\n            if (!ca.isValid()) {\n                return false\n            };\n            this._updateWrapperPosition(ca);\n            this._updateWrapperClass(ca);\n            var da = this.getRoot();\n            k.conditionClass(da, \"uiContextualLayerPositionerFixed\", ba);\n            var ea, fa, ga = (ba ? \"viewport\" : \"document\"), ha = (ba ? document.documentElement : w(da));\n            if ((ha === document.documentElement)) {\n                ea = new s(0, 0);\n                fa = document.documentElement.clientWidth;\n            }\n             else if (!ha) {\n                return false;\n            }\n             else {\n                ea = s.getElementPosition(ha, ga);\n                fa = ha.offsetWidth;\n                if ((ha !== document.body)) {\n                    ea = ea.sub(new s(ha.scrollLeft, ha.scrollTop));\n                };\n            }\n            \n        ;\n            var ia = s.getElementPosition(aa, ga), ja = (ia.x - ea.x), ka = (ia.y - ea.y), la = p.isRTL();\n            if ((ca.getPosition() === \"below\")) {\n                ka += aa.offsetHeight;\n            };\n            if (((((ca.getPosition() === \"right\") || ((ca.isVertical() && (ca.getAlignment() === \"right\"))))) != la)) {\n                ja += aa.offsetWidth;\n            };\n            var ma = ca.getOffsetX();\n            if ((ca.isVertical() && (ca.getAlignment() === \"center\"))) {\n                ma += (((aa.offsetWidth - this._content.offsetWidth)) / 2);\n            };\n            if (la) {\n                ma *= -1;\n            };\n            var na = \"left\", oa = (ja + ma);\n            if ((v(ca) !== la)) {\n                na = \"right\";\n                oa = (fa - oa);\n            }\n        ;\n            r.set(da, na, (oa + \"px\"));\n            r.set(da, ((na === \"left\") ? \"right\" : \"left\"), \"\");\n            var pa = this.getInsertScrollParent(), qa;\n            if ((pa !== window)) {\n                qa = pa.clientWidth;\n            }\n             else qa = document.documentElement.clientWidth;\n        ;\n            var ra = s.getElementPosition(da).x;\n            if ((na === \"left\")) {\n                if (((qa - ra) > 0)) {\n                    r.set(da, \"width\", (((qa - ra)) + \"px\"));\n                }\n                 else r.set(da, \"width\", \"\");\n            ;\n            }\n             else r.set(da, \"width\", ((ra + da.offsetWidth) + \"px\"));\n        ;\n            r.set(da, \"top\", (((ka + ca.getOffsetY())) + \"px\"));\n            var sa = u(aa, this.getInsertParent());\n            r.set(da, \"z-index\", ((sa > 200) ? sa : \"\"));\n            this.inform(\"reposition\", ca);\n            return true;\n        },\n        _updateWrapperPosition: function(aa) {\n            var ba = (aa.getPosition() === \"above\");\n            r.set(this._contentWrapper, \"bottom\", (ba ? \"0\" : null));\n            var ca = (p.isRTL() ? \"left\" : \"right\"), da = v(aa);\n            r.set(this._contentWrapper, ca, (da ? \"0\" : null));\n        },\n        _updateWrapperClass: function(aa) {\n            var ba = aa.getClassName();\n            if ((ba === this._orientationClass)) {\n                return\n            };\n            if (this._orientationClass) {\n                k.removeClass(this._contentWrapper, this._orientationClass);\n            };\n            this._orientationClass = ba;\n            k.addClass(this._contentWrapper, ba);\n        },\n        simulateOrientation: function(aa, ba) {\n            var ca = aa.getClassName();\n            if ((ca === this._orientationClass)) {\n                return ba();\n            }\n             else {\n                if (this._orientationClass) {\n                    k.removeClass(this._contentWrapper, this._orientationClass);\n                };\n                k.addClass(this._contentWrapper, ca);\n                var da = ba();\n                k.removeClass(this._contentWrapper, ca);\n                if (this._orientationClass) {\n                    k.addClass(this._contentWrapper, this._orientationClass);\n                };\n                return da;\n            }\n        ;\n        },\n        destroy: function() {\n            this.parent.destroy();\n            this._contentWrapper = null;\n            this._content = null;\n            return this;\n        }\n    });\n    function z() {\n        this._default = {\n            _position: \"above\",\n            _alignment: \"left\",\n            _offsetX: 0,\n            _offsetY: 0,\n            _valid: true\n        };\n        this.reset();\n    };\n    z.OPPOSITE = {\n        above: \"below\",\n        below: \"above\",\n        left: \"right\",\n        right: \"left\"\n    };\n    t(z.prototype, {\n        setPosition: function(aa) {\n            this._position = aa;\n            return this;\n        },\n        setAlignment: function(aa) {\n            this._alignment = aa;\n            return this;\n        },\n        getOppositePosition: function() {\n            return z.OPPOSITE[this.getPosition()];\n        },\n        invalidate: function() {\n            this._valid = false;\n            return this;\n        },\n        getPosition: function() {\n            return (this._position || \"above\");\n        },\n        getAlignment: function() {\n            return (this._alignment || \"left\");\n        },\n        getOffsetX: function() {\n            var aa = (this._offsetX || 0);\n            if (!this.isVertical()) {\n                if ((this._default._position !== this._position)) {\n                    aa *= -1;\n                };\n            }\n             else if ((this._default._alignment !== this._alignment)) {\n                aa *= -1;\n            }\n        ;\n            return aa;\n        },\n        getOffsetY: function() {\n            var aa = (this._offsetY || 0);\n            if ((this.isVertical() && (this._default._position !== this._position))) {\n                aa *= -1;\n            };\n            return aa;\n        },\n        getClassName: function() {\n            var aa = this.getAlignment(), ba = this.getPosition();\n            if ((ba === \"below\")) {\n                if ((aa === \"left\")) {\n                    return \"uiContextualLayerBelowLeft\";\n                }\n                 else if ((aa === \"right\")) {\n                    return \"uiContextualLayerBelowRight\";\n                }\n                 else return \"uiContextualLayerBelowCenter\"\n                \n            ;\n            }\n             else if ((ba === \"above\")) {\n                if ((aa === \"left\")) {\n                    return \"uiContextualLayerAboveLeft\";\n                }\n                 else if ((aa === \"right\")) {\n                    return \"uiContextualLayerAboveRight\";\n                }\n                 else return \"uiContextualLayerAboveCenter\"\n                \n            ;\n            }\n             else if ((ba === \"left\")) {\n                return \"uiContextualLayerLeft\";\n            }\n             else return \"uiContextualLayerRight\"\n            \n            \n        ;\n        },\n        isValid: function() {\n            return this._valid;\n        },\n        isVertical: function() {\n            return ((this.getPosition() === \"above\") || (this.getPosition() === \"below\"));\n        },\n        reset: function(aa, ba) {\n            t(this, this._default);\n            return this;\n        },\n        setDefaultPosition: function(aa) {\n            this._default._position = aa;\n            return this;\n        },\n        setDefaultAlignment: function(aa) {\n            this._default._alignment = aa;\n            return this;\n        },\n        setDefaultOffsetX: function(aa) {\n            this._default._offsetX = aa;\n            return this;\n        },\n        setDefaultOffsetY: function(aa) {\n            this._default._offsetY = aa;\n            return this;\n        }\n    });\n    e.exports = x;\n});\n__d(\"KeyStatus\", [\"event-extensions\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = null, h = null;\n    function i() {\n        if (!h) {\n            h = Event.listen(window, \"blur\", function() {\n                g = null;\n                j();\n            });\n        };\n    };\n    function j() {\n        if (h) {\n            h.remove();\n            h = null;\n        }\n    ;\n    };\n    Event.listen(document.documentElement, \"keydown\", function(l) {\n        g = Event.getKeyCode(l);\n        i();\n    }, Event.Priority.URGENT);\n    Event.listen(document.documentElement, \"keyup\", function(l) {\n        g = null;\n        j();\n    }, Event.Priority.URGENT);\n    var k = {\n        isKeyDown: function() {\n            return !!g;\n        },\n        getKeyDownCode: function() {\n            return g;\n        }\n    };\n    e.exports = k;\n});\n__d(\"Menu\", [\"event-extensions\",\"Arbiter\",\"CSS\",\"DataStore\",\"DOM\",\"HTML\",\"Keys\",\"Parent\",\"Run\",\"Style\",\"UserAgent\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"CSS\"), i = b(\"DataStore\"), j = b(\"DOM\"), k = b(\"HTML\"), l = b(\"Keys\"), m = b(\"Parent\"), n = b(\"Run\"), o = b(\"Style\"), p = b(\"UserAgent\"), q = b(\"copyProperties\"), r = null, s = \"menu:mouseover\", t = null;\n    function u(ca) {\n        if (h.hasClass(ca, \"uiMenuContainer\")) {\n            return ca\n        };\n        return m.byClass(ca, \"uiMenu\");\n    };\n    function v(ca) {\n        return m.byClass(ca, \"uiMenuItem\");\n    };\n    function w(ca) {\n        if (document.activeElement) {\n            var da = v(document.activeElement);\n            return ca.indexOf(da);\n        }\n    ;\n        return -1;\n    };\n    function x(ca) {\n        return j.find(ca, \"a.itemAnchor\");\n    };\n    function y(ca) {\n        return h.hasClass(ca, \"checked\");\n    };\n    function z(ca) {\n        return (!h.hasClass(ca, \"disabled\") && (o.get(ca, \"display\") !== \"none\"));\n    };\n    function aa(event) {\n        var ca = document.activeElement;\n        if (((!ca || !m.byClass(ca, \"uiMenu\")) || !j.isNodeOfType(ca, [\"input\",\"textarea\",]))) {\n            var da = v(event.getTarget());\n            (da && r.focusItem(da));\n        }\n    ;\n    };\n    function ba(ca) {\n        (p.firefox() && x(ca).blur());\n        r.inform(\"select\", {\n            menu: u(ca),\n            item: ca\n        });\n    };\n    n.onLoad(function() {\n        var ca = {\n        };\n        ca.click = function(event) {\n            var da = v(event.getTarget());\n            if ((da && z(da))) {\n                ba(da);\n                var ea = x(da), fa = ea.href, ga = ea.getAttribute(\"rel\");\n                return (((ga && (ga !== \"ignore\"))) || ((fa && (fa.charAt((fa.length - 1)) !== \"#\"))));\n            }\n        ;\n        };\n        ca.keydown = function(event) {\n            var da = event.getTarget();\n            if (event.getModifiers().any) {\n                return\n            };\n            if ((!t || j.isNodeOfType(da, [\"input\",\"textarea\",]))) {\n                return\n            };\n            var ea = Event.getKeyCode(event), fa;\n            switch (ea) {\n              case l.UP:\n            \n              case l.DOWN:\n                var ga = r.getEnabledItems(t);\n                fa = w(ga);\n                r.focusItem(ga[(fa + (((ea === l.UP) ? -1 : 1)))]);\n                return false;\n              case l.SPACE:\n                var ha = v(da);\n                if (ha) {\n                    ba(ha);\n                    event.prevent();\n                }\n            ;\n                break;\n              default:\n                var ia = String.fromCharCode(ea).toLowerCase(), ja = r.getEnabledItems(t);\n                fa = w(ja);\n                var ka = fa, la = ja.length;\n                while ((((~fa && ((ka = (++ka \u0025 la)) !== fa))) || ((!~fa && (++ka < la))))) {\n                    var ma = r.getItemLabel(ja[ka]);\n                    if ((ma && (ma.charAt(0).toLowerCase() === ia))) {\n                        r.focusItem(ja[ka]);\n                        return false;\n                    }\n                ;\n                };\n            };\n        };\n        Event.listen(document.documentElement, ca);\n    });\n    r = e.exports = q(new g(), {\n        focusItem: function(ca) {\n            if ((ca && z(ca))) {\n                this._removeSelected(u(ca));\n                h.addClass(ca, \"selected\");\n                x(ca).focus();\n            }\n        ;\n        },\n        getEnabledItems: function(ca) {\n            return r.getItems(ca).filter(z);\n        },\n        getCheckedItems: function(ca) {\n            return r.getItems(ca).filter(y);\n        },\n        getItems: function(ca) {\n            return j.scry(ca, \"li.uiMenuItem\");\n        },\n        getItemLabel: function(ca) {\n            return (ca.getAttribute(\"data-label\", 2) || \"\");\n        },\n        isItemChecked: function(ca) {\n            return h.hasClass(ca, \"checked\");\n        },\n        register: function(ca, da) {\n            ca = u(ca);\n            if (!i.get(ca, s)) {\n                i.set(ca, s, Event.listen(ca, \"mouseover\", aa));\n            };\n            if ((da !== false)) {\n                t = ca;\n            };\n        },\n        setItemEnabled: function(ca, da) {\n            if ((!da && !j.scry(ca, \"span.disabledAnchor\")[0])) {\n                j.appendContent(ca, j.create(\"span\", {\n                    className: (j.find(ca, \"a\").className + \" disabledAnchor\")\n                }, k(x(ca).innerHTML)));\n            };\n            h.conditionClass(ca, \"disabled\", !da);\n        },\n        toggleItem: function(ca) {\n            var da = !r.isItemChecked(ca);\n            r.setItemChecked(ca, da);\n        },\n        setItemChecked: function(ca, da) {\n            h.conditionClass(ca, \"checked\", da);\n            x(ca).setAttribute(\"aria-checked\", da);\n        },\n        unregister: function(ca) {\n            ca = u(ca);\n            var da = i.remove(ca, s);\n            (da && da.remove());\n            t = null;\n            this._removeSelected(ca);\n        },\n        _removeSelected: function(ca) {\n            r.getItems(ca).filter(function(da) {\n                return h.hasClass(da, \"selected\");\n            }).forEach(function(da) {\n                h.removeClass(da, \"selected\");\n            });\n        }\n    });\n});\n__d(\"ContextualLayerDimensions\", [\"DOM\",\"Locale\",\"Rect\",\"Vector\",\"ViewportBounds\",\"ge\",\"getOverlayZIndex\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"Locale\"), i = b(\"Rect\"), j = b(\"Vector\"), k = b(\"ViewportBounds\"), l = b(\"ge\"), m = b(\"getOverlayZIndex\"), n = {\n        getViewportRect: function(o) {\n            var p = l(\"globalContainer\"), q = o.getContext(), r = (((p && g.contains(p, q))) || (m(q) < 300)), s = i.getViewportBounds();\n            if (r) {\n                s.t += k.getTop();\n                if (h.isRTL()) {\n                    s.l += k.getRight();\n                }\n                 else s.r -= k.getRight();\n            ;\n            }\n        ;\n            return s;\n        },\n        getLayerRect: function(o, p) {\n            var q = o.getContext(), r = j.getElementPosition(q, \"viewport\"), s = o.simulateOrientation(p, function() {\n                return j.getElementDimensions(o.getContent());\n            }), t = (r.y + p.getOffsetY());\n            if ((p.getPosition() === \"above\")) {\n                t -= s.y;\n            }\n             else if ((p.getPosition() === \"below\")) {\n                t += q.offsetHeight;\n            }\n        ;\n            var u = (r.x + p.getOffsetX());\n            if (p.isVertical()) {\n                var v = p.getAlignment();\n                if ((v === \"center\")) {\n                    u += (((q.offsetWidth - s.x)) / 2);\n                }\n                 else if ((((v === \"right\")) !== h.isRTL())) {\n                    u += (q.offsetWidth - s.x);\n                }\n            ;\n            }\n             else if ((((p.getPosition() === \"right\")) !== h.isRTL())) {\n                u += q.offsetWidth;\n            }\n             else u -= s.x;\n            \n        ;\n            return new i(t, (u + s.x), (t + s.y), u, \"viewport\");\n        }\n    };\n    e.exports = n;\n});\n__d(\"ContextualLayerAutoFlip\", [\"array-extensions\",\"event-extensions\",\"ContextualLayerDimensions\",\"DOM\",\"Vector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    var g = b(\"ContextualLayerDimensions\"), h = b(\"DOM\"), i = b(\"Vector\"), j = b(\"copyProperties\");\n    function k(l) {\n        this._layer = l;\n    };\n    j(k.prototype, {\n        _subscription: null,\n        enable: function() {\n            this._subscription = this._layer.subscribe(\"adjust\", this._adjustOrientation.bind(this));\n            if (this._layer.isShown()) {\n                this._layer.updatePosition();\n            };\n        },\n        disable: function() {\n            this._subscription.unsubscribe();\n            this._subscription = null;\n            if (this._layer.isShown()) {\n                this._layer.updatePosition();\n            };\n        },\n        _adjustOrientation: function(l, m) {\n            var n = this._getValidPositions(m);\n            if (!n.length) {\n                m.invalidate();\n                return;\n            }\n        ;\n            var o = g.getViewportRect(this._layer), p = this._getValidAlignments(m);\n            for (var q = 0; (q < p.length); q++) {\n                m.setAlignment(p[q]);\n                for (var r = 0; (r < n.length); r++) {\n                    m.setPosition(n[r]);\n                    var s = g.getLayerRect(this._layer, m);\n                    if (o.contains(s)) {\n                        return\n                    };\n                };\n            };\n            m.setPosition((n.contains(\"below\") ? \"below\" : n[0])).setAlignment(p[0]);\n        },\n        _getValidPositions: function(l) {\n            var m = [l.getPosition(),l.getOppositePosition(),], n = this._layer.getContextScrollParent();\n            if (((n === window) || (n === h.getDocumentScrollElement()))) {\n                return m\n            };\n            var o = this._layer.getContext(), p = i.getElementPosition(n, \"viewport\").y, q = i.getElementPosition(o, \"viewport\").y;\n            if (l.isVertical()) {\n                return m.filter(function(s) {\n                    if ((s === \"above\")) {\n                        return (q >= p);\n                    }\n                     else {\n                        var t = (p + n.offsetHeight), u = (q + o.offsetHeight);\n                        return (u <= t);\n                    }\n                ;\n                });\n            }\n             else {\n                var r = (p + n.offsetHeight);\n                if (((q >= p) && ((q + o.offsetHeight) <= r))) {\n                    return m;\n                }\n                 else return []\n            ;\n            }\n        ;\n        },\n        _getValidAlignments: function(l) {\n            var m = [\"left\",\"center\",\"right\",], n = l.getAlignment(), o = m.indexOf(n);\n            if ((o > 0)) {\n                m.splice(o, 1);\n                m.unshift(n);\n            }\n        ;\n            return m;\n        }\n    });\n    e.exports = k;\n});\n__d(\"Tooltip\", [\"event-extensions\",\"ARIA\",\"AsyncRequest\",\"copyProperties\",\"ContextualLayer\",\"ContextualLayerAutoFlip\",\"CSS\",\"DataStore\",\"DOM\",\"Style\",\"URI\",\"tx\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ARIA\"), h = b(\"AsyncRequest\"), i = b(\"copyProperties\"), j = b(\"ContextualLayer\"), k = b(\"ContextualLayerAutoFlip\"), l = b(\"CSS\"), m = b(\"DataStore\"), n = b(\"DOM\"), o = b(\"Style\"), p = b(\"URI\"), q = b(\"tx\"), r = null, s = null, t = null, u = [];\n    function v() {\n        if (!s) {\n            t = n.create(\"div\", {\n                className: \"tooltipContent\"\n            });\n            var ca = n.create(\"i\", {\n                className: \"arrow\"\n            }), da = n.create(\"div\", {\n                className: \"uiTooltipX\"\n            }, [t,ca,]);\n            s = new j({\n            }, da);\n            s.enableBehavior(k);\n        }\n    ;\n    };\n    function w(ca) {\n        return i({\n            position: (ca.getAttribute(\"data-tooltip-position\") || \"above\"),\n            alignH: (ca.getAttribute(\"data-tooltip-alignh\") || \"left\")\n        }, m.get(ca, \"tooltip\"));\n    };\n    function x(ca, da) {\n        var ea = w(ca);\n        m.set(ca, \"tooltip\", {\n            content: (da.content || ea.content),\n            position: (da.position || ea.position),\n            alignH: (da.alignH || ea.alignH)\n        });\n        ca.setAttribute(\"data-hover\", \"tooltip\");\n    };\n    function y(ca, da) {\n        ba.set(ca, \"Loading...\");\n        new h(da).setHandler(function(ea) {\n            ba.set(ca, ea.getPayload());\n        }).setErrorHandler(bagofholding).send();\n    };\n    var z = /(\\r\\n|[\\r\\n])/;\n    function aa(ca) {\n        return ca.split(z).map(function(da) {\n            return (z.test(da) ? n.create(\"br\") : da);\n        });\n    };\n    var ba = {\n        process: function(ca, da) {\n            if (!n.contains(ca, da)) {\n                return\n            };\n            if ((ca !== r)) {\n                var ea = ca.getAttribute(\"data-tooltip-uri\");\n                if (ea) {\n                    ca.removeAttribute(\"data-tooltip-uri\");\n                    y(ca, ea);\n                }\n            ;\n                var fa = ca.getAttribute(\"title\");\n                if (fa) {\n                    ca.setAttribute(\"title\", \"\");\n                    var ga = w(ca);\n                    (!ga.content && ba.set(ca, fa));\n                }\n            ;\n                ba.show(ca);\n            }\n        ;\n        },\n        remove: function(ca) {\n            m.remove(ca, \"tooltip\");\n            ca.removeAttribute(\"data-hover\");\n            ca.removeAttribute(\"data-tooltip-position\");\n            ca.removeAttribute(\"data-tooltip-alignh\");\n            ((ca === r) && ba.hide());\n        },\n        hide: function() {\n            if (r) {\n                s.hide();\n                r = null;\n                while (u.length) {\n                    u.pop().remove();;\n                };\n            }\n        ;\n        },\n        set: function(ca, da, ea, fa) {\n            if ((ea || fa)) {\n                x(ca, {\n                    position: ea,\n                    alignH: fa\n                });\n            };\n            if ((da instanceof p)) {\n                if ((ca === r)) {\n                    y(ca, da);\n                }\n                 else ca.setAttribute(\"data-tooltip-uri\", da);\n            ;\n            }\n             else {\n                if ((typeof da !== \"string\")) {\n                    da = n.create(\"div\", {\n                    }, da);\n                };\n                x(ca, {\n                    content: da\n                });\n                ((ca === r) && ba.show(ca));\n            }\n        ;\n        },\n        show: function(ca) {\n            v();\n            ba.hide();\n            var da = w(ca);\n            if (!da.content) {\n                return\n            };\n            var ea = 0, fa = 0;\n            if (((da.position === \"left\") || (da.position === \"right\"))) {\n                fa = (((ca.offsetHeight - 20)) / 2);\n            }\n             else if ((da.alignH !== \"center\")) {\n                var ga = ca.offsetWidth;\n                if ((ga < 18)) {\n                    ea = ((((ga - 18)) / 2) * (((da.alignH === \"right\") ? -1 : 1)));\n                };\n            }\n            \n        ;\n            s.setContext(ca).setOffsetX(ea).setOffsetY(fa).setPosition(da.position).setAlignment(da.alignH);\n            if ((typeof da.content === \"string\")) {\n                l.addClass(s, \"invisible_elem\");\n                var ha = n.create(\"span\", {\n                }, aa(da.content)), ia = n.create(\"div\", {\n                    className: \"tooltipText\"\n                }, ha);\n                n.setContent(t, ia);\n                s.show();\n                g.notify(da.content);\n                if ((ia.offsetWidth < ha.offsetWidth)) {\n                    l.addClass(ia, \"tooltipWrap\");\n                    s.updatePosition();\n                }\n            ;\n                l.removeClass(s, \"invisible_elem\");\n            }\n             else {\n                n.setContent(t, da.content);\n                s.show();\n                g.notify(n.getText(t));\n            }\n        ;\n            var ja = function(la) {\n                if (!n.contains(r, la.getTarget())) {\n                    ba.hide();\n                };\n            };\n            u.push(Event.listen(document.documentElement, \"mouseover\", ja));\n            u.push(Event.listen(document.documentElement, \"focusin\", ja));\n            var ka = o.getScrollParent(ca);\n            if ((ka !== window)) {\n                u.push(Event.listen(ka, \"scroll\", ba.hide));\n            };\n            u.push(Event.listen(ca, \"click\", ba.hide));\n            r = ca;\n        }\n    };\n    Event.listen(window, \"scroll\", ba.hide);\n    e.exports = ba;\n});\n__d(\"Selector\", [\"event-extensions\",\"Arbiter\",\"Button\",\"ContextualLayer\",\"copyProperties\",\"CSS\",\"DataStore\",\"DOM\",\"HTML\",\"Input\",\"Keys\",\"KeyStatus\",\"Menu\",\"Parent\",\"Style\",\"Toggler\",\"Tooltip\",\"Vector\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"Button\"), i = b(\"ContextualLayer\"), j = b(\"copyProperties\"), k = b(\"CSS\"), l = b(\"DataStore\"), m = b(\"DOM\"), n = b(\"HTML\"), o = b(\"Input\"), p = b(\"Keys\"), q = b(\"KeyStatus\"), r = b(\"Menu\"), s = b(\"Parent\"), t = b(\"Style\"), u = b(\"Toggler\"), v = b(\"Tooltip\"), w = b(\"Vector\"), x, y, z = [], aa;\n    function ba(ma) {\n        return s.byClass(ma, \"uiSelector\");\n    };\n    function ca(ma) {\n        return s.byClass(ma, \"uiSelectorButton\");\n    };\n    function da() {\n        if (!y) {\n            y = new i({\n                position: \"below\"\n            }, m.create(\"div\"));\n            k.addClass(y.getRoot(), \"uiSelectorContextualLayer\");\n        }\n    ;\n        return y;\n    };\n    function ea(ma) {\n        return m.scry(ma, \"select\")[0];\n    };\n    function fa(ma) {\n        return m.find(ma, \"div.uiSelectorMenuWrapper\");\n    };\n    function ga() {\n        ga = bagofholding;\n        r.subscribe(\"select\", function(ma, na) {\n            if (((!x || !na) || (na.menu !== la.getSelectorMenu(x)))) {\n                return\n            };\n            var oa = ha(x), pa = ia(na.item);\n            if (pa) {\n                var qa = x, ra = la.isOptionSelected(na.item), sa = la.inform(\"select\", {\n                    selector: qa,\n                    option: na.item,\n                    clone: aa\n                });\n                if ((sa === false)) {\n                    return\n                };\n                if ((oa || !ra)) {\n                    la.setSelected(qa, la.getOptionValue(na.item), !ra);\n                    la.inform(\"toggle\", {\n                        selector: qa,\n                        option: na.item\n                    });\n                    la.inform(\"change\", {\n                        selector: qa\n                    });\n                    g.inform(\"Form/change\", {\n                        node: qa\n                    });\n                    if (ja(qa)) {\n                        l.set(qa, \"dirty\", true);\n                    };\n                }\n            ;\n            }\n        ;\n            if ((!oa || !pa)) {\n                (x && la.toggle(x));\n            };\n        });\n    };\n    function ha(ma) {\n        return !!ma.getAttribute(\"data-multiple\");\n    };\n    function ia(ma) {\n        return k.hasClass(ma, \"uiSelectorOption\");\n    };\n    function ja(ma) {\n        return !!ma.getAttribute(\"data-autosubmit\");\n    };\n    var ka = {\n        keydown: function(event) {\n            var ma = event.getTarget();\n            if (m.isNodeOfType(ma, [\"input\",\"textarea\",])) {\n                return\n            };\n            switch (Event.getKeyCode(event)) {\n              case p.DOWN:\n            \n              case p.SPACE:\n            \n              case p.UP:\n                if (ca(ma)) {\n                    var na = ba(ma);\n                    la.toggle(na);\n                    return false;\n                }\n            ;\n                break;\n              case p.ESC:\n                if (x) {\n                    la.toggle(x);\n                    return false;\n                }\n            ;\n                break;\n            };\n        },\n        mouseover: function(event) {\n            var ma = s.byAttribute(event.getTarget(), \"ajaxify\");\n            if ((ma && k.hasClass(ma, \"uiSelectorButton\"))) {\n                la.loadMenu(ba(ma));\n            };\n        }\n    };\n    Event.listen(document.documentElement, ka);\n    u.subscribe([\"show\",\"hide\",], function(ma, na) {\n        var oa = ba(na.getActive());\n        if (oa) {\n            ga();\n            var pa = la.getSelectorButton(oa), qa = la.getSelectorMenu(oa), ra = (ma === \"show\");\n            pa.setAttribute(\"aria-expanded\", (ra ? \"true\" : \"false\"));\n            if (ra) {\n                x = oa;\n                if (k.hasClass(pa, \"uiButtonDisabled\")) {\n                    la.setEnabled(oa, false);\n                    return false;\n                }\n            ;\n                qa = (qa || la.loadMenu(oa));\n                var sa = t.getScrollParent(oa), ta = ((sa !== window) && (sa !== m.getDocumentScrollElement()));\n                if ((ta || k.hasClass(oa, \"uiSelectorUseLayer\"))) {\n                    if (ta) {\n                        z.push(Event.listen(sa, \"scroll\", function() {\n                            na.hide();\n                        }));\n                    };\n                    aa = m.create(\"div\", {\n                        className: oa.className\n                    });\n                    k.addClass(aa, \"invisible_elem\");\n                    w.getElementDimensions(oa).setElementDimensions(aa);\n                    m.replace(oa, aa);\n                    var ua = k.hasClass(oa, \"uiSelectorRight\"), va = k.hasClass(oa, \"uiSelectorBottomUp\");\n                    da().setContext(aa).setContent(oa).setPosition((va ? \"above\" : \"below\")).setAlignment((ua ? \"right\" : \"left\")).show();\n                }\n            ;\n                r.register(qa);\n                if (q.isKeyDown()) {\n                    var wa = r.getCheckedItems(qa);\n                    if (!wa.length) {\n                        wa = r.getEnabledItems(qa);\n                    };\n                    r.focusItem(wa[0]);\n                }\n            ;\n            }\n             else {\n                x = null;\n                if (aa) {\n                    while (z.length) {\n                        z.pop().remove();;\n                    };\n                    m.replace(aa, oa);\n                    da().hide();\n                    aa = null;\n                }\n            ;\n                (qa && r.unregister(qa));\n                if ((ja(oa) && l.get(oa, \"dirty\"))) {\n                    var xa = m.scry(oa, \"input.submitButton\")[0];\n                    (xa && xa.click());\n                    l.remove(oa, \"dirty\");\n                }\n            ;\n            }\n        ;\n            k.conditionClass(la.getSelectorButton(oa), \"selected\", ra);\n            la.inform((ra ? \"open\" : \"close\"), {\n                selector: oa,\n                clone: aa\n            });\n        }\n    ;\n    });\n    var la = j(new g(), {\n        attachMenu: function(ma, na, oa) {\n            ma = ba(ma);\n            if (ma) {\n                (x && r.unregister(la.getSelectorMenu(x)));\n                m.setContent(fa(ma), na);\n                (x && r.register(la.getSelectorMenu(ma)));\n                (aa && da().updatePosition());\n                if (oa) {\n                    var pa = ma.getAttribute(\"data-name\");\n                    (pa && oa.setAttribute(\"name\", pa));\n                    if (!ha(ma)) {\n                        oa.setAttribute(\"multiple\", false);\n                    };\n                    var qa = ea(ma);\n                    if (qa) {\n                        m.replace(qa, oa);\n                    }\n                     else m.insertAfter(ma.firstChild, oa);\n                ;\n                }\n            ;\n                return true;\n            }\n        ;\n        },\n        getOption: function(ma, na) {\n            var oa = la.getOptions(ma), pa = oa.length;\n            while (pa--) {\n                if ((na === la.getOptionValue(oa[pa]))) {\n                    return oa[pa]\n                };\n            };\n            return null;\n        },\n        getOptions: function(ma) {\n            var na = r.getItems(la.getSelectorMenu(ma));\n            return na.filter(ia);\n        },\n        getEnabledOptions: function(ma) {\n            var na = r.getEnabledItems(la.getSelectorMenu(ma));\n            return na.filter(ia);\n        },\n        getSelectedOptions: function(ma) {\n            return r.getCheckedItems(la.getSelectorMenu(ma));\n        },\n        getOptionText: function(ma) {\n            return r.getItemLabel(ma);\n        },\n        getOptionValue: function(ma) {\n            var na = ba(ma), oa = ea(na), pa = la.getOptions(na).indexOf(ma);\n            return ((pa >= 0) ? oa.options[(pa + 1)].value : \"\");\n        },\n        getSelectorButton: function(ma) {\n            return m.find(ma, \"a.uiSelectorButton\");\n        },\n        getSelectorMenu: function(ma) {\n            return m.scry(ma, \"div.uiSelectorMenu\")[0];\n        },\n        getValue: function(ma) {\n            var na = ea(ma);\n            if (!na) {\n                return null\n            };\n            if (!ha(ma)) {\n                return na.value\n            };\n            var oa = [], pa = na.options;\n            for (var qa = 1, ra = pa.length; (qa < ra); qa++) {\n                if (pa[qa].selected) {\n                    oa.push(pa[qa].value);\n                };\n            };\n            return oa;\n        },\n        isOptionSelected: function(ma) {\n            return r.isItemChecked(ma);\n        },\n        listen: function(ma, na, oa) {\n            return this.subscribe(na, function(pa, qa) {\n                if ((qa.selector === ma)) {\n                    return oa(qa, pa)\n                };\n            });\n        },\n        loadMenu: function(ma) {\n            var na = la.getSelectorMenu(ma);\n            if (!na) {\n                var oa = la.getSelectorButton(ma), pa = oa.getAttribute(\"ajaxify\");\n                if (pa) {\n                    d([\"AsyncRequest\",], function(ra) {\n                        ra.bootstrap(pa, oa);\n                    });\n                    var qa = n(((((((\"\\u003Cdiv class=\\\"uiSelectorMenuWrapper uiToggleFlyout\\\"\\u003E\" + \"\\u003Cdiv class=\\\"uiMenu uiSelectorMenu loading\\\"\\u003E\") + \"\\u003Cul class=\\\"uiMenuInner\\\"\\u003E\") + \"\\u003Cli\\u003E\\u003Cspan\\u003E\\u003C/span\\u003E\\u003C/li\\u003E\") + \"\\u003C/ul\\u003E\") + \"\\u003C/div\\u003E\") + \"\\u003C/div\\u003E\"));\n                    m.appendContent(oa.parentNode, qa);\n                    na = la.getSelectorMenu(ma);\n                    oa.removeAttribute(\"onmouseover\");\n                }\n            ;\n            }\n        ;\n            return na;\n        },\n        setButtonLabel: function(ma, na) {\n            var oa = la.getSelectorButton(ma), pa = parseInt(oa.getAttribute(\"data-length\"), 10);\n            na = ((na || oa.getAttribute(\"data-label\")) || \"\");\n            h.setLabel(oa, na);\n            if ((typeof na === \"string\")) {\n                k.conditionClass(oa, \"uiSelectorBigButtonLabel\", (na.length > pa));\n                if ((pa && (na.length > pa))) {\n                    oa.setAttribute(\"title\", na);\n                }\n                 else oa.removeAttribute(\"title\");\n            ;\n            }\n        ;\n        },\n        setButtonTooltip: function(ma, na) {\n            var oa = la.getSelectorButton(ma), pa = s.byTag(oa, \"a\");\n            (pa && v.set(pa, ((na || oa.getAttribute(\"data-tooltip\")) || \"\")));\n        },\n        updateButtonARIALabel: function(ma, na) {\n            var oa = la.getSelectorButton(ma), pa = s.byTag(oa, \"a\");\n            if (pa) {\n                var qa = oa.getAttribute(\"data-ariaprefix\");\n                if (qa) {\n                    oa.setAttribute(\"aria-label\", ((qa + \": \") + na));\n                };\n            }\n        ;\n        },\n        setEnabled: function(ma, na) {\n            if (((!na && x) && (ba(ma) === x))) {\n                la.toggle(ma);\n            };\n            h.setEnabled(la.getSelectorButton(ma), na);\n        },\n        setOptionEnabled: function(ma, na) {\n            r.setItemEnabled(ma, na);\n        },\n        setSelected: function(ma, na, oa) {\n            oa = (oa !== false);\n            var pa = la.getOption(ma, na);\n            if (!pa) {\n                return\n            };\n            var qa = la.isOptionSelected(pa);\n            if ((oa !== qa)) {\n                if ((!ha(ma) && !qa)) {\n                    var ra = la.getSelectedOptions(ma)[0];\n                    (ra && r.toggleItem(ra));\n                }\n            ;\n                r.toggleItem(pa);\n            }\n        ;\n            la.updateSelector(ma);\n        },\n        toggle: function(ma) {\n            u.toggle(m.scry(ba(ma), \"div.wrap\")[0]);\n        },\n        updateSelector: function(ma) {\n            var na = la.getOptions(ma), oa = la.getSelectedOptions(ma), pa = ea(ma).options, qa = [], ra = [];\n            for (var sa = 0, ta = na.length; (sa < ta); sa++) {\n                var ua = oa.contains(na[sa]);\n                pa[(sa + 1)].selected = ua;\n                if (ua) {\n                    var va = la.getOptionText(na[sa]);\n                    qa.push(va);\n                    ra.push((na[sa].getAttribute(\"data-tooltip\") || va));\n                }\n            ;\n            };\n            pa[0].selected = !oa.length;\n            var wa = k.hasClass(ma, \"uiSelectorDynamicLabel\"), xa = k.hasClass(ma, \"uiSelectorDynamicTooltip\");\n            if ((wa || xa)) {\n                var ya = \"\";\n                if (ha(ma)) {\n                    var za = la.getSelectorButton(ma);\n                    ya = (za.getAttribute(\"data-delimiter\") || \", \");\n                }\n            ;\n                qa = qa.join(ya);\n                ra = ra.join(ya);\n                if (wa) {\n                    la.setButtonLabel(ma, qa);\n                    la.updateButtonARIALabel(ma, qa);\n                }\n            ;\n                (xa && la.setButtonTooltip(ma, ra));\n            }\n        ;\n        }\n    });\n    e.exports = la;\n});\n__d(\"DynamicIconSelector\", [\"Button\",\"CSS\",\"DOM\",\"Selector\",], function(a, b, c, d, e, f) {\n    var g = b(\"Button\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"Selector\"), k = {\n        swapIcon: function(l) {\n            var m = j.getSelectedOptions(l)[0], n = (m && i.scry(m, \".itemIcon\")[0]), o = j.getSelectorButton(l);\n            if (n) {\n                g.setIcon(o, n.cloneNode(true));\n            }\n             else {\n                var p = i.scry(o, \".img\")[0];\n                (p && i.remove(p));\n            }\n        ;\n            h.conditionClass(o, \"uiSelectorChevronOnly\", !n);\n        }\n    };\n    j.subscribe(\"change\", function(l, m) {\n        var n = m.selector;\n        if (h.hasClass(n, \"dynamicIconSelector\")) {\n            k.swapIcon(n);\n        };\n    });\n    e.exports = k;\n});\n__d(\"AudienceSelector\", [\"Arbiter\",\"CSS\",\"DOM\",\"DynamicIconSelector\",\"PrivacyConst\",\"Selector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"DynamicIconSelector\"), k = b(\"PrivacyConst\"), l = b(\"Selector\"), m = b(\"copyProperties\");\n    l.subscribe(\"select\", function(p, q) {\n        if (!h.hasClass(q.selector, \"audienceSelector\")) {\n            return\n        };\n        var r = l.getOptionValue(q.option);\n        g.inform(\"AudienceSelector/changed\", q);\n        if (((r == k.BaseValue.CUSTOM) && !h.hasClass(q.option, \"noDialog\"))) {\n            l.toggle(q.selector);\n            return false;\n        }\n    ;\n        if (h.hasClass(q.selector, \"dataTooltip\")) {\n            var s = i.find(q.option, \".itemAnchor\").getAttribute(\"data-tooltip\");\n            l.setButtonTooltip(q.selector, (s || null));\n        }\n    ;\n        if (!h.hasClass(q.option, \"specialOption\")) {\n            return\n        };\n        var t = i.find(q.option, \"a\").getAttribute(\"data-type\");\n        if (h.hasClass(q.option, \"moreOption\")) {\n            h.addClass(q.selector, t);\n            h.addClass(q.selector, \"showSecondaryOptions\");\n            return false;\n        }\n         else if (h.hasClass(q.option, \"returnOption\")) {\n            h.removeClass(q.selector, \"showSecondaryOptions\");\n            h.removeClass(q.selector, \"friendList\");\n            return false;\n        }\n        \n    ;\n    });\n    var n = {\n    }, o = {\n        hasTags: function(p) {\n            return n.hasOwnProperty(p);\n        },\n        setHasTags: function(p) {\n            if (!p) {\n                return\n            };\n            n[p] = true;\n        }\n    };\n    g.subscribe(\"CustomPrivacyOption/update\", function(p, q) {\n        if (!h.hasClass(q.selector, \"audienceSelector\")) {\n            return\n        };\n        l.setSelected(q.selector, l.getOptionValue(q.option));\n        j.swapIcon(q.selector);\n        l.setButtonTooltip(q.selector, q.tooltip);\n        g.inform(\"AudienceSelector/update\", q.selector);\n    });\n    e.exports = o;\n});\n__d(\"ContextualDialogArrow\", [\"CSS\",\"DOM\",\"Locale\",\"Style\",\"Vector\",\"copyProperties\",\"cx\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"Locale\"), j = b(\"Style\"), k = b(\"Vector\"), l = b(\"copyProperties\"), m = b(\"cx\"), n = 15, o = 16, p = {\n        bottom: \"-cx-PRIVATE-uiContextualDialog__arrowBottom\",\n        top: \"-cx-PRIVATE-uiContextualDialog__arrowTop\",\n        right: \"-cx-PRIVATE-uiContextualDialog__arrowRight\",\n        left: \"-cx-PRIVATE-uiContextualDialog__arrowLeft\"\n    }, q = {\n        above: \"bottom\",\n        below: \"top\",\n        left: \"right\",\n        right: \"left\"\n    };\n    function r(s) {\n        this._layer = s;\n    };\n    l(r.prototype, {\n        _subscription: null,\n        _arrow: null,\n        enable: function() {\n            this._subscription = this._layer.subscribe([\"adjust\",\"reposition\",], this._handle.bind(this));\n        },\n        disable: function() {\n            this._subscription.unsubscribe();\n            this._subscription = null;\n        },\n        _handle: function(s, t) {\n            if ((s === \"adjust\")) {\n                this._repositionArrow(t);\n            }\n             else this._repositionRoot(t);\n        ;\n        },\n        _repositionRoot: function(s) {\n            var t = this._layer.getRoot();\n            if (!s.isVertical()) {\n                var u = parseInt(j.get(t, \"top\"), 10);\n                u -= n;\n                j.set(t, \"top\", (u + \"px\"));\n            }\n        ;\n        },\n        _repositionArrow: function(s) {\n            var t = this._layer._contentWrapper, u = 0, v = s.getAlignment(), w = s.getPosition();\n            if (((w == \"above\") || (w == \"below\"))) {\n                if ((v == \"center\")) {\n                    u = 50;\n                }\n                 else if ((v == \"right\")) {\n                    u = 100;\n                }\n            \n            };\n            var x = q[w];\n            for (var y in p) {\n                g.conditionClass(t, p[y], (x === y));;\n            };\n            if ((w == \"none\")) {\n                return\n            };\n            if (!this._arrow) {\n                this._arrow = this._drawArrow();\n                h.appendContent(t, this._arrow);\n            }\n        ;\n            g.conditionClass(t, \"-cx-PRIVATE-uiContextualDialog__withFooter\", this._layer.getFooter());\n            j.set(this._arrow, \"top\", \"\");\n            j.set(this._arrow, \"left\", \"\");\n            j.set(this._arrow, \"right\", \"\");\n            j.set(this._arrow, \"margin\", \"\");\n            var z = ((x == \"top\") || (x == \"bottom\")), aa = (z ? ((i.isRTL() ? \"right\" : \"left\")) : \"top\");\n            u = (u || 0);\n            j.set(this._arrow, aa, (u + \"\u0025\"));\n            var ba = (o + ((n * 2))), ca = n;\n            if ((z && ((v != \"center\")))) {\n                var da = this._layer.getContext(), ea = k.getElementDimensions(da).x;\n                if ((ea < ba)) {\n                    ca = Math.max((((ea / 2)) - ((o / 2))), 0);\n                };\n            }\n        ;\n            j.set(this._arrow, (\"margin-\" + aa), (-((((ba * u) / 100) - ca)) + \"px\"));\n        },\n        _drawArrow: function() {\n            return h.create(\"i\", {\n                className: \"-cx-PRIVATE-uiContextualDialog__arrow\"\n            });\n        }\n    });\n    r.OFFSET = n;\n    r.LENGTH = o;\n    e.exports = r;\n});\n__d(\"ContextualDialogFitInViewport\", [\"event-extensions\",\"ContextualDialogArrow\",\"ContextualLayerDimensions\",\"Style\",\"Vector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ContextualDialogArrow\"), h = b(\"ContextualLayerDimensions\"), i = b(\"Style\"), j = b(\"Vector\"), k = b(\"copyProperties\"), l = g.OFFSET, m = g.LENGTH, n = (l + m);\n    function o(p) {\n        this._layer = p;\n    };\n    k(o.prototype, {\n        _scrollListener: null,\n        _subscription: null,\n        _minimumTop: null,\n        enable: function() {\n            this._subscription = this._layer.subscribe([\"show\",\"hide\",\"reposition\",], function(p, q) {\n                if ((p == \"reposition\")) {\n                    this._calculateMinimumTop(q);\n                }\n                 else if ((p == \"show\")) {\n                    this._attachScroll();\n                    this._adjustForScroll();\n                }\n                 else this._detachScroll();\n                \n            ;\n            }.bind(this));\n            if (this._layer.isShown()) {\n                this._attachScroll();\n            };\n        },\n        disable: function() {\n            if (this._layer.isShown()) {\n                this._detachScroll();\n            };\n            this._subscription.unsubscribe();\n            this._subscription = null;\n        },\n        _attachScroll: function() {\n            this._scrollListener = Event.listen((this._layer.getContextScrollParent() || window), \"scroll\", this._adjustForScroll.bind(this));\n        },\n        _detachScroll: function() {\n            this._scrollListener.remove();\n            this._scrollListener = null;\n        },\n        _getContentHeight: function() {\n            return j.getElementDimensions(this._layer._contentWrapper).y;\n        },\n        _getContextY: function() {\n            return j.getElementPosition(this._layer.getContext()).y;\n        },\n        _calculateMinimumTop: function(p) {\n            if (p.isVertical()) {\n                return\n            };\n            this._minimumTop = (((this._getContextY() - ((this._getContentHeight() - n))) + p.getOffsetY()));\n        },\n        _adjustForScroll: function() {\n            var p = this._layer._getOrientation();\n            if (p.isVertical()) {\n                return\n            };\n            var q = h.getViewportRect(this._layer), r = (q.b - this._minimumTop);\n            if ((r < 0)) {\n                return\n            };\n            var s = this._getContentHeight(), t = (s - ((n + l))), u = Math.max(0, Math.min(t, (t - ((r - s)))));\n            i.set(this._layer.getContent(), \"top\", (-u + \"px\"));\n        }\n    });\n    e.exports = o;\n});\n__d(\"ContextualDialog\", [\"AccessibleLayer\",\"Class\",\"ContextualDialogFitInViewport\",\"ContextualLayer\",\"CSS\",\"DOM\",\"LayerButtons\",\"LayerFormHooks\",\"LayerMouseHooks\",\"Style\",\"copyProperties\",\"csx\",\"cx\",], function(a, b, c, d, e, f) {\n    var g = b(\"AccessibleLayer\"), h = b(\"Class\"), i = b(\"ContextualDialogFitInViewport\"), j = b(\"ContextualLayer\"), k = b(\"CSS\"), l = b(\"DOM\"), m = b(\"LayerButtons\"), n = b(\"LayerFormHooks\"), o = b(\"LayerMouseHooks\"), p = b(\"Style\"), q = b(\"copyProperties\"), r = b(\"csx\"), s = b(\"cx\");\n    function t(u, v) {\n        this.parent.construct(this, u, v);\n    };\n    h.extend(t, j);\n    q(t.prototype, {\n        _footer: null,\n        _configure: function(u, v) {\n            u.addedBehaviors.push(u.arrowBehavior);\n            var w = l.scry(v, \"div.-cx-PRIVATE-uiContextualDialog__footer\");\n            if (w.length) {\n                this._footer = w[0];\n            };\n            this.parent._configure(u, v);\n        },\n        _getDefaultBehaviors: function() {\n            return this.parent._getDefaultBehaviors().concat([g,i,m,n,o,]);\n        },\n        _buildWrapper: function(u, v) {\n            k.addClass(v, \"-cx-PRIVATE-uiContextualDialog__content\");\n            var w = this.parent._buildWrapper(u, v);\n            k.addClass(this._contentWrapper, \"-cx-PRIVATE-uiContextualDialog__wrapper\");\n            if (u.width) {\n                this.setWidth(u.width);\n            };\n            return w;\n        },\n        setWidth: function(u) {\n            this._width = Math.floor(u);\n            p.set(this._contentWrapper, \"width\", (u + \"px\"));\n            return this;\n        },\n        getFooter: function() {\n            return this._footer;\n        }\n    });\n    q(t, {\n        setContext: function(u, v) {\n            u.setContext(v);\n        }\n    });\n    e.exports = t;\n});\n__d(\"ContextualLayerHideOnScroll\", [\"event-extensions\",\"Class\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Class\"), h = b(\"copyProperties\");\n    function i(j) {\n        this._layer = j;\n    };\n    h(i.prototype, {\n        _subscriptions: [],\n        enable: function() {\n            this._subscriptions = [this._layer.subscribe(\"contextchange\", this._handleContextChange.bind(this)),this._layer.subscribe(\"show\", this.attach.bind(this)),this._layer.subscribe(\"hide\", this.detach.bind(this)),];\n        },\n        disable: function() {\n            while (this._subscriptions.length) {\n                this._subscriptions.pop().unsubscribe();;\n            };\n            this.detach();\n        },\n        attach: function() {\n            if (this._listener) {\n                return\n            };\n            var j = this._layer.getContextScrollParent();\n            if ((j === window)) {\n                return\n            };\n            this._listener = Event.listen(j, \"scroll\", this._layer.hide.bind(this._layer));\n        },\n        detach: function() {\n            (this._listener && this._listener.remove());\n            this._listener = null;\n        },\n        _handleContextChange: function() {\n            this.detach();\n            if (this._layer.isShown()) {\n                this.attach();\n            };\n        }\n    });\n    e.exports = i;\n});\n__d(\"ContextualLayerUpdateOnScroll\", [\"event-extensions\",\"Class\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Class\"), h = b(\"copyProperties\");\n    function i(j) {\n        this._layer = j;\n    };\n    h(i.prototype, {\n        _subscriptions: [],\n        enable: function() {\n            this._subscriptions = [this._layer.subscribe(\"show\", this._attachScrollListener.bind(this)),this._layer.subscribe(\"hide\", this._removeScrollListener.bind(this)),];\n        },\n        disable: function() {\n            while (this._subscriptions.length) {\n                this._subscriptions.pop().unsubscribe();;\n            };\n            this.detach();\n        },\n        _attachScrollListener: function() {\n            if (this._listener) {\n                return\n            };\n            var j = this._layer.getContextScrollParent();\n            this._listener = Event.listen(j, \"scroll\", this._layer.updatePosition.bind(this._layer));\n        },\n        _removeScrollListener: function() {\n            (this._listener && this._listener.remove());\n            this._listener = null;\n        }\n    });\n    e.exports = i;\n});\n__d(\"BasicTypeaheadRenderer\", [\"DOM\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\");\n    function h(i, j) {\n        var k = [];\n        if (i.icon) {\n            k.push(g.create(\"img\", {\n                alt: \"\",\n                src: i.icon\n            }));\n        };\n        if (i.text) {\n            k.push(g.create(\"span\", {\n                className: \"text\"\n            }, [i.text,]));\n        };\n        if (i.subtext) {\n            k.push(g.create(\"span\", {\n                className: \"subtext\"\n            }, [i.subtext,]));\n        };\n        var l = g.create(\"li\", {\n            className: (i.type || \"\")\n        }, k);\n        l.setAttribute(\"role\", \"option\");\n        if (i.text) {\n            l.setAttribute(\"aria-label\", i.text);\n        };\n        return l;\n    };\n    h.className = \"basic\";\n    e.exports = h;\n});\n__d(\"TypeaheadView\", [\"event-extensions\",\"ArbiterMixin\",\"ARIA\",\"BasicTypeaheadRenderer\",\"Class\",\"CSS\",\"DOM\",\"Parent\",\"$\",\"copyProperties\",\"ge\",\"tx\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"ARIA\"), i = b(\"BasicTypeaheadRenderer\"), j = b(\"Class\"), k = b(\"CSS\"), l = b(\"DOM\"), m = b(\"Parent\"), n = b(\"$\"), o = b(\"copyProperties\"), p = b(\"ge\"), q = b(\"tx\");\n    function r(s, t) {\n        this.element = this.content = n(s);\n        o(this, t);\n    };\n    o(r.prototype, g, {\n        events: [\"highlight\",\"render\",\"reset\",\"select\",\"beforeRender\",\"next\",\"prev\",],\n        renderer: i,\n        autoSelect: false,\n        accessibleResultsText: \"Autocomplete results are available. Use the up and down arrow keys to navigate the results.\",\n        accessibleEmptyText: \"No autocomplete results are available.\",\n        ignoreMouseover: false,\n        init: function() {\n            this.init = bagofholding;\n            this.initializeEvents();\n            this.reset();\n        },\n        initializeEvents: function() {\n            Event.listen(this.element, {\n                mouseup: this.mouseup.bind(this),\n                mouseover: this.mouseover.bind(this)\n            });\n        },\n        setTypeahead: function(s) {\n            this.typeahead = s;\n        },\n        getElement: function() {\n            return this.element;\n        },\n        mouseup: function(event) {\n            if ((event.button != 2)) {\n                this.select(true);\n                event.kill();\n            }\n        ;\n        },\n        mouseover: function(event) {\n            if (this.ignoreMouseover) {\n                this.ignoreMouseover = false;\n                return;\n            }\n        ;\n            if (this.visible) {\n                this.highlight(this.getIndex(event));\n            };\n        },\n        reset: function(s) {\n            if (!s) {\n                this.disableAutoSelect = false;\n            };\n            this.justRendered = false;\n            this.justShown = false;\n            this.index = -1;\n            this.items = [];\n            this.results = [];\n            this.value = \"\";\n            this.content.innerHTML = \"\";\n            this.inform(\"reset\");\n            return this;\n        },\n        getIndex: function(event) {\n            return this.items.indexOf(m.byTag(event.getTarget(), \"li\"));\n        },\n        getSelection: function() {\n            var s = (this.results[this.index] || null);\n            return (this.visible ? s : null);\n        },\n        isEmpty: function() {\n            return !this.results.length;\n        },\n        isVisible: function() {\n            return this.visible;\n        },\n        show: function() {\n            k.show(this.element);\n            if ((this.results && this.results.length)) {\n                if (this.autoSelect) {\n                    h.notify(q._(\"{name} is auto-selected. Use the up and down arrow keys to navigate more results.\", {\n                        name: this.getItemText(this.selected)\n                    }));\n                }\n                 else h.notify(this.accessibleResultsText);\n            \n            };\n            (this.typeahead && this.element.setAttribute(\"aria-expanded\", \"true\"));\n            this.visible = true;\n            return this;\n        },\n        hide: function() {\n            k.hide(this.element);\n            h.notify(\"\");\n            (this.typeahead && this.typeahead.setAttribute(\"aria-expanded\", \"false\"));\n            this.visible = false;\n            return this;\n        },\n        render: function(s, t, u) {\n            this.value = s;\n            if (!t.length) {\n                if ((this.results.length && s)) {\n                    h.notify(this.accessibleEmptyText);\n                };\n                this.reset(true);\n                return;\n            }\n        ;\n            this.justRendered = true;\n            if (!this.results.length) {\n                this.justShown = true;\n                if (((!this.autoSelect && this.isVisible()) && t.length)) {\n                    h.notify(this.accessibleResultsText);\n                };\n            }\n        ;\n            var v = {\n                results: t,\n                value: s\n            };\n            this.inform(\"beforeRender\", v);\n            t = v.results;\n            var w = this.getDefaultIndex(t);\n            if (((this.index > 0) && (this.index !== this.getDefaultIndex(this.results)))) {\n                var x = this.results[this.index];\n                for (var y = 0, z = t.length; (y < z); ++y) {\n                    if ((x.uid == t[y].uid)) {\n                        w = y;\n                        break;\n                    }\n                ;\n                };\n            }\n        ;\n            this.results = t;\n            l.setContent(this.content, this.buildResults(t));\n            this.items = this.getItems();\n            this.highlight(w, false);\n            this.inform(\"render\", t);\n        },\n        getItems: function() {\n            return l.scry(this.content, \"li\");\n        },\n        buildResults: function(s) {\n            var t, u = null;\n            if ((typeof this.renderer == \"function\")) {\n                t = this.renderer;\n                u = (this.renderer.className || \"\");\n            }\n             else {\n                t = a.TypeaheadRenderers[this.renderer];\n                u = this.renderer;\n            }\n        ;\n            t = t.bind(this);\n            var v = s.map(function(x, y) {\n                return (x.node || t(x, y));\n            }), w = l.create(\"ul\", {\n                className: u,\n                id: (\"typeahead_list_\" + ((this.typeahead ? l.getID(this.typeahead) : l.getID(this.element))))\n            }, v);\n            w.setAttribute(\"role\", \"listbox\");\n            return w;\n        },\n        getDefaultIndex: function(s) {\n            var t = ((this.autoSelect && !this.disableAutoSelect));\n            return (((this.index < 0) && !t) ? -1 : 0);\n        },\n        next: function() {\n            this.highlight((this.index + 1));\n            this.inform(\"next\", this.selected);\n        },\n        prev: function() {\n            this.highlight((this.index - 1));\n            this.inform(\"prev\", this.selected);\n        },\n        getItemText: function(s) {\n            var t = \"\";\n            if (s) {\n                t = s.getAttribute(\"aria-label\");\n                if (!t) {\n                    t = l.getText(s);\n                    s.setAttribute(\"aria-label\", t);\n                }\n            ;\n            }\n        ;\n            return t;\n        },\n        setIsViewingSelectedItems: function(s) {\n            this.viewingSelected = s;\n            return this;\n        },\n        getIsViewingSelectedItems: function() {\n            return this.viewingSelected;\n        },\n        highlight: function(s, t) {\n            var u = true;\n            (this.selected && k.removeClass(this.selected, \"selected\"));\n            if ((s > (this.items.length - 1))) {\n                s = -1;\n            }\n             else if ((s < -1)) {\n                s = (this.items.length - 1);\n            }\n        ;\n            if (((s >= 0) && (s < this.items.length))) {\n                if ((this.selected && (this.getItemText(this.items[s]) === this.getItemText(this.selected)))) {\n                    u = false;\n                };\n                this.selected = this.items[s];\n                k.addClass(this.selected, \"selected\");\n            }\n        ;\n            this.index = s;\n            this.disableAutoSelect = ((s == -1));\n            var v = ((s !== -1)), w = this.getItemText(this.selected);\n            if (((((s !== -1) && this.isVisible()) && w) && this.autoSelect)) {\n                if (this.justShown) {\n                    h.notify(q._(\"{name} is auto-selected. Use the up and down arrow keys to navigate more results.\", {\n                        name: w\n                    }));\n                    this.justRendered = false;\n                    this.justShown = false;\n                    v = false;\n                }\n                 else if ((u && this.justRendered)) {\n                    h.notify(q._(\"{name} is auto-selected.\", {\n                        name: w\n                    }));\n                    this.justRendered = false;\n                    v = false;\n                }\n                \n            \n            };\n            if ((u && v)) {\n                h.announce(w);\n            };\n            if ((t !== false)) {\n                this.inform(\"highlight\", {\n                    index: s,\n                    selected: this.results[s],\n                    element: this.selected\n                });\n            };\n        },\n        select: function(s) {\n            var t = this.index, u = this.results[t];\n            if (u) {\n                this.inform(\"select\", {\n                    index: t,\n                    clicked: !!s,\n                    selected: u\n                });\n                this.inform(\"afterSelect\");\n            }\n        ;\n        }\n    });\n    e.exports = r;\n});\n__d(\"BucketedTypeaheadView\", [\"Class\",\"DOM\",\"TypeaheadView\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Class\"), h = b(\"DOM\"), i = b(\"TypeaheadView\"), j = b(\"copyProperties\");\n    function k(l, m) {\n        this.parent.construct(this, l, m);\n    };\n    g.extend(k, i);\n    j(k.prototype, {\n        render: function(l, m, n) {\n            m = this.buildBuckets(l, m);\n            return this.parent.render(l, m, n);\n        },\n        highlight: function(l, m) {\n            if (((l == -1) && (this.index !== 0))) {\n                l = this.index;\n            };\n            if ((((l >= 0) && (l < this.items.length)) && (this.results[l].type == \"header\"))) {\n                l = (l + 1);\n            };\n            this.parent.highlight(l, m);\n        },\n        buildBuckets: function(l, m) {\n            if (!this.typeObjects) {\n                return m\n            };\n            var n = [], o = {\n            };\n            for (var p = 0; (p < m.length); ++p) {\n                var q = m[p], r = (q.render_type || q.type);\n                if (!o.hasOwnProperty(r)) {\n                    o[r] = n.length;\n                    n.push([this.buildBucketHeader(r),]);\n                }\n            ;\n                q.classNames = r;\n                q.groupIndex = o[r];\n                q.indexInGroup = (n[q.groupIndex].length - 1);\n                n[q.groupIndex].push(q);\n            };\n            var s = [];\n            for (var t = 0; (t < n.length); ++t) {\n                s = s.concat(n[t]);;\n            };\n            return s;\n        },\n        buildBucketHeader: function(l) {\n            var m = this.typeObjects[l];\n            if (m.markup) {\n                m.text = m.markup;\n                delete m.markup;\n            }\n        ;\n            return this.typeObjects[l];\n        },\n        buildResults: function(l) {\n            var m = this.parent.buildResults(l);\n            if (this.typeObjects) {\n                return h.create(\"div\", {\n                    className: \"bucketed\"\n                }, [m,]);\n            }\n             else return m\n        ;\n        },\n        select: function(l) {\n            var m = this.results[this.index];\n            if ((m && (m.type != \"header\"))) {\n                this.parent.select(l);\n            };\n        },\n        getDefaultIndex: function(l) {\n            var m = ((this.autoSelect && !this.disableAutoSelect)), n = ((l.length === 0) ? -1 : (((l[0].type == \"header\") ? 1 : 0)));\n            return (((this.index < 0) && !m) ? -1 : n);\n        },\n        prev: function() {\n            var l = this.results[(this.index - 1)];\n            if ((l && (l.type == \"header\"))) {\n                this.index--;\n            };\n            return this.parent.prev();\n        },\n        next: function() {\n            var l = this.results[(this.index + 1)];\n            if ((l && (l.type == \"header\"))) {\n                this.index++;\n            };\n            return this.parent.next();\n        }\n    });\n    e.exports = k;\n});\n__d(\"ContextualTypeaheadView\", [\"event-extensions\",\"Class\",\"ContextualLayer\",\"ContextualLayerAutoFlip\",\"ContextualLayerHideOnScroll\",\"CSS\",\"DOM\",\"Style\",\"BucketedTypeaheadView\",\"Vector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Class\"), h = b(\"ContextualLayer\"), i = b(\"ContextualLayerAutoFlip\"), j = b(\"ContextualLayerHideOnScroll\"), k = b(\"CSS\"), l = b(\"DOM\"), m = b(\"Style\"), n = b(\"BucketedTypeaheadView\"), o = b(\"Vector\"), p = b(\"copyProperties\");\n    function q(r, s) {\n        this.parent.construct(this, r, s);\n    };\n    g.extend(q, n);\n    p(q.prototype, {\n        init: function() {\n            this.initializeLayer();\n            this.parent.init();\n        },\n        initializeLayer: function() {\n            this.context = this.getContext();\n            this.wrapper = l.create(\"div\");\n            l.appendContent(this.wrapper, this.element);\n            k.addClass(this.element, \"uiContextualTypeaheadView\");\n            this.layer = new h({\n                context: this.context,\n                position: \"below\",\n                causalElement: this.causalElement\n            }, this.wrapper);\n            this.layer.enableBehavior(j);\n            if (m.isFixed(this.context)) {\n                this.layer.enableBehavior(i);\n            };\n            this.subscribe(\"render\", this.renderLayer.bind(this));\n        },\n        show: function() {\n            this.layer.show();\n            o.getElementDimensions(this.context).setElementWidth(this.wrapper);\n            return this.parent.show();\n        },\n        hide: function() {\n            this.layer.hide();\n            return this.parent.hide();\n        },\n        renderLayer: function() {\n            if (!this.isVisible()) {\n                return\n            };\n            if (this.layer.isShown()) {\n                this.layer.updatePosition();\n            }\n             else this.layer.show();\n        ;\n        },\n        getContext: function() {\n            return this.element.parentNode;\n        }\n    });\n    e.exports = q;\n});\n__d(\"CustomPrivacyOption\", [\"event-extensions\",\"AsyncRequest\",\"Dialog\",\"DOM\",\"Form\",\"Parent\",\"Selector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"AsyncRequest\"), h = b(\"Dialog\"), i = b(\"DOM\"), j = b(\"Form\"), k = b(\"Parent\"), l = b(\"Selector\"), m = b(\"copyProperties\");\n    function n() {\n    \n    };\n    m(n, {\n        _instances: {\n        },\n        update: function(o, p, q, r) {\n            var s = n._instances[o];\n            s._update(p, q)._updateOption(q, r);\n            Arbiter.inform(\"Form/change\", {\n                node: s._container\n            });\n        },\n        getData: function(o) {\n            return n._instances[o]._privacyData;\n        }\n    });\n    m(n.prototype, {\n        init: function(o, p, q, r, s) {\n            (function() {\n                var t = this.initCustomState(o, p);\n                if (!t) {\n                    return\n                };\n                Event.listen(t, \"click\", function(event) {\n                    this.openCustomDialog(event, o, q, s);\n                }.bind(this));\n                this._initSelector(t, r);\n            }).bind(this).defer();\n        },\n        _initSelector: function(o, p) {\n            this._selector = k.byClass(o, \"uiSelector\");\n            l.listen(this._selector, \"select\", function(q) {\n                if ((q.option._id != this._id)) {\n                    this.clearCustomState();\n                };\n            }.bind(this));\n            if (p) {\n                l.setButtonTooltip(this._selector, p);\n            };\n        },\n        _updateOption: function(o, p) {\n            var q = (l.getOption(this._selector, o) || l.getOption(this._selector, (PrivacyBaseValue.CUSTOM + \"\")));\n            Arbiter.inform(\"CustomPrivacyOption/update\", {\n                selector: this._selector,\n                option: q,\n                tooltip: p\n            });\n            return this;\n        },\n        _update: function(o, p) {\n            var q = ((p == PrivacyBaseValue.CUSTOM) || !l.getOption(this._selector, p)), r = this._selector.getAttribute(\"data-name\");\n            this.updateCustomState(o, q, r);\n            return this;\n        },\n        initCustomState: function(o, p) {\n            var q = ge(o);\n            if (!q) {\n                return q\n            };\n            n._instances[o] = this;\n            this._container = i.find(q, \".customPrivacyInputs\");\n            this._id = p;\n            this._privacyData = {\n            };\n            var r = j.serialize(this._container);\n            if (r.audience) {\n                this._privacyData = r.audience[p];\n            };\n            return q;\n        },\n        openCustomDialog: function(event, o, p, q) {\n            var r = new g(\"/ajax/privacy/custom_dialog/\").setData({\n                option_id: o,\n                id: this._id,\n                privacy_data: this._privacyData,\n                explain_tags: p,\n                autosave: q\n            });\n            new h().setAsync(r).setModal(true).setCausalElement(event.getTarget()).show();\n        },\n        updateCustomState: function(o, p, q) {\n            this.clearCustomState();\n            this._privacyData = m({\n            }, o);\n            if (p) {\n                if (q) {\n                    q = q.slice(0, -\"[value]\".length);\n                    var r = {\n                    };\n                    r[q] = o;\n                    j.createHiddenInputs(r, this._container, null, true);\n                }\n            \n            };\n        },\n        clearCustomState: function() {\n            this._privacyData = {\n            };\n            i.empty(this._container);\n        }\n    });\n    e.exports = n;\n});\n__d(\"TypeaheadUtil\", [\"function-extensions\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = /[ ]+/g, h = /[^ ]+/g, i = /[.,+*?$|#{}()\\^\\-\\[\\]\\\\\\/!@\u0025'\"~=<>_:;\\u2010\\u2011\\u2012\\u2013\\u2014\\u2015\\u30fb\\uff1a]/g, j = {\n    }, k = {\n        a: \"\\u0430 \\u00e0 \\u00e1 \\u00e2 \\u00e3 \\u00e4 \\u00e5\",\n        b: \"\\u0431\",\n        c: \"\\u0446 \\u00e7 \\u010d\",\n        d: \"\\u0434 \\u00f0 \\u010f \\u0111\",\n        e: \"\\u044d \\u0435 \\u00e8 \\u00e9 \\u00ea \\u00eb \\u011b\",\n        f: \"\\u0444\",\n        g: \"\\u0433 \\u011f\",\n        h: \"\\u0445 \\u0127\",\n        i: \"\\u0438 \\u00ec \\u00ed \\u00ee \\u00ef \\u0131\",\n        j: \"\\u0439\",\n        k: \"\\u043a \\u0138\",\n        l: \"\\u043b \\u013e \\u013a \\u0140 \\u0142\",\n        m: \"\\u043c\",\n        n: \"\\u043d \\u00f1 \\u0148 \\u0149 \\u014b\",\n        o: \"\\u043e \\u00f8 \\u00f6 \\u00f5 \\u00f4 \\u00f3 \\u00f2\",\n        p: \"\\u043f\",\n        r: \"\\u0440 \\u0159 \\u0155\",\n        s: \"\\u0441 \\u015f \\u0161 \\u017f\",\n        t: \"\\u0442 \\u0165 \\u0167 \\u00fe\",\n        u: \"\\u0443 \\u044e \\u00fc \\u00fb \\u00fa \\u00f9 \\u016f\",\n        v: \"\\u0432\",\n        y: \"\\u044b \\u00ff \\u00fd\",\n        z: \"\\u0437 \\u017e\",\n        ae: \"\\u00e6\",\n        oe: \"\\u0153\",\n        ts: \"\\u0446\",\n        ch: \"\\u0447\",\n        ij: \"\\u0133\",\n        sh: \"\\u0448\",\n        ss: \"\\u00df\",\n        ya: \"\\u044f\"\n    };\n    for (var l in k) {\n        var m = k[l].split(\" \");\n        for (var n = 0; (n < m.length); n++) {\n            j[m[n]] = l;;\n        };\n    };\n    var o = {\n    };\n    function p(v) {\n        return (v ? v.replace(i, \" \") : \"\");\n    };\n    function q(v) {\n        v = ((\"\" + v)).toLowerCase();\n        var w = \"\", x = \"\";\n        for (var y = v.length; y--; ) {\n            x = v.charAt(y);\n            w = (((j[x] || x)) + w);\n        };\n        return w.replace(g, \" \");\n    };\n    function r(v) {\n        var w = [], x = h.exec(v);\n        while (x) {\n            x = x[0];\n            w.push(x);\n            x = h.exec(v);\n        };\n        return w;\n    };\n    function s(v, w) {\n        v = (\"\" + v);\n        if (!o.hasOwnProperty(v)) {\n            var x = q(v), y = p(x);\n            o[v] = {\n                value: v,\n                flatValue: x,\n                tokens: r(y),\n                isPrefixQuery: (y && (y[(y.length - 1)] != \" \"))\n            };\n        }\n    ;\n        if ((w && (typeof o[v].sortedTokens == \"undefined\"))) {\n            o[v].sortedTokens = o[v].tokens.slice();\n            o[v].sortedTokens.sort(function(z, aa) {\n                return (aa.length - z.length);\n            });\n        }\n    ;\n        return o[v];\n    };\n    function t(v, w, x) {\n        var y = s(w, (v == \"prefix\")), z = ((v == \"prefix\") ? y.sortedTokens : y.tokens), aa = s(x).tokens, ba = {\n        }, ca = ((y.isPrefixQuery && (v == \"query\")) ? (z.length - 1) : null), da = function(ea, fa) {\n            for (var ga = 0; (ga < aa.length); ++ga) {\n                var ha = aa[ga];\n                if ((!ba[ga] && (((ha == ea) || ((((((v == \"query\") && (fa === ca)) || (v == \"prefix\"))) && (ha.indexOf(ea) === 0))))))) {\n                    return (ba[ga] = true)\n                };\n            };\n            return false;\n        };\n        return (z.length && z.every(da));\n    };\n    var u = {\n        parse: s,\n        isExactMatch: t.curry(\"exact\"),\n        isQueryMatch: t.curry(\"query\"),\n        isPrefixMatch: t.curry(\"prefix\")\n    };\n    e.exports = u;\n});\n__d(\"DataSource\", [\"array-extensions\",\"ArbiterMixin\",\"AsyncRequest\",\"Class\",\"TypeaheadUtil\",\"copyProperties\",\"createArrayFrom\",\"createObjectFrom\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"AsyncRequest\"), i = b(\"Class\"), j = b(\"TypeaheadUtil\"), k = b(\"copyProperties\"), l = b(\"createArrayFrom\"), m = b(\"createObjectFrom\");\n    function n(o) {\n        this._maxResults = (o.maxResults || 10);\n        this.token = o.token;\n        this.queryData = (o.queryData || {\n        });\n        this.queryEndpoint = (o.queryEndpoint || \"\");\n        this.bootstrapData = (o.bootstrapData || {\n        });\n        this.bootstrapEndpoint = (o.bootstrapEndpoint || \"\");\n        this._exclusions = (o.exclusions || []);\n        this._indexedFields = (o.indexedFields || [\"text\",\"tokens\",]);\n        this._alwaysPrefixMatch = (o.alwaysPrefixMatch || false);\n        this._deduplicationKey = (o.deduplicationKey || null);\n        this._minExactMatchLength = 4;\n        this._filters = [];\n    };\n    k(n.prototype, g, {\n        events: [\"bootstrap\",\"query\",\"respond\",],\n        init: function() {\n            this.init = bagofholding;\n            this._fields = m(this._indexedFields);\n            this._activeQueries = 0;\n            this.dirty();\n        },\n        dirty: function() {\n            this.value = \"\";\n            this._bootstrapped = false;\n            this._bootstrapping = false;\n            this._data = {\n            };\n            this.localCache = {\n            };\n            this.queryCache = {\n            };\n            this.inform(\"dirty\", {\n            });\n            return this;\n        },\n        bootstrap: function() {\n            if (this._bootstrapped) {\n                return\n            };\n            this.bootstrapWithoutToken();\n            this._bootstrapped = true;\n            this._bootstrapping = true;\n            this.inform(\"bootstrap\", {\n                bootstrapping: true\n            });\n        },\n        bootstrapWithoutToken: function() {\n            this.fetch(this.bootstrapEndpoint, this.bootstrapData, {\n                bootstrap: true,\n                token: this.token\n            });\n        },\n        bootstrapWithToken: function() {\n            var o = k({\n            }, this.bootstrapData);\n            o.token = this.token;\n            this.fetch(this.bootstrapEndpoint, o, {\n                bootstrap: true,\n                replaceCache: true\n            });\n        },\n        query: function(o, p, q) {\n            this.inform(\"beforeQuery\", {\n                value: o\n            });\n            var r = this.buildUids(o, [], q), s = this.respond(o, r);\n            this.value = o;\n            this.inform(\"query\", {\n                value: o,\n                results: s\n            });\n            var t = j.parse(o).flatValue;\n            if (((((p || !t) || !this.queryEndpoint) || this.getQueryCache().hasOwnProperty(t)) || !this.shouldFetchMoreResults(s))) {\n                return false\n            };\n            this.inform(\"queryEndpoint\", {\n                value: o\n            });\n            this.fetch(this.queryEndpoint, this.getQueryData(o, r), {\n                value: o,\n                exclusions: q\n            });\n            return true;\n        },\n        shouldFetchMoreResults: function(o) {\n            return (o.length < this._maxResults);\n        },\n        getQueryData: function(o, p) {\n            var q = k({\n                value: o\n            }, (this.queryData || {\n            }));\n            p = (p || []);\n            if (p.length) {\n                q.existing_ids = p.join(\",\");\n            };\n            if (this._bootstrapping) {\n                q.bsp = true;\n            };\n            return q;\n        },\n        setQueryData: function(o, p) {\n            if (p) {\n                this.queryData = {\n                };\n            };\n            k(this.queryData, o);\n            return this;\n        },\n        setBootstrapData: function(o, p) {\n            if (p) {\n                this.bootstrapData = {\n                };\n            };\n            k(this.bootstrapData, o);\n            return this;\n        },\n        getExclusions: function() {\n            return l(this._exclusions);\n        },\n        setExclusions: function(o) {\n            this._exclusions = (o || []);\n        },\n        addFilter: function(o) {\n            var p = this._filters;\n            p.push(o);\n            return {\n                remove: function() {\n                    p.splice(p.indexOf(o), 1);\n                }\n            };\n        },\n        clearFilters: function() {\n            this._filters = [];\n        },\n        respond: function(o, p, q) {\n            var r = this.buildData(p);\n            this.inform(\"respond\", {\n                value: o,\n                results: r,\n                isAsync: !!q\n            });\n            return r;\n        },\n        asyncErrorHandler: bagofholding,\n        fetch: function(o, p, q) {\n            if (!o) {\n                return\n            };\n            var r = new h().setURI(o).setData(p).setMethod(\"GET\").setReadOnly(true).setHandler(function(s) {\n                this.fetchHandler(s, (q || {\n                }));\n            }.bind(this));\n            if ((o === this.queryEndpoint)) {\n                r.setFinallyHandler(function() {\n                    this._activeQueries--;\n                    if (!this._activeQueries) {\n                        this.inform(\"activity\", {\n                            activity: false\n                        });\n                    };\n                }.bind(this));\n            };\n            r.setErrorHandler(this.asyncErrorHandler);\n            this.inform(\"beforeFetch\", {\n                request: r,\n                fetch_context: q\n            });\n            r.send();\n            if ((o === this.queryEndpoint)) {\n                if (!this._activeQueries) {\n                    this.inform(\"activity\", {\n                        activity: true\n                    });\n                };\n                this._activeQueries++;\n            }\n        ;\n        },\n        fetchHandler: function(o, p) {\n            var q = p.value, r = p.exclusions;\n            if ((!q && p.replaceCache)) {\n                this.localCache = {\n                };\n            };\n            this.addEntries(o.getPayload().entries, q);\n            this.inform(\"fetchComplete\", {\n                response: o,\n                value: q,\n                fetch_context: p\n            });\n            var s = (((!q && this.value)) ? this.value : q);\n            this.respond(s, this.buildUids(s, [], r), true);\n            if (!q) {\n                if (this._bootstrapping) {\n                    this._bootstrapping = false;\n                    this.inform(\"bootstrap\", {\n                        bootstrapping: false\n                    });\n                }\n            ;\n                if ((p.token && (o.getPayload().token !== p.token))) {\n                    this.bootstrapWithToken();\n                };\n            }\n        ;\n        },\n        addEntries: function(o, p) {\n            var q = this.processEntries(l((o || [])), p), r = this.buildUids(p, q);\n            if (p) {\n                var s = this.getQueryCache();\n                s[j.parse(p).flatValue] = r;\n            }\n             else this.fillCache(r);\n        ;\n        },\n        processEntries: function(o, p) {\n            return o.map(function(q, r) {\n                var s = (q.uid = (q.uid + \"\")), t = this.getEntry(s);\n                if (!t) {\n                    t = q;\n                    t.query = p;\n                    this.setEntry(s, t);\n                }\n                 else k(t, q);\n            ;\n                ((t.index === undefined) && (t.index = r));\n                return s;\n            }, this);\n        },\n        getAllEntries: function() {\n            return (this._data || {\n            });\n        },\n        getEntry: function(o) {\n            return (this._data[o] || null);\n        },\n        setEntry: function(o, p) {\n            this._data[o] = p;\n        },\n        fillCache: function(o) {\n            var p = this.localCache;\n            o.forEach(function(q) {\n                var r = this.getEntry(q);\n                if (!r) {\n                    return\n                };\n                r.bootstrapped = true;\n                var s = j.parse(this.getTextToIndex(r)).tokens;\n                for (var t = 0, u = s.length; (t < u); ++t) {\n                    var v = s[t];\n                    if (!p.hasOwnProperty(v)) {\n                        p[v] = {\n                        };\n                    };\n                    p[v][q] = true;\n                };\n            }, this);\n        },\n        getTextToIndex: function(o) {\n            if ((o.textToIndex && !o.needs_update)) {\n                return o.textToIndex\n            };\n            var p = [];\n            for (var q in this._fields) {\n                var r = o[q];\n                if (r) {\n                    p.push((r.join ? r.join(\" \") : r));\n                };\n            };\n            o.needs_update = false;\n            return (o.textToIndex = p.join(\" \"));\n        },\n        mergeUids: function(o, p, q, r) {\n            var s = function(t, u) {\n                var v = this.getEntry(t), w = this.getEntry(u);\n                if ((v.extended_match !== w.extended_match)) {\n                    return (v.extended_match ? 1 : -1)\n                };\n                if ((v.index !== w.index)) {\n                    return (v.index - w.index)\n                };\n                if ((v.text.length !== w.text.length)) {\n                    return (v.text.length - w.text.length)\n                };\n                return (v.uid < w.uid);\n            }.bind(this);\n            this._checkExtendedMatch(r, o);\n            return this.deduplicateByKey(o.sort(s).concat(p, q));\n        },\n        _checkExtendedMatch: function(o, p) {\n            var q = (this._alwaysPrefixMatch ? j.isPrefixMatch : j.isQueryMatch);\n            for (var r = 0; (r < p.length); ++r) {\n                var s = this.getEntry(p[r]);\n                s.extended_match = (s.tokens ? !q(o, s.text) : false);\n            };\n        },\n        buildUids: function(o, p, q) {\n            if (!p) {\n                p = [];\n            };\n            if (!o) {\n                return p\n            };\n            if (!q) {\n                q = [];\n            };\n            var r = this.buildCacheResults(o, this.localCache), s = this.buildQueryResults(o), t = this.mergeUids(r, s, p, o), u = m(q.concat(this._exclusions)), v = t.filter(function(w) {\n                if ((u.hasOwnProperty(w) || !this.getEntry(w))) {\n                    return false\n                };\n                for (var x = 0; (x < this._filters.length); ++x) {\n                    if (!this._filters[x](this.getEntry(w), o)) {\n                        return false\n                    };\n                };\n                return (u[w] = true);\n            }, this);\n            return this.uidsIncludingExact(o, v, u);\n        },\n        uidsIncludingExact: function(o, p, q) {\n            var r = p.length;\n            if (((o.length < this._minExactMatchLength) || (r <= this._maxResults))) {\n                return p\n            };\n            for (var s = 0; (s < r); ++s) {\n                var t = this.getEntry(p[s]);\n                (t.text_lower || (t.text_lower = t.text.toLowerCase()));\n                if ((t.text_lower === j.parse(o).flatValue)) {\n                    if ((s >= this._maxResults)) {\n                        var u = p.splice(s, 1);\n                        p.splice((this._maxResults - 1), 0, u);\n                    }\n                ;\n                    break;\n                }\n            ;\n            };\n            return p;\n        },\n        buildData: function(o) {\n            var p = [], q = Math.min(o.length, this._maxResults);\n            for (var r = 0; (r < q); ++r) {\n                p.push(this.getEntry(o[r]));;\n            };\n            return p;\n        },\n        findQueryCache: function(o) {\n            var p = 0, q = null, r = this.getQueryCache();\n            for (var s in r) {\n                if (((o.indexOf(s) === 0) && (s.length > p))) {\n                    p = s.length;\n                    q = s;\n                }\n            ;\n            };\n            return (r[q] || []);\n        },\n        buildQueryResults: function(o) {\n            var p = j.parse(o).flatValue, q = this.findQueryCache(p);\n            if (this.getQueryCache().hasOwnProperty(p)) {\n                return q\n            };\n            return this.filterQueryResults(o, q);\n        },\n        filterQueryResults: function(o, p) {\n            var q = (this._alwaysPrefixMatch ? j.isPrefixMatch : j.isQueryMatch);\n            return p.filter(function(r) {\n                return q(o, this.getTextToIndex(this.getEntry(r)));\n            }, this);\n        },\n        buildCacheResults: function(o, p) {\n            var q = j.parse(o, this._alwaysPrefixMatch), r = (this._alwaysPrefixMatch ? q.sortedTokens : q.tokens), s = r.length, t = (q.isPrefixQuery ? (s - 1) : null), u = {\n            }, v = {\n            }, w = {\n            }, x = [], y = false, z = {\n            }, aa = 0;\n            for (var ba = 0; (ba < s); ++ba) {\n                var ca = r[ba];\n                if (!z.hasOwnProperty(ca)) {\n                    aa++;\n                    z[ca] = true;\n                }\n                 else continue;\n            ;\n                for (var da in p) {\n                    if ((((!u.hasOwnProperty(da) && (da === ca))) || ((((this._alwaysPrefixMatch || (t === ba))) && (da.indexOf(ca) === 0))))) {\n                        if ((da === ca)) {\n                            if (v.hasOwnProperty(da)) {\n                                y = true;\n                            };\n                            u[da] = true;\n                        }\n                         else {\n                            if ((u.hasOwnProperty(da) || v.hasOwnProperty(da))) {\n                                y = true;\n                            };\n                            v[da] = true;\n                        }\n                    ;\n                        for (var ea in p[da]) {\n                            if (((ba === 0) || ((w.hasOwnProperty(ea) && (w[ea] == (aa - 1)))))) {\n                                w[ea] = aa;\n                            };\n                        };\n                    }\n                ;\n                };\n            };\n            for (var fa in w) {\n                if ((w[fa] == aa)) {\n                    x.push(fa);\n                };\n            };\n            if ((y || (aa < s))) {\n                x = this.filterQueryResults(o, x);\n            };\n            return x;\n        },\n        deduplicateByKey: function(o) {\n            if (!this._deduplicationKey) {\n                return o\n            };\n            var p = m(o.map(this._getDeduplicationKey.bind(this)), o);\n            return o.filter(function(q) {\n                return (p[this._getDeduplicationKey(q)] == q);\n            }.bind(this));\n        },\n        _getDeduplicationKey: function(o) {\n            var p = this.getEntry(o);\n            return (p[this._deduplicationKey] || ((\"__\" + o) + \"__\"));\n        },\n        getQueryCache: function() {\n            return this.queryCache;\n        },\n        setMaxResults: function(o) {\n            this._maxResults = o;\n            (this.value && this.respond(this.value, this.buildUids(this.value)));\n        },\n        updateToken: function(o) {\n            this.token = o;\n            this.dirty();\n            return this;\n        }\n    });\n    e.exports = n;\n});\n__d(\"Dcode\", [], function(a, b, c, d, e, f) {\n    var g, h = {\n    }, i = {\n        _: \"\u0025\",\n        A: \"\u00252\",\n        B: \"000\",\n        C: \"\u00257d\",\n        D: \"\u00257b\u002522\",\n        E: \"\u00252c\u002522\",\n        F: \"\u002522\u00253a\",\n        G: \"\u00252c\u002522ut\u002522\u00253a1\",\n        H: \"\u00252c\u002522bls\u002522\u00253a\",\n        I: \"\u00252c\u002522n\u002522\u00253a\u002522\u0025\",\n        J: \"\u002522\u00253a\u00257b\u002522i\u002522\u00253a0\u00257d\",\n        K: \"\u00252c\u002522pt\u002522\u00253a0\u00252c\u002522vis\u002522\u00253a\",\n        L: \"\u00252c\u002522ch\u002522\u00253a\u00257b\u002522h\u002522\u00253a\u002522\",\n        M: \"\u00257b\u002522v\u002522\u00253a2\u00252c\u002522time\u002522\u00253a1\",\n        N: \".channel\u002522\u00252c\u002522sub\u002522\u00253a\u00255b\",\n        O: \"\u00252c\u002522sb\u002522\u00253a1\u00252c\u002522t\u002522\u00253a\u00255b\",\n        P: \"\u00252c\u002522ud\u002522\u00253a100\u00252c\u002522lc\u002522\u00253a0\",\n        Q: \"\u00255d\u00252c\u002522f\u002522\u00253anull\u00252c\u002522uct\u002522\u00253a\",\n        R: \".channel\u002522\u00252c\u002522sub\u002522\u00253a\u00255b1\u00255d\",\n        S: \"\u002522\u00252c\u002522m\u002522\u00253a0\u00257d\u00252c\u00257b\u002522i\u002522\u00253a\",\n        T: \"\u00252c\u002522blc\u002522\u00253a1\u00252c\u002522snd\u002522\u00253a1\u00252c\u002522ct\u002522\u00253a\",\n        U: \"\u00252c\u002522blc\u002522\u00253a0\u00252c\u002522snd\u002522\u00253a1\u00252c\u002522ct\u002522\u00253a\",\n        V: \"\u00252c\u002522blc\u002522\u00253a0\u00252c\u002522snd\u002522\u00253a0\u00252c\u002522ct\u002522\u00253a\",\n        W: \"\u00252c\u002522s\u002522\u00253a0\u00252c\u002522blo\u002522\u00253a0\u00257d\u00252c\u002522bl\u002522\u00253a\u00257b\u002522ac\u002522\u00253a\",\n        X: \"\u00252c\u002522ri\u002522\u00253a0\u00257d\u00252c\u002522state\u002522\u00253a\u00257b\u002522p\u002522\u00253a0\u00252c\u002522ut\u002522\u00253a1\",\n        Y: \"\u00252c\u002522pt\u002522\u00253a0\u00252c\u002522vis\u002522\u00253a1\u00252c\u002522bls\u002522\u00253a0\u00252c\u002522blc\u002522\u00253a0\u00252c\u002522snd\u002522\u00253a1\u00252c\u002522ct\u002522\u00253a\",\n        Z: \"\u00252c\u002522sb\u002522\u00253a1\u00252c\u002522t\u002522\u00253a\u00255b\u00255d\u00252c\u002522f\u002522\u00253anull\u00252c\u002522uct\u002522\u00253a0\u00252c\u002522s\u002522\u00253a0\u00252c\u002522blo\u002522\u00253a0\u00257d\u00252c\u002522bl\u002522\u00253a\u00257b\u002522ac\u002522\u00253a\"\n    };\n    (function() {\n        var k = [];\n        for (var l in i) {\n            h[i[l]] = l;\n            k.push(i[l]);\n        };\n        k.reverse();\n        g = new RegExp(k.join(\"|\"), \"g\");\n    })();\n    var j = {\n        encode: function(k) {\n            return encodeURIComponent(k).replace(/([_A-Z])|\u0025../g, function(l, m) {\n                return (m ? (\"\u0025\" + m.charCodeAt(0).toString(16)) : l);\n            }).toLowerCase().replace(g, function(l) {\n                return h[l];\n            });\n        },\n        decode: function(k) {\n            return decodeURIComponent(k.replace(/[_A-Z]/g, function(l) {\n                return i[l];\n            }));\n        }\n    };\n    e.exports = j;\n});\n__d(\"DialogHideOnSuccess\", [\"copyProperties\",\"CSS\",\"cx\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\"), h = b(\"CSS\"), i = b(\"cx\");\n    function j(k) {\n        this._layer = k;\n    };\n    g(j.prototype, {\n        _subscription: null,\n        enable: function() {\n            this._subscription = this._layer.subscribe(\"success\", this._handle.bind(this));\n        },\n        disable: function() {\n            this._subscription.unsubscribe();\n            this._subscription = null;\n        },\n        _handle: function(k, event) {\n            if (h.hasClass(event.getTarget(), \"-cx-PRIVATE-uiDialog__form\")) {\n                this._layer.hide();\n            };\n        }\n    });\n    e.exports = j;\n});\n__d(\"DocRPC\", [], function(a, b, c, d, e, f) {\n    var g = {\n        _apis: {\n        },\n        _dispatch: function(h) {\n            var i;\n            try {\n                h = JSON.parse(h);\n            } catch (j) {\n                throw new Error(((\"DocRPC unparsable dispatch: \\\"\" + h) + \"\\\"\"));\n            };\n            if (g._apis.hasOwnProperty(h.api)) {\n                var k = g._apis[h.api];\n                if (k[h.method]) {\n                    i = k[h.method].apply(k, h.args);\n                };\n            }\n        ;\n            if ((i === undefined)) {\n                i = null;\n            };\n            return JSON.stringify(i);\n        },\n        publish: function(h, i) {\n            g._apis[i] = h;\n        },\n        proxy: function(h, i, j) {\n            var k = {\n            };\n            j.forEach(function(l) {\n                k[l] = function() {\n                    var m = {\n                        api: i,\n                        method: l,\n                        args: Array.prototype.slice.call(arguments)\n                    }, n = h.DocRPC._dispatch(JSON.stringify(m));\n                    if ((typeof (n) == \"string\")) {\n                        try {\n                            n = JSON.parse(n);\n                        } catch (o) {\n                            throw new Error(((((((\"DocRPC \" + i) + \".\") + l) + \" unparsable return: \\\"\") + n) + \"\\\"\"));\n                        }\n                    };\n                    return n;\n                };\n            });\n            return k;\n        }\n    };\n    e.exports = a.DocRPC = g;\n});\n__d(\"DocumentTitle\", [\"Arbiter\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = document.title, i = null, j = 1500, k = [], l = 0, m = null, n = false;\n    function o() {\n        if ((k.length > 0)) {\n            if (!n) {\n                p(k[l].title);\n                l = (++l \u0025 k.length);\n            }\n             else q();\n        ;\n        }\n         else {\n            clearInterval(m);\n            m = null;\n            q();\n        }\n    ;\n    };\n    function p(s) {\n        document.title = s;\n        n = true;\n    };\n    function q() {\n        r.set((i || h), true);\n        n = false;\n    };\n    var r = {\n        get: function() {\n            return h;\n        },\n        set: function(s, t) {\n            document.title = s;\n            if (!t) {\n                h = s;\n                i = null;\n                g.inform(\"update_title\", s);\n            }\n             else i = s;\n        ;\n        },\n        blink: function(s) {\n            var t = {\n                title: s\n            };\n            k.push(t);\n            if ((m === null)) {\n                m = setInterval(o, j);\n            };\n            return {\n                stop: function() {\n                    var u = k.indexOf(t);\n                    if ((u >= 0)) {\n                        k.splice(u, 1);\n                        if ((l > u)) {\n                            l--;\n                        }\n                         else if (((l == u) && (l == k.length))) {\n                            l = 0;\n                        }\n                    ;\n                    }\n                ;\n                }\n            };\n        }\n    };\n    e.exports = r;\n});\n__d(\"Emote\", [\"DOM\",\"Env\",\"htmlize\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"Env\"), i = b(\"htmlize\"), j = e.exports = {\n        _initialized: false,\n        _imageBase: null,\n        _emoteMap: null,\n        _emoteOrderMap: null,\n        _fbidEmoticonPattern: \"\\\\[\\\\[([A-Za-z0-9\\\\.]+)\\\\]\\\\]\",\n        _fbidEmoticonRegex: null,\n        _imageURLs: null,\n        _regex: null,\n        _regexWithoutFBIDs: null,\n        _init: function() {\n            var k = h.static_base;\n            j._imageBase = (k + \"images/emote/\");\n            j._blankImgSrc = (k + \"images/blank.gif\");\n            var l = [\"smile\",\"frown\",\"tongue\",\"grin\",\"gasp\",\"wink\",\"glasses\",\"sunglasses\",\"grumpy\",\"unsure\",\"cry\",\"devil\",\"angel\",\"kiss\",\"heart\",\"kiki\",\"squint\",\"confused\",\"upset\",\"pacman\",\"colonthree\",\"like\",];\n            j._emoteMap = {\n                \":-)\": [\"\\\\:\\\\-\\\\)\",\"smile\",],\n                \":)\": [\"\\\\:\\\\)\",\"smile\",],\n                \":]\": [\"\\\\:\\\\]\",\"smile\",],\n                \"=)\": [\"=\\\\)\",\"smile\",],\n                \":-(\": [\"\\\\:\\\\-\\\\(\",\"frown\",],\n                \":(\": [\"\\\\:\\\\(\",\"frown\",],\n                \":[\": [\"\\\\:\\\\[\",\"frown\",],\n                \"=(\": [\"=\\\\(\",\"frown\",],\n                \":-P\": [\"\\\\:\\\\-P\",\"tongue\",],\n                \":P\": [\"\\\\:P\",\"tongue\",],\n                \":-p\": [\"\\\\:\\\\-p\",\"tongue\",],\n                \":p\": [\"\\\\:p\",\"tongue\",],\n                \"=P\": [\"=P\",\"tongue\",],\n                \":-D\": [\"\\\\:\\\\-D\",\"grin\",],\n                \":D\": [\"\\\\:D\",\"grin\",],\n                \"=D\": [\"=D\",\"grin\",],\n                \":-O\": [\"\\\\:\\\\-O\",\"gasp\",],\n                \":O\": [\"\\\\:O\",\"gasp\",],\n                \":-o\": [\"\\\\:\\\\-o\",\"gasp\",],\n                \":o\": [\"\\\\:o\",\"gasp\",],\n                \";-)\": [\"\\\\;\\\\-\\\\)\",\"wink\",],\n                \";)\": [\"\\\\;\\\\)\",\"wink\",],\n                \"8-)\": [\"8\\\\-\\\\)\",\"glasses\",],\n                \"8)\": [\"8\\\\)\",\"glasses\",],\n                \"B-)\": [\"B\\\\-\\\\)\",\"glasses\",],\n                \"B)\": [\"B\\\\)\",\"glasses\",],\n                \"8-|\": [\"8\\\\-\\\\|\",\"sunglasses\",],\n                \"8|\": [\"8\\\\|\",\"sunglasses\",],\n                \"B-|\": [\"B\\\\-\\\\|\",\"sunglasses\",],\n                \"B|\": [\"B\\\\|\",\"sunglasses\",],\n                \"\\u003E:(\": [\"\\u003E\\\\:\\\\(\",\"grumpy\",],\n                \"\\u003E:-(\": [\"\\u003E\\\\:\\\\-\\\\(\",\"grumpy\",],\n                \":/\": [\"\\\\:/\",\"unsure\",],\n                \":-/\": [\"\\\\:\\\\-/\",\"unsure\",],\n                \":\\\\\": [\"\\\\:\\\\\\\\\",\"unsure\",],\n                \":-\\\\\": [\"\\\\:\\\\-\\\\\\\\\",\"unsure\",],\n                \":'(\": [\"\\\\:'\\\\(\",\"cry\",],\n                \"3:)\": [\"3\\\\:\\\\)\",\"devil\",],\n                \"3:-)\": [\"3\\\\:\\\\-\\\\)\",\"devil\",],\n                \"O:)\": [\"O\\\\:\\\\)\",\"angel\",],\n                \"O:-)\": [\"O\\\\:\\\\-\\\\)\",\"angel\",],\n                \":-*\": [\"\\\\:\\\\-\\\\*\",\"kiss\",],\n                \":*\": [\"\\\\:\\\\*\",\"kiss\",],\n                \"\\u003C3\": [\"\\u003C3\",\"heart\",],\n                \"&lt;3\": [\"&lt\\\\;3\",\"heart\",],\n                \"\\u2665\": [\"\\u2665\",\"heart\",],\n                \"^_^\": [\"\\\\^_\\\\^\",\"kiki\",],\n                \"-_-\": [\"\\\\-_\\\\-\",\"squint\",],\n                \"o.O\": [\"o\\\\.O\",\"confused\",],\n                \"O.o\": [\"O\\\\.o\",\"confused\",],\n                \"\\u003E:O\": [\"\\u003E\\\\:O\",\"upset\",],\n                \"\\u003E:-O\": [\"\\u003E\\\\:\\\\-O\",\"upset\",],\n                \"\\u003E:o\": [\"\\u003E\\\\:o\",\"upset\",],\n                \"\\u003E:-o\": [\"\\u003E\\\\:\\\\-o\",\"upset\",],\n                \"\\u003E_\\u003C\": [\"\\u003E_\\u003C\",\"upset\",],\n                \"\\u003E.\\u003C\": [\"\\u003E\\\\.\\u003C\",\"upset\",],\n                \":v\": [\"\\\\:v\",\"pacman\",],\n                \":|]\": [\"\\\\:\\\\|\\\\]\",\"robot\",],\n                \":3\": [\"\\\\:3\",\"colonthree\",],\n                \"\\u003C(\\\")\": [\"\\u003C\\\\(\\\\\\\"\\\\)\",\"penguin\",],\n                \":putnam:\": [\"\\\\:putnam\\\\:\",\"putnam\",],\n                \"(^^^)\": [\"\\\\(\\\\^\\\\^\\\\^\\\\)\",\"shark\",],\n                \":42:\": [\"\\\\:42\\\\:\",\"42\",],\n                \":like:\": [\"\\\\:like\\\\:\",\"like\",],\n                \"(y)\": [\"\\\\(y\\\\)\",\"like\",],\n                \"(Y)\": [\"\\\\(Y\\\\)\",\"like\",]\n            };\n            var m = [], n = [];\n            if (h.fbid_emoticons) {\n                j._fbidEmoticonRegex = new RegExp(j._fbidEmoticonPattern);\n                m.push(j._fbidEmoticonPattern);\n            }\n        ;\n            for (var o in j._emoteMap) {\n                var p = j._emoteMap[o][0];\n                m.push(p);\n                n.push(p);\n            };\n            var q = ((\"(?:^|\\\\s|'|\\\"|\\\\.)(\" + m.join(\"|\")) + \")(?:\\\\s|'|\\\"|\\\\.|,|!|\\\\?|\\u003Cbr\\u003E|$)\"), r = ((\"(?:^|\\\\s|'|\\\"|\\\\.)(\" + n.join(\"|\")) + \")(?:\\\\s|'|\\\"|\\\\.|,|!|\\\\?|\\u003Cbr\\u003E|$)\");\n            j._regex = new RegExp(q);\n            j._regexWithoutFBIDs = new RegExp(r);\n            j._emoteOrderMap = {\n            };\n            for (var s = 0; (s < l.length); s++) {\n                j._emoteOrderMap[l[s]] = s;;\n            };\n            j._initialized = true;\n        },\n        htmlEmote: function(k, l) {\n            return j._htmlEmote(k, l, true);\n        },\n        htmlEmoteWithoutFBID: function(k, l) {\n            return j._htmlEmote(k, l, false);\n        },\n        _getRegex: function(k) {\n            return (k ? j._regex : j._regexWithoutFBIDs);\n        },\n        _htmlEmote: function(k, l, m) {\n            if ((typeof l != \"function\")) {\n                l = i;\n            };\n            if (!j._initialized) {\n                j._init();\n            };\n            var n = k, o = [];\n            while (true) {\n                var p = j._getRegex(m), q = p.exec(n);\n                if ((!q || !q.length)) {\n                    break;\n                };\n                var r = q[1], s = n.indexOf(r), t = n.substring(0, s);\n                if (t) {\n                    o.push(l(t));\n                };\n                o.push(\"\\u003Cspan class=\\\"emote_text\\\"\\u003E\");\n                o.push(r);\n                o.push(\"\\u003C/span\\u003E\");\n                var u = {\n                    title: r\n                }, v = (j._fbidEmoticonRegex && ((j._fbidEmoticonRegex.exec(r) || []))[1]);\n                if (v) {\n                    u.className = \"emote_custom\";\n                    u.src = (((window.location.protocol + \"//graph.facebook.com/\") + encodeURIComponent(v)) + \"/picture\");\n                }\n                 else {\n                    var w = j._emoteMap[r][1], x = j._emoteOrderMap[w];\n                    if ((x === undefined)) {\n                        u.className = \"emote_custom\";\n                        u.src = ((j._imageBase + w) + \".gif\");\n                    }\n                     else {\n                        var y = (x * -16);\n                        u.className = \"emote_img\";\n                        u.src = j._blankImgSrc;\n                        u.style = {\n                            backgroundPosition: (y + \"px 0\")\n                        };\n                    }\n                ;\n                }\n            ;\n                var z = g.create(\"img\", u);\n                o.push(g.create(\"span\", {\n                }, z).innerHTML);\n                n = n.substring((s + r.length));\n            };\n            if (n) {\n                o.push(l(n));\n            };\n            return o.join(\"\");\n        }\n    };\n});\n__d(\"SupportedEmoji\", [\"cx\",], function(a, b, c, d, e, f) {\n    var g = b(\"cx\");\n    e.exports = {\n        utf16Regex: /\\u203C|\\u2049|[\\u2100-\\u21FF]|[\\u2300-\\u27FF]|[\\u2900-\\u29FF]|[\\u2B00-\\u2BFF]|[\\u3000-\\u30FF]|[\\u3200-\\u32FF]|\\uD83C[\\uDC00-\\uDFFF]|\\uD83D[\\uDC00-\\uDEFF]/,\n        emoji: {\n            127744: \"-cx-PRIVATE-fbEmoji__icon_1f300\",\n            127746: \"-cx-PRIVATE-fbEmoji__icon_1f302\",\n            127754: \"-cx-PRIVATE-fbEmoji__icon_1f30a\",\n            127769: \"-cx-PRIVATE-fbEmoji__icon_1f319\",\n            127775: \"-cx-PRIVATE-fbEmoji__icon_1f31f\",\n            127793: \"-cx-PRIVATE-fbEmoji__icon_1f331\",\n            127796: \"-cx-PRIVATE-fbEmoji__icon_1f334\",\n            127797: \"-cx-PRIVATE-fbEmoji__icon_1f335\",\n            127799: \"-cx-PRIVATE-fbEmoji__icon_1f337\",\n            127800: \"-cx-PRIVATE-fbEmoji__icon_1f338\",\n            127801: \"-cx-PRIVATE-fbEmoji__icon_1f339\",\n            127802: \"-cx-PRIVATE-fbEmoji__icon_1f33a\",\n            127803: \"-cx-PRIVATE-fbEmoji__icon_1f33b\",\n            127806: \"-cx-PRIVATE-fbEmoji__icon_1f33e\",\n            127808: \"-cx-PRIVATE-fbEmoji__icon_1f340\",\n            127809: \"-cx-PRIVATE-fbEmoji__icon_1f341\",\n            127810: \"-cx-PRIVATE-fbEmoji__icon_1f342\",\n            127811: \"-cx-PRIVATE-fbEmoji__icon_1f343\",\n            127818: \"-cx-PRIVATE-fbEmoji__icon_1f34a\",\n            127822: \"-cx-PRIVATE-fbEmoji__icon_1f34e\",\n            127827: \"-cx-PRIVATE-fbEmoji__icon_1f353\",\n            127828: \"-cx-PRIVATE-fbEmoji__icon_1f354\",\n            127864: \"-cx-PRIVATE-fbEmoji__icon_1f378\",\n            127866: \"-cx-PRIVATE-fbEmoji__icon_1f37a\",\n            127873: \"-cx-PRIVATE-fbEmoji__icon_1f381\",\n            127875: \"-cx-PRIVATE-fbEmoji__icon_1f383\",\n            127876: \"-cx-PRIVATE-fbEmoji__icon_1f384\",\n            127877: \"-cx-PRIVATE-fbEmoji__icon_1f385\",\n            127880: \"-cx-PRIVATE-fbEmoji__icon_1f388\",\n            127881: \"-cx-PRIVATE-fbEmoji__icon_1f389\",\n            127885: \"-cx-PRIVATE-fbEmoji__icon_1f38d\",\n            127886: \"-cx-PRIVATE-fbEmoji__icon_1f38e\",\n            127887: \"-cx-PRIVATE-fbEmoji__icon_1f38f\",\n            127888: \"-cx-PRIVATE-fbEmoji__icon_1f390\",\n            127891: \"-cx-PRIVATE-fbEmoji__icon_1f393\",\n            127925: \"-cx-PRIVATE-fbEmoji__icon_1f3b5\",\n            127926: \"-cx-PRIVATE-fbEmoji__icon_1f3b6\",\n            127932: \"-cx-PRIVATE-fbEmoji__icon_1f3bc\",\n            128013: \"-cx-PRIVATE-fbEmoji__icon_1f40d\",\n            128014: \"-cx-PRIVATE-fbEmoji__icon_1f40e\",\n            128017: \"-cx-PRIVATE-fbEmoji__icon_1f411\",\n            128018: \"-cx-PRIVATE-fbEmoji__icon_1f412\",\n            128020: \"-cx-PRIVATE-fbEmoji__icon_1f414\",\n            128023: \"-cx-PRIVATE-fbEmoji__icon_1f417\",\n            128024: \"-cx-PRIVATE-fbEmoji__icon_1f418\",\n            128025: \"-cx-PRIVATE-fbEmoji__icon_1f419\",\n            128026: \"-cx-PRIVATE-fbEmoji__icon_1f41a\",\n            128027: \"-cx-PRIVATE-fbEmoji__icon_1f41b\",\n            128031: \"-cx-PRIVATE-fbEmoji__icon_1f41f\",\n            128032: \"-cx-PRIVATE-fbEmoji__icon_1f420\",\n            128033: \"-cx-PRIVATE-fbEmoji__icon_1f421\",\n            128037: \"-cx-PRIVATE-fbEmoji__icon_1f425\",\n            128038: \"-cx-PRIVATE-fbEmoji__icon_1f426\",\n            128039: \"-cx-PRIVATE-fbEmoji__icon_1f427\",\n            128040: \"-cx-PRIVATE-fbEmoji__icon_1f428\",\n            128041: \"-cx-PRIVATE-fbEmoji__icon_1f429\",\n            128043: \"-cx-PRIVATE-fbEmoji__icon_1f42b\",\n            128044: \"-cx-PRIVATE-fbEmoji__icon_1f42c\",\n            128045: \"-cx-PRIVATE-fbEmoji__icon_1f42d\",\n            128046: \"-cx-PRIVATE-fbEmoji__icon_1f42e\",\n            128047: \"-cx-PRIVATE-fbEmoji__icon_1f42f\",\n            128048: \"-cx-PRIVATE-fbEmoji__icon_1f430\",\n            128049: \"-cx-PRIVATE-fbEmoji__icon_1f431\",\n            128051: \"-cx-PRIVATE-fbEmoji__icon_1f433\",\n            128052: \"-cx-PRIVATE-fbEmoji__icon_1f434\",\n            128053: \"-cx-PRIVATE-fbEmoji__icon_1f435\",\n            128055: \"-cx-PRIVATE-fbEmoji__icon_1f437\",\n            128056: \"-cx-PRIVATE-fbEmoji__icon_1f438\",\n            128057: \"-cx-PRIVATE-fbEmoji__icon_1f439\",\n            128058: \"-cx-PRIVATE-fbEmoji__icon_1f43a\",\n            128059: \"-cx-PRIVATE-fbEmoji__icon_1f43b\",\n            128062: \"-cx-PRIVATE-fbEmoji__icon_1f43e\",\n            128064: \"-cx-PRIVATE-fbEmoji__icon_1f440\",\n            128066: \"-cx-PRIVATE-fbEmoji__icon_1f442\",\n            128067: \"-cx-PRIVATE-fbEmoji__icon_1f443\",\n            128068: \"-cx-PRIVATE-fbEmoji__icon_1f444\",\n            128069: \"-cx-PRIVATE-fbEmoji__icon_1f445\",\n            128070: \"-cx-PRIVATE-fbEmoji__icon_1f446\",\n            128071: \"-cx-PRIVATE-fbEmoji__icon_1f447\",\n            128072: \"-cx-PRIVATE-fbEmoji__icon_1f448\",\n            128073: \"-cx-PRIVATE-fbEmoji__icon_1f449\",\n            128074: \"-cx-PRIVATE-fbEmoji__icon_1f44a\",\n            128075: \"-cx-PRIVATE-fbEmoji__icon_1f44b\",\n            128076: \"-cx-PRIVATE-fbEmoji__icon_1f44c\",\n            128077: \"-cx-PRIVATE-fbEmoji__icon_1f44d\",\n            128078: \"-cx-PRIVATE-fbEmoji__icon_1f44e\",\n            128079: \"-cx-PRIVATE-fbEmoji__icon_1f44f\",\n            128080: \"-cx-PRIVATE-fbEmoji__icon_1f450\",\n            128102: \"-cx-PRIVATE-fbEmoji__icon_1f466\",\n            128103: \"-cx-PRIVATE-fbEmoji__icon_1f467\",\n            128104: \"-cx-PRIVATE-fbEmoji__icon_1f468\",\n            128105: \"-cx-PRIVATE-fbEmoji__icon_1f469\",\n            128107: \"-cx-PRIVATE-fbEmoji__icon_1f46b\",\n            128110: \"-cx-PRIVATE-fbEmoji__icon_1f46e\",\n            128111: \"-cx-PRIVATE-fbEmoji__icon_1f46f\",\n            128113: \"-cx-PRIVATE-fbEmoji__icon_1f471\",\n            128114: \"-cx-PRIVATE-fbEmoji__icon_1f472\",\n            128115: \"-cx-PRIVATE-fbEmoji__icon_1f473\",\n            128116: \"-cx-PRIVATE-fbEmoji__icon_1f474\",\n            128117: \"-cx-PRIVATE-fbEmoji__icon_1f475\",\n            128118: \"-cx-PRIVATE-fbEmoji__icon_1f476\",\n            128119: \"-cx-PRIVATE-fbEmoji__icon_1f477\",\n            128120: \"-cx-PRIVATE-fbEmoji__icon_1f478\",\n            128123: \"-cx-PRIVATE-fbEmoji__icon_1f47b\",\n            128124: \"-cx-PRIVATE-fbEmoji__icon_1f47c\",\n            128125: \"-cx-PRIVATE-fbEmoji__icon_1f47d\",\n            128126: \"-cx-PRIVATE-fbEmoji__icon_1f47e\",\n            128127: \"-cx-PRIVATE-fbEmoji__icon_1f47f\",\n            128128: \"-cx-PRIVATE-fbEmoji__icon_1f480\",\n            128130: \"-cx-PRIVATE-fbEmoji__icon_1f482\",\n            128131: \"-cx-PRIVATE-fbEmoji__icon_1f483\",\n            128133: \"-cx-PRIVATE-fbEmoji__icon_1f485\",\n            128139: \"-cx-PRIVATE-fbEmoji__icon_1f48b\",\n            128143: \"-cx-PRIVATE-fbEmoji__icon_1f48f\",\n            128144: \"-cx-PRIVATE-fbEmoji__icon_1f490\",\n            128145: \"-cx-PRIVATE-fbEmoji__icon_1f491\",\n            128147: \"-cx-PRIVATE-fbEmoji__icon_1f493\",\n            128148: \"-cx-PRIVATE-fbEmoji__icon_1f494\",\n            128150: \"-cx-PRIVATE-fbEmoji__icon_1f496\",\n            128151: \"-cx-PRIVATE-fbEmoji__icon_1f497\",\n            128152: \"-cx-PRIVATE-fbEmoji__icon_1f498\",\n            128153: \"-cx-PRIVATE-fbEmoji__icon_1f499\",\n            128154: \"-cx-PRIVATE-fbEmoji__icon_1f49a\",\n            128155: \"-cx-PRIVATE-fbEmoji__icon_1f49b\",\n            128156: \"-cx-PRIVATE-fbEmoji__icon_1f49c\",\n            128157: \"-cx-PRIVATE-fbEmoji__icon_1f49d\",\n            128162: \"-cx-PRIVATE-fbEmoji__icon_1f4a2\",\n            128164: \"-cx-PRIVATE-fbEmoji__icon_1f4a4\",\n            128166: \"-cx-PRIVATE-fbEmoji__icon_1f4a6\",\n            128168: \"-cx-PRIVATE-fbEmoji__icon_1f4a8\",\n            128169: \"-cx-PRIVATE-fbEmoji__icon_1f4a9\",\n            128170: \"-cx-PRIVATE-fbEmoji__icon_1f4aa\",\n            128187: \"-cx-PRIVATE-fbEmoji__icon_1f4bb\",\n            128189: \"-cx-PRIVATE-fbEmoji__icon_1f4bd\",\n            128190: \"-cx-PRIVATE-fbEmoji__icon_1f4be\",\n            128191: \"-cx-PRIVATE-fbEmoji__icon_1f4bf\",\n            128192: \"-cx-PRIVATE-fbEmoji__icon_1f4c0\",\n            128222: \"-cx-PRIVATE-fbEmoji__icon_1f4de\",\n            128224: \"-cx-PRIVATE-fbEmoji__icon_1f4e0\",\n            128241: \"-cx-PRIVATE-fbEmoji__icon_1f4f1\",\n            128242: \"-cx-PRIVATE-fbEmoji__icon_1f4f2\",\n            128250: \"-cx-PRIVATE-fbEmoji__icon_1f4fa\",\n            128276: \"-cx-PRIVATE-fbEmoji__icon_1f514\",\n            128513: \"-cx-PRIVATE-fbEmoji__icon_1f601\",\n            128514: \"-cx-PRIVATE-fbEmoji__icon_1f602\",\n            128515: \"-cx-PRIVATE-fbEmoji__icon_1f603\",\n            128516: \"-cx-PRIVATE-fbEmoji__icon_1f604\",\n            128518: \"-cx-PRIVATE-fbEmoji__icon_1f606\",\n            128521: \"-cx-PRIVATE-fbEmoji__icon_1f609\",\n            128523: \"-cx-PRIVATE-fbEmoji__icon_1f60b\",\n            128524: \"-cx-PRIVATE-fbEmoji__icon_1f60c\",\n            128525: \"-cx-PRIVATE-fbEmoji__icon_1f60d\",\n            128527: \"-cx-PRIVATE-fbEmoji__icon_1f60f\",\n            128530: \"-cx-PRIVATE-fbEmoji__icon_1f612\",\n            128531: \"-cx-PRIVATE-fbEmoji__icon_1f613\",\n            128532: \"-cx-PRIVATE-fbEmoji__icon_1f614\",\n            128534: \"-cx-PRIVATE-fbEmoji__icon_1f616\",\n            128536: \"-cx-PRIVATE-fbEmoji__icon_1f618\",\n            128538: \"-cx-PRIVATE-fbEmoji__icon_1f61a\",\n            128540: \"-cx-PRIVATE-fbEmoji__icon_1f61c\",\n            128541: \"-cx-PRIVATE-fbEmoji__icon_1f61d\",\n            128542: \"-cx-PRIVATE-fbEmoji__icon_1f61e\",\n            128544: \"-cx-PRIVATE-fbEmoji__icon_1f620\",\n            128545: \"-cx-PRIVATE-fbEmoji__icon_1f621\",\n            128546: \"-cx-PRIVATE-fbEmoji__icon_1f622\",\n            128547: \"-cx-PRIVATE-fbEmoji__icon_1f623\",\n            128548: \"-cx-PRIVATE-fbEmoji__icon_1f624\",\n            128549: \"-cx-PRIVATE-fbEmoji__icon_1f625\",\n            128552: \"-cx-PRIVATE-fbEmoji__icon_1f628\",\n            128553: \"-cx-PRIVATE-fbEmoji__icon_1f629\",\n            128554: \"-cx-PRIVATE-fbEmoji__icon_1f62a\",\n            128555: \"-cx-PRIVATE-fbEmoji__icon_1f62b\",\n            128557: \"-cx-PRIVATE-fbEmoji__icon_1f62d\",\n            128560: \"-cx-PRIVATE-fbEmoji__icon_1f630\",\n            128561: \"-cx-PRIVATE-fbEmoji__icon_1f631\",\n            128562: \"-cx-PRIVATE-fbEmoji__icon_1f632\",\n            128563: \"-cx-PRIVATE-fbEmoji__icon_1f633\",\n            128565: \"-cx-PRIVATE-fbEmoji__icon_1f635\",\n            128567: \"-cx-PRIVATE-fbEmoji__icon_1f637\",\n            128568: \"-cx-PRIVATE-fbEmoji__icon_1f638\",\n            128569: \"-cx-PRIVATE-fbEmoji__icon_1f639\",\n            128570: \"-cx-PRIVATE-fbEmoji__icon_1f63a\",\n            128571: \"-cx-PRIVATE-fbEmoji__icon_1f63b\",\n            128572: \"-cx-PRIVATE-fbEmoji__icon_1f63c\",\n            128573: \"-cx-PRIVATE-fbEmoji__icon_1f63d\",\n            128575: \"-cx-PRIVATE-fbEmoji__icon_1f63f\",\n            128576: \"-cx-PRIVATE-fbEmoji__icon_1f640\",\n            128587: \"-cx-PRIVATE-fbEmoji__icon_1f64b\",\n            128588: \"-cx-PRIVATE-fbEmoji__icon_1f64c\",\n            128589: \"-cx-PRIVATE-fbEmoji__icon_1f64d\",\n            128591: \"-cx-PRIVATE-fbEmoji__icon_1f64f\",\n            9757: \"-cx-PRIVATE-fbEmoji__icon_261d\",\n            9786: \"-cx-PRIVATE-fbEmoji__icon_263a\",\n            9889: \"-cx-PRIVATE-fbEmoji__icon_26a1\",\n            9924: \"-cx-PRIVATE-fbEmoji__icon_26c4\",\n            9994: \"-cx-PRIVATE-fbEmoji__icon_270a\",\n            9995: \"-cx-PRIVATE-fbEmoji__icon_270b\",\n            9996: \"-cx-PRIVATE-fbEmoji__icon_270c\",\n            9728: \"-cx-PRIVATE-fbEmoji__icon_2600\",\n            9729: \"-cx-PRIVATE-fbEmoji__icon_2601\",\n            9748: \"-cx-PRIVATE-fbEmoji__icon_2614\",\n            9749: \"-cx-PRIVATE-fbEmoji__icon_2615\",\n            10024: \"-cx-PRIVATE-fbEmoji__icon_2728\",\n            10084: \"-cx-PRIVATE-fbEmoji__icon_2764\"\n        }\n    };\n});\n__d(\"Utf16\", [], function(a, b, c, d, e, f) {\n    var g = {\n        decode: function(h) {\n            switch (h.length) {\n              case 1:\n                return h.charCodeAt(0);\n              case 2:\n                return ((65536 | ((((h.charCodeAt(0) - 55296)) * 1024))) | ((h.charCodeAt(1) - 56320)));\n            };\n        },\n        encode: function(h) {\n            if ((h < 65536)) {\n                return String.fromCharCode(h);\n            }\n             else return (String.fromCharCode((55296 + ((((h - 65536)) >> 10)))) + String.fromCharCode((56320 + ((h \u0025 1024)))))\n        ;\n        }\n    };\n    e.exports = g;\n});\n__d(\"Emoji\", [\"cx\",\"DOM\",\"Emote\",\"SupportedEmoji\",\"htmlize\",\"Utf16\",], function(a, b, c, d, e, f) {\n    var g = b(\"cx\"), h = b(\"DOM\"), i = b(\"Emote\"), j = b(\"SupportedEmoji\"), k = b(\"htmlize\"), l = b(\"Utf16\"), m = e.exports = {\n        htmlEmojiAndEmote: function(n, o) {\n            return m.htmlEmoji(n, function(p) {\n                return i.htmlEmote(p, o);\n            });\n        },\n        htmlEmoji: function(n, o) {\n            if ((typeof o != \"function\")) {\n                o = k;\n            };\n            var p = n, q = [];\n            while (true) {\n                var r = j.utf16Regex.exec(p);\n                if ((!r || !r.length)) {\n                    break;\n                };\n                var s = r[0], t = p.indexOf(s);\n                q.push(o(p.substring(0, t)));\n                var u = l.decode(s);\n                if (j.emoji[u]) {\n                    var v = ((\"-cx-PRIVATE-fbEmoji__icon -cx-PRIVATE-fbEmoji__size_16\" + \" \") + j.emoji[u]), w = h.create(\"span\", {\n                        className: v\n                    });\n                    q.push(h.create(\"span\", {\n                    }, w).innerHTML);\n                }\n                 else q.push(o(s));\n            ;\n                p = p.substring((t + s.length));\n            };\n            q.push(o(p));\n            return q.join(\"\");\n        }\n    };\n});\n__d(\"ErrorDialog\", [\"Dialog\",], function(a, b, c, d, e, f) {\n    var g = b(\"Dialog\"), h = {\n        showAsyncError: function(i) {\n            try {\n                return h.show(i.getErrorSummary(), i.getErrorDescription());\n            } catch (j) {\n                alert(i);\n            };\n        },\n        show: function(i, j, k, l) {\n            return (new g()).setTitle(i).setBody(j).setButtons([g.OK,]).setStackable(true).setModal(true).setHandler((k || bagofholding)).setButtonsMessage((l || \"\")).show();\n        }\n    };\n    e.exports = h;\n});\n__d(\"throttle\", [\"debounce\",], function(a, b, c, d, e, f) {\n    var g = b(\"debounce\");\n    function h(i, j, k) {\n        return g(i, j, k, false, true);\n    };\n    e.exports = h;\n});\n__d(\"FullScreen\", [\"event-extensions\",\"Arbiter\",\"CSS\",\"UserAgent\",\"copyProperties\",\"throttle\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"CSS\"), i = b(\"UserAgent\"), j = b(\"copyProperties\"), k = b(\"throttle\"), l = j(new g(), {\n        listenForEvent: function(m) {\n            var n = k(this.onChange, 0, this);\n            Event.listen(m, {\n                webkitfullscreenchange: n,\n                mozfullscreenchange: n,\n                fullscreenchange: n\n            });\n            Event.listen(document, {\n                webkitfullscreenchange: n,\n                mozfullscreenchange: n,\n                fullscreenchange: n\n            });\n        },\n        enableFullScreen: function(m) {\n            this.listenForEvent(m);\n            if (m.webkitRequestFullScreen) {\n                if (i.chrome()) {\n                    m.webkitRequestFullScreen(Element.ALLOW_KEYBOARD_INPUT);\n                }\n                 else m.webkitRequestFullScreen();\n            ;\n            }\n             else if (m.mozRequestFullScreen) {\n                m.mozRequestFullScreen();\n            }\n             else if (m.requestFullScreen) {\n                m.requestFullScreen();\n            }\n             else return false\n            \n            \n        ;\n            return true;\n        },\n        disableFullScreen: function() {\n            if (document.webkitCancelFullScreen) {\n                document.webkitCancelFullScreen();\n            }\n             else if (document.mozCancelFullScreen) {\n                document.mozCancelFullScreen();\n            }\n             else if (document.cancelFullScreen) {\n                document.cancelFullScreen();\n            }\n             else if (document.exitFullScreen) {\n                document.exitFullScreen();\n            }\n             else return false\n            \n            \n            \n        ;\n            return true;\n        },\n        isFullScreen: function() {\n            return (((document.webkitIsFullScreen || document.fullScreen) || document.mozFullScreen));\n        },\n        toggleFullScreen: function(m) {\n            if (this.isFullScreen()) {\n                this.disableFullScreen();\n                return false;\n            }\n             else return this.enableFullScreen(m)\n        ;\n            return false;\n        },\n        onChange: function() {\n            var m = this.isFullScreen();\n            h.conditionClass(document.body, \"fullScreen\", m);\n            this.inform(\"changed\");\n        },\n        isSupported: function() {\n            return (((((document.webkitCancelFullScreen && i.chrome())) || document.mozCancelFullScreen) || document.cancelFullScreen) || document.exitFullScreen);\n        }\n    });\n    e.exports = l;\n});\n__d(\"ImageUtils\", [\"UserAgent\",], function(a, b, c, d, e, f) {\n    var g = b(\"UserAgent\"), h = {\n        hasLoaded: function(i) {\n            if ((i.naturalWidth !== undefined)) {\n                return (i.complete && (i.width !== 0));\n            }\n             else if ((((i.height == 20) && (i.width == 20)) && i.complete)) {\n                return false;\n            }\n             else if (((i.complete === undefined) && (g.safari() < 500))) {\n                var j = new Image();\n                j.src = i.src;\n                return j.complete;\n            }\n            \n            \n        ;\n            return i.complete;\n        }\n    };\n    e.exports = h;\n});\n__d(\"flattenArray\", [], function(a, b, c, d, e, f) {\n    function g(h) {\n        var i = [];\n        while (h.length) {\n            var j = h.pop();\n            if (Array.isArray(j)) {\n                Array.prototype.push.apply(h, j);\n            }\n             else i.push(j);\n        ;\n        };\n        return i.reverse();\n    };\n    e.exports = g;\n});\n__d(\"JSXDOM\", [\"DOM\",\"flattenArray\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"flattenArray\"), i = [\"a\",\"br\",\"button\",\"checkbox\",\"dd\",\"div\",\"dl\",\"dt\",\"form\",\"h1\",\"h2\",\"h3\",\"h4\",\"h5\",\"h6\",\"hr\",\"i\",\"iframe\",\"img\",\"input\",\"label\",\"li\",\"option\",\"p\",\"pre\",\"select\",\"span\",\"strong\",\"table\",\"td\",\"textarea\",\"th\",\"tr\",\"ul\",], j = {\n    };\n    i.forEach(function(k) {\n        var l = function(m) {\n            var n;\n            if (m.children) {\n                n = (Array.isArray(m.children) ? h(m.children) : h([m.children,]));\n                delete m.children;\n            }\n        ;\n            return g.create(k, m, n);\n        };\n        j[k] = l;\n    });\n    e.exports = j;\n});\n__d(\"LayerStopBlur\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\");\n    function h(i) {\n        this._layer = i;\n    };\n    g(h.prototype, {\n        _subscriptions: null,\n        _onBlur: null,\n        enable: function() {\n            this._subscriptions = [this._layer.subscribe(\"show\", this._attach.bind(this)),this._layer.subscribe(\"hide\", this._detach.bind(this)),];\n            if (this._layer.isShown()) {\n                this._attach();\n            };\n        },\n        disable: function() {\n            this._detach();\n            while (this._subscriptions.length) {\n                this._subscriptions.pop().unsubscribe();;\n            };\n            this._subscriptions = null;\n        },\n        _detach: function() {\n            (this._onBlur && this._onBlur.unsubscribe());\n            this._onBlur = null;\n        },\n        _attach: function() {\n            (function() {\n                this._onBlur = this._layer.subscribe(\"blur\", function() {\n                    return false;\n                });\n            }).bind(this).defer();\n        }\n    });\n    e.exports = h;\n});\n__d(\"ScrollableArea\", [\"array-extensions\",\"event-extensions\",\"Animation\",\"ArbiterMixin\",\"CSS\",\"DataStore\",\"DOM\",\"Parent\",\"Run\",\"SimpleDrag\",\"Style\",\"UserAgent\",\"Vector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    var g = b(\"Animation\"), h = b(\"ArbiterMixin\"), i = b(\"CSS\"), j = b(\"DataStore\"), k = b(\"DOM\"), l = b(\"Parent\"), m = b(\"Run\"), n = b(\"SimpleDrag\"), o = b(\"Style\"), p = b(\"UserAgent\"), q = b(\"Vector\"), r = b(\"copyProperties\");\n    function s(t, u) {\n        if (!t) {\n            return\n        };\n        u = (u || {\n        });\n        this._elem = t;\n        this._wrap = k.find(t, \"div.uiScrollableAreaWrap\");\n        this._body = k.find(this._wrap, \"div.uiScrollableAreaBody\");\n        this._content = k.find(this._body, \"div.uiScrollableAreaContent\");\n        this._track = k.find(t, \"div.uiScrollableAreaTrack\");\n        this._gripper = k.find(this._track, \"div.uiScrollableAreaGripper\");\n        this._options = u;\n        this.adjustGripper.bind(this).defer();\n        this._listeners = [Event.listen(this._wrap, \"scroll\", this._handleScroll.bind(this)),];\n        if ((u.fade !== false)) {\n            this._listeners.push(Event.listen(t, \"mouseenter\", this.showScrollbar.shield(this)), Event.listen(t, \"mousemove\", this._handleMousemove.bind(this)), Event.listen(t, \"mouseout\", this.hideScrollbar.shield(this)));\n        };\n        if ((p.safari() || p.chrome())) {\n            this._listeners.push(Event.listen(t, \"mousedown\", function() {\n                var v = Event.listen(window, \"mouseup\", function() {\n                    if (t.scrollLeft) {\n                        t.scrollLeft = 0;\n                    };\n                    v.remove();\n                });\n            }));\n        }\n         else if (p.firefox()) {\n            this._wrap.addEventListener(\"DOMMouseScroll\", function(event) {\n                ((event.axis === event.HORIZONTAL_AXIS) && event.preventDefault());\n            }, false);\n        }\n    ;\n        this.initDrag();\n        j.set(this._elem, \"ScrollableArea\", this);\n        if (!u.persistent) {\n            m.onLeave(this.destroy.bind(this));\n        };\n    };\n    r(s, {\n        renderDOM: function() {\n            var t = k.create(\"div\", {\n                className: \"uiScrollableAreaContent\"\n            }), u = k.create(\"div\", {\n                className: \"uiScrollableAreaBody\"\n            }, t), v = k.create(\"div\", {\n                className: \"uiScrollableAreaWrap\"\n            }, u), w = k.create(\"div\", {\n                className: \"uiScrollableArea native\"\n            }, v);\n            return {\n                root: w,\n                wrap: v,\n                body: u,\n                content: t\n            };\n        },\n        fromNative: function(t, u) {\n            if ((!i.hasClass(t, \"uiScrollableArea\") || !i.hasClass(t, \"native\"))) {\n                return\n            };\n            u = (u || {\n            });\n            i.removeClass(t, \"native\");\n            var v = k.create(\"div\", {\n                className: \"uiScrollableAreaTrack\"\n            }, k.create(\"div\", {\n                className: \"uiScrollableAreaGripper\"\n            }));\n            if ((u.fade !== false)) {\n                i.addClass(t, \"fade\");\n                i.addClass(v, \"invisible_elem\");\n            }\n             else i.addClass(t, \"nofade\");\n        ;\n            k.appendContent(t, v);\n            var w = new s(t, u);\n            w.resize();\n            return w;\n        },\n        getInstance: function(t) {\n            var u = l.byClass(t, \"uiScrollableArea\");\n            return (u ? j.get(u, \"ScrollableArea\") : null);\n        },\n        poke: function(t) {\n            var u = s.getInstance(t);\n            (u && u.poke());\n        }\n    });\n    r(s.prototype, h, {\n        initDrag: function() {\n            var t = new n(this._gripper);\n            t.subscribe(\"start\", function(u, event) {\n                if (!((((event.which && (event.which === 1))) || ((event.button && (event.button === 1)))))) {\n                    return\n                };\n                var v = q.getEventPosition(event).y, w = this._gripper.offsetTop, x = t.subscribe(\"update\", function(z, event) {\n                    var aa = (q.getEventPosition(event).y - v), ba = this._elem.clientHeight, ca = this._content.offsetHeight, da = this._track.offsetHeight, ea = ((ba / ca) * da), fa = (ca - this._wrap.offsetHeight), ga = (w + aa), ha = (da - ea);\n                    ga = Math.max(Math.min(ga, ha), 0);\n                    var ia = ((ga / ha) * fa);\n                    this._wrap.scrollTop = ia;\n                }.bind(this)), y = t.subscribe(\"end\", function() {\n                    t.unsubscribe(x);\n                    t.unsubscribe(y);\n                });\n            }.bind(this));\n        },\n        adjustGripper: function() {\n            var t = this._elem.clientHeight, u = this._content.offsetHeight, v = this._track.offsetHeight, w = ((t / u) * v);\n            if ((w < v)) {\n                o.set(this._gripper, \"height\", (w + \"px\"));\n                var x = ((this._wrap.scrollTop / u) * v);\n                o.set(this._gripper, \"top\", (x + \"px\"));\n                i.show(this._gripper);\n            }\n             else i.hide(this._gripper);\n        ;\n            this._checkContentBoundaries();\n            return this;\n        },\n        _checkContentBoundaries: function() {\n            i.conditionClass(this._elem, \"contentBefore\", (this._wrap.scrollTop > 0));\n            i.conditionClass(this._elem, \"contentAfter\", !this.isScrolledToBottom());\n        },\n        destroy: function() {\n            this._listeners.forEach(function(t) {\n                t.remove();\n            });\n            this._listeners.length = 0;\n        },\n        _handleMousemove: function(event) {\n            var t = q.getElementPosition(this._track).x, u = q.getElementDimensions(this._track).x;\n            if ((Math.abs(((t + (u / 2)) - q.getEventPosition(event).x)) < 25)) {\n                this.showScrollbar(false);\n            }\n             else this.hideScrollbar();\n        ;\n        },\n        _handleScroll: function(event) {\n            this.adjustGripper();\n            if ((this._options.fade !== false)) {\n                this.showScrollbar();\n            };\n            this.inform(\"scroll\");\n        },\n        hideScrollbar: function(t) {\n            if (!this._scrollbarVisible) {\n                return this\n            };\n            this._scrollbarVisible = false;\n            if (this._hideTimeout) {\n                clearTimeout(this._hideTimeout);\n                this._hideTimeout = null;\n            }\n        ;\n            if (t) {\n                o.set(this._track, \"opacity\", 0);\n                i.addClass.curry(this._track, \"invisible_elem\");\n            }\n             else this._hideTimeout = function() {\n                if (this._hideAnimation) {\n                    this._hideAnimation.stop();\n                    this._hideAnimation = null;\n                }\n            ;\n                this._hideAnimation = (new g(this._track)).from(\"opacity\", 1).to(\"opacity\", 0).duration(250).ondone(i.addClass.curry(this._track, \"invisible_elem\")).go();\n            }.bind(this).defer(750);\n        ;\n            return this;\n        },\n        resize: function() {\n            var t = q.getElementDimensions(this._elem).x;\n            if (!this._options.fade) {\n                t -= 10;\n            };\n            t = Math.max(0, t);\n            o.set(this._body, \"width\", (t + \"px\"));\n            return this;\n        },\n        showScrollbar: function(t) {\n            this.adjustGripper();\n            if (this._scrollbarVisible) {\n                return this\n            };\n            this._scrollbarVisible = true;\n            if (this._hideTimeout) {\n                clearTimeout(this._hideTimeout);\n                this._hideTimeout = null;\n            }\n        ;\n            if (this._hideAnimation) {\n                this._hideAnimation.stop();\n                this._hideAnimation = null;\n            }\n        ;\n            o.set(this._track, \"opacity\", 1);\n            i.removeClass(this._track, \"invisible_elem\");\n            if ((t !== false)) {\n                this.hideScrollbar();\n            };\n            return this;\n        },\n        isScrolledToBottom: function() {\n            return (this._wrap.scrollTop >= (this._wrap.scrollHeight - this._wrap.clientHeight));\n        },\n        scrollToBottom: function(t) {\n            this.setScrollTop(this._wrap.scrollHeight, t);\n        },\n        scrollToTop: function(t) {\n            this.setScrollTop(0, t);\n        },\n        scrollIntoView: function(t, u) {\n            var v = this._wrap.clientHeight, w = t.offsetHeight, x = this._wrap.scrollTop, y = (x + v), z = t.offsetTop, aa = (z + w);\n            if (((z < x) || (v < w))) {\n                this.setScrollTop(z, u);\n            }\n             else if ((aa > y)) {\n                this.setScrollTop((x + ((aa - y))), u);\n            }\n        ;\n        },\n        poke: function() {\n            var t = this._wrap.scrollTop;\n            this._wrap.scrollTop += 1;\n            this._wrap.scrollTop -= 1;\n            this._wrap.scrollTop = t;\n            return this.showScrollbar(false);\n        },\n        getScrollTop: function() {\n            return this._wrap.scrollTop;\n        },\n        getScrollHeight: function() {\n            return this._wrap.scrollHeight;\n        },\n        setScrollTop: function(t, u) {\n            if ((u !== false)) {\n                if (this._scrollTopAnimation) {\n                    this._scrollTopAnimation.stop();\n                };\n                this._scrollTopAnimation = (new g(this._wrap)).to(\"scrollTop\", t).ease(g.ease.end).go();\n            }\n             else this._wrap.scrollTop = t;\n        ;\n        }\n    });\n    e.exports = s;\n});\n__d(\"ScrollableTypeaheadBehavior\", [\"DOM\",\"CSS\",\"Style\",\"Parent\",\"cx\",\"ScrollableArea\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"CSS\"), i = b(\"Style\"), j = b(\"Parent\"), k = b(\"cx\"), l = b(\"ScrollableArea\"), m = b(\"copyProperties\");\n    function n(o) {\n        this._typeahead = o;\n    };\n    m(n.prototype, {\n        _subscriptions: null,\n        _scrollableElems: null,\n        _scrollableArea: null,\n        _showScrollbar: null,\n        enable: function() {\n            this._scrollableElems = (l.renderDOM());\n            h.addClass(this._scrollableElems.root, \"-cx-PRIVATE-scrollableTypeahead__ScrollableTypeaheadArea\");\n            g.appendContent(this._typeahead.getView().element, this._scrollableElems.root);\n            this._typeahead.getView().content = this._scrollableElems.content;\n            this._scrollableArea = (l.fromNative(this._scrollableElems.root, {\n                fade: false\n            }));\n            this._subscriptions = [this._typeahead.getView().subscribe(\"reset\", this._reset.bind(this)),this._typeahead.getView().subscribe(\"render\", this._render.bind(this)),this._typeahead.getView().subscribe(\"beforeRender\", this._beforeRender.bind(this)),this._typeahead.getView().subscribe(\"next\", this._scrollHelper.bind(this)),this._typeahead.getView().subscribe(\"prev\", this._scrollHelper.bind(this)),];\n            i.set(this._scrollableElems.wrap, \"height\", \"0px\");\n            h.removeClass(this._scrollableElems.root, \"-cx-PRIVATE-scrollableTypeahead__hasResults\");\n        },\n        disable: function() {\n            while (this._subscriptions.length) {\n                this._subscriptions.pop().unsubscribe();;\n            };\n            this._subscriptions = null;\n        },\n        _reset: function() {\n            i.set(this._scrollableElems.wrap, \"height\", \"0px\");\n            h.removeClass(this._scrollableElems.root, \"-cx-PRIVATE-scrollableTypeahead__hasResults\");\n            this._scrollableArea.scrollToTop();\n        },\n        _render: function() {\n            this._scrollableArea.poke();\n            (this._showScrollbar ? this._scrollableArea.showScrollbar(false) : this._scrollableArea.hideScrollbar(true));\n            h.addClass(this._scrollableElems.root, \"-cx-PRIVATE-scrollableTypeahead__hasResults\");\n        },\n        _beforeRender: function(o, p) {\n            var q = 5;\n            if ((this._typeahead.getView().maxResults < 10)) {\n                q = 3;\n            };\n            i.set(this._scrollableElems.body, \"width\", (this._scrollableElems.wrap.offsetWidth + \"px\"));\n            if ((p.results.length < q)) {\n                i.set(this._scrollableElems.wrap, \"height\", ((((38 * p.results.length) + 4)) + \"px\"));\n                this._showScrollbar = false;\n            }\n             else {\n                this._scrollableArea.showScrollbar(false);\n                i.set(this._scrollableElems.wrap, \"height\", ((((38 * q) + 4)) + \"px\"));\n                this._showScrollbar = true;\n            }\n        ;\n        },\n        _scrollHelper: function(o, p) {\n            if (!j.byClass(p, \"uiScrollableArea\")) {\n                return\n            };\n            this._typeahead.getView().ignoreMouseover = true;\n            var q = j.byClass(p, \"uiScrollableAreaWrap\"), r = (p.offsetTop - q.offsetTop);\n            if ((r < q.scrollTop)) {\n                q.scrollTop = r;\n                return;\n            }\n        ;\n            var s = (r + p.offsetHeight);\n            if ((s > (q.scrollTop + q.offsetHeight))) {\n                q.scrollTop = (s - q.offsetHeight);\n            };\n        }\n    });\n    e.exports = n;\n});\n__d(\"legacy:LegacyScrollableTypeaheadBehavior\", [\"ScrollableTypeaheadBehavior\",], function(a, b, c, d) {\n    var e = b(\"ScrollableTypeaheadBehavior\");\n    if (!a.TypeaheadBehaviors) {\n        a.TypeaheadBehaviors = {\n        };\n    };\n    a.TypeaheadBehaviors.scrollArea = function(f) {\n        f.enableBehavior(e);\n    };\n}, 3);\n__d(\"MultiBootstrapDataSource\", [\"Class\",\"DataSource\",], function(a, b, c, d, e, f) {\n    var g = b(\"Class\"), h = b(\"DataSource\");\n    function i(j) {\n        this._bootstrapEndpoints = j.bootstrapEndpoints;\n        this.parent.construct(this, j);\n    };\n    g.extend(i, h);\n    i.prototype.bootstrapWithoutToken = function() {\n        for (var j = 0; (j < this._bootstrapEndpoints.length); j++) {\n            this.fetch(this._bootstrapEndpoints[j].endpoint, (this._bootstrapEndpoints[j].data || {\n            }), {\n                bootstrap: true\n            });;\n        };\n    };\n    e.exports = i;\n});\n__d(\"OnVisible\", [\"event-extensions\",\"Arbiter\",\"DOM\",\"Run\",\"Vector\",\"copyProperties\",\"throttle\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"DOM\"), i = b(\"Run\"), j = b(\"Vector\"), k = b(\"copyProperties\"), l = b(\"throttle\");\n    function m(n, o, p, q) {\n        this.element = n;\n        this.handler = o;\n        this.strict = p;\n        this.buffer = (q || 300);\n        this.scrollHandler = null;\n        this.reset();\n        i.onLeave(this.remove.bind(this));\n    };\n    k(m.prototype, {\n        reset: function() {\n            if (this.scrollListener) {\n                return\n            };\n            this.removed = false;\n            this.scrollHandler = l(function(n) {\n                var o = j.getElementPosition(this.element);\n                if ((!o || this.removed)) {\n                    this.remove();\n                    return;\n                }\n            ;\n                this.targetY = o.y;\n                var p = j.getScrollPosition().y, q = j.getViewportDimensions().y, r = ((p + q) + this.buffer);\n                if ((r > this.targetY)) {\n                    var s = (!this.strict || (((p - this.buffer) < ((this.targetY + j.getElementDimensions(this.element).y)))));\n                    if (s) {\n                        this.remove();\n                        this.handler(!n);\n                    }\n                ;\n                }\n            ;\n                return true;\n            }, 100, this);\n            (function() {\n                this.scrollListener = Event.listen(window, \"scroll\", this.scrollHandler);\n                this.resizeListener = Event.listen(window, \"resize\", this.scrollHandler);\n                this.domScrollListener = g.subscribe(\"dom-scroll\", this.scrollHandler);\n                this.scrollHandler.defer();\n            }).bind(this).defer();\n        },\n        remove: function() {\n            this.removed = true;\n            if (this.scrollListener) {\n                this.scrollListener.remove();\n                this.resizeListener.remove();\n                this.domScrollListener.unsubscribe();\n                this.scrollListener = this.resizeListener = this.domScrollListener = null;\n            }\n        ;\n        },\n        setBuffer: function(n) {\n            this.buffer = n;\n            (this.scrollHandler && this.scrollHandler.defer());\n        }\n    });\n    e.exports = m;\n});\n__d(\"Poller\", [\"AsyncRequest\",\"Cookie\",\"copyProperties\",\"Env\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncRequest\"), h = b(\"Cookie\"), i = b(\"copyProperties\"), j = b(\"Env\");\n    function k(l, m, n) {\n        this._clearOnQuicklingEvent = !n;\n        this._requestCallback = m;\n        this.setTimePeriod(l);\n    };\n    k.MIN_TIME_PERIOD = 2000;\n    i(k.prototype, {\n        stop: function() {\n            clearTimeout(this._token);\n            this._token = null;\n            this._cancelRequest();\n        },\n        scheduleRequest: function() {\n            this.stop();\n            if (this._timePeriod) {\n                this._token = this._makeRequest.bind(this).defer(this._timePeriod, this._clearOnQuicklingEvent);\n            };\n        },\n        requestNow: function() {\n            this.stop();\n            this._makeRequest();\n        },\n        _timePeriod: null,\n        setTimePeriod: function(l) {\n            l = (l || null);\n            if ((l && ((isNaN(l) || (l < k.MIN_TIME_PERIOD))))) {\n                return\n            };\n            if ((l && (this._timePeriod == null))) {\n                this._token = this._makeRequest.bind(this).defer(l, this._clearOnQuicklingEvent);\n            };\n            this._timePeriod = l;\n        },\n        _makeRequest: function() {\n            this._cancelRequest();\n            if (!this._isLoadUser()) {\n                return\n            };\n            var l = new g(), m = true;\n            l.setInitialHandler(function() {\n                return m;\n            });\n            this._cancelRequest = function() {\n                m = false;\n            };\n            l.setFinallyHandler(this.scheduleRequest.bind(this));\n            l.setInitialHandler = bagofholding;\n            l.setFinallyHandler = bagofholding;\n            this._requestCallback(l);\n            if (m) {\n                l.send();\n            };\n        },\n        _isLoadUser: function() {\n            return (j.user == h.get(\"c_user\"));\n        },\n        _cancelRequest: bagofholding,\n        getTimePeriod: function() {\n            return this._timePeriod;\n        }\n    });\n    e.exports = k;\n});\n__d(\"Popover\", [\"event-extensions\",\"Arbiter\",\"ArbiterMixin\",\"Class\",\"ContextualLayer\",\"ContextualLayerHideOnScroll\",\"CSS\",\"DataStore\",\"DOM\",\"Input\",\"KeyStatus\",\"LayerHideOnEscape\",\"Toggler\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"Class\"), j = b(\"ContextualLayer\"), k = b(\"ContextualLayerHideOnScroll\"), l = b(\"CSS\"), m = b(\"DataStore\"), n = b(\"DOM\"), o = b(\"Input\"), p = b(\"KeyStatus\"), q = b(\"LayerHideOnEscape\"), r = b(\"Toggler\"), s = b(\"copyProperties\");\n    r.subscribe([\"show\",\"hide\",], function(u, v) {\n        var w = m.get(v.getActive(), \"Popover\");\n        if (w) {\n            if ((u === \"show\")) {\n                w.showLayer();\n            }\n             else w.hideLayer();\n        \n        };\n    });\n    function t(u, v, w, x) {\n        this._root = u;\n        this._triggerElem = v;\n        this._behaviors = w;\n        this._config = x;\n        if (!(((v.nodeName === \"A\") && (v.rel === \"toggle\")))) {\n            Event.listen(v, \"click\", function() {\n                r.bootstrap(v);\n            });\n        };\n        m.set(u, \"Popover\", this);\n    };\n    s(t.prototype, h, {\n        _layer: null,\n        _closeListener: null,\n        ensureInit: function() {\n            if (!this._layer) {\n                this._init();\n            };\n        },\n        showLayer: function() {\n            this.ensureInit();\n            this._layer.show();\n            r.show(this._root);\n            l.addClass(this._root, \"selected\");\n            this.inform(\"show\");\n            this._triggerElem.setAttribute(\"aria-expanded\", \"true\");\n        },\n        hideLayer: function() {\n            this._layer.hide();\n            this._triggerElem.setAttribute(\"aria-expanded\", \"false\");\n        },\n        isShown: function() {\n            return this._layer.isShown();\n        },\n        setLayerContent: function(u) {\n            this.ensureInit();\n            this._layer.setContent(u);\n        },\n        _init: function() {\n            var u = new j({\n                context: this._triggerElem,\n                position: \"below\"\n            }, n.create(\"div\"));\n            u.enableBehaviors([k,q,]);\n            r.createInstance(u.getRoot()).setSticky(false);\n            u.subscribe(\"hide\", this._onLayerHide.bind(this));\n            (this._behaviors && u.enableBehaviors(this._behaviors));\n            this._layer = u;\n            if (this._config.alignh) {\n                this._layer.setAlignment(this._config.alignh);\n            };\n            if (this._config.layer_content) {\n                this._layer.setContent(this._config.layer_content);\n            };\n            this.inform(\"init\", null, g.BEHAVIOR_PERSISTENT);\n        },\n        _onLayerHide: function() {\n            r.hide(this._root);\n            l.removeClass(this._root, \"selected\");\n            this.inform(\"hide\");\n            if (p.isKeyDown()) {\n                o.focus(this._triggerElem);\n            };\n        }\n    });\n    e.exports = t;\n});\n__d(\"PopoverMenuInterface\", [\"Arbiter\",\"ArbiterMixin\",\"Class\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"Class\"), j = b(\"copyProperties\");\n    function k() {\n    \n    };\n    j(k.prototype, h, {\n        getRoot: bagofholding,\n        onShow: bagofholding,\n        onHide: bagofholding,\n        focusAnItem: bagof(false),\n        blur: bagofholding,\n        handleKeydown: bagof(false),\n        done: function() {\n            this.inform(\"done\");\n        }\n    });\n    e.exports = k;\n});\n__d(\"PopoverAsyncMenuLoading\", [\"Class\",\"copyProperties\",\"DOM\",\"PopoverMenuInterface\",], function(a, b, c, d, e, f) {\n    var g = b(\"Class\"), h = b(\"copyProperties\"), i = b(\"DOM\"), j = b(\"PopoverMenuInterface\");\n    function k(l) {\n        this.parent.construct(this);\n        this._className = (l || \"\");\n    };\n    g.extend(k, j);\n    h(k.prototype, {\n        _root: null,\n        getRoot: function() {\n            if (!this._root) {\n                this._root = i.create(\"div\", {\n                    className: this._className\n                }, i.create(\"div\", {\n                    className: \"uiMenuXBorder\"\n                }, i.create(\"div\", {\n                    className: \"uiMenuX uiMenuXLoading\"\n                }, i.create(\"span\", {\n                    className: \"spinner\"\n                }))));\n            };\n            return this._root;\n        }\n    });\n    e.exports = k;\n});\n__d(\"PopoverMenu\", [\"event-extensions\",\"Arbiter\",\"ArbiterMixin\",\"ARIA\",\"BehaviorsMixin\",\"Class\",\"Input\",\"Keys\",\"KeyStatus\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"ARIA\"), j = b(\"BehaviorsMixin\"), k = b(\"Class\"), l = b(\"Input\"), m = b(\"Keys\"), n = b(\"KeyStatus\"), o = b(\"copyProperties\");\n    function p(q, r, s, t) {\n        this._popover = q;\n        this._triggerElem = r;\n        this._initialMenu = s;\n        q.subscribe(\"init\", this._onLayerInit.bind(this));\n        q.subscribe(\"show\", this._onPopoverShow.bind(this));\n        q.subscribe(\"hide\", this._onPopoverHide.bind(this));\n        (t && this.enableBehaviors(t));\n    };\n    o(p.prototype, h, j);\n    o(p.prototype, {\n        _keydownListener: null,\n        _popoverShown: false,\n        setMenu: function(q) {\n            this._menu = q;\n            var r = q.getRoot();\n            this._popover.setLayerContent(r);\n            q.subscribe(\"done\", this._onMenuDone.bind(this));\n            if (this._popoverShown) {\n                this._menu.onShow();\n            };\n            i.owns(this._triggerElem, r);\n            this.inform(\"setMenu\", null, g.BEHAVIOR_PERSISTENT);\n        },\n        getPopover: function() {\n            return this._popover;\n        },\n        getTriggerElem: function() {\n            return this._triggerElem;\n        },\n        getMenu: function() {\n            return this._menu;\n        },\n        _onLayerInit: function() {\n            this.setMenu(this._initialMenu);\n        },\n        _onPopoverShow: function() {\n            if (this._menu) {\n                this._menu.onShow();\n                if (n.isKeyDown()) {\n                    this._menu.focusAnItem();\n                };\n                this._keydownListener = Event.listen(document.documentElement, \"keydown\", this._handleKeydown.bind(this));\n            }\n        ;\n            this._popoverShown = true;\n        },\n        _onPopoverHide: function() {\n            if (this._menu) {\n                this._menu.onHide();\n            };\n            if (this._keydownListener) {\n                this._keydownListener.remove();\n                this._keydownListener = null;\n            }\n        ;\n            this._popoverShown = false;\n        },\n        _handleKeydown: function(q) {\n            if (q.getModifiers().any) {\n                return\n            };\n            var r = Event.getKeyCode(q);\n            switch (r) {\n              case m.RETURN:\n                return;\n              case m.UP:\n            \n              case m.DOWN:\n                this._menu.handleKeydown(r);\n                break;\n              default:\n                if ((this._menu.handleKeydown(r) === false)) {\n                    this._menu.blur();\n                    this._menu.handleKeydown(r);\n                }\n            ;\n                break;\n            };\n            q.prevent();\n        },\n        _onMenuDone: function(q) {\n            this._popover.hideLayer.bind(this._popover).defer();\n            if (n.isKeyDown()) {\n                l.focus(this._triggerElem);\n            };\n        }\n    });\n    e.exports = p;\n});\n__d(\"PopoverAsyncMenu\", [\"event-extensions\",\"AsyncRequest\",\"Class\",\"CSS\",\"DOM\",\"PopoverAsyncMenuLoading\",\"PopoverMenu\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"AsyncRequest\"), h = b(\"Class\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"PopoverAsyncMenuLoading\"), l = b(\"PopoverMenu\"), m = b(\"copyProperties\"), n = {\n    }, o = 0;\n    function p(q, r, s, t, u) {\n        this._endpoint = t;\n        this._loadingMenu = s;\n        this._instanceId = o++;\n        n[this._instanceId] = this;\n        this._mouseoverListener = Event.listen(r, \"mouseover\", this._fetchMenu.bind(this));\n        this.parent.construct(this, q, r, null, u);\n    };\n    p.setMenu = function(q, r) {\n        n[q].setMenu(r);\n    };\n    h.extend(p, l);\n    m(p.prototype, {\n        _fetched: false,\n        _mouseoverListener: null,\n        _onLayerInit: function() {\n            if (!this._menu) {\n                this.setMenu(this._loadingMenu);\n            };\n            this._fetchMenu();\n        },\n        _fetchMenu: function() {\n            if (this._fetched) {\n                return\n            };\n            new g().setURI(this._endpoint).setData({\n                pmid: this._instanceId\n            }).send();\n            this._fetched = true;\n            if (this._mouseoverListener) {\n                this._mouseoverListener.remove();\n                this._mouseoverListener = null;\n            }\n        ;\n        }\n    });\n    e.exports = p;\n});\n__d(\"PopoverMenuOverlappingBorder\", [\"function-extensions\",\"CSS\",\"DOM\",\"Style\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"Style\"), j = b(\"copyProperties\");\n    function k(l) {\n        this._popoverMenu = l;\n        this._popover = l.getPopover();\n        this._triggerElem = l.getTriggerElem();\n    };\n    j(k.prototype, {\n        _shortBorder: null,\n        _setMenuSubscription: null,\n        _showSubscription: null,\n        _menuSubscription: null,\n        enable: function() {\n            this._setMenuSubscription = this._popoverMenu.subscribe(\"setMenu\", this._onSetMenu.bind(this));\n        },\n        disable: function() {\n            this._popoverMenu.unsubscribe(this._setMenuSubscription);\n            this._setMenuSubscription = null;\n            this._removeBorderSubscriptions();\n            this._removeShortBorder();\n        },\n        _onSetMenu: function() {\n            this._removeBorderSubscriptions();\n            this._menu = this._popoverMenu.getMenu();\n            this._renderShortBorder(this._menu.getRoot());\n            this._showSubscription = this._popover.subscribe(\"show\", this._updateBorder.bind(this));\n            this._menuSubscription = this._menu.subscribe([\"change\",\"resize\",], Function.prototype.defer.shield(this._updateBorder.bind(this)));\n            this._updateBorder();\n        },\n        _updateBorder: function() {\n            var l = this._menu.getRoot(), m = this._triggerElem.offsetWidth;\n            i.set(l, \"min-width\", (m + \"px\"));\n            var n = Math.max((l.offsetWidth - m), 0);\n            i.set(this._shortBorder, \"width\", (n + \"px\"));\n        },\n        _renderShortBorder: function(l) {\n            this._shortBorder = h.create(\"div\", {\n                className: \"uiMenuXShortBorder\"\n            });\n            h.appendContent(l, this._shortBorder);\n            g.addClass(l, \"uiMenuXWithShortBorder\");\n        },\n        _removeShortBorder: function() {\n            if (this._shortBorder) {\n                h.remove(this._shortBorder);\n                this._shortBorder = null;\n                g.removeClass(this._popoverMenu.getMenu().getRoot(), \"uiMenuXShortBorder\");\n            }\n        ;\n        },\n        _removeBorderSubscriptions: function() {\n            if (this._showSubscription) {\n                this._popover.unsubscribe(this._showSubscription);\n                this._showSubscription = null;\n            }\n        ;\n            if (this._menuSubscription) {\n                this._menu.unsubscribe(this._menuSubscription);\n                this._menuSubscription = null;\n            }\n        ;\n        }\n    });\n    e.exports = k;\n});\n__d(\"PrivacyModel\", [\"PrivacyConst\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"PrivacyConst\"), h = b(\"copyProperties\");\n    function i() {\n        this.value = g.BaseValue.ALL_FRIENDS;\n        this.friends = g.FriendsValue.NO_FRIENDS;\n        this.networks = [];\n        this.objects = [];\n        this.lists = [];\n        this.lists_x = [];\n        this.list_anon = 0;\n        this.ids_anon = [];\n        this.list_x_anon = 0;\n        this.ids_x_anon = [];\n        this.tdata = {\n        };\n        return this;\n    };\n    h(i.prototype, {\n        init: function(j, k, l, m, n, o, p, q, r, s, t) {\n            this.value = j;\n            this.friends = k;\n            this.networks = l.slice();\n            this.objects = m.slice();\n            this.lists = n.slice();\n            this.lists_x = o.slice();\n            this.list_anon = p;\n            this.ids_anon = q.slice();\n            this.list_x_anon = r;\n            this.ids_x_anon = s.slice();\n            t = (t || {\n            });\n            h(this.tdata, t);\n        },\n        clone: function() {\n            var j = new i();\n            j.init(this.value, this.friends, this.networks, this.objects, this.lists, this.lists_x, this.list_anon, this.ids_anon, this.list_x_anon, this.ids_x_anon, this.tdata);\n            return j;\n        },\n        getData: function() {\n            var j = [\"value\",\"friends\",\"networks\",\"objects\",\"lists\",\"lists_x\",\"list_anon\",\"ids_anon\",\"list_x_anon\",\"ids_x_anon\",], k = {\n            };\n            for (var l = 0; (l < j.length); ++l) {\n                var m = j[l];\n                k[m] = this[m];\n            };\n            return k;\n        }\n    });\n    e.exports = i;\n});\n__d(\"UIPagelet\", [\"AjaxPipeRequest\",\"AsyncRequest\",\"DOM\",\"HTML\",\"ScriptPathState\",\"URI\",\"copyProperties\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"AjaxPipeRequest\"), h = b(\"AsyncRequest\"), i = b(\"DOM\"), j = b(\"HTML\"), k = b(\"ScriptPathState\"), l = b(\"URI\"), m = b(\"copyProperties\"), n = b(\"ge\");\n    function o(p, q, r, s) {\n        this._id = (p || null);\n        this._element = n((p || i.create(\"div\")));\n        this._src = (q || null);\n        this._context_data = (r || {\n        });\n        this._data = (s || {\n        });\n        this._handler = bagofholding;\n        this._request = null;\n        this._use_ajaxpipe = false;\n        this._is_bundle = true;\n        this._allow_cross_page_transition = false;\n        this._append = false;\n        return this;\n    };\n    o.loadFromEndpoint = function(p, q, r, s) {\n        s = (s || {\n        });\n        var t = \"/ajax/pagelet/generic.php/\";\n        if (s.intern) {\n            t = (\"/intern\" + t);\n        };\n        var u = ((t + p)).replace(/\\/+/g, \"/\");\n        if (s.subdomain) {\n            u = l(u).setSubdomain(s.subdomain);\n        };\n        var v = new o(q, u, r).setUseAjaxPipe(s.usePipe).setPageletCacheMiss(s.pageletCacheMiss).setBundleOption(((p.substring(0, 8) != \"/intern/\") && (s.bundle !== false))).setAppend(s.append).setJSNonBlock(s.jsNonblock).setForceFinish(s.forceFinish).setAutomatic(s.automatic).setDisplayCallback(s.displayCallback).setConstHeight(s.constHeight).setAllowCrossPageTransition(s.crossPage);\n        (s.handler && v.setHandler(s.handler));\n        v.go();\n        return v;\n    };\n    m(o.prototype, {\n        getElement: function(p) {\n            p = (p || false);\n            if (p) {\n                this._element = n(this._id);\n            };\n            return this._element;\n        },\n        setHandler: function(p) {\n            this._handler = p;\n            return this;\n        },\n        go: function(p, q) {\n            if (((arguments.length >= 2) || (typeof p == \"string\"))) {\n                this._src = p;\n                this._data = (q || {\n                });\n            }\n             else if ((arguments.length == 1)) {\n                this._data = p;\n            }\n        ;\n            this.refresh();\n            return this;\n        },\n        setAllowCrossPageTransition: function(p) {\n            this._allow_cross_page_transition = p;\n            return this;\n        },\n        setBundleOption: function(p) {\n            this._is_bundle = p;\n            return this;\n        },\n        refresh: function(p) {\n            var q = function(t) {\n                this._request = null;\n                if ((p && this._id)) {\n                    this._element = n(this._id);\n                };\n                var u = j(t.getPayload());\n                if (this._append) {\n                    i.appendContent(this._element, u);\n                }\n                 else i.setContent(this._element, u);\n            ;\n                this._handler();\n            }.bind(this);\n            if (this._use_ajaxpipe) {\n                k.setIsUIPageletRequest(true);\n                this._request = new g();\n                this._request.setCanvasId(this._id).setAppend(this._append).setConstHeight(this._constHeight).setJSNonBlock(this._jsNonblock).setForceFinish(this._forceFinish).setAutomatic(this._automatic).setPageletCacheMiss(this._pageletCacheMiss).setDisplayCallback(this._displayCallback);\n            }\n             else {\n                var r = this._displayCallback;\n                this._request = new h().setMethod(\"GET\").setReadOnly(true).setOption(\"bundle\", this._is_bundle).setHandler(function(t) {\n                    if (r) {\n                        r(q.curry(t));\n                    }\n                     else q(t);\n                ;\n                });\n            }\n        ;\n            var s = {\n            };\n            m(s, this._context_data);\n            m(s, this._data);\n            this._request.setURI(this._src).setAllowCrossPageTransition(this._allow_cross_page_transition).setData({\n                data: JSON.stringify(s)\n            }).send();\n            return this;\n        },\n        cancel: function() {\n            if (this._request) {\n                this._request.abort();\n            };\n        },\n        setUseAjaxPipe: function(p) {\n            this._use_ajaxpipe = !!p;\n            return this;\n        },\n        setPageletCacheMiss: function(p) {\n            this._pageletCacheMiss = p;\n            return this;\n        },\n        setAppend: function(p) {\n            this._append = !!p;\n            return this;\n        },\n        setJSNonBlock: function(p) {\n            this._jsNonblock = !!p;\n            return this;\n        },\n        setForceFinish: function(p) {\n            this._forceFinish = !!p;\n            return this;\n        },\n        setAutomatic: function(p) {\n            this._automatic = !!p;\n            return this;\n        },\n        setDisplayCallback: function(p) {\n            this._displayCallback = p;\n            return this;\n        },\n        setConstHeight: function(p) {\n            this._constHeight = !!p;\n            return this;\n        }\n    });\n    e.exports = o;\n});\n__d(\"ScrollingPager\", [\"Arbiter\",\"copyProperties\",\"CSS\",\"OnVisible\",\"UIPagelet\",\"$\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"copyProperties\"), i = b(\"CSS\"), j = b(\"OnVisible\"), k = b(\"UIPagelet\"), l = b(\"$\"), m = b(\"ge\"), n = {\n    };\n    function o(p, q, r, s) {\n        this.scroll_loader_id = p;\n        this.pagelet_src = q;\n        this.data = r;\n        this.options = (s || {\n        });\n        if (this.options.target_id) {\n            this.target_id = this.options.target_id;\n            this.options.append = true;\n        }\n         else this.target_id = p;\n    ;\n        this.handler = null;\n    };\n    h(o, {\n        REGISTERED: \"ScrollingPager/registered\",\n        getInstance: function(p) {\n            return n[p];\n        }\n    });\n    h(o.prototype, {\n        setBuffer: function(p) {\n            this.options.buffer = p;\n            (this.onvisible && this.onvisible.setBuffer(p));\n        },\n        getBuffer: function() {\n            return this.options.buffer;\n        },\n        register: function() {\n            this.onvisible = new j(l(this.scroll_loader_id), this.getHandler(), false, this.options.buffer, this.options);\n            n[this.scroll_loader_id] = this;\n            g.inform(o.REGISTERED, {\n                id: this.scroll_loader_id\n            });\n        },\n        getInstance: function(p) {\n            return n[p];\n        },\n        getHandler: function() {\n            if (this.handler) {\n                return this.handler\n            };\n            function p(q) {\n                var r = m(this.scroll_loader_id);\n                if (!r) {\n                    this.onvisible.remove();\n                    return;\n                }\n            ;\n                i.addClass(r.firstChild, \"async_saving\");\n                var s = this.options.handler;\n                this.options.handler = function() {\n                    g.inform(\"ScrollingPager/loadingComplete\");\n                    (s && s.apply(null, arguments));\n                };\n                if (q) {\n                    this.data.pager_fired_on_init = true;\n                };\n                k.loadFromEndpoint(this.pagelet_src, this.target_id, this.data, this.options);\n            };\n            return p.bind(this);\n        },\n        setHandler: function(p) {\n            this.handler = p;\n        },\n        removeOnVisible: function() {\n            this.onvisible.remove();\n        }\n    });\n    e.exports = o;\n});\n__d(\"InputSelection\", [\"DOM\",\"Input\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"Input\"), i = {\n        get: function(j) {\n            if (!document.selection) {\n                return {\n                    start: j.selectionStart,\n                    end: j.selectionEnd\n                }\n            };\n            var k = document.selection.createRange();\n            if ((k.parentElement() !== j)) {\n                return {\n                    start: 0,\n                    end: 0\n                }\n            };\n            var l = j.value.length;\n            if (g.isNodeOfType(j, \"input\")) {\n                return {\n                    start: -k.moveStart(\"character\", -l),\n                    end: -k.moveEnd(\"character\", -l)\n                };\n            }\n             else {\n                var m = k.duplicate();\n                m.moveToElementText(j);\n                m.setEndPoint(\"StartToEnd\", k);\n                var n = (l - m.text.length);\n                m.setEndPoint(\"StartToStart\", k);\n                return {\n                    start: (l - m.text.length),\n                    end: n\n                };\n            }\n        ;\n        },\n        set: function(j, k, l) {\n            if ((typeof l == \"undefined\")) {\n                l = k;\n            };\n            if (document.selection) {\n                if ((j.tagName == \"TEXTAREA\")) {\n                    var m = ((j.value.slice(0, k).match(/\\r/g) || [])).length, n = ((j.value.slice(k, l).match(/\\r/g) || [])).length;\n                    k -= m;\n                    l -= (m + n);\n                }\n            ;\n                var o = j.createTextRange();\n                o.collapse(true);\n                o.moveStart(\"character\", k);\n                o.moveEnd(\"character\", (l - k));\n                o.select();\n            }\n             else {\n                j.selectionStart = k;\n                j.selectionEnd = Math.min(l, j.value.length);\n                h.focus(j);\n            }\n        ;\n        }\n    };\n    e.exports = i;\n});\n__d(\"ControlledReferer\", [\"event-extensions\",\"URI\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"URI\"), h = {\n        useFacebookReferer: function(i, j, k) {\n            var l = false;\n            function m() {\n                if (l) {\n                    return\n                };\n                l = true;\n                i.contentWindow.document.body.style.margin = 0;\n                j();\n            };\n            var n;\n            if ((document.domain !== \"facebook.com\")) {\n                n = \"/intern/common/referer_frame.php\";\n            }\n             else if (g().isSecure()) {\n                n = \"https://s-static.ak.facebook.com/common/referer_frame.php\";\n            }\n             else n = \"http://static.ak.facebook.com/common/referer_frame.php\";\n            \n        ;\n            if (k) {\n                n += (\"?fb_source=\" + k);\n            };\n            Event.listen(i, \"load\", m);\n            i.src = n;\n        },\n        useFacebookRefererHtml: function(i, j, k) {\n            h.useFacebookReferer(i, function() {\n                i.contentWindow.document.body.innerHTML = j;\n            }, k);\n        }\n    };\n    e.exports = h;\n});\n__d(\"swfobject\", [\"AsyncRequest\",\"Bootloader\",\"ControlledReferer\",\"copyProperties\",\"CSS\",\"DOM\",\"function-extensions\",\"ge\",\"htmlSpecialChars\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncRequest\"), h = b(\"Bootloader\"), i = b(\"ControlledReferer\"), j = b(\"copyProperties\"), k = b(\"CSS\"), l = b(\"DOM\");\n    b(\"function-extensions\");\n    var m = b(\"ge\"), n = b(\"htmlSpecialChars\");\n    if ((typeof o == \"undefined\")) {\n        var o = {\n        }\n    };\n    if ((typeof o.util == \"undefined\")) {\n        o.util = {\n        };\n    };\n    if ((typeof o.SWFObjectUtil == \"undefined\")) {\n        o.SWFObjectUtil = {\n        };\n    };\n    o.SWFObject = function(u, v, w, x, y, z, aa, ba, ca, da) {\n        if (!document.getElementById) {\n            return\n        };\n        this.DETECT_KEY = (da ? da : \"detectflash\");\n        this.skipDetect = o.util.getRequestParameter(this.DETECT_KEY);\n        this.params = {\n        };\n        this.variables = {\n        };\n        this.attributes = [];\n        this.fallback_html = \"\";\n        this.fallback_js_fcn = function() {\n        \n        };\n        if (u) {\n            this.setAttribute(\"swf\", u);\n        };\n        if (v) {\n            this.setAttribute(\"id\", v);\n        };\n        if (w) {\n            this.setAttribute(\"width\", w);\n        };\n        if (x) {\n            this.setAttribute(\"height\", x);\n        };\n        this.installedVer = o.SWFObjectUtil.getPlayerVersion();\n        if (y) {\n            if (!((y instanceof Array))) {\n                y = [y,];\n            };\n            var ea;\n            y.forEach(function(ha) {\n                ea = new o.PlayerVersion(ha.toString().split(\".\"));\n                if ((ea.major == this.installedVer.major)) {\n                    this.setAttribute(\"version\", ea);\n                    return;\n                }\n                 else if ((!this.getAttribute(\"version\") || (ea.major < this.getAttribute(\"version\").major))) {\n                    this.setAttribute(\"version\", ea);\n                }\n            ;\n            }.bind(this));\n        }\n    ;\n        if (((!window.opera && document.all) && (this.installedVer.major > 7))) {\n            if (!o.unloadSet) {\n                o.SWFObjectUtil.prepUnload = function() {\n                    var ha = function() {\n                    \n                    }, ia = function() {\n                    \n                    };\n                    window.attachEvent(\"onunload\", o.SWFObjectUtil.cleanupSWFs);\n                };\n                window.attachEvent(\"onbeforeunload\", o.SWFObjectUtil.prepUnload);\n                o.unloadSet = true;\n            }\n        \n        };\n        if (z) {\n            this.addParam(\"bgcolor\", z);\n        };\n        var fa = (aa ? aa : \"high\");\n        this.addParam(\"quality\", fa);\n        this.setAttribute(\"useExpressInstall\", false);\n        this.setAttribute(\"doExpressInstall\", false);\n        var ga = ((ba) ? ba : window.location);\n        this.setAttribute(\"xiRedirectUrl\", ga);\n        this.setAttribute(\"redirectUrl\", \"\");\n        if (ca) {\n            this.setAttribute(\"redirectUrl\", ca);\n        };\n        this.setAttribute(\"useIframe\", false);\n    };\n    o.SWFObject.ieWorkaroundApplied = false;\n    o.SWFObject.ensureIEWorkaroundAttached = function() {\n        if ((!o.SWFObject.ieWorkaroundApplied && document.attachEvent)) {\n            o.SWFObject.ieWorkaroundApplied = true;\n            document.attachEvent(\"onpropertychange\", o.SWFObject.onDocumentPropertyChange);\n        }\n    ;\n    };\n    o.SWFObject.onDocumentPropertyChange = function(event) {\n        if ((event.propertyName == \"title\")) {\n            var u = document.title;\n            if (((u != null) && (u.indexOf(\"#!\") != -1))) {\n                u = u.substring(0, u.indexOf(\"#!\"));\n                document.title = u;\n            }\n        ;\n        }\n    ;\n    };\n    j(o.SWFObject.prototype, {\n        useExpressInstall: function(u) {\n            this.xiSWFPath = (!u ? \"/swf/expressinstall.swf\" : u);\n            this.setAttribute(\"useExpressInstall\", true);\n        },\n        setAttribute: function(u, v) {\n            this.attributes[u] = v;\n        },\n        getAttribute: function(u) {\n            return (this.attributes[u] || \"\");\n        },\n        addParam: function(u, v) {\n            this.params[u] = v;\n        },\n        getParams: function() {\n            return this.params;\n        },\n        addVariable: function(u, v) {\n            this.variables[u] = v;\n        },\n        getVariable: function(u) {\n            return (this.variables[u] || \"\");\n        },\n        getVariables: function() {\n            return this.variables;\n        },\n        getVariablePairs: function() {\n            var u = [], v, w = this.getVariables();\n            for (v in w) {\n                u[u.length] = ((v + \"=\") + w[v]);;\n            };\n            return u.join(\"&\");\n        },\n        getSWFHTML: function() {\n            var u, v, w;\n            if (((navigator.plugins && navigator.mimeTypes) && navigator.mimeTypes.length)) {\n                if (this.getAttribute(\"doExpressInstall\")) {\n                    this.addVariable(\"MMplayerType\", \"PlugIn\");\n                    this.setAttribute(\"swf\", this.xiSWFPath);\n                }\n            ;\n                v = {\n                    type: \"application/x-shockwave-flash\",\n                    src: this.getAttribute(\"swf\"),\n                    width: this.getAttribute(\"width\"),\n                    height: this.getAttribute(\"height\"),\n                    style: (this.getAttribute(\"style\") || \"display: block;\"),\n                    id: this.getAttribute(\"id\"),\n                    name: this.getAttribute(\"id\")\n                };\n                var x = this.getParams();\n                for (var y in x) {\n                    v[y] = x[y];;\n                };\n                w = this.getVariablePairs();\n                if (w) {\n                    v.flashvars = w;\n                };\n                u = t(\"embed\", v, null);\n            }\n             else {\n                if (this.getAttribute(\"doExpressInstall\")) {\n                    this.addVariable(\"MMplayerType\", \"ActiveX\");\n                    this.setAttribute(\"swf\", this.xiSWFPath);\n                }\n            ;\n                v = {\n                    id: this.getAttribute(\"id\"),\n                    classid: \"clsid:D27CDB6E-AE6D-11cf-96B8-444553540000\",\n                    width: this.getAttribute(\"width\"),\n                    height: this.getAttribute(\"height\"),\n                    style: (this.getAttribute(\"style\") || \"display: block;\")\n                };\n                var z = t(\"param\", {\n                    name: \"movie\",\n                    value: this.getAttribute(\"swf\")\n                }, null), x = this.getParams();\n                for (var y in x) {\n                    z += t(\"param\", {\n                        name: y,\n                        value: x[y]\n                    }, null);;\n                };\n                w = this.getVariablePairs();\n                if (w) {\n                    z += t(\"param\", {\n                        name: \"flashvars\",\n                        value: w\n                    }, null);\n                };\n                u = t(\"object\", v, z);\n            }\n        ;\n            return u;\n        },\n        write: function(u) {\n            if (this.getAttribute(\"useExpressInstall\")) {\n                var v = new o.PlayerVersion([6,0,65,]);\n                if ((this.installedVer.versionIsValid(v) && !this.installedVer.versionIsValid(this.getAttribute(\"version\")))) {\n                    this.setAttribute(\"doExpressInstall\", true);\n                    this.addVariable(\"MMredirectURL\", escape(this.getAttribute(\"xiRedirectUrl\")));\n                    document.title = (document.title.slice(0, 47) + \" - Flash Player Installation\");\n                    this.addVariable(\"MMdoctitle\", document.title);\n                }\n            ;\n            }\n        ;\n            var w = (((typeof u == \"string\")) ? document.getElementById(u) : u);\n            if (!w) {\n                return false\n            };\n            k.addClass(w, \"swfObject\");\n            w.setAttribute(\"data-swfid\", this.getAttribute(\"id\"));\n            if (((this.skipDetect || this.getAttribute(\"doExpressInstall\")) || this.installedVer.versionIsValid(this.getAttribute(\"version\")))) {\n                if (!this.getAttribute(\"useIframe\")) {\n                    o.SWFObject.ensureIEWorkaroundAttached();\n                    w.innerHTML = this.getSWFHTML();\n                }\n                 else this._createIframe(w);\n            ;\n                return true;\n            }\n             else {\n                if ((this.getAttribute(\"redirectUrl\") != \"\")) {\n                    document.location.replace(this.getAttribute(\"redirectUrl\"));\n                };\n                var x = ((((((this.getAttribute(\"version\").major + \".\") + this.getAttribute(\"version\").minor) + \".\") + this.getAttribute(\"version\").release) + \".\") + this.getAttribute(\"version\").build), y = ((((((this.installedVer.major + \".\") + this.installedVer.minor) + \".\") + this.installedVer.release) + \".\") + this.installedVer.build);\n                this.fallback_js_fcn(y, x);\n                w.innerHTML = this.fallback_html;\n            }\n        ;\n            return false;\n        },\n        _createIframe: function(u) {\n            var v = l.create(\"iframe\", {\n                width: this.getAttribute(\"width\"),\n                height: this.getAttribute(\"height\"),\n                frameBorder: 0\n            });\n            l.empty(u);\n            u.appendChild(v);\n            i.useFacebookRefererHtml.bind(null, v, this.getSWFHTML(), this.getAttribute(\"iframeSource\")).defer();\n        }\n    });\n    o.SWFObjectUtil.getPlayerVersion = function() {\n        var u = new o.PlayerVersion([0,0,0,0,]), v;\n        if ((navigator.plugins && navigator.mimeTypes.length)) {\n            for (var w = 0; (w < navigator.plugins.length); w++) {\n                try {\n                    var y = navigator.plugins[w];\n                    if ((y.name == \"Shockwave Flash\")) {\n                        v = new o.PlayerVersion(y.description.replace(/([a-zA-Z]|\\s)+/, \"\").replace(/(\\s+(r|d)|\\s+b[0-9]+)/, \".\").split(\".\"));\n                        if ((((typeof u == \"undefined\") || (v.major > u.major)) || (((v.major == u.major) && (((v.minor > u.minor) || (((v.minor == u.minor) && (((v.release > u.release) || (((v.release == u.release) && (v.build > u.build))))))))))))) {\n                            u = v;\n                        };\n                    }\n                ;\n                } catch (x) {\n                \n                };\n            };\n        }\n         else if ((navigator.userAgent && (navigator.userAgent.indexOf(\"Windows CE\") >= 0))) {\n            var z = 1, aa = 3;\n            while (z) {\n                try {\n                    aa++;\n                    z = new ActiveXObject((\"ShockwaveFlash.ShockwaveFlash.\" + aa));\n                    u = new o.PlayerVersion([aa,0,0,]);\n                } catch (ba) {\n                    z = null;\n                };\n            };\n        }\n         else {\n            try {\n                var z = new ActiveXObject(\"ShockwaveFlash.ShockwaveFlash.7\");\n            } catch (ca) {\n                try {\n                    var z = new ActiveXObject(\"ShockwaveFlash.ShockwaveFlash.6\");\n                    u = new o.PlayerVersion([6,0,21,]);\n                    z.AllowScriptAccess = \"always\";\n                } catch (da) {\n                    if ((u.major == 6)) {\n                        return u\n                    };\n                };\n                try {\n                    z = new ActiveXObject(\"ShockwaveFlash.ShockwaveFlash\");\n                } catch (ea) {\n                \n                };\n            };\n            if ((z != null)) {\n                u = new o.PlayerVersion(z.GetVariable(\"$version\").split(\" \")[1].split(\",\"));\n            };\n        }\n        \n    ;\n        return u;\n    };\n    o.PlayerVersion = function(u) {\n        this.major = ((u[0] != null) ? parseInt(u[0], 10) : 0);\n        this.minor = ((u[1] != null) ? parseInt(u[1], 10) : 0);\n        this.release = ((u[2] != null) ? parseInt(u[2], 10) : 0);\n        this.build = ((u[3] != null) ? parseInt(u[3], 10) : 0);\n    };\n    o.PlayerVersion.prototype.versionIsValid = function(u) {\n        if ((this.major < u.major)) {\n            return false\n        };\n        if ((this.major > u.major)) {\n            return true\n        };\n        if ((this.minor < u.minor)) {\n            return false\n        };\n        if ((this.minor > u.minor)) {\n            return true\n        };\n        if ((this.release < u.release)) {\n            return false\n        };\n        if ((this.release > u.release)) {\n            return true\n        };\n        if ((this.build < u.build)) {\n            return false\n        };\n        return true;\n    };\n    o.util = {\n        getRequestParameter: function(u) {\n            var v = (document.location.search || document.location.hash);\n            if ((u == null)) {\n                return v\n            };\n            if (v) {\n                var w = v.substring(1).split(\"&\");\n                for (var x = 0; (x < w.length); x++) {\n                    if ((w[x].substring(0, w[x].indexOf(\"=\")) == u)) {\n                        return w[x].substring(((w[x].indexOf(\"=\") + 1)))\n                    };\n                };\n            }\n        ;\n            return \"\";\n        }\n    };\n    o.SWFObjectUtil.cleanupSWFs = function() {\n        var u = document.getElementsByTagName(\"OBJECT\");\n        for (var v = (u.length - 1); (v >= 0); v--) {\n            u[v].style.display = \"none\";\n            for (var w in u[v]) {\n                if ((typeof u[v][w] == \"function\")) {\n                    u[v][w] = function() {\n                    \n                    };\n                };\n            };\n        };\n    };\n    if ((!document.getElementById && document.all)) {\n        document.getElementById = function(u) {\n            return document.all[u];\n        };\n    };\n    var p = o.util.getRequestParameter, q = o.SWFObject, r = o.SWFObject;\n    o.spawn_flash_update_dialog = function() {\n        new g().setURI(\"/ajax/flash_update_dialog.php\").setMethod(\"GET\").setReadOnly(true).send();\n    };\n    function s(u, v) {\n        var w = m(u), x = o.SWFObjectUtil.getPlayerVersion(), y;\n        v.forEach(function(ba) {\n            ba = new o.PlayerVersion(ba.toString().split(\".\"));\n            if ((ba.major == x.major)) {\n                y = ba;\n                return;\n            }\n             else if (((typeof y == \"undefined\") || (ba.major < y.major))) {\n                y = ba;\n            }\n        ;\n        }.bind(this));\n        if ((w && (x.major > 0))) {\n            var z = ((((((x.major + \".\") + x.minor) + \".\") + x.release) + \".\") + x.build), aa = ((((((y.major + \".\") + y.minor) + \".\") + y.release) + \".\") + y.build);\n            l.setContent(w, l.tx._(\"Flash {required-version} is required to view this content. Your current version is {current-version}. Please download the latest Flash Player.\", {\n                \"required-version\": aa,\n                \"current-version\": z\n            }));\n        }\n    ;\n    };\n    o.showFlashErrorDialog = function(u, v) {\n        h.loadModules([\"ErrorDialog\",], function(w) {\n            w.show(u, v);\n        });\n    };\n    function t(u, v, w) {\n        var x = /^[A-Za-z0-9\\-]+$/;\n        if (!u.match(x)) {\n            throw new Error((\"Invalid tag \" + u))\n        };\n        var y = (\"\\u003C\" + u);\n        for (var z in v) {\n            if (!z.match(x)) {\n                throw new Error((\"Invalid attr \" + z))\n            };\n            y += ((((\" \" + z) + \"=\\\"\") + n(v[z])) + \"\\\"\");\n        };\n        if ((w === null)) {\n            return (y + \"/\\u003E\");\n        }\n         else return (((((y + \"\\u003E\") + w) + \"\\u003C/\") + u) + \"\\u003E\")\n    ;\n    };\n    e.exports = (a.deconcept || o);\n});\n__d(\"swfobject2\", [], function(a, b, c, d, e, f) {\n    var g = function() {\n        var h = \"undefined\", i = \"object\", j = \"Shockwave Flash\", k = \"ShockwaveFlash.ShockwaveFlash\", l = \"application/x-shockwave-flash\", m = \"SWFObjectExprInst\", n = \"onreadystatechange\", o = window, p = document, q = navigator, r = false, s = [ka,], t = [], u = [], v = [], w, x, y, z, aa = false, ba = false, ca, da, ea = true, fa = function() {\n            var eb = (((typeof p.getElementById != h) && (typeof p.getElementsByTagName != h)) && (typeof p.createElement != h)), fb = q.userAgent.toLowerCase(), gb = q.platform.toLowerCase(), hb = (gb ? /win/.test(gb) : /win/.test(fb)), ib = (gb ? /mac/.test(gb) : /mac/.test(fb)), jb = (/webkit/.test(fb) ? parseFloat(fb.replace(/^.*webkit\\/(\\d+(\\.\\d+)?).*$/, \"$1\")) : false), kb = !+\"\\u000b1\", lb = [0,0,0,], mb = null;\n            if (((typeof q.plugins != h) && (typeof q.plugins[j] == i))) {\n                mb = q.plugins[j].description;\n                if ((mb && !((((typeof q.mimeTypes != h) && q.mimeTypes[l]) && !q.mimeTypes[l].enabledPlugin)))) {\n                    r = true;\n                    kb = false;\n                    mb = mb.replace(/^.*\\s+(\\S+\\s+\\S+$)/, \"$1\");\n                    lb[0] = parseInt(mb.replace(/^(.*)\\..*$/, \"$1\"), 10);\n                    lb[1] = parseInt(mb.replace(/^.*\\.(.*)\\s.*$/, \"$1\"), 10);\n                    lb[2] = (/[a-zA-Z]/.test(mb) ? parseInt(mb.replace(/^.*[a-zA-Z]+(.*)$/, \"$1\"), 10) : 0);\n                }\n            ;\n            }\n             else if ((typeof o.ActiveXObject != h)) {\n                try {\n                    var ob = new ActiveXObject(k);\n                    if (ob) {\n                        mb = ob.GetVariable(\"$version\");\n                        if (mb) {\n                            kb = true;\n                            mb = mb.split(\" \")[1].split(\",\");\n                            lb = [parseInt(mb[0], 10),parseInt(mb[1], 10),parseInt(mb[2], 10),];\n                        }\n                    ;\n                    }\n                ;\n                } catch (nb) {\n                \n                }\n            }\n        ;\n            return {\n                w3: eb,\n                pv: lb,\n                wk: jb,\n                ie: kb,\n                win: hb,\n                mac: ib\n            };\n        }(), ga = function() {\n            if (!fa.w3) {\n                return\n            };\n            if (((((typeof p.readyState != h) && (p.readyState == \"complete\"))) || (((typeof p.readyState == h) && ((p.getElementsByTagName(\"body\")[0] || p.body)))))) {\n                ha();\n            };\n            if (!aa) {\n                if ((typeof p.addEventListener != h)) {\n                    p.addEventListener(\"DOMContentLoaded\", ha, false);\n                };\n                if ((fa.ie && fa.win)) {\n                    p.attachEvent(n, function() {\n                        if ((p.readyState == \"complete\")) {\n                            p.detachEvent(n, arguments.callee);\n                            ha();\n                        }\n                    ;\n                    });\n                    if ((o == top)) {\n                        (function() {\n                            if (aa) {\n                                return\n                            };\n                            try {\n                                p.documentElement.doScroll(\"left\");\n                            } catch (eb) {\n                                setTimeout(arguments.callee, 0);\n                                return;\n                            };\n                            ha();\n                        })();\n                    };\n                }\n            ;\n                if (fa.wk) {\n                    (function() {\n                        if (aa) {\n                            return\n                        };\n                        if (!/loaded|complete/.test(p.readyState)) {\n                            setTimeout(arguments.callee, 0);\n                            return;\n                        }\n                    ;\n                        ha();\n                    })();\n                };\n                ja(ha);\n            }\n        ;\n        }();\n        function ha() {\n            if (aa) {\n                return\n            };\n            try {\n                var fb = p.getElementsByTagName(\"body\")[0].appendChild(xa(\"span\"));\n                fb.parentNode.removeChild(fb);\n            } catch (eb) {\n                return;\n            };\n            aa = true;\n            var gb = s.length;\n            for (var hb = 0; (hb < gb); hb++) {\n                s[hb]();;\n            };\n        };\n        function ia(eb) {\n            if (aa) {\n                eb();\n            }\n             else s[s.length] = eb;\n        ;\n        };\n        function ja(eb) {\n            if ((typeof o.addEventListener != h)) {\n                o.addEventListener(\"load\", eb, false);\n            }\n             else if ((typeof p.addEventListener != h)) {\n                p.addEventListener(\"load\", eb, false);\n            }\n             else if ((typeof o.attachEvent != h)) {\n                ya(o, \"onload\", eb);\n            }\n             else if ((typeof o.onload == \"function\")) {\n                var fb = o.onload;\n                o.onload = function() {\n                    fb();\n                    eb();\n                };\n            }\n             else o.onload = eb;\n            \n            \n            \n        ;\n        };\n        function ka() {\n            if (r) {\n                la();\n            }\n             else ma();\n        ;\n        };\n        function la() {\n            var eb = p.getElementsByTagName(\"body\")[0], fb = xa(i);\n            fb.setAttribute(\"type\", l);\n            var gb = eb.appendChild(fb);\n            if (gb) {\n                var hb = 0;\n                (function() {\n                    if ((typeof gb.GetVariable != h)) {\n                        var ib = gb.GetVariable(\"$version\");\n                        if (ib) {\n                            ib = ib.split(\" \")[1].split(\",\");\n                            fa.pv = [parseInt(ib[0], 10),parseInt(ib[1], 10),parseInt(ib[2], 10),];\n                        }\n                    ;\n                    }\n                     else if ((hb < 10)) {\n                        hb++;\n                        setTimeout(arguments.callee, 10);\n                        return;\n                    }\n                    \n                ;\n                    eb.removeChild(fb);\n                    gb = null;\n                    ma();\n                })();\n            }\n             else ma();\n        ;\n        };\n        function ma() {\n            var eb = t.length;\n            if ((eb > 0)) {\n                for (var fb = 0; (fb < eb); fb++) {\n                    var gb = t[fb].id, hb = t[fb].callbackFn, ib = {\n                        success: false,\n                        id: gb\n                    };\n                    if ((fa.pv[0] > 0)) {\n                        var jb = wa(gb);\n                        if (jb) {\n                            if ((za(t[fb].swfVersion) && !((fa.wk && (fa.wk < 312))))) {\n                                bb(gb, true);\n                                if (hb) {\n                                    ib.success = true;\n                                    ib.ref = na(gb);\n                                    hb(ib);\n                                }\n                            ;\n                            }\n                             else if ((t[fb].expressInstall && oa())) {\n                                var kb = {\n                                };\n                                kb.data = t[fb].expressInstall;\n                                kb.width = (jb.getAttribute(\"width\") || \"0\");\n                                kb.height = (jb.getAttribute(\"height\") || \"0\");\n                                if (jb.getAttribute(\"class\")) {\n                                    kb.styleclass = jb.getAttribute(\"class\");\n                                };\n                                if (jb.getAttribute(\"align\")) {\n                                    kb.align = jb.getAttribute(\"align\");\n                                };\n                                var lb = {\n                                }, mb = jb.getElementsByTagName(\"param\"), nb = mb.length;\n                                for (var ob = 0; (ob < nb); ob++) {\n                                    if ((mb[ob].getAttribute(\"name\").toLowerCase() != \"movie\")) {\n                                        lb[mb[ob].getAttribute(\"name\")] = mb[ob].getAttribute(\"value\");\n                                    };\n                                };\n                                pa(kb, lb, gb, hb);\n                            }\n                             else {\n                                qa(jb);\n                                if (hb) {\n                                    hb(ib);\n                                };\n                            }\n                            \n                        \n                        };\n                    }\n                     else {\n                        bb(gb, true);\n                        if (hb) {\n                            var pb = na(gb);\n                            if ((pb && (typeof pb.SetVariable != h))) {\n                                ib.success = true;\n                                ib.ref = pb;\n                            }\n                        ;\n                            hb(ib);\n                        }\n                    ;\n                    }\n                ;\n                }\n            };\n        };\n        function na(eb) {\n            var fb = null, gb = wa(eb);\n            if ((gb && (gb.nodeName == \"OBJECT\"))) {\n                if ((typeof gb.SetVariable != h)) {\n                    fb = gb;\n                }\n                 else {\n                    var hb = gb.getElementsByTagName(i)[0];\n                    if (hb) {\n                        fb = hb;\n                    };\n                }\n            \n            };\n            return fb;\n        };\n        function oa() {\n            return (((!ba && za(\"6.0.65\")) && ((fa.win || fa.mac))) && !((fa.wk && (fa.wk < 312))));\n        };\n        function pa(eb, fb, gb, hb) {\n            ba = true;\n            y = (hb || null);\n            z = {\n                success: false,\n                id: gb\n            };\n            var ib = wa(gb);\n            if (ib) {\n                if ((ib.nodeName == \"OBJECT\")) {\n                    w = ra(ib);\n                    x = null;\n                }\n                 else {\n                    w = ib;\n                    x = gb;\n                }\n            ;\n                eb.id = m;\n                if (((typeof eb.width == h) || ((!/\u0025$/.test(eb.width) && (parseInt(eb.width, 10) < 310))))) {\n                    eb.width = \"310\";\n                };\n                if (((typeof eb.height == h) || ((!/\u0025$/.test(eb.height) && (parseInt(eb.height, 10) < 137))))) {\n                    eb.height = \"137\";\n                };\n                p.title = (p.title.slice(0, 47) + \" - Flash Player Installation\");\n                var jb = ((fa.ie && fa.win) ? \"ActiveX\" : \"PlugIn\"), kb = (((((\"MMredirectURL=\" + o.location.toString().replace(/&/g, \"\u002526\")) + \"&MMplayerType=\") + jb) + \"&MMdoctitle=\") + p.title);\n                if ((typeof fb.flashvars != h)) {\n                    fb.flashvars += (\"&\" + kb);\n                }\n                 else fb.flashvars = kb;\n            ;\n                if (((fa.ie && fa.win) && (ib.readyState != 4))) {\n                    var lb = xa(\"div\");\n                    gb += \"SWFObjectNew\";\n                    lb.setAttribute(\"id\", gb);\n                    ib.parentNode.insertBefore(lb, ib);\n                    ib.style.display = \"none\";\n                    (function() {\n                        if ((ib.readyState == 4)) {\n                            ib.parentNode.removeChild(ib);\n                        }\n                         else setTimeout(arguments.callee, 10);\n                    ;\n                    })();\n                }\n            ;\n                sa(eb, fb, gb);\n            }\n        ;\n        };\n        function qa(eb) {\n            if (((fa.ie && fa.win) && (eb.readyState != 4))) {\n                var fb = xa(\"div\");\n                eb.parentNode.insertBefore(fb, eb);\n                fb.parentNode.replaceChild(ra(eb), fb);\n                eb.style.display = \"none\";\n                (function() {\n                    if ((eb.readyState == 4)) {\n                        eb.parentNode.removeChild(eb);\n                    }\n                     else setTimeout(arguments.callee, 10);\n                ;\n                })();\n            }\n             else eb.parentNode.replaceChild(ra(eb), eb);\n        ;\n        };\n        function ra(eb) {\n            var fb = xa(\"div\");\n            if ((fa.win && fa.ie)) {\n                fb.innerHTML = eb.innerHTML;\n            }\n             else {\n                var gb = eb.getElementsByTagName(i)[0];\n                if (gb) {\n                    var hb = gb.childNodes;\n                    if (hb) {\n                        var ib = hb.length;\n                        for (var jb = 0; (jb < ib); jb++) {\n                            if ((!(((hb[jb].nodeType == 1) && (hb[jb].nodeName == \"PARAM\"))) && !((hb[jb].nodeType == 8)))) {\n                                fb.appendChild(hb[jb].cloneNode(true));\n                            };\n                        };\n                    }\n                ;\n                }\n            ;\n            }\n        ;\n            return fb;\n        };\n        function sa(eb, fb, gb) {\n            var hb, ib = wa(gb);\n            if ((fa.wk && (fa.wk < 312))) {\n                return hb\n            };\n            if (ib) {\n                if ((typeof eb.id == h)) {\n                    eb.id = gb;\n                };\n                if ((fa.ie && fa.win)) {\n                    var jb = \"\";\n                    for (var kb in eb) {\n                        if ((eb[kb] != Object.prototype[kb])) {\n                            if ((kb.toLowerCase() == \"data\")) {\n                                fb.movie = eb[kb];\n                            }\n                             else if ((kb.toLowerCase() == \"styleclass\")) {\n                                jb += ((\" class=\\\"\" + eb[kb]) + \"\\\"\");\n                            }\n                             else if ((kb.toLowerCase() != \"classid\")) {\n                                jb += ((((\" \" + kb) + \"=\\\"\") + eb[kb]) + \"\\\"\");\n                            }\n                            \n                        \n                        };\n                    };\n                    var lb = \"\";\n                    for (var mb in fb) {\n                        if ((fb[mb] != Object.prototype[mb])) {\n                            lb += ((((\"\\u003Cparam name=\\\"\" + mb) + \"\\\" value=\\\"\") + fb[mb]) + \"\\\" /\\u003E\");\n                        };\n                    };\n                    ib.outerHTML = ((((\"\\u003Cobject classid=\\\"clsid:D27CDB6E-AE6D-11cf-96B8-444553540000\\\"\" + jb) + \"\\u003E\") + lb) + \"\\u003C/object\\u003E\");\n                    u[u.length] = eb.id;\n                    hb = wa(eb.id);\n                }\n                 else {\n                    var nb = xa(i);\n                    nb.setAttribute(\"type\", l);\n                    for (var ob in eb) {\n                        if ((eb[ob] != Object.prototype[ob])) {\n                            if ((ob.toLowerCase() == \"styleclass\")) {\n                                nb.setAttribute(\"class\", eb[ob]);\n                            }\n                             else if ((ob.toLowerCase() != \"classid\")) {\n                                nb.setAttribute(ob, eb[ob]);\n                            }\n                        \n                        };\n                    };\n                    for (var pb in fb) {\n                        if (((fb[pb] != Object.prototype[pb]) && (pb.toLowerCase() != \"movie\"))) {\n                            ta(nb, pb, fb[pb]);\n                        };\n                    };\n                    ib.parentNode.replaceChild(nb, ib);\n                    hb = nb;\n                }\n            ;\n            }\n        ;\n            return hb;\n        };\n        function ta(eb, fb, gb) {\n            var hb = xa(\"param\");\n            hb.setAttribute(\"name\", fb);\n            hb.setAttribute(\"value\", gb);\n            eb.appendChild(hb);\n        };\n        function ua(eb) {\n            var fb = wa(eb);\n            if ((fb && (fb.nodeName == \"OBJECT\"))) {\n                if ((fa.ie && fa.win)) {\n                    fb.style.display = \"none\";\n                    (function() {\n                        if ((fb.readyState == 4)) {\n                            va(eb);\n                        }\n                         else setTimeout(arguments.callee, 10);\n                    ;\n                    })();\n                }\n                 else fb.parentNode.removeChild(fb);\n            \n            };\n        };\n        function va(eb) {\n            var fb = wa(eb);\n            if (fb) {\n                for (var gb in fb) {\n                    if ((typeof fb[gb] == \"function\")) {\n                        fb[gb] = null;\n                    };\n                };\n                fb.parentNode.removeChild(fb);\n            }\n        ;\n        };\n        function wa(eb) {\n            var fb = null;\n            try {\n                fb = p.getElementById(eb);\n            } catch (gb) {\n            \n            };\n            return fb;\n        };\n        function xa(eb) {\n            return p.createElement(eb);\n        };\n        function ya(eb, fb, gb) {\n            eb.attachEvent(fb, gb);\n            v[v.length] = [eb,fb,gb,];\n        };\n        function za(eb) {\n            var fb = fa.pv, gb = eb.split(\".\");\n            gb[0] = parseInt(gb[0], 10);\n            gb[1] = (parseInt(gb[1], 10) || 0);\n            gb[2] = (parseInt(gb[2], 10) || 0);\n            return (((((fb[0] > gb[0]) || (((fb[0] == gb[0]) && (fb[1] > gb[1])))) || ((((fb[0] == gb[0]) && (fb[1] == gb[1])) && (fb[2] >= gb[2]))))) ? true : false);\n        };\n        function ab(eb, fb, gb, hb) {\n            if ((fa.ie && fa.mac)) {\n                return\n            };\n            var ib = p.getElementsByTagName(\"head\")[0];\n            if (!ib) {\n                return\n            };\n            var jb = (((gb && (typeof gb == \"string\"))) ? gb : \"screen\");\n            if (hb) {\n                ca = null;\n                da = null;\n            }\n        ;\n            if ((!ca || (da != jb))) {\n                var kb = xa(\"style\");\n                kb.setAttribute(\"type\", \"text/css\");\n                kb.setAttribute(\"media\", jb);\n                ca = ib.appendChild(kb);\n                if ((((fa.ie && fa.win) && (typeof p.styleSheets != h)) && (p.styleSheets.length > 0))) {\n                    ca = p.styleSheets[(p.styleSheets.length - 1)];\n                };\n                da = jb;\n            }\n        ;\n            if ((fa.ie && fa.win)) {\n                if ((ca && (typeof ca.addRule == i))) {\n                    ca.addRule(eb, fb);\n                };\n            }\n             else if ((ca && (typeof p.createTextNode != h))) {\n                ca.appendChild(p.createTextNode((((eb + \" {\") + fb) + \"}\")));\n            }\n        ;\n        };\n        function bb(eb, fb) {\n            if (!ea) {\n                return\n            };\n            var gb = (fb ? \"visible\" : \"hidden\");\n            if ((aa && wa(eb))) {\n                wa(eb).style.visibility = gb;\n            }\n             else ab((\"#\" + eb), (\"visibility:\" + gb));\n        ;\n        };\n        function cb(eb) {\n            var fb = /[\\\\\\\"<>\\.;]/, gb = (fb.exec(eb) != null);\n            return ((gb && (typeof encodeURIComponent != h)) ? encodeURIComponent(eb) : eb);\n        };\n        var db = function() {\n            if ((fa.ie && fa.win)) {\n                window.attachEvent(\"onunload\", function() {\n                    var eb = v.length;\n                    for (var fb = 0; (fb < eb); fb++) {\n                        v[fb][0].detachEvent(v[fb][1], v[fb][2]);;\n                    };\n                    var gb = u.length;\n                    for (var hb = 0; (hb < gb); hb++) {\n                        ua(u[hb]);;\n                    };\n                    for (var ib in fa) {\n                        fa[ib] = null;;\n                    };\n                    fa = null;\n                    for (var jb in g) {\n                        g[jb] = null;;\n                    };\n                    g = null;\n                });\n            };\n        }();\n        return {\n            registerObject: function(eb, fb, gb, hb) {\n                if (((fa.w3 && eb) && fb)) {\n                    var ib = {\n                    };\n                    ib.id = eb;\n                    ib.swfVersion = fb;\n                    ib.expressInstall = gb;\n                    ib.callbackFn = hb;\n                    t[t.length] = ib;\n                    bb(eb, false);\n                }\n                 else if (hb) {\n                    hb({\n                        success: false,\n                        id: eb\n                    });\n                }\n            ;\n            },\n            getObjectById: function(eb) {\n                if (fa.w3) {\n                    return na(eb)\n                };\n            },\n            embedSWF: function(eb, fb, gb, hb, ib, jb, kb, lb, mb, nb) {\n                var ob = {\n                    success: false,\n                    id: fb\n                };\n                if (((((((fa.w3 && !((fa.wk && (fa.wk < 312)))) && eb) && fb) && gb) && hb) && ib)) {\n                    bb(fb, false);\n                    ia(function() {\n                        gb += \"\";\n                        hb += \"\";\n                        var pb = {\n                        };\n                        if ((mb && (typeof mb === i))) {\n                            for (var qb in mb) {\n                                pb[qb] = mb[qb];;\n                            }\n                        };\n                        pb.data = eb;\n                        pb.width = gb;\n                        pb.height = hb;\n                        var rb = {\n                        };\n                        if ((lb && (typeof lb === i))) {\n                            for (var sb in lb) {\n                                rb[sb] = lb[sb];;\n                            }\n                        };\n                        if ((kb && (typeof kb === i))) {\n                            for (var tb in kb) {\n                                if ((typeof rb.flashvars != h)) {\n                                    rb.flashvars += (((\"&\" + tb) + \"=\") + kb[tb]);\n                                }\n                                 else rb.flashvars = ((tb + \"=\") + kb[tb]);\n                            ;\n                            }\n                        };\n                        if (za(ib)) {\n                            var ub = sa(pb, rb, fb);\n                            if ((pb.id == fb)) {\n                                bb(fb, true);\n                            };\n                            ob.success = true;\n                            ob.ref = ub;\n                        }\n                         else if ((jb && oa())) {\n                            pb.data = jb;\n                            pa(pb, rb, fb, nb);\n                            return;\n                        }\n                         else bb(fb, true);\n                        \n                    ;\n                        if (nb) {\n                            nb(ob);\n                        };\n                    });\n                }\n                 else if (nb) {\n                    nb(ob);\n                }\n            ;\n            },\n            switchOffAutoHideShow: function() {\n                ea = false;\n            },\n            ua: fa,\n            getFlashPlayerVersion: function() {\n                return {\n                    major: fa.pv[0],\n                    minor: fa.pv[1],\n                    release: fa.pv[2]\n                };\n            },\n            hasFlashPlayerVersion: za,\n            createSWF: function(eb, fb, gb) {\n                if (fa.w3) {\n                    return sa(eb, fb, gb);\n                }\n                 else return undefined\n            ;\n            },\n            showExpressInstall: function(eb, fb, gb, hb) {\n                if ((fa.w3 && oa())) {\n                    pa(eb, fb, gb, hb);\n                };\n            },\n            removeSWF: function(eb) {\n                if (fa.w3) {\n                    ua(eb);\n                };\n            },\n            createCSS: function(eb, fb, gb, hb) {\n                if (fa.w3) {\n                    ab(eb, fb, gb, hb);\n                };\n            },\n            addDomLoadEvent: ia,\n            addLoadEvent: ja,\n            getQueryParamValue: function(eb) {\n                var fb = (p.location.search || p.location.hash);\n                if (fb) {\n                    if (/\\?/.test(fb)) {\n                        fb = fb.split(\"?\")[1];\n                    };\n                    if ((eb == null)) {\n                        return cb(fb)\n                    };\n                    var gb = fb.split(\"&\");\n                    for (var hb = 0; (hb < gb.length); hb++) {\n                        if ((gb[hb].substring(0, gb[hb].indexOf(\"=\")) == eb)) {\n                            return cb(gb[hb].substring(((gb[hb].indexOf(\"=\") + 1))))\n                        };\n                    };\n                }\n            ;\n                return \"\";\n            },\n            expressInstallCallback: function() {\n                if (ba) {\n                    var eb = wa(m);\n                    if ((eb && w)) {\n                        eb.parentNode.replaceChild(w, eb);\n                        if (x) {\n                            bb(x, true);\n                            if ((fa.ie && fa.win)) {\n                                w.style.display = \"block\";\n                            };\n                        }\n                    ;\n                        if (y) {\n                            y(z);\n                        };\n                    }\n                ;\n                    ba = false;\n                }\n            ;\n            }\n        };\n    }();\n    e.exports = g;\n});\n__d(\"SoundPlayer\", [\"Arbiter\",\"ChatConfig\",\"Env\",\"swfobject\",\"swfobject2\",\"URI\",\"createArrayFrom\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ChatConfig\"), i = b(\"Env\"), j = b(\"swfobject\").SWFObject, k = b(\"swfobject2\"), l = b(\"URI\"), m = b(\"createArrayFrom\"), n = {\n    }, o = null, p = false, q = \"so_sound_player\", r = \"/swf/SoundPlayerHater.swf\", s = \"10.0.22.87\", t = null, u = h.get(\"sound.useswfobject_2\", false), v = h.get(\"sound.force_flash\", false);\n    function w(ea) {\n        var fa = l(ea);\n        if (!fa.getDomain()) {\n            return l(i.static_base).setPath(fa.getPath()).toString()\n        };\n        return ea;\n    };\n    function x(ea) {\n        if (/\\.mp3$/.test(ea)) {\n            return \"audio/mpeg\"\n        };\n        if (/\\.og[ga]$/.test(ea)) {\n            return \"audio/ogg\"\n        };\n        return \"\";\n    };\n    function y() {\n        if ((!t && !v)) {\n            var ea = document.createElement(\"audio\");\n            if ((!ea || !ea.canPlayType)) {\n                return null\n            };\n            ea.setAttribute(\"preload\", \"auto\");\n            document.body.appendChild(ea);\n            t = ea;\n        }\n    ;\n        return t;\n    };\n    function z() {\n        var ea = (document[q] || window[q]);\n        if (ea) {\n            if ((!ea.playSound && ea.length)) {\n                ea = ea[0];\n            }\n        };\n        return ((((ea && ea.playSound) && ea.loopSound)) ? ea : null);\n    };\n    function aa() {\n        return p;\n    };\n    function ba(ea, fa, ga) {\n        o = {\n            path: ea,\n            sync: fa,\n            loop: ga\n        };\n    };\n    function ca() {\n        p = true;\n        if (o) {\n            var ea = z();\n            if (o.loop) {\n                ea.loopSound(o.path, o.sync);\n            }\n             else ea.playSound(o.path, o.sync);\n        ;\n        }\n    ;\n    };\n    var da = {\n        init: function(ea) {\n            ea = m(ea);\n            var fa;\n            for (var ga = 0; (ga < ea.length); ++ga) {\n                fa = ea[ga];\n                if (n[fa]) {\n                    return\n                };\n            };\n            var ha = y();\n            for (ga = 0; (ha && (ga < ea.length)); ++ga) {\n                fa = ea[ga];\n                if (ha.canPlayType(fa)) {\n                    n[fa] = true;\n                    return;\n                }\n            ;\n            };\n            n[\"audio/mpeg\"] = true;\n            if (z()) {\n                return\n            };\n            try {\n                g.registerCallback(ca, [\"sound/player_ready\",\"sound/ready\",]);\n                var ja = document.createElement(\"div\");\n                ja.id = \"sound_player_holder\";\n                document.body.appendChild(ja);\n                if (u) {\n                    k.embedSWF(r, ja.id, \"1px\", \"1px\", s, null, {\n                        swf_id: q\n                    }, {\n                        allowscriptaccess: \"always\",\n                        wmode: \"transparent\"\n                    }, null, function(la) {\n                        window[q] = la.ref;\n                        g.inform(\"sound/player_ready\");\n                    });\n                }\n                 else {\n                    var ka = new j(r, q, \"1px\", \"1px\", [s,], \"#ffffff\");\n                    ka.addParam(\"allowscriptaccess\", \"always\");\n                    ka.addParam(\"wmode\", \"transparent\");\n                    ka.addVariable(\"swf_id\", q);\n                    ka.fallback_html = \" \";\n                    ka.write(ja.id);\n                    window[q] = ka;\n                    g.inform(\"sound/player_ready\");\n                }\n            ;\n            } catch (ia) {\n            \n            };\n        },\n        play: function(ea, fa) {\n            ea = m(ea);\n            var ga = y(), ha, ia;\n            for (var ja = 0; (ga && (ja < ea.length)); ++ja) {\n                ha = ea[ja];\n                ia = x(ha);\n                if (!ga.canPlayType(ia)) {\n                    continue;\n                };\n                da.init([ia,]);\n                ga.src = w(ha);\n                if (fa) {\n                    ga.setAttribute(\"loop\", \"\");\n                }\n                 else ga.removeAttribute(\"loop\");\n            ;\n                ga.play();\n                return;\n            };\n            for (ja = 0; (ja < ea.length); ++ja) {\n                ha = w(ea[ja]);\n                ia = x(ha);\n                if ((ia != \"audio/mpeg\")) {\n                    continue;\n                };\n                da.init([ia,]);\n                var ka = z();\n                if (!aa()) {\n                    ba(ha, true, fa);\n                    return;\n                }\n                 else if (ka) {\n                    if (fa) {\n                        ka.loopSound(ha, true);\n                    }\n                     else ka.playSound(ha, true);\n                ;\n                    return;\n                }\n                \n            ;\n            };\n        },\n        stop: function(ea) {\n            ea = m(ea);\n            for (var fa = 0; (fa < ea.length); ++fa) {\n                var ga = w(ea[fa]), ha = y(), ia = z();\n                if ((ha && (ha.src == ga))) {\n                    ha.pause();\n                    ha.src = undefined;\n                }\n                 else (ia && ia.stopSound(ga));\n            ;\n            };\n        }\n    };\n    e.exports = da;\n});\n__d(\"SoundSynchronizer\", [\"event-extensions\",\"hasArrayNature\",\"SoundPlayer\",\"createArrayFrom\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"hasArrayNature\"), h = b(\"SoundPlayer\"), i = b(\"createArrayFrom\"), j = \"fb_sounds_playing3\";\n    function k() {\n        if (window.localStorage) {\n            try {\n                var p = window.localStorage[j];\n                if (p) {\n                    p = JSON.parse(p);\n                    if (g(p)) {\n                        return p\n                    };\n                }\n            ;\n            } catch (o) {\n            \n            }\n        };\n        return [];\n    };\n    function l(o) {\n        if (window.localStorage) {\n            var p = k();\n            p.push(o);\n            while ((p.length > 5)) {\n                p.shift();;\n            };\n            try {\n                window.localStorage[j] = JSON.stringify(p);\n            } catch (q) {\n            \n            };\n        }\n    ;\n    };\n    function m(o) {\n        return k().some(function(p) {\n            return (p === o);\n        });\n    };\n    var n = {\n        play: function(o, p, q) {\n            o = i(o);\n            p = (p || ((o[0] + Math.floor((Date.now() / 1000)))));\n            if (m(p)) {\n                return\n            };\n            h.play(o, q);\n            l(p);\n        },\n        isSupported: function() {\n            return !!window.localStorage;\n        }\n    };\n    e.exports = n;\n});\n__d(\"SoundRPC\", [\"event-extensions\",\"SoundSynchronizer\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"SoundSynchronizer\");\n    function h(j, k, l) {\n        g.play(j, k, l);\n    };\n    var i = {\n        playLocal: h,\n        playRemote: function(j, k, l, m) {\n            var n = {\n                paths: k,\n                sync: l,\n                loop: m\n            };\n            j.postMessage(JSON.stringify(n), \"*\");\n        },\n        supportsRPC: function() {\n            return !!window.postMessage;\n        },\n        _listen: function() {\n            Event.listen(window, \"message\", function(j) {\n                if (!/\\.facebook.com$/.test(j.origin)) {\n                    return\n                };\n                var k = JSON.parse(j.data);\n                h(k.paths, k.sync, k.loop);\n            });\n        }\n    };\n    e.exports = i;\n});\n__d(\"Sound\", [\"SoundPlayer\",\"SoundRPC\",\"SoundSynchronizer\",\"UserAgent\",], function(a, b, c, d, e, f) {\n    var g = b(\"SoundPlayer\"), h = b(\"SoundRPC\"), i = b(\"SoundSynchronizer\"), j = b(\"UserAgent\"), k = null, l = {\n        init: function(o) {\n            if (!k) {\n                g.init(o);\n            };\n        },\n        play: function(o, p, q) {\n            if (k) {\n                h.playRemote(k.contentWindow, o, p, false);\n            }\n             else h.playLocal(o, p, q);\n        ;\n        },\n        stop: function(o) {\n            if (!k) {\n                g.stop(o);\n            };\n        }\n    }, m = location.host.replace(/^[^.]+/, \"www\");\n    function n() {\n        if ((j.ie() < 9)) {\n            return false\n        };\n        return (i.isSupported() && h.supportsRPC());\n    };\n    if (((location.host !== m) && n())) {\n        k = document.createElement(\"iframe\");\n        k.setAttribute(\"src\", ((\"//\" + m) + \"/sound_iframe.php\"));\n        k.style.display = \"none\";\n        document.body.appendChild(k);\n    }\n;\n    e.exports = l;\n});\n__d(\"Token\", [\"CSS\",\"DataStore\",\"DOM\",\"copyProperties\",\"tx\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"DataStore\"), i = b(\"DOM\"), j = b(\"copyProperties\"), k = b(\"tx\");\n    function l(m, n) {\n        this.info = m;\n        this.paramName = n;\n    };\n    j(l.prototype, {\n        getInfo: function() {\n            return this.info;\n        },\n        getText: function() {\n            return this.info.text;\n        },\n        getValue: function() {\n            return this.info.uid;\n        },\n        isFreeform: function() {\n            return !!this.info.freeform;\n        },\n        getElement: function() {\n            if (!this.element) {\n                this.setElement(this.createElement());\n            };\n            return this.element;\n        },\n        setElement: function(m) {\n            h.set(m, \"Token\", this);\n            this.element = m;\n            return this;\n        },\n        isRemovable: function() {\n            return g.hasClass(this.element, \"removable\");\n        },\n        createElement: function() {\n            var m = this.paramName, n = this.getText(), o = this.getValue(), p = i.create(\"a\", {\n                href: \"#\",\n                \"aria-label\": k._(\"Remove {item}\", {\n                    item: n\n                }),\n                className: \"remove uiCloseButton uiCloseButtonSmall\"\n            }), q = i.create(\"input\", {\n                type: \"hidden\",\n                value: o,\n                name: (m + \"[]\"),\n                autocomplete: \"off\"\n            }), r = i.create(\"input\", {\n                type: \"hidden\",\n                value: n,\n                name: ((\"text_\" + m) + \"[]\"),\n                autocomplete: \"off\"\n            }), s = i.create(\"span\", {\n                className: \"removable uiToken\"\n            }, [n,q,r,p,]);\n            return s;\n        }\n    });\n    e.exports = l;\n});\n__d(\"StickyPlaceholderInput\", [\"event-extensions\",\"CSS\",\"DOM\",\"Input\",\"Parent\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"Input\"), j = b(\"Parent\");\n    function k(o) {\n        return j.byClass(o, \"uiStickyPlaceholderInput\");\n    };\n    function l(o) {\n        return h.scry(o, \".placeholder\")[0];\n    };\n    function m(o) {\n        o = (o || window.event);\n        var p = (o.target || o.srcElement);\n        if (h.isNodeOfType(p, [\"input\",\"textarea\",])) {\n            var q = k(p);\n            if (q) {\n                var r = o.type;\n                (function() {\n                    if (((((r === \"keydown\") || (r === \"paste\"))) && p.value.length)) {\n                        g.removeClass(q, \"uiStickyPlaceholderEmptyInput\");\n                    };\n                    if (((((r === \"blur\") || (r === \"focusout\"))) && !p.value.length)) {\n                        g.addClass(q, \"uiStickyPlaceholderEmptyInput\");\n                    };\n                }).defer();\n            }\n        ;\n        }\n    ;\n    };\n    var n = {\n        init: function() {\n            n.init = bagofholding;\n            Event.listen(document.documentElement, {\n                keydown: m,\n                paste: m\n            });\n            if (document.documentElement.addEventListener) {\n                document.documentElement.addEventListener(\"blur\", m, true);\n            }\n             else Event.listen(document.documentElement, \"focusout\", m);\n        ;\n        },\n        registerInput: function(o) {\n            n.init();\n            var p = (o.getAttribute(\"placeholder\") || \"\");\n            if (p.length) {\n                if ((document.activeElement === o)) {\n                    var q = Event.listen(o, \"blur\", function() {\n                        n.manipulateInput(o, p);\n                        q.remove();\n                    });\n                }\n                 else n.manipulateInput(o, p);\n            \n            };\n        },\n        manipulateInput: function(o, p) {\n            var q = h.create(\"div\", {\n                className: \"placeholder\",\n                \"aria-hidden\": \"true\"\n            }, p), r = h.create(\"div\", {\n                className: \"uiStickyPlaceholderInput\"\n            }, q);\n            if (h.isNodeOfType(o, \"textarea\")) {\n                g.addClass(r, \"uiStickyPlaceholderTextarea\");\n            };\n            Event.listen(q, \"click\", function() {\n                o.focus();\n            });\n            if ((o.value === p)) {\n                o.value = \"\";\n            };\n            g.removeClass(o, \"DOMControl_placeholder\");\n            o.setAttribute(\"placeholder\", \"\");\n            h.replace(o, r);\n            h.appendContent(r, o);\n            g.conditionClass(r, \"uiStickyPlaceholderEmptyInput\", !o.value.length);\n        },\n        setPlaceholderText: function(o, p) {\n            var q = k(o);\n            if (!q) {\n                i.setPlaceholder(o, p);\n            }\n             else {\n                var r = l(q);\n                (r && h.setContent(r, p));\n            }\n        ;\n        },\n        getPlaceholderText: function(o) {\n            var p = k(o), q = l(p);\n            return (q && h.getText(q));\n        },\n        update: function(o) {\n            var p = k(o);\n            if (p) {\n                g.conditionClass(p, \"uiStickyPlaceholderEmptyInput\", !o.value.length);\n            };\n        },\n        getVisibleText: function(o) {\n            var p = k(o);\n            if (g.hasClass(p, \"uiStickyPlaceholderEmptyInput\")) {\n                var q = l(p);\n                return (q && h.getText(q));\n            }\n             else return o.value\n        ;\n        }\n    };\n    e.exports = n;\n});\n__d(\"Tokenizer\", [\"array-extensions\",\"event-extensions\",\"Arbiter\",\"ArbiterMixin\",\"Class\",\"CSS\",\"DataStore\",\"DOM\",\"DOMQuery\",\"Input\",\"Keys\",\"Parent\",\"StickyPlaceholderInput\",\"Style\",\"TextMetrics\",\"Token\",\"UserAgent\",\"copyProperties\",\"createObjectFrom\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"Class\"), j = b(\"CSS\"), k = b(\"DataStore\"), l = b(\"DOM\"), m = b(\"DOMQuery\"), n = b(\"Input\"), o = b(\"Keys\"), p = b(\"Parent\"), q = b(\"StickyPlaceholderInput\"), r = b(\"Style\"), s = b(\"TextMetrics\"), t = b(\"Token\"), u = b(\"UserAgent\"), v = b(\"copyProperties\"), w = b(\"createObjectFrom\");\n    function x(y, z) {\n        this.element = y;\n        this.typeahead = z;\n        this.input = z.getCore().getElement();\n        k.set(this.element, \"Tokenizer\", this);\n    };\n    x.getInstance = function(y) {\n        var z = p.byClass(y, \"uiTokenizer\");\n        return (z ? k.get(z, \"Tokenizer\") : null);\n    };\n    v(x.prototype, h, {\n        inline: false,\n        maxTokens: null,\n        excludeDuplicates: true,\n        placeholder: \"\",\n        init: function(y, z, aa, ba) {\n            this.init = bagofholding;\n            this.tokenarea = y;\n            this.paramName = z;\n            if (!this.placeholder) {\n                this.placeholder = (this.input.getAttribute(\"data-placeholder\") || \"\");\n            };\n            v(this, (ba || {\n            }));\n            this.initEvents();\n            this.initTypeahead();\n            this.reset(aa);\n            this.initBehaviors();\n            g.inform(\"Tokenizer/init\", this, g.BEHAVIOR_PERSISTENT);\n        },\n        reset: function(y) {\n            this.tokens = [];\n            this.unique = {\n            };\n            if (y) {\n                this.populate(y);\n            }\n             else l.empty(this.tokenarea);\n        ;\n            this.updateTokenarea();\n        },\n        populate: function(y) {\n            var z = [];\n            this.tokens = this.getTokenElements().map(function(aa, ba) {\n                var ca = y[ba];\n                z.push(this._tokenKey(ca));\n                return this.createToken(ca, aa);\n            }, this);\n            this.unique = w(z, this.tokens);\n        },\n        getElement: function() {\n            return this.element;\n        },\n        getTypeahead: function() {\n            return this.typeahead;\n        },\n        getInput: function() {\n            return this.input;\n        },\n        initBehaviors: function() {\n            this.behaviors = (this.behaviors || []);\n            if ((this.behaviors instanceof Array)) {\n                this.behaviors.forEach(function(aa) {\n                    aa.behavior(this, aa.config);\n                }.bind(this));\n            }\n             else for (var y in ((this.behaviors || {\n            }))) {\n                var z = (window.TokenizerBehaviors && window.TokenizerBehaviors[y]);\n                z.call(null, this, this.behaviors[y]);\n            }\n        ;\n        },\n        initTypeahead: function() {\n            var y = this.typeahead.getCore();\n            y.resetOnSelect = true;\n            y.setValueOnSelect = false;\n            y.preventFocusChangeOnTab = true;\n            if (this.inline) {\n                var z = this.typeahead.getView();\n                j.addClass(z.getElement(), \"uiInlineTokenizerView\");\n            }\n        ;\n            this.typeahead.subscribe(\"select\", function(aa, ba) {\n                var ca = ba.selected;\n                if ((\"uid\" in ca)) {\n                    this.updateInput();\n                    this.addToken(this.createToken(ca));\n                }\n            ;\n            }.bind(this));\n            this.typeahead.subscribe(\"blur\", this.handleBlur.bind(this));\n        },\n        handleBlur: function(event) {\n            this.inform(\"blur\", {\n                event: event\n            });\n            this.updatePlaceholder();\n        },\n        initEvents: function() {\n            var y = this.handleEvents.bind(this), z = ((u.firefox() < 4) ? \"keypress\" : \"keydown\");\n            Event.listen(this.tokenarea, {\n                click: y,\n                keydown: y\n            });\n            Event.listen(this.input, \"paste\", this.paste.bind(this));\n            Event.listen(this.input, z, this.keydown.bind(this));\n        },\n        handleEvents: function(event) {\n            var y = event.getTarget(), z = (y && this.getTokenElementFromTarget(y));\n            if (!z) {\n                return\n            };\n            if (((event.type != \"keydown\") || (Event.getKeyCode(event) == o.RETURN))) {\n                this.processEvents(event, y, z);\n            };\n        },\n        processEvents: function(event, y, z) {\n            if (p.byClass(y, \"remove\")) {\n                var aa = z.nextSibling;\n                aa = (aa && m.scry(z.nextSibling, \".remove\")[0]);\n                var ba = this.getTokenFromElement(z);\n                ba = this.addTokenData(ba, y);\n                this.removeToken(ba);\n                this.focusOnTokenRemoval(event, aa);\n                event.kill();\n            }\n        ;\n        },\n        focusOnTokenRemoval: function(event, y) {\n            n.focus((((event.type == \"keydown\") && y) || this.input));\n        },\n        addTokenData: function(y, z) {\n            return y;\n        },\n        keydown: function(event) {\n            this.inform(\"keydown\", {\n                event: event\n            });\n            var y = Event.getKeyCode(event), z = this.input;\n            if (((this.inline && (y == o.BACKSPACE)) && n.isEmpty(z))) {\n                var aa = this.getLastToken();\n                if ((aa && aa.isRemovable())) {\n                    this.removeToken(aa);\n                };\n            }\n        ;\n            this.updateInput();\n        },\n        paste: function(event) {\n            this.inform(\"paste\", {\n                event: event\n            });\n            this.updateInput(true);\n        },\n        focusInput: function() {\n            n.focus(this.input);\n        },\n        updateInput: function(y) {\n            if (!this.inline) {\n                return\n            };\n            setTimeout(function() {\n                this.adjustWidth(this.input.value);\n                if (y) {\n                    this.input.value = this.input.value;\n                };\n            }.bind(this), 20);\n            q.setPlaceholderText(this.input, \"\");\n        },\n        setPlaceholder: function(y) {\n            this.placeholder = y;\n            if (this.stickyPlaceholder) {\n                q.setPlaceholderText(this.input, y);\n            };\n            this.updatePlaceholder();\n        },\n        updatePlaceholder: function() {\n            if ((!this.inline || this.input.value)) {\n                return\n            };\n            var y = !this.tokens.length, z = \"\";\n            if ((y || this.stickyPlaceholder)) {\n                this.adjustWidth(this.placeholder);\n                z = this.placeholder;\n            }\n        ;\n            q.setPlaceholderText(this.input, z);\n        },\n        adjustWidth: function(y) {\n            if ((!this.inline || !this._getIsInDOM())) {\n                return\n            };\n            if (((!y && this.stickyPlaceholder) && (this.input.value === \"\"))) {\n                y = this.placeholder;\n            };\n            var z = this._getMetrics().measure(y), aa = ((z.width + this._getWidthOffset()) + 10);\n            r.set(this.input, \"width\", (aa + \"px\"));\n        },\n        getToken: function(y) {\n            return (this.unique[y] || null);\n        },\n        getTokens: function() {\n            return (this.tokens || []);\n        },\n        getTokenElements: function() {\n            return m.scry(this.tokenarea, \"span.uiToken\");\n        },\n        getTokenElementFromTarget: function(y) {\n            return p.byClass(y, \"uiToken\");\n        },\n        getTokenFromElement: function(y) {\n            return k.get(y, \"Token\");\n        },\n        getTokenValues: function() {\n            return this.tokens.map(function(y) {\n                return y.getValue();\n            });\n        },\n        getFirstToken: function() {\n            return (this.tokens[0] || null);\n        },\n        getLastToken: function() {\n            return (this.tokens[(this.tokens.length - 1)] || null);\n        },\n        hasMaxTokens: function() {\n            return (this.maxTokens && (this.maxTokens <= this.tokens.length));\n        },\n        createToken: function(y, z) {\n            var aa = this.getToken(this._tokenKey(y));\n            aa = (aa || new t(y, this.paramName));\n            (z && aa.setElement(z));\n            return aa;\n        },\n        addToken: function(y) {\n            if (this.hasMaxTokens()) {\n                return\n            };\n            var z = this._tokenKey(y.getInfo());\n            if ((z in this.unique)) {\n                return\n            };\n            this.unique[z] = y;\n            this.tokens.push(y);\n            this.insertToken(y);\n            this.updateTokenarea();\n            this.inform(\"addToken\", y);\n            g.inform(\"Form/change\", {\n                node: this.element\n            });\n        },\n        insertToken: function(y) {\n            l.appendContent(this.tokenarea, y.getElement());\n        },\n        removeToken: function(y) {\n            if (!y) {\n                return\n            };\n            var z = this.tokens.indexOf(y);\n            if ((z < 0)) {\n                return\n            };\n            this.tokens.splice(this.tokens.indexOf(y), 1);\n            delete this.unique[this._tokenKey(y.getInfo())];\n            l.remove(y.getElement());\n            this.updateTokenarea();\n            this.inform(\"removeToken\", y);\n            g.inform(\"Form/change\", {\n                node: this.element\n            });\n        },\n        removeAllTokens: function() {\n            this.reset();\n            this.inform(\"removeAllTokens\");\n        },\n        updateTokenarea: function() {\n            var y = this.typeahead.getCore(), z = this.getTokenValues();\n            if (this.excludeDuplicates) {\n                (this._exclusions || (this._exclusions = y.getExclusions()));\n                y.setExclusions(z.concat(this._exclusions));\n            }\n        ;\n            y.setEnabled(!this.hasMaxTokens());\n            this.updateTokenareaVisibility();\n            this.updatePlaceholder();\n            this.adjustWidth(this.placeholder);\n        },\n        updateTokenareaVisibility: function() {\n            j.conditionShow(this.tokenarea, (this.tokens.length !== 0));\n        },\n        _tokenKey: function(y) {\n            return (y.uid + ((y.freeform ? \":\" : \"\")));\n        },\n        _widthOffset: null,\n        _getWidthOffset: function() {\n            if ((this._widthOffset === null)) {\n                var y = this.input.clientWidth, z = r.getFloat(this.input, \"width\");\n                if ((y == z)) {\n                    this._widthOffset = (r.getFloat(this.input, \"paddingLeft\") + r.getFloat(this.input, \"paddingRight\"));\n                }\n                 else this._widthOffset = 0;\n            ;\n            }\n        ;\n            return this._widthOffset;\n        },\n        _metrics: null,\n        _getMetrics: function() {\n            if (!this._metrics) {\n                this._metrics = new s(this.input, this.inline);\n            };\n            return this._metrics;\n        },\n        _getIsInDOM: function() {\n            return (this._isInDOM || (this._isInDOM = m.contains(document.body, this.input)));\n        }\n    });\n    e.exports = x;\n});\n__d(\"Typeahead\", [\"array-extensions\",\"event-extensions\",\"ArbiterMixin\",\"BehaviorsMixin\",\"Class\",\"DataStore\",\"DOM\",\"Parent\",\"Run\",\"copyProperties\",\"ge\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"BehaviorsMixin\"), i = b(\"Class\"), j = b(\"DataStore\"), k = b(\"DOM\"), l = b(\"Parent\"), m = b(\"Run\"), n = b(\"copyProperties\"), o = b(\"ge\");\n    function p(q, r, s, t) {\n        this.args = {\n            data: q,\n            view: r,\n            core: s\n        };\n        j.set(t, \"Typeahead\", this);\n        this.element = t;\n    };\n    p.getInstance = function(q) {\n        var r = l.byClass(q, \"uiTypeahead\");\n        return (r ? j.get(r, \"Typeahead\") : null);\n    };\n    n(p.prototype, g, h, {\n        init: function(q) {\n            this.init = bagofholding;\n            this.getCore();\n            this.proxyEvents();\n            this.initBehaviors((q || []));\n            this.inform(\"init\", this);\n            this.data.bootstrap();\n            this.core.focus();\n        },\n        getData: function() {\n            if (!this.data) {\n                var q = this.args.data;\n                this.data = q;\n                this.data.init();\n            }\n        ;\n            return this.data;\n        },\n        getView: function() {\n            if (!this.view) {\n                var q = this.args.view, r = o(q.node_id);\n                if (!r) {\n                    r = k.create(\"div\", {\n                        className: \"uiTypeaheadView\"\n                    });\n                    k.appendContent(this.element, r);\n                }\n            ;\n                if ((typeof q.ctor === \"string\")) {\n                    this.view = new window[q.ctor](r, (q.options || {\n                    }));\n                }\n                 else this.view = new q.ctor(r, (q.options || {\n                }));\n            ;\n                this.view.init();\n                this.view.setTypeahead(this.element);\n            }\n        ;\n            return this.view;\n        },\n        getCore: function() {\n            if (!this.core) {\n                var q = this.args.core;\n                if ((typeof q.ctor === \"string\")) {\n                    this.core = new window[q.ctor]((q.options || {\n                    }));\n                }\n                 else this.core = new q.ctor((q.options || {\n                }));\n            ;\n                this.core.init(this.getData(), this.getView(), this.getElement());\n            }\n        ;\n            return this.core;\n        },\n        getElement: function() {\n            return this.element;\n        },\n        swapData: function(q) {\n            var r = this.core;\n            this.data = this.args.data = q;\n            q.init();\n            if (r) {\n                r.data = q;\n                r.initData();\n                r.reset();\n            }\n        ;\n            q.bootstrap();\n            return q;\n        },\n        proxyEvents: function() {\n            [this.data,this.view,this.core,].forEach(function(q) {\n                q.subscribe(q.events, this.inform.bind(this));\n            }, this);\n        },\n        initBehaviors: function(q) {\n            q.forEach(function(r) {\n                if ((typeof r === \"string\")) {\n                    if ((a.TypeaheadBehaviors && a.TypeaheadBehaviors[r])) {\n                        a.TypeaheadBehaviors[r](this);\n                    }\n                     else m.onLoad(function() {\n                        if (a.TypeaheadBehaviors) {\n                            ((a.TypeaheadBehaviors[r] || bagofholding))(this);\n                        };\n                    }.bind(this));\n                ;\n                }\n                 else this.enableBehavior(r);\n            ;\n            }, this);\n        }\n    });\n    p.initNow = function(q, r, s) {\n        if (s) {\n            s.init(q);\n        };\n        q.init(r);\n    };\n    p.init = function(q, r, s, t) {\n        if (!k.isNodeOfType(q, [\"input\",\"textarea\",])) {\n            q = (k.scry(q, \"input\")[0] || k.scry(q, \"textarea\")[0]);\n        };\n        var u = false;\n        try {\n            u = (document.activeElement === q);\n        } catch (v) {\n        \n        };\n        if (u) {\n            p.initNow(r, s, t);\n        }\n         else var w = Event.listen(q, \"focus\", function() {\n            p.initNow(r, s, t);\n            w.remove();\n        })\n    ;\n    };\n    e.exports = p;\n});\n__d(\"TypeaheadCore\", [\"event-extensions\",\"Arbiter\",\"ArbiterMixin\",\"Class\",\"CSS\",\"DOM\",\"Input\",\"InputSelection\",\"Keys\",\"UserAgent\",\"bind\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"Class\"), j = b(\"CSS\"), k = b(\"DOM\"), l = b(\"Input\"), m = b(\"InputSelection\"), n = b(\"Keys\"), o = b(\"UserAgent\"), p = b(\"bind\"), q = b(\"copyProperties\");\n    function r(s) {\n        q(this, s);\n    };\n    q(r.prototype, h, {\n        events: [\"blur\",\"focus\",\"click\",\"unselect\",\"loading\",],\n        keepFocused: true,\n        resetOnSelect: false,\n        resetOnKeyup: true,\n        setValueOnSelect: false,\n        queryTimeout: 250,\n        preventFocusChangeOnTab: false,\n        init: function(s, t, u) {\n            this.init = bagofholding;\n            this.data = s;\n            this.view = t;\n            this.root = u;\n            this.initInput();\n            this.inputWrap = k.find(u, \"div.wrap\");\n            this.hiddenInput = k.find(u, \"input.hiddenInput\");\n            this.value = \"\";\n            this.nextQuery = null;\n            this.selectedText = null;\n            if ((this.setValueOnSelect && j.hasClass(this.inputWrap, \"selected\"))) {\n                this.selectedText = this.getValue();\n            };\n            this.initView();\n            this.initData();\n            this.initEvents();\n            this.initToggle();\n            this._exclusions = [];\n        },\n        initInput: function() {\n            this.element = k.find(this.root, \".textInput\");\n            var s = k.scry(this.element, \"input\")[0];\n            if (s) {\n                this.element = s;\n            };\n        },\n        initView: function() {\n            this.view.subscribe(\"highlight\", function(s, t) {\n                this.element.focus();\n                this.element.setAttribute(\"aria-activedescendant\", (((t.index !== -1)) ? k.getID(t.element) : \"\"));\n            }.bind(this));\n            this.view.subscribe(\"select\", function(s, t) {\n                this.select(t.selected);\n            }.bind(this));\n            this.view.subscribe(\"afterSelect\", function() {\n                this.afterSelect();\n            }.bind(this));\n        },\n        initData: function() {\n            this.data.subscribe(\"respond\", function(s, t) {\n                if ((t.forceDisplay || ((t.value == this.getValue()) && !this.element.disabled))) {\n                    this.view.render(t.value, t.results, t.isAsync);\n                };\n            }.bind(this));\n            this.data.subscribe(\"activity\", function(s, t) {\n                this.fetching = t.activity;\n                if (!this.fetching) {\n                    (this.nextQuery && this.performQuery());\n                };\n                if ((this.loading != this.fetching)) {\n                    this.loading = this.fetching;\n                    this.inform(\"loading\", {\n                        loading: this.loading\n                    });\n                }\n            ;\n            }.bind(this));\n        },\n        initEvents: function() {\n            Event.listen(this.view.getElement(), {\n                mouseup: this.viewMouseup.bind(this),\n                mousedown: this.viewMousedown.bind(this)\n            });\n            var s = {\n                blur: p(this, \"blur\"),\n                focus: p(this, \"focus\"),\n                click: p(this, \"click\"),\n                keyup: p(this, \"keyup\"),\n                keydown: p(this, \"keydown\")\n            };\n            if (o.firefox()) {\n                s.text = s.keyup;\n            };\n            if ((o.firefox() < 4)) {\n                s.keypress = s.keydown;\n                delete s.keydown;\n            }\n        ;\n            Event.listen(this.element, s);\n            Event.listen(this.element, \"keypress\", p(this, \"keypress\"));\n        },\n        initToggle: function() {\n            this.subscribe(\"blur\", this.view.hide.bind(this.view));\n            this.subscribe(\"focus\", this.view.show.bind(this.view));\n        },\n        viewMousedown: function() {\n            this.selecting = true;\n        },\n        viewMouseup: function() {\n            this.selecting = false;\n        },\n        blur: function() {\n            if (this.selecting) {\n                this.selecting = false;\n                return;\n            }\n        ;\n            this.inform(\"blur\");\n        },\n        click: function() {\n            var s = m.get(this.element);\n            if ((s.start == s.end)) {\n                this.element.select();\n            };\n            this.inform(\"click\");\n        },\n        focus: function() {\n            this.checkValue();\n            this.inform(\"focus\");\n        },\n        keyup: function() {\n            if ((this.resetOnKeyup && !this.getValue())) {\n                this.view.reset();\n            };\n            this.checkValue();\n        },\n        keydown: function(event) {\n            if ((!this.view.isVisible() || this.view.isEmpty())) {\n                this.checkValue.bind(this).defer();\n                return;\n            }\n        ;\n            switch (Event.getKeyCode(event)) {\n              case n.TAB:\n                this.handleTab(event);\n                return;\n              case n.UP:\n                this.view.prev();\n                break;\n              case n.DOWN:\n                this.view.next();\n                break;\n              case n.ESC:\n                this.view.reset();\n                break;\n              default:\n                this.checkValue.bind(this).defer();\n                return;\n            };\n            event.kill();\n        },\n        keypress: function(event) {\n            if ((this.view.getSelection() && (Event.getKeyCode(event) == n.RETURN))) {\n                this.view.select();\n                event.kill();\n            }\n        ;\n        },\n        handleTab: function(event) {\n            if (this.preventFocusChangeOnTab) {\n                if (this.view.getSelection()) {\n                    event.kill();\n                }\n                 else event.preventDefault();\n            \n            };\n            this.view.select();\n        },\n        select: function(s) {\n            if ((s && this.setValueOnSelect)) {\n                this.setValue(s.text);\n                this.setHiddenValue(s.uid);\n                this.selectedText = s.text;\n                j.addClass(this.inputWrap, \"selected\");\n            }\n        ;\n        },\n        afterSelect: function() {\n            (this.keepFocused ? this.element.focus() : this.element.blur());\n            (this.resetOnSelect ? this.reset() : this.view.reset());\n        },\n        unselect: function() {\n            if (this.setValueOnSelect) {\n                this.selectedText = null;\n                j.removeClass(this.inputWrap, \"selected\");\n            }\n        ;\n            this.setHiddenValue();\n            this.inform(\"unselect\", this);\n        },\n        setEnabled: function(s) {\n            var t = (s === false);\n            this.element.disabled = t;\n            j.conditionClass(this.root, \"uiTypeaheadDisabled\", t);\n        },\n        reset: function() {\n            this.unselect();\n            this.setValue();\n            (!this.keepFocused && l.reset(this.element));\n            this.view.reset();\n            this.inform(\"reset\");\n        },\n        getElement: function() {\n            return this.element;\n        },\n        setExclusions: function(s) {\n            this._exclusions = s;\n        },\n        getExclusions: function() {\n            return this._exclusions;\n        },\n        setValue: function(s) {\n            this.value = this.nextQuery = (s || \"\");\n            l.setValue(this.element, this.value);\n        },\n        setHiddenValue: function(s) {\n            this.hiddenInput.value = (((s || (s === 0))) ? s : \"\");\n            g.inform(\"Form/change\", {\n                node: this.hiddenInput\n            });\n        },\n        getValue: function() {\n            return l.getValue(this.element);\n        },\n        getHiddenValue: function() {\n            return (this.hiddenInput.value || \"\");\n        },\n        checkValue: function() {\n            var s = this.getValue();\n            if ((s == this.value)) {\n                return\n            };\n            if ((this.selectedText && (this.selectedText != s))) {\n                this.unselect();\n            };\n            var t = Date.now(), u = (t - this.time);\n            this.time = t;\n            this.value = this.nextQuery = s;\n            this.performQuery(u);\n        },\n        performQuery: function(s) {\n            if (this.selectedText) {\n                return\n            };\n            s = (s || 0);\n            if ((this.fetching && (s < this.queryTimeout))) {\n                this.data.query(this.nextQuery, true, this._exclusions);\n            }\n             else {\n                this.data.query(this.nextQuery, false, this._exclusions);\n                this.nextQuery = null;\n            }\n        ;\n        }\n    });\n    e.exports = r;\n});\n__d(\"UntrustedLink\", [\"DOM\",\"event-extensions\",\"URI\",\"UserAgent\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"event-extensions\"), i = b(\"URI\"), j = b(\"UserAgent\"), k = b(\"copyProperties\");\n    function l(m, n, o, p) {\n        this.dom = m;\n        this.url = m.href;\n        this.hash = n;\n        this.func_get_params = (p || function() {\n            return {\n            };\n        });\n        Event.listen(this.dom, \"click\", this.onclick.bind(this));\n        Event.listen(this.dom, \"mousedown\", this.onmousedown.bind(this));\n        Event.listen(this.dom, \"mouseup\", this.onmouseup.bind(this));\n        Event.listen(this.dom, \"mouseout\", this.onmouseout.bind(this));\n        this.onmousedown(h.$E(o));\n    };\n    l.bootstrap = function(m, n, o, p) {\n        if (m.__untrusted) {\n            return\n        };\n        m.__untrusted = true;\n        new l(m, n, o, p);\n    };\n    l.prototype.getRewrittenURI = function() {\n        var m = k({\n            u: this.url,\n            h: this.hash\n        }, this.func_get_params(this.dom)), n = new i(\"/l.php\");\n        return n.setQueryData(m).setSubdomain(\"www\").setProtocol(\"http\");\n    };\n    l.prototype.onclick = function() {\n        (function() {\n            this.setHref(this.url);\n        }).bind(this).defer(100);\n        this.setHref(this.getRewrittenURI());\n    };\n    l.prototype.onmousedown = function(m) {\n        if ((m.button == 2)) {\n            this.setHref(this.getRewrittenURI());\n        };\n    };\n    l.prototype.onmouseup = function() {\n        this.setHref(this.getRewrittenURI());\n    };\n    l.prototype.onmouseout = function() {\n        this.setHref(this.url);\n    };\n    l.prototype.setHref = function(m) {\n        if ((j.ie() < 9)) {\n            var n = g.create(\"span\");\n            g.appendContent(this.dom, n);\n            this.dom.href = m;\n            g.remove(n);\n        }\n         else this.dom.href = m;\n    ;\n    };\n    e.exports = l;\n});\n__d(\"UIIntentionalStreamMessage\", [], function(a, b, c, d, e, f) {\n    var g = {\n        SET_AUTO_INSERT: \"UIIntentionalStream/setAutoInsert\",\n        UPDATE_STREAM: \"UIIntentionalStreamRefresh/updateStream\",\n        REFRESH_STREAM: \"UIIntentionalStreamRefresh/refreshStream\",\n        UPDATE_AUTOREFRESH_CONFIG: \"UIIntentionalStream/updateAutoRefreshConfig\",\n        UPDATE_HTML_CONTENT: \"UIIntentionalStream/updateHtmlContent\",\n        UPDATE_LAST_REFRESH_TIME: \"UIIntentionalStream/updateLastRefreshTime\",\n        INSERT_STORIES: \"UIIntentionalStream/updateLastRefreshTime\",\n        UNLOAD: \"UIIntentionalStream/unload\"\n    };\n    e.exports = g;\n});\n__d(\"collectSubtreeData\", [], function(a, b, c, d, e, f) {\n    function g(i, j, k, l, m) {\n        if (((i.offsetWidth === 0) && (i.offsetHeight === 0))) {\n            return m\n        };\n        var n = {\n        };\n        if (i.getAttribute) {\n            for (r = 0; (r < j.length); r++) {\n                t = j[r];\n                var o = i.getAttribute(k[t]);\n                if (o) {\n                    n[t] = {\n                    };\n                    var p = JSON.parse(o);\n                    for (var q in l) {\n                        if ((p[q] !== undefined)) {\n                            n[t][q] = true;\n                            if ((m[t] === undefined)) {\n                                m[t] = {\n                                };\n                            };\n                            if ((m[t][q] === undefined)) {\n                                m[t][q] = [];\n                            };\n                            if ((l[q].length > 0)) {\n                                m[t][q].push(l[q]);\n                            };\n                            m[t][q].push((\"(\" + p[q]));\n                        }\n                    ;\n                    };\n                }\n            ;\n            }\n        };\n        for (var r = 0; (r < i.childNodes.length); r++) {\n            var s = i.childNodes[r];\n            g(s, j, k, l, m);\n        };\n        for (var t in n) {\n            for (var u in n[t]) {\n                var v = m[t][u][(m[t][u].length - 1)];\n                if (((v.length > 0) && (v.charAt(0) == \"(\"))) {\n                    m[t][u][(m[t][u].length - 1)] = v.substr(1);\n                }\n                 else m[t][u].push(\")\");\n            ;\n            };\n        };\n        return m;\n    };\n    function h(i, j) {\n        var k = {\n        };\n        for (var l = 0; (l < j.length); ++l) {\n            k[j[l]] = (\"data-\" + j[l]);;\n        };\n        var m = {\n            tn: \"\",\n            \"tn-debug\": \",\"\n        }, n = {\n        };\n        g(i, j, k, m, n);\n        for (var o in n) {\n            for (var p in n[o]) {\n                n[o][p] = n[o][p].join(\"\");;\n            };\n        };\n        return n;\n    };\n    e.exports = h;\n});\n__d(\"ViewportTracking\", [\"event-extensions\",\"Arbiter\",\"DOM\",\"NavigationMessage\",\"Run\",\"Style\",\"UIIntentionalStreamMessage\",\"Vector\",\"$\",\"collectSubtreeData\",\"copyProperties\",\"debounce\",\"userAction\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"DOM\"), i = b(\"NavigationMessage\"), j = b(\"Run\"), k = b(\"Style\"), l = b(\"UIIntentionalStreamMessage\"), m = b(\"Vector\"), n = b(\"$\"), o = b(\"collectSubtreeData\"), p = b(\"copyProperties\"), q = b(\"debounce\"), r = b(\"userAction\"), s = \"vpv\";\n    function t() {\n    \n    };\n    p(t.prototype, {\n        init: function(u) {\n            p(this, {\n                readStoryIDs: {\n                },\n                minSizeToBeVisible: 200,\n                listeners: [],\n                arbiterSubscriptions: []\n            });\n            this.getDataFromConfig(u);\n            this.fireTimer();\n            var v = q(this.fireTimer, this.getTimeout(), this);\n            this.listeners.push(Event.listen(window, \"scroll\", v));\n            this.listeners.push(Event.listen(window, \"resize\", v));\n            this.arbiterSubscriptions.push(g.subscribe(l.UPDATE_HTML_CONTENT, v));\n            j.onLeave(this.cleanup.bind(this));\n            this.arbiterSubscriptions.push(g.subscribe(i.NAVIGATION_BEGIN, this.cleanup.bind(this)));\n        },\n        cleanup: function() {\n            this.listeners.forEach(function(u) {\n                u.remove();\n            });\n            this.listeners = [];\n            this.arbiterSubscriptions.forEach(function(u) {\n                u.unsubscribe();\n            });\n            this.arbiterSubscriptions = [];\n        },\n        fireTimer: function() {\n            this.getStoriesInView().forEach(this.markStoryRead.bind(this));\n        },\n        getStoriesInView: function() {\n            var u = this.getAllStories(), v = [], w = false;\n            for (var x = 0; (x < u.length); x++) {\n                var y = u[x], z = this.getStoryID(y);\n                if (this.hasBeenVisible(z)) {\n                    continue;\n                };\n                if (this.isVisible(y)) {\n                    v.push(y);\n                    w = true;\n                }\n                 else if (w) {\n                    break;\n                }\n            ;\n            };\n            return v;\n        },\n        hasBeenVisible: function(u) {\n            return (u in this.readStoryIDs);\n        },\n        isVisible: function(u) {\n            var v = m.getViewportDimensions(), w = m.getElementPosition(u, \"viewport\"), x = m.getElementDimensions(u), y = Math.max(w.y, 0), z = Math.min((w.y + x.y), v.y), aa = Math.min(x.y, this.minSizeToBeVisible);\n            return (((z - y)) >= aa);\n        },\n        markStoryRead: function(u) {\n            var v = this.getStoryID(u);\n            if (!v) {\n                return\n            };\n            if (!this.hasBeenVisible(v)) {\n                this.readStoryIDs[v] = true;\n                var w = this.getDataToLog(u);\n                r(s, u, null, \"FORCE\", w);\n            }\n        ;\n        }\n    });\n    e.exports = t;\n});\n__d(\"XHPTemplate\", [\"event-extensions\",\"DataStore\",\"DOM\",\"HTML\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"DataStore\"), h = b(\"DOM\"), i = b(\"HTML\"), j = b(\"copyProperties\");\n    function k(m) {\n        this._model = m;\n    };\n    j(k.prototype, {\n        render: function() {\n            if (i.isHTML(this._model)) {\n                this._model = h.setContent(document.createDocumentFragment(), this._model)[0];\n            };\n            return this._model.cloneNode(true);\n        },\n        build: function() {\n            return new l(this.render());\n        }\n    });\n    j(k, {\n        getNode: function(m, n) {\n            return k.getNodes(m)[n];\n        },\n        getNodes: function(m) {\n            var n = g.get(m, \"XHPTemplate:nodes\");\n            if (!n) {\n                n = {\n                };\n                var o = h.scry(m, \"[data-jsid]\");\n                o.push(m);\n                var p = o.length;\n                while (p--) {\n                    var q = o[p];\n                    n[q.getAttribute(\"data-jsid\")] = q;\n                    q.removeAttribute(\"data-jsid\");\n                };\n                g.set(m, \"XHPTemplate:nodes\", n);\n            }\n        ;\n            return n;\n        }\n    });\n    function l(m) {\n        this._root = m;\n        this._populateNodes();\n    };\n    j(l.prototype, {\n        _populateNodes: function() {\n            this._nodes = {\n            };\n            this._leaves = {\n            };\n            var m = this._root.getElementsByTagName(\"*\");\n            for (var n = 0, o = m.length; (n < o); n++) {\n                var p = m[n], q = p.getAttribute(\"data-jsid\");\n                if (q) {\n                    p.removeAttribute(\"data-jsid\");\n                    this._nodes[q] = p;\n                    this._leaves[q] = !p.childNodes.length;\n                }\n            ;\n            };\n        },\n        getRoot: function() {\n            return this._root;\n        },\n        getNode: function(m) {\n            return this._nodes[m];\n        },\n        setNodeProperty: function(m, n, o) {\n            this.getNode(m)[n] = o;\n            return this;\n        },\n        setNodeContent: function(m, n) {\n            if (!this._leaves[m]) {\n                throw new Error((\"Can't setContent on non-leaf node: \" + m))\n            };\n            h.setContent(this.getNode(m), n);\n            return this;\n        }\n    });\n    e.exports = k;\n});\n__d(\"enforceMaxLength\", [\"event-extensions\",\"function-extensions\",\"DOM\",\"Input\",\"InputSelection\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"DOM\"), h = b(\"Input\"), i = b(\"InputSelection\"), j = function(m, n) {\n        var o = h.getValue(m), p = o.length, q = (p - n);\n        if ((q > 0)) {\n            var r, s;\n            try {\n                r = i.get(m);\n                s = r.end;\n            } catch (t) {\n                r = null;\n                s = 0;\n            };\n            if ((s >= q)) {\n                p = s;\n            };\n            var u = (p - q);\n            if ((u && (((o.charCodeAt((u - 1)) & 64512)) === 55296))) {\n                u--;\n            };\n            s = Math.min(s, u);\n            h.setValue(m, (o.slice(0, u) + o.slice(p)));\n            if (r) {\n                i.set(m, Math.min(r.start, s), s);\n            };\n        }\n    ;\n    }, k = function(event) {\n        var m = event.getTarget(), n = (m.getAttribute && parseInt(m.getAttribute(\"maxlength\"), 10));\n        if (((n > 0) && g.isNodeOfType(m, [\"input\",\"textarea\",]))) {\n            j.bind(null, m, n).defer();\n        };\n    }, l = ((\"maxLength\" in g.create(\"input\")) && (\"maxLength\" in g.create(\"textarea\")));\n    if (!l) {\n        Event.listen(document.documentElement, {\n            keydown: k,\n            paste: k\n        });\n    };\n    e.exports = j;\n});\n__d(\"htmlHyperlink\", [\"Env\",\"htmlize\",\"UntrustedLink\",\"URI\",\"URLScraper\",], function(a, b, c, d, e, f) {\n    var g = b(\"Env\"), h = b(\"htmlize\"), i = b(\"UntrustedLink\"), j = b(\"URI\"), k = b(\"URLScraper\");\n    function l(m, n, o, p) {\n        if (((typeof m === \"undefined\") || !m.toString)) {\n            return \"\"\n        };\n        if ((typeof n !== \"function\")) {\n            n = h;\n        };\n        if ((typeof o !== \"function\")) {\n            o = h;\n        };\n        var m = m.toString(), q = [], r;\n        while ((r = k.match(m))) {\n            var s = m.indexOf(r);\n            if ((s >= 0)) {\n                q.push(n(m.substring(0, s)));\n            };\n            var t = o(r), u = r.replace(/\"/g, \"\u002522\");\n            if (!(/^[a-z][a-z0-9\\-+.]+:\\/\\//i.test(r))) {\n                u = (\"http://\" + u);\n            };\n            q.push(((\"\\u003Ca target=\\\"_blank\\\" rel=\\\"nofollow\\\" href=\\\"\" + u) + \"\\\"\"));\n            if ((p && !j(u).isFacebookURI())) {\n                a.UntrustedLink = i;\n                q.push(((\" onmousedown=\\\"UntrustedLink.bootstrap(this, '\" + g.lhsh) + \"', event)\\\"\"));\n            }\n        ;\n            q.push(((\"\\u003E\" + t) + \"\\u003C/a\\u003E\"));\n            m = m.substring((s + r.length));\n        };\n        (m && q.push(n(m)));\n        return q.join(\"\");\n    };\n    e.exports = l;\n});\n__d(\"randomInt\", [], function(a, b, c, d, e, f) {\n    function g(h, i) {\n        if ((arguments.length === 1)) {\n            i = h;\n            h = 0;\n        }\n    ;\n        var j = (this.random || Math.random);\n        return Math.floor((h + (j() * ((i - h)))));\n    };\n    e.exports = g;\n});\n__d(\"setIntervalAcrossTransitions\", [], function(a, b, c, d, e, f) {\n    function g(h, i) {\n        return setInterval(h, i, false);\n    };\n    e.exports = g;\n});\n__d(\"setTimeoutAcrossTransitions\", [], function(a, b, c, d, e, f) {\n    function g(h, i) {\n        return setTimeout(h, i, false);\n    };\n    e.exports = g;\n});\n__d(\"submitForm\", [\"DOM\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = function(i) {\n        var j = g.scry(i, \"input[type=\\\"submit\\\"]\")[0];\n        if (j) {\n            j.click();\n        }\n         else {\n            j = g.create(\"input\", {\n                type: \"submit\",\n                className: \"hidden_elem\"\n            });\n            g.appendContent(i, j);\n            j.click();\n            g.remove(j);\n        }\n    ;\n    };\n    e.exports = h;\n});\n__d(\"debounceAcrossTransitions\", [\"debounce\",], function(a, b, c, d, e, f) {\n    var g = b(\"debounce\");\n    function h(i, j, k) {\n        return g(i, j, k, true);\n    };\n    e.exports = h;\n});\n__d(\"legacy:onvisible\", [\"OnVisible\",], function(a, b, c, d) {\n    a.OnVisible = b(\"OnVisible\");\n}, 3);\n__d(\"PhotoEverstoreLogger\", [\"event-extensions\",\"AsyncRequest\",\"copyProperties\",\"ImageUtils\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"AsyncRequest\"), h = b(\"copyProperties\"), i = b(\"ImageUtils\"), j = {\n        BATCH_WINDOW_MS: 500,\n        storedLog: []\n    };\n    function k() {\n    \n    };\n    h(k, {\n        _log: function(m) {\n            j.storedLog.push(m);\n            if ((j.storedLog.length == 1)) {\n                setTimeout(l, j.BATCH_WINDOW_MS, false);\n            };\n        },\n        logImmediately: function(m) {\n            k._log(m);\n        },\n        registerForLogging: function(m) {\n            if (i.hasLoaded(m)) {\n                k._log(m.src);\n            }\n             else Event.listen(m, \"load\", function(event) {\n                k._log(m.src);\n            });\n        ;\n        }\n    });\n    function l() {\n        var m = j.storedLog;\n        j.storedLog = [];\n        var n = JSON.stringify(m);\n        new g().setURI(\"/ajax/photos/logging/everstore_logging.php\").setData({\n            loggedUrls: n\n        }).setMethod(\"POST\").setOption(\"suppressErrorHandlerWarning\", true).setOption(\"suppressErrorAlerts\", true).send();\n    };\n    e.exports = k;\n});\n__d(\"PhotoSessionLog\", [\"AsyncRequest\",\"Run\",\"Vector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncRequest\"), h = b(\"Run\"), i = b(\"Vector\"), j = b(\"copyProperties\");\n    function k() {\n    \n    };\n    j(k, {\n        UNKNOWN: 0,\n        ESC: 1,\n        X: 2,\n        OUTSIDE: 3,\n        UNLOAD: 4,\n        NAVIGATE: 5,\n        AGGREGATE: 6,\n        LEAVE: 7,\n        PERMALINK: 0,\n        SNOWLIFT: 6,\n        AGGREGATION_COUNT: 20,\n        set: null,\n        time: null,\n        views: 0,\n        fbidList: [],\n        details: {\n        },\n        width: 0,\n        height: 0,\n        first: false,\n        last: false,\n        logIds: false,\n        version: null,\n        buttonLikes: 0,\n        pagingAction: \"\",\n        faceTagImpressions: 0,\n        cycle: false,\n        endOfRelevant: false,\n        relevantCount: 0,\n        initLogging: function(l) {\n            this.set = null;\n            this.time = new Date();\n            this.views = 0;\n            this.hiResLoads = 0;\n            this.fullScreenViews = {\n            };\n            this.first = true;\n            this.last = false;\n            this.logIds = false;\n            this.version = l;\n            this.buttonLikes = 0;\n            this.pagingAction = \"\";\n            this.faceTagImpressions = 0;\n            this.cycle = false;\n            this.endOfRelevant = false;\n            this.relevantCount = 0;\n            if ((l === k.SNOWLIFT)) {\n                var m = i.getViewportDimensions();\n                this.width = m.x;\n                this.height = m.y;\n            }\n        ;\n        },\n        setLogFbids: function(l) {\n            this.logIds = l;\n        },\n        setPhotoSet: function(l) {\n            this.set = l;\n        },\n        addButtonLike: function() {\n            this.buttonLikes++;\n        },\n        setPagingAction: function(l) {\n            this.pagingAction = l;\n        },\n        addFaceTagImpression: function() {\n            this.faceTagImpressions++;\n        },\n        setCycle: function(l) {\n            this.cycle = l;\n        },\n        setEndOfRelevant: function(l) {\n            this.endOfRelevant = l;\n        },\n        setRelevantCount: function(l) {\n            this.relevantCount = l;\n        },\n        setEndMetrics: function(l) {\n            this.endMetrics = l;\n        },\n        addPhotoView: function(l, m, n) {\n            if ((this.logIds && (this.views >= this.AGGREGATION_COUNT))) {\n                this.logPhotoViews(this.AGGREGATE);\n            };\n            this.views++;\n            if (l) {\n                this.fbidList.push([l.fbid,l.owner,Date.now(),]);\n            };\n            if (m) {\n                this.hiResLoads++;\n            };\n            if (n) {\n                this.fullScreenViews[l.fbid] = true;\n            };\n        },\n        logEnterFullScreen: function(l) {\n            this.fullScreenViews[l] = true;\n        },\n        addDetailData: function(l, m) {\n            if (!this.details[l]) {\n                this.details[l] = {\n                    t: m.num_tags,\n                    l: m.has_location,\n                    c: m.has_caption,\n                    cm: m.comment_count,\n                    lk: m.like_count,\n                    w: m.width,\n                    h: m.height,\n                    ad: \"{}\",\n                    p: this.pagingAction\n                };\n            };\n        },\n        updateAdData: function(l, m) {\n            if (this.details[l]) {\n                this.details[l].ad = JSON.stringify(m);\n            };\n        },\n        logPhotoViews: function(l) {\n            if (((!this.views) || (((this.version === k.SNOWLIFT) && (l == k.LEAVE))))) {\n                return\n            };\n            if ((l != this.AGGREGATE)) {\n                this.last = true;\n            };\n            var m = {\n                set: this.set,\n                time: (new Date() - this.time),\n                fbids: (this.logIds ? this.fbidList : []),\n                details: (this.logIds ? this.details : {\n                }),\n                first: this.first,\n                last: this.last,\n                close: (l ? l : this.UNKNOWN),\n                button_likes: this.buttonLikes,\n                version: this.version,\n                face_imp: this.faceTagImpressions,\n                endmetric: this.endMetrics,\n                cycle: this.cycle,\n                end_relev: this.endOfRelevant,\n                relev_count: this.relevantCount\n            };\n            if ((this.version === k.SNOWLIFT)) {\n                var n = i.getViewportDimensions();\n                m.width = (n.x || this.width);\n                m.height = (n.y || this.height);\n                if ((this.hiResLoads > 0)) {\n                    m.hires_loads = this.hiResLoads;\n                };\n                if (this.last) {\n                    var o = Object.keys(this.fullScreenViews).length;\n                    if ((o > 0)) {\n                        m.fullscreen = o;\n                    };\n                }\n            ;\n            }\n        ;\n            new g().setURI(\"/ajax/photos/logging/session_logging.php\").setAllowCrossPageTransition(true).setOption(\"asynchronous\", ((l != k.UNLOAD))).setOption(\"suppressErrorHandlerWarning\", true).setData(m).send();\n            this.views = 0;\n            this.hiResLoads = 0;\n            this.fbidList = [];\n            this.details = {\n            };\n            this.first = false;\n            this.buttonLikes = 0;\n            if (this.last) {\n                this.set = null;\n                this.logIds = false;\n                this.fullScreenViews = {\n                };\n            }\n        ;\n        }\n    });\n    h.onUnload(function() {\n        k.logPhotoViews(k.UNLOAD);\n    });\n    h.onLeave(function() {\n        k.logPhotoViews(k.LEAVE);\n    });\n    e.exports = k;\n});\n__d(\"PhotosConst\", [], function(a, b, c, d, e, f) {\n    var g = {\n        VIEWER_PERMALINK: 0,\n        VIEWER_SNOWLIFT: 6,\n        VIEWER_VAULTBOX: 8,\n        BULK_EDITOR: 3,\n        FLASH_UPLOADER: 4,\n        HTML5_UPLOADER: 10,\n        SIZE_NORMAL: \"n\"\n    };\n    e.exports = g;\n});\n__d(\"PhotosUtils\", [\"copyProperties\",\"Rect\",\"Vector\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\"), h = b(\"Rect\"), i = b(\"Vector\");\n    function j() {\n    \n    };\n    g(j, {\n        getNearestBox: function(k, l) {\n            var m = Infinity, n = null;\n            for (var o in k) {\n                var p = k[o];\n                if (p.contains(l)) {\n                    var q = l.distanceTo(p.getCenter());\n                    if ((q < m)) {\n                        m = q;\n                        n = o;\n                    }\n                ;\n                }\n            ;\n            };\n            return n;\n        },\n        absoluteToNormalizedPosition: function(k, l) {\n            var m = i.getElementPosition(k), n = i.getElementDimensions(k), o = l.sub(m).mul((100 / n.x), (100 / n.y));\n            o.domain = \"pure\";\n            return o;\n        },\n        normalizedToAbsolutePosition: function(k, l) {\n            var m = i.getElementPosition(k), n = i.getElementDimensions(k), o = l.mul((n.x / 100), (n.y / 100)).add(m);\n            o.domain = \"document\";\n            return o;\n        },\n        isFacebox: function(k) {\n            return k.match(/^face:/);\n        }\n    });\n    e.exports = j;\n});\n__d(\"PhotoStreamCache\", [\"array-extensions\",\"HTML\",\"PhotosConst\",\"PhotoEverstoreLogger\",\"Rect\",\"UIPagelet\",\"URI\",\"Vector\",\"copyProperties\",\"createArrayFrom\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    var g = b(\"HTML\"), h = b(\"PhotosConst\"), i = b(\"PhotoEverstoreLogger\"), j = b(\"Rect\"), k = b(\"UIPagelet\"), l = b(\"URI\"), m = b(\"Vector\"), n = b(\"copyProperties\"), o = b(\"createArrayFrom\");\n    function p() {\n    \n    };\n    n(p, {\n        ERROR: \"error\",\n        HTML: \"html\",\n        IMAGE_DATA: \"image\",\n        EXTRA: \"extra\",\n        BUFFER_SIZE: 3,\n        INIT_BUCKET_SIZE: 4,\n        FULL_BUCKET_SIZE: 12,\n        ERROR_ID: -1,\n        INIT_PLACEHOLDER: 1\n    });\n    n(p.prototype, {\n        init: function(q, r) {\n            this.version = q;\n            this.pageletName = r;\n            this.bufferSize = p.BUFFER_SIZE;\n            this.fullBucketSize = p.FULL_BUCKET_SIZE;\n            this.initError = false;\n            this.isActive = true;\n            this.leftLock = false;\n            this.rightLock = false;\n            this.reset();\n        },\n        reset: function() {\n            this.cache = {\n                image: {\n                },\n                extra: {\n                },\n                html: {\n                }\n            };\n            this.fbidList = [];\n            this.loaded = false;\n            this.allLoaded = false;\n            this.permalinkMap = {\n            };\n            this.position = 0;\n            this.totalCount = null;\n            this.firstCursor = null;\n            this.firstCursorIndex = null;\n        },\n        waitForInitData: function() {\n            this.fbidList.push(p.INIT_PLACEHOLDER);\n        },\n        destroy: function() {\n            this.reset();\n            this.isActive = false;\n        },\n        isLoaded: function() {\n            return this.loaded;\n        },\n        canPage: function() {\n            if (!this.isLoaded()) {\n                return false\n            };\n            if ((this.totalCount !== null)) {\n                return (this.totalCount > 1)\n            };\n            return (this.getLength() > 1);\n        },\n        errorInCurrent: function() {\n            if (this.initError) {\n                return true;\n            }\n             else if (!this.isLoaded()) {\n                return false\n            }\n        ;\n            return this.checkErrorAt(this.getCursor());\n        },\n        getLength: function() {\n            return this.fbidList.length;\n        },\n        getPhotoSet: function() {\n            return this.photoSetQuery.set;\n        },\n        getPhotoSetQuery: function() {\n            return this.photoSetQuery;\n        },\n        getCurrentImageData: function() {\n            return this.getImageData(this.getCursor());\n        },\n        getImageData: function(q) {\n            return this.getCacheContent(q, p.IMAGE_DATA);\n        },\n        getCurrentHtml: function() {\n            return this.getCacheContent(this.getCursor(), p.HTML);\n        },\n        getCurrentExtraData: function() {\n            return this.getCacheContent(this.getCursor(), p.EXTRA);\n        },\n        getCacheContent: function(q, r) {\n            if (((!q || (q === p.ERROR_ID)) || (q === p.INIT_PLACEHOLDER))) {\n                return null\n            };\n            return this.cache[r][q];\n        },\n        getCursorPos: function() {\n            return this.position;\n        },\n        getCursor: function() {\n            if (((this.position >= 0) && (this.position < this.getLength()))) {\n                return this.fbidList[this.position]\n            };\n            return null;\n        },\n        getCursorForURI: function(q) {\n            return this.permalinkMap[q];\n        },\n        calculatePositionForMovement: function(q) {\n            var r = (this.position + q);\n            if (this.allLoaded) {\n                var s = this.getLength();\n                r = (((s + (r \u0025 s))) \u0025 s);\n            }\n        ;\n            return r;\n        },\n        isValidMovement: function(q) {\n            if ((!this.isLoaded() || !this.canPage())) {\n                return false\n            };\n            var r = this.calculatePositionForMovement(q);\n            return ((this.getCursor() > 0) || (((r >= 0) && (r < this.getLength()))));\n        },\n        moveCursor: function(q) {\n            if (!this.isValidMovement(q)) {\n                return\n            };\n            this.position = this.calculatePositionForMovement(q);\n            if ((q !== 0)) {\n                this.loadMoreIfNeccessary((q > 0));\n            };\n        },\n        checkErrorAt: function(q) {\n            if (!this.isLoaded()) {\n                return false\n            };\n            if ((q === p.ERROR_ID)) {\n                return true\n            };\n            return false;\n        },\n        getRelativeMovement: function(q) {\n            for (var r = 0; (r < this.getLength()); r++) {\n                if ((this.fbidList[r] == q)) {\n                    return (r - this.position)\n                };\n            };\n            return null;\n        },\n        preloadImages: function(q) {\n            var r, s, t = this.getLength(), u = this.cache.image, v = p.BUFFER_SIZE;\n            if ((t > (v * 2))) {\n                r = ((((this.position + t) - (v \u0025 t))) \u0025 t);\n                s = (((this.position + v)) \u0025 t);\n            }\n             else {\n                r = 0;\n                s = (t - 1);\n            }\n        ;\n            while ((r != s)) {\n                var w = this.fbidList[r];\n                if ((u[w] && u[w].url)) {\n                    if ((q && !u[w].resource)) {\n                        u[w].resource = new Image();\n                        u[w].resource.src = u[w].url;\n                        if ((u[w].everstoreLogThis === true)) {\n                            i.logImmediately(u[w].resource.src);\n                        };\n                    }\n                     else if ((!q && !u[w].small)) {\n                        u[w].small = new Image();\n                        u[w].small.src = (u[w].smallurl || u[w].url);\n                        if ((u[w].everstoreLogThis === true)) {\n                            i.logImmediately(u[w].small.src);\n                        };\n                    }\n                    \n                \n                };\n                r = (((r + 1)) \u0025 t);\n            };\n        },\n        loadMoreIfNeccessary: function(q) {\n            if (((this.allLoaded || ((q && this.rightLock))) || ((!q && this.leftLock)))) {\n                return\n            };\n            var r = (q ? 1 : -1), s = (this.position + (this.bufferSize * r));\n            if (((s < 0) && !this.checkErrorAt(this.getEndCursor(false)))) {\n                this.leftLock = true;\n                this.fetch(this.fullBucketSize, false);\n            }\n             else if (((s > this.getLength()) && !this.checkErrorAt(this.getEndCursor(true)))) {\n                this.rightLock = true;\n                this.fetch(this.fullBucketSize, true);\n            }\n            \n        ;\n        },\n        getEndCursor: function(q) {\n            return (q ? this.fbidList[(this.getLength() - 1)] : this.fbidList[0]);\n        },\n        calculateRelativeIndex: function(q, r, s) {\n            if (!this.totalCount) {\n                return null\n            };\n            var t = this.fbidList.indexOf(r), u = this.fbidList.indexOf(s);\n            if (((t === -1) || (u === -1))) {\n                return null\n            };\n            var v = (u - t);\n            return ((((q + v) + this.totalCount)) \u0025 this.totalCount);\n        },\n        calculateDistance: function(q, r) {\n            var s = this.fbidList.indexOf(q), t = this.fbidList.indexOf(r);\n            if (((s === -1) || (t === -1))) {\n                return null\n            };\n            return ((((t - s) + this.getLength())) \u0025 this.getLength());\n        },\n        fetch: function(q, r) {\n            var s = this.getEndCursor(r), t = n({\n                cursor: s,\n                version: this.version,\n                end: this.getEndCursor(!r),\n                fetchSize: (r ? q : (-1 * q)),\n                relevant_count: this.relevantCount\n            }, this.photoSetQuery);\n            if ((this.totalCount && (this.firstCursorIndex !== null))) {\n                t.total = this.totalCount;\n                t.cursorIndex = this.calculateRelativeIndex(this.firstCursorIndex, this.firstCursor, s);\n            }\n        ;\n            k.loadFromEndpoint(this.pageletName, null, t, {\n                usePipe: true,\n                jsNonblock: true,\n                crossPage: true\n            });\n        },\n        storeToCache: function(q) {\n            var r = {\n            };\n            if (!this.isActive) {\n                return r\n            };\n            if ((\"error\" in q)) {\n                this.processErrorResult(q.error);\n                r.error = true;\n                return r;\n            }\n        ;\n            if ((\"init\" in q)) {\n                this.processInitResult(q.init);\n                r.init = {\n                    logids: q.init.logids,\n                    fbid: q.init.fbid,\n                    loggedin: q.init.loggedin,\n                    fromad: q.init.fromad\n                };\n            }\n        ;\n            if ((\"image\" in q)) {\n                this.processImageResult(q.image);\n                r.image = true;\n            }\n        ;\n            if ((\"data\" in q)) {\n                this.processDataResult(q.data);\n                r.data = true;\n            }\n        ;\n            return r;\n        },\n        processInitResult: function(q) {\n            if (this.loaded) {\n                return\n            };\n            this.loaded = true;\n            this.photoSetQuery = q.query;\n            if (q.bufferSize) {\n                this.bufferSize = q.bufferSize;\n            };\n            if (q.fullBucketSize) {\n                this.fullBucketSize = q.fullBucketSize;\n            };\n            if ((this.fbidList.length === 0)) {\n                this.fbidList.push(q.fbid);\n                this.rightLock = true;\n            }\n             else {\n                var r = this.fbidList.indexOf(p.INIT_PLACEHOLDER);\n                if ((r != -1)) {\n                    this.fbidList[r] = q.fbid;\n                };\n            }\n        ;\n            this.firstCursor = q.fbid;\n            if (((\"initIndex\" in q) && (\"totalCount\" in q))) {\n                this.firstCursorIndex = q.initIndex;\n                this.totalCount = q.totalCount;\n            }\n        ;\n            if ((this.version == h.VIEWER_PERMALINK)) {\n                this.fetch(p.INIT_BUCKET_SIZE, true);\n            };\n        },\n        processImageResult: function(q) {\n            for (var r in q) {\n                if (((r === this.firstCursor) && q[r].everstoreLogThis)) {\n                    i.logImmediately(q[r].url);\n                };\n                this.cache.image[r] = q[r];\n                if (q[r].dimensions) {\n                    this.cache.image[r].dimensions = m.deserialize(q[r].dimensions);\n                };\n                if (q[r].smalldims) {\n                    this.cache.image[r].smalldims = m.deserialize(q[r].smalldims);\n                };\n                this.permalinkMap[l(q[r].info.permalink).getUnqualifiedURI().toString()] = r;\n            };\n        },\n        attachToFbidsList: function(q, r, s) {\n            if (this.allLoaded) {\n                return\n            };\n            if ((r === -1)) {\n                for (var t = (q.length - 1); (t >= 0); t--) {\n                    this.fbidList.unshift(q[t]);\n                    this.position++;\n                };\n                this.leftLock = false;\n            }\n             else {\n                for (var u = 0; (u < q.length); u++) {\n                    this.fbidList.push(q[u]);;\n                };\n                this.rightLock = false;\n            }\n        ;\n            if (s) {\n                this.setAllLoaded();\n            };\n        },\n        setAllLoaded: function() {\n            this.allLoaded = true;\n            if ((this.getCursor() === null)) {\n                this.position = this.calculatePositionForMovement(0);\n            };\n        },\n        processDataResult: function(q) {\n            for (var r in q) {\n                if (!this.cache.html[r]) {\n                    this.cache.html[r] = {\n                    };\n                };\n                for (var s in q[r].html) {\n                    var t = q[r].html[s];\n                    if ((typeof t === \"string\")) {\n                        t = g(t).getRootNode();\n                    };\n                    this.cache.html[r][s] = o(t.childNodes);\n                };\n                if (!((\"extra\" in q[r]))) {\n                    this.cache.extra[r] = null;\n                    continue;\n                }\n            ;\n                this.cache.extra[r] = {\n                    tagRects: {\n                    }\n                };\n                if (!Array.isArray(q[r].extra.tagRects)) {\n                    for (var u in q[r].extra.tagRects) {\n                        if (q[r].extra.tagRects[u]) {\n                            this.cache.extra[r].tagRects[u] = j.deserialize(q[r].extra.tagRects[u]);\n                        };\n                    }\n                };\n            };\n        },\n        processErrorResult: function(q) {\n            if (!this.isLoaded()) {\n                this.initError = true;\n                return;\n            }\n        ;\n            var r = q.side, s = [p.ERROR_ID,];\n            this.attachToFbidsList(s, r);\n        },\n        setTotalCount: function(q) {\n            this.totalCount = q;\n        },\n        setFirstCursorIndex: function(q) {\n            this.firstCursorIndex = q;\n        }\n    });\n    e.exports = p;\n});\n__d(\"PhotoSnowliftAds\", [\"array-extensions\",\"event-extensions\",\"copyProperties\",\"CSS\",\"csx\",\"DataStore\",\"DOM\",\"PhotoSessionLog\",\"UIPagelet\",\"URI\",\"Vector\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    var g = b(\"copyProperties\"), h = b(\"CSS\"), i = b(\"csx\"), j = b(\"DataStore\"), k = b(\"DOM\"), l = b(\"PhotoSessionLog\"), m = b(\"UIPagelet\"), n = b(\"URI\"), o = b(\"Vector\"), p = {\n        DEFAULT_UNITS_REFRESH_RATE: 30000,\n        UNITS_REGISTER_DELAY: 1000,\n        root: null,\n        availableDimensions: null,\n        loadQuery: null,\n        lastLoadTime: 0,\n        minAds: 100,\n        units: null,\n        isLogAdData: null,\n        showSmallerAd: false,\n        egoEnabled: false,\n        refreshUnitsRate: null,\n        adsStatus: \"null\",\n        adsEvents: {\n        },\n        resetEvents: function() {\n            this.adsStatus = \"reset\";\n            this.adsEvents = {\n            };\n        },\n        addEvent: function(q, r) {\n            if (r) {\n                this.adsStatus = q;\n            };\n            var s = Date.now();\n            this.adsEvents[((q + \"_\") + s)] = s;\n        },\n        init: function(q, r, s) {\n            this.reset();\n            this.root = q;\n            this.snowlift = r;\n            this.showSmallerAd = s.showsmallerad;\n            this.egoEnabled = s.ego_enabled;\n            this.minAds = s.min_ads;\n            this.addEvent(\"init\", true);\n            this.refreshUnitsRate = p.DEFAULT_UNITS_REFRESH_RATE;\n            if (s.refresh_fast) {\n                this.refreshUnitsRate = s.refresh_rate;\n            };\n        },\n        reset: function() {\n            this.lastLoadTime = 0;\n            this.units = [];\n            this.resetEvents();\n            this.addEvent(\"reset\", true);\n        },\n        resize: function(q) {\n            this.availableDimensions = q;\n            this.loadQuery = this.snowlift.getLoadQuery();\n            this.processResize();\n        },\n        calculateUnitSizes: function(q, r) {\n            var s = {\n            };\n            q.forEach(function(t) {\n                var u = t.root.firstChild.offsetHeight;\n                t.units.forEach(function(w) {\n                    if (!h.hasClass(w, \"hidden\")) {\n                        var x = this.getHeight(w.firstChild, r);\n                        u -= x;\n                    }\n                ;\n                }.bind(this));\n                var v = {\n                    height: u,\n                    visible: false\n                };\n                t.units.forEach(function(w) {\n                    var x = this.getIsAds(w), y = this.getHeight(w.firstChild, r), z = this.getUnitId(w);\n                    s[z] = {\n                        height: y,\n                        visible: false,\n                        priority: 0,\n                        is_ads: x,\n                        section_ref: v\n                    };\n                }.bind(this));\n            }.bind(this));\n            return s;\n        },\n        calculateVisibleUnits: function(q, r, s) {\n            var t = 0, u = this.getUnitPriority(r);\n            u.forEach(function(v) {\n                if (r.hasOwnProperty(v)) {\n                    var w = r[v], x = w.height;\n                    if (!w.section_ref.visible) {\n                        x += w.section_ref.height;\n                    };\n                    w.height_below = (s - x);\n                    w.visible = ((w.height_below >= 0) && (x > 0));\n                    if (w.visible) {\n                        w.section_ref.visible = true;\n                        s -= x;\n                        t++;\n                    }\n                ;\n                }\n            ;\n            }.bind(this));\n            return r;\n        },\n        displayUnits: function(q, r) {\n            q.forEach(function(s) {\n                var t = false;\n                s.units.forEach(function(u) {\n                    var v = this.getUnitId(u), w = r[v], x = w.visible, y = w.height_below, z = w.is_ads;\n                    h.conditionClass(u, \"hidden\", !x);\n                    t = (t || x);\n                    this.calcUnitStats(this.units[z][v], x, y);\n                }.bind(this));\n                h.conditionClass(s.root, \"hidden\", !t);\n            }.bind(this));\n        },\n        getUnitPriority: function(q) {\n            var r = [], s = 0, t = 0;\n            for (var u in q) {\n                var v = q[u];\n                r.push(u);\n                var w = ((this.minAds + s) + t);\n                if (v.is_ads) {\n                    if ((t < this.minAds)) {\n                        w = t;\n                    };\n                    t++;\n                }\n                 else s++;\n            ;\n                v.priority = w;\n            };\n            r = r.sort(function(x, y) {\n                var z = q[x], aa = q[y];\n                return (z.priority - aa.priority);\n            }.bind(this));\n            return r;\n        },\n        updateUnitsStatus: function() {\n            var q = this.availableDimensions.x, r = this.availableDimensions.y, s = this.calculateUnitSizes(this.sections, q);\n            s = this.calculateVisibleUnits(this.sections, s, r);\n            this.displayUnits(this.sections, s);\n        },\n        calcUnitStats: function(q, r, s) {\n            var t = Date.now();\n            if (q.visible) {\n                q.totalTime += (t - q.lastShowTime);\n            };\n            if (((q.trackingCode !== null) && (q.totalTime >= this.UNITS_REGISTER_DELAY))) {\n                var u = q.trackingCode;\n                q.trackingCode = null;\n                this.registerImpression(u, q.registerUrl);\n            }\n        ;\n            q.visible = r;\n            q.heightBelow = s;\n            q.lastShowTime = t;\n        },\n        prepareResize: function() {\n            var q = function(r) {\n                var s = k.create(\"div\", {\n                    className: \"inner\"\n                }), t = k.create(\"div\", {\n                    className: \"wrapper\"\n                }, s);\n                k.replace(r, t);\n                k.setContent(s, r);\n                return t;\n            };\n            this.sections = k.scry(this.root, \"div.ego_section\").map(function(r) {\n                return {\n                    root: q(r),\n                    units: k.scry(r, \"div.ego_unit\").map(q)\n                };\n            });\n        },\n        processResize: function() {\n            if (((this.isLoading || (this.lastLoadTime === 0)) || (this.availableDimensions === null))) {\n                this.setLogData();\n                return;\n            }\n        ;\n            this.updateUnitsStatus();\n            this.setLogData();\n            var q = this.nextRegisterTime();\n            if ((q !== Infinity)) {\n                this.processResize.bind(this).defer(q, true);\n            };\n        },\n        setIsLogAdData: function(q) {\n            this.isLogAdData = q;\n            this.addEvent(\"setIsLogAdData\", false);\n            this.setLogData();\n        },\n        setLogData: function() {\n            var q = this.snowlift.getImageId();\n            if ((this.isLogAdData && q)) {\n                var r = o.getElementDimensions(this.snowlift.getImage()), s = o.getElementDimensions(this.snowlift.getRHCHeader()), t = o.getElementDimensions(this.snowlift.getRHCBody()), u = o.getElementDimensions(this.snowlift.getRHCFooter()), v = {\n                    query_set: this.snowlift.getLoadQuery().set,\n                    window_x: window.innerWidth,\n                    window_y: window.innerHeight,\n                    image_x: r.x,\n                    image_y: r.y,\n                    header_x: s.x,\n                    header_y: s.y,\n                    body_x: t.x,\n                    body_y: t.y,\n                    footer_x: u.x,\n                    footer_y: u.y,\n                    ads_below_space: this.getAdsBelowSpace(),\n                    time: Date.now(),\n                    adsStatus: this.adsStatus,\n                    adsEvents: this.adsEvents\n                };\n                l.updateAdData(q, v);\n            }\n        ;\n        },\n        getAdsBelowSpace: function() {\n            var q = [], r = this.units[1];\n            for (var s in r) {\n                if (r.hasOwnProperty(s)) {\n                    q.push(r[s].heightBelow);\n                };\n            };\n            return q;\n        },\n        getIsAds: function(q) {\n            var r = k.scry(q, \"div.-cx-PRIVATE-fbAdUnit__root\");\n            return r.length;\n        },\n        getUnitId: function(q) {\n            if (this.getIsAds(q)) {\n                return this.getAdId(q);\n            }\n             else return this.getEgoId(q)\n        ;\n        },\n        getEgoId: function(q) {\n            var r = k.find(q, \"div.fbEgoUnit\"), s = r.getAttribute(\"data-ego\"), t = JSON.parse(s).egoid;\n            return t;\n        },\n        getAdId: function(q) {\n            var r = k.find(q, \"div.-cx-PRIVATE-fbAdUnit__root\"), s = r.getAttribute(\"data-ad\"), t = JSON.parse(s).adid;\n            return t;\n        },\n        nextRegisterTime: function() {\n            var q = Infinity, r = g(g({\n            }, this.units[0]), this.units[1]);\n            for (var s in r) {\n                if (r.hasOwnProperty(s)) {\n                    var t = r[s];\n                    if (((t.trackingCode !== null) && t.visible)) {\n                        q = Math.min(q, (this.UNITS_REGISTER_DELAY - t.totalTime));\n                    };\n                }\n            ;\n            };\n            return q;\n        },\n        getHeight: function(q, r) {\n            var s = j.get(q, \"height\");\n            if ((s && (s.x === r))) {\n                return s.y\n            };\n            return this.cacheHeight(q, r);\n        },\n        cacheHeight: function(q, r) {\n            var s = {\n                x: r,\n                y: q.offsetHeight\n            };\n            j.set(q, \"height\", s);\n            return s.y;\n        },\n        loadAdsAndEgo: function() {\n            this.resetEvents();\n            this.addEvent(\"adsRequested\", true);\n            m.loadFromEndpoint(\"WebEgoPane\", this.root, {\n                pid: 34,\n                data: [this.loadQuery.set,true,this.egoEnabled,]\n            }, {\n                crossPage: true,\n                bundle: false\n            });\n        },\n        unitsLoaded: function(q, r) {\n            var s;\n            if (r) {\n                s = \"/ai.php\";\n                this.addEvent(\"adsLoaded\", true);\n            }\n             else {\n                s = \"/ajax/ei.php\";\n                this.addEvent(\"egoLoaded\", true);\n            }\n        ;\n            var t = {\n            };\n            for (var u in q) {\n                if (q.hasOwnProperty(u)) {\n                    t[u] = {\n                        trackingCode: q[u],\n                        totalTime: 0,\n                        lastShowTime: 0,\n                        heightBelow: -10000,\n                        visible: false,\n                        registerUrl: s\n                    };\n                };\n            };\n            this.units[r] = t;\n            if (r) {\n                this.waitForImages(this.imagesLoaded.bind(this));\n            };\n        },\n        imagesLoaded: function() {\n            this.prepareResize();\n            this.addEvent(\"imagesLoaded\", true);\n            this.lastLoadTime = Date.now();\n            this.isLoading = false;\n            this.processResize();\n            h.removeClass(this.root, \"loading\");\n        },\n        loadAdsFromUserActivity: function() {\n            var q = Date.now(), r = this.refreshUnitsRate;\n            if ((!this.isLoading && ((q - this.lastLoadTime) > r))) {\n                h.addClass(this.root, \"loading\");\n                this.isLoading = true;\n                this.loadAdsAndEgo();\n            }\n        ;\n        },\n        registerImpression: function(q, r) {\n            var s = k.create(\"iframe\", {\n                src: n(r).addQueryData({\n                    aed: q\n                }),\n                width: 0,\n                height: 0,\n                frameborder: 0,\n                scrolling: \"no\",\n                className: \"fbEmuTracking\"\n            });\n            s.setAttribute(\"aria-hidden\", \"true\");\n            k.appendContent(this.root, s);\n        },\n        waitForImages: function(q) {\n            var r = k.scry(this.root, \"img.img\"), s = r.length, t = s;\n            if ((t === 0)) {\n                q();\n            };\n            var u = function() {\n                t--;\n                if ((t === 0)) {\n                    q.defer();\n                };\n            };\n            for (var v = 0; (v < s); v++) {\n                var w = r[v];\n                if (w.complete) {\n                    u();\n                }\n                 else Event.listen(w, {\n                    load: u,\n                    error: u,\n                    abort: u\n                });\n            ;\n            };\n        }\n    };\n    e.exports = p;\n});\n__d(\"PhotoViewer\", [\"Bootloader\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Bootloader\"), h = b(\"copyProperties\");\n    function i() {\n        this.image = null;\n        this.root = null;\n        this.stream = null;\n    };\n    h(i, {\n        bootstrap: function(j, k) {\n            g.loadModules([\"PhotoSnowlift\",], function(l) {\n                l.bootstrap(j, k);\n            });\n        }\n    });\n    h(i.prototype, {\n        getEventPrefix: bagof(null),\n        getEventString: function(j) {\n            var k = this.getEventPrefix();\n            if (k) {\n                return ((k + \".\") + j)\n            };\n            return null;\n        },\n        getImage: function() {\n            return this.image;\n        },\n        getPosition: function() {\n            return (this.stream ? this.stream.getCursor() : null);\n        },\n        getRoot: function() {\n            return this.root;\n        },\n        getSourceString: bagof(null),\n        getVersionConst: bagof(null)\n    });\n    e.exports = i;\n});\n__d(\"PhotoSnowlift\", [\"array-extensions\",\"event-extensions\",\"function-extensions\",\"Amoeba\",\"Arbiter\",\"AsyncDialog\",\"AsyncRequest\",\"Bootloader\",\"Class\",\"CSS\",\"Dialog\",\"DOM\",\"DOMControl\",\"DOMScroll\",\"FullScreen\",\"ImageUtils\",\"KeyEventController\",\"Keys\",\"LinkController\",\"Locale\",\"PageTransitions\",\"Parent\",\"PhotosConst\",\"PhotoSessionLog\",\"PhotoSnowliftAds\",\"PhotoStreamCache\",\"PhotosUtils\",\"PhotoViewer\",\"Rect\",\"ScrollableArea\",\"Style\",\"Toggler\",\"UIPagelet\",\"URI\",\"UserAgent\",\"Vector\",\"$\",\"computeRelativeURI\",\"copyProperties\",\"createArrayFrom\",\"ge\",\"goURI\",\"tx\",\"csx\",\"userAction\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Amoeba\"), h = b(\"Arbiter\"), i = b(\"AsyncDialog\"), j = b(\"AsyncRequest\"), k = b(\"Bootloader\"), l = b(\"Class\"), m = b(\"CSS\"), n = b(\"Dialog\"), o = b(\"DOM\"), p = b(\"DOMControl\"), q = b(\"DOMScroll\"), r = b(\"FullScreen\"), s = b(\"ImageUtils\"), t = b(\"KeyEventController\"), u = b(\"Keys\"), v = b(\"LinkController\"), w = b(\"Locale\"), x = b(\"PageTransitions\"), y = b(\"Parent\"), z = b(\"PhotosConst\"), aa = b(\"PhotoSessionLog\"), ba = b(\"PhotoSnowliftAds\"), ca = b(\"PhotoStreamCache\"), da = b(\"PhotosUtils\"), ea = b(\"PhotoViewer\"), fa = b(\"Rect\"), ga = b(\"ScrollableArea\"), ha = b(\"Style\"), ia = b(\"Toggler\"), ja = b(\"UIPagelet\"), ka = b(\"URI\"), la = b(\"UserAgent\"), ma = b(\"Vector\"), na = b(\"$\"), oa = b(\"computeRelativeURI\"), pa = b(\"copyProperties\"), qa = b(\"createArrayFrom\"), ra = b(\"ge\"), sa = b(\"goURI\"), ta = b(\"tx\"), ua = b(\"csx\"), va = b(\"userAction\"), wa = b(\"event-extensions\").$E;\n    function xa() {\n        this.parent.construct(this);\n    };\n    pa(xa, {\n        STATE_ERROR: \"error\",\n        STATE_HTML: \"html\",\n        STATE_IMAGE_PIXELS: \"image_pixels\",\n        STATE_IMAGE_DATA: \"image\",\n        LOADING_TIMEOUT: 2000,\n        PAGER_FADE: 3000,\n        FULL_SCREEN_PADDING: 10,\n        STAGE_HIRES_MAX: {\n            x: 2048,\n            y: 2048\n        },\n        STAGE_NORMAL_MAX: {\n            x: 960,\n            y: 960\n        },\n        STAGE_MIN: {\n            x: 520,\n            y: 520\n        },\n        SIDEBAR_SIZE_MAX: 340,\n        SIDEBAR_SIZE_MIN: 285,\n        STAGE_CHROME: {\n            x: 102,\n            y: 42\n        },\n        VIDEO_BOTTOM_BAR_SPACE: 40,\n        GOPREV_AREA: 120,\n        TIMELINE_STRETCH_WIDTH: 843,\n        TIMELINE_STRETCH_MIN: 480,\n        MIN_TAG_DISTANCE: 83,\n        PADDING_MIN: 40,\n        _instance: null,\n        getInstance: function() {\n            if (!xa._instance) {\n                xa._instance = new xa();\n            };\n            return xa._instance;\n        },\n        initInstance: function(ya, za) {\n            xa.getInstance().init(ya, za);\n        },\n        addPhotoFbids: function(ya, za, ab, bb) {\n            xa.getInstance().addPhotoFbids(ya, za, ab, bb);\n        },\n        attachFollowFlyout: function(ya) {\n            o.insertAfter(na(\"fbPhotoSnowliftSubscribe\"), ya);\n        },\n        attachSubscribeFlyout: function(ya) {\n            o.insertAfter(na(\"fbPhotoSnowliftSubscribe\"), ya);\n        },\n        attachTagger: function(ya) {\n            xa.getInstance().attachTagger(ya);\n        },\n        preload: function(ya, za) {\n            xa.getInstance().preload(ya, za);\n        },\n        bootstrap: function(ya, za) {\n            if (za.getAttribute(\"data-vaultbox\")) {\n                k.loadModules([\"VaultBox\",], function(ab) {\n                    ab.bootstrap(ya, za);\n                });\n                return;\n            }\n        ;\n            if ((ya && ka(ya).getQueryData().hasOwnProperty(\"share_id\"))) {\n                k.loadModules([\"SpotlightShareViewer\",], function(ab) {\n                    ab.bootstrap(ya, za);\n                });\n                return;\n            }\n        ;\n            xa.getInstance().bootstrap(ya, za);\n        },\n        closeRefresh: function() {\n            xa.getInstance().closeRefresh();\n        },\n        deletePhoto: function(ya) {\n            xa.getInstance().deletePhoto(ya);\n        },\n        getImage: function() {\n            return xa.getInstance().getImage();\n        },\n        getImageId: function() {\n            return xa.getInstance().getImageId();\n        },\n        getLoadQuery: function() {\n            return xa.getInstance().getLoadQuery();\n        },\n        getRHCBody: function() {\n            return xa.getInstance().getRHCBody();\n        },\n        getRHCFooter: function() {\n            return xa.getInstance().getRHCFooter();\n        },\n        getRHCHeader: function() {\n            return xa.getInstance().getRHCHeader();\n        },\n        getRoot: function() {\n            return xa.getInstance().getRoot();\n        },\n        likePhotoSkipConfirmation: function(ya) {\n            xa.getInstance().likePhotoSkipConfirmation(ya);\n        },\n        saveTagsFromPayload: function(ya) {\n            xa.getInstance().saveTagsFromPayload(ya);\n        },\n        saveTagsFromPayloadDelayed: function(ya) {\n            xa.saveTagsFromPayload.curry(ya).defer(2000);\n        },\n        handleServerError: function(ya, za) {\n            xa.getInstance().handleServerError(ya, za);\n        },\n        storeFromData: function(ya) {\n            xa.getInstance().storeFromData(ya);\n        },\n        swapData: function() {\n            xa.getInstance().swapData();\n        },\n        touchMarkup: bagofholding,\n        updateTotalCount: function(ya, za, ab) {\n            xa.getInstance().updateTotalCount(ya, za, ab);\n        }\n    });\n    l.extend(xa, ea);\n    pa(xa.prototype, {\n        switchTimer: null,\n        imageRefreshTimer: null,\n        imageLoadingTimer: null,\n        lastPage: 0,\n        currentMinSize: null,\n        extraClass: null,\n        currentImageSize: null,\n        resetUriStack: true,\n        thumbSrc: null,\n        shouldStretch: false,\n        stageMax: xa.STAGE_NORMAL_MAX,\n        stageChrome: xa.STAGE_CHROME,\n        stagePagerPrev: null,\n        ua: null,\n        PhotoTagger: null,\n        showHiRes: false,\n        showHover: false,\n        skipLikePhotoConfirmation: false,\n        isShowingLikePhotoConfirmation: false,\n        preload: function(ya, za) {\n            k.loadModules([\"PhotoTagger\",\"fb-photos-snowlift-css\",\"Live\",\"PhotoTagApproval\",\"PhotoTags\",\"TagTokenizer\",\"fb-photos-snowlift-fullscreen-css\",], function(bb) {\n                this.PhotoTagger = bb;\n            }.bind(this));\n            var ab = this.getImageSrc(ka(ya).getQueryData());\n            if (ab) {\n                (new Image()).src = ab;\n            };\n        },\n        bootstrap: function(ya, za) {\n            this.preload(ya, za);\n            ba.reset();\n            this.resetUriStack = true;\n            if (this.isOpen) {\n                if (this.openExplicitly) {\n                    this.closeCleanup();\n                    this.resetUriStack = false;\n                }\n                 else return\n            \n            };\n            this.ua = va(\"snowlift\", za, null, \"FORCE\").set_namespace(\"snowlift\").set_ua_id(\"open\");\n            this.returningToStart = false;\n            (this.loading && m.removeClass(this.loading, \"loading\"));\n            if (za) {\n                m.addClass((this.loading = za), \"loading\");\n                this.getThumbAndSize(za);\n            }\n             else this.loading = null;\n        ;\n            h.inform(\"PhotoSnowlift.GO\", ya, h.BEHAVIOR_STATE);\n            this.loadFrameIfUninitialized();\n        },\n        getEventPrefix: function() {\n            return \"PhotoSnowlift\";\n        },\n        getRoot: function() {\n            return this.root;\n        },\n        getSourceString: function() {\n            return \"snowlift\";\n        },\n        getVersionConst: function() {\n            return z.VIEWER_SNOWLIFT;\n        },\n        getImage: function() {\n            return this.image;\n        },\n        getImageId: function() {\n            return this.stream.getCursor();\n        },\n        getRHCHeader: function() {\n            return this.rhcHeader;\n        },\n        getRHCBody: function() {\n            return this.ufiForm;\n        },\n        getRHCFooter: function() {\n            return this.rhcFooter;\n        },\n        getLoadQuery: function() {\n            return this.loadQuery;\n        },\n        getOwnerId: function() {\n            var ya = this.stream.getCurrentImageData();\n            if (ya) {\n                return ya.info.owner\n            };\n            return null;\n        },\n        getThumbAndSize: function(ya) {\n            this.currentImageSize = null;\n            this.thumbSrc = null;\n            var za = ka(ya.getAttribute(\"ajaxify\")).getQueryData();\n            if (!za.size) {\n                return\n            };\n            var ab = ma.deserialize(za.size);\n            if ((!ab.x || !ab.y)) {\n                return\n            };\n            this.currentImageSize = ab;\n            if (((!m.hasClass(ya, \"uiMediaThumb\") && !m.hasClass(ya, \"uiPhotoThumb\")) && !m.hasClass(ya, \"uiScaledThumb\"))) {\n                return\n            };\n            if (ya.getAttribute(\"data-cropped\")) {\n                return\n            };\n            var bb = o.scry(ya, \"img\")[0], cb = o.scry(ya, \"i\")[0], db = y.byAttribute(ya, \"data-size\");\n            this.shouldStretch = ((((((db && this.currentImageSize) && bb) && (db.getAttribute(\"data-size\") === \"2\")) && (this.currentImageSize.x > this.currentImageSize.y)) && (this.currentImageSize.x <= xa.TIMELINE_STRETCH_WIDTH)) && (bb.offsetWidth === xa.TIMELINE_STRETCH_WIDTH));\n            var eb;\n            if (bb) {\n                eb = bb.src;\n            }\n             else if (cb) {\n                eb = ha.get(cb, \"backgroundImage\").replace(/.*url\\(\"?([^\"]*)\"?\\).*/, \"$1\");\n            }\n             else return\n            \n        ;\n            this.thumbSrc = eb;\n        },\n        loadFrameIfUninitialized: function() {\n            if (this.root) {\n                return\n            };\n            new j(\"/ajax/photos/snowlift/init.php\").setAllowCrossPageTransition(true).setMethod(\"GET\").setReadOnly(true).send();\n        },\n        init: function(ya, za) {\n            this.showHiRes = za.hires;\n            this.showHover = za.pivot_hover;\n            aa.setEndMetrics(za.pivot_end_metric);\n            this.showEndPivot = za.pivot_end;\n            this.fullscreen = (za.hires && r.isSupported());\n            this.showOGVideos = za.og_videos;\n            this.stageMax = (this.showHiRes ? xa.STAGE_HIRES_MAX : xa.STAGE_NORMAL_MAX);\n            var ab = ra(\"fbPhotoSnowlift\");\n            if (!ab) {\n                ab = o.appendContent(document.body, ya)[0];\n                this.initialLoad = false;\n            }\n        ;\n            if ((this.root == ab)) {\n                return\n            };\n            this.initializeNodes(ab);\n            ba.init(this.sideAdUnit, this, za);\n            if (!this.subscription) {\n                v.registerHandler(this.handleNavigateAway.bind(this));\n                this.subscription = h.subscribe(\"PhotoSnowlift.GO\", function(bb, cb) {\n                    this.openExplicitly = true;\n                    (this.loading && m.removeClass(this.loading, \"loading\"));\n                    this.open(cb);\n                }.bind(this));\n            }\n        ;\n            this.transitionHandlerRegistered = false;\n            this.returningToStart = false;\n            x.registerHandler(this.openHandler.bind(this));\n            this.openHandlerRegistered = true;\n            h.subscribe(\"PhotoTagApproval.HILITE_TAG\", this.onHiliteTag.bind(this));\n            h.subscribe(\"PhotoTagApproval.UPDATE_TAG_BOX\", this.onUpdateTagBox.bind(this));\n            if (this.fullscreen) {\n                r.subscribe(\"changed\", this.onFullScreenChange.bind(this));\n            };\n        },\n        onFullScreenChange: function() {\n            if (r.isFullScreen()) {\n                if (!m.hasClass(this.root, \"fbPhotoSnowliftEditMode\")) {\n                    this.collapseRHC();\n                };\n                var ya = this.stream.getCurrentImageData();\n                if ((((ya && ya.url) && (this.image.src !== ya.url)) && this.shouldShowHiRes(ya))) {\n                    this.switchImage(ya.url);\n                };\n                this.adjustForResize();\n            }\n             else this.uncollapseRHC();\n        ;\n            ia.hide();\n        },\n        initializeNodes: function(ya) {\n            this.root = ya;\n            this.container = o.find(ya, \"div.fbPhotoSnowliftContainer\");\n            g.instrument(this.container, \"snowlift\");\n            this.snowliftPopup = o.find(this.container, \"div.fbPhotoSnowliftPopup\");\n            this.rhc = o.find(this.snowliftPopup, \"div.rhc\");\n            this.rhcHeader = o.find(this.rhc, \"div.rhcHeader\");\n            this.rhcFooter = o.find(this.rhc, \"div.rhcFooter\");\n            this.ufiForm = o.find(this.rhc, \"form.fbPhotosSnowliftFeedbackForm\");\n            this.ufiInputContainer = na(\"fbPhotoSnowliftFeedbackInput\");\n            this.scroller = o.find(this.ufiForm, \"div.rhcScroller\");\n            this.scrollerBody = o.find(this.scroller, \"div.uiScrollableAreaBody\");\n            this.stageWrapper = o.find(this.snowliftPopup, \"div.stageWrapper\");\n            this.overlay = o.find(this.snowliftPopup, \"div.snowliftOverlay\");\n            this.errorBox = o.find(this.stageWrapper, \"div.stageError\");\n            this.image = o.find(this.stageWrapper, \"img.spotlight\");\n            this.stage = o.find(this.stageWrapper, \"div.stage\");\n            this.videoStage = o.find(this.stageWrapper, \"div.videoStage\");\n            this.prevPager = o.find(this.snowliftPopup, \"a.snowliftPager.prev\");\n            g.instrument(this.prevPager, \"prev_pager\");\n            this.nextPager = o.find(this.snowliftPopup, \"a.snowliftPager.next\");\n            g.instrument(this.nextPager, \"next_pager\");\n            this.stageActions = o.find(ya, \"div.stageActions\");\n            this.buttonActions = o.find(this.stageActions, \"div.fbPhotosPhotoButtons\");\n            this.sideAdUnit = o.find(ya, \".-cx-PRIVATE-snowliftAds__root\");\n            m.conditionClass(this.root, \"fullScreenAvailable\", this.fullscreen);\n        },\n        initializeScroller: function() {\n            this.initializeScroller = bagofholding;\n            this.scrollableArea = ga.fromNative(this.scroller, {\n                fade: true,\n                persistent: true\n            });\n            var ya = function(event) {\n                var za = wa(event).getTarget();\n                if (o.contains(this.ufiInputContainer, za)) {\n                    var ab = p.getInstance(za);\n                    if (ab) {\n                        this.scrollableArea.scrollToBottom();\n                        var bb = ab.subscribe(\"resize\", function() {\n                            var db = this.scrollableArea.isScrolledToBottom();\n                            this.adjustScroller();\n                            (db && this.scrollableArea.scrollToBottom());\n                        }.bind(this)), cb = Event.listen(za, \"blur\", function() {\n                            ab.unsubscribe(bb);\n                            cb.remove();\n                        });\n                    }\n                ;\n                }\n            ;\n            }.bind(this);\n            h.subscribe(\"ufi/comment\", function(za, ab) {\n                if ((this.ufiForm === ab.form)) {\n                    this.adjustScrollerIfNecessary();\n                    this.scrollableArea.scrollToBottom();\n                }\n            ;\n            }.bind(this));\n            Event.listen(this.rhc, \"click\", function(event) {\n                var za = event.getTarget();\n                if (((y.byTag(za, \"a\") || y.byTag(za, \"button\")) || o.isNodeOfType(za, \"input\"))) {\n                    this.adjustScrollerIfNecessary();\n                };\n            }.bind(this));\n            h.subscribe(\"reflow\", function() {\n                if (this.isOpen) {\n                    this.adjustScroller();\n                };\n            }.bind(this));\n            h.subscribe([\"reflow\",\"CommentUFI.Pager\",], function() {\n                if (this.isOpen) {\n                    this.adjustScroller();\n                };\n            }.bind(this));\n            if (this.ufiForm.attachEvent) {\n                this.ufiForm.attachEvent(\"onfocusin\", ya);\n            }\n             else this.ufiForm.addEventListener(\"focus\", ya, true);\n        ;\n        },\n        openHandler: function(ya) {\n            if ((((((this.isOpen || (ya.getPath() != \"/photo.php\")) || this.returningToStart) || ya.getQueryData().closeTheater) || ya.getQueryData().permPage) || ya.getQueryData().makeprofile)) {\n                this.openHandlerRegistered = false;\n                return false;\n            }\n        ;\n            this.open(ya);\n            this._uriStack.push(ka(ya).getQualifiedURI().toString());\n            x.transitionComplete();\n            return true;\n        },\n        getImageSrc: function(ya) {\n            if (ya.smallsrc) {\n                if (!ya.size) {\n                    return ya.smallsrc\n                };\n                var za = ma.deserialize(ya.size), ab = this.getStageSize(za);\n                if (((ab.x <= xa.STAGE_NORMAL_MAX.x) && (ab.y <= xa.STAGE_NORMAL_MAX.y))) {\n                    return ya.smallsrc\n                };\n            }\n        ;\n            return ya.src;\n        },\n        open: function(ya) {\n            var za = ka(ya).getQueryData(), ab = this.getImageSrc(za);\n            if (ab) {\n                delete za.src;\n                delete za.smallsrc;\n            }\n        ;\n            if (this.resetUriStack) {\n                this._uriStack = [];\n            };\n            if (!this.initialLoad) {\n                za.firstLoad = true;\n                this.initialLoad = true;\n            }\n        ;\n            this.sessionID = Date.now();\n            this.loadQuery = pa(za, {\n                ssid: this.sessionID\n            });\n            this.isOpen = true;\n            this.pagersShown = false;\n            this.refreshOnClose = false;\n            this.hilitedTag = null;\n            this.loadingStates = {\n                image: false,\n                html: false\n            };\n            this.replaceUrl = false;\n            this.stream = new ca();\n            this.stream.init(z.VIEWER_SNOWLIFT, \"PhotoViewerPagelet\");\n            this.fetchInitialData();\n            this.setLoadingState(xa.STATE_HTML, true);\n            this.rhcCollapsed = false;\n            this.keyHandlers = [t.registerKey(\"ESCAPE\", this.closeListener.bind(this)),];\n            k.loadModules([\"fb-photos-snowlift-css\",], this._open.bind(this, ya, ab));\n            if (this.showEndPivot) {\n                k.loadModules([\"PhotoPivot\",], function(bb) {\n                    this.pivots = bb.getInstance();\n                    if (za.relevant_count) {\n                        this.pivots.setRelevantCount(za.relevant_count);\n                    };\n                }.bind(this));\n            };\n            k.loadModules([\"PhotosButtonTooltips\",], function(bb) {\n                bb.init();\n            });\n        },\n        _open: function(ya, za) {\n            this.createLoader(za);\n            m.show(this.root);\n            (function() {\n                var cb = ma.getScrollPosition();\n                m.addClass(document.documentElement, \"theaterMode\");\n                var db = q.getScrollbarSize();\n                if ((db === 0)) {\n                    this.extraClass = \"zeroScrollbar\";\n                }\n                 else if ((db === 20)) {\n                    this.extraClass = \"scrollbar20\";\n                }\n                 else this.extraClass = \"defaultScrollbar\";\n                \n            ;\n                m.addClass(document.body, this.extraClass);\n                q.scrollTo(cb, 0);\n            }).defer();\n            (this.ua && this.ua.add_event(\"frame\"));\n            h.inform(\"layer_shown\", {\n                type: \"PhotoSnowlift\"\n            });\n            h.inform(\"PhotoSnowlift.OPEN\");\n            this.stageHandlers = [Event.listen(window, \"resize\", this.adjustForResize.bind(this)),Event.listen(this.root, \"click\", this.closeListener.bind(this)),Event.listen(this.stageWrapper, \"click\", this.buttonListener.bind(this)),Event.listen(this.stageWrapper, \"mouseleave\", function(event) {\n                this.unhiliteAllTags();\n                this.hidePagers();\n            }.bind(this)),Event.listen(this.stageWrapper, \"mousemove\", this.hilitePagerOnMouseMove.bind(this)),Event.listen(this.stageWrapper, \"mousemove\", this.hiliteTagsOnMouseMove.bind(this)),Event.listen(this.overlay, \"mouseenter\", this.unhiliteAllTags.bind(this)),];\n            this.stageHandlers.push(Event.listen(this.container, \"click\", (function(event) {\n                var cb = event.getTarget();\n                if (y.byClass(cb, \"rotateRight\")) {\n                    this.rotate(\"right\");\n                }\n                 else if (y.byClass(cb, \"rotateLeft\")) {\n                    this.rotate(\"left\");\n                }\n                 else if (this.fullscreen) {\n                    if (y.byClass(cb, \"fbPhotoSnowliftFullScreen\")) {\n                        this.toggleFullScreen();\n                    }\n                     else if (y.byClass(cb, \"fbPhotoSnowliftCollapse\")) {\n                        this.toggleCollapse();\n                    }\n                \n                }\n                \n            ;\n            }).bind(this)));\n            var ab = ra(\"fbPhotoSnowliftFeedback\");\n            if (ab) {\n                this.stageHandlers.push(Event.listen(ab, \"click\", function(event) {\n                    if ((y.byClass(event.getTarget(), \"like_link\") || y.byClass(event.getTarget(), \"UFILikeLink\"))) {\n                        this.toggleLikeButton();\n                    };\n                    var cb = y.byClass(event.getTarget(), \"uiUfiCollapsedComment\");\n                    if (cb) {\n                        m.addClass(cb, \"uiUfiCollapsedCommentToggle\");\n                    };\n                }.bind(this)));\n            };\n            var bb = ra(\"fbPhotoSnowliftOnProfile\");\n            if (bb) {\n                this.stageHandlers.push(Event.listen(bb, \"click\", function(event) {\n                    if (y.byClass(event.getTarget(), \"fbPhotoRemoveFromProfileLink\")) {\n                        this.refreshOnClose = true;\n                    };\n                }.bind(this)));\n            };\n            if (this.resetUriStack) {\n                this.startingURI = ka.getMostRecentURI().addQueryData({\n                    closeTheater: 1\n                }).getUnqualifiedURI();\n            };\n            if (!za) {\n                this.setLoadingState(xa.STATE_IMAGE_DATA, true);\n            };\n            if (!this.transitionHandlerRegistered) {\n                x.registerHandler(this.transitionHandler.bind(this));\n                this.transitionHandlerRegistered = true;\n            }\n        ;\n            aa.initLogging(aa.SNOWLIFT);\n            if (this.pivots) {\n                aa.setRelevantCount(this.pivots.relevantCount);\n            };\n            if ((la.firefox() < 13)) {\n                this.turnFlashAutoplayOff.defer();\n            };\n            (function() {\n                this.root.focus();\n            }).bind(this).defer();\n        },\n        toggleFullScreen: function() {\n            var ya = r.toggleFullScreen(document.documentElement);\n            if (ya) {\n                var za = this.stream.getCurrentImageData();\n                if ((((za && za.url) && (this.image.src !== za.url)) && this.shouldShowHiRes(za))) {\n                    (new Image()).src = za.url;\n                };\n                aa.logEnterFullScreen(this.stream.getCursor());\n            }\n        ;\n        },\n        getStream: function() {\n            return this.stream;\n        },\n        fetchInitialData: function() {\n            (this.ua && this.ua.add_event(\"init_data\"));\n            this.stream.waitForInitData();\n            ja.loadFromEndpoint(\"PhotoViewerInitPagelet\", null, this.loadQuery, {\n                usePipe: true,\n                jsNonblock: true,\n                crossPage: true\n            });\n        },\n        turnFlashAutoplayOff: function() {\n            o.scry(document, \"div.swfObject\").forEach(function(ya) {\n                var za = ya.getAttribute(\"data-swfid\");\n                if ((za && window[za])) {\n                    var ab = window[za];\n                    ab.addParam(\"autostart\", \"false\");\n                    ab.addParam(\"autoplay\", \"false\");\n                    ab.addParam(\"play\", \"false\");\n                    ab.addVariable(\"video_autoplay\", \"0\");\n                    ab.addVariable(\"autoplay\", \"0\");\n                    ab.addVariable(\"play\", \"0\");\n                    var bb = ka(ab.getAttribute(\"swf\"));\n                    bb.addQueryData({\n                        autoplay: \"0\"\n                    });\n                    bb.setPath(bb.getPath().replace(\"autoplay=1\", \"autoplay=0\"));\n                    ab.setAttribute(\"swf\", bb.toString());\n                    ab.write(ya);\n                }\n            ;\n            });\n        },\n        toggleCollapse: function() {\n            if (this.rhcCollapsed) {\n                this.uncollapseRHC();\n            }\n             else this.collapseRHC();\n        ;\n        },\n        collapseRHC: function() {\n            this.rhcCollapsed = true;\n            m.addClass(this.root, \"collapseRHC\");\n            this.adjustForResize();\n        },\n        uncollapseRHC: function() {\n            this.rhcCollapsed = false;\n            m.removeClass(this.root, \"collapseRHC\");\n            this.adjustForResize();\n        },\n        closeHandler: function() {\n            if (!this.isOpen) {\n                return\n            };\n            if ((ka.getMostRecentURI().addQueryData({\n                closeTheater: 1\n            }).getUnqualifiedURI().toString() == this.startingURI.toString())) {\n                this.close();\n                return;\n            }\n        ;\n            this.close();\n            this.returnToStartingURI(this.refreshOnClose);\n        },\n        returnToStartingURI: function(ya, za) {\n            if (!ya) {\n                if (za) {\n                    this.squashNextTransition(sa.curry(za));\n                }\n                 else this.squashNextTransition();\n            \n            };\n            this.returningToStart = true;\n            var ab = h.subscribe(\"page_transition\", function() {\n                this.returningToStart = false;\n                ab.unsubscribe();\n            }), bb = (ya || isNaN(la.opera())), cb = this._uriStack.length;\n            if ((bb && (cb < window.history.length))) {\n                window.history.go(-cb);\n            }\n             else {\n                var db = this.startingURI, eb = new ka(db).removeQueryData(\"closeTheater\");\n                if (((db.getQueryData().sk == \"approve\") && (db.getPath() == \"/profile.php\"))) {\n                    eb.removeQueryData(\"highlight\");\n                    eb.removeQueryData(\"notif_t\");\n                }\n            ;\n                sa(eb);\n            }\n        ;\n        },\n        squashNextTransition: function(ya) {\n            this.squashNext = true;\n            x.registerHandler(function za() {\n                if (this.squashNext) {\n                    this.squashNext = false;\n                    if (ya) {\n                        ya.defer();\n                    };\n                    x.transitionComplete();\n                    return true;\n                }\n            ;\n                return false;\n            }.bind(this), 7);\n        },\n        handleNavigateAway: function(ya) {\n            var za = oa(x._most_recent_uri.getQualifiedURI(), ya.getAttribute(\"href\"));\n            if ((((this.isOpen && ((za instanceof ka))) && (za.getUnqualifiedURI().toString() != this.startingURI.toString())) && (za.getPath() != \"/photo.php\"))) {\n                if (!this.closingAction) {\n                    this.closingAction = aa.NAVIGATE;\n                };\n                this.close();\n                this.returnToStartingURI(false, za);\n                return false;\n            }\n        ;\n            return true;\n        },\n        closeListener: function(event) {\n            if ((this.isOpen && !n.getCurrent())) {\n                if ((Event.getKeyCode(event) == u.ESC)) {\n                    if ((!m.hasClass(this.root, \"taggingMode\") && !m.hasClass(this.root, \"fbPhotoSnowliftEditMode\"))) {\n                        this.closingAction = aa.ESC;\n                        Event.kill(event);\n                        this.closeHandler();\n                    }\n                ;\n                    return;\n                }\n            ;\n                var ya = event.getTarget(), za = y.byClass(ya, \"closeTheater\"), ab = (((za || (ya == this.root)) || (ya == o.find(this.root, \"div.fbPhotoSnowliftOuter\"))) || (ya == o.find(this.root, \"div.fbPhotoSnowliftInner\")));\n                if (ab) {\n                    if (r.isFullScreen()) {\n                        if (za) {\n                            r.toggleFullScreen();\n                        };\n                        return;\n                    }\n                ;\n                    if (za) {\n                        this.closingAction = aa.X;\n                    }\n                     else this.closingAction = aa.OUTSIDE;\n                ;\n                    Event.kill(event);\n                    this.closeHandler();\n                }\n            ;\n            }\n        ;\n        },\n        close: function() {\n            if (!this.isOpen) {\n                return\n            };\n            if (this.fullscreen) {\n                r.disableFullScreen();\n            };\n            va(\"snowlift\", null, null, \"FORCE\").set_namespace(\"snowlift\").set_ua_id(\"close\");\n            m.hide(this.root);\n            this.openExplicitly = false;\n            this.closeCleanup.bind(this).defer();\n        },\n        closeCleanup: function() {\n            var ya = ma.getScrollPosition();\n            m.removeClass(document.documentElement, \"theaterMode\");\n            m.removeClass(document.body, this.extraClass);\n            q.scrollTo(ya, 0);\n            m.removeClass(this.root, \"dataLoaded\");\n            this.keyHandlers.forEach(function(ab) {\n                ab.remove();\n            });\n            this.keyHandlers = null;\n            aa.logPhotoViews(this.closingAction);\n            this.destroy();\n            m.hide(this.errorBox);\n            m.hide(this.image);\n            this.currentImageSize = null;\n            this.thumbSrc = null;\n            this.shouldStretch = false;\n            this.resetUriStack = true;\n            m.removeClass(this.stageWrapper, \"showVideo\");\n            o.empty(this.videoStage);\n            this.uncollapseRHC();\n            this.currentMinSize = null;\n            this.setStagePagersState(\"reset\");\n            this.recacheData();\n            o.empty(this.sideAdUnit);\n            this.stream.destroy();\n            var za = (this.closingAction === aa.NAVIGATE);\n            this.closingAction = null;\n            if (!this.openHandlerRegistered) {\n                x.registerHandler(this.openHandler.bind(this));\n                this.openHandlerRegistered = true;\n            }\n        ;\n            h.inform(\"layer_hidden\", {\n                type: \"PhotoSnowlift\"\n            });\n            h.inform(\"PhotoSnowlift.CLOSE\", za);\n            this.root.setAttribute(\"aria-busy\", \"true\");\n            this.isOpen = false;\n        },\n        createLoader: function(ya) {\n            if ((this.currentImageSize === null)) {\n                this.adjustStageSize(xa.STAGE_MIN);\n            }\n             else {\n                var za = this.getStageSize(this.currentImageSize);\n                za = new ma(Math.max(za.x, xa.STAGE_MIN.x), Math.max(za.y, xa.STAGE_MIN.y));\n                var ab = this.getImageSizeInStage(this.currentImageSize, za);\n                if ((this.thumbSrc === null)) {\n                    this.adjustStageSize(ab);\n                }\n                 else this.useImage(o.create(\"img\", {\n                    className: \"spotlight\",\n                    alt: \"\",\n                    src: this.thumbSrc,\n                    style: {\n                        width: (ab.x + \"px\"),\n                        height: (ab.y + \"px\")\n                    }\n                }), ab, false);\n            ;\n            }\n        ;\n            this.setLoadingState(this.STATE_IMAGE_PIXELS, true);\n            if (ya) {\n                (function() {\n                    var bb = new Image();\n                    bb.onload = a.async_callback(function() {\n                        if ((!this.isOpen || (this.pendingImageUrl != ya))) {\n                            return\n                        };\n                        if ((!this.stream || !this.stream.errorInCurrent())) {\n                            this.switchImage(ya, this.currentImageSize);\n                            (this.ua && this.ua.add_event(\"image\"));\n                            this.setLoadingState(xa.STATE_IMAGE_DATA, false);\n                        }\n                    ;\n                    }.bind(this), \"photo_theater\");\n                    bb.src = this.pendingImageUrl = ya;\n                }).bind(this).defer();\n            };\n            m.hide(this.stageActions);\n            this.setStagePagersState(\"disabled\");\n        },\n        initDataFetched: function(ya) {\n            aa.setPhotoSet(this.stream.getPhotoSet());\n            aa.setLogFbids(ya.logids);\n            var za = this.stream.getCurrentImageData();\n            aa.addPhotoView(za.info, this.shouldShowHiRes(za), (this.fullscreen && r.isFullScreen()));\n            if (!this.pageHandlers) {\n                this.pageHandlers = [Event.listen(this.root, \"click\", this.pageListener.bind(this)),Event.listen(this.root, \"mouseleave\", this.mouseLeaveListener.bind(this)),];\n                this.keyHandlers = this.keyHandlers.concat([t.registerKey(\"LEFT\", this.pageListener.bind(this)),t.registerKey(\"RIGHT\", this.pageListener.bind(this)),t.registerKey(\"L\", this.likePhotoWithKey.bind(this), function(event, ab) {\n                    event = wa(event);\n                    return ((((ab == \"onkeyup\") && t.filterEventTargets(event, ab)) && t.filterEventModifiers(event, ab)));\n                }),]);\n            }\n        ;\n            m.show(this.stageActions);\n            this.root.setAttribute(\"aria-busy\", \"false\");\n            this.isLoggedInViewer = ya.loggedin;\n            this.disableAds = (!this.isLoggedInViewer || ya.fromad);\n            this.loadAds();\n        },\n        adjustScrollerIfNecessary: function() {\n            clearTimeout(this.scrollerTimeout);\n            this.scrollerTimeout = this.adjustScroller.bind(this).defer();\n        },\n        adjustScroller: function() {\n            clearTimeout(this.scrollerTimeout);\n            this.initializeScroller();\n            this.scrollableArea.resize();\n            var ya = ma.getElementDimensions(this.rhc), za = ya.y;\n            za -= ma.getElementDimensions(this.rhcHeader).y;\n            za -= ma.getElementDimensions(this.ufiInputContainer).y;\n            var ab = ma.getElementDimensions(this.scrollerBody).y;\n            if ((ab >= za)) {\n                ha.set(this.scroller, \"height\", (za + \"px\"));\n                m.addClass(this.rhc, \"pinnedUfi\");\n                za = 0;\n            }\n             else {\n                ha.set(this.scroller, \"height\", \"auto\");\n                m.removeClass(this.rhc, \"pinnedUfi\");\n                za -= ab;\n            }\n        ;\n            var bb = ma.getElementDimensions(this.ufiInputContainer).y;\n            ha.set(this.ufiForm, \"padding-bottom\", (bb + \"px\"));\n            ba.resize(new ma(ya.x, za));\n            this.scrollableArea.adjustGripper();\n        },\n        adjustForResize: function() {\n            this.currentMinSize = null;\n            this.adjustStageSize();\n            this.adjustForNewData();\n        },\n        shouldShowHiRes: function(ya) {\n            if (((!this.showHiRes || !ya) || !ya.smallurl)) {\n                return false\n            };\n            var za = this.getStageSize(ya.dimensions), ab = this.getImageSizeInStage(ya.dimensions, za);\n            return (((ab.x > xa.STAGE_NORMAL_MAX.x) || (ab.y > xa.STAGE_NORMAL_MAX.y)));\n        },\n        getImageURL: function(ya) {\n            if (ya.video) {\n                return null;\n            }\n             else if ((ya.smallurl && !this.shouldShowHiRes(ya))) {\n                return ya.smallurl\n            }\n        ;\n            return ya.url;\n        },\n        getImageDimensions: function(ya) {\n            if ((ya.smalldims && ((!this.shouldShowHiRes(ya) || (this.image.src === ya.smallurl))))) {\n                return ya.smalldims\n            };\n            return ya.dimensions;\n        },\n        getStageSize: function(ya, za) {\n            var ab = ma.getViewportDimensions(), bb = new ma(ya.x, ya.y);\n            if (za) {\n                bb = new ma(Math.max(ya.x, za.x), Math.max(ya.y, za.y));\n            };\n            var cb, db;\n            if ((this.fullscreen && r.isFullScreen())) {\n                return new ma(((this.rhcCollapsed ? screen.width : (screen.width - xa.SIDEBAR_SIZE_MAX))), (screen.height - (xa.FULL_SCREEN_PADDING * 2)));\n            }\n             else {\n                cb = Math.min(bb.x, this.stageMax.x, (((ab.x - xa.SIDEBAR_SIZE_MAX) - xa.STAGE_CHROME.x)));\n                db = Math.min(bb.y, this.stageMax.y, (ab.y - xa.STAGE_CHROME.y));\n            }\n        ;\n            if (((cb === 0) && (db === 0))) {\n                return new ma(0, 0)\n            };\n            var eb = (cb / db), fb = (bb.x / bb.y);\n            if ((eb < fb)) {\n                return new ma(cb, Math.ceil((cb / fb)))\n            };\n            return new ma(Math.ceil((db * fb)), db);\n        },\n        getImageSizeInStage: function(ya, za) {\n            var ab = ya.x, bb = ya.y;\n            if (((ab >= za.x) || (bb >= za.y))) {\n                var cb = (za.x / za.y), db = (ab / bb);\n                if ((cb < db)) {\n                    ab = za.x;\n                    bb = Math.ceil((ab / db));\n                }\n                 else if ((cb > db)) {\n                    bb = za.y;\n                    ab = Math.ceil((bb * db));\n                }\n                 else {\n                    ab = za.x;\n                    bb = za.y;\n                }\n                \n            ;\n            }\n        ;\n            return new ma(ab, bb);\n        },\n        adjustStageSize: function(ya) {\n            var za = this.currentImageSize;\n            if (ya) {\n                za = ya;\n            }\n             else {\n                var ab = (this.stream && this.stream.getCurrentImageData());\n                if (ab) {\n                    za = this.getImageDimensions(ab);\n                };\n            }\n        ;\n            if (!za) {\n                return\n            };\n            this.currentImageSize = za;\n            var bb = 0;\n            if (((((this.shouldStretch && !this.getVideoOnStage()) && (za.x > za.y)) && (za.x <= xa.TIMELINE_STRETCH_WIDTH)) && (za.x >= xa.TIMELINE_STRETCH_MIN))) {\n                za.y = Math.round(((za.y * xa.TIMELINE_STRETCH_WIDTH) / za.x));\n                za.x = xa.TIMELINE_STRETCH_WIDTH;\n            }\n             else if (this.getVideoOnStage()) {\n                bb = (xa.VIDEO_BOTTOM_BAR_SPACE * 2);\n                za.y += bb;\n            }\n            \n        ;\n            var cb = this.getStageSize(za, this.currentMinSize);\n            if (!this.currentMinSize) {\n                this.currentMinSize = new ma(0, 0);\n            };\n            this.currentMinSize = new ma(Math.max(cb.x, xa.STAGE_MIN.x, this.currentMinSize.x), Math.max(cb.y, xa.STAGE_MIN.y, this.currentMinSize.y));\n            var db = this.getImageSizeInStage(za, this.currentMinSize), eb = (this.currentMinSize.x - db.x), fb = (this.currentMinSize.y - db.y);\n            if (((eb > 0) && (eb < xa.PADDING_MIN))) {\n                this.currentMinSize.x -= eb;\n            }\n             else if (((fb > 0) && (fb < xa.PADDING_MIN))) {\n                this.currentMinSize.y -= fb;\n            }\n        ;\n            var gb = (this.currentMinSize.x + xa.SIDEBAR_SIZE_MAX);\n            if (this.rhcCollapsed) {\n                gb = this.currentMinSize.x;\n            };\n            this.snowliftPopup.style.cssText = (((((\"width:\" + gb) + \"px;\") + \"height:\") + this.currentMinSize.y) + \"px;\");\n            var hb = ((this.currentMinSize.y - bb) + \"px\");\n            if ((la.firefox() || (la.ie() < 8))) {\n                var ib = ha.get(this.stageWrapper, \"font-size\");\n                if ((la.ie() && (ib.indexOf(\"px\") < 0))) {\n                    var jb = o.create(\"div\");\n                    jb.style.fontSize = ib;\n                    jb.style.height = \"1em\";\n                    ib = jb.style.pixelHeight;\n                }\n            ;\n                hb = (((((this.currentMinSize.y - bb)) / parseFloat(ib))) + \"em\");\n            }\n        ;\n            this.stageWrapper.style.cssText = (((((\"width:\" + this.currentMinSize.x) + \"px;\") + \"line-height:\") + hb) + \";\");\n            if ((la.ie() < 8)) {\n                ha.set(this.root, \"height\", (ma.getViewportDimensions().y + \"px\"));\n                ha.set(this.container, \"min-height\", (((this.currentMinSize.y + xa.STAGE_CHROME.y)) + \"px\"));\n            }\n        ;\n            this.image.style.cssText = (((((\"width:\" + db.x) + \"px;\") + \"height:\") + db.y) + \"px;\");\n            this.adjustScrollerIfNecessary();\n        },\n        adjustForNewData: function() {\n            if (!this.image) {\n                return\n            };\n            var ya = o.scry(this.stage, \"div.tagsWrapper\")[0], za = ma.getElementDimensions(this.image);\n            if (ya) {\n                ha.set(ya, \"width\", (za.x + \"px\"));\n                ha.set(ya, \"height\", (za.y + \"px\"));\n                if ((la.ie() <= 7)) {\n                    var ab = o.scry(this.root, \"div.tagContainer\")[0];\n                    if (ab) {\n                        m.conditionClass(ya, \"ie7VerticalFix\", (ma.getElementDimensions(ab).y > za.y));\n                    };\n                }\n            ;\n            }\n        ;\n        },\n        setLoadingState: function(ya, za) {\n            switch (ya) {\n              case xa.STATE_IMAGE_PIXELS:\n                m.conditionClass(this.root, \"imagePixelsLoading\", za);\n                break;\n              case xa.STATE_IMAGE_DATA:\n                this.loadingStates[ya] = za;\n                m.conditionClass(this.root, \"imageLoading\", za);\n                break;\n              case xa.STATE_HTML:\n                this.loadingStates[ya] = za;\n                m.conditionClass(this.root, \"dataLoading\", za);\n                this.rhc.setAttribute(\"aria-busy\", (za ? \"true\" : \"false\"));\n                break;\n            };\n        },\n        destroy: function() {\n            this.stageHandlers.forEach(function(ya) {\n                ya.remove();\n            });\n            if (this.pageHandlers) {\n                this.pageHandlers.forEach(function(ya) {\n                    ya.remove();\n                });\n                this.pageHandlers = null;\n            }\n        ;\n        },\n        checkState: function(ya) {\n            if (((ya != xa.STATE_ERROR) && !this.loadingStates[ya])) {\n                return\n            };\n            switch (ya) {\n              case xa.STATE_IMAGE_DATA:\n                var za = this.stream.getCurrentImageData();\n                if (za) {\n                    var ab = this.getImageURL(za);\n                    if (ab) {\n                        this.switchImage(ab, null, true);\n                    }\n                     else if (za.video) {\n                        this.switchVideo(za.video, true);\n                    }\n                ;\n                    this.setLoadingState(ya, false);\n                }\n            ;\n                break;\n              case xa.STATE_HTML:\n                if (this.stream.getCurrentHtml()) {\n                    this.swapData();\n                    this.setLoadingState(ya, false);\n                }\n            ;\n                break;\n              default:\n                if (this.stream.errorInCurrent()) {\n                    m.hide(this.image);\n                    m.show(this.errorBox);\n                }\n            ;\n                break;\n            };\n        },\n        buttonListener: function(event) {\n            var ya = event.getTarget(), za = Date.now();\n            if (y.byClass(ya, \"fbPhotoTagApprovalBox\")) {\n                return\n            };\n            if (((za - this.lastPage) < 350)) {\n                return\n            };\n            if (y.byClass(ya, \"fbPhotosPhotoLike\")) {\n                this.likePhoto();\n            }\n             else if (y.byClass(ya, \"tagApproveIgnore\")) {\n                this.updateTagBox(event, ya);\n            }\n        ;\n        },\n        likePhoto: function() {\n            aa.addButtonLike();\n            var ya = na(\"fbPhotoSnowliftFeedback\"), za = o.scry(ya, \"button.like_link\")[0];\n            if (!za) {\n                za = o.scry(ya, \"a.UFILikeLink\")[0];\n            };\n            za.click();\n        },\n        toggleLikeButton: function() {\n            var ya = o.scry(this.buttonActions, \"a.fbPhotosPhotoLike\")[0];\n            if (ya) {\n                m.toggleClass(ya, \"viewerLikesThis\");\n                m.removeClass(ya, \"viewerAlreadyLikedThis\");\n            }\n        ;\n        },\n        likePhotoWithKey: function() {\n            if (this.isShowingLikePhotoConfirmation) {\n                return\n            };\n            if (this.skipLikePhotoConfirmation) {\n                this.likePhoto();\n            }\n             else i.send(new j(\"/photos/confirm_like.php\"), function(ya) {\n                this.isShowingLikePhotoConfirmation = true;\n                ya.subscribe(\"confirm\", this.onCloseLikePhotoConfirmDialog.bind(this));\n                ya.subscribe(\"cancel\", this.onCloseLikePhotoConfirmDialog.bind(this));\n            }.bind(this));\n        ;\n            return false;\n        },\n        likePhotoSkipConfirmation: function(ya) {\n            this.skipLikePhotoConfirmation = ya;\n            this.likePhoto();\n        },\n        onCloseLikePhotoConfirmDialog: function() {\n            this.isShowingLikePhotoConfirmation = false;\n        },\n        updateTagBox: function(ya, za) {\n            this.unhiliteAllTags();\n            var ab = ra(ya);\n            if (!ab) {\n                return\n            };\n            m.addClass(ab, \"tagBox\");\n            m.addClass(ab, \"tagBoxPendingResponse\");\n            m.removeClass(ab, \"tagBoxPending\");\n            m.hide(o.find(ab, \"span.tagForm\"));\n            if (za) {\n                m.show(o.find(ab, \"span.tagApproved\"));\n            }\n             else m.show(o.find(ab, \"span.tagIgnored\"));\n        ;\n        },\n        rotate: function(ya) {\n            var za = this.stream.getCursor();\n            if (this.getVideoOnStage()) {\n                var ab = (((ya == \"left\")) ? 270 : 90);\n                k.loadModules([\"VideoRotate\",], function(cb) {\n                    new cb(za).motionRotate(ab);\n                });\n                return;\n            }\n        ;\n            var bb = pa({\n                fbid: za,\n                cs_ver: z.VIEWER_SNOWLIFT\n            }, this.stream.getPhotoSetQuery());\n            bb[ya] = 1;\n            this.setLoadingState(xa.STATE_IMAGE_DATA, true);\n            this.setLoadingState(this.STATE_IMAGE_PIXELS, true);\n            m.hide(this.image);\n            new j(\"/ajax/photos/photo/rotate/\").setAllowCrossPageTransition(true).setData(bb).setErrorHandler(this.rotationError.bind(this, za)).setFinallyHandler(this.rotationComplete.bind(this, za)).setMethod(\"POST\").setReadOnly(false).send();\n        },\n        rotationComplete: function(ya, za) {\n            if ((ya == this.stream.getCursor())) {\n                this.setLoadingState(xa.STATE_IMAGE_DATA, false);\n                this.switchImage(this.getImageURL(this.stream.getCurrentImageData()));\n                this.swapData();\n            }\n        ;\n        },\n        rotationError: function(ya, za) {\n            if ((ya == this.stream.getCursor())) {\n                this.setLoadingState(xa.STATE_IMAGE_DATA, false);\n                this.switchImage(this.getImageURL(this.stream.getCurrentImageData()));\n                k.loadModules([\"AsyncResponse\",], function(ab) {\n                    ab.defaultErrorHandler(za);\n                });\n            }\n        ;\n        },\n        saveTagsFromPayload: function(ya) {\n            this.storeFromData(ya);\n            if (((\"data\" in ya) && (this.stream.getCursor() in ya.data))) {\n                this.swapData();\n            };\n        },\n        saveEdit: function() {\n            if (!m.hasClass(this.root, \"fbPhotoSnowliftEditMode\")) {\n                return\n            };\n            k.loadModules([\"PhotoInlineEditor\",\"Form\",], function(ya, za) {\n                var ab = ya.getInstance(this.getViewerConst());\n                (ab && za.bootstrap(ab.getForm().controller));\n            }.bind(this));\n        },\n        mouseLeaveListener: function(event) {\n            this.unhiliteAllTags();\n            this.reHilitePendingTag();\n        },\n        hilitePagerOnMouseMove: function(event) {\n            var ya = ma.getEventPosition(event), za = ma.getElementPosition(this.stage);\n            if (w.isRTL()) {\n                var ab = ma.getElementDimensions(this.stage);\n                this.stagePagerPrev = ((ab.x - ((ya.x - za.x))) < xa.GOPREV_AREA);\n            }\n             else this.stagePagerPrev = ((ya.x - za.x) < xa.GOPREV_AREA);\n        ;\n            m.conditionClass(this.prevPager, \"hilightPager\", this.stagePagerPrev);\n            m.conditionClass(this.nextPager, \"hilightPager\", !this.stagePagerPrev);\n            var bb, cb = event.getTarget();\n            if (((!y.byClass(cb, \"snowliftOverlay\") && !y.byClass(cb, \"bottomBarActions\")) && !y.byClass(cb, \"snowliftPager\"))) {\n                bb = xa.PAGER_FADE;\n            };\n            this.showPagers(bb);\n        },\n        showPagers: function(ya) {\n            clearTimeout(this.fadePagerTimer);\n            this.setStagePagersState(\"active\");\n            if ((typeof ya !== \"undefined\")) {\n                this.fadePagerTimer = this.hidePagers.bind(this).defer(ya);\n            };\n        },\n        hidePagers: function() {\n            var ya = o.scry(this.getRoot(), \".fbPhotosPhotoActionsMenu\")[0];\n            if (ya) {\n                return\n            };\n            clearTimeout(this.fadePagerTimer);\n            this.setStagePagersState(\"inactive\");\n        },\n        getTagger: function() {\n            if (!this.PhotoTagger) {\n                return null\n            };\n            var ya = this.PhotoTagger.getInstance(z.VIEWER_SNOWLIFT);\n            if ((!ya || !ya.tagHoverFacebox)) {\n                return null\n            };\n            return ya;\n        },\n        unhiliteAllTags: function() {\n            o.scry(this.stage, \"div.tagsWrapper div.hover\").forEach(function(za) {\n                m.removeClass(za, \"hover\");\n            });\n            this.hilitedTag = null;\n            if (!m.hasClass(this.root, \"taggingMode\")) {\n                var ya = this.getTagger();\n                if (ya) {\n                    ya.hideTagger();\n                    ya.setCurrentFacebox(null);\n                }\n            ;\n            }\n        ;\n        },\n        switchHilitedTags: function(ya, za) {\n            if ((this.switchTimer !== null)) {\n                clearTimeout(this.switchTimer);\n                this.switchTimer = null;\n            }\n        ;\n            this.unhiliteAllTags();\n            var ab = ra(ya);\n            if (ab) {\n                this.hilitedTag = ya;\n                if ((!m.hasClass(this.root, \"taggingMode\") && da.isFacebox(this.hilitedTag))) {\n                    var bb = this.getTagger();\n                    if (bb) {\n                        m.addClass(ab, \"hover\");\n                        var cb = bb.getFacebox(ya);\n                        bb.setCurrentFacebox(cb);\n                        if (cb) {\n                            bb.addTagFromFacebox(cb);\n                        };\n                    }\n                ;\n                }\n                 else m.addClass(ab, \"hover\");\n            ;\n                if (((m.hasClass(ab, \"tagBoxPending\") && !m.hasClass(ab, \"showPendingTagName\")) && (za === true))) {\n                    o.scry(this.stage, \"div.tagsWrapper div.showPendingTagName\").forEach(function(db) {\n                        m.removeClass(db, \"showPendingTagName\");\n                    });\n                    m.addClass(ab, \"showPendingTagName\");\n                }\n            ;\n            }\n        ;\n        },\n        reHilitePendingTag: function() {\n            var ya = ra(this.hilitedTag);\n            if ((ya && m.hasClass(ya, \"showPendingTagName\"))) {\n                return\n            };\n            var za = o.scry(this.stage, \"div.tagsWrapper div.showPendingTagName\")[0];\n            if (za) {\n                this.switchHilitedTags(za.id);\n            };\n        },\n        hiliteTagsOnMouseMove: function(event) {\n            if ((!this.stream.getCurrentExtraData() || this.getVideoOnStage())) {\n                return\n            };\n            if ((this.switchTimer !== null)) {\n                return\n            };\n            var ya = event.getTarget();\n            if ((((y.byClass(ya, \"snowliftOverlay\") || y.byClass(ya, \"fbPhotoSnowliftTagApproval\")) || y.byClass(ya, \"tagPointer\")) || y.byClass(ya, \"photoTagTypeahead\"))) {\n                return\n            };\n            var za = y.byClass(ya, \"tagBoxPending\"), ab = false;\n            if (this.hilitedTag) {\n                var bb = ra(this.hilitedTag);\n                ab = (bb && m.hasClass(bb, \"tagBoxPending\"));\n            }\n        ;\n            var cb = ((((!this.hilitedTag && za)) || ((!ab && za))));\n            if (cb) {\n                this.switchHilitedTags(za.id);\n                return;\n            }\n        ;\n            if ((za && ((za.id == this.hilitedTag)))) {\n                return\n            };\n            var db = 250, eb = da.absoluteToNormalizedPosition(this.image, ma.getEventPosition(event));\n            if (this.currentTagHasPrecedence(eb)) {\n                return\n            };\n            var fb = da.getNearestBox(this.stream.getCurrentExtraData().tagRects, eb);\n            if (!fb) {\n                if (!ab) {\n                    this.unhiliteAllTags();\n                    this.reHilitePendingTag();\n                }\n            ;\n                return;\n            }\n        ;\n            var gb = null;\n            if (ab) {\n                var hb = {\n                };\n                hb[this.hilitedTag] = this.stream.getCurrentExtraData().tagRects[this.hilitedTag];\n                gb = da.getNearestBox(hb, eb);\n            }\n        ;\n            if (((gb !== null) && ab)) {\n                return\n            };\n            if ((this.hilitedTag != fb)) {\n                if (ab) {\n                    this.switchTimer = this.switchHilitedTags.bind(this, fb).defer(db);\n                }\n                 else {\n                    if (this.showHover) {\n                        if (!this.seenTags) {\n                            this.seenTags = [];\n                        };\n                        if (!this.seenTags[fb]) {\n                            aa.addFaceTagImpression();\n                            this.seenTags[fb] = true;\n                        }\n                    ;\n                    }\n                ;\n                    this.switchHilitedTags(fb);\n                }\n            \n            };\n        },\n        currentTagHasPrecedence: function(ya) {\n            if (!this.hilitedTag) {\n                return false\n            };\n            var za = this.stream.getCurrentExtraData().tagRects[this.hilitedTag], ab = new fa((za.t + ((za.h() / 2))), za.r, (za.b + ((da.isFacebox(this.hilitedTag) ? 10 : 0))), za.l, za.domain);\n            return ab.contains(ya);\n        },\n        getVideoOnStage: function() {\n            var ya = (this.stream && this.stream.getCurrentImageData());\n            return (ya && ya.video);\n        },\n        shouldPageOnAction: function(ya, za) {\n            if ((!this.isOpen || this.isShowingLikePhotoConfirmation)) {\n                return false\n            };\n            var ab = (o.isNode(za) && (((y.byClass(za, \"snowliftPager\") || y.byClass(za, \"stagePagers\")) || y.byClass(za, \"pivotPageColumn\")))), bb = (o.isNode(za) && y.byClass(za, \"stage\")), cb = m.hasClass(za, \"faceBox\"), db = (((((((bb && m.hasClass(this.root, \"taggingMode\"))) || y.byClass(za, \"tagBoxPending\")) || y.byClass(za, \"tagBoxPendingResponse\")) || y.byClass(za, \"fbPhotoTagApprovalBox\")) || y.byClass(za, \"tag\")));\n            if (db) {\n                return false\n            };\n            return (((((ya == u.LEFT) || (ya == u.RIGHT)) || ((!m.hasClass(this.root, \"taggingMode\") && cb))) || ab) || bb);\n        },\n        pageListener: function(event) {\n            var ya = Event.getKeyCode(event), za = event.getTarget();\n            if (!this.shouldPageOnAction(ya, za)) {\n                return\n            };\n            var ab = 0;\n            if ((ya == u.RIGHT)) {\n                ab = 1;\n                aa.setPagingAction(\"key_right\");\n            }\n             else if ((ya == u.LEFT)) {\n                ab = -1;\n                aa.setPagingAction(\"key_left\");\n            }\n             else if (y.byClass(za, \"next\")) {\n                ab = 1;\n                aa.setPagingAction(\"click_next\");\n            }\n             else if (y.byClass(za, \"prev\")) {\n                ab = -1;\n                aa.setPagingAction(\"click_prev\");\n            }\n             else if (!this.stagePagerPrev) {\n                ab = 1;\n                aa.setPagingAction(\"click_stage\");\n            }\n             else {\n                ab = -1;\n                aa.setPagingAction(\"click_stage_back\");\n            }\n            \n            \n            \n            \n        ;\n            if (m.hasClass(this.root, \"fbPhotoSnowliftEditMode\")) {\n                this.warnLeavePage(ab);\n            }\n             else {\n                this.page(ab);\n                va(\"a\", za, event, \"FORCE\").set_namespace(\"snowlift\").set_ua_id(aa.pagingAction);\n            }\n        ;\n        },\n        warnLeavePage: function(ya) {\n            new n().setTitle(\"Are you sure you want to leave this page?\").setBody(\"You have unsaved changes that will be lost if you leave the page.\").setButtons([{\n                name: \"leave_page\",\n                label: \"Leave this Page\",\n                handler: this.page.bind(this, ya)\n            },{\n                name: \"continue_editing\",\n                label: \"Stay on this Page\",\n                className: \"inputaux\"\n            },]).setModal(true).show();\n        },\n        page: function(ya, za) {\n            if (!this.stream.isValidMovement(ya)) {\n                this.showPagers(xa.PAGER_FADE);\n                return;\n            }\n        ;\n            this.lastPage = Date.now();\n            this.unhiliteAllTags();\n            this.seenTags = [];\n            var ab = this.getVideoOnStage();\n            if (ab) {\n                this.switchVideo(ab, false);\n            };\n            if ((this.pivots && this.pivots.page(ya))) {\n                return\n            };\n            h.inform(\"PhotoSnowlift.PAGE\");\n            ia.hide();\n            this.recacheData();\n            this.stream.moveCursor(ya);\n            m.hide(this.image);\n            if (this.stream.errorInCurrent()) {\n                this.setLoadingState(xa.STATE_HTML, true);\n                m.show(this.errorBox);\n                return;\n            }\n        ;\n            var bb = this.stream.getCurrentImageData();\n            if (bb) {\n                var cb = this.getImageURL(bb);\n                if (cb) {\n                    this.switchImage(cb, null, true);\n                }\n                 else if (bb.video) {\n                    this.switchVideo(bb.video, true);\n                }\n            ;\n                if (!za) {\n                    this.replaceUrl = true;\n                    sa(bb.info.permalink);\n                }\n            ;\n                this.setLoadingState(xa.STATE_IMAGE_DATA, false);\n            }\n             else {\n                this.setLoadingState(xa.STATE_IMAGE_PIXELS, true);\n                this.setLoadingState(xa.STATE_IMAGE_DATA, true);\n            }\n        ;\n            if (this.stream.getCurrentHtml()) {\n                this.swapData();\n            }\n             else this.setLoadingState(xa.STATE_HTML, true);\n        ;\n            this.disableAds = !this.isLoggedInViewer;\n            this.loadAds();\n        },\n        logImpressionDetailsForPhoto: function() {\n            var ya = [].concat(o.scry(na(\"fbPhotoSnowliftTagList\"), \"input.photoImpressionDetails\"), o.scry(na(\"fbPhotoSnowliftFeedback\"), \"input.photoImpressionDetails\"));\n            if ((ya.length === 0)) {\n                return\n            };\n            var za = {\n            };\n            for (var ab = 0; (ab < ya.length); ab++) {\n                za[ya[ab].name] = ya[ab].value;;\n            };\n            if (this.getVideoOnStage()) {\n                za.width = 0;\n                za.height = 0;\n            }\n             else {\n                var bb = this.getImageDimensions(this.stream.getCurrentImageData());\n                za.width = bb.x;\n                za.height = bb.y;\n            }\n        ;\n            aa.addDetailData(this.stream.getCursor(), za);\n            ba.setIsLogAdData(true);\n        },\n        loadAds: function() {\n            if (this.disableAds) {\n                return\n            };\n            ba.loadAdsFromUserActivity();\n        },\n        transitionHandler: function(ya) {\n            if ((((ya.getQueryData().closeTheater || ya.getQueryData().permPage) || ya.getQueryData().makeprofile) || this.returningToStart)) {\n                if (this.isOpen) {\n                    this.close();\n                };\n                this.transitionHandlerRegistered = false;\n                return false;\n            }\n        ;\n            if (this.replaceUrl) {\n                this.replaceUrl = false;\n                this._uriStack.push(ya.getQualifiedURI().toString());\n                x.transitionComplete();\n                return true;\n            }\n        ;\n            var za = this._uriStack.length;\n            if (((za >= 2) && (this._uriStack[(za - 2)] == ya.getQualifiedURI().toString()))) {\n                this._uriStack.pop();\n            };\n            var ab = this.stream.getCursorForURI(ya.getUnqualifiedURI().toString());\n            if (ab) {\n                var bb = this.stream.getRelativeMovement(ab);\n                this.page(bb, true);\n                x.transitionComplete();\n                return true;\n            }\n        ;\n            if (this.isOpen) {\n                this.close();\n                x.transitionComplete();\n                return true;\n            }\n        ;\n            this.transitionHandlerRegistered = false;\n            return false;\n        },\n        recacheData: function() {\n            if (!this.loadingStates.html) {\n                var ya = this.stream.getCurrentHtml();\n                for (var za in ya) {\n                    ya[za] = qa(na(za).childNodes);\n                    o.empty(na(za));\n                };\n            }\n        ;\n        },\n        reloadIfTimeout: function() {\n            if (!s.hasLoaded(this.image)) {\n                var ya = this.makeNewImage(this.image.src, true);\n                Event.listen(ya, \"load\", this.useImage.bind(this, ya, null, true));\n            }\n        ;\n        },\n        useImage: function(ya, za, ab) {\n            if ((ab && s.hasLoaded(this.image))) {\n                return\n            };\n            o.replace(this.image, ya);\n            this.image = ya;\n            this.adjustStageSize(za);\n        },\n        makeNewImage: function(ya, za) {\n            if (this.imageLoadingTimer) {\n                clearTimeout(this.imageLoadingTimer);\n                this.imageLoadingTimer = null;\n            }\n             else if (!za) {\n                this.imageRefreshTimer = setTimeout(this.reloadIfTimeout.bind(this), xa.LOADING_TIMEOUT);\n            }\n        ;\n            var ab = o.create(\"img\", {\n                className: \"spotlight\",\n                alt: \"\"\n            });\n            ab.setAttribute(\"aria-describedby\", \"fbPhotosSnowliftCaption\");\n            ab.setAttribute(\"aria-busy\", \"true\");\n            Event.listen(ab, \"load\", a.async_callback(function() {\n                clearTimeout(this.imageRefreshTimer);\n                this.image.setAttribute(\"aria-busy\", \"false\");\n                this.setLoadingState(this.STATE_IMAGE_PIXELS, false);\n                (function() {\n                    if (this.isOpen) {\n                        this.adjustStageSize();\n                        this.adjustForNewData();\n                    }\n                ;\n                }).bind(this).defer();\n            }.bind(this), \"photo_theater\"));\n            ab.src = ya;\n            return ab;\n        },\n        switchImage: function(ya, za, ab) {\n            m.hide(this.image);\n            m.hide(this.errorBox);\n            this.setLoadingState(this.STATE_IMAGE_PIXELS, true);\n            var bb = (this.stream && this.stream.getCurrentImageData());\n            if (bb) {\n                aa.addPhotoView(bb.info, this.shouldShowHiRes(bb), (this.fullscreen && r.isFullScreen()));\n            };\n            this.useImage(this.makeNewImage(ya, false), za, false);\n            if (ab) {\n                this.stream.preloadImages(this.shouldShowHiRes(bb));\n            };\n        },\n        switchVideo: function(ya, za) {\n            var ab = (\"swf_\" + ya);\n            if (za) {\n                m.addClass(this.stageWrapper, \"showVideo\");\n                var bb = o.create(\"div\", {\n                    className: \"videoStageContainer\"\n                });\n                o.appendContent(this.videoStage, bb);\n                bb.id = ya;\n                if ((window[ab] && !ra(ab))) {\n                    window[ab].write(ya);\n                };\n                this.adjustStageSizeForVideo.bind(this, ab).defer();\n            }\n             else {\n                (window[ab] && window[ab].addVariable(\"video_autoplay\", 0));\n                (this.videoLoadTimer && clearTimeout(this.videoLoadTimer));\n                o.empty(this.videoStage);\n                m.removeClass(this.stageWrapper, \"showVideo\");\n            }\n        ;\n        },\n        checkVideoStatus: function(ya) {\n            if (this.videoLoadTimer) {\n                clearTimeout(this.videoLoadTimer);\n            };\n            var za = this.getVideoOnStage();\n            if (!za) {\n                return;\n            }\n             else {\n                var ab = (\"swf_\" + za);\n                if ((ya !== ab)) {\n                    return\n                };\n                this.adjustStageSizeForVideo(ya);\n            }\n        ;\n        },\n        adjustStageSizeForVideo: function(ya) {\n            var za = ra(ya);\n            if (!za) {\n                this.videoLoadTimer = setTimeout(this.checkVideoStatus.bind(this, ya), 200);\n            }\n             else this.adjustStageSize(new ma(za.width, za.height));\n        ;\n        },\n        handleServerError: function(ya, za) {\n            o.setContent(this.errorBox, ya);\n            this.storeFromData(za);\n        },\n        swapData: function() {\n            var ya, za = this.stream.getCurrentHtml();\n            if (za) {\n                this.setLoadingState(xa.STATE_HTML, false);\n                for (var ab in za) {\n                    ya = ra(ab);\n                    (ya && o.setContent(ya, za[ab]));\n                };\n                h.inform(\"PhotoSnowlift.DATA_CHANGE\", this.stream.getCurrentImageData().info, h.BEHAVIOR_STATE);\n                if (this.stream.getCurrentExtraData()) {\n                    h.inform(\"PhotoSnowlift.EXTRA_DATA_CHANGE\", this.stream.getCurrentExtraData(), h.BEHAVIOR_STATE);\n                };\n            }\n        ;\n            this.showPagers(xa.PAGER_FADE);\n            this.adjustScroller();\n            this.scrollableArea.showScrollbar(false);\n            this.adjustForNewData();\n            this.logImpressionDetailsForPhoto();\n        },\n        updateTotalCount: function(ya, za, ab) {\n            var bb = this.stream.getCurrentHtml();\n            if (bb) {\n                var cb = na(\"fbPhotoSnowliftPositionAndCount\");\n                o.replace(cb, ab);\n                cb = ab;\n                m.show(cb);\n                var db = \"fbPhotoSnowliftPositionAndCount\";\n                bb[db] = qa(cb.childNodes);\n            }\n        ;\n            this.stream.setTotalCount(ya);\n            this.stream.setFirstCursorIndex(za);\n        },\n        addPhotoFbids: function(ya, za, ab, bb) {\n            if (((bb && this.sessionID) && (bb != this.sessionID))) {\n                return\n            };\n            var cb = (this.stream.getCursor() === null);\n            this.stream.attachToFbidsList(ya, za, ab);\n            if ((ab && cb)) {\n                this.page(0, true);\n            };\n            if ((this.pivots && ab)) {\n                this.pivots.setCycleCount(this.stream.calculateDistance(this.stream.getCursor(), this.stream.firstCursor));\n            };\n            if ((!this.pagersShown && this.stream.canPage())) {\n                this.setStagePagersState(\"ready\");\n            };\n        },\n        attachTagger: function(ya) {\n            o.appendContent(this.stageActions, ya);\n        },\n        storeFromData: function(ya) {\n            if (!this.isOpen) {\n                return\n            };\n            if (((ya.ssid && this.sessionID) && (this.sessionID != ya.ssid))) {\n                return\n            };\n            var za = this.stream.storeToCache(ya);\n            if ((\"error\" in za)) {\n                this.checkState(xa.STATE_ERROR);\n                return;\n            }\n        ;\n            if ((\"init\" in za)) {\n                this.initDataFetched(za.init);\n                if (this.openExplicitly) {\n                    this.replaceUrl = true;\n                    sa(this.stream.getCurrentImageData().info.permalink);\n                }\n            ;\n                if (this.stream.canPage()) {\n                    this.setStagePagersState(\"ready\");\n                };\n                (this.ua && this.ua.add_event(\"ufi\"));\n            }\n        ;\n            if ((\"image\" in za)) {\n                this.checkState(xa.STATE_IMAGE_DATA);\n            };\n            if ((\"data\" in za)) {\n                this.checkState(xa.STATE_HTML);\n            };\n        },\n        setStagePagersState: function(ya) {\n            switch (ya) {\n              case \"ready\":\n                m.addClass(this.root, \"pagingReady\");\n                this.pagersShown = true;\n                (this.ua && this.ua.add_event(\"arrows\"));\n                return;\n              case \"active\":\n                m.addClass(this.root, \"pagingActivated\");\n                return;\n              case \"inactive\":\n                m.removeClass(this.root, \"pagingActivated\");\n                return;\n              case \"disabled\":\n            \n              case \"reset\":\n                m.removeClass(this.root, \"pagingReady\");\n                return;\n            };\n        },\n        deletePhoto: function(ya) {\n            this.closeRefresh();\n        },\n        closeRefresh: function() {\n            this.refreshOnClose = true;\n            this.closeHandler();\n        },\n        onHiliteTag: function(ya, za) {\n            if ((za.version != z.VIEWER_SNOWLIFT)) {\n                return\n            };\n            var ab = za.tag;\n            if (ab) {\n                this.switchHilitedTags(ab, true);\n            };\n        },\n        onUpdateTagBox: function(ya, za) {\n            if ((za.version == z.VIEWER_SNOWLIFT)) {\n                this.updateTagBox(za.id, za.approve);\n            };\n        }\n    });\n    e.exports = xa;\n});\n__d(\"legacy:AudienceSelector\", [\"AudienceSelector\",], function(a, b, c, d) {\n    b(\"AudienceSelector\");\n}, 3);\n__d(\"legacy:CustomPrivacyOption\", [\"CustomPrivacyOption\",], function(a, b, c, d) {\n    a.CustomPrivacyOption = b(\"CustomPrivacyOption\");\n}, 3);\n__d(\"legacy:Selector\", [\"Selector\",], function(a, b, c, d) {\n    a.Selector = b(\"Selector\");\n}, 3);\nvar FriendListPrivacyOptions = (function() {\n    var a = false, b = false, c = null, d = {\n    }, e = function(f) {\n        if (is_empty(d)) {\n            PageTransitions.registerHandler(function() {\n                d = {\n                };\n                a = false;\n                b = false;\n            });\n        };\n        var g = f.getAttribute(\"data-name\");\n        d[g] = f;\n        Selector.listen(f, \"select\", function(h) {\n            var i = h.option, j = DOM.find(i, \"a.itemAnchor\"), k = j.getAttribute(\"data-flid\");\n            if (!k) {\n                return\n            };\n            var l = j.getAttribute(\"data-dynamic\");\n            if ((l && a)) {\n                FriendListPrivacyOptions.showSmartListNux(i, k);\n            }\n             else if ((!l && b)) {\n                FriendListPrivacyOptions.showDumbListNux([k,]);\n            }\n        ;\n        });\n    };\n    return {\n        listen: function(f, g, h) {\n            var i = ge(f);\n            if (!i) {\n                return\n            };\n            var j = Parent.byClass(i, \"audienceSelector\");\n            if (j) {\n                e(j);\n                a = g;\n                b = h;\n            }\n        ;\n        },\n        showSmartListNux: function(f, g) {\n            new AsyncRequest(\"/ajax/friends/lists/smart_list_publish_nux.php\").setData({\n                option_id: f.id,\n                flid: g\n            }).send();\n            a = false;\n        },\n        setContextualDialog: function(f, g) {\n            var h = Parent.byClass(g, \"audienceSelector\");\n            if (h) {\n                f.setContext(h);\n                f.show();\n                var i = Arbiter.subscribe(\"composer/publish\", function() {\n                    f.hide();\n                });\n                f.subscribe(\"hide\", function() {\n                    i.unsubscribe();\n                });\n            }\n        ;\n        },\n        showDumbListNux: function(f) {\n            new AsyncRequest(\"/ajax/friends/lists/dumb_list_publish_nux.php\").setData({\n                flids: f\n            }).send();\n            b = false;\n        },\n        showBothListsNux: function(f, g) {\n            c = f;\n            FriendListPrivacyOptions.showDumbListNux(g);\n        },\n        setDialog: function() {\n            if (!c) {\n                return\n            };\n            var f = Dialog.getCurrent();\n            if (f) {\n                f.setCloseHandler(function() {\n                    FriendListPrivacyOptions.showSmartListNux(c);\n                    c = null;\n                });\n            };\n        }\n    };\n})();\n__d(\"legacy:privacy-common\", [\"PrivacyConst\",\"PrivacyModel\",], function(a, b, c, d) {\n    var e = b(\"PrivacyConst\");\n    a.PrivacyModel = b(\"PrivacyModel\");\n    a.PrivacyBaseValue = e.BaseValue;\n    a.PrivacyFriendsValue = e.FriendsValue;\n}, 3);\nfunction OnlyMePrivacyOption() {\n\n};\ncopyProperties(OnlyMePrivacyOption.prototype, {\n    init: function(a) {\n        this._selector = Parent.byClass(a, \"composerAudienceSelector\");\n        this._plusLabel = DOM.find(a, \".plusLabel\");\n        if (!this._selector) {\n            return\n        };\n        this._elem = a;\n        this._taggedIDs = [];\n        this._tags = [];\n        this._eventTag = null;\n        this._recalculateTooltipAndLabel();\n        this._updateSelector();\n        Arbiter.subscribe(\"Composer/changedtags\", function(b, c) {\n            var d = this._eventTag;\n            this._eventTag = c.eventTag;\n            this._tags = c.withTags.map(function(f) {\n                return f.getText();\n            });\n            this._taggedIDs = c.withTags.map(function(f) {\n                return f.getValue();\n            });\n            for (var e in c.mention) {\n                if (((c.mention[e].type == \"user\") && (c.mention[e].uid != Env.user))) {\n                    this._tags.push(c.mention[e].text);\n                    this._taggedIDs.push(c.mention[e].uid);\n                }\n            ;\n            };\n            if (((this._eventTag && (d != this._eventTag)) && Selector.isOptionSelected(this._elem))) {\n                Arbiter.inform(\"EventTagged/changed\", this._getChangedData());\n            };\n            if ((this._recalculateTooltipAndLabel() && Selector.isOptionSelected(this._elem))) {\n                this._updateSelector();\n                Arbiter.inform(\"SelectedPrivacyOption/changed\", this._getChangedData());\n            }\n        ;\n        }.bind(this));\n        Selector.listen(this._selector, \"change\", this._updateSelector.bind(this));\n    },\n    _getChangedData: function() {\n        return {\n            eventTag: this._eventTag,\n            tags: this._taggedIDs,\n            privacy: PrivacyFriendsValue.SELF\n        };\n    },\n    _recalculateTooltipAndLabel: function() {\n        var a = this._tooltip, b = this._label;\n        if (this._taggedIDs.length) {\n            this._tooltip = \"Anyone tagged\";\n            this._label = (\"Only Me\" + \" (+)\");\n        }\n         else {\n            this._tooltip = \"Only you\";\n            this._label = \"Only Me\";\n        }\n    ;\n        CSS.conditionShow(this._plusLabel, this._taggedIDs.length);\n        return (((a != this._tooltip)) || ((b != this._label)));\n    },\n    _updateSelector: function() {\n        if (Selector.isOptionSelected(this._elem)) {\n            Selector.setButtonLabel(this._selector, this._label);\n            Selector.setButtonTooltip(this._selector, this._tooltip);\n            return false;\n        }\n    ;\n        return true;\n    }\n});\n__d(\"legacy:ui-scrolling-pager-js\", [\"ScrollingPager\",], function(a, b, c, d) {\n    a.ScrollingPager = b(\"ScrollingPager\");\n}, 3);\n__d(\"TypeaheadBestName\", [\"TypeaheadUtil\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"TypeaheadUtil\"), h = b(\"copyProperties\");\n    function i(j) {\n        this._typeahead = j;\n    };\n    h(i.prototype, {\n        _subscription: null,\n        enable: function() {\n            var j = this._typeahead.getView();\n            this._subscription = j.subscribe(\"beforeRender\", function(k, l) {\n                var m = l.value;\n                for (var n = 0; (n < l.results.length); ++n) {\n                    var o = l.results[n];\n                    if ((o.alternate_names == null)) {\n                        continue;\n                    };\n                    if (g.isQueryMatch(m, o.default_name)) {\n                        o.text = o.default_name;\n                        return;\n                    }\n                ;\n                    for (var p = 0; (p < o.alternate_names.length); p++) {\n                        if (g.isQueryMatch(m, o.alternate_names[p])) {\n                            o.text = o.alternate_names[p];\n                            return;\n                        }\n                    ;\n                    };\n                    o.text = o.default_name;\n                };\n            });\n        },\n        disable: function() {\n            this._typeahead.getView().unsubscribe(this._subscription);\n            this._subscription = null;\n        }\n    });\n    e.exports = i;\n});\n__d(\"legacy:BestNameTypeaheadBehavior\", [\"TypeaheadBestName\",], function(a, b, c, d) {\n    var e = b(\"TypeaheadBestName\");\n    if (!a.TypeaheadBehaviors) {\n        a.TypeaheadBehaviors = {\n        };\n    };\n    a.TypeaheadBehaviors.buildBestAvailableNames = function(f) {\n        f.enableBehavior(e);\n    };\n}, 3);\nvar StreamShareVideo = {\n    _endpoints: [],\n    _thumbs: [],\n    registerThumb: function(a, b, c, d) {\n        StreamShareVideo._endpoints[((a + \" \") + c)] = d;\n        StreamShareVideo._thumbs[((a + \" \") + c)] = b;\n    },\n    clickTitle: function(a, b, event) {\n        this.expandInlineOrRedirect(a, b, event);\n    },\n    expandInlineOrRedirect: function(a, b, event) {\n        if (StreamShareVideo._shouldFollowHref(event)) {\n            return true\n        };\n        var c = StreamShareVideo._thumbs[((a + \" \") + b)], d = ge(c);\n        if (d) {\n            CSS.addClass(d, \"uiVideoThumbLoading\");\n            AsyncRequest.bootstrap(StreamShareVideo._endpoints[((a + \" \") + b)], d.parentElement);\n            return false;\n        }\n    ;\n        return true;\n    },\n    clickTimeline: function(a, b, event) {\n        if (StreamShareVideo._shouldFollowHref(event)) {\n            return true\n        };\n        CSS.addClass(a, \"-cx-PRIVATE-fbTimelineExternalShareUnit__loading\");\n        CSS.removeClass(a, \"-cx-PRIVATE-fbTimelineExternalShareUnit__video\");\n        AsyncRequest.bootstrap(b, a);\n        return false;\n    },\n    _shouldFollowHref: function(event) {\n        event = $E(event);\n        if (!event) {\n            return false\n        };\n        if ((event.getModifiers().any || event.isMiddleClick())) {\n            return true\n        };\n        return false;\n    }\n};\nfunction tz_calculate(a) {\n    var b = new Date(), c = (b.getTimezoneOffset() / 30), d = (b.getTime() / 1000), e = Math.round((((a - d)) / 1800)), f = (Math.round((c + e)) \u0025 48);\n    if ((f == 0)) {\n        return 0;\n    }\n     else if ((f > 24)) {\n        f -= (Math.ceil((f / 48)) * 48);\n    }\n     else if ((f < -28)) {\n        f += (Math.ceil((f / -48)) * 48);\n    }\n    \n;\n    return (f * 30);\n};\nfunction tz_autoset(a, b) {\n    if ((!a || (undefined == b))) {\n        return\n    };\n    if (window.tz_autoset.calculated) {\n        return\n    };\n    window.tz_autoset.calculated = true;\n    var c = -tz_calculate(a);\n    if ((c != b)) {\n        var d = \"/ajax/autoset_timezone_ajax.php\";\n        new AsyncRequest().setURI(d).setData({\n            gmt_off: c\n        }).setErrorHandler(bagofholding).setTransportErrorHandler(bagofholding).setOption(\"suppressErrorAlerts\", true).send();\n    }\n;\n};\n__d(\"TypingDetector\", [\"event-extensions\",\"function-extensions\",\"ArbiterMixin\",\"Class\",\"Input\",\"Run\",\"copyProperties\",\"createObjectFrom\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"Class\"), i = b(\"Input\"), j = b(\"Run\"), k = b(\"copyProperties\"), l = b(\"createObjectFrom\");\n    function m(n) {\n        this._input = n;\n        this._ignoreKeys = {\n        };\n    };\n    m.INACTIVE = 0;\n    m.TYPING = 1;\n    m.QUITTING = 2;\n    k(m.prototype, g, {\n        _timeout: 7000,\n        _currentState: m.INACTIVE,\n        init: function() {\n            this.init = bagofholding;\n            this.reset();\n            Event.listen(this._input, \"keyup\", this._update.bind(this));\n            j.onUnload(this._onunload.bind(this));\n        },\n        reset: function() {\n            clearTimeout(this._checkTimer);\n            this._checkTimer = null;\n            this._lastKeystrokeAt = null;\n            this._currentState = m.INACTIVE;\n        },\n        setIgnoreKeys: function(n) {\n            this._ignoreKeys = l(n);\n        },\n        _onunload: function() {\n            if ((this._currentState == m.TYPING)) {\n                this._transition(m.QUITTING);\n            };\n        },\n        _update: function(event) {\n            var n = Event.getKeyCode(event), o = this._currentState;\n            if (!this._ignoreKeys[n]) {\n                if ((i.getValue(this._input).trim().length === 0)) {\n                    if ((o == m.TYPING)) {\n                        this._transition(m.INACTIVE);\n                    };\n                }\n                 else if ((o == m.TYPING)) {\n                    this._recordKeystroke();\n                }\n                 else if ((o == m.INACTIVE)) {\n                    this._transition(m.TYPING);\n                    this._recordKeystroke();\n                }\n                \n                \n            \n            };\n        },\n        _transition: function(n) {\n            this.reset();\n            this._currentState = n;\n            this.inform(\"change\", n);\n        },\n        _recordKeystroke: function() {\n            this._lastKeystrokeTime = Date.now();\n            if (!this._checkTimer) {\n                this._checkTimer = this._checkTyping.bind(this).defer(this._timeout);\n            };\n        },\n        _checkTyping: function() {\n            var n = (this._lastKeystrokeTime + this._timeout), o = Date.now();\n            if ((o > n)) {\n                this._transition(m.INACTIVE);\n            }\n             else {\n                clearTimeout(this._checkTimer);\n                this._checkTimer = this._checkTyping.bind(this).defer(((n - o) + 10));\n            }\n        ;\n        }\n    });\n    e.exports = m;\n});\n__d(\"MentionsInputMatchers\", [], function(a, b, c, d, e, f) {\n    var g = [\"@\",\"\\\\uff20\",\"+\",\"\\\\uff0b\",].join(\"\"), h = \".,*?$|#{}()\\\\^\\\\-\\\\[\\\\]\\\\\\\\/!\u0025&'\\\"~=\\u003C\\u003E_:;\", i = ((\"\\\\b[A-Z][^ A-Z\" + h) + \"]\"), j = (((((((\"([^\" + g) + h) + \"]|[\") + h) + \"][^ \") + h) + \"])\"), k = ((((\"(?:^|\\\\s)(?:[\" + g) + \"](\") + j) + \"{0,20}))\"), l = ((((\"(?:(?:\" + i) + \"+)|\") + k) + \")\"), m = ((\"(?:\" + i) + \"{4,})\"), n = {\n        trigger: new RegExp(((\"[\" + g) + \"]$\")),\n        mainMatcher: new RegExp((k + \"$\")),\n        autoMatcher: new RegExp((l + \"$\")),\n        userMatcher: new RegExp((m + \"$\"))\n    };\n    e.exports = n;\n});\n__d(\"MentionsInput\", [\"event-extensions\",\"function-extensions\",\"Arbiter\",\"ArbiterMixin\",\"Class\",\"CSS\",\"DataStore\",\"DOM\",\"HTML\",\"Input\",\"InputSelection\",\"Parent\",\"htmlize\",\"Style\",\"Typeahead\",\"TypeaheadUtil\",\"UserAgent\",\"copyProperties\",\"MentionsInputMatchers\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"Class\"), j = b(\"CSS\"), k = b(\"DataStore\"), l = b(\"DOM\"), m = b(\"HTML\"), n = b(\"Input\"), o = b(\"InputSelection\"), p = b(\"Parent\"), q = b(\"htmlize\"), r = b(\"Style\"), s = b(\"Typeahead\"), t = b(\"TypeaheadUtil\"), u = b(\"UserAgent\"), v = b(\"copyProperties\"), w = b(\"MentionsInputMatchers\");\n    function x(y, z, aa, ba, ca, da) {\n        k.set(y, \"MentionsInput\", this);\n        this._root = y;\n        this._typeahead = z;\n        this._input = aa;\n        var ea = false;\n        try {\n            ea = (document.activeElement === this._input);\n        } catch (fa) {\n        \n        };\n        if (ea) {\n            this.init.bind(this, ba, ca, da).defer();\n        }\n         else var ga = Event.listen(this._input, \"focus\", function() {\n            this.init.bind(this, ba, ca, da).defer();\n            ga.remove();\n        }.bind(this))\n    ;\n    };\n    x.getInstance = function(y) {\n        var z = p.byClass(y, \"uiMentionsInput\");\n        return (z ? k.get(z, \"MentionsInput\") : null);\n    };\n    v(x.prototype, h, {\n        init: function(y, z, aa) {\n            this.init = Function.prototype;\n            this._initialized = true;\n            this._highlighter = l.find(this._root, \".highlighter\");\n            this._highlighterInner = this._highlighter.firstChild;\n            this._highlighterContent = l.find(this._root, \".highlighterContent\");\n            this._hiddenInput = l.find(this._root, \".mentionsHidden\");\n            this._placeholder = (this._input.getAttribute(\"placeholder\") || \"\");\n            this._maxMentions = (y.max || 6);\n            this._metrics = aa;\n            if ((u.firefox() < 4)) {\n                this._input.blur();\n                setTimeout(function() {\n                    this._input.focus();\n                }.bind(this));\n            }\n        ;\n            if (!this._hiddenInput.name) {\n                var ba = this._input.name;\n                this._input.name = (ba + \"_text\");\n                this._hiddenInput.name = ba;\n            }\n        ;\n            this._initEvents();\n            this._initTypeahead();\n            this.reset(z);\n            this.inform(\"init\", null, g.BEHAVIOR_STATE);\n        },\n        reset: function(y) {\n            if (!this._initialized) {\n                return\n            };\n            this._mentioned = {\n            };\n            this._orderedUIDs = [];\n            this._numMentioned = 0;\n            this._filterData = null;\n            (this._hiddenInput && (this._hiddenInput.value = \"\"));\n            (this._highlighterContent && l.empty(this._highlighterContent));\n            (this._highlighterAuxContent && l.remove(this._highlighterAuxContent));\n            this._highlighterAuxContent = null;\n            n.setPlaceholder(this._input, this._placeholder);\n            r.set(this._typeahead.getElement(), \"height\", \"auto\");\n            if (y) {\n                n.setValue(this._input, y.flattened);\n                for (var z in y.mention_data) {\n                    this._addToken({\n                        uid: z,\n                        text: y.mention_data[z],\n                        type: \"unknown\"\n                    });;\n                };\n            }\n        ;\n            this._updateTypeahead();\n            this._updateWidth();\n            this._update();\n        },\n        getValue: function() {\n            return n.getValue(this._input);\n        },\n        getRawValue: function() {\n            this._update();\n            return n.getValue(this._hiddenInput);\n        },\n        checkValue: function() {\n            var y = this._typeahead.getCore().getValue();\n            if ((w.trigger.exec(y) || (y === \"\"))) {\n                this.inform(\"sessionEnd\", {\n                });\n            };\n        },\n        getTypeahead: function() {\n            return this._typeahead;\n        },\n        _initEvents: function() {\n            var y = this._update.bind(this);\n            Event.listen(this._input, {\n                input: y,\n                keyup: y,\n                change: y,\n                blur: this._handleBlur.bind(this),\n                focus: this._handleFocus.bind(this)\n            });\n            if (this._metrics) {\n                this._metrics._reset();\n                this._metrics.bindSessionStart(this._typeahead, \"render\", true);\n                this._metrics.bindSessionEnd(this._typeahead.getView(), \"select\", true);\n                this._metrics.bindSessionEnd(this, \"sessionEnd\", false);\n                Event.listen(this._input, \"keyup\", function(event) {\n                    this.checkValue.bind(this).defer();\n                }.bind(this));\n            }\n        ;\n        },\n        _initTypeahead: function() {\n            this._typeahead.subscribe(\"select\", function(ca, da) {\n                var ea = da.selected;\n                this._addToken({\n                    uid: ea.uid,\n                    text: ea.text,\n                    type: ea.type\n                });\n                this.updateValue();\n            }.bind(this));\n            var y = this._input, z = null, aa = function() {\n                if ((z === null)) {\n                    z = n.getSubmitOnEnter(y);\n                    n.setSubmitOnEnter(y, false);\n                }\n            ;\n            }, ba = function() {\n                if ((z !== null)) {\n                    n.setSubmitOnEnter(y, z);\n                    z = null;\n                }\n            ;\n            };\n            this._typeahead.subscribe(\"render\", aa);\n            this._typeahead.subscribe(\"reset\", ba);\n            this._typeahead.subscribe(\"highlight\", function(ca, da) {\n                ((da.index >= 0) ? aa() : ba());\n            });\n            this._typeahead.subscribe(\"query\", function() {\n                this._filterData = null;\n            }.bind(this));\n            this._typeahead.getCore().suffix = \"\";\n            this._handleFocus();\n        },\n        _handleBlur: function() {\n            if (this._filterToken) {\n                this._filterToken.remove();\n                this._filterToken = null;\n            }\n        ;\n        },\n        _handleFocus: function() {\n            if (!this._filterToken) {\n                this._filterToken = this._typeahead.getData().addFilter(this._filterResults.bind(this));\n            };\n            this._updateWidth();\n        },\n        _filterResults: function(y) {\n            if ((this._filterData === null)) {\n                var z = (o.get(this._input).start || 0);\n                for (var aa = 0; (aa < this._offsets.length); aa++) {\n                    var ba = this._offsets[aa];\n                    if (((z > ba[0]) && (z <= ba[1]))) {\n                        this._filterData = {\n                            caretIsInsideMention: true\n                        };\n                        return false;\n                    }\n                ;\n                };\n                var ca = this._typeahead.getCore();\n                this._filterData = {\n                    value: ca.getValue(),\n                    rawValue: ca.getRawValue()\n                };\n            }\n        ;\n            if (this._filterData.caretIsInsideMention) {\n                return false\n            };\n            if (w.mainMatcher.test(this._filterData.rawValue)) {\n                return true\n            };\n            if ((y.type != \"user\")) {\n                return false\n            };\n            if (w.userMatcher.test(this._filterData.value)) {\n                return true\n            };\n            return t.isExactMatch(this._filterData.value, this._typeahead.getData().getTextToIndex(y));\n        },\n        _addToken: function(y) {\n            var z = y.uid;\n            if (!this._mentioned.hasOwnProperty(z)) {\n                this._mentioned[z] = y;\n                this._orderedUIDs.push(z);\n                this._numMentioned++;\n                this._updateTypeahead();\n            }\n        ;\n        },\n        _removeToken: function(y) {\n            if (this._mentioned.hasOwnProperty(y)) {\n                delete this._mentioned[y];\n                this._orderedUIDs.remove(y);\n                this._numMentioned--;\n                this._updateTypeahead();\n            }\n        ;\n        },\n        _reduceToken: function(y, z) {\n            var aa = z.split(\" \"), ba = [];\n            for (var ca = 0; (ca < aa.length); ca++) {\n                if ((y.indexOf(aa[ca]) != -1)) {\n                    ba.push(aa[ca]);\n                };\n            };\n            aa = ba;\n            for (ca = 1; (ca < aa.length); ca++) {\n                for (var da = 1; (da < (aa[(ca - 1)].length + 1)); da++) {\n                    if ((y.indexOf((aa[(ca - 1)].substr(0, da) + aa[ca])) != -1)) {\n                        aa.splice((ca - 1), 1);\n                    };\n                };\n            };\n            while ((y.indexOf(aa.join(\" \")) == -1)) {\n                aa.splice(0, 1);;\n            };\n            return aa.join(\" \");\n        },\n        _update: function() {\n            var y = this.getValue();\n            if ((y == this._value)) {\n                return\n            };\n            this._updateTokens();\n            this.updateValue();\n            this._updateDirection();\n        },\n        _updateTokens: function() {\n            var y = this.getValue(), z = false;\n            for (var aa = 0; (aa < this._orderedUIDs.length); ++aa) {\n                var ba = this._orderedUIDs[aa], ca = this._mentioned[ba], da = ca.text, ea;\n                if (((ca.type == \"user\") && ((ea = this._reduceToken(y, da)) !== \"\"))) {\n                    if (((ea == da.substring(0, da.lastIndexOf(\" \"))) && (y == this._value.substring(0, (this._value.length - 1))))) {\n                        y = y.substring(0, y.lastIndexOf(\" \"));\n                        z = true;\n                    }\n                ;\n                    ca.text = ea;\n                }\n                 else if (((!da || (y.indexOf(da) == -1)) || (typeof da !== \"string\"))) {\n                    this._removeToken(ba);\n                }\n            ;\n            };\n            this._value = y;\n            if (z) {\n                n.setValue(this._input, y);\n            };\n        },\n        updateValue: function() {\n            var y = this.getValue(), z = this._orderedUIDs, aa = [], ba, ca, da, ea;\n            for (ea = 0; (ea < z.length); ++ea) {\n                ca = this._mentioned[z[ea]].text;\n                y = y.replace(ca, function(fa, ga) {\n                    aa.push([ga,(ga + ca.length),]);\n                    return ca;\n                });\n            };\n            for (ea = 0; (ea < z.length); ++ea) {\n                da = z[ea];\n                ca = this._mentioned[da].text;\n                y = y.replace(ca, ((\"@[\" + da) + \":]\"));\n            };\n            ba = q(y);\n            for (ea = 0; (ea < z.length); ++ea) {\n                da = z[ea];\n                ca = this._mentioned[da].text;\n                ba = ba.replace(((\"@[\" + da) + \":]\"), ((\"\\u003Cb\\u003E\" + q(ca)) + \"\\u003C/b\\u003E\"));\n                ca = ca.replace(/[\\\\\\]:]/g, function(fa) {\n                    return (\"\\\\\" + fa);\n                });\n                y = y.replace(((\"@[\" + da) + \":]\"), ((((\"@[\" + da) + \":\") + ca) + \"]\"));\n            };\n            if (u.ie()) {\n                ba = ba.replace(/ {2}/g, \"&nbsp;\\u003Cwbr /\\u003E&nbsp;\\u003Cwbr /\\u003E\");\n                ba = ba.replace(/ (?=[^\\/]|\\/[^>])/g, \"&nbsp;\\u003Cwbr /\\u003E\");\n            }\n        ;\n            this._offsets = aa;\n            this._hiddenInput.value = y;\n            l.setContent(this._highlighterContent, m(ba));\n            this._updateHighlighter();\n            this._updateHeight();\n        },\n        _updateDirection: function() {\n            var y = r.get(this._input, \"direction\");\n            if ((y == this._dir)) {\n                return\n            };\n            this._dir = y;\n            r.set(this._highlighter, \"direction\", y);\n            if ((y == \"rtl\")) {\n                r.set(this._highlighter, \"text-align\", \"right\");\n            }\n             else r.set(this._highlighter, \"text-align\", \"left\");\n        ;\n        },\n        _updateWidth: function() {\n            var y = r.getFloat.curry(this._input), z = ((((this._input.offsetWidth - y(\"paddingLeft\")) - y(\"paddingRight\")) - y(\"borderLeftWidth\")) - y(\"borderRightWidth\"));\n            if (u.firefox()) {\n                z -= 2;\n            };\n            if ((u.ie() <= 7)) {\n                z -= r.getFloat(this._highlighterInner, \"paddingLeft\");\n                this._highlighter.style.zoom = 1;\n            }\n        ;\n            this._highlighterInner.style.width = (Math.max(z, 0) + \"px\");\n        },\n        _updateHeight: function() {\n            if (this._highlighterAuxContent) {\n                var y = this._highlighter.offsetHeight, z = this._typeahead.getElement();\n                if ((y > z.offsetHeight)) {\n                    r.set(z, \"height\", (y + \"px\"));\n                    g.inform(\"reflow\");\n                }\n            ;\n            }\n        ;\n        },\n        _updateTypeahead: function() {\n            var y = this._typeahead.getCore(), z = null;\n            if ((!this._maxMentions || (this._numMentioned < this._maxMentions))) {\n                z = w.autoMatcher;\n            };\n            y.matcher = z;\n            y.setExclusions(this._orderedUIDs);\n            this.inform(\"update\", {\n                mentioned: this._mentioned\n            });\n        },\n        setPlaceholder: function(y) {\n            this._placeholder = y;\n            if (!this.hasAuxContent()) {\n                n.setPlaceholder(this._input, y);\n            };\n        },\n        _updateHighlighter: function() {\n            if (this._highlighterContent) {\n                j.conditionShow(this._highlighterContent, ((this._numMentioned > 0) || this.hasAuxContent()));\n            };\n        },\n        setAuxContent: function(y) {\n            if (this._highlighterContent) {\n                if (!this._highlighterAuxContent) {\n                    this._highlighterAuxContent = l.create(\"span\", {\n                        className: \"highlighterAuxContent\"\n                    });\n                    l.insertAfter(this._highlighterContent, this._highlighterAuxContent);\n                }\n            ;\n                l.setContent(this._highlighterAuxContent, y);\n                if (y) {\n                    n.setPlaceholder(this._input, \"\");\n                }\n                 else n.setPlaceholder(this._input, this._placeholder);\n            ;\n                this._updateHighlighter();\n                this._updateHeight();\n            }\n        ;\n        },\n        hasAuxContent: function() {\n            var y = this.getAuxContentRoot();\n            return (y && (y.innerHTML.length > 0));\n        },\n        getAuxContentRoot: function() {\n            return this._highlighterAuxContent;\n        },\n        addMention: function(y) {\n            var z = this.getValue();\n            n.setValue(this._input, ((z + \" \") + y.text));\n            this._addToken(y);\n            this._update();\n        },\n        getMentions: function() {\n            return this._mentioned;\n        }\n    });\n    e.exports = x;\n});\n__d(\"OptimisticUFI\", [\"event-extensions\",\"Arbiter\",\"AsyncRequest\",\"AsyncResponse\",\"CommentPrelude\",\"CSS\",\"DOM\",\"Form\",\"HTML\",\"Input\",\"MentionsInput\",\"Parent\",\"htmlize\",\"XHPTemplate\",\"randomInt\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"AsyncResponse\"), j = b(\"CommentPrelude\"), k = b(\"CSS\"), l = b(\"DOM\"), m = b(\"Form\"), n = b(\"HTML\"), o = b(\"Input\"), p = b(\"MentionsInput\"), q = b(\"Parent\"), r = b(\"htmlize\"), s = b(\"XHPTemplate\"), t = b(\"randomInt\"), u = {\n        _commentSeqNo: 0,\n        init: function(v) {\n            this._commentTemplate = v;\n            if (!this._loaded) {\n                Event.listen(document.documentElement, \"click\", this._clickHandler.bind(this), Event.Priority.URGENT);\n                this._loaded = true;\n            }\n        ;\n        },\n        _clickHandler: function(event) {\n            var v = event.getTarget(), w = (((v.name == \"comment\") && v.parentNode) && q.byClass(v, \"optimistic_submit\"));\n            if (!w) {\n                return true\n            };\n            var x = v.form, y = l.scry(x, \"textarea\")[0];\n            if (o.isEmpty(y)) {\n                return true\n            };\n            j.uncollapse(x);\n            var z, aa, ba = l.scry(v, \"^.commentList li.uiUfiAddComment\")[0];\n            if (!ba) {\n                z = this._commentTemplate.render();\n                aa = s.getNode(z, \"text\");\n                l.setContent(aa, n(r(y.value.trim())));\n            }\n        ;\n            var ca = l.scry(x, \"ul.commentList\")[0];\n            if (!ca) {\n                return true\n            };\n            var da;\n            if (ba) {\n                da = ba.previousSibling;\n                k.show(da);\n                k.hide(ba);\n            }\n             else {\n                k.show(ca.parentNode);\n                ca.appendChild(z);\n                da = ca.lastChild;\n            }\n        ;\n            var ea = t(0, 4294967295);\n            da.id = (((\"optimistic_comment_\" + ea) + \"_\") + this._commentSeqNo++);\n            var fa = m.serialize(x);\n            fa.comment_replace = da.id;\n            fa.comment = 1;\n            function ga() {\n                new h(m.getAttribute(x, \"action\")).setData(fa).setRelativeTo(x).setErrorHandler(function(ia) {\n                    k.addClass(da, \"uiUfiCommentFailed\");\n                    i.defaultErrorHandler(ia);\n                }).setServerDialogCancelHandler(function() {\n                    l.remove(da);\n                }).send();\n            };\n            if (!ba) {\n                Event.listen(s.getNode(z, \"retry_link\"), \"click\", ga);\n            };\n            ga();\n            y.value = y.style.height = \"\";\n            y.focus();\n            var ha = p.getInstance(y);\n            (ha && ha.reset());\n            if (ba) {\n                l.remove(ba);\n            }\n             else g.inform(\"ufi/comment\", {\n                form: x\n            });\n        ;\n            return false;\n        }\n    };\n    e.exports = u;\n});\n__d(\"UFIUpdate\", [\"CommentPrelude\",\"CSS\",\"DOM\",\"DOMQuery\",\"HTML\",\"MentionsInput\",\"Parent\",\"ScrollableArea\",\"ScrollAwareDOM\",], function(a, b, c, d, e, f) {\n    var g = b(\"CommentPrelude\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"DOMQuery\"), k = b(\"HTML\"), l = b(\"MentionsInput\"), m = b(\"Parent\"), n = b(\"ScrollableArea\"), o = b(\"ScrollAwareDOM\"), p = {\n        expandFeedback: function(q, r, s) {\n            i.scry(q, r).forEach(function(t) {\n                g.expand(t, s);\n            });\n        },\n        uncollapseFeedback: function(q) {\n            g.uncollapse(m.byTag(i.find(q, \".fbUfi\"), \"form\"));\n        },\n        multiContentReplaceGlobal: function(q, r) {\n            this.multiContentReplace(document.documentElement, q, r);\n        },\n        multiContentReplace: function(q, r, s) {\n            s = ((s instanceof k) ? s.getRootNode() : s);\n            i.scry(q, r).forEach(function(t) {\n                o.replace(t, s.cloneNode(true));\n            });\n        },\n        refocusCommentBox: function(q, r) {\n            var s = i.find(q, \"textarea\");\n            s.value = s.style.height = \"\";\n            if (r) {\n                s.blur();\n                s.focus.defer();\n            }\n             else document.documentElement.onfocusin({\n                target: s\n            });\n        ;\n        },\n        resetMentionsInput: function(q) {\n            var r = l.getInstance(i.find(q, \"div.uiMentionsInput\"));\n            (r && r.reset());\n        },\n        insertAtBottom: function(q, r, s, t) {\n            var u = i.scry(q, (\".comment_\" + s)).length;\n            if (r) {\n                u += i.scry(q, (\"#\" + r)).length;\n            };\n            if (!u) {\n                var v = i.find(q, \".commentList\"), w = n.getInstance(v), x = (w && w.isScrolledToBottom());\n                o.appendContent(v, t);\n                (x && w.scrollToBottom(false));\n            }\n        ;\n        },\n        updateUnsubscribeLink: function(q, r) {\n            var s = i.scry(q, \".unsub_link\")[0];\n            if (s) {\n                i.replace(s, r);\n            }\n             else if (r) {\n                i.insertAfter(i.find(q, \".comment_link\"), [\" \\u00b7 \",r,]);\n            }\n        ;\n        },\n        updateSeenCount: function(q) {\n            j.scry(q, \".uiUfiSeenBar\").forEach(function(t) {\n                h.hide(t);\n            });\n            j.scry(q, \".uiUfiViewSeenCount\").forEach(function(t) {\n                h.hide(t);\n            });\n            var r = j.scry(q, \".uiUfiLike\")[0];\n            if ((r && (r.childNodes.length === 0))) {\n                r = null;\n            };\n            r = (r || j.scry(q, \".uiUfiSeenBar\")[0]);\n            if (!r) {\n                return\n            };\n            var s = j.scry(r, \".uiUfiViewSeenCount\")[0];\n            if (!s) {\n                return\n            };\n            h.show(s);\n            h.show(r);\n        }\n    };\n    e.exports = p;\n});\nfunction ufi_add_ft_hidden_node(a) {\n    if (a.link_data) {\n        return\n    };\n    var b = collect_data_attribs(a, [\"ft\",]).ft;\n    if (Object.keys(b).length) {\n        var c = DOM.create(\"input\", {\n            type: \"hidden\",\n            name: \"link_data\",\n            value: JSON.stringify(b)\n        });\n        a.appendChild(c);\n    }\n;\n};\nfunction ufi_add_all_link_data() {\n    Bootloader.loadComponents(\"dom-collect\", function() {\n        DOM.scry(document.body, \"form.commentable_item\").forEach(ufi_add_ft_hidden_node);\n    });\n};\nfunction question_add_all_link_data() {\n    Bootloader.loadComponents(\"dom-collect\", function() {\n        DOM.scry(document.body, \"form.fbEigenpollForm\").forEach(ufi_add_ft_hidden_node);\n        DOM.scry(document.body, \"form.fbQuestionPollForm\").forEach(ufi_add_ft_hidden_node);\n    });\n};\n__d(\"legacy:UIPagelet\", [\"UIPagelet\",], function(a, b, c, d) {\n    a.UIPagelet = b(\"UIPagelet\");\n}, 3);\n__d(\"Scrollable\", [\"event-extensions\",\"Parent\",\"UserAgent\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Parent\"), h = b(\"UserAgent\"), i = function(event) {\n        var k = g.byClass(event.getTarget(), \"scrollable\");\n        if (!k) {\n            return\n        };\n        if (((((typeof event.axis !== \"undefined\") && (event.axis === event.HORIZONTAL_AXIS))) || ((event.wheelDeltaX && !event.wheelDeltaY)))) {\n            return\n        };\n        var l = (event.wheelDelta ? event.wheelDelta : -event.detail), m = k.scrollHeight, n = k.clientHeight;\n        if ((m > n)) {\n            var o = k.scrollTop;\n            if (((((l > 0) && (o === 0))) || (((l < 0) && (o >= (m - n)))))) {\n                event.prevent();\n            }\n             else if ((h.ie() < 9)) {\n                if (k.currentStyle) {\n                    var p = k.currentStyle.fontSize;\n                    if ((p.indexOf(\"px\") < 0)) {\n                        var q = document.createElement(\"div\");\n                        q.style.fontSize = p;\n                        q.style.height = \"1em\";\n                        p = q.style.pixelHeight;\n                    }\n                     else p = parseInt(p, 10);\n                ;\n                    k.scrollTop = (o - Math.round(((l / 120) * p)));\n                    event.prevent();\n                }\n            \n            }\n        ;\n        }\n    ;\n    }, j = document.documentElement;\n    if (h.firefox()) {\n        j.addEventListener(\"DOMMouseScroll\", i, false);\n    }\n     else Event.listen(j, \"mousewheel\", i);\n;\n});\n__d(\"TinyViewport\", [\"event-extensions\",\"CSS\",\"DOM\",\"debounce\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"debounce\"), j = i(function() {\n        var k = document.documentElement, l = h.getDocumentScrollElement(), m = ((k.clientHeight < 400) || (l.clientWidth < l.scrollWidth));\n        g.conditionClass(k, \"tinyViewport\", m);\n        g.conditionClass(k, \"canHaveFixedElements\", !m);\n    });\n    j();\n    Event.listen(window, \"resize\", j);\n});\n__d(\"legacy:Toggler\", [\"Toggler\",], function(a, b, c, d) {\n    a.Toggler = b(\"Toggler\");\n}, 3);\n__d(\"legacy:Button\", [\"Button\",], function(a, b, c, d) {\n    a.Button = b(\"Button\");\n}, 3);\n__d(\"ButtonGroup\", [\"function-extensions\",\"copyProperties\",\"createArrayFrom\",\"CSS\",\"DataStore\",\"Parent\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"copyProperties\"), h = b(\"createArrayFrom\"), i = b(\"CSS\"), j = b(\"DataStore\"), k = b(\"Parent\"), l = \"firstItem\", m = \"lastItem\";\n    function n(s, t) {\n        var u = k.byClass(s, t);\n        if (!u) {\n            throw new Error(\"invalid use case\")\n        };\n        return u;\n    };\n    function o(s) {\n        return (i.shown(s) && h(s.childNodes).some(i.shown));\n    };\n    function p(s) {\n        var t, u, v;\n        h(s.childNodes).forEach(function(w) {\n            v = o(w);\n            i.removeClass(w, l);\n            i.removeClass(w, m);\n            i.conditionShow(w, v);\n            if (v) {\n                t = (t || w);\n                u = w;\n            }\n        ;\n        });\n        (t && i.addClass(t, l));\n        (u && i.addClass(u, m));\n        i.conditionShow(s, t);\n    };\n    function q(s, t) {\n        var u = n(t, \"uiButtonGroupItem\");\n        s(u);\n        p(u.parentNode);\n    };\n    function r(s) {\n        this._root = n(s, \"uiButtonGroup\");\n        j.set(this._root, \"ButtonGroup\", this);\n        p(this._root);\n    };\n    r.getInstance = function(s) {\n        var t = n(s, \"uiButtonGroup\"), u = j.get(t, \"ButtonGroup\");\n        return (u || new r(t));\n    };\n    g(r.prototype, {\n        hideItem: q.curry(i.hide),\n        showItem: q.curry(i.show),\n        toggleItem: q.curry(i.toggle)\n    });\n    e.exports = r;\n});\n__d(\"legacy:MentionsInput\", [\"MentionsInput\",], function(a, b, c, d) {\n    a.MentionsInput = b(\"MentionsInput\");\n}, 3);\n__d(\"FormDisableOnSubmit\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\");\n    function h(i) {\n        this._form = i;\n    };\n    g(h.prototype, {\n        _subscription: null,\n        _disabled: false,\n        enable: function() {\n            this._subscription = this._form.subscribe([\"submit\",\"reset\",], this._handle.bind(this));\n        },\n        disable: function() {\n            this._form.unsubscribe(this._subscription);\n            this._subscription = null;\n        },\n        _handle: function(i, j) {\n            if ((i == \"submit\")) {\n                if (this._disabled) {\n                    return false\n                };\n                this._disabled = true;\n                return true;\n            }\n        ;\n            this._disabled = false;\n        }\n    });\n    e.exports = h;\n});\n__d(\"FormSubmitOnChange\", [\"event-extensions\",\"copyProperties\",\"submitForm\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"copyProperties\"), h = b(\"submitForm\");\n    function i(j) {\n        this._form = j;\n    };\n    g(i.prototype, {\n        _listener: null,\n        enable: function() {\n            this._listener = Event.listen(this._form.getRoot(), \"change\", this._submit.bind(this));\n        },\n        disable: function() {\n            this._listener.remove();\n            this._listener = null;\n        },\n        _submit: function() {\n            h(this._form.getRoot());\n        }\n    });\n    e.exports = i;\n});\n__d(\"UIForm\", [\"event-extensions\",\"ArbiterMixin\",\"BehaviorsMixin\",\"Class\",\"DOM\",\"Form\",\"FormDisableOnSubmit\",\"FormSubmitOnChange\",\"Run\",\"areObjectsEqual\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"BehaviorsMixin\"), i = b(\"Class\"), j = b(\"DOM\"), k = b(\"Form\"), l = b(\"FormDisableOnSubmit\"), m = b(\"FormSubmitOnChange\"), n = b(\"Run\"), o = b(\"areObjectsEqual\"), p = b(\"copyProperties\");\n    function q(r, s, t, u) {\n        this._root = r;\n        this.controller = r;\n        this._message = s;\n        n.onAfterLoad(function() {\n            this._originalState = k.serialize(this._root);\n        }.bind(this));\n        this._forceDirty = t;\n        this._submitted = false;\n        Event.listen(this._root, \"submit\", this._handleSubmit.bind(this));\n        if ((u && u.length)) {\n            this.enableBehaviors(u);\n        };\n        var v = true;\n        n.onBeforeUnload(this.checkUnsaved.bind(this), v);\n    };\n    p(q.prototype, g, h, {\n        getRoot: function() {\n            return this._root;\n        },\n        _handleSubmit: function() {\n            if ((this.inform(\"submit\") === false)) {\n                return false\n            };\n            this._submitted = true;\n            return true;\n        },\n        reset: function() {\n            this.inform(\"reset\");\n            this._submitted = false;\n        },\n        isDirty: function() {\n            if ((this._submitted || !j.contains(document.body, this._root))) {\n                return false\n            };\n            if (this._forceDirty) {\n                return true\n            };\n            var r = k.serialize(this._root);\n            return !o(r, this._originalState);\n        },\n        checkUnsaved: function() {\n            if (this.isDirty()) {\n                return this._message\n            };\n            return null;\n        }\n    });\n    e.exports = (a.UIForm || q);\n});\n__d(\"legacy:ScrollableArea\", [\"ScrollableArea\",], function(a, b, c, d) {\n    a.ScrollableArea = b(\"ScrollableArea\");\n}, 3);\n__d(\"TooltipLink\", [\"Parent\",\"Tooltip\",], function(a, b, c, d, e, f) {\n    var g = b(\"Parent\"), h = b(\"Tooltip\"), i = {\n        setTooltipText: function(j, k) {\n            j = g.byTag(j, \"a\");\n            (j && h.set(j, k));\n        }\n    };\n    e.exports = i;\n});\n__d(\"SubMenu\", [\"event-extensions\",\"Arbiter\",\"copyProperties\",\"CSS\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"copyProperties\"), i = b(\"CSS\");\n    function j() {\n    \n    };\n    h(j.prototype, {\n        _subMenu: null,\n        _mainMenu: null,\n        _forward: null,\n        _backward: null,\n        init: function(k, l, m, n) {\n            this._subMenu = k;\n            this._mainMenu = l;\n            this._forward = m;\n            this._backward = n;\n            g.subscribe(\"SubMenu/Reset\", this._goToMainMenu.bind(this));\n            Event.listen(m, \"click\", this._goToSubMenu.bind(this));\n            Event.listen(n, \"click\", this._goToMainMenu.bind(this));\n        },\n        initAsyncChildMenu: function(k) {\n            Event.listen(this._forward, \"click\", function() {\n                this._goToSubMenu();\n                k.load();\n            }.bind(this));\n        },\n        _goToMainMenu: function() {\n            i.hide(this._subMenu);\n            i.show(this._mainMenu);\n        },\n        _goToSubMenu: function() {\n            i.hide(this._mainMenu);\n            i.show(this._subMenu);\n        }\n    });\n    e.exports = j;\n});\n__d(\"legacy:ui-submenu\", [\"SubMenu\",], function(a, b, c, d) {\n    a.SubMenu = b(\"SubMenu\");\n}, 3);\n__d(\"AsyncMenu\", [\"AsyncRequest\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncRequest\"), h = b(\"copyProperties\");\n    function i() {\n    \n    };\n    h(i.prototype, {\n        _uri: null,\n        _elem: null,\n        init: function(j, k) {\n            this._uri = j;\n            this._elem = k;\n        },\n        load: function() {\n            this.load = bagofholding;\n            g.bootstrap(this._uri, this._elem);\n        }\n    });\n    e.exports = i;\n});\n__d(\"legacy:ui-asyncmenu\", [\"AsyncMenu\",], function(a, b, c, d) {\n    a.AsyncMenu = b(\"AsyncMenu\");\n}, 3);\nfunction FutureSideNav() {\n    (FutureSideNav.instance && FutureSideNav.instance.uninstall());\n    FutureSideNav.instance = this;\n};\nFutureSideNav.instance = null;\nFutureSideNav.getInstance = function() {\n    return (FutureSideNav.instance || new FutureSideNav());\n};\ncopyProperties(FutureSideNav.prototype, {\n    init: function(a, b, c) {\n        this.root = a;\n        this.items = {\n        };\n        this.sections = {\n        };\n        this.editor = null;\n        this.editing = false;\n        this.selected = null;\n        this.loading = null;\n        this.keyParam = \"sk\";\n        this.defaultKey = b;\n        this.uri = URI.getRequestURI();\n        this.ajaxPipe = c;\n        this.ajaxPipeEndpoints = {\n        };\n        this.sidecol = true;\n        this._installed = true;\n        this._handlePageTransitions = true;\n        PageTransitions.registerHandler(function(d) {\n            return (this._handlePageTransitions && this.handlePageTransition(d));\n        }.bind(this));\n        this._eventHandlers = [];\n        this._arbiterSubscriptions = [Arbiter.subscribe(NavigationMessage.NAVIGATION_COMPLETED, this.navigationComplete.bind(this)),Arbiter.subscribe(NavigationMessage.NAVIGATION_FAILED, this.navigationFailed.bind(this)),Arbiter.subscribe(NavigationMessage.NAVIGATION_COUNT_UPDATE, this.navigationCountUpdate.bind(this)),Arbiter.subscribe(NavigationMessage.NAVIGATION_SELECT, this.navigationSelect.bind(this)),Arbiter.subscribe(ChannelConstants.getArbiterType(\"nav_update_counts\"), this.navigationCountUpdateFromPresence.bind(this)),];\n        this._explicitHover = [];\n        this._ensureHover(\"sideNavItem\");\n        this._eventHandlers.push(Event.listen(window, \"resize\", this._handleResize.bind(this)));\n        this._checkNarrow();\n        this._selectorSubscriptions = [];\n        (window.Selector && this._selectorSubscriptions.push(Selector.subscribe([\"open\",\"close\",], function(d, e) {\n            var f = Parent.byClass(e.selector, \"sideNavItem\");\n            (f && CSS.conditionClass(f, \"editMenuOpened\", (d === \"open\")));\n        })));\n        onleaveRegister(this.uninstall.bind(this));\n        if (this._pendingSections) {\n            this._pendingSections.forEach(function(d) {\n                this.initSection.apply(this, d);\n            }.bind(this));\n        };\n    },\n    _handleResize: (function() {\n        var a;\n        return function() {\n            (a && clearTimeout(a));\n            a = this._checkNarrow.bind(this).defer(200);\n        };\n    })(),\n    _checkNarrow: function() {\n        CSS.conditionClass(this.root, \"uiNarrowSideNav\", (Vector2.getElementPosition(this.root).x < 20));\n    },\n    _ensureHover: function(a) {\n        if ((ua.ie() < 8)) {\n            Bootloader.loadComponents(\"explicit-hover\", function() {\n                this._explicitHover.push(new ExplicitHover(this.root, a));\n            }.bind(this));\n        };\n    },\n    uninstall: function() {\n        if (this._installed) {\n            this._installed = false;\n            this._handlePageTransitions = false;\n            this._arbiterSubscriptions.forEach(Arbiter.unsubscribe);\n            this._selectorSubscriptions.forEach(function(a) {\n                Selector.unsubscribe(a);\n            });\n            this._eventHandlers.forEach(function(a) {\n                a.remove();\n            });\n            this._explicitHover.forEach(function(a) {\n                a.uninstall();\n            });\n        }\n    ;\n    },\n    initSection: function(a, b) {\n        if (!this._installed) {\n            this._pendingSections = (this._pendingSections || []);\n            this._pendingSections.push(arguments);\n            return;\n        }\n    ;\n        this._initItems(b);\n        this._initSection(a);\n    },\n    addItem: function(a, b) {\n        this._initItem(a, b);\n    },\n    _initItems: function(a) {\n        var b = function(c, d) {\n            var e = this._initItem(c, d);\n            if (c.children) {\n                c.children.forEach(function(f) {\n                    b(f, e);\n                });\n            };\n        }.bind(this);\n        $A(a).forEach(function(c) {\n            b(c, null);\n        });\n    },\n    _initItem: function(a, b) {\n        var c = this.items[a.id] = this._constructItem(a, b);\n        if ((c.equals(this.selected) || a.selected)) {\n            this.setSelected(c);\n        };\n        var d = c.getLinkNode();\n        (d && this._eventHandlers.push(Event.listen(d, \"click\", function(event) {\n            return !this.editing;\n        }.bind(this))));\n        return c;\n    },\n    _initSection: function(a) {\n        var b = this.sections[a.id] = this._constructSection(a);\n        this._eventHandlers.push(Event.listen(b.node, \"click\", this.handleSectionClick.bind(this, b)));\n        DOM.scry(b.node, \"div.bookmarksMenuButton\").forEach(CSS.show);\n        return b;\n    },\n    _constructItem: function(a, b) {\n        return new FutureSideNavItem(a, b);\n    },\n    _constructSection: function(a) {\n        return new FutureSideNavSection(a);\n    },\n    handleSectionClick: function(a, event) {\n        var b = this._getEventTarget(event, \"a\"), c = this._getItemForNode(b);\n        if (!b) {\n            return;\n        }\n         else if (CSS.hasClass(b.parentNode, \"uiMenuItem\")) {\n            this._handleMenuClick(a, c, b.parentNode, event);\n        }\n         else this._handleLinkClick(a, b, event);\n        \n    ;\n    },\n    _getEventTarget: function(event, a) {\n        var b = event.getTarget();\n        if ((b.tagName !== a.toUpperCase())) {\n            return Parent.byTag(b, a);\n        }\n         else return b\n    ;\n    },\n    _handleMenuClick: function(a, b, c, event) {\n        if (CSS.hasClass(c, \"rearrange\")) {\n            this.beginEdit(a);\n        };\n    },\n    _handleLinkClick: function(a, b, event) {\n        if (CSS.hasClass(b, \"navEditDone\")) {\n            (this.editing ? this.endEdit() : this.beginEdit(a));\n            event.kill();\n        }\n    ;\n    },\n    getItem: function(a) {\n        if (this._isCurrentPath(a)) {\n            return this._getItemForKey((this._getKey(a.getQueryData()) || this.defaultKey));\n        }\n         else return this._getItemForPath(a.getPath())\n    ;\n    },\n    getNodeForKey: function(a) {\n        var b = this._getItemForKey(a);\n        if (b) {\n            return b.node\n        };\n    },\n    _isCurrentPath: function(a) {\n        return ((a.getDomain() === this.uri.getDomain()) && (a.getPath() === this.uri.getPath()));\n    },\n    _getKey: function(a) {\n        return a[this.keyParam];\n    },\n    _getItemForNode: function(a) {\n        a = Parent.byClass(a, \"sideNavItem\");\n        return (a && this.items[a.id]);\n    },\n    _getItemForKey: function(a) {\n        return this._findItem(function(b) {\n            return b.matchKey(a);\n        });\n    },\n    _getItemForPath: function(a) {\n        return this._findItem(function(b) {\n            return b.matchPath(a);\n        });\n    },\n    _findItem: function(a) {\n        for (var b in this.items) {\n            if (a(this.items[b])) {\n                return this.items[b]\n            };\n        };\n    },\n    removeItem: function(a) {\n        if ((a && this.items[a.id])) {\n            DOM.remove(a.node);\n            delete this.items[a.id];\n        }\n    ;\n    },\n    removeItemByKey: function(a) {\n        this.removeItem(this._getItemForKey(a));\n    },\n    moveItem: function(a, b, c) {\n        var d = DOM.find(a.node, \"ul.uiSideNav\");\n        ((c ? DOM.prependContent : DOM.appendContent))(d, b.node);\n    },\n    setLoading: function(a) {\n        (this.loading && this.loading.hideLoading());\n        this.loading = a;\n        (this.loading && this.loading.showLoading());\n    },\n    setSelected: function(a) {\n        this.setLoading(null);\n        if (this.selected) {\n            this.selected.hideSelected();\n            this.selected.getTop().hideChildren();\n        }\n    ;\n        this.selected = a;\n        if (this.selected) {\n            this.selected.showSelected();\n            this.selected.getTop().showChildren();\n        }\n    ;\n    },\n    handlePageTransition: function(a) {\n        var b = this.getItem(a), c = ((b && b.endpoint) && this._doPageTransition(b, a));\n        return c;\n    },\n    _doPageTransition: function(a, b) {\n        this.setLoading(a);\n        this._sendPageTransition(a.endpoint, copyProperties(this._getTransitionData(a, b), b.getQueryData()));\n        return true;\n    },\n    _sendPageTransition: function(a, b) {\n        b.endpoint = a;\n        Arbiter.inform(NavigationMessage.NAVIGATION_BEGIN, {\n            useAjaxPipe: this._useAjaxPipe(a),\n            params: b\n        });\n    },\n    _getTransitionData: function(a, b) {\n        var c = {\n        };\n        c.sidecol = this.sidecol;\n        c.path = b.getPath();\n        c[this.keyParam] = a.textKey;\n        c.key = a.textKey;\n        return c;\n    },\n    _useAjaxPipe: function(a) {\n        return (this.ajaxPipe || this.ajaxPipeEndpoints[a]);\n    },\n    navigationComplete: function() {\n        (this.loading && this.setSelected(this.loading));\n    },\n    navigationFailed: function() {\n        this.setLoading(null);\n    },\n    navigationSelect: function(a, b) {\n        var c = this._getItemForKey(this._getKey(b));\n        if (b.asLoading) {\n            this.setLoading(c);\n        }\n         else this.setSelected(c);\n    ;\n    },\n    navigationCountUpdate: function(a, b) {\n        var c = this._getItemForKey((b && b.key));\n        if (c) {\n            if ((typeof b.count !== \"undefined\")) {\n                c.setCount(b.count, b.hide);\n            }\n             else if ((typeof b.increment !== \"undefined\")) {\n                c.incrementCount(b.increment, b.hide);\n            }\n        \n        };\n    },\n    navigationCountUpdateFromPresence: function(a, b) {\n        b = b.obj;\n        if (b) {\n            if ((!b.class_name || (b.class_name && CSS.hasClass(this.root, b.class_name)))) {\n                if (b.items) {\n                    for (var c = 0; (c < b.items.length); c++) {\n                        this.navigationCountUpdate(a, b.items[c]);;\n                    }\n                }\n            }\n        };\n    },\n    beginEdit: function(a) {\n        if (!this.editing) {\n            this.editing = true;\n            CSS.addClass(this.root, \"editMode\");\n            this._updateTrackingData();\n            Bootloader.loadComponents(\"sortable-side-nav-js\", this._initEditor.bind(this, a));\n        }\n    ;\n    },\n    endEdit: function() {\n        if (this.editing) {\n            CSS.removeClass(this.root, \"editMode\");\n            this.editor.endEdit();\n            this.editor = null;\n            this.editing = false;\n            this._updateTrackingData();\n        }\n    ;\n    },\n    _updateTrackingData: function(a) {\n        var b = (this.root.getAttribute(\"data-gt\") || \"{}\");\n        try {\n            b = JSON.parse(b);\n            if (this.editing) {\n                b.editing = true;\n            }\n             else delete b.editing;\n        ;\n            this.root.setAttribute(\"data-gt\", JSON.stringify(b));\n        } catch (c) {\n        \n        };\n    },\n    _initEditor: function(a) {\n        this.editor = a.getEditor();\n        this.editor.beginEdit();\n    }\n});\nfunction FutureSideNavSection(a) {\n    this.id = a.id;\n    this.node = (this.node || $(a.id));\n    this.editEndpoint = a.editEndpoint;\n};\ncopyProperties(FutureSideNavSection.prototype, {\n    equals: function(a) {\n        return (a && (a.id === this.id));\n    },\n    getEditor: function() {\n        return new SortableSideNav(DOM.find(this.node, \"ul.uiSideNav\"), this.editEndpoint);\n    }\n});\nfunction FutureSideNavItem(a, b) {\n    this.id = a.id;\n    this.up = b;\n    this.endpoint = a.endpoint;\n    this.type = a.type;\n    this.node = (a.node || $(a.id));\n    this.paths = (a.path ? $A(a.path) : []);\n    this.keys = (a.key ? $A(a.key) : []);\n    var c = this._findKeys(this.keys);\n    this.numericKey = (c.numeric || this.keys[0]);\n    this.textKey = (c.text || this.keys[0]);\n    this._pathPattern = this._buildRegex(this.paths);\n    this._keyPattern = this._buildRegex(this.keys);\n    this.hideLoading();\n    this.hideSelected();\n};\ncopyProperties(FutureSideNavItem.prototype, {\n    equals: function(a) {\n        return (a && (a.id === this.id));\n    },\n    getLinkNode: function() {\n        return ((DOM.scry(this.node, \"a.item\")[0] || DOM.scry(this.node, \"a.subitem\")[0]));\n    },\n    matchPath: function(a) {\n        return this._matchInput(this._pathPattern, a);\n    },\n    matchKey: function(a) {\n        return this._matchInput(this._keyPattern, a);\n    },\n    _matchInput: function(a, b) {\n        var c = (a && a.exec(b));\n        return (c && c.slice(1));\n    },\n    getTop: function() {\n        return (this.isTop() ? this : this.up.getTop());\n    },\n    isTop: function(a) {\n        return !this.up;\n    },\n    setCount: function(a, b) {\n        return this._updateCount(a, true);\n    },\n    incrementCount: function(a, b) {\n        return this._updateCount(a, false);\n    },\n    _updateCount: function(a, b, c) {\n        var d = DOM.scry(this.node, \"span.count\")[0], e = (d && DOM.scry(d, \"span.countValue\")[0]);\n        if (e) {\n            var f = (b ? 0 : parseInt(DOM.getText(e), 10)), g = Math.max(0, (f + a)), h = (this.isTop() ? \"hidden\" : \"hiddenSubitem\");\n            DOM.setContent(e, g);\n            (c && CSS.conditionClass(this.node, h, !g));\n            CSS.conditionClass(d, \"hidden_elem\", !g);\n            if (this.isTop()) {\n                var i = DOM.scry(this.node, \"div.linkWrap\")[0];\n                if (i) {\n                    CSS.conditionClass(i, \"noCount\", !g);\n                    CSS.conditionClass(i, \"hasCount\", g);\n                }\n            ;\n            }\n        ;\n        }\n    ;\n        Arbiter.inform(\"NavigationMessage.COUNT_UPDATE_DONE\");\n    },\n    showLoading: function() {\n        CSS.addClass(this.node, \"loading\");\n    },\n    hideLoading: function() {\n        CSS.removeClass(this.node, \"loading\");\n    },\n    showSelected: function() {\n        CSS.addClass(this.node, \"selectedItem\");\n        (CSS.hasClass(this.node, \"hider\") && CSS.addClass(this._getExpanderParent(), \"expandedMode\"));\n    },\n    hideSelected: function() {\n        CSS.removeClass(this.node, \"selectedItem\");\n    },\n    showChildren: function() {\n        CSS.addClass(this.node, \"open\");\n    },\n    hideChildren: function() {\n        CSS.removeClass(this.node, \"open\");\n    },\n    _getExpanderParent: function() {\n        return Parent.byClass(this.node, \"expandableSideNav\");\n    },\n    _buildRegex: function(a) {\n        if (a.length) {\n            var b = a.map(function(c) {\n                if ((typeof c === \"string\")) {\n                    return c.replace(/([^a-z0-9_])/gi, \"\\\\$1\");\n                }\n                 else if ((c && c.regex)) {\n                    return c.regex\n                }\n            ;\n            });\n            return new RegExp(((\"^(?:\" + b.join(\"|\")) + \")$\"));\n        }\n    ;\n    },\n    _findKeys: function(a) {\n        var b = /^(app|group|fl)_/, c = {\n        };\n        for (var d = 0; (d < a.length); d++) {\n            var e = b.test(a[d]);\n            if ((e && !c.numeric)) {\n                c.numeric = a[d];\n            }\n             else if ((!e && !c.text)) {\n                c.text = a[d];\n            }\n        ;\n            if ((c.numeric && c.text)) {\n                break;\n            };\n        };\n        return c;\n    }\n});\n__d(\"legacy:LayerDestroyOnHide\", [\"LayerDestroyOnHide\",], function(a, b, c, d) {\n    a.LayerDestroyOnHide = b(\"LayerDestroyOnHide\");\n}, 3);\n__d(\"legacy:ContextualDialogX\", [\"ContextualDialogX\",], function(a, b, c, d) {\n    a.ContextualDialogX = b(\"ContextualDialogX\");\n}, 3);\n__d(\"legacy:Tooltip\", [\"Tooltip\",], function(a, b, c, d) {\n    a.Tooltip = b(\"Tooltip\");\n}, 3);\n__d(\"ClearableTypeahead\", [\"event-extensions\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = {\n        resetOnCloseButtonClick: function(h, i) {\n            Event.listen(i, \"click\", function() {\n                var j = h.getCore();\n                j.reset();\n                j.getElement().focus();\n            });\n        }\n    };\n    e.exports = g;\n});\n__d(\"TypeaheadAreaCore\", [\"Class\",\"InputSelection\",\"TypeaheadCore\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Class\"), h = b(\"InputSelection\"), i = b(\"TypeaheadCore\"), j = b(\"copyProperties\");\n    function k(l) {\n        this.parent.construct(this, l);\n        this.matcher = new RegExp((this.matcher + \"$\"));\n        this.preventFocusChangeOnTab = true;\n    };\n    g.extend(k, i);\n    j(k.prototype, {\n        prefix: \"\",\n        suffix: \", \",\n        matcher: \"\\\\b[^,]*\",\n        click: bagofholding,\n        select: function(l) {\n            this.parent.select(l);\n            var m = this.element.value, n = ((this.prefix + l.text) + this.suffix);\n            this.expandBounds(m, n);\n            var o = m.substring(0, this.start), p = m.substring(this.end);\n            this.element.value = ((o + n) + p);\n            h.set(this.element, (o.length + n.length));\n        },\n        expandBounds: function(l, m) {\n            l = l.toLowerCase().trim();\n            m = m.toLowerCase();\n            var n, o, p, q, r = /\\s/;\n            o = l.substring(this.start, this.end);\n            p = m.indexOf(o);\n            n = this.start;\n            while (((n >= 0) && (p >= 0))) {\n                q = l.charAt((n - 1));\n                if ((!q || r.test(q))) {\n                    this.start = n;\n                };\n                o = (q + o);\n                p = m.indexOf(o);\n                n--;\n            };\n            o = l.substring(this.start, this.end);\n            p = m.indexOf(o);\n            n = this.end;\n            while (((n <= l.length) && (p >= 0))) {\n                q = l.charAt(n);\n                if ((!q || r.test(q))) {\n                    this.end = n;\n                };\n                o = (o + q);\n                p = m.indexOf(o);\n                n++;\n            };\n        },\n        getRawValue: function() {\n            var l = (h.get(this.element).start || 0);\n            return this.parent.getValue().substring(0, l);\n        },\n        getValue: function() {\n            var l = (this.matcher && this.matcher.exec(this.getRawValue()));\n            if (!l) {\n                return \"\"\n            };\n            var m = l[0], n = (l.index + m.length);\n            m = m.replace(/^\\s/, \"\");\n            var o = m.length;\n            m = m.replace(/\\s$/, \"\");\n            var p = (o - m.length);\n            this.start = (n - o);\n            this.end = (n + p);\n            return (l[1] || l[0]);\n        }\n    });\n    e.exports = k;\n});\n__d(\"TypeaheadMetrics\", [\"event-extensions\",\"AsyncRequest\",\"copyProperties\",\"Typeahead\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"AsyncRequest\"), h = b(\"copyProperties\"), i = b(\"Typeahead\");\n    function j(k) {\n        this.extraData = {\n        };\n        h(this, k);\n    };\n    h(j.prototype, {\n        endPoint: \"/ajax/typeahead/record_basic_metrics.php\",\n        init: function(k) {\n            this.init = bagofholding;\n            this.core = k.getCore();\n            this.view = k.getView();\n            this.data = k.getData();\n            this.stats = {\n            };\n            this.sessionActive = false;\n            this._sessionStartEvents = [];\n            this._sessionEndEvents = [];\n            this._reset();\n            this.initEvents();\n        },\n        _reset: function() {\n            this.stats = {\n            };\n            this.avgStats = {\n            };\n            this.sessionActive = false;\n            this.sid = Math.floor((Date.now() * Math.random()));\n            this.data.setQueryData({\n                sid: this.sid\n            });\n        },\n        recordSelect: function(k) {\n            var l = k.selected;\n            if ((l.uid == null)) {\n                this.recordStat(\"selected_id\", \"SELECT_NULL\");\n            }\n             else this.recordStat(\"selected_id\", l.uid);\n        ;\n            this.recordStat(\"selected_type\", l.type);\n            this.recordStat(\"selected_position\", k.index);\n            this.recordStat(\"selected_with_mouse\", (k.clicked ? 1 : 0));\n            this._sessionEnd();\n        },\n        bindSessionStart: function(k, event, l) {\n            if (l) {\n                for (var m = 0; (m < this._sessionStartEvents.length); ++m) {\n                    var n = this._sessionStartEvents[m];\n                    n.obj.unsubscribe(n.token);\n                }\n            };\n            this._sessionStartEvents.push({\n                obj: k,\n                token: k.subscribe(event, function(o, p) {\n                    this._sessionStart();\n                }.bind(this))\n            });\n        },\n        bindSessionEnd: function(k, event, l) {\n            if (l) {\n                for (var m = 0; (m < this._sessionEndEvents.length); ++m) {\n                    var n = this._sessionEndEvents[m];\n                    n.obj.unsubscribe(n.token);\n                }\n            };\n            this._sessionEndEvents.push({\n                obj: k,\n                token: k.subscribe(event, function(o, p) {\n                    this._sessionEnd();\n                }.bind(this))\n            });\n        },\n        initEvents: function() {\n            this.bindSessionStart(this.core, \"focus\", false);\n            this.bindSessionEnd(this.core, \"blur\", false);\n            this.view.subscribe(\"select\", function(k, l) {\n                this.recordSelect(l);\n            }.bind(this));\n            this.bindSessionEnd(this.view, \"select\", false);\n            this.view.subscribe(\"render\", function(k, l) {\n                this.results = l;\n            }.bind(this));\n            this.data.subscribe(\"beforeQuery\", function(k, l) {\n                if (!l.value) {\n                    return\n                };\n                this.query = l.value;\n                this.recordCountStat(\"num_queries\");\n            }.bind(this));\n            this.data.subscribe(\"beforeFetch\", function(k, l) {\n                if (l.fetch_context.bootstrap) {\n                    this.bootstrapBegin = Date.now();\n                }\n                 else l.fetch_context.queryBegin = Date.now();\n            ;\n            }.bind(this));\n            this.data.subscribe(\"fetchComplete\", function(k, l) {\n                if (l.fetch_context.bootstrap) {\n                    this.recordAvgStat(\"bootstrap_latency\", (Date.now() - this.bootstrapBegin));\n                    var m = {\n                    };\n                    l.response.payload.entries.forEach(function(n) {\n                        if (!m[n.type]) {\n                            m[n.type] = 1;\n                        }\n                         else m[n.type]++;\n                    ;\n                    });\n                    this.recordStat(\"bootstrap_response_types\", m);\n                    this.bootstrapped = true;\n                }\n                 else this.recordAvgStat(\"avg_query_latency\", (Date.now() - l.fetch_context.queryBegin));\n            ;\n            }.bind(this));\n            this.data.subscribe(\"dirty\", function(k, l) {\n                this.bootstrapped = false;\n            });\n        },\n        _sessionStart: function() {\n            if (this.sessionActive) {\n                return\n            };\n            this.sessionActive = true;\n        },\n        _sessionEnd: function() {\n            if (!this.sessionActive) {\n                return\n            };\n            this.sessionActive = false;\n            this.submit();\n            this._reset();\n        },\n        recordStat: function(k, l) {\n            this.stats[k] = l;\n        },\n        recordCountStat: function(k) {\n            var l = this.stats[k];\n            this.stats[k] = (l ? (l + 1) : 1);\n        },\n        recordAvgStat: function(k, l) {\n            if (this.avgStats[k]) {\n                this.avgStats[k][0] += l;\n                ++this.avgStats[k][1];\n            }\n             else this.avgStats[k] = [l,1,];\n        ;\n        },\n        submit: function() {\n            if (Object.keys(this.stats).length) {\n                h(this.stats, this.extraData);\n                if (this.results) {\n                    var k = (this.results).map(function(n, o) {\n                        return n.uid;\n                    });\n                    this.recordStat(\"candidate_results\", JSON.stringify(k));\n                }\n            ;\n                if (this.query) {\n                    this.recordStat(\"query\", this.query);\n                };\n                if (this.sid) {\n                    this.recordStat(\"sid\", this.sid);\n                };\n                if (this.bootstrapped) {\n                    this.recordStat(\"bootstrapped\", 1);\n                };\n                for (var l in this.avgStats) {\n                    var m = this.avgStats[l];\n                    this.stats[l] = (m[0] / m[1]);\n                };\n                new g().setURI(this.endPoint).setMethod(\"POST\").setData({\n                    stats: this.stats\n                }).send();\n                this._reset();\n            }\n        ;\n        }\n    });\n    j.register = function(k, l, m) {\n        if ((document.activeElement === k)) {\n            l.init(m);\n        }\n         else var n = Event.listen(k, \"focus\", function() {\n            l.init(m);\n            n.remove();\n        })\n    ;\n    };\n    e.exports = j;\n});\n__d(\"TypeaheadHoistFriends\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\");\n    function h(i) {\n        this._typeahead = i;\n    };\n    g(h.prototype, {\n        _subscription: null,\n        enable: function() {\n            var i = this._typeahead.getView();\n            this._subscription = i.subscribe(\"beforeRender\", function(j, k) {\n                var l = [], m = [];\n                for (var n = 0; (n < k.results.length); ++n) {\n                    var o = k.results[n];\n                    if (((o.type == \"user\") && o.bootstrapped)) {\n                        m.push(o);\n                    }\n                     else l.push(o);\n                ;\n                };\n                k.results = m.concat(l);\n            });\n        },\n        disable: function() {\n            this._typeahead.getView().unsubscribe(this._subscription);\n            this._subscription = null;\n        }\n    });\n    e.exports = h;\n});\n__d(\"legacy:HoistFriendsTypeaheadBehavior\", [\"TypeaheadHoistFriends\",], function(a, b, c, d) {\n    var e = b(\"TypeaheadHoistFriends\");\n    if (!a.TypeaheadBehaviors) {\n        a.TypeaheadBehaviors = {\n        };\n    };\n    a.TypeaheadBehaviors.hoistFriends = function(f) {\n        f.enableBehavior(e);\n    };\n}, 3);\n__d(\"TypeaheadShowLoadingIndicator\", [\"CSS\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"copyProperties\");\n    function i(j) {\n        this._typeahead = j;\n    };\n    h(i.prototype, {\n        _subscription: null,\n        enable: function() {\n            this._subscription = this._typeahead.subscribe(\"loading\", function(j, k) {\n                g.conditionClass(this._typeahead.getElement(), \"typeaheadLoading\", k.loading);\n                g.conditionClass(this._typeahead.getView().getElement(), \"typeaheadViewLoading\", k.loading);\n            }.bind(this));\n        },\n        disable: function() {\n            this._typeahead.unsubscribe(this._subscription);\n            this._subscription = null;\n        }\n    });\n    e.exports = i;\n});\n__d(\"legacy:ShowLoadingIndicatorTypeaheadBehavior\", [\"TypeaheadShowLoadingIndicator\",], function(a, b, c, d) {\n    var e = b(\"TypeaheadShowLoadingIndicator\");\n    if (!a.TypeaheadBehaviors) {\n        a.TypeaheadBehaviors = {\n        };\n    };\n    a.TypeaheadBehaviors.showLoadingIndicator = function(f) {\n        f.enableBehavior(e);\n    };\n}, 3);\n__d(\"CompactTypeaheadRenderer\", [\"DOM\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\");\n    function h(i, j) {\n        var k = [], l = i.photo;\n        if (l) {\n            if ((l instanceof Array)) {\n                var m = [g.create(\"span\", {\n                    className: \"splitpic leftpic\"\n                }, [g.create(\"img\", {\n                    alt: \"\",\n                    src: l[0]\n                }),]),g.create(\"span\", {\n                    className: (\"splitpic\" + ((l[2] ? \" toppic\" : \"\")))\n                }, [g.create(\"img\", {\n                    alt: \"\",\n                    src: l[1]\n                }),]),];\n                if (l[2]) {\n                    m.push(g.create(\"span\", {\n                        className: \"splitpic bottompic\"\n                    }, [g.create(\"img\", {\n                        alt: \"\",\n                        src: l[2]\n                    }),]));\n                };\n                l = g.create(\"span\", {\n                    className: \"splitpics clearfix\"\n                }, m);\n            }\n             else l = g.create(\"img\", {\n                alt: \"\",\n                src: l\n            });\n        ;\n            k.push(l);\n        }\n    ;\n        if (i.text) {\n            k.push(g.create(\"span\", {\n                className: \"text\"\n            }, [i.text,]));\n        };\n        var n = i.subtext, o = i.category;\n        if ((n || o)) {\n            var p = [];\n            (n && p.push(n));\n            ((n && o) && p.push(\" \\u00b7 \"));\n            (o && p.push(o));\n            k.push(g.create(\"span\", {\n                className: \"subtext\"\n            }, p));\n        }\n    ;\n        var q = g.create(\"li\", {\n            className: (i.type || \"\")\n        }, k);\n        q.setAttribute(\"role\", \"option\");\n        if (i.text) {\n            q.setAttribute(\"aria-label\", i.text);\n        };\n        return q;\n    };\n    h.className = \"compact\";\n    e.exports = h;\n});");
// 2609
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"se832d80b877038f3f4b89f19a22a5847d60aa3b4");
// 2610
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"bS0QP\",]);\n}\n;\n;\n__d(\"AsyncDOM\", [\"CSS\",\"DOM\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = {\n        invoke: function(j, k) {\n            for (var l = 0; ((l < j.length)); ++l) {\n                var m = j[l], n = m[0], o = m[1], p = m[2], q = m[3], r = ((((p && k)) || null));\n                if (o) {\n                    r = h.scry(((r || JSBNG__document.documentElement)), o)[0];\n                }\n            ;\n            ;\n                switch (n) {\n                  case \"eval\":\n                    (new Function(q)).apply(r);\n                    break;\n                  case \"hide\":\n                    g.hide(r);\n                    break;\n                  case \"show\":\n                    g.show(r);\n                    break;\n                  case \"setContent\":\n                    h.setContent(r, q);\n                    break;\n                  case \"appendContent\":\n                    h.appendContent(r, q);\n                    break;\n                  case \"prependContent\":\n                    h.prependContent(r, q);\n                    break;\n                  case \"insertAfter\":\n                    h.insertAfter(r, q);\n                    break;\n                  case \"insertBefore\":\n                    h.insertBefore(r, q);\n                    break;\n                  case \"remove\":\n                    h.remove(r);\n                    break;\n                  case \"replace\":\n                    h.replace(r, q);\n                    break;\n                  default:\n                \n                };\n            ;\n            };\n        ;\n        }\n    };\n    e.exports = i;\n});\n__d(\"AsyncResponse\", [\"Bootloader\",\"Env\",\"copyProperties\",\"tx\",], function(a, b, c, d, e, f) {\n    var g = b(\"Bootloader\"), h = b(\"Env\"), i = b(\"copyProperties\"), j = b(\"tx\");\n    function k(l, m) {\n        i(this, {\n            error: 0,\n            errorSummary: null,\n            errorDescription: null,\n            JSBNG__onload: null,\n            replay: false,\n            payload: ((m || null)),\n            request: ((l || null)),\n            silentError: false,\n            is_last: true\n        });\n        return this;\n    };\n;\n    i(k, {\n        defaultErrorHandler: function(l) {\n            try {\n                if (!l.silentError) {\n                    k.verboseErrorHandler(l);\n                }\n                 else l.logErrorByGroup(\"silent\", 10);\n            ;\n            ;\n            } catch (m) {\n                JSBNG__alert(l);\n            };\n        ;\n        },\n        verboseErrorHandler: function(l) {\n            try {\n                var n = l.getErrorSummary(), o = l.getErrorDescription();\n                l.logErrorByGroup(\"popup\", 10);\n                if (((l.silentError && ((o == \"\"))))) {\n                    o = \"Something went wrong. We're working on getting this fixed as soon as we can. You may be able to try again.\";\n                }\n            ;\n            ;\n                g.loadModules([\"Dialog\",], function(p) {\n                    new p().setTitle(n).setBody(o).setButtons([p.OK,]).setModal(true).setCausalElement(this.relativeTo).show();\n                });\n            } catch (m) {\n                JSBNG__alert(l);\n            };\n        ;\n        }\n    });\n    i(k.prototype, {\n        getRequest: function() {\n            return this.request;\n        },\n        getPayload: function() {\n            return this.payload;\n        },\n        getError: function() {\n            return this.error;\n        },\n        getErrorSummary: function() {\n            return this.errorSummary;\n        },\n        setErrorSummary: function(l) {\n            l = ((((l === undefined)) ? null : l));\n            this.errorSummary = l;\n            return this;\n        },\n        getErrorDescription: function() {\n            return this.errorDescription;\n        },\n        getErrorIsWarning: function() {\n            return this.errorIsWarning;\n        },\n        logError: function(l, m) {\n            if (window.send_error_signal) {\n                var n = {\n                    err_code: this.error,\n                    vip: ((h.vip || \"-\"))\n                };\n                if (m) {\n                    n.duration = m.duration;\n                    n.xfb_ip = m.xfb_ip;\n                }\n            ;\n            ;\n                var o = this.request.getURI();\n                n.path = ((o || \"-\"));\n                n.aid = this.request.userActionID;\n                if (((o && ((o.indexOf(\"scribe_endpoint.php\") != -1))))) {\n                    l = \"async_error_double\";\n                }\n            ;\n            ;\n                send_error_signal(l, JSON.stringify(n));\n            }\n        ;\n        ;\n        },\n        logErrorByGroup: function(l, m) {\n            if (((Math.floor(((Math.JSBNG__random() * m))) == 0))) {\n                if (((((this.error == 1357010)) || ((this.error < 15000))))) {\n                    this.logError(((\"async_error_oops_\" + l)));\n                }\n                 else this.logError(((\"async_error_logic_\" + l)));\n            ;\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = k;\n});\n__d(\"HTTPErrors\", [], function(a, b, c, d, e, f) {\n    var g = {\n        get: bagofholding,\n        getAll: bagofholding\n    };\n    e.exports = g;\n});\n__d(\"AsyncRequest\", [\"event-extensions\",\"Arbiter\",\"AsyncDOM\",\"AsyncResponse\",\"Bootloader\",\"CSS\",\"Env\",\"HTTPErrors\",\"JSCC\",\"Parent\",\"Run\",\"ServerJS\",\"URI\",\"UserAgent\",\"XHR\",\"bind\",\"copyProperties\",\"evalGlobal\",\"ge\",\"goURI\",\"isEmpty\",\"tx\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"AsyncDOM\"), i = b(\"AsyncResponse\"), j = b(\"Bootloader\"), k = b(\"CSS\"), l = b(\"Env\"), m = b(\"HTTPErrors\"), n = b(\"JSCC\"), o = b(\"Parent\"), p = b(\"Run\"), q = b(\"ServerJS\"), r = b(\"URI\"), s = b(\"UserAgent\"), t = b(\"XHR\"), u = b(\"bind\"), v = b(\"copyProperties\"), w = b(\"evalGlobal\"), x = b(\"ge\"), y = b(\"goURI\"), z = b(\"isEmpty\"), aa = b(\"tx\");\n    function ba() {\n        try {\n            return !window.loaded;\n        } catch (ka) {\n            return true;\n        };\n    ;\n    };\n;\n    function ca(ka) {\n        return ((((\"upload\" in ka)) && ((\"JSBNG__onprogress\" in ka.upload))));\n    };\n;\n    function da(ka) {\n        return ((\"withCredentials\" in ka));\n    };\n;\n    function ea(ka) {\n        return ((ka.JSBNG__status in {\n            0: 1,\n            12029: 1,\n            12030: 1,\n            12031: 1,\n            12152: 1\n        }));\n    };\n;\n    function fa(ka) {\n        var la = ((!ka || ((typeof (ka) === \"function\"))));\n        return la;\n    };\n;\n    var ga = 2, ha = ga;\n    g.subscribe(\"page_transition\", function(ka, la) {\n        ha = la.id;\n    });\n    function ia(ka) {\n        v(this, {\n            transport: null,\n            method: \"POST\",\n            uri: \"\",\n            timeout: null,\n            timer: null,\n            initialHandler: bagofholding,\n            handler: null,\n            uploadProgressHandler: null,\n            errorHandler: null,\n            transportErrorHandler: null,\n            timeoutHandler: null,\n            interceptHandler: bagofholding,\n            finallyHandler: bagofholding,\n            abortHandler: bagofholding,\n            serverDialogCancelHandler: null,\n            relativeTo: null,\n            statusElement: null,\n            statusClass: \"\",\n            data: {\n            },\n            file: null,\n            context: {\n            },\n            readOnly: false,\n            writeRequiredParams: [],\n            remainingRetries: 0,\n            userActionID: \"-\"\n        });\n        this.option = {\n            asynchronous: true,\n            suppressErrorHandlerWarning: false,\n            suppressEvaluation: false,\n            suppressErrorAlerts: false,\n            retries: 0,\n            jsonp: false,\n            bundle: false,\n            useIframeTransport: false,\n            handleErrorAfterUnload: false\n        };\n        this.errorHandler = i.defaultErrorHandler;\n        this.transportErrorHandler = u(this, \"errorHandler\");\n        if (((ka !== undefined))) {\n            this.setURI(ka);\n        }\n    ;\n    ;\n    };\n;\n    v(ia, {\n        bootstrap: function(ka, la, ma) {\n            var na = \"GET\", oa = true, pa = {\n            };\n            if (((ma || ((la && ((((la.rel == \"async-post\")) || ((la.getAttribute && ((la.getAttribute(\"forcemethod\") == \"post\"))))))))))) {\n                na = \"POST\";\n                oa = false;\n                if (ka) {\n                    ka = r(ka);\n                    pa = ka.getQueryData();\n                    ka.setQueryData({\n                    });\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            var qa = ((o.byClass(la, \"stat_elem\") || la));\n            if (((qa && k.hasClass(qa, \"async_saving\")))) {\n                return false;\n            }\n        ;\n        ;\n            var ra = new ia(ka).setReadOnly(oa).setMethod(na).setData(pa).setNectarModuleDataSafe(la).setRelativeTo(la);\n            if (la) {\n                ra.setHandler(function(ta) {\n                    JSBNG__Event.fire(la, \"success\", {\n                        response: ta\n                    });\n                });\n                ra.setErrorHandler(function(ta) {\n                    if (((JSBNG__Event.fire(la, \"error\", {\n                        response: ta\n                    }) !== false))) {\n                        i.defaultErrorHandler(ta);\n                    }\n                ;\n                ;\n                });\n            }\n        ;\n        ;\n            if (qa) {\n                ra.setStatusElement(qa);\n                var sa = qa.getAttribute(\"data-status-class\");\n                ((sa && ra.setStatusClass(sa)));\n            }\n        ;\n        ;\n            if (la) {\n                JSBNG__Event.fire(la, \"AsyncRequest/send\", {\n                    request: ra\n                });\n            }\n        ;\n        ;\n            ra.send();\n            return false;\n        },\n        post: function(ka, la) {\n            new ia(ka).setReadOnly(false).setMethod(\"POST\").setData(la).send();\n            return false;\n        },\n        getLastID: function() {\n            return ga;\n        },\n        suppressOnloadToken: {\n        },\n        _inflight: [],\n        _inflightCount: 0,\n        _inflightAdd: bagofholding,\n        _inflightPurge: bagofholding,\n        getInflightCount: function() {\n            return this._inflightCount;\n        },\n        _inflightEnable: function() {\n            if (s.ie()) {\n                v(ia, {\n                    _inflightAdd: function(ka) {\n                        this._inflight.push(ka);\n                    },\n                    _inflightPurge: function() {\n                        ia._inflight = ia._inflight.filter(function(ka) {\n                            return ((ka.transport && ((ka.transport.readyState < 4))));\n                        });\n                    }\n                });\n                p.JSBNG__onUnload(function() {\n                    ia._inflight.forEach(function(ka) {\n                        if (((ka.transport && ((ka.transport.readyState < 4))))) {\n                            ka.transport.abort();\n                            delete ka.transport;\n                        }\n                    ;\n                    ;\n                    });\n                });\n            }\n        ;\n        ;\n        }\n    });\n    v(ia.prototype, {\n        _dispatchResponse: function(ka) {\n            try {\n                this.clearStatusIndicator();\n                if (!this._isRelevant()) {\n                    this._invokeErrorHandler(1010);\n                    return;\n                }\n            ;\n            ;\n                if (((this.initialHandler(ka) === false))) {\n                    return;\n                }\n            ;\n            ;\n                JSBNG__clearTimeout(this.timer);\n                if (ka.jscc_map) {\n                    var ma = (eval)(ka.jscc_map);\n                    n.init(ma);\n                }\n            ;\n            ;\n                var na;\n                if (this.handler) {\n                    try {\n                        na = this._shouldSuppressJS(this.handler(ka));\n                    } catch (oa) {\n                        ((ka.is_last && this.finallyHandler(ka)));\n                        throw oa;\n                    };\n                }\n            ;\n            ;\n                if (!na) {\n                    this._handleJSResponse(ka);\n                }\n            ;\n            ;\n                ((ka.is_last && this.finallyHandler(ka)));\n            } catch (la) {\n            \n            };\n        ;\n        },\n        _shouldSuppressJS: function(ka) {\n            return ((ka === ia.suppressOnloadToken));\n        },\n        _handleJSResponse: function(ka) {\n            var la = this.getRelativeTo(), ma = ka.domops, na = ka.jsmods, oa = new q().setRelativeTo(la);\n            if (((na && ((((na.define || na.instances)) || na.markup))))) {\n                oa.handle({\n                    define: na.define,\n                    instances: na.instances,\n                    markup: na.markup\n                });\n                delete na.define;\n                delete na.instances;\n                delete na.markup;\n            }\n        ;\n        ;\n            if (ma) {\n                h.invoke(ma, la);\n            }\n        ;\n        ;\n            if (na) {\n                oa.handle(na);\n            }\n        ;\n        ;\n            this._handleJSRegisters(ka, \"JSBNG__onload\");\n            if (this.lid) {\n                g.inform(\"tti_ajax\", {\n                    s: this.lid,\n                    d: [((this._sendTimeStamp || 0)),((((this._sendTimeStamp && this._responseTime)) ? ((this._responseTime - this._sendTimeStamp)) : 0)),]\n                }, g.BEHAVIOR_EVENT);\n            }\n        ;\n        ;\n            this._handleJSRegisters(ka, \"JSBNG__onafterload\");\n        },\n        _handleJSRegisters: function(ka, la) {\n            var ma = ka[la];\n            if (!ma) {\n                return;\n            }\n        ;\n        ;\n            for (var na = 0; ((na < ma.length)); na++) {\n                try {\n                    (new Function(ma[na])).apply(this);\n                } catch (oa) {\n                \n                };\n            ;\n            };\n        ;\n        },\n        invokeResponseHandler: function(ka) {\n            if (((typeof (ka.redirect) !== \"undefined\"))) {\n                (function() {\n                    this.setURI(ka.redirect).send();\n                }).bind(this).defer();\n                return;\n            }\n        ;\n        ;\n            if (((((!this.handler && !this.errorHandler)) && !this.transportErrorHandler))) {\n                return;\n            }\n        ;\n        ;\n            if (((typeof (ka.asyncResponse) !== \"undefined\"))) {\n                if (!this._isRelevant()) {\n                    this._invokeErrorHandler(1010);\n                    return;\n                }\n            ;\n            ;\n                var la = ka.asyncResponse;\n                if (la.inlinejs) {\n                    w(la.inlinejs);\n                }\n            ;\n            ;\n                if (la.lid) {\n                    this._responseTime = JSBNG__Date.now();\n                    if (a.CavalryLogger) {\n                        this.cavalry = a.CavalryLogger.getInstance(la.lid);\n                    }\n                ;\n                ;\n                    this.lid = la.lid;\n                }\n            ;\n            ;\n                j.setResourceMap(la.resource_map);\n                if (la.bootloadable) {\n                    j.enableBootload(la.bootloadable);\n                }\n            ;\n            ;\n                var ma;\n                if (((la.getError() && !la.getErrorIsWarning()))) {\n                    var na = this.errorHandler.bind(this);\n                    ma = this._dispatchErrorResponse.bind(this, la, na);\n                }\n                 else ma = this._dispatchResponse.bind(this, la);\n            ;\n            ;\n                ma = ma.defer.bind(ma);\n                var oa = false;\n                if (this.preBootloadHandler) {\n                    oa = this.preBootloadHandler(la);\n                }\n            ;\n            ;\n                la.css = ((la.css || []));\n                la.js = ((la.js || []));\n                j.loadResources(la.css.concat(la.js), ma, oa, this.getURI());\n            }\n             else if (((typeof (ka.transportError) !== \"undefined\"))) {\n                if (this._xFbServer) {\n                    this._invokeErrorHandler(1008);\n                }\n                 else this._invokeErrorHandler(1012);\n            ;\n            ;\n            }\n             else this._invokeErrorHandler(1007);\n            \n        ;\n        ;\n        },\n        _invokeErrorHandler: function(ka) {\n            if (((ba() && !this.getOption(\"handleErrorAfterUnload\")))) {\n                return;\n            }\n        ;\n        ;\n            var la;\n            if (((this.responseText === \"\"))) {\n                la = 1002;\n            }\n             else if (this._requestAborted) {\n                la = 1011;\n            }\n             else {\n                try {\n                    la = ((((ka || this.transport.JSBNG__status)) || 1004));\n                } catch (ma) {\n                    la = 1005;\n                };\n            ;\n                if (((false === JSBNG__navigator.JSBNG__onLine))) {\n                    la = 1006;\n                }\n            ;\n            ;\n            }\n            \n        ;\n        ;\n            if (!this.transportErrorHandler) {\n                return;\n            }\n        ;\n        ;\n            var na = this.transportErrorHandler.bind(this), oa, pa, qa = true;\n            if (((la === 1006))) {\n                pa = \"No Network Connection\";\n                oa = \"Your browser appears to be offline. Please check your internet connection and try again.\";\n            }\n             else if (((((la >= 300)) && ((la <= 399))))) {\n                pa = \"Redirection\";\n                oa = \"Your access to Facebook was redirected or blocked by a third party at this time, please contact your ISP or reload. \";\n                var ra = this.transport.getResponseHeader(\"Location\");\n                if (ra) {\n                    y(ra, true);\n                }\n            ;\n            ;\n                qa = true;\n            }\n             else {\n                pa = \"Oops\";\n                oa = \"Something went wrong. We're working on getting this fixed as soon as we can. You may be able to try again.\";\n            }\n            \n        ;\n        ;\n            !this.getOption(\"suppressErrorAlerts\");\n            var sa = new i(this);\n            v(sa, {\n                error: la,\n                errorSummary: pa,\n                errorDescription: oa,\n                silentError: qa\n            });\n            this._dispatchErrorResponse(sa, na);\n        },\n        _dispatchErrorResponse: function(ka, la) {\n            var ma = ka.getError();\n            try {\n                this.clearStatusIndicator();\n                var oa = ((this._sendTimeStamp && {\n                    duration: ((JSBNG__Date.now() - this._sendTimeStamp)),\n                    xfb_ip: ((this._xFbServer || \"-\"))\n                }));\n                ka.logError(\"async_error\", oa);\n                if (((!this._isRelevant() || ((ma === 1010))))) {\n                    this.abort();\n                    return;\n                }\n            ;\n            ;\n                if (((((((((ma == 1357008)) || ((ma == 1357007)))) || ((ma == 1442002)))) || ((ma == 1357001))))) {\n                    var pa = ((((ma == 1357008)) || ((ma == 1357007))));\n                    this.interceptHandler(ka);\n                    this._displayServerDialog(ka, pa);\n                }\n                 else if (((this.initialHandler(ka) !== false))) {\n                    JSBNG__clearTimeout(this.timer);\n                    try {\n                        la(ka);\n                    } catch (qa) {\n                        this.finallyHandler(ka);\n                        throw qa;\n                    };\n                ;\n                    this.finallyHandler(ka);\n                }\n                \n            ;\n            ;\n            } catch (na) {\n            \n            };\n        ;\n        },\n        _displayServerDialog: function(ka, la) {\n            var ma = ka.getPayload();\n            if (((ma.__dialog !== undefined))) {\n                this._displayServerLegacyDialog(ka, la);\n                return;\n            }\n        ;\n        ;\n            var na = ma.__dialogx;\n            new q().handle(na);\n            j.loadModules([\"ConfirmationDialog\",], function(oa) {\n                oa.setupConfirmation(ka, this);\n            }.bind(this));\n        },\n        _displayServerLegacyDialog: function(ka, la) {\n            var ma = ka.getPayload().__dialog;\n            j.loadModules([\"Dialog\",], function(na) {\n                var oa = new na(ma);\n                if (la) {\n                    oa.setHandler(this._displayConfirmationHandler.bind(this, oa));\n                }\n            ;\n            ;\n                oa.setCancelHandler(function() {\n                    var pa = this.getServerDialogCancelHandler();\n                    try {\n                        ((pa && pa(ka)));\n                    } catch (qa) {\n                        throw qa;\n                    } finally {\n                        this.finallyHandler(ka);\n                    };\n                ;\n                }.bind(this)).setCausalElement(this.relativeTo).show();\n            }.bind(this));\n        },\n        _displayConfirmationHandler: function(ka) {\n            this.data.confirmed = 1;\n            v(this.data, ka.getFormData());\n            this.send();\n        },\n        _handleJSONPResponse: function(ka) {\n            this.is_first = ((this.is_first === undefined));\n            var la = this._interpretResponse(ka);\n            la.asyncResponse.is_first = this.is_first;\n            la.asyncResponse.is_last = this.transport.hasFinished();\n            this.invokeResponseHandler(la);\n            if (this.transport.hasFinished()) {\n                delete this.transport;\n            }\n        ;\n        ;\n        },\n        _handleXHRResponse: function(ka) {\n            var la;\n            if (this.getOption(\"suppressEvaluation\")) {\n                la = {\n                    asyncResponse: new i(this, ka)\n                };\n            }\n             else {\n                var ma = ka.responseText, na = null;\n                try {\n                    var pa = this._unshieldResponseText(ma);\n                    try {\n                        var qa = (eval)(((((\"(\" + pa)) + \")\")));\n                        la = this._interpretResponse(qa);\n                    } catch (oa) {\n                        na = \"excep\";\n                        la = {\n                            transportError: ((\"eval() failed on async to \" + this.getURI()))\n                        };\n                    };\n                ;\n                } catch (oa) {\n                    na = \"empty\";\n                    la = {\n                        transportError: oa.message\n                    };\n                };\n            ;\n                if (na) {\n                    ((a.send_error_signal && a.send_error_signal(\"async_xport_resp\", [((((this._xFbServer ? \"1008_\" : \"1012_\")) + na)),((this._xFbServer || \"-\")),this.getURI(),ma.length,ma.substr(0, 1600),].join(\":\"))));\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            this.invokeResponseHandler(la);\n        },\n        _unshieldResponseText: function(ka) {\n            var la = \"for (;;);\", ma = la.length;\n            if (((ka.length <= ma))) {\n                throw new Error(((\"Response too short on async to \" + this.getURI())));\n            }\n        ;\n        ;\n            var na = 0;\n            while (((((ka.charAt(na) == \" \")) || ((ka.charAt(na) == \"\\u000a\"))))) {\n                na++;\n            ;\n            };\n        ;\n            ((na && ((ka.substring(na, ((na + ma))) == la))));\n            return ka.substring(((na + ma)));\n        },\n        _interpretResponse: function(ka) {\n            if (ka.redirect) {\n                return {\n                    redirect: ka.redirect\n                };\n            }\n        ;\n        ;\n            var la = new i(this);\n            if (((ka.__ar != 1))) {\n                la.payload = ka;\n            }\n             else v(la, ka);\n        ;\n        ;\n            return {\n                asyncResponse: la\n            };\n        },\n        _onStateChange: function() {\n            try {\n                if (((this.transport.readyState == 4))) {\n                    ia._inflightCount--;\n                    ia._inflightPurge();\n                    try {\n                        if (((((typeof (this.transport.getResponseHeader) !== \"undefined\")) && this.transport.getResponseHeader(\"X-FB-Debug\")))) {\n                            this._xFbServer = this.transport.getResponseHeader(\"X-FB-Debug\");\n                        }\n                    ;\n                    ;\n                    } catch (la) {\n                    \n                    };\n                ;\n                    if (((((this.transport.JSBNG__status >= 200)) && ((this.transport.JSBNG__status < 300))))) {\n                        ia.lastSuccessTime = JSBNG__Date.now();\n                        this._handleXHRResponse(this.transport);\n                    }\n                     else if (((s.safari() && ((typeof (this.transport.JSBNG__status) == \"undefined\"))))) {\n                        this._invokeErrorHandler(1002);\n                    }\n                     else if (((((l.retry_ajax_on_network_error && ea(this.transport))) && ((this.remainingRetries > 0))))) {\n                        this.remainingRetries--;\n                        delete this.transport;\n                        this.send(true);\n                        return;\n                    }\n                     else this._invokeErrorHandler();\n                    \n                    \n                ;\n                ;\n                    if (((this.getOption(\"asynchronous\") !== false))) {\n                        delete this.transport;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            } catch (ka) {\n                if (ba()) {\n                    return;\n                }\n            ;\n            ;\n                delete this.transport;\n                if (((this.remainingRetries > 0))) {\n                    this.remainingRetries--;\n                    this.send(true);\n                }\n                 else {\n                    !this.getOption(\"suppressErrorAlerts\");\n                    ((a.send_error_signal && a.send_error_signal(\"async_xport_resp\", [1007,((this._xFbServer || \"-\")),this.getURI(),ka.message,].join(\":\"))));\n                    this._invokeErrorHandler(1007);\n                }\n            ;\n            ;\n            };\n        ;\n        },\n        _isMultiplexable: function() {\n            if (((this.getOption(\"jsonp\") || this.getOption(\"useIframeTransport\")))) {\n                return false;\n            }\n        ;\n        ;\n            if (!this.uri.isFacebookURI()) {\n                return false;\n            }\n        ;\n        ;\n            if (!this.getOption(\"asynchronous\")) {\n                return false;\n            }\n        ;\n        ;\n            return true;\n        },\n        handleResponse: function(ka) {\n            var la = this._interpretResponse(ka);\n            this.invokeResponseHandler(la);\n        },\n        setMethod: function(ka) {\n            this.method = ka.toString().toUpperCase();\n            return this;\n        },\n        getMethod: function() {\n            return this.method;\n        },\n        setData: function(ka) {\n            this.data = ka;\n            return this;\n        },\n        _setDataHash: function() {\n            if (((((this.method != \"POST\")) || this.data.phstamp))) {\n                return;\n            }\n        ;\n        ;\n            var ka = r.implodeQuery(this.data).length, la = \"\";\n            for (var ma = 0; ((ma < this.data.fb_dtsg.length)); ma++) {\n                la += this.data.fb_dtsg.charCodeAt(ma);\n            ;\n            };\n        ;\n            this.data.phstamp = ((((\"1\" + la)) + ka));\n        },\n        setRawData: function(ka) {\n            this.rawData = ka;\n            return this;\n        },\n        getData: function() {\n            return this.data;\n        },\n        setContextData: function(ka, la, ma) {\n            ma = ((((ma === undefined)) ? true : ma));\n            if (ma) {\n                this.context[((\"_log_\" + ka))] = la;\n            }\n        ;\n        ;\n            return this;\n        },\n        _setUserActionID: function() {\n            var ka = ((((a.ArbiterMonitor && a.ArbiterMonitor.getUE())) || \"-\"));\n            this.userActionID = ((((((((a.EagleEye && a.EagleEye.getSessionID())) || \"-\")) + \"/\")) + ka));\n        },\n        setURI: function(ka) {\n            var la = r(ka);\n            if (((this.getOption(\"useIframeTransport\") && !la.isFacebookURI()))) {\n                return this;\n            }\n        ;\n        ;\n            if (((((((!this._allowCrossOrigin && !this.getOption(\"jsonp\"))) && !this.getOption(\"useIframeTransport\"))) && !la.isSameOrigin()))) {\n                return this;\n            }\n        ;\n        ;\n            this._setUserActionID();\n            if (((!ka || la.isEmpty()))) {\n                if (((a.send_error_signal && a.get_error_stack))) {\n                    var ma = {\n                        err_code: 1013,\n                        vip: \"-\",\n                        duration: 0,\n                        xfb_ip: \"-\",\n                        path: window.JSBNG__location.href,\n                        aid: this.userActionID\n                    };\n                    a.send_error_signal(\"async_error\", JSON.stringify(ma));\n                    a.send_error_signal(\"async_xport_stack\", [1013,window.JSBNG__location.href,null,a.get_error_stack(),].join(\":\"));\n                }\n            ;\n            ;\n                return this;\n            }\n        ;\n        ;\n            this.uri = la;\n            return this;\n        },\n        getURI: function() {\n            return this.uri.toString();\n        },\n        setInitialHandler: function(ka) {\n            this.initialHandler = ka;\n            return this;\n        },\n        setHandler: function(ka) {\n            if (fa(ka)) {\n                this.handler = ka;\n            }\n        ;\n        ;\n            return this;\n        },\n        getHandler: function() {\n            return this.handler;\n        },\n        setUploadProgressHandler: function(ka) {\n            if (fa(ka)) {\n                this.uploadProgressHandler = ka;\n            }\n        ;\n        ;\n            return this;\n        },\n        setErrorHandler: function(ka) {\n            if (fa(ka)) {\n                this.errorHandler = ka;\n            }\n        ;\n        ;\n            return this;\n        },\n        setTransportErrorHandler: function(ka) {\n            this.transportErrorHandler = ka;\n            return this;\n        },\n        getErrorHandler: function() {\n            return this.errorHandler;\n        },\n        getTransportErrorHandler: function() {\n            return this.transportErrorHandler;\n        },\n        setTimeoutHandler: function(ka, la) {\n            if (fa(la)) {\n                this.timeout = ka;\n                this.timeoutHandler = la;\n            }\n        ;\n        ;\n            return this;\n        },\n        resetTimeout: function(ka) {\n            if (!((this.timeoutHandler === null))) {\n                if (((ka === null))) {\n                    this.timeout = null;\n                    JSBNG__clearTimeout(this.timer);\n                    this.timer = null;\n                }\n                 else {\n                    var la = !this._allowCrossPageTransition;\n                    this.timeout = ka;\n                    JSBNG__clearTimeout(this.timer);\n                    this.timer = this._handleTimeout.bind(this).defer(this.timeout, la);\n                }\n            ;\n            }\n        ;\n        ;\n            return this;\n        },\n        _handleTimeout: function() {\n            this.abandon();\n            this.timeoutHandler(this);\n        },\n        setNewSerial: function() {\n            this.id = ++ga;\n            return this;\n        },\n        setInterceptHandler: function(ka) {\n            this.interceptHandler = ka;\n            return this;\n        },\n        setFinallyHandler: function(ka) {\n            this.finallyHandler = ka;\n            return this;\n        },\n        setAbortHandler: function(ka) {\n            this.abortHandler = ka;\n            return this;\n        },\n        getServerDialogCancelHandler: function() {\n            return this.serverDialogCancelHandler;\n        },\n        setServerDialogCancelHandler: function(ka) {\n            this.serverDialogCancelHandler = ka;\n            return this;\n        },\n        setPreBootloadHandler: function(ka) {\n            this.preBootloadHandler = ka;\n            return this;\n        },\n        setReadOnly: function(ka) {\n            if (!((typeof (ka) != \"boolean\"))) {\n                this.readOnly = ka;\n            }\n        ;\n        ;\n            return this;\n        },\n        setFBMLForm: function() {\n            this.writeRequiredParams = [\"fb_sig\",];\n            return this;\n        },\n        getReadOnly: function() {\n            return this.readOnly;\n        },\n        setRelativeTo: function(ka) {\n            this.relativeTo = ka;\n            return this;\n        },\n        getRelativeTo: function() {\n            return this.relativeTo;\n        },\n        setStatusClass: function(ka) {\n            this.statusClass = ka;\n            return this;\n        },\n        setStatusElement: function(ka) {\n            this.statusElement = ka;\n            return this;\n        },\n        getStatusElement: function() {\n            return x(this.statusElement);\n        },\n        _isRelevant: function() {\n            if (this._allowCrossPageTransition) {\n                return true;\n            }\n        ;\n        ;\n            if (!this.id) {\n                return true;\n            }\n        ;\n        ;\n            return ((this.id > ha));\n        },\n        clearStatusIndicator: function() {\n            var ka = this.getStatusElement();\n            if (ka) {\n                k.removeClass(ka, \"async_saving\");\n                k.removeClass(ka, this.statusClass);\n            }\n        ;\n        ;\n        },\n        addStatusIndicator: function() {\n            var ka = this.getStatusElement();\n            if (ka) {\n                k.addClass(ka, \"async_saving\");\n                k.addClass(ka, this.statusClass);\n            }\n        ;\n        ;\n        },\n        specifiesWriteRequiredParams: function() {\n            return this.writeRequiredParams.every(function(ka) {\n                this.data[ka] = ((((this.data[ka] || l[ka])) || ((x(ka) || {\n                })).value));\n                if (((this.data[ka] !== undefined))) {\n                    return true;\n                }\n            ;\n            ;\n                return false;\n            }, this);\n        },\n        setOption: function(ka, la) {\n            if (((typeof (this.option[ka]) != \"undefined\"))) {\n                this.option[ka] = la;\n            }\n        ;\n        ;\n            return this;\n        },\n        getOption: function(ka) {\n            ((typeof (this.option[ka]) == \"undefined\"));\n            return this.option[ka];\n        },\n        abort: function() {\n            if (this.transport) {\n                var ka = this.getTransportErrorHandler();\n                this.setOption(\"suppressErrorAlerts\", true);\n                this.setTransportErrorHandler(bagofholding);\n                this._requestAborted = true;\n                this.transport.abort();\n                this.setTransportErrorHandler(ka);\n            }\n        ;\n        ;\n            this.abortHandler();\n        },\n        abandon: function() {\n            JSBNG__clearTimeout(this.timer);\n            this.setOption(\"suppressErrorAlerts\", true).setHandler(bagofholding).setErrorHandler(bagofholding).setTransportErrorHandler(bagofholding);\n            if (this.transport) {\n                this._requestAborted = true;\n                this.transport.abort();\n            }\n        ;\n        ;\n        },\n        setNectarData: function(ka) {\n            if (ka) {\n                if (((this.data.nctr === undefined))) {\n                    this.data.nctr = {\n                    };\n                }\n            ;\n            ;\n                v(this.data.nctr, ka);\n            }\n        ;\n        ;\n            return this;\n        },\n        setNectarModuleDataSafe: function(ka) {\n            if (this.setNectarModuleData) {\n                this.setNectarModuleData(ka);\n            }\n        ;\n        ;\n            return this;\n        },\n        setNectarImpressionIdSafe: function() {\n            if (this.setNectarImpressionId) {\n                this.setNectarImpressionId();\n            }\n        ;\n        ;\n            return this;\n        },\n        setAllowCrossPageTransition: function(ka) {\n            this._allowCrossPageTransition = !!ka;\n            if (this.timer) {\n                this.resetTimeout(this.timeout);\n            }\n        ;\n        ;\n            return this;\n        },\n        setAllowCrossOrigin: function(ka) {\n            this._allowCrossOrigin = !!ka;\n            return this;\n        },\n        send: function(ka) {\n            ka = ((ka || false));\n            if (!this.uri) {\n                return false;\n            }\n        ;\n        ;\n            ((!this.errorHandler && !this.getOption(\"suppressErrorHandlerWarning\")));\n            if (((this.getOption(\"jsonp\") && ((this.method != \"GET\"))))) {\n                this.setMethod(\"GET\");\n            }\n        ;\n        ;\n            if (((this.getOption(\"useIframeTransport\") && ((this.method != \"GET\"))))) {\n                this.setMethod(\"GET\");\n            }\n        ;\n        ;\n            ((((this.timeoutHandler !== null)) && ((this.getOption(\"jsonp\") || this.getOption(\"useIframeTransport\")))));\n            if (!this.getReadOnly()) {\n                this.specifiesWriteRequiredParams();\n                if (((this.method != \"POST\"))) {\n                    return false;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            v(this.data, t.getAsyncParams(this.method));\n            if (!z(this.context)) {\n                v(this.data, this.context);\n                this.data.ajax_log = 1;\n            }\n        ;\n        ;\n            if (l.force_param) {\n                v(this.data, l.force_param);\n            }\n        ;\n        ;\n            this._setUserActionID();\n            if (((this.getOption(\"bundle\") && this._isMultiplexable()))) {\n                ja.schedule(this);\n                return true;\n            }\n        ;\n        ;\n            this.setNewSerial();\n            if (!this.getOption(\"asynchronous\")) {\n                this.uri.addQueryData({\n                    __s: 1\n                });\n            }\n        ;\n        ;\n            this.finallyHandler = a.async_callback(this.finallyHandler, \"final\");\n            var la, ma;\n            if (((((this.method == \"GET\")) || this.rawData))) {\n                la = this.uri.addQueryData(this.data).toString();\n                ma = ((this.rawData || \"\"));\n            }\n             else {\n                la = this.uri.toString();\n                this._setDataHash();\n                ma = r.implodeQuery(this.data);\n            }\n        ;\n        ;\n            if (this.transport) {\n                return false;\n            }\n        ;\n        ;\n            if (((this.getOption(\"jsonp\") || this.getOption(\"useIframeTransport\")))) {\n                d([\"JSONPTransport\",], function(qa) {\n                    this.transport = new qa(((this.getOption(\"jsonp\") ? \"jsonp\" : \"div\")), this.uri, this._handleJSONPResponse.bind(this));\n                    this.transport.send();\n                }.bind(this));\n                return true;\n            }\n        ;\n        ;\n            var na = t.create();\n            if (!na) {\n                return false;\n            }\n        ;\n        ;\n            na.JSBNG__onreadystatechange = a.async_callback(this._onStateChange.bind(this), \"xhr\");\n            if (((this.uploadProgressHandler && ca(na)))) {\n                na.upload.JSBNG__onprogress = this.uploadProgressHandler.bind(this);\n            }\n        ;\n        ;\n            if (!ka) {\n                this.remainingRetries = this.getOption(\"retries\");\n            }\n        ;\n        ;\n            if (((a.send_error_signal || a.ArbiterMonitor))) {\n                this._sendTimeStamp = ((this._sendTimeStamp || JSBNG__Date.now()));\n            }\n        ;\n        ;\n            this.transport = na;\n            try {\n                this.transport.open(this.method, la, this.getOption(\"asynchronous\"));\n            } catch (oa) {\n                return false;\n            };\n        ;\n            var pa = l.svn_rev;\n            if (pa) {\n                this.transport.setRequestHeader(\"X-SVN-Rev\", String(pa));\n            }\n        ;\n        ;\n            if (((((!this.uri.isSameOrigin() && !this.getOption(\"jsonp\"))) && !this.getOption(\"useIframeTransport\")))) {\n                if (!da(this.transport)) {\n                    return false;\n                }\n            ;\n            ;\n                if (this.uri.isFacebookURI()) {\n                    this.transport.withCredentials = true;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            if (((((this.method == \"POST\")) && !this.rawData))) {\n                this.transport.setRequestHeader(\"Content-Type\", \"application/x-www-form-urlencoded\");\n            }\n        ;\n        ;\n            this.addStatusIndicator();\n            this.transport.send(ma);\n            if (((this.timeout !== null))) {\n                this.resetTimeout(this.timeout);\n            }\n        ;\n        ;\n            ia._inflightCount++;\n            ia._inflightAdd(this);\n            return true;\n        }\n    });\n    function ja() {\n        this._requests = [];\n    };\n;\n    v(ja, {\n        multiplex: null,\n        schedule: function(ka) {\n            if (!ja.multiplex) {\n                ja.multiplex = new ja();\n                (function() {\n                    ja.multiplex.send();\n                    ja.multiplex = null;\n                }).defer();\n            }\n        ;\n        ;\n            ja.multiplex.add(ka);\n        }\n    });\n    v(ja.prototype, {\n        add: function(ka) {\n            this._requests.push(ka);\n        },\n        send: function() {\n            var ka = this._requests;\n            if (!ka.length) {\n                return;\n            }\n        ;\n        ;\n            var la;\n            if (((ka.length === 1))) {\n                la = ka[0];\n            }\n             else {\n                var ma = ka.map(function(na) {\n                    return [na.uri.getPath(),r.implodeQuery(na.data),];\n                });\n                la = new ia(\"/ajax/proxy.php\").setAllowCrossPageTransition(true).setData({\n                    data: ma\n                }).setHandler(this._handler.bind(this)).setTransportErrorHandler(this._transportErrorHandler.bind(this));\n            }\n        ;\n        ;\n            la.setOption(\"bundle\", false).send();\n        },\n        _handler: function(ka) {\n            var la = ka.getPayload().responses;\n            if (((la.length !== this._requests.length))) {\n                return;\n            }\n        ;\n        ;\n            for (var ma = 0; ((ma < this._requests.length)); ma++) {\n                var na = this._requests[ma], oa = na.uri.getPath();\n                na.id = this.id;\n                if (((la[ma][0] !== oa))) {\n                    na.invokeResponseHandler({\n                        transportError: ((\"Wrong response order in bundled request to \" + oa))\n                    });\n                    continue;\n                }\n            ;\n            ;\n                na.handleResponse(la[ma][1]);\n            };\n        ;\n        },\n        _transportErrorHandler: function(ka) {\n            var la = {\n                transportError: ka.errorDescription\n            }, ma = this._requests.map(function(na) {\n                na.id = this.id;\n                na.invokeResponseHandler(la);\n                return na.uri.getPath();\n            });\n        }\n    });\n    e.exports = ia;\n});\n__d(\"legacy:async\", [\"AsyncRequest\",\"AsyncResponse\",], function(a, b, c, d) {\n    a.AsyncRequest = b(\"AsyncRequest\");\n    a.AsyncResponse = b(\"AsyncResponse\");\n}, 3);\n__d(\"legacy:css\", [\"CSS\",], function(a, b, c, d) {\n    a.CSS = b(\"CSS\");\n}, 3);\n__d(\"legacy:data-store\", [\"DataStore\",], function(a, b, c, d) {\n    a.DataStore = ((a.DataStore || b(\"DataStore\")));\n}, 3);\nfunction EmuController(a, b) {\n    this.impression = b;\n    this.containerId = a;\n    DataStore.set($(a), \"emuController\", this);\n    return this;\n};\n;\ncopyProperties(EmuController, {\n    fromContainer: function(a) {\n        var b = ge(a);\n        if (!b) {\n            return null;\n        }\n    ;\n    ;\n        return DataStore.get(b, \"emuController\");\n    },\n    getEventClass: function(a) {\n        return ((\"emuEvent\" + String(a).trim()));\n    }\n});\ncopyProperties(EmuController.prototype, {\n    EVENT_HANDLER_PATH: \"/ajax/emu/end.php\",\n    CLICK: 1,\n    FAN: \"fad_fan\",\n    JSBNG__event: function(a, b, c, d) {\n        var e = {\n            eid: this.impression,\n            f: 0,\n            ui: this.containerId,\n            en: a,\n            a: 1\n        };\n        if (b) {\n            e.ed = JSON.stringify(b);\n        }\n    ;\n    ;\n        if (!d) {\n            var d = bagofholding;\n        }\n    ;\n    ;\n        var f = new AsyncRequest().setURI(this.EVENT_HANDLER_PATH).setData(e).setErrorHandler(d);\n        if (c) {\n            f.setHandler(c);\n        }\n    ;\n    ;\n        f.send();\n    },\n    redirect: function() {\n        var a = {\n            eid: this.impression,\n            f: 0,\n            ui: this.containerId,\n            en: this.CLICK,\n            a: 0,\n            sig: ((Math.floor(((Math.JSBNG__random() * 65535))) + 65536))\n        }, b = new URI(this.EVENT_HANDLER_PATH);\n        b.setQueryData(a);\n        goURI(b);\n    }\n});\nvar ShortClickHandlers = {\n    EVENT_NAME_CAME_BACK: \"cameback\",\n    JSBNG__onclicked: function(a) {\n        if (this.JSBNG__onsite) {\n            return;\n        }\n    ;\n    ;\n        if (((((a.button !== 0)) || a.getModifiers().any))) {\n            return;\n        }\n    ;\n    ;\n        this.click_ts = (+new JSBNG__Date());\n        if (((this.listeners !== undefined))) {\n            for (var b in this.listeners) {\n                this.listeners[b].remove();\n            ;\n            };\n        }\n    ;\n    ;\n        this.listeners = {\n            JSBNG__focus: JSBNG__Event.listen(window, \"JSBNG__focus\", ShortClickHandlers.JSBNG__oncameback.bind(this))\n        };\n    },\n    JSBNG__oncameback: function(a) {\n        var b = (((+new JSBNG__Date()) - this.click_ts));\n        this.listeners[a.type].remove();\n        var c = {\n            click_ts: this.click_ts,\n            length: b,\n            trigger: a.type\n        };\n        this.sendData(ShortClickHandlers.EVENT_NAME_CAME_BACK, c);\n    }\n};\nfunction EmuTracker(a, b) {\n    this.base = EmuController.fromContainer(a);\n    !this.base;\n    this.JSBNG__onsite = b;\n    var c = DOM.scry($(a), ((\"a.\" + EmuController.getEventClass(EmuTracker.EVENT_CLICK))));\n    c.forEach(function(d) {\n        JSBNG__Event.listen(d, \"click\", ShortClickHandlers.JSBNG__onclicked.bind(this));\n    }.bind(this));\n    return this;\n};\n;\ncopyProperties(EmuTracker, {\n    EVENT_CLICK: 1\n});\ncopyProperties(EmuTracker.prototype, {\n    sendData: function(a, b) {\n        this.base.JSBNG__event(a, b);\n    }\n});\n__d(\"legacy:event-extensions\", [\"event-extensions\",], function(a, b, c, d) {\n    b(\"event-extensions\");\n}, 3);\nfunction BassWhitespaceListener(a, b) {\n    this.link = b;\n    JSBNG__Event.listen(a, \"click\", this.JSBNG__onclicked.bind(this));\n};\n;\ncopyProperties(BassWhitespaceListener.prototype, {\n    JSBNG__onclicked: function(a) {\n        if (Parent.byTag(a.getTarget(), \"A\")) {\n            return;\n        }\n    ;\n    ;\n        switch (this.link.getAttribute(\"rel\")) {\n          case \"async\":\n            Bootloader.loadComponents(\"async\", function() {\n                AsyncRequest.bootstrap(this.link.getAttribute(\"ajaxify\"), this.link);\n            }.bind(this));\n            break;\n          case \"theater\":\n            var b = Parent.byClass(a.getTarget(), \"fbPhotoSnowlift\");\n            Bootloader.loadComponents(\"PhotoViewer\", function() {\n                PhotoViewer.bootstrap(this.link.getAttribute(\"ajaxify\"), this.link);\n            }.bind(this));\n            if (b) {\n                return false;\n            }\n        ;\n        ;\n            break;\n          default:\n            goURI(this.link.getAttribute(\"href\"));\n        };\n    ;\n    }\n});\n__d(\"GenderConst\", [], function(a, b, c, d, e, f) {\n    var g = {\n        UNKNOWN: 0,\n        FEMALE_SINGULAR: 1,\n        MALE_SINGULAR: 2,\n        FEMALE_SINGULAR_GUESS: 3,\n        MALE_SINGULAR_GUESS: 4,\n        MIXED_SINGULAR: 5,\n        MIXED_PLURAL: 5,\n        NEUTER_SINGULAR: 6,\n        UNKNOWN_SINGULAR: 7,\n        FEMALE_PLURAL: 8,\n        MALE_PLURAL: 9,\n        NEUTER_PLURAL: 10,\n        UNKNOWN_PLURAL: 11\n    };\n    e.exports = g;\n});\n__d(\"Button\", [\"event-extensions\",\"CSS\",\"DataStore\",\"DOM\",\"Parent\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"CSS\"), h = b(\"DataStore\"), i = b(\"DOM\"), j = b(\"Parent\"), k = \"uiButtonDisabled\", l = \"uiButtonDepressed\", m = \"button:blocker\", n = \"href\", o = \"ajaxify\";\n    function p(t, u) {\n        var v = h.get(t, m);\n        if (u) {\n            if (v) {\n                v.remove();\n                h.remove(t, m);\n            }\n        ;\n        ;\n        }\n         else if (!v) {\n            h.set(t, m, JSBNG__Event.listen(t, \"click\", bagof(false), JSBNG__Event.Priority.URGENT));\n        }\n        \n    ;\n    ;\n    };\n;\n    function q(t) {\n        var u = j.byClass(t, \"uiButton\");\n        if (!u) {\n            throw new Error(\"invalid use case\");\n        }\n    ;\n    ;\n        return u;\n    };\n;\n    function r(t) {\n        return i.isNodeOfType(t, \"a\");\n    };\n;\n    var s = {\n        getInputElement: function(t) {\n            t = q(t);\n            if (r(t)) {\n                throw new Error(\"invalid use case\");\n            }\n        ;\n        ;\n            return i.JSBNG__find(t, \"input\");\n        },\n        isEnabled: function(t) {\n            return !g.hasClass(q(t), k);\n        },\n        setEnabled: function(t, u) {\n            t = q(t);\n            g.conditionClass(t, k, !u);\n            if (r(t)) {\n                var v = t.href, w = t.getAttribute(\"ajaxify\"), x = h.get(t, n, \"#\"), y = h.get(t, o);\n                if (u) {\n                    if (!v) {\n                        t.href = x;\n                    }\n                ;\n                ;\n                    if (((!w && y))) {\n                        t.setAttribute(\"ajaxify\", y);\n                    }\n                ;\n                ;\n                }\n                 else {\n                    if (((v && ((v !== x))))) {\n                        h.set(t, n, v);\n                    }\n                ;\n                ;\n                    if (((w && ((w !== y))))) {\n                        h.set(t, o, w);\n                    }\n                ;\n                ;\n                    t.removeAttribute(\"href\");\n                    t.removeAttribute(\"ajaxify\");\n                }\n            ;\n            ;\n                p(t, u);\n            }\n             else {\n                var z = s.getInputElement(t);\n                z.disabled = !u;\n                p(z, u);\n            }\n        ;\n        ;\n        },\n        setDepressed: function(t, u) {\n            g.conditionClass(q(t), l, u);\n        },\n        isDepressed: function(t) {\n            return g.hasClass(q(t), l);\n        },\n        setLabel: function(t, u) {\n            t = q(t);\n            if (r(t)) {\n                var v = i.JSBNG__find(t, \"span.uiButtonText\");\n                i.setContent(v, u);\n            }\n             else s.getInputElement(t).value = u;\n        ;\n        ;\n            g.conditionClass(t, \"uiButtonNoText\", !u);\n        },\n        setIcon: function(t, u) {\n            if (((u && !i.isNode(u)))) {\n                return;\n            }\n        ;\n        ;\n            t = q(t);\n            var v = i.scry(t, \".img\")[0];\n            if (!u) {\n                ((v && i.remove(v)));\n                return;\n            }\n        ;\n        ;\n            g.addClass(u, \"customimg\");\n            if (((v != u))) {\n                if (v) {\n                    i.replace(v, u);\n                }\n                 else i.prependContent(t, u);\n            ;\n            }\n        ;\n        ;\n        }\n    };\n    e.exports = s;\n});\n__d(\"DOMControl\", [\"DataStore\",\"$\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"DataStore\"), h = b(\"$\"), i = b(\"copyProperties\");\n    function j(k) {\n        this.root = h(k);\n        this.updating = false;\n        g.set(k, \"DOMControl\", this);\n    };\n;\n    i(j.prototype, {\n        getRoot: function() {\n            return this.root;\n        },\n        beginUpdate: function() {\n            if (this.updating) {\n                return false;\n            }\n        ;\n        ;\n            this.updating = true;\n            return true;\n        },\n        endUpdate: function() {\n            this.updating = false;\n        },\n        update: function(k) {\n            if (!this.beginUpdate()) {\n                return this;\n            }\n        ;\n        ;\n            this.JSBNG__onupdate(k);\n            this.endUpdate();\n        },\n        JSBNG__onupdate: function(k) {\n        \n        }\n    });\n    j.getInstance = function(k) {\n        return g.get(k, \"DOMControl\");\n    };\n    e.exports = j;\n});\n__d(\"Input\", [\"CSS\",\"DOMQuery\",\"DOMControl\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"DOMQuery\"), i = b(\"DOMControl\"), j = function(l) {\n        var m = l.getAttribute(\"maxlength\");\n        if (((m && ((m > 0))))) {\n            d([\"enforceMaxLength\",], function(n) {\n                n(l, m);\n            });\n        }\n    ;\n    ;\n    }, k = {\n        JSBNG__focus: function(l) {\n            try {\n                l.JSBNG__focus();\n            } catch (m) {\n            \n            };\n        ;\n        },\n        isEmpty: function(l) {\n            return ((!(/\\S/).test(((l.value || \"\"))) || g.hasClass(l, \"DOMControl_placeholder\")));\n        },\n        getValue: function(l) {\n            return ((k.isEmpty(l) ? \"\" : l.value));\n        },\n        setValue: function(l, m) {\n            g.removeClass(l, \"DOMControl_placeholder\");\n            l.value = ((m || \"\"));\n            j(l);\n            var n = i.getInstance(l);\n            ((((n && n.resetHeight)) && n.resetHeight()));\n        },\n        setPlaceholder: function(l, m) {\n            l.setAttribute(\"aria-label\", m);\n            l.setAttribute(\"placeholder\", m);\n            if (((l == JSBNG__document.activeElement))) {\n                return;\n            }\n        ;\n        ;\n            if (k.isEmpty(l)) {\n                g.conditionClass(l, \"DOMControl_placeholder\", m);\n                l.value = ((m || \"\"));\n            }\n        ;\n        ;\n        },\n        reset: function(l) {\n            var m = ((((l !== JSBNG__document.activeElement)) ? ((l.getAttribute(\"placeholder\") || \"\")) : \"\"));\n            l.value = m;\n            g.conditionClass(l, \"DOMControl_placeholder\", m);\n            l.style.height = \"\";\n        },\n        setSubmitOnEnter: function(l, m) {\n            g.conditionClass(l, \"enter_submit\", m);\n        },\n        getSubmitOnEnter: function(l) {\n            return g.hasClass(l, \"enter_submit\");\n        },\n        setMaxLength: function(l, m) {\n            if (((m > 0))) {\n                l.setAttribute(\"maxlength\", m);\n                j(l);\n            }\n             else l.removeAttribute(\"maxlength\");\n        ;\n        ;\n        }\n    };\n    e.exports = k;\n});\n__d(\"Form\", [\"event-extensions\",\"AsyncRequest\",\"AsyncResponse\",\"CSS\",\"DOM\",\"DOMPosition\",\"DOMQuery\",\"DataStore\",\"Env\",\"Input\",\"Parent\",\"URI\",\"createArrayFrom\",\"trackReferrer\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"AsyncRequest\"), h = b(\"AsyncResponse\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"DOMPosition\"), l = b(\"DOMQuery\"), m = b(\"DataStore\"), n = b(\"Env\"), o = b(\"Input\"), p = b(\"Parent\"), q = b(\"URI\"), r = b(\"createArrayFrom\"), s = b(\"trackReferrer\"), t = ((\"JSBNG__FileList\" in window)), u = ((\"JSBNG__FormData\" in window));\n    function v(x) {\n        var y = {\n        };\n        q.implodeQuery(x).split(\"&\").forEach(function(z) {\n            if (z) {\n                var aa = /^([^=]*)(?:=(.*))?$/.exec(z), ba = q.decodeComponent(aa[1]), ca = ((aa[2] ? q.decodeComponent(aa[2]) : null));\n                y[ba] = ca;\n            }\n        ;\n        ;\n        });\n        return y;\n    };\n;\n    var w = {\n        getInputs: function(x) {\n            x = ((x || JSBNG__document));\n            return [].concat(r(l.scry(x, \"input\")), r(l.scry(x, \"select\")), r(l.scry(x, \"textarea\")), r(l.scry(x, \"button\")));\n        },\n        getSelectValue: function(x) {\n            return x.options[x.selectedIndex].value;\n        },\n        setSelectValue: function(x, y) {\n            for (var z = 0; ((z < x.options.length)); ++z) {\n                if (((x.options[z].value == y))) {\n                    x.selectedIndex = z;\n                    break;\n                }\n            ;\n            ;\n            };\n        ;\n        },\n        getRadioValue: function(x) {\n            for (var y = 0; ((y < x.length)); y++) {\n                if (x[y].checked) {\n                    return x[y].value;\n                }\n            ;\n            ;\n            };\n        ;\n            return null;\n        },\n        getElements: function(x) {\n            return r(((((x.tagName == \"FORM\")) ? x.elements : w.getInputs(x))));\n        },\n        getAttribute: function(x, y) {\n            return ((((x.getAttributeNode(y) || {\n            })).value || null));\n        },\n        setDisabled: function(x, y) {\n            w.getElements(x).forEach(function(z) {\n                if (((z.disabled !== undefined))) {\n                    var aa = m.get(z, \"origDisabledState\");\n                    if (y) {\n                        if (((aa === undefined))) {\n                            m.set(z, \"origDisabledState\", z.disabled);\n                        }\n                    ;\n                    ;\n                        z.disabled = y;\n                    }\n                     else if (((aa !== true))) {\n                        z.disabled = false;\n                    }\n                    \n                ;\n                ;\n                }\n            ;\n            ;\n            });\n        },\n        bootstrap: function(x, y) {\n            var z = ((w.getAttribute(x, \"method\") || \"GET\")).toUpperCase();\n            y = ((p.byTag(y, \"button\") || y));\n            var aa = ((p.byClass(y, \"stat_elem\") || x));\n            if (i.hasClass(aa, \"async_saving\")) {\n                return;\n            }\n        ;\n        ;\n            if (((y && ((((((y.form !== x)) || ((((y.nodeName != \"INPUT\")) && ((y.nodeName != \"BUTTON\")))))) || ((y.type != \"submit\"))))))) {\n                var ba = l.scry(x, \".enter_submit_target\")[0];\n                ((ba && (y = ba)));\n            }\n        ;\n        ;\n            var ca = w.serialize(x, y);\n            w.setDisabled(x, true);\n            var da = ((w.getAttribute(x, \"ajaxify\") || w.getAttribute(x, \"action\")));\n            s(x, da);\n            var ea = new g(da);\n            ea.setData(ca).setNectarModuleDataSafe(x).setReadOnly(((z == \"GET\"))).setMethod(z).setRelativeTo(x).setStatusElement(aa).setInitialHandler(w.setDisabled.curry(x, false)).setHandler(function(fa) {\n                JSBNG__Event.fire(x, \"success\", {\n                    response: fa\n                });\n            }).setErrorHandler(function(fa) {\n                if (((JSBNG__Event.fire(x, \"error\", {\n                    response: fa\n                }) !== false))) {\n                    h.defaultErrorHandler(fa);\n                }\n            ;\n            ;\n            }).setFinallyHandler(w.setDisabled.curry(x, false)).send();\n        },\n        forEachValue: function(x, y, z) {\n            w.getElements(x).forEach(function(aa) {\n                if (((((aa.JSBNG__name && !aa.disabled)) && ((aa.type !== \"submit\"))))) {\n                    if (((((((((((!aa.type || ((((((aa.type === \"radio\")) || ((aa.type === \"checkbox\")))) && aa.checked)))) || ((aa.type === \"text\")))) || ((aa.type === \"password\")))) || ((aa.type === \"hidden\")))) || ((aa.nodeName === \"TEXTAREA\"))))) {\n                        z(aa.type, aa.JSBNG__name, o.getValue(aa));\n                    }\n                     else if (((aa.nodeName === \"SELECT\"))) {\n                        for (var ba = 0, ca = aa.options.length; ((ba < ca)); ba++) {\n                            var da = aa.options[ba];\n                            if (da.selected) {\n                                z(\"select\", aa.JSBNG__name, da.value);\n                            }\n                        ;\n                        ;\n                        };\n                    ;\n                    }\n                     else if (((t && ((aa.type === \"file\"))))) {\n                        var ea = aa.files;\n                        for (var fa = 0; ((fa < ea.length)); fa++) {\n                            z(\"file\", aa.JSBNG__name, ea.item(fa));\n                        ;\n                        };\n                    ;\n                    }\n                    \n                    \n                ;\n                }\n            ;\n            ;\n            });\n            if (((((((((y && y.JSBNG__name)) && ((y.type === \"submit\")))) && l.contains(x, y))) && l.isNodeOfType(y, [\"input\",\"button\",])))) {\n                z(\"submit\", y.JSBNG__name, y.value);\n            }\n        ;\n        ;\n        },\n        createFormData: function(x, y) {\n            if (!u) {\n                return null;\n            }\n        ;\n        ;\n            var z = new JSBNG__FormData();\n            if (x) {\n                if (l.isNode(x)) {\n                    w.forEachValue(x, y, function(ca, da, ea) {\n                        z.append(da, ea);\n                    });\n                }\n                 else {\n                    var aa = v(x);\n                    for (var ba in aa) {\n                        z.append(ba, aa[ba]);\n                    ;\n                    };\n                ;\n                }\n            ;\n            }\n        ;\n        ;\n            return z;\n        },\n        serialize: function(x, y) {\n            var z = {\n            };\n            w.forEachValue(x, y, function(aa, ba, ca) {\n                if (((aa === \"file\"))) {\n                    return;\n                }\n            ;\n            ;\n                w._serializeHelper(z, ba, ca);\n            });\n            return w._serializeFix(z);\n        },\n        _serializeHelper: function(x, y, z) {\n            var aa = Object.prototype.hasOwnProperty, ba = /([^\\]]+)\\[([^\\]]*)\\](.*)/.exec(y);\n            if (ba) {\n                if (((!x[ba[1]] || !aa.call(x, ba[1])))) {\n                    var ca;\n                    x[ba[1]] = ca = {\n                    };\n                    if (((x[ba[1]] !== ca))) {\n                        return;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                var da = 0;\n                if (((ba[2] === \"\"))) {\n                    while (((x[ba[1]][da] !== undefined))) {\n                        da++;\n                    ;\n                    };\n                ;\n                }\n                 else da = ba[2];\n            ;\n            ;\n                if (((ba[3] === \"\"))) {\n                    x[ba[1]][da] = z;\n                }\n                 else w._serializeHelper(x[ba[1]], da.concat(ba[3]), z);\n            ;\n            ;\n            }\n             else x[y] = z;\n        ;\n        ;\n        },\n        _serializeFix: function(x) {\n            var y = [];\n            for (var z in x) {\n                if (((x[z] instanceof Object))) {\n                    x[z] = w._serializeFix(x[z]);\n                }\n            ;\n            ;\n                y.push(z);\n            };\n        ;\n            if (((y.length > 0))) {\n                var aa = 0, ba = true;\n                y.sort().forEach(function(da) {\n                    if (((da != aa++))) {\n                        ba = false;\n                    }\n                ;\n                ;\n                });\n                if (ba) {\n                    var ca = [];\n                    y.forEach(function(da) {\n                        ca[da] = x[da];\n                    });\n                    return ca;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            return x;\n        },\n        post: function(x, y, z) {\n            var aa = JSBNG__document.createElement(\"form\");\n            aa.action = x.toString();\n            aa.method = \"POST\";\n            aa.style.display = \"none\";\n            if (z) {\n                aa.target = z;\n            }\n        ;\n        ;\n            y.fb_dtsg = n.fb_dtsg;\n            w.createHiddenInputs(y, aa);\n            l.getRootElement().appendChild(aa);\n            aa.submit();\n            return false;\n        },\n        createHiddenInputs: function(x, y, z, aa) {\n            z = ((z || {\n            }));\n            var ba = v(x);\n            for (var ca in ba) {\n                if (((ba[ca] === null))) {\n                    continue;\n                }\n            ;\n            ;\n                if (((z[ca] && aa))) {\n                    z[ca].value = ba[ca];\n                }\n                 else {\n                    var da = j.create(\"input\", {\n                        type: \"hidden\",\n                        JSBNG__name: ca,\n                        value: ba[ca]\n                    });\n                    z[ca] = da;\n                    y.appendChild(da);\n                }\n            ;\n            ;\n            };\n        ;\n            return z;\n        },\n        getFirstElement: function(x, y) {\n            y = ((y || [\"input[type=\\\"text\\\"]\",\"textarea\",\"input[type=\\\"password\\\"]\",\"input[type=\\\"button\\\"]\",\"input[type=\\\"submit\\\"]\",]));\n            var z = [];\n            for (var aa = 0; ((aa < y.length)); aa++) {\n                z = l.scry(x, y[aa]);\n                for (var ba = 0; ((ba < z.length)); ba++) {\n                    var ca = z[ba];\n                    try {\n                        var ea = k.getElementPosition(ca);\n                        if (((((ea.y > 0)) && ((ea.x > 0))))) {\n                            return ca;\n                        }\n                    ;\n                    ;\n                    } catch (da) {\n                    \n                    };\n                ;\n                };\n            ;\n            };\n        ;\n            return null;\n        },\n        focusFirst: function(x) {\n            var y = w.getFirstElement(x);\n            if (y) {\n                y.JSBNG__focus();\n                return true;\n            }\n        ;\n        ;\n            return false;\n        }\n    };\n    e.exports = w;\n});\n__d(\"AsyncUploadBase\", [\"ArbiterMixin\",\"AsyncRequest\",\"AsyncResponse\",\"Form\",\"UserAgent\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"ArbiterMixin\"), h = b(\"AsyncRequest\"), i = b(\"AsyncResponse\"), j = b(\"Form\"), k = b(\"UserAgent\"), l = b(\"copyProperties\");\n    function m(o) {\n        this.setURI(o);\n    };\n;\n    m.isSupported = function() {\n        if (((((k.safari() && !k.JSBNG__chrome())) && k.windows()))) {\n            return false;\n        }\n    ;\n    ;\n        return ((((\"JSBNG__FileList\" in window)) && ((\"JSBNG__FormData\" in window))));\n    };\n    l(m.prototype, g, {\n        _limit: 10,\n        setAllowCrossOrigin: function(o) {\n            this._allowCrossOrigin = !!o;\n            return this;\n        },\n        setData: function(o) {\n            this._data = o;\n            return this;\n        },\n        setLimit: function(o) {\n            this._limit = o;\n            return this;\n        },\n        setRelativeTo: function(o) {\n            this._relativeTo = o;\n            return this;\n        },\n        setStatusElement: function(o) {\n            this._statusElement = o;\n            return this;\n        },\n        setURI: function(o) {\n            this._uri = o;\n            return this;\n        },\n        _createFileUpload: function(o, p) {\n            return new n(o, p);\n        },\n        _parseFiles: function(o) {\n            var p = {\n            };\n            for (var q in o) {\n                var r = o[q];\n                if (Array.isArray(r)) {\n                    p[q] = r;\n                }\n                 else {\n                    p[q] = [];\n                    if (((r instanceof window.JSBNG__FileList))) {\n                        for (var s = 0; ((s < r.length)); s++) {\n                            p[q].push(r.item(s));\n                        ;\n                        };\n                    ;\n                    }\n                     else if (((((r instanceof window.JSBNG__File)) || ((r instanceof window.JSBNG__Blob))))) {\n                        p[q].push(r);\n                    }\n                    \n                ;\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            return p;\n        },\n        _processQueue: function() {\n            while (((this._pending.length < this._limit))) {\n                if (!this._waiting.length) {\n                    break;\n                }\n            ;\n            ;\n                var o = this._waiting.shift();\n                this._processUpload(o);\n                this._pending.push(o);\n            };\n        ;\n        },\n        _processUpload: function(o) {\n            this.inform(\"start\", o);\n            var p = j.createFormData(this._data);\n            if (o.getFile()) {\n                p.append(o.getName(), o.getFile());\n            }\n        ;\n        ;\n            new h().setAllowCrossOrigin(this._allowCrossOrigin).setURI(this._uri).setRawData(p).setRelativeTo(this._relativeTo).setStatusElement(this._statusElement).setHandler(this._success.bind(this, o)).setErrorHandler(this._failure.bind(this, o)).setUploadProgressHandler(this._progress.bind(this, o)).setInitialHandler(this._initial.bind(this, o)).send();\n        },\n        _initial: function(o) {\n            this.inform(\"initial\", o);\n        },\n        _success: function(o, p) {\n            this.inform(\"success\", o.handleSuccess(p));\n            this._complete(o);\n        },\n        _failure: function(o, p) {\n            if (((this.inform(\"failure\", o.handleFailure(p)) !== false))) {\n                i.defaultErrorHandler(p);\n            }\n        ;\n        ;\n            this._complete(o);\n        },\n        _progress: function(o, JSBNG__event) {\n            this.inform(\"progress\", o.handleProgress(JSBNG__event));\n        },\n        _complete: function(o) {\n            this._pending.remove(o);\n            this._processQueue();\n            if (!this._pending.length) {\n                this._inFlight = false;\n            }\n        ;\n        ;\n        }\n    });\n    var n = function(o, p) {\n        this._name = o;\n        this._file = p;\n        this._success = null;\n        this._response = null;\n        this._progressEvent = null;\n    };\n    l(n.prototype, {\n        getName: function() {\n            return this._name;\n        },\n        getFile: function() {\n            return this._file;\n        },\n        isComplete: function() {\n            return ((this._success !== null));\n        },\n        isSuccess: function() {\n            return ((this._success === true));\n        },\n        getResponse: function() {\n            return this._response;\n        },\n        getProgressEvent: function() {\n            return this._progressEvent;\n        },\n        handleSuccess: function(o) {\n            this._success = true;\n            this._response = o;\n            this._progressEvent = null;\n            return this;\n        },\n        handleFailure: function(o) {\n            this._success = false;\n            this._response = o;\n            this._progressEvent = null;\n            return this;\n        },\n        handleProgress: function(JSBNG__event) {\n            this._progressEvent = JSBNG__event;\n            return this;\n        }\n    });\n    e.exports = m;\n});\n__d(\"AsyncUploadRequest\", [\"AsyncUploadBase\",\"Class\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncUploadBase\"), h = b(\"Class\"), i = b(\"copyProperties\");\n    function j(k) {\n        this.parent.construct(this, k);\n    };\n;\n    j.isSupported = function() {\n        return g.isSupported();\n    };\n    h.extend(j, g);\n    i(j.prototype, {\n        setFiles: function(k) {\n            this._files = this._parseFiles(k);\n            return this;\n        },\n        send: function() {\n            if (this._inFlight) {\n                return;\n            }\n        ;\n        ;\n            this._inFlight = true;\n            this._uploads = [];\n            for (var k in this._files) {\n                this._files[k].forEach(function(l) {\n                    this._uploads.push(this._createFileUpload(k, l));\n                }.bind(this));\n            ;\n            };\n        ;\n            if (this._uploads.length) {\n                this._waiting = this._uploads.slice(0);\n                this._pending = [];\n                this._processQueue();\n            }\n             else this._processUpload(this._createFileUpload(null, null));\n        ;\n        ;\n        },\n        _complete: function(k) {\n            this.parent._complete(k);\n            if (!this._pending.length) {\n                this.inform(\"complete\", this._uploads);\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = j;\n});\n__d(\"JSONPTransport\", [\"DOM\",\"HTML\",\"URI\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"HTML\"), i = b(\"URI\"), j = b(\"copyProperties\"), k = {\n    }, l = 2, m = \"jsonp\", n = \"div\";\n    function o(p, q, r) {\n        this._type = p;\n        this._uri = q;\n        this._handler = r;\n        k[this.getID()] = this;\n    };\n;\n    j(o, {\n        respond: function(p, q, r) {\n            var s = k[p];\n            if (s) {\n                if (!r) {\n                    delete k[p];\n                }\n            ;\n            ;\n                if (((s._type == n))) {\n                    q = JSON.parse(JSON.stringify(q));\n                }\n            ;\n            ;\n                a.async_callback(s.handleResponse.bind(s), \"json\")(q);\n            }\n             else if (((a.logJSError && !r))) {\n                a.logJSError(\"ajax\", {\n                    error: \"UnexpectedJsonResponse\",\n                    extra: {\n                        id: p,\n                        uri: ((((q.payload && q.payload.uri)) || \"\"))\n                    }\n                });\n            }\n            \n        ;\n        ;\n        }\n    });\n    j(o.prototype, {\n        getID: function() {\n            return ((this._id || (this._id = l++)));\n        },\n        hasFinished: function() {\n            return !((this.getID() in k));\n        },\n        getRequestURI: function() {\n            return i(this._uri).addQueryData({\n                __a: 1,\n                __adt: this.getID()\n            });\n        },\n        createTransportFrame: function() {\n            var p = ((\"transport_frame_\" + this.getID())), q = h(((((\"\\u003Ciframe class=\\\"hidden_elem\\\" name=\\\"\" + p)) + \"\\\" src=\\\"javascript:void(0)\\\" /\\u003E\")));\n            return g.appendContent(JSBNG__document.body, q)[0];\n        },\n        send: function() {\n            if (((this._type === m))) {\n                (function() {\n                    g.appendContent(JSBNG__document.body, g.create(\"script\", {\n                        src: this.getRequestURI().toString(),\n                        type: \"text/javascript\"\n                    }));\n                }).bind(this).defer();\n            }\n             else {\n                this._iframe = this.createTransportFrame();\n                this._iframe.src = this.getRequestURI().toString();\n            }\n        ;\n        ;\n        },\n        handleResponse: function(p) {\n            if (!this._aborted) {\n                this._handler(p);\n            }\n        ;\n        ;\n            if (this.hasFinished()) {\n                if (this._iframe) {\n                    g.remove.curry(this._iframe).defer();\n                    this._iframe = null;\n                }\n            ;\n            }\n        ;\n        ;\n        },\n        abort: function() {\n            this._aborted = true;\n        }\n    });\n    e.exports = o;\n});\n__d(\"FileForm\", [\"event-extensions\",\"ArbiterMixin\",\"AsyncRequest\",\"AsyncUploadRequest\",\"AsyncResponse\",\"BehaviorsMixin\",\"DataStore\",\"DOMQuery\",\"Env\",\"Form\",\"JSONPTransport\",\"Parent\",\"URI\",\"UserAgent\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"AsyncRequest\"), i = b(\"AsyncUploadRequest\"), j = b(\"AsyncResponse\"), k = b(\"BehaviorsMixin\"), l = b(\"DataStore\"), m = b(\"DOMQuery\"), n = b(\"Env\"), o = b(\"Form\"), p = b(\"JSONPTransport\"), q = b(\"Parent\"), r = b(\"URI\"), s = b(\"UserAgent\"), t = b(\"copyProperties\");\n    function u(w) {\n        var x = {\n        }, y = m.scry(w, \"input[type=\\\"file\\\"]\");\n        y.forEach(function(z) {\n            x[z.JSBNG__name] = z.files;\n        });\n        return x;\n    };\n;\n    function v(w, x, y) {\n        if (((w.getAttribute(\"rel\") === \"async\"))) {\n            throw new Error(\"FileForm cannot be used with Primer forms.\");\n        }\n    ;\n    ;\n        if (((w.getAttribute(\"method\").toUpperCase() !== \"POST\"))) {\n            throw new Error(\"FileForm must be used with POST forms.\");\n        }\n    ;\n    ;\n        this._form = w;\n        this._form.enctype = this._form.encoding = \"multipart/form-data\";\n        ((x && this.enableBehaviors(x)));\n        this._options = ((y || {\n        }));\n        this.setAllowCrossOrigin(this._options.allowCrossOrigin);\n        this.setUploadInParallel(this._options.uploadInParallel);\n        this._listener = JSBNG__Event.listen(this._form, \"submit\", this._submit.bind(this));\n        l.set(this._form, \"FileForm\", this);\n    };\n;\n    t(v, {\n        EVENTS: [\"submit\",\"initial\",\"progress\",\"success\",\"failure\",],\n        getInstance: function(w) {\n            return l.get(w, \"FileForm\");\n        }\n    });\n    t(v.prototype, g, k, {\n        getRoot: function() {\n            return this._form;\n        },\n        setAllowCrossOrigin: function(w) {\n            this._allowCrossOrigin = !!w;\n            return this;\n        },\n        setUploadInParallel: function(w) {\n            this._uploadInParallel = !!w;\n            return this;\n        },\n        _submit: function(JSBNG__event) {\n            if (((this.inform(\"submit\") === false))) {\n                JSBNG__event.prevent();\n                return;\n            }\n        ;\n        ;\n            var w = ((\"JSBNG__FormData\" in window));\n            if (w) {\n                if (((!r(this._form.action).isSameOrigin() && !this._allowCrossOrigin))) {\n                    w = false;\n                }\n            ;\n            }\n        ;\n        ;\n            return ((w ? this._sendViaXHR(JSBNG__event) : this._sendViaFrame(JSBNG__event)));\n        },\n        _sendViaFrame: function(JSBNG__event) {\n            var w = new h();\n            w.setStatusElement(this._getStatusElement());\n            w.addStatusIndicator();\n            w.setOption(\"useIframeTransport\", true);\n            var x = w.handleResponse.bind(w), y = new p(\"div\", this._form.action, x), z = y.createTransportFrame(), aa = y.getRequestURI().addQueryData({\n                __iframe: true,\n                __user: n.user\n            });\n            this._form.setAttribute(\"action\", aa.toString());\n            this._form.setAttribute(\"target\", z.JSBNG__name);\n            w.setURI(aa);\n            w.setHandler(this.success.bind(this, null));\n            w.setErrorHandler(this.failure.bind(this, null));\n            w.setInitialHandler(this.initial.shield(this, null));\n        },\n        _sendViaXHR: function(JSBNG__event) {\n            var w;\n            if (((this._uploadInParallel && i.isSupported()))) {\n                w = new i().setData(o.serialize(this._form)).setFiles(u(this._form));\n                var x = [w.subscribe(\"progress\", function(y, z) {\n                    this.progress(z, z.getProgressEvent());\n                }.bind(this)),w.subscribe(\"initial\", function(y, z) {\n                    this.initial(z, z.getResponse());\n                }.bind(this)),w.subscribe(\"success\", function(y, z) {\n                    this.success(z, z.getResponse());\n                }.bind(this)),w.subscribe(\"failure\", function(y, z) {\n                    this.failure(z, z.getResponse());\n                    return false;\n                }.bind(this)),w.subscribe(\"complete\", function() {\n                    while (x.length) {\n                        x.pop().unsubscribe();\n                    ;\n                    };\n                ;\n                }),];\n            }\n             else w = new h().setRawData(o.createFormData(this._form)).setHandler(this.success.bind(this, null)).setErrorHandler(this.failure.bind(this, null)).setUploadProgressHandler(this.progress.bind(this, null)).setInitialHandler(this.initial.shield(this, null));\n        ;\n        ;\n            w.setAllowCrossOrigin(this._allowCrossOrigin).setRelativeTo(this._form).setStatusElement(this._getStatusElement()).setURI(this._form.action).send();\n            JSBNG__event.prevent();\n        },\n        initial: function(w) {\n            return this.inform(\"initial\", {\n                upload: w\n            });\n        },\n        success: function(w, x) {\n            var y = {\n                response: x,\n                upload: w\n            };\n            if (((this.inform(\"success\", y) !== false))) {\n                JSBNG__Event.fire(this._form, \"success\", y);\n            }\n        ;\n        ;\n        },\n        failure: function(w, x) {\n            var y = {\n                response: x,\n                upload: w\n            };\n            if (((this.inform(\"failure\", y) !== false))) {\n                if (((JSBNG__Event.fire(this._form, \"error\", y) !== false))) {\n                    j.defaultErrorHandler(x);\n                }\n            ;\n            }\n        ;\n        ;\n        },\n        progress: function(w, JSBNG__event) {\n            this.inform(\"progress\", {\n                JSBNG__event: JSBNG__event,\n                upload: w\n            });\n        },\n        destroy: function() {\n            this._listener.remove();\n            this._listener = null;\n            if (((isNaN(s.ie()) || ((s.ie() > 8))))) {\n                this._form.encoding = null;\n            }\n        ;\n        ;\n            this._form.enctype = null;\n            l.remove(this._form, \"FileForm\");\n        },\n        _getStatusElement: function() {\n            return ((q.byClass(this._form, \"stat_elem\") || this._form));\n        }\n    });\n    e.exports = v;\n});\n__d(\"goOrReplace\", [\"URI\",\"UserAgent\",], function(a, b, c, d, e, f) {\n    var g = b(\"URI\"), h = b(\"UserAgent\");\n    function i(j, k, l) {\n        var m = new g(k);\n        if (((((((j.pathname == \"/\")) && ((m.getPath() != \"/\")))) && m.isQuicklingEnabled()))) {\n            var n = ((j.search ? {\n            } : {\n                q: \"\"\n            }));\n            m = new g().setPath(\"/\").setQueryData(n).setFragment(m.getUnqualifiedURI()).toString();\n            k = m.toString();\n        }\n    ;\n    ;\n        if (((l && !((h.ie() < 8))))) {\n            j.replace(k);\n        }\n         else if (((j.href == k))) {\n            j.reload();\n        }\n         else j.href = k;\n        \n    ;\n    ;\n    };\n;\n    e.exports = i;\n});\n__d(\"AjaxPipeRequest\", [\"Arbiter\",\"AsyncRequest\",\"BigPipe\",\"DOM\",\"Env\",\"JSCC\",\"ScriptPathState\",\"copyProperties\",\"goOrReplace\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"BigPipe\"), j = b(\"DOM\"), k = b(\"Env\"), l = b(\"JSCC\"), m = b(\"ScriptPathState\"), n = b(\"copyProperties\"), o = b(\"goOrReplace\"), p = b(\"ge\"), q;\n    function r(u, v) {\n        var w = p(u);\n        if (w) {\n            if (!v) {\n                w.style.minHeight = \"600px\";\n            }\n        ;\n        ;\n            for (var x in i.pageletIDs) {\n                if (((((u !== x)) && j.contains(w, x)))) {\n                    g.inform(\"ajaxpipe/clear_pagelet\", {\n                        pagelet_id: x\n                    });\n                    l.clearForPagelet(x);\n                    delete i.pageletIDs[x];\n                }\n            ;\n            ;\n            };\n        ;\n            j.empty(w);\n        }\n    ;\n    ;\n    };\n;\n    function s(u, v) {\n        var w = p(u);\n        if (w) {\n            if (!v) {\n                w.style.minHeight = \"100px\";\n            }\n        ;\n        }\n    ;\n    ;\n    };\n;\n    function t(u, v) {\n        this._uri = u;\n        this._query_data = v;\n        this._request = new h();\n        this._canvas_id = null;\n        this._allow_cross_page_transition = true;\n    };\n;\n    n(t.prototype, {\n        setCanvasId: function(u) {\n            this._canvas_id = u;\n            return this;\n        },\n        setURI: function(u) {\n            this._uri = u;\n            return this;\n        },\n        setData: function(u) {\n            this._query_data = u;\n            return this;\n        },\n        getData: function(u) {\n            return this._query_data;\n        },\n        setAllowCrossPageTransition: function(u) {\n            this._allow_cross_page_transition = u;\n            return this;\n        },\n        setAppend: function(u) {\n            this._append = u;\n            return this;\n        },\n        send: function() {\n            var u = {\n                ajaxpipe: 1,\n                ajaxpipe_token: k.ajaxpipe_token\n            };\n            n(u, m.getParams());\n            m.reset();\n            if (this._pageletCacheMiss) {\n                u.pcmiss = 1;\n            }\n        ;\n        ;\n            this._request.setOption(\"useIframeTransport\", true).setURI(this._uri).setData(n(u, this._query_data)).setPreBootloadHandler(this._preBootloadHandler.bind(this)).setInitialHandler(this._onInitialResponse.bind(this)).setHandler(this._onResponse.bind(this)).setMethod(\"GET\").setReadOnly(true).setAllowCrossPageTransition(this._allow_cross_page_transition);\n            if (this._automatic) {\n                this._relevantRequest = q;\n            }\n             else q = this._request;\n        ;\n        ;\n            this._request.send();\n            return this;\n        },\n        _preBootloadFirstResponse: function(u) {\n            return false;\n        },\n        _fireDomContentCallback: function() {\n            this._arbiter.inform(\"ajaxpipe/domcontent_callback\", true, g.BEHAVIOR_STATE);\n        },\n        _fireOnloadCallback: function() {\n            this._arbiter.inform(\"ajaxpipe/onload_callback\", true, g.BEHAVIOR_STATE);\n        },\n        _isRelevant: function(u) {\n            return ((((((((this._request == q)) || ((this._automatic && ((this._relevantRequest == q)))))) || this._jsNonBlock)) || this._forceFinish));\n        },\n        _preBootloadHandler: function(u) {\n            var v = u.getPayload();\n            if (((((!v || v.redirect)) || !this._isRelevant(u)))) {\n                return false;\n            }\n        ;\n        ;\n            var w = false;\n            if (u.is_first) {\n                ((((!this._append && !this._displayCallback)) && r(this._canvas_id, this._constHeight)));\n                this._arbiter = new g();\n                w = this._preBootloadFirstResponse(u);\n                this.pipe = new i({\n                    arbiter: this._arbiter,\n                    rootNodeID: this._canvas_id,\n                    lid: this._request.lid,\n                    isAjax: true,\n                    domContentCallback: this._fireDomContentCallback.bind(this),\n                    JSBNG__onloadCallback: this._fireOnloadCallback.bind(this),\n                    domContentEvt: \"ajaxpipe/domcontent_callback\",\n                    JSBNG__onloadEvt: \"ajaxpipe/onload_callback\",\n                    jsNonBlock: this._jsNonBlock,\n                    forceFinish: this._forceFinish,\n                    automatic: this._automatic,\n                    displayCallback: this._displayCallback\n                });\n            }\n        ;\n        ;\n            return w;\n        },\n        _redirect: function(u) {\n            if (u.redirect) {\n                if (((u.force || !this.isPageActive(u.redirect)))) {\n                    var v = [\"ajaxpipe\",\"ajaxpipe_token\",].concat(this.getSanitizedParameters());\n                    o(window.JSBNG__location, URI(u.redirect).removeQueryData(v), true);\n                }\n                 else PageTransitions.go(u.redirect, true);\n            ;\n            ;\n                return true;\n            }\n             else return false\n        ;\n        },\n        isPageActive: function(u) {\n            return true;\n        },\n        getSanitizedParameters: function() {\n            return [];\n        },\n        _versionCheck: function(u) {\n            return true;\n        },\n        _onInitialResponse: function(u) {\n            var v = u.getPayload();\n            if (!this._isRelevant(u)) {\n                return false;\n            }\n        ;\n        ;\n            if (!v) {\n                return true;\n            }\n        ;\n        ;\n            if (((this._redirect(v) || !this._versionCheck(v)))) {\n                return false;\n            }\n        ;\n        ;\n            return true;\n        },\n        _processFirstResponse: function(u) {\n            var v = u.getPayload();\n            if (((p(this._canvas_id) && ((v.canvas_class !== null))))) {\n                CSS.setClass(this._canvas_id, v.canvas_class);\n            }\n        ;\n        ;\n        },\n        setFirstResponseCallback: function(u) {\n            this._firstResponseCallback = u;\n            return this;\n        },\n        setFirstResponseHandler: function(u) {\n            this._processFirstResponse = u;\n            return this;\n        },\n        _onResponse: function(u) {\n            var v = u.payload;\n            if (!this._isRelevant(u)) {\n                return h.suppressOnloadToken;\n            }\n        ;\n        ;\n            if (u.is_first) {\n                this._processFirstResponse(u);\n                ((this._firstResponseCallback && this._firstResponseCallback()));\n                v.provides = ((v.provides || []));\n                v.provides.push(\"uipage_onload\");\n                if (this._append) {\n                    v.append = this._canvas_id;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            if (v) {\n                if (((((((\"JSBNG__content\" in v.JSBNG__content)) && ((this._canvas_id !== null)))) && ((this._canvas_id != \"JSBNG__content\"))))) {\n                    v.JSBNG__content[this._canvas_id] = v.JSBNG__content.JSBNG__content;\n                    delete v.JSBNG__content.JSBNG__content;\n                }\n            ;\n            ;\n                if (((this._pageletCacheMiss && u.is_first))) {\n                    v.id = this._pageletCacheMiss.id;\n                    v.cacheable = true;\n                    v.cache_controller = this._pageletCacheMiss.cache_controller;\n                    v.cache_type = this._pageletCacheMiss.cache_type;\n                    v.key = this._pageletCacheMiss.key;\n                }\n            ;\n            ;\n                this.pipe.JSBNG__onPageletArrive(v);\n            }\n        ;\n        ;\n            if (u.is_last) {\n                s(this._canvas_id, this._constHeight);\n            }\n        ;\n        ;\n            return h.suppressOnloadToken;\n        },\n        setNectarModuleDataSafe: function(u) {\n            this._request.setNectarModuleDataSafe(u);\n            return this;\n        },\n        setFinallyHandler: function(u) {\n            this._request.setFinallyHandler(u);\n            return this;\n        },\n        setErrorHandler: function(u) {\n            this._request.setErrorHandler(u);\n            return this;\n        },\n        abort: function() {\n            this._request.abort();\n            if (((q == this._request))) {\n                q = null;\n            }\n        ;\n        ;\n            this._request = null;\n            return this;\n        },\n        setJSNonBlock: function(u) {\n            this._jsNonBlock = u;\n            return this;\n        },\n        setForceFinish: function(u) {\n            this._forceFinish = u;\n            return this;\n        },\n        setAutomatic: function(u) {\n            this._automatic = u;\n            return this;\n        },\n        setDisplayCallback: function(u) {\n            this._displayCallback = u;\n            return this;\n        },\n        setPageletCacheMiss: function(u) {\n            this._pageletCacheMiss = u;\n            return this;\n        },\n        setConstHeight: function(u) {\n            this._constHeight = u;\n            return this;\n        },\n        getAsyncRequest: function() {\n            return this._request;\n        }\n    });\n    n(t, {\n        getCurrentRequest: function() {\n            return q;\n        },\n        setCurrentRequest: function(u) {\n            q = u;\n        }\n    });\n    e.exports = t;\n});\n__d(\"Animation\", [\"CSS\",\"DOM\",\"Style\",\"UserAgent\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"Style\"), j = b(\"UserAgent\");\n    function k(l) {\n        if (((a == this))) {\n            return new k(l);\n        }\n         else {\n            this.obj = l;\n            this._reset_state();\n            this.queue = [];\n            this.last_attr = null;\n        }\n    ;\n    ;\n    };\n;\n    k.resolution = 20;\n    k.offset = 0;\n    k.prototype._reset_state = function() {\n        this.state = {\n            attrs: {\n            },\n            duration: 500\n        };\n    };\n    k.prototype.JSBNG__stop = function() {\n        this._reset_state();\n        this.queue = [];\n        return this;\n    };\n    k.prototype._build_container = function() {\n        if (this.container_div) {\n            this._refresh_container();\n            return;\n        }\n    ;\n    ;\n        if (((this.obj.firstChild && this.obj.firstChild.__animation_refs))) {\n            this.container_div = this.obj.firstChild;\n            this.container_div.__animation_refs++;\n            this._refresh_container();\n            return;\n        }\n    ;\n    ;\n        var l = JSBNG__document.createElement(\"div\");\n        l.style.padding = \"0px\";\n        l.style.margin = \"0px\";\n        l.style.border = \"0px\";\n        l.__animation_refs = 1;\n        var m = this.obj.childNodes;\n        while (m.length) {\n            l.appendChild(m[0]);\n        ;\n        };\n    ;\n        this.obj.appendChild(l);\n        this._orig_overflow = this.obj.style.overflow;\n        this.obj.style.overflow = \"hidden\";\n        this.container_div = l;\n        this._refresh_container();\n    };\n    k.prototype._refresh_container = function() {\n        this.container_div.style.height = \"auto\";\n        this.container_div.style.width = \"auto\";\n        this.container_div.style.height = ((this.container_div.offsetHeight + \"px\"));\n        this.container_div.style.width = ((this.container_div.offsetWidth + \"px\"));\n    };\n    k.prototype._destroy_container = function() {\n        if (!this.container_div) {\n            return;\n        }\n    ;\n    ;\n        if (!--this.container_div.__animation_refs) {\n            var l = this.container_div.childNodes;\n            while (l.length) {\n                this.obj.appendChild(l[0]);\n            ;\n            };\n        ;\n            this.obj.removeChild(this.container_div);\n        }\n    ;\n    ;\n        this.container_div = null;\n        this.obj.style.overflow = this._orig_overflow;\n    };\n    k.ATTR_TO = 1;\n    k.ATTR_BY = 2;\n    k.ATTR_FROM = 3;\n    k.prototype._attr = function(l, m, n) {\n        l = l.replace(/-[a-z]/gi, function(p) {\n            return p.substring(1).toUpperCase();\n        });\n        var o = false;\n        switch (l) {\n          case \"background\":\n            this._attr(\"backgroundColor\", m, n);\n            return this;\n          case \"margin\":\n            m = k.parse_group(m);\n            this._attr(\"marginBottom\", m[0], n);\n            this._attr(\"marginLeft\", m[1], n);\n            this._attr(\"marginRight\", m[2], n);\n            this._attr(\"marginTop\", m[3], n);\n            return this;\n          case \"padding\":\n            m = k.parse_group(m);\n            this._attr(\"paddingBottom\", m[0], n);\n            this._attr(\"paddingLeft\", m[1], n);\n            this._attr(\"paddingRight\", m[2], n);\n            this._attr(\"paddingTop\", m[3], n);\n            return this;\n          case \"backgroundColor\":\n        \n          case \"borderColor\":\n        \n          case \"color\":\n            m = k.parse_color(m);\n            break;\n          case \"opacity\":\n            m = parseFloat(m, 10);\n            break;\n          case \"height\":\n        \n          case \"width\":\n            if (((m == \"auto\"))) {\n                o = true;\n            }\n             else m = parseInt(m, 10);\n        ;\n        ;\n            break;\n          case \"borderWidth\":\n        \n          case \"lineHeight\":\n        \n          case \"fontSize\":\n        \n          case \"marginBottom\":\n        \n          case \"marginLeft\":\n        \n          case \"marginRight\":\n        \n          case \"marginTop\":\n        \n          case \"paddingBottom\":\n        \n          case \"paddingLeft\":\n        \n          case \"paddingRight\":\n        \n          case \"paddingTop\":\n        \n          case \"bottom\":\n        \n          case \"left\":\n        \n          case \"right\":\n        \n          case \"JSBNG__top\":\n        \n          case \"scrollTop\":\n        \n          case \"scrollLeft\":\n            m = parseInt(m, 10);\n            break;\n          default:\n            throw new Error(((l + \" is not a supported attribute!\")));\n        };\n    ;\n        if (((this.state.attrs[l] === undefined))) {\n            this.state.attrs[l] = {\n            };\n        }\n    ;\n    ;\n        if (o) {\n            this.state.attrs[l].auto = true;\n        }\n    ;\n    ;\n        switch (n) {\n          case k.ATTR_FROM:\n            this.state.attrs[l].start = m;\n            break;\n          case k.ATTR_BY:\n            this.state.attrs[l].by = true;\n          case k.ATTR_TO:\n            this.state.attrs[l].value = m;\n            break;\n        };\n    ;\n    };\n    k._get_box_width = function(l) {\n        var m = parseInt(i.get(l, \"paddingLeft\"), 10), n = parseInt(i.get(l, \"paddingRight\"), 10), o = parseInt(i.get(l, \"borderLeftWidth\"), 10), p = parseInt(i.get(l, \"borderRightWidth\"), 10);\n        return ((((((((l.offsetWidth - ((m ? m : 0)))) - ((n ? n : 0)))) - ((o ? o : 0)))) - ((p ? p : 0))));\n    };\n    k._get_box_height = function(l) {\n        var m = parseInt(i.get(l, \"paddingTop\"), 10), n = parseInt(i.get(l, \"paddingBottom\"), 10), o = parseInt(i.get(l, \"borderTopWidth\"), 10), p = parseInt(i.get(l, \"borderBottomWidth\"), 10);\n        return ((((((((l.offsetHeight - ((m ? m : 0)))) - ((n ? n : 0)))) - ((o ? o : 0)))) - ((p ? p : 0))));\n    };\n    k.prototype.to = function(l, m) {\n        if (((m === undefined))) {\n            this._attr(this.last_attr, l, k.ATTR_TO);\n        }\n         else {\n            this._attr(l, m, k.ATTR_TO);\n            this.last_attr = l;\n        }\n    ;\n    ;\n        return this;\n    };\n    k.prototype.by = function(l, m) {\n        if (((m === undefined))) {\n            this._attr(this.last_attr, l, k.ATTR_BY);\n        }\n         else {\n            this._attr(l, m, k.ATTR_BY);\n            this.last_attr = l;\n        }\n    ;\n    ;\n        return this;\n    };\n    k.prototype.from = function(l, m) {\n        if (((m === undefined))) {\n            this._attr(this.last_attr, l, k.ATTR_FROM);\n        }\n         else {\n            this._attr(l, m, k.ATTR_FROM);\n            this.last_attr = l;\n        }\n    ;\n    ;\n        return this;\n    };\n    k.prototype.duration = function(l) {\n        this.state.duration = ((l ? l : 0));\n        return this;\n    };\n    k.prototype.checkpoint = function(l, m) {\n        if (((l === undefined))) {\n            l = 1;\n        }\n    ;\n    ;\n        this.state.checkpoint = l;\n        this.queue.push(this.state);\n        this._reset_state();\n        this.state.checkpointcb = m;\n        return this;\n    };\n    k.prototype.blind = function() {\n        this.state.blind = true;\n        return this;\n    };\n    k.prototype.hide = function() {\n        this.state.hide = true;\n        return this;\n    };\n    k.prototype.show = function() {\n        this.state.show = true;\n        return this;\n    };\n    k.prototype.ease = function(l) {\n        this.state.ease = l;\n        return this;\n    };\n    k.prototype.go = function() {\n        var l = (new JSBNG__Date()).getTime();\n        this.queue.push(this.state);\n        for (var m = 0; ((m < this.queue.length)); m++) {\n            this.queue[m].start = ((l - k.offset));\n            if (this.queue[m].checkpoint) {\n                l += ((this.queue[m].checkpoint * this.queue[m].duration));\n            }\n        ;\n        ;\n        };\n    ;\n        k.push(this);\n        return this;\n    };\n    k.prototype._show = function() {\n        g.show(this.obj);\n    };\n    k.prototype._hide = function() {\n        g.hide(this.obj);\n    };\n    k.prototype._frame = function(l) {\n        var m = true, n = false, o = false, p;\n        function q(aa) {\n            return ((JSBNG__document.documentElement[aa] || JSBNG__document.body[aa]));\n        };\n    ;\n        for (var r = 0; ((r < this.queue.length)); r++) {\n            var s = this.queue[r];\n            if (((s.start > l))) {\n                m = false;\n                continue;\n            }\n        ;\n        ;\n            if (s.checkpointcb) {\n                this._callback(s.checkpointcb, ((l - s.start)));\n                s.checkpointcb = null;\n            }\n        ;\n        ;\n            if (((s.started === undefined))) {\n                if (s.show) {\n                    this._show();\n                }\n            ;\n            ;\n                for (var t in s.attrs) {\n                    if (((s.attrs[t].start !== undefined))) {\n                        continue;\n                    }\n                ;\n                ;\n                    switch (t) {\n                      case \"backgroundColor\":\n                    \n                      case \"borderColor\":\n                    \n                      case \"color\":\n                        p = k.parse_color(i.get(this.obj, ((((t == \"borderColor\")) ? \"borderLeftColor\" : t))));\n                        if (s.attrs[t].by) {\n                            s.attrs[t].value[0] = Math.min(255, Math.max(0, ((s.attrs[t].value[0] + p[0]))));\n                            s.attrs[t].value[1] = Math.min(255, Math.max(0, ((s.attrs[t].value[1] + p[1]))));\n                            s.attrs[t].value[2] = Math.min(255, Math.max(0, ((s.attrs[t].value[2] + p[2]))));\n                        }\n                    ;\n                    ;\n                        break;\n                      case \"opacity\":\n                        p = i.getOpacity(this.obj);\n                        if (s.attrs[t].by) {\n                            s.attrs[t].value = Math.min(1, Math.max(0, ((s.attrs[t].value + p))));\n                        }\n                    ;\n                    ;\n                        break;\n                      case \"height\":\n                        p = k._get_box_height(this.obj);\n                        if (s.attrs[t].by) {\n                            s.attrs[t].value += p;\n                        }\n                    ;\n                    ;\n                        break;\n                      case \"width\":\n                        p = k._get_box_width(this.obj);\n                        if (s.attrs[t].by) {\n                            s.attrs[t].value += p;\n                        }\n                    ;\n                    ;\n                        break;\n                      case \"scrollLeft\":\n                    \n                      case \"scrollTop\":\n                        p = ((((this.obj === JSBNG__document.body)) ? q(t) : this.obj[t]));\n                        if (s.attrs[t].by) {\n                            s.attrs[t].value += p;\n                        }\n                    ;\n                    ;\n                        s[((\"last\" + t))] = p;\n                        break;\n                      default:\n                        p = ((parseInt(i.get(this.obj, t), 10) || 0));\n                        if (s.attrs[t].by) {\n                            s.attrs[t].value += p;\n                        }\n                    ;\n                    ;\n                        break;\n                    };\n                ;\n                    s.attrs[t].start = p;\n                };\n            ;\n                if (((((s.attrs.height && s.attrs.height.auto)) || ((s.attrs.width && s.attrs.width.auto))))) {\n                    if (((j.firefox() < 3))) {\n                        o = true;\n                    }\n                ;\n                ;\n                    this._destroy_container();\n                    for (var t in {\n                        height: 1,\n                        width: 1,\n                        fontSize: 1,\n                        borderLeftWidth: 1,\n                        borderRightWidth: 1,\n                        borderTopWidth: 1,\n                        borderBottomWidth: 1,\n                        paddingLeft: 1,\n                        paddingRight: 1,\n                        paddingTop: 1,\n                        paddingBottom: 1\n                    }) {\n                        if (s.attrs[t]) {\n                            this.obj.style[t] = ((s.attrs[t].value + ((((typeof s.attrs[t].value == \"number\")) ? \"px\" : \"\"))));\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    if (((s.attrs.height && s.attrs.height.auto))) {\n                        s.attrs.height.value = k._get_box_height(this.obj);\n                    }\n                ;\n                ;\n                    if (((s.attrs.width && s.attrs.width.auto))) {\n                        s.attrs.width.value = k._get_box_width(this.obj);\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                s.started = true;\n                if (s.blind) {\n                    this._build_container();\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            var u = ((((l - s.start)) / s.duration));\n            if (((u >= 1))) {\n                u = 1;\n                if (s.hide) {\n                    this._hide();\n                }\n            ;\n            ;\n            }\n             else m = false;\n        ;\n        ;\n            var v = ((s.ease ? s.ease(u) : u));\n            if (((((!n && ((u != 1)))) && s.blind))) {\n                n = true;\n            }\n        ;\n        ;\n            if (((o && this.obj.parentNode))) {\n                var w = this.obj.parentNode, x = this.obj.nextSibling;\n                w.removeChild(this.obj);\n            }\n        ;\n        ;\n            for (var t in s.attrs) {\n                switch (t) {\n                  case \"backgroundColor\":\n                \n                  case \"borderColor\":\n                \n                  case \"color\":\n                    if (((s.attrs[t].start[3] != s.attrs[t].value[3]))) {\n                        this.obj.style[t] = ((((((((((((((((\"rgba(\" + k.calc_tween(v, s.attrs[t].start[0], s.attrs[t].value[0], true))) + \",\")) + k.calc_tween(v, s.attrs[t].start[1], s.attrs[t].value[1], true))) + \",\")) + k.calc_tween(v, s.attrs[t].start[2], s.attrs[t].value[2], true))) + \",\")) + k.calc_tween(v, s.attrs[t].start[3], s.attrs[t].value[3], false))) + \")\"));\n                    }\n                     else this.obj.style[t] = ((((((((((((\"rgb(\" + k.calc_tween(v, s.attrs[t].start[0], s.attrs[t].value[0], true))) + \",\")) + k.calc_tween(v, s.attrs[t].start[1], s.attrs[t].value[1], true))) + \",\")) + k.calc_tween(v, s.attrs[t].start[2], s.attrs[t].value[2], true))) + \")\"));\n                ;\n                ;\n                    break;\n                  case \"opacity\":\n                    i.set(this.obj, \"opacity\", k.calc_tween(v, s.attrs[t].start, s.attrs[t].value));\n                    break;\n                  case \"height\":\n                \n                  case \"width\":\n                    this.obj.style[t] = ((((((v == 1)) && s.attrs[t].auto)) ? \"auto\" : ((k.calc_tween(v, s.attrs[t].start, s.attrs[t].value, true) + \"px\"))));\n                    break;\n                  case \"scrollLeft\":\n                \n                  case \"scrollTop\":\n                    var y = ((this.obj === JSBNG__document.body));\n                    p = ((y ? q(t) : this.obj[t]));\n                    if (((s[((\"last\" + t))] !== p))) {\n                        delete s.attrs[t];\n                    }\n                     else {\n                        var z = k.calc_tween(v, s.attrs[t].start, s.attrs[t].value, true);\n                        if (!y) {\n                            z = this.obj[t] = z;\n                        }\n                         else {\n                            if (((t == \"scrollLeft\"))) {\n                                a.JSBNG__scrollTo(z, q(\"scrollTop\"));\n                            }\n                             else a.JSBNG__scrollTo(q(\"scrollLeft\"), z);\n                        ;\n                        ;\n                            z = q(t);\n                        }\n                    ;\n                    ;\n                        s[((\"last\" + t))] = z;\n                    }\n                ;\n                ;\n                    break;\n                  default:\n                    this.obj.style[t] = ((k.calc_tween(v, s.attrs[t].start, s.attrs[t].value, true) + \"px\"));\n                    break;\n                };\n            ;\n            };\n        ;\n            if (((u == 1))) {\n                this.queue.splice(r--, 1);\n                this._callback(s.JSBNG__ondone, ((((l - s.start)) - s.duration)));\n            }\n        ;\n        ;\n        };\n    ;\n        if (o) {\n            w[((x ? \"insertBefore\" : \"appendChild\"))](this.obj, x);\n        }\n    ;\n    ;\n        if (((!n && this.container_div))) {\n            this._destroy_container();\n        }\n    ;\n    ;\n        return !m;\n    };\n    k.prototype.JSBNG__ondone = function(l) {\n        this.state.JSBNG__ondone = l;\n        return this;\n    };\n    k.prototype._callback = function(l, m) {\n        if (l) {\n            k.offset = m;\n            l.call(this);\n            k.offset = 0;\n        }\n    ;\n    ;\n    };\n    k.calc_tween = function(l, m, n, o) {\n        return ((o ? parseInt : parseFloat))(((((((n - m)) * l)) + m)), 10);\n    };\n    k.parse_color = function(l) {\n        var m = /^#([a-f0-9]{1,2})([a-f0-9]{1,2})([a-f0-9]{1,2})$/i.exec(l);\n        if (m) {\n            return [parseInt(((((m[1].length == 1)) ? ((m[1] + m[1])) : m[1])), 16),parseInt(((((m[2].length == 1)) ? ((m[2] + m[2])) : m[2])), 16),parseInt(((((m[3].length == 1)) ? ((m[3] + m[3])) : m[3])), 16),1,];\n        }\n         else {\n            var n = /^rgba? *\\(([0-9]+), *([0-9]+), *([0-9]+)(?:, *([0-9]+))?\\)$/.exec(l);\n            if (n) {\n                return [parseInt(n[1], 10),parseInt(n[2], 10),parseInt(n[3], 10),((n[4] ? parseFloat(n[4]) : 1)),];\n            }\n             else if (((l == \"transparent\"))) {\n                return [255,255,255,0,];\n            }\n             else throw \"Named color attributes are not supported.\"\n            \n        ;\n        }\n    ;\n    ;\n    };\n    k.parse_group = function(l) {\n        l = l.trim().split(/ +/);\n        if (((l.length == 4))) {\n            return l;\n        }\n         else if (((l.length == 3))) {\n            return [l[0],l[1],l[2],l[1],];\n        }\n         else if (((l.length == 2))) {\n            return [l[0],l[1],l[0],l[1],];\n        }\n         else return [l[0],l[0],l[0],l[0],]\n        \n        \n    ;\n    };\n    k.push = function(l) {\n        if (!k.active) {\n            k.active = [];\n        }\n    ;\n    ;\n        k.active.push(l);\n        if (((k.active.length === 1))) {\n            if (!k.requestAnimationFrame) {\n                var m = ((((a.requestAnimationFrame || a.JSBNG__webkitRequestAnimationFrame)) || a.JSBNG__mozRequestAnimationFrame));\n                if (m) {\n                    k.requestAnimationFrame = m.bind(a);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            if (k.requestAnimationFrame) {\n                k.requestAnimationFrame(k._animate);\n            }\n             else k.timeout = JSBNG__setInterval(k._animate, k.resolution, false);\n        ;\n        ;\n        }\n    ;\n    ;\n        if (k.requestAnimationFrame) {\n            k._updateEndingTimer();\n        }\n    ;\n    ;\n        k._animate(JSBNG__Date.now(), true);\n    };\n    k._updateEndingTimer = function() {\n        if (!k.requestAnimationFrame) {\n            throw new Error(\"Ending timer only valid with requestAnimationFrame\");\n        }\n    ;\n    ;\n        var l = 0;\n        for (var m = 0; ((m < k.active.length)); m++) {\n            var n = k.active[m];\n            for (var o = 0; ((o < n.queue.length)); o++) {\n                var p = ((n.queue[o].start + n.queue[o].duration));\n                if (((p > l))) {\n                    l = p;\n                }\n            ;\n            ;\n            };\n        ;\n        };\n    ;\n        if (k.timeout) {\n            JSBNG__clearTimeout(k.timeout);\n            delete k.timeout;\n        }\n    ;\n    ;\n        var q = JSBNG__Date.now();\n        if (((l > q))) {\n            k.timeout = JSBNG__setTimeout(k._animate.shield(), ((l - q)), false);\n        }\n    ;\n    ;\n    };\n    k._animate = function(l, m) {\n        l = ((l || JSBNG__Date.now()));\n        for (var n = ((((m === true)) ? ((k.active.length - 1)) : 0)); ((n < k.active.length)); n++) {\n            try {\n                if (!k.active[n]._frame(l)) {\n                    k.active.splice(n--, 1);\n                }\n            ;\n            ;\n            } catch (o) {\n                k.active.splice(n--, 1);\n            };\n        ;\n        };\n    ;\n        if (((k.active.length === 0))) {\n            if (k.timeout) {\n                if (k.requestAnimationFrame) {\n                    JSBNG__clearTimeout(k.timeout);\n                }\n                 else JSBNG__clearInterval(k.timeout);\n            ;\n            ;\n                delete k.timeout;\n            }\n        ;\n        ;\n        }\n         else if (k.requestAnimationFrame) {\n            k.requestAnimationFrame(k._animate);\n        }\n        \n    ;\n    ;\n    };\n    k.ease = {\n    };\n    k.ease.begin = function(l) {\n        return ((Math.sin(((((Math.PI / 2)) * ((l - 1))))) + 1));\n    };\n    k.ease.end = function(l) {\n        return Math.sin(((((59718 * Math.PI)) * l)));\n    };\n    k.ease.both = function(l) {\n        return ((((59765 * Math.sin(((Math.PI * ((l - 59788))))))) + 59793));\n    };\n    k.prependInsert = function(l, m) {\n        k.insert(l, m, h.prependContent);\n    };\n    k.appendInsert = function(l, m) {\n        k.insert(l, m, h.appendContent);\n    };\n    k.insert = function(l, m, n) {\n        i.set(m, \"opacity\", 0);\n        n(l, m);\n        new k(m).from(\"opacity\", 0).to(\"opacity\", 1).duration(400).go();\n    };\n    e.exports = k;\n});\n__d(\"CSSSupport\", [], function(a, b, c, d, e, f) {\n    var g = {\n        supportsBorderRadius: function() {\n            var h = [\"KhtmlBorderRadius\",\"OBorderRadius\",\"MozBorderRadius\",\"WebkitBorderRadius\",\"msBorderRadius\",\"borderRadius\",], i = false, j = JSBNG__document.createElement(\"div\");\n            for (var k = h.length; ((k >= 0)); k--) {\n                if (i = ((j.style[h[k]] !== undefined))) {\n                    break;\n                }\n            ;\n            ;\n            };\n        ;\n            g.supportsBorderRadius = bagof(i);\n            return i;\n        }\n    };\n    e.exports = g;\n});\n__d(\"Keys\", [], function(a, b, c, d, e, f) {\n    var g = {\n        BACKSPACE: 8,\n        TAB: 9,\n        RETURN: 13,\n        ESC: 27,\n        SPACE: 32,\n        PAGE_UP: 33,\n        PAGE_DOWN: 34,\n        END: 35,\n        HOME: 36,\n        LEFT: 37,\n        UP: 38,\n        RIGHT: 39,\n        DOWN: 40,\n        DELETE: 46,\n        COMMA: 188\n    };\n    e.exports = g;\n});\n__d(\"Locale\", [\"Style\",], function(a, b, c, d, e, f) {\n    var g = b(\"Style\"), h, i = {\n        isRTL: function() {\n            if (((h === undefined))) {\n                h = ((\"rtl\" === g.get(JSBNG__document.body, \"direction\")));\n            }\n        ;\n        ;\n            return h;\n        }\n    };\n    e.exports = i;\n});\n__d(\"Vector\", [\"event-extensions\",\"DOMDimensions\",\"DOMPosition\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"DOMDimensions\"), h = b(\"DOMPosition\"), i = b(\"copyProperties\");\n    function j(k, l, m) {\n        i(this, {\n            x: parseFloat(k),\n            y: parseFloat(l),\n            domain: ((m || \"pure\"))\n        });\n    };\n;\n    i(j.prototype, {\n        toString: function() {\n            return ((((((((\"(\" + this.x)) + \", \")) + this.y)) + \")\"));\n        },\n        add: function(k, l) {\n            if (((arguments.length == 1))) {\n                if (((k.domain != \"pure\"))) {\n                    k = k.convertTo(this.domain);\n                }\n            ;\n            ;\n                return this.add(k.x, k.y);\n            }\n        ;\n        ;\n            var m = parseFloat(k), n = parseFloat(l);\n            return new j(((this.x + m)), ((this.y + n)), this.domain);\n        },\n        mul: function(k, l) {\n            if (((typeof l == \"undefined\"))) {\n                l = k;\n            }\n        ;\n        ;\n            return new j(((this.x * k)), ((this.y * l)), this.domain);\n        },\n        sub: function(k, l) {\n            if (((arguments.length == 1))) {\n                return this.add(k.mul(-1));\n            }\n             else return this.add(-k, -l)\n        ;\n        },\n        distanceTo: function(k) {\n            return this.sub(k).magnitude();\n        },\n        magnitude: function() {\n            return Math.sqrt(((((this.x * this.x)) + ((this.y * this.y)))));\n        },\n        convertTo: function(k) {\n            if (((((((k != \"pure\")) && ((k != \"viewport\")))) && ((k != \"JSBNG__document\"))))) {\n                return new j(0, 0);\n            }\n        ;\n        ;\n            if (((k == this.domain))) {\n                return new j(this.x, this.y, this.domain);\n            }\n        ;\n        ;\n            if (((k == \"pure\"))) {\n                return new j(this.x, this.y);\n            }\n        ;\n        ;\n            if (((this.domain == \"pure\"))) {\n                return new j(0, 0);\n            }\n        ;\n        ;\n            var l = j.getScrollPosition(\"JSBNG__document\"), m = this.x, n = this.y;\n            if (((this.domain == \"JSBNG__document\"))) {\n                m -= l.x;\n                n -= l.y;\n            }\n             else {\n                m += l.x;\n                n += l.y;\n            }\n        ;\n        ;\n            return new j(m, n, k);\n        },\n        setElementPosition: function(k) {\n            var l = this.convertTo(\"JSBNG__document\");\n            k.style.left = ((parseInt(l.x) + \"px\"));\n            k.style.JSBNG__top = ((parseInt(l.y) + \"px\"));\n            return this;\n        },\n        setElementDimensions: function(k) {\n            return this.setElementWidth(k).setElementHeight(k);\n        },\n        setElementWidth: function(k) {\n            k.style.width = ((parseInt(this.x, 10) + \"px\"));\n            return this;\n        },\n        setElementHeight: function(k) {\n            k.style.height = ((parseInt(this.y, 10) + \"px\"));\n            return this;\n        },\n        scrollElementBy: function(k) {\n            if (((k == JSBNG__document.body))) {\n                window.JSBNG__scrollBy(this.x, this.y);\n            }\n             else {\n                k.scrollLeft += this.x;\n                k.scrollTop += this.y;\n            }\n        ;\n        ;\n            return this;\n        }\n    });\n    i(j, {\n        getEventPosition: function(k, l) {\n            l = ((l || \"JSBNG__document\"));\n            var m = JSBNG__Event.getPosition(k), n = new j(m.x, m.y, \"JSBNG__document\");\n            return n.convertTo(l);\n        },\n        getScrollPosition: function(k) {\n            k = ((k || \"JSBNG__document\"));\n            var l = h.getScrollPosition();\n            return new j(l.x, l.y, \"JSBNG__document\").convertTo(k);\n        },\n        getElementPosition: function(k, l) {\n            l = ((l || \"JSBNG__document\"));\n            var m = h.getElementPosition(k);\n            return new j(m.x, m.y, \"viewport\").convertTo(l);\n        },\n        getElementDimensions: function(k) {\n            var l = g.getElementDimensions(k);\n            return new j(l.width, l.height);\n        },\n        getViewportDimensions: function() {\n            var k = g.getViewportDimensions();\n            return new j(k.width, k.height, \"viewport\");\n        },\n        getDocumentDimensions: function(k) {\n            var l = g.getDocumentDimensions(k);\n            return new j(l.width, l.height, \"JSBNG__document\");\n        },\n        deserialize: function(k) {\n            var l = k.split(\",\");\n            return new j(l[0], l[1]);\n        }\n    });\n    e.exports = j;\n});\n__d(\"getOverlayZIndex\", [\"Style\",], function(a, b, c, d, e, f) {\n    var g = b(\"Style\");\n    function h(i, j) {\n        j = ((j || JSBNG__document.body));\n        var k = [];\n        while (((i && ((i !== j))))) {\n            k.push(i);\n            i = i.parentNode;\n        };\n    ;\n        if (((i !== j))) {\n            return 0;\n        }\n    ;\n    ;\n        for (var l = ((k.length - 1)); ((l >= 0)); l--) {\n            var m = k[l];\n            if (((g.get(m, \"position\") != \"static\"))) {\n                var n = parseInt(g.get(m, \"z-index\"), 10);\n                if (!isNaN(n)) {\n                    return n;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        };\n    ;\n        return 0;\n    };\n;\n    e.exports = h;\n});\n__d(\"Dialog\", [\"array-extensions\",\"event-extensions\",\"AjaxPipeRequest\",\"Animation\",\"Arbiter\",\"AsyncRequest\",\"Bootloader\",\"Button\",\"CSS\",\"CSSSupport\",\"DOM\",\"Form\",\"HTML\",\"Input\",\"Keys\",\"Locale\",\"Parent\",\"Run\",\"Style\",\"URI\",\"UserAgent\",\"Vector\",\"bind\",\"copyProperties\",\"createArrayFrom\",\"getObjectValues\",\"getOverlayZIndex\",\"tx\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    var g = b(\"AjaxPipeRequest\"), h = b(\"Animation\"), i = b(\"Arbiter\"), j = b(\"AsyncRequest\"), k = b(\"Bootloader\"), l = b(\"Button\"), m = b(\"CSS\"), n = b(\"CSSSupport\"), o = b(\"DOM\"), p = b(\"Form\"), q = b(\"HTML\"), r = b(\"Input\"), s = b(\"Keys\"), t = b(\"Locale\"), u = b(\"Parent\"), v = b(\"Run\"), w = b(\"Style\"), x = b(\"URI\"), y = b(\"UserAgent\"), z = b(\"Vector\"), aa = b(\"bind\"), ba = b(\"copyProperties\"), ca = b(\"createArrayFrom\"), da = b(\"getObjectValues\"), ea = b(\"getOverlayZIndex\"), fa = b(\"tx\"), ga = function() {\n        var ia = JSBNG__document.body, ja = JSBNG__document.createElement(\"div\"), ka = JSBNG__document.createElement(\"div\");\n        ia.insertBefore(ja, ia.firstChild);\n        ia.insertBefore(ka, ia.firstChild);\n        ja.style.position = \"fixed\";\n        ja.style.JSBNG__top = \"20px\";\n        var la = ((ja.offsetTop !== ka.offsetTop));\n        ia.removeChild(ja);\n        ia.removeChild(ka);\n        ga = bagof(la);\n        return la;\n    };\n    function ha(ia) {\n        this._show_loading = true;\n        this._auto_focus = true;\n        this._submit_on_enter = false;\n        this._fade_enabled = true;\n        this._onload_handlers = [];\n        this._top = 125;\n        this._uniqueID = ((\"dialog_\" + ha._globalCount++));\n        this._content = null;\n        this._obj = null;\n        this._popup = null;\n        this._overlay = null;\n        this._shim = null;\n        this._causal_elem = null;\n        this._previous_focus = null;\n        this._buttons = [];\n        this._buildDialog();\n        if (ia) {\n            this._setFromModel(ia);\n        }\n    ;\n    ;\n        ha._init();\n    };\n;\n    ba(ha, {\n        OK: {\n            JSBNG__name: \"ok\",\n            label: \"Okay\"\n        },\n        CANCEL: {\n            JSBNG__name: \"cancel\",\n            label: \"Cancel\",\n            className: \"inputaux\"\n        },\n        CLOSE: {\n            JSBNG__name: \"close\",\n            label: \"Close\"\n        },\n        NEXT: {\n            JSBNG__name: \"next\",\n            label: \"Next\"\n        },\n        SAVE: {\n            JSBNG__name: \"save\",\n            label: \"Save\"\n        },\n        SUBMIT: {\n            JSBNG__name: \"submit\",\n            label: \"Submit\"\n        },\n        CONFIRM: {\n            JSBNG__name: \"JSBNG__confirm\",\n            label: \"Confirm\"\n        },\n        DELETE: {\n            JSBNG__name: \"delete\",\n            label: \"Delete\"\n        },\n        _globalCount: 0,\n        _bottoms: [0,],\n        max_bottom: 0,\n        _updateMaxBottom: function() {\n            ha.max_bottom = Math.max.apply(Math, ha._bottoms);\n        }\n    });\n    ba(ha, {\n        OK_AND_CANCEL: [ha.OK,ha.CANCEL,],\n        _STANDARD_BUTTONS: [ha.OK,ha.CANCEL,ha.CLOSE,ha.SAVE,ha.SUBMIT,ha.CONFIRM,ha.DELETE,],\n        SIZE: {\n            WIDE: 555,\n            STANDARD: 445\n        },\n        _HALO_WIDTH: 10,\n        _BORDER_WIDTH: 1,\n        _PADDING_WIDTH: 10,\n        _PAGE_MARGIN: 40,\n        _stack: [],\n        _isUsingCSSBorders: function() {\n            return ((n.supportsBorderRadius() || ((y.ie() < 7))));\n        },\n        newButton: function(ia, ja, ka, la) {\n            var ma = {\n                JSBNG__name: ia,\n                label: ja\n            };\n            if (ka) {\n                ma.className = ka;\n            }\n        ;\n        ;\n            if (la) {\n                ma.handler = la;\n            }\n        ;\n        ;\n            return ma;\n        },\n        getCurrent: function() {\n            var ia = ha._stack;\n            return ((ia.length ? ia[((ia.length - 1))] : null));\n        },\n        hideCurrent: function() {\n            var ia = ha.getCurrent();\n            ((ia && ia.hide()));\n        },\n        bootstrap: function(ia, ja, ka, la, ma, na) {\n            ja = ((ja || {\n            }));\n            ba(ja, new x(ia).getQueryData());\n            la = ((la || ((ka ? \"GET\" : \"POST\"))));\n            var oa = ((u.byClass(na, \"stat_elem\") || na));\n            if (((oa && m.hasClass(oa, \"async_saving\")))) {\n                return false;\n            }\n        ;\n        ;\n            var pa = new j().setReadOnly(!!ka).setMethod(la).setRelativeTo(na).setStatusElement(oa).setURI(ia).setNectarModuleDataSafe(na).setData(ja), qa = new ha(ma).setCausalElement(na).setAsync(pa);\n            qa.show();\n            return false;\n        },\n        showFromModel: function(ia, ja) {\n            var ka = new ha(ia).setCausalElement(ja).show();\n            if (ia.hiding) {\n                ka.hide();\n            }\n        ;\n        ;\n        },\n        _init: function() {\n            this._init = bagofholding;\n            v.JSBNG__onLeave(ha._tearDown.shield(null, false));\n            i.subscribe(\"page_transition\", ha._tearDown.shield(null, true));\n            JSBNG__Event.listen(JSBNG__document.documentElement, \"keydown\", function(JSBNG__event) {\n                if (((((JSBNG__Event.getKeyCode(JSBNG__event) == s.ESC)) && !JSBNG__event.getModifiers().any))) {\n                    if (ha._escape()) {\n                        JSBNG__event.kill();\n                    }\n                ;\n                ;\n                }\n                 else if (((((JSBNG__Event.getKeyCode(JSBNG__event) == s.RETURN)) && !JSBNG__event.getModifiers().any))) {\n                    if (ha._enter()) {\n                        JSBNG__event.kill();\n                    }\n                ;\n                }\n                \n            ;\n            ;\n            });\n            JSBNG__Event.listen(window, \"resize\", function(JSBNG__event) {\n                var ia = ha.getCurrent();\n                ((ia && ia._resetDialogObj()));\n            });\n        },\n        _findButton: function(ia, ja) {\n            if (ia) {\n                for (var ka = 0; ((ka < ia.length)); ++ka) {\n                    if (((ia[ka].JSBNG__name == ja))) {\n                        return ia[ka];\n                    }\n                ;\n                ;\n                };\n            }\n        ;\n        ;\n            return null;\n        },\n        _tearDown: function(ia) {\n            var ja = ha._stack.slice();\n            for (var ka = ((ja.length - 1)); ((ka >= 0)); ka--) {\n                if (((((ia && !ja[ka]._cross_transition)) || ((!ia && !ja[ka]._cross_quickling))))) {\n                    ja[ka].hide();\n                }\n            ;\n            ;\n            };\n        ;\n        },\n        _escape: function() {\n            var ia = ha.getCurrent();\n            if (!ia) {\n                return false;\n            }\n        ;\n        ;\n            var ja = ia._semi_modal, ka = ia._buttons;\n            if (((!ka.length && !ja))) {\n                return false;\n            }\n        ;\n        ;\n            if (((ja && !ka.length))) {\n                ia.hide();\n                return true;\n            }\n        ;\n        ;\n            var la, ma = ha._findButton(ka, \"cancel\");\n            if (ia._cancelHandler) {\n                ia.cancel();\n                return true;\n            }\n             else if (ma) {\n                la = ma;\n            }\n             else if (((ka.length == 1))) {\n                la = ka[0];\n            }\n             else return false\n            \n            \n        ;\n            ia._handleButton(la);\n            return true;\n        },\n        _enter: function() {\n            var ia = ha.getCurrent();\n            if (((!ia || !ia._submit_on_enter))) {\n                return false;\n            }\n        ;\n        ;\n            if (((JSBNG__document.activeElement != ia._frame))) {\n                return false;\n            }\n        ;\n        ;\n            var ja = ia._buttons;\n            if (!ja) {\n                return false;\n            }\n        ;\n        ;\n            ia._handleButton(ja[0]);\n            return true;\n        },\n        call_or_eval: function(ia, ja, ka) {\n            if (!ja) {\n                return undefined;\n            }\n        ;\n        ;\n            ka = ((ka || {\n            }));\n            if (((typeof ja == \"string\"))) {\n                var la = Object.keys(ka).join(\", \");\n                ja = (eval)(((((((((\"({f: function(\" + la)) + \") { \")) + ja)) + \"}})\"))).f;\n            }\n        ;\n        ;\n            return ja.apply(ia, da(ka));\n        }\n    });\n    ba(ha.prototype, {\n        _cross_quickling: false,\n        _cross_transition: false,\n        _loading: false,\n        _showing: false,\n        show: function() {\n            this._showing = true;\n            if (this._async_request) {\n                if (this._show_loading) {\n                    this.showLoading();\n                }\n            ;\n            ;\n            }\n             else this._update();\n        ;\n        ;\n            return this;\n        },\n        showLoading: function() {\n            this._loading = true;\n            m.addClass(this._frame, \"dialog_loading_shown\");\n            this._renderDialog();\n            return this;\n        },\n        hide: function() {\n            if (((!this._showing && !this._loading))) {\n                return this;\n            }\n        ;\n        ;\n            this._showing = false;\n            if (this._autohide_timeout) {\n                JSBNG__clearTimeout(this._autohide_timeout);\n                this._autohide_timeout = null;\n            }\n        ;\n        ;\n            if (((this._fade_enabled && ((ha._stack.length <= 1))))) {\n                this._fadeOut();\n            }\n             else this._hide();\n        ;\n        ;\n            return this;\n        },\n        cancel: function() {\n            if (((!this._cancelHandler || ((this._cancelHandler() !== false))))) {\n                this.hide();\n            }\n        ;\n        ;\n        },\n        getRoot: function() {\n            return this._obj;\n        },\n        getBody: function() {\n            return o.scry(this._obj, \"div.dialog_body\")[0];\n        },\n        getButtonElement: function(ia) {\n            if (((typeof ia == \"string\"))) {\n                ia = ha._findButton(this._buttons, ia);\n            }\n        ;\n        ;\n            if (((!ia || !ia.JSBNG__name))) {\n                return null;\n            }\n        ;\n        ;\n            var ja = o.scry(this._popup, \"input\"), ka = function(la) {\n                return ((la.JSBNG__name == ia.JSBNG__name));\n            };\n            return ((ja.filter(ka)[0] || null));\n        },\n        getContentNode: function() {\n            return o.JSBNG__find(this._content, \"div.dialog_content\");\n        },\n        getFormData: function() {\n            return p.serialize(this.getContentNode());\n        },\n        setAllowCrossPageTransition: function(ia) {\n            this._cross_transition = ia;\n            return this;\n        },\n        setAllowCrossQuicklingNavigation: function(ia) {\n            this._cross_quickling = ia;\n            return this;\n        },\n        setShowing: function() {\n            this.show();\n            return this;\n        },\n        setHiding: function() {\n            this.hide();\n            return this;\n        },\n        setTitle: function(ia) {\n            var ja = this._nodes.title, ka = this._nodes.title_inner, la = this._nodes.JSBNG__content;\n            o.setContent(ka, this._format(((ia || \"\"))));\n            m.conditionShow(ja, !!ia);\n            m.conditionClass(la, \"dialog_content_titleless\", !ia);\n            return this;\n        },\n        setBody: function(ia) {\n            o.setContent(this._nodes.body, this._format(ia));\n            return this;\n        },\n        setExtraData: function(ia) {\n            this._extra_data = ia;\n            return this;\n        },\n        setReturnData: function(ia) {\n            this._return_data = ia;\n            return this;\n        },\n        setShowLoading: function(ia) {\n            this._show_loading = ia;\n            return this;\n        },\n        setFullBleed: function(ia) {\n            this._full_bleed = ia;\n            this._updateWidth();\n            m.conditionClass(this._obj, \"full_bleed\", ia);\n            return this;\n        },\n        setCausalElement: function(ia) {\n            this._causal_elem = ia;\n            return this;\n        },\n        setUserData: function(ia) {\n            this._user_data = ia;\n            return this;\n        },\n        getUserData: function() {\n            return this._user_data;\n        },\n        setAutohide: function(ia) {\n            if (ia) {\n                if (this._showing) {\n                    this._autohide_timeout = JSBNG__setTimeout(this.hide.shield(this), ia);\n                }\n                 else this._autohide = ia;\n            ;\n            ;\n            }\n             else {\n                this._autohide = null;\n                if (this._autohide_timeout) {\n                    JSBNG__clearTimeout(this._autohide_timeout);\n                    this._autohide_timeout = null;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            return this;\n        },\n        setSummary: function(ia) {\n            var ja = this._nodes.summary;\n            o.setContent(ja, this._format(((ia || \"\"))));\n            m.conditionShow(ja, !!ia);\n            return this;\n        },\n        setButtons: function(ia) {\n            var ja, ka;\n            if (!((ia instanceof Array))) {\n                ja = ca(arguments);\n            }\n             else ja = ia;\n        ;\n        ;\n            for (var la = 0; ((la < ja.length)); ++la) {\n                if (((typeof ja[la] == \"string\"))) {\n                    ka = ha._findButton(ha._STANDARD_BUTTONS, ja[la]);\n                    ja[la] = ka;\n                }\n            ;\n            ;\n            };\n        ;\n            this._buttons = ja;\n            var ma = [];\n            if (((ja && ((ja.length > 0))))) {\n                for (var na = 0; ((na < ja.length)); na++) {\n                    ka = ja[na];\n                    var oa = o.create(\"input\", {\n                        type: \"button\",\n                        JSBNG__name: ((ka.JSBNG__name || \"\")),\n                        value: ka.label\n                    }), pa = o.create(\"label\", {\n                        className: \"uiButton uiButtonLarge uiButtonConfirm\"\n                    }, oa);\n                    if (ka.className) {\n                        ka.className.split(/\\s+/).forEach(function(ra) {\n                            m.addClass(pa, ra);\n                        });\n                        if (m.hasClass(pa, \"inputaux\")) {\n                            m.removeClass(pa, \"inputaux\");\n                            m.removeClass(pa, \"uiButtonConfirm\");\n                        }\n                    ;\n                    ;\n                        if (m.hasClass(pa, \"uiButtonSpecial\")) {\n                            m.removeClass(pa, \"uiButtonConfirm\");\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    if (ka.icon) {\n                        o.prependContent(pa, o.create(\"img\", {\n                            src: ka.icon,\n                            className: \"img mrs\"\n                        }));\n                    }\n                ;\n                ;\n                    if (ka.disabled) {\n                        l.setEnabled(pa, false);\n                    }\n                ;\n                ;\n                    JSBNG__Event.listen(oa, \"click\", this._handleButton.bind(this, ka.JSBNG__name));\n                    for (var qa in ka) {\n                        if (((((qa.indexOf(\"data-\") === 0)) && ((qa.length > 5))))) {\n                            oa.setAttribute(qa, ka[qa]);\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    ma.push(pa);\n                };\n            }\n        ;\n        ;\n            o.setContent(this._nodes.buttons, ma);\n            this._updateButtonVisibility();\n            return this;\n        },\n        setButtonsMessage: function(ia) {\n            o.setContent(this._nodes.button_message, this._format(((ia || \"\"))));\n            this._has_button_message = !!ia;\n            this._updateButtonVisibility();\n            return this;\n        },\n        _updateButtonVisibility: function() {\n            var ia = ((((this._buttons.length > 0)) || this._has_button_message));\n            m.conditionShow(this._nodes.button_wrapper, ia);\n            m.conditionClass(this._obj, \"omitDialogFooter\", !ia);\n        },\n        setClickButtonOnEnter: function(ia, ja) {\n            this._clickOnEnterTarget = ia;\n            if (!this._clickOnEnterListener) {\n                this._clickOnEnterListener = JSBNG__Event.listen(this._nodes.body, \"keypress\", function(JSBNG__event) {\n                    var ka = JSBNG__event.getTarget();\n                    if (((ka && ((ka.id === this._clickOnEnterTarget))))) {\n                        if (((JSBNG__Event.getKeyCode(JSBNG__event) == s.RETURN))) {\n                            this._handleButton(ja);\n                            JSBNG__event.kill();\n                        }\n                    ;\n                    }\n                ;\n                ;\n                    return true;\n                }.bind(this));\n            }\n        ;\n        ;\n            return this;\n        },\n        setStackable: function(ia, ja) {\n            this._is_stackable = ia;\n            this._shown_while_stacked = ((ia && ja));\n            return this;\n        },\n        setHandler: function(ia) {\n            this._handler = ia;\n            return this;\n        },\n        setCancelHandler: function(ia) {\n            this._cancelHandler = ha.call_or_eval.bind(null, this, ia);\n            return this;\n        },\n        setCloseHandler: function(ia) {\n            this._close_handler = ha.call_or_eval.bind(null, this, ia);\n            return this;\n        },\n        clearHandler: function() {\n            return this.setHandler(null);\n        },\n        setPostURI: function(ia, ja) {\n            if (((ja === undefined))) {\n                ja = true;\n            }\n        ;\n        ;\n            if (ja) {\n                this.setHandler(this._submitForm.bind(this, \"POST\", ia));\n            }\n             else this.setHandler(function() {\n                p.post(ia, this.getFormData());\n                this.hide();\n            }.bind(this));\n        ;\n        ;\n            return this;\n        },\n        setGetURI: function(ia) {\n            this.setHandler(this._submitForm.bind(this, \"GET\", ia));\n            return this;\n        },\n        setModal: function(ia) {\n            this._modal = ia;\n            m.conditionClass(this._obj, \"generic_dialog_modal\", ia);\n            return this;\n        },\n        setSemiModal: function(ia) {\n            if (ia) {\n                this.setModal(true);\n                this._semiModalListener = JSBNG__Event.listen(this._obj, \"click\", function(ja) {\n                    if (!o.contains(this._popup, ja.getTarget())) {\n                        this.hide();\n                    }\n                ;\n                ;\n                }.bind(this));\n            }\n             else ((this._semiModalListener && this._semiModalListener.remove()));\n        ;\n        ;\n            this._semi_modal = ia;\n            return this;\n        },\n        setWideDialog: function(ia) {\n            this._wide_dialog = ia;\n            this._updateWidth();\n            return this;\n        },\n        setContentWidth: function(ia) {\n            this._content_width = ia;\n            this._updateWidth();\n            return this;\n        },\n        setTitleLoading: function(ia) {\n            if (((ia === undefined))) {\n                ia = true;\n            }\n        ;\n        ;\n            var ja = o.JSBNG__find(this._popup, \"h2.dialog_title\");\n            if (ja) {\n                m.conditionClass(ja, \"loading\", ia);\n            }\n        ;\n        ;\n            return this;\n        },\n        setSecure: function(ia) {\n            m.conditionClass(this._nodes.title, \"secure\", ia);\n            return this;\n        },\n        setClassName: function(ia) {\n            ia.split(/\\s+/).forEach(m.addClass.bind(m, this._obj));\n            return this;\n        },\n        setFadeEnabled: function(ia) {\n            this._fade_enabled = ia;\n            return this;\n        },\n        setFooter: function(ia) {\n            var ja = this._nodes.footer;\n            o.setContent(ja, this._format(((ia || \"\"))));\n            m.conditionShow(ja, !!ia);\n            return this;\n        },\n        setAutoFocus: function(ia) {\n            this._auto_focus = ia;\n            return this;\n        },\n        setTop: function(ia) {\n            this._top = ia;\n            this._resetDialogObj();\n            return this;\n        },\n        JSBNG__onloadRegister: function(ia) {\n            ca(ia).forEach(function(ja) {\n                if (((typeof ja == \"string\"))) {\n                    ja = new Function(ja);\n                }\n            ;\n            ;\n                this._onload_handlers.push(ja.bind(this));\n            }.bind(this));\n            return this;\n        },\n        setAsyncURL: function(ia) {\n            return this.setAsync(new j(ia));\n        },\n        setAsync: function(ia) {\n            var ja = function(ra) {\n                if (((this._async_request != ia))) {\n                    return;\n                }\n            ;\n            ;\n                this._async_request = null;\n                var sa = ra.getPayload(), ta = sa;\n                if (this._loading) {\n                    this._showing = true;\n                }\n            ;\n            ;\n                if (((typeof ta == \"string\"))) {\n                    this.setBody(ta);\n                }\n                 else this._setFromModel(ta);\n            ;\n            ;\n                this._update();\n            }.bind(this), ka = ia.getData();\n            ka.__d = 1;\n            ia.setData(ka);\n            var la = ((ia.getHandler() || bagofholding));\n            ia.setHandler(function(ra) {\n                la(ra);\n                ja(ra);\n            });\n            var ma = ia, na = ((ma.getErrorHandler() || bagofholding)), oa = ((ma.getTransportErrorHandler() || bagofholding)), pa = function() {\n                this._async_request = null;\n                this._loading = false;\n                if (((this._showing && this._shown_while_stacked))) {\n                    this._update();\n                }\n                 else this._hide(this._is_stackable);\n            ;\n            ;\n            }.bind(this), qa = ((ma.getServerDialogCancelHandler() || pa));\n            ma.setAllowCrossPageTransition(this._cross_transition).setErrorHandler(function(ra) {\n                pa();\n                na(ra);\n            }).setTransportErrorHandler(function(ra) {\n                pa();\n                oa(ra);\n            }).setServerDialogCancelHandler(qa);\n            ia.send();\n            this._async_request = ia;\n            if (this._showing) {\n                this.show();\n            }\n        ;\n        ;\n            return this;\n        },\n        _format: function(ia) {\n            if (((typeof ia == \"string\"))) {\n                ia = q(ia);\n            }\n             else ia = q.replaceJSONWrapper(ia);\n        ;\n        ;\n            if (((ia instanceof q))) {\n                ia.setDeferred(true);\n            }\n        ;\n        ;\n            return ia;\n        },\n        _update: function() {\n            if (!this._showing) {\n                return;\n            }\n        ;\n        ;\n            if (((((this._autohide && !this._async_request)) && !this._autohide_timeout))) {\n                this._autohide_timeout = JSBNG__setTimeout(aa(this, \"hide\"), this._autohide);\n            }\n        ;\n        ;\n            m.removeClass(this._frame, \"dialog_loading_shown\");\n            this._loading = false;\n            this._renderDialog();\n            this._runOnloads();\n            this._previous_focus = JSBNG__document.activeElement;\n            r.JSBNG__focus(this._frame);\n        },\n        _runOnloads: function() {\n            for (var ia = 0; ((ia < this._onload_handlers.length)); ++ia) {\n                try {\n                    this._onload_handlers[ia]();\n                } catch (ja) {\n                \n                };\n            ;\n            };\n        ;\n            this._onload_handlers = [];\n        },\n        _updateWidth: function() {\n            var ia = ((2 * ha._BORDER_WIDTH));\n            if (ha._isUsingCSSBorders()) {\n                ia += ((2 * ha._HALO_WIDTH));\n            }\n        ;\n        ;\n            if (this._content_width) {\n                ia += this._content_width;\n                if (!this._full_bleed) {\n                    ia += ((2 * ha._PADDING_WIDTH));\n                }\n            ;\n            ;\n            }\n             else if (this._wide_dialog) {\n                ia += ha.SIZE.WIDE;\n            }\n             else ia += ha.SIZE.STANDARD;\n            \n        ;\n        ;\n            this._popup.style.width = ((ia + \"px\"));\n        },\n        _updateZIndex: function() {\n            if (((!this._hasSetZIndex && this._causal_elem))) {\n                var ia = ea(this._causal_elem);\n                this._hasSetZIndex = ((ia > ((this._modal ? 400 : 200))));\n                w.set(this._obj, \"z-index\", ((this._hasSetZIndex ? ia : \"\")));\n            }\n        ;\n        ;\n        },\n        _renderDialog: function() {\n            this._updateZIndex();\n            this._pushOntoStack();\n            this._obj.style.height = ((((this._modal && ((y.ie() < 7)))) ? ((z.getDocumentDimensions().y + \"px\")) : null));\n            if (((this._obj && this._obj.style.display))) {\n                this._obj.style.visibility = \"hidden\";\n                this._obj.style.display = \"\";\n                this.resetDialogPosition();\n                this._obj.style.visibility = \"\";\n                this._obj.dialog = this;\n            }\n             else this.resetDialogPosition();\n        ;\n        ;\n            JSBNG__clearInterval(this.active_hiding);\n            this.active_hiding = JSBNG__setInterval(this._activeResize.bind(this), 500);\n            this._submit_on_enter = false;\n            if (this._auto_focus) {\n                var ia = p.getFirstElement(this._content, [\"input[type=\\\"text\\\"]\",\"textarea\",\"input[type=\\\"password\\\"]\",]);\n                if (ia) {\n                    p.focusFirst.bind(this, this._content).defer();\n                }\n                 else this._submit_on_enter = true;\n            ;\n            ;\n            }\n        ;\n        ;\n            var ja = ((z.getElementDimensions(this._content).y + z.getElementPosition(this._content).y));\n            ha._bottoms.push(ja);\n            this._bottom = ja;\n            ha._updateMaxBottom();\n            return this;\n        },\n        _buildDialog: function() {\n            this._obj = o.create(\"div\", {\n                className: \"generic_dialog\",\n                id: this._uniqueID\n            });\n            this._obj.style.display = \"none\";\n            o.appendContent(JSBNG__document.body, this._obj);\n            if (!this._popup) {\n                this._popup = o.create(\"div\", {\n                    className: \"generic_dialog_popup\"\n                });\n            }\n        ;\n        ;\n            this._obj.appendChild(this._popup);\n            if (((((y.ie() < 7)) && !this._shim))) {\n                k.loadModules([\"IframeShim\",], function(ua) {\n                    this._shim = new ua(this._popup);\n                });\n            }\n        ;\n        ;\n            m.addClass(this._obj, \"pop_dialog\");\n            if (t.isRTL()) {\n                m.addClass(this._obj, \"pop_dialog_rtl\");\n            }\n        ;\n        ;\n            var ia;\n            if (ha._isUsingCSSBorders()) {\n                ia = ((((\"\\u003Cdiv class=\\\"pop_container_advanced\\\"\\u003E\" + \"\\u003Cdiv class=\\\"pop_content\\\" id=\\\"pop_content\\\"\\u003E\\u003C/div\\u003E\")) + \"\\u003C/div\\u003E\"));\n            }\n             else ia = ((((((((((((((((\"\\u003Cdiv class=\\\"pop_container\\\"\\u003E\" + \"\\u003Cdiv class=\\\"pop_verticalslab\\\"\\u003E\\u003C/div\\u003E\")) + \"\\u003Cdiv class=\\\"pop_horizontalslab\\\"\\u003E\\u003C/div\\u003E\")) + \"\\u003Cdiv class=\\\"pop_topleft\\\"\\u003E\\u003C/div\\u003E\")) + \"\\u003Cdiv class=\\\"pop_topright\\\"\\u003E\\u003C/div\\u003E\")) + \"\\u003Cdiv class=\\\"pop_bottomright\\\"\\u003E\\u003C/div\\u003E\")) + \"\\u003Cdiv class=\\\"pop_bottomleft\\\"\\u003E\\u003C/div\\u003E\")) + \"\\u003Cdiv class=\\\"pop_content pop_content_old\\\" id=\\\"pop_content\\\"\\u003E\\u003C/div\\u003E\")) + \"\\u003C/div\\u003E\"));\n        ;\n        ;\n            o.setContent(this._popup, q(ia));\n            var ja = o.JSBNG__find(this._popup, \"div.pop_content\");\n            ja.setAttribute(\"tabIndex\", \"0\");\n            ja.setAttribute(\"role\", \"alertdialog\");\n            this._frame = this._content = ja;\n            var ka = o.create(\"div\", {\n                className: \"dialog_loading\"\n            }, \"Loading...\"), la = o.create(\"span\"), ma = o.create(\"h2\", {\n                className: \"dialog_title hidden_elem\",\n                id: ((\"title_\" + this._uniqueID))\n            }, la), na = o.create(\"div\", {\n                className: \"dialog_summary hidden_elem\"\n            }), oa = o.create(\"div\", {\n                className: \"dialog_body\"\n            }), pa = o.create(\"div\"), qa = o.create(\"div\", {\n                className: \"dialog_buttons_msg\"\n            }), ra = o.create(\"div\", {\n                className: \"dialog_buttons clearfix hidden_elem\"\n            }, [qa,pa,]), sa = o.create(\"div\", {\n                className: \"dialog_footer hidden_elem\"\n            }), ta = o.create(\"div\", {\n                className: \"dialog_content\"\n            }, [na,oa,ra,sa,]);\n            this._nodes = {\n                summary: na,\n                body: oa,\n                buttons: pa,\n                button_message: qa,\n                button_wrapper: ra,\n                footer: sa,\n                JSBNG__content: ta,\n                title: ma,\n                title_inner: la\n            };\n            o.setContent(this._frame, [ma,ta,ka,]);\n        },\n        _updateShim: function() {\n            return ((this._shim && this._shim.show()));\n        },\n        _activeResize: function() {\n            if (((this.last_offset_height != this._content.offsetHeight))) {\n                this.last_offset_height = this._content.offsetHeight;\n                this.resetDialogPosition();\n            }\n        ;\n        ;\n        },\n        resetDialogPosition: function() {\n            if (!this._popup) {\n                return;\n            }\n        ;\n        ;\n            this._resetDialogObj();\n            this._updateShim();\n        },\n        _resetDialogObj: function() {\n            var ia = ((2 * ha._PAGE_MARGIN)), ja = z.getViewportDimensions(), ka = ((ja.x - ia)), la = ((ja.y - ia)), ma = ((2 * ha._HALO_WIDTH)), na = z.getElementDimensions(this._content), oa = ((na.x + ma)), pa = ((na.y + ma)), qa = this._top, ra = ((ka - oa)), sa = ((la - pa));\n            if (((sa < 0))) {\n                qa = ha._PAGE_MARGIN;\n            }\n             else if (((qa > sa))) {\n                qa = ((ha._PAGE_MARGIN + ((Math.max(sa, 0) / 2))));\n            }\n            \n        ;\n        ;\n            var ta = ga();\n            if (!ta) {\n                qa += z.getScrollPosition().y;\n            }\n        ;\n        ;\n            w.set(this._popup, \"marginTop\", ((qa + \"px\")));\n            var ua = ((ta && ((((ra < 0)) || ((sa < 0))))));\n            m.conditionClass(this._obj, \"generic_dialog_fixed_overflow\", ua);\n            m.conditionClass(JSBNG__document.documentElement, \"generic_dialog_overflow_mode\", ua);\n        },\n        _fadeOut: function(ia) {\n            if (!this._popup) {\n                return;\n            }\n        ;\n        ;\n            try {\n                new h(this._obj).duration(0).checkpoint().to(\"opacity\", 0).hide().duration(250).JSBNG__ondone(this._hide.bind(this, ia)).go();\n            } catch (ja) {\n                this._hide(ia);\n            };\n        ;\n        },\n        _hide: function(ia) {\n            if (this._obj) {\n                this._obj.style.display = \"none\";\n            }\n        ;\n        ;\n            m.removeClass(JSBNG__document.documentElement, \"generic_dialog_overflow_mode\");\n            this._updateShim();\n            JSBNG__clearInterval(this.active_hiding);\n            if (this._bottom) {\n                var ja = ha._bottoms;\n                ja.splice(ja.indexOf(this._bottom), 1);\n                ha._updateMaxBottom();\n            }\n        ;\n        ;\n            if (((((this._previous_focus && JSBNG__document.activeElement)) && o.contains(this._obj, JSBNG__document.activeElement)))) {\n                r.JSBNG__focus(this._previous_focus);\n            }\n        ;\n        ;\n            if (ia) {\n                return;\n            }\n        ;\n        ;\n            this.destroy();\n        },\n        destroy: function() {\n            this._popFromStack();\n            if (this._obj) {\n                o.remove(this._obj);\n                this._obj = null;\n                ((this._shim && this._shim.hide()));\n                this._shim = null;\n            }\n        ;\n        ;\n            ((this._clickOnEnterListener && this._clickOnEnterListener.remove()));\n            if (this._close_handler) {\n                this._close_handler({\n                    return_data: this._return_data\n                });\n            }\n        ;\n        ;\n        },\n        _handleButton: function(ia) {\n            if (((typeof ia == \"string\"))) {\n                ia = ha._findButton(this._buttons, ia);\n            }\n        ;\n        ;\n            var ja = ha.call_or_eval(ia, ia.handler);\n            if (((ja === false))) {\n                return;\n            }\n        ;\n        ;\n            if (((ia.JSBNG__name == \"cancel\"))) {\n                this.cancel();\n            }\n             else if (((ha.call_or_eval(this, this._handler, {\n                button: ia\n            }) !== false))) {\n                this.hide();\n            }\n            \n        ;\n        ;\n        },\n        _submitForm: function(ia, ja, ka) {\n            var la = this.getFormData();\n            if (ka) {\n                la[ka.JSBNG__name] = ka.label;\n            }\n        ;\n        ;\n            if (this._extra_data) {\n                ba(la, this._extra_data);\n            }\n        ;\n        ;\n            var ma = new j().setURI(ja).setData(la).setMethod(ia).setNectarModuleDataSafe(this._causal_elem).setReadOnly(((ia == \"GET\")));\n            this.setAsync(ma);\n            return false;\n        },\n        _setFromModel: function(ia) {\n            var ja = {\n            };\n            ba(ja, ia);\n            for (var ka in ja) {\n                if (((ka == \"JSBNG__onloadRegister\"))) {\n                    this.JSBNG__onloadRegister(ja[ka]);\n                    continue;\n                }\n            ;\n            ;\n                var la = this[((((\"set\" + ka.substr(0, 1).toUpperCase())) + ka.substr(1)))];\n                la.apply(this, ca(ja[ka]));\n            };\n        ;\n        },\n        _updateBottom: function() {\n            var ia = ((z.getElementDimensions(this._content).y + z.getElementPosition(this._content).y));\n            ha._bottoms[((ha._bottoms.length - 1))] = ia;\n            ha._updateMaxBottom();\n        },\n        _pushOntoStack: function() {\n            var ia = ha._stack;\n            if (!ia.length) {\n                i.inform(\"layer_shown\", {\n                    type: \"Dialog\"\n                });\n            }\n        ;\n        ;\n            ia.remove(this);\n            ia.push(this);\n            for (var ja = ((ia.length - 2)); ((ja >= 0)); ja--) {\n                var ka = ia[ja];\n                if (((!ka._is_stackable && !ka._async_request))) {\n                    ka._hide();\n                }\n                 else if (!ka._shown_while_stacked) {\n                    ka._hide(true);\n                }\n                \n            ;\n            ;\n            };\n        ;\n        },\n        _popFromStack: function() {\n            var ia = ha._stack, ja = ((ia[((ia.length - 1))] === this));\n            ia.remove(this);\n            if (ia.length) {\n                if (ja) {\n                    ia[((ia.length - 1))].show();\n                }\n            ;\n            ;\n            }\n             else i.inform(\"layer_hidden\", {\n                type: \"Dialog\"\n            });\n        ;\n        ;\n        }\n    });\n    e.exports = ha;\n});\n__d(\"ViewportBounds\", [\"Style\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"Style\"), h = b(\"ge\"), i = {\n        JSBNG__top: [],\n        right: [],\n        bottom: [],\n        left: []\n    };\n    function j(n) {\n        return function() {\n            var o = 0;\n            i[n].forEach(function(p) {\n                o = Math.max(o, p.getSize());\n            });\n            return o;\n        };\n    };\n;\n    function k(n) {\n        return function(o) {\n            return new l(n, o);\n        };\n    };\n;\n    function l(n, o) {\n        this.getSide = bagof(n);\n        this.getSize = function() {\n            return ((((typeof o === \"function\")) ? o() : o));\n        };\n        i[n].push(this);\n    };\n;\n    l.prototype.remove = function() {\n        i[this.getSide()].remove(this);\n    };\n    var m = {\n        getTop: j(\"JSBNG__top\"),\n        getRight: j(\"right\"),\n        getBottom: j(\"bottom\"),\n        getLeft: j(\"left\"),\n        addTop: k(\"JSBNG__top\"),\n        addRight: k(\"right\"),\n        addBottom: k(\"bottom\"),\n        addLeft: k(\"left\")\n    };\n    m.addTop(function() {\n        var n = h(\"blueBar\");\n        if (((n && g.isFixed(n)))) {\n            return h(\"blueBarHolder\").offsetHeight;\n        }\n    ;\n    ;\n        return 0;\n    });\n    e.exports = m;\n});\n__d(\"DOMScroll\", [\"Animation\",\"Arbiter\",\"DOM\",\"DOMQuery\",\"Vector\",\"ViewportBounds\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"Animation\"), h = b(\"Arbiter\"), i = b(\"DOM\"), j = b(\"DOMQuery\"), k = b(\"Vector\"), l = b(\"ViewportBounds\"), m = b(\"ge\"), n = {\n        SCROLL: \"dom-scroll\",\n        getScrollState: function() {\n            var o = k.getViewportDimensions(), p = k.getDocumentDimensions(), q = ((p.x > o.x)), r = ((p.y > o.y));\n            q += 0;\n            r += 0;\n            return new k(q, r);\n        },\n        _scrollbarSize: null,\n        _initScrollbarSize: function() {\n            var o = i.create(\"p\");\n            o.style.width = \"100%\";\n            o.style.height = \"200px\";\n            var p = i.create(\"div\");\n            p.style.position = \"absolute\";\n            p.style.JSBNG__top = \"0px\";\n            p.style.left = \"0px\";\n            p.style.visibility = \"hidden\";\n            p.style.width = \"200px\";\n            p.style.height = \"150px\";\n            p.style.overflow = \"hidden\";\n            p.appendChild(o);\n            JSBNG__document.body.appendChild(p);\n            var q = o.offsetWidth;\n            p.style.overflow = \"JSBNG__scroll\";\n            var r = o.offsetWidth;\n            if (((q == r))) {\n                r = p.clientWidth;\n            }\n        ;\n        ;\n            JSBNG__document.body.removeChild(p);\n            n._scrollbarSize = ((q - r));\n        },\n        getScrollbarSize: function() {\n            if (((n._scrollbarSize === null))) {\n                n._initScrollbarSize();\n            }\n        ;\n        ;\n            return n._scrollbarSize;\n        },\n        JSBNG__scrollTo: function(o, p, q, r, s) {\n            if (((((typeof p == \"undefined\")) || ((p === true))))) {\n                p = 750;\n            }\n        ;\n        ;\n            if (!((o instanceof k))) {\n                var t = k.getScrollPosition().x, u = k.getElementPosition(m(o)).y;\n                o = new k(t, u, \"JSBNG__document\");\n                if (!r) {\n                    o.y -= ((l.getTop() / ((q ? 2 : 1))));\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            if (q) {\n                o.y -= ((k.getViewportDimensions().y / 2));\n            }\n             else if (r) {\n                o.y -= k.getViewportDimensions().y;\n                o.y += r;\n            }\n            \n        ;\n        ;\n            o = o.convertTo(\"JSBNG__document\");\n            if (p) {\n                return new g(JSBNG__document.body).to(\"scrollTop\", o.y).to(\"scrollLeft\", o.x).ease(g.ease.end).duration(p).JSBNG__ondone(s).go();\n            }\n             else if (window.JSBNG__scrollTo) {\n                window.JSBNG__scrollTo(o.x, o.y);\n                ((s && s()));\n            }\n            \n        ;\n        ;\n            h.inform(n.SCROLL);\n        },\n        ensureVisible: function(o, p, q, r, s) {\n            if (((q === undefined))) {\n                q = 10;\n            }\n        ;\n        ;\n            o = m(o);\n            if (p) {\n                o = j.JSBNG__find(o, p);\n            }\n        ;\n        ;\n            var t = k.getScrollPosition().x, u = k.getScrollPosition().y, v = ((u + k.getViewportDimensions().y)), w = k.getElementPosition(o).y, x = ((w + k.getElementDimensions(o).y));\n            w -= l.getTop();\n            w -= q;\n            x += q;\n            if (((w < u))) {\n                n.JSBNG__scrollTo(new k(t, w, \"JSBNG__document\"), r, false, false, s);\n            }\n             else if (((x > v))) {\n                if (((((w - ((x - v)))) < u))) {\n                    n.JSBNG__scrollTo(new k(t, w, \"JSBNG__document\"), r, false, false, s);\n                }\n                 else n.JSBNG__scrollTo(new k(t, x, \"JSBNG__document\"), r, false, true, s);\n            ;\n            }\n            \n        ;\n        ;\n        },\n        scrollToTop: function(o) {\n            var p = k.getScrollPosition();\n            n.JSBNG__scrollTo(new k(p.x, 0, \"JSBNG__document\"), ((o !== false)));\n        }\n    };\n    e.exports = n;\n});\n__d(\"HistoryManager\", [\"event-extensions\",\"function-extensions\",\"Cookie\",\"Env\",\"URI\",\"UserAgent\",\"copyProperties\",\"goOrReplace\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Cookie\"), h = b(\"Env\"), i = b(\"URI\"), j = b(\"UserAgent\"), k = b(\"copyProperties\"), l = b(\"goOrReplace\"), m = {\n        _IFRAME_BASE_URI: \"http://static.ak.facebook.com/common/history_manager.php\",\n        JSBNG__history: null,\n        current: 0,\n        fragment: null,\n        _setIframeSrcFragment: function(n) {\n            n = n.toString();\n            var o = ((m.JSBNG__history.length - 1));\n            m.iframe.src = ((((((((m._IFRAME_BASE_URI + \"?|index=\")) + o)) + \"#\")) + encodeURIComponent(n)));\n            return m;\n        },\n        getIframeSrcFragment: function() {\n            return decodeURIComponent(i(m.iframe.contentWindow.JSBNG__document.JSBNG__location.href).getFragment());\n        },\n        nextframe: function(n, o) {\n            if (o) {\n                m._setIframeSrcFragment(n);\n                return;\n            }\n        ;\n        ;\n            if (((n !== undefined))) {\n                m.iframeQueue.push(n);\n            }\n             else {\n                m.iframeQueue.splice(0, 1);\n                m.iframeTimeout = null;\n                m.checkURI();\n            }\n        ;\n        ;\n            if (((m.iframeQueue.length && !m.iframeTimeout))) {\n                var p = m.iframeQueue[0];\n                m.iframeTimeout = JSBNG__setTimeout(function() {\n                    m._setIframeSrcFragment(p);\n                }, 100, false);\n            }\n        ;\n        ;\n        },\n        isInitialized: function() {\n            return !!m._initialized;\n        },\n        init: function() {\n            if (((!h.ALLOW_TRANSITION_IN_IFRAME && ((window != window.JSBNG__top))))) {\n                return;\n            }\n        ;\n        ;\n            if (m._initialized) {\n                return m;\n            }\n        ;\n        ;\n            var n = i(), o = ((n.getFragment() || \"\"));\n            if (((o.charAt(0) === \"!\"))) {\n                o = o.substr(1);\n                n.setFragment(o);\n            }\n        ;\n        ;\n            if (((i.getRequestURI(false).getProtocol().toLowerCase() == \"https\"))) {\n                m._IFRAME_BASE_URI = \"https://s-static.ak.facebook.com/common/history_manager.php\";\n            }\n        ;\n        ;\n            k(m, {\n                _initialized: true,\n                fragment: o,\n                orig_fragment: o,\n                JSBNG__history: [n,],\n                callbacks: [],\n                lastChanged: JSBNG__Date.now(),\n                canonical: i(\"#\"),\n                fragmentTimeout: null,\n                user: 0,\n                iframeTimeout: null,\n                iframeQueue: [],\n                enabled: true,\n                debug: bagofholding\n            });\n            if (((window.JSBNG__history && JSBNG__history.pushState))) {\n                this.lastURI = JSBNG__document.JSBNG__URL;\n                window.JSBNG__history.replaceState(this.lastURI, null);\n                JSBNG__Event.listen(window, \"popstate\", function(p) {\n                    if (((((p && p.state)) && ((m.lastURI != p.state))))) {\n                        m.lastURI = p.state;\n                        m.lastChanged = JSBNG__Date.now();\n                        m.notify(i(p.state).getUnqualifiedURI().toString());\n                    }\n                ;\n                ;\n                }.bind(m));\n                if (((((j.safari() < 534)) || ((j.JSBNG__chrome() <= 13))))) {\n                    JSBNG__setInterval(m.checkURI, 42, false);\n                    m._updateRefererURI(this.lastURI);\n                }\n            ;\n            ;\n                return m;\n            }\n        ;\n        ;\n            m._updateRefererURI(i.getRequestURI(false));\n            if (((((j.safari() < 500)) || ((j.firefox() < 2))))) {\n                m.enabled = false;\n                return m;\n            }\n        ;\n        ;\n            if (((j.ie() < 8))) {\n                m.iframe = JSBNG__document.createElement(\"div\");\n                k(m.iframe.style, {\n                    width: \"0\",\n                    height: \"0\",\n                    frameborder: \"0\",\n                    left: \"0\",\n                    JSBNG__top: \"0\",\n                    position: \"absolute\"\n                });\n                m._setIframeSrcFragment(o);\n                JSBNG__document.body.insertBefore(m.iframe, JSBNG__document.body.firstChild);\n            }\n             else if (((\"JSBNG__onhashchange\" in window))) {\n                JSBNG__Event.listen(window, \"hashchange\", function() {\n                    m.checkURI.bind(m).defer();\n                });\n            }\n             else JSBNG__setInterval(m.checkURI, 42, false);\n            \n        ;\n        ;\n            return m;\n        },\n        registerURIHandler: function(n) {\n            m.callbacks.push(n);\n            return m;\n        },\n        setCanonicalLocation: function(n) {\n            m.canonical = i(n);\n            return m;\n        },\n        notify: function(n) {\n            if (((n == m.orig_fragment))) {\n                n = m.canonical.getFragment();\n            }\n        ;\n        ;\n            for (var o = 0; ((o < m.callbacks.length)); o++) {\n                try {\n                    if (m.callbacks[o](n)) {\n                        return true;\n                    }\n                ;\n                ;\n                } catch (p) {\n                \n                };\n            ;\n            };\n        ;\n            return false;\n        },\n        checkURI: function() {\n            if (((((JSBNG__Date.now() - m.lastChanged)) < 400))) {\n                return;\n            }\n        ;\n        ;\n            if (((window.JSBNG__history && JSBNG__history.pushState))) {\n                var n = i(JSBNG__document.JSBNG__URL).removeQueryData(\"ref\").toString(), o = i(m.lastURI).removeQueryData(\"ref\").toString();\n                if (((n != o))) {\n                    m.lastChanged = JSBNG__Date.now();\n                    m.lastURI = n;\n                    if (((j.safari() < 534))) {\n                        m._updateRefererURI(n);\n                    }\n                ;\n                ;\n                    m.notify(i(n).getUnqualifiedURI().toString());\n                }\n            ;\n            ;\n                return;\n            }\n        ;\n        ;\n            if (((((j.ie() < 8)) && m.iframeQueue.length))) {\n                return;\n            }\n        ;\n        ;\n            if (((j.safari() && ((window.JSBNG__history.length == 200))))) {\n                if (!m.warned) {\n                    m.warned = true;\n                }\n            ;\n            ;\n                return;\n            }\n        ;\n        ;\n            var p = i().getFragment();\n            if (((p.charAt(0) == \"!\"))) {\n                p = p.substr(1);\n            }\n        ;\n        ;\n            if (((j.ie() < 8))) {\n                p = m.getIframeSrcFragment();\n            }\n        ;\n        ;\n            p = p.replace(/%23/g, \"#\");\n            if (((p != m.fragment.replace(/%23/g, \"#\")))) {\n                m.debug([p,\" vs \",m.fragment,\"whl: \",window.JSBNG__history.length,\"QHL: \",m.JSBNG__history.length,].join(\" \"));\n                for (var q = ((m.JSBNG__history.length - 1)); ((q >= 0)); --q) {\n                    if (((m.JSBNG__history[q].getFragment().replace(/%23/g, \"#\") == p))) {\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n                ++m.user;\n                if (((q >= 0))) {\n                    m.go(((q - m.current)));\n                }\n                 else m.go(((\"#\" + p)));\n            ;\n            ;\n                --m.user;\n            }\n        ;\n        ;\n        },\n        _updateRefererURI: function(n) {\n            n = n.toString();\n            if (((((n.charAt(0) != \"/\")) && ((n.indexOf(\"//\") == -1))))) {\n                return;\n            }\n        ;\n        ;\n            var o = new i(window.JSBNG__location);\n            if (o.isFacebookURI()) {\n                var p = ((o.getPath() + window.JSBNG__location.search));\n            }\n             else var p = \"\"\n        ;\n            var q = i(n).getQualifiedURI().setFragment(p).toString(), r = 2048;\n            if (((q.length > r))) {\n                q = ((q.substring(0, r) + \"...\"));\n            }\n        ;\n        ;\n            g.set(\"x-referer\", q);\n        },\n        go: function(n, o, p) {\n            if (((window.JSBNG__history && JSBNG__history.pushState))) {\n                ((o || ((typeof (n) == \"number\"))));\n                var q = i(n).removeQueryData(\"ref\").toString();\n                m.lastChanged = JSBNG__Date.now();\n                this.lastURI = q;\n                if (p) {\n                    window.JSBNG__history.replaceState(n, null, q);\n                }\n                 else window.JSBNG__history.pushState(n, null, q);\n            ;\n            ;\n                if (((j.safari() < 534))) {\n                    m._updateRefererURI(n);\n                }\n            ;\n            ;\n                return false;\n            }\n        ;\n        ;\n            m.debug(((\"go: \" + n)));\n            if (((o === undefined))) {\n                o = true;\n            }\n        ;\n        ;\n            if (!m.enabled) {\n                if (!o) {\n                    return false;\n                }\n            ;\n            }\n        ;\n        ;\n            if (((typeof (n) == \"number\"))) {\n                if (!n) {\n                    return false;\n                }\n            ;\n            ;\n                var r = ((n + m.current)), s = Math.max(0, Math.min(((m.JSBNG__history.length - 1)), r));\n                m.current = s;\n                r = ((m.JSBNG__history[s].getFragment() || m.orig_fragment));\n                r = i(r).removeQueryData(\"ref\").getUnqualifiedURI().toString();\n                m.fragment = r;\n                m.lastChanged = JSBNG__Date.now();\n                if (((j.ie() < 8))) {\n                    if (m.fragmentTimeout) {\n                        JSBNG__clearTimeout(m.fragmentTimeout);\n                    }\n                ;\n                ;\n                    m._temporary_fragment = r;\n                    m.fragmentTimeout = JSBNG__setTimeout(function() {\n                        window.JSBNG__location.hash = ((\"#!\" + r));\n                        delete m._temporary_fragment;\n                    }, 750, false);\n                    if (!m.user) {\n                        m.nextframe(r, p);\n                    }\n                ;\n                ;\n                }\n                 else if (!m.user) {\n                    l(window.JSBNG__location, ((((window.JSBNG__location.href.split(\"#\")[0] + \"#!\")) + r)), p);\n                }\n                \n            ;\n            ;\n                if (o) {\n                    m.notify(r);\n                }\n            ;\n            ;\n                m._updateRefererURI(r);\n                return false;\n            }\n        ;\n        ;\n            n = i(n);\n            if (((n.getDomain() == i().getDomain()))) {\n                n = i(((\"#\" + n.getUnqualifiedURI())));\n            }\n        ;\n        ;\n            var t = m.JSBNG__history[m.current].getFragment(), u = n.getFragment();\n            if (((((u == t)) || ((((t == m.orig_fragment)) && ((u == m.canonical.getFragment()))))))) {\n                if (o) {\n                    m.notify(u);\n                }\n            ;\n            ;\n                m._updateRefererURI(u);\n                return false;\n            }\n        ;\n        ;\n            if (p) {\n                m.current--;\n            }\n        ;\n        ;\n            var v = ((((m.JSBNG__history.length - m.current)) - 1));\n            m.JSBNG__history.splice(((m.current + 1)), v);\n            m.JSBNG__history.push(i(n));\n            return m.go(1, o, p);\n        },\n        getCurrentFragment: function() {\n            var n = ((((m._temporary_fragment !== undefined)) ? m._temporary_fragment : i.getRequestURI(false).getFragment()));\n            return ((((n == m.orig_fragment)) ? m.canonical.getFragment() : n));\n        }\n    };\n    e.exports = m;\n});\n__d(\"JSLogger\", [], function(a, b, c, d, e, f) {\n    var g = {\n        MAX_HISTORY: 500,\n        counts: {\n        },\n        categories: {\n        },\n        seq: 0,\n        pageId: ((((Math.JSBNG__random() * 2147483648)) | 0)).toString(36)\n    };\n    function h(l) {\n        if (((((l instanceof Error)) && a.ErrorUtils))) {\n            l = a.ErrorUtils.normalizeError(l);\n        }\n    ;\n    ;\n        try {\n            return JSON.stringify(l);\n        } catch (m) {\n            return \"{}\";\n        };\n    ;\n    };\n;\n    function i(l, JSBNG__event, m) {\n        if (!g.counts[l]) {\n            g.counts[l] = {\n            };\n        }\n    ;\n    ;\n        if (!g.counts[l][JSBNG__event]) {\n            g.counts[l][JSBNG__event] = 0;\n        }\n    ;\n    ;\n        m = ((((m == null)) ? 1 : Number(m)));\n        g.counts[l][JSBNG__event] += ((isFinite(m) ? m : 0));\n    };\n;\n    g.logAction = function(JSBNG__event, l, m) {\n        if (((this.type == \"bump\"))) {\n            i(this.cat, JSBNG__event, l);\n        }\n         else if (((this.type == \"rate\"))) {\n            ((l && i(this.cat, ((JSBNG__event + \"_n\")), m)));\n            i(this.cat, ((JSBNG__event + \"_d\")), m);\n        }\n         else {\n            var n = {\n                cat: this.cat,\n                type: this.type,\n                JSBNG__event: JSBNG__event,\n                data: ((((l != null)) ? h(l) : null)),\n                date: JSBNG__Date.now(),\n                seq: g.seq++\n            };\n            g.head = ((g.head ? (g.head.next = n) : (g.tail = n)));\n            while (((((g.head.seq - g.tail.seq)) > g.MAX_HISTORY))) {\n                g.tail = g.tail.next;\n            ;\n            };\n        ;\n            return n;\n        }\n        \n    ;\n    ;\n    };\n    function j(l) {\n        if (!g.categories[l]) {\n            g.categories[l] = {\n            };\n            var m = function(n) {\n                var o = {\n                    cat: l,\n                    type: n\n                };\n                g.categories[l][n] = function() {\n                    if (((JSBNG__document.domain != \"facebook.com\"))) {\n                        return;\n                    }\n                ;\n                ;\n                    var p;\n                    try {\n                        p = ((a.JSBNG__top.require && a.JSBNG__top.require(\"JSLogger\")._.logAction));\n                    } catch (q) {\n                    \n                    };\n                ;\n                    ((p && p.apply(o, arguments)));\n                };\n            };\n            m(\"debug\");\n            m(\"log\");\n            m(\"warn\");\n            m(\"error\");\n            m(\"bump\");\n            m(\"rate\");\n        }\n    ;\n    ;\n        return g.categories[l];\n    };\n;\n    function k(l, m) {\n        var n = [];\n        for (var o = ((m || g.tail)); o; o = o.next) {\n            if (((!l || l(o)))) {\n                var p = {\n                    type: o.type,\n                    cat: o.cat,\n                    date: o.date,\n                    JSBNG__event: o.JSBNG__event,\n                    seq: o.seq\n                };\n                if (o.data) {\n                    p.data = JSON.parse(o.data);\n                }\n            ;\n            ;\n                n.push(p);\n            }\n        ;\n        ;\n        };\n    ;\n        return n;\n    };\n;\n    e.exports = {\n        _: g,\n        DUMP_EVENT: \"jslogger/dump\",\n        create: j,\n        getEntries: k\n    };\n});\n__d(\"LinkController\", [\"event-extensions\",\"DataStore\",\"Parent\",\"trackReferrer\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"DataStore\"), h = b(\"Parent\"), i = b(\"trackReferrer\"), j = \"LinkControllerHandler\", k = [], l = [];\n    function m(JSBNG__event) {\n        var q = h.byTag(JSBNG__event.getTarget(), \"a\"), r = ((q && q.getAttribute(\"href\", 2)));\n        if (((((((!r || q.rel)) || !o(r))) || g.get(q, j)))) {\n            return;\n        }\n    ;\n    ;\n        var s = JSBNG__Event.listen(q, \"click\", function(t) {\n            if (((r.charAt(((r.length - 1))) == \"#\"))) {\n                t.prevent();\n                return;\n            }\n        ;\n        ;\n            i(q, r);\n            n(q, t);\n        });\n        g.set(q, j, s);\n    };\n;\n    function n(q, JSBNG__event) {\n        if (((((q.target || JSBNG__event.getModifiers().any)) || ((JSBNG__event.which && ((JSBNG__event.which != 1))))))) {\n            return;\n        }\n    ;\n    ;\n        var r = k.concat(l);\n        for (var s = 0, t = r.length; ((s < t)); s++) {\n            if (((r[s](q, JSBNG__event) === false))) {\n                return JSBNG__event.kill();\n            }\n        ;\n        ;\n        };\n    ;\n    };\n;\n    function o(q) {\n        var r = q.match(/^(\\w+):/);\n        return ((!r || r[1].match(/^http/i)));\n    };\n;\n    var p = {\n        registerHandler: function(q) {\n            k.push(q);\n        },\n        registerFallbackHandler: function(q) {\n            l.push(q);\n        }\n    };\n    JSBNG__Event.listen(JSBNG__document.documentElement, \"mousedown\", m);\n    JSBNG__Event.listen(JSBNG__document.documentElement, \"keydown\", m);\n    e.exports = p;\n});\n__d(\"htmlSpecialChars\", [], function(a, b, c, d, e, f) {\n    function g(h) {\n        if (((((((typeof h == \"undefined\")) || ((h === null)))) || !h.toString))) {\n            return \"\";\n        }\n    ;\n    ;\n        if (((h === false))) {\n            return \"0\";\n        }\n         else if (((h === true))) {\n            return \"1\";\n        }\n        \n    ;\n    ;\n        return h.toString().replace(/&/g, \"&amp;\").replace(/\"/g, \"&quot;\").replace(/'/g, \"&#039;\").replace(/</g, \"&lt;\").replace(/>/g, \"&gt;\");\n    };\n;\n    e.exports = g;\n});\n__d(\"htmlize\", [\"htmlSpecialChars\",], function(a, b, c, d, e, f) {\n    var g = b(\"htmlSpecialChars\");\n    function h(i) {\n        return g(i).replace(/\\r\\n|[\\r\\n]/g, \"\\u003Cbr /\\u003E\");\n    };\n;\n    e.exports = h;\n});\n__d(\"escapeJSQuotes\", [], function(a, b, c, d, e, f) {\n    function g(h) {\n        if (((((((typeof h == \"undefined\")) || ((h == null)))) || !h.valueOf()))) {\n            return \"\";\n        }\n    ;\n    ;\n        return h.toString().replace(/\\\\/g, \"\\\\\\\\\").replace(/\\n/g, \"\\\\n\").replace(/\\r/g, \"\\\\r\").replace(/\"/g, \"\\\\x22\").replace(/'/g, \"\\\\'\").replace(/</g, \"\\\\x3c\").replace(/>/g, \"\\\\x3e\").replace(/&/g, \"\\\\x26\");\n    };\n;\n    e.exports = g;\n});\n__d(\"areObjectsEqual\", [], function(a, b, c, d, e, f) {\n    function g(h, i) {\n        return ((JSON.stringify(h) == JSON.stringify(i)));\n    };\n;\n    e.exports = g;\n});\n__d(\"computeRelativeURI\", [\"URI\",\"isEmpty\",], function(a, b, c, d, e, f) {\n    var g = b(\"URI\"), h = b(\"isEmpty\");\n    function i(k, l) {\n        if (!l) {\n            return k;\n        }\n    ;\n    ;\n        if (((l.charAt(0) == \"/\"))) {\n            return l;\n        }\n    ;\n    ;\n        var m = k.split(\"/\").slice(0, -1);\n        ((m[0] !== \"\"));\n        l.split(\"/\").forEach(function(n) {\n            if (!((n == \".\"))) {\n                if (((n == \"..\"))) {\n                    if (((m.length > 1))) {\n                        m = m.slice(0, -1);\n                    }\n                ;\n                ;\n                }\n                 else m.push(n);\n            ;\n            }\n        ;\n        ;\n        });\n        return m.join(\"/\");\n    };\n;\n    function j(k, l) {\n        var m = new g(), n = l;\n        k = new g(k);\n        l = new g(l);\n        if (((l.getDomain() && !l.isFacebookURI()))) {\n            return n;\n        }\n    ;\n    ;\n        var o = k, p = [\"Protocol\",\"Domain\",\"Port\",\"Path\",\"QueryData\",\"Fragment\",];\n        p.forEach(function(q) {\n            var r = ((((q == \"Path\")) && ((o === k))));\n            if (r) {\n                m.setPath(i(k.getPath(), l.getPath()));\n            }\n        ;\n        ;\n            if (!h(l[((\"get\" + q))]())) {\n                o = l;\n            }\n        ;\n        ;\n            if (!r) {\n                m[((\"set\" + q))](o[((\"get\" + q))]());\n            }\n        ;\n        ;\n        });\n        return m;\n    };\n;\n    e.exports = j;\n});\n__d(\"startsWith\", [], function(a, b, c, d, e, f) {\n    function g(h, i, j) {\n        var k = String(h);\n        j = Math.min(Math.max(((j || 0)), 0), k.length);\n        return ((k.lastIndexOf(String(i), j) === j));\n    };\n;\n    e.exports = g;\n});\n__d(\"PageTransitions\", [\"event-extensions\",\"Arbiter\",\"Dialog\",\"DOM\",\"DOMScroll\",\"Env\",\"Form\",\"HistoryManager\",\"JSLogger\",\"LinkController\",\"OnloadHooks\",\"htmlize\",\"escapeJSQuotes\",\"URI\",\"UserAgent\",\"Vector\",\"areObjectsEqual\",\"computeRelativeURI\",\"copyProperties\",\"ge\",\"goOrReplace\",\"startsWith\",\"tx\",\"userAction\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"Dialog\"), i = b(\"DOM\"), j = b(\"DOMScroll\"), k = b(\"Env\"), l = b(\"Form\"), m = b(\"HistoryManager\"), n = b(\"JSLogger\"), o = b(\"LinkController\"), p = b(\"OnloadHooks\"), q = b(\"htmlize\"), r = b(\"escapeJSQuotes\"), s = b(\"URI\"), t = b(\"UserAgent\"), u = b(\"Vector\"), v = b(\"areObjectsEqual\"), w = b(\"computeRelativeURI\"), x = b(\"copyProperties\"), y = b(\"ge\"), z = b(\"goOrReplace\"), aa = b(\"startsWith\"), ba = b(\"tx\"), ca = b(\"userAction\"), da = {\n        _transition_handlers: [],\n        _scroll_positions: {\n        },\n        _scroll_locked: false,\n        isInitialized: function() {\n            return !!da._initialized;\n        },\n        _init: function() {\n            if (((!k.ALLOW_TRANSITION_IN_IFRAME && ((window != window.JSBNG__top))))) {\n                return;\n            }\n        ;\n        ;\n            if (da._initialized) {\n                return da;\n            }\n        ;\n        ;\n            da._initialized = true;\n            var fa = s.getRequestURI(false), ga = fa.getUnqualifiedURI(), ha = s(ga).setFragment(null), ia = ga.getFragment();\n            if (((((ia.charAt(0) === \"!\")) && ((ha.toString() === ia.substr(1)))))) {\n                ga = ha;\n            }\n        ;\n        ;\n            x(da, {\n                _current_uri: ga,\n                _most_recent_uri: ga,\n                _next_uri: ga\n            });\n            var ja;\n            if (aa(fa.getFragment(), \"/\")) {\n                ja = fa.getFragment();\n            }\n             else ja = ga;\n        ;\n        ;\n            m.init().setCanonicalLocation(((\"#\" + ja))).registerURIHandler(da._historyManagerHandler);\n            o.registerFallbackHandler(da._rewriteHref);\n            o.registerFallbackHandler(da._onlinkclick);\n            JSBNG__Event.listen(JSBNG__document.documentElement, \"submit\", da._onformsubmit);\n            JSBNG__Event.listen(window, \"JSBNG__scroll\", function() {\n                if (!da._scroll_locked) {\n                    da._scroll_positions[da._current_uri] = u.getScrollPosition();\n                }\n            ;\n            ;\n            });\n            return da;\n        },\n        registerHandler: function(fa, ga) {\n            da._init();\n            ga = ((ga || 5));\n            if (!da._transition_handlers[ga]) {\n                da._transition_handlers[ga] = [];\n            }\n        ;\n        ;\n            da._transition_handlers[ga].push(fa);\n        },\n        getCurrentURI: function(fa) {\n            if (((!da._current_uri && !fa))) {\n                return new s(da._most_recent_uri);\n            }\n        ;\n        ;\n            return new s(da._current_uri);\n        },\n        getMostRecentURI: function() {\n            return new s(da._most_recent_uri);\n        },\n        getNextURI: function() {\n            return new s(da._next_uri);\n        },\n        _rewriteHref: function(fa) {\n            var ga = fa.getAttribute(\"href\"), ha = w(da._most_recent_uri.getQualifiedURI(), ga).toString();\n            if (((ga != ha))) {\n                fa.setAttribute(\"href\", ha);\n            }\n        ;\n        ;\n        },\n        _onlinkclick: function(fa) {\n            ea.lookBusy(fa);\n            da.go(fa.getAttribute(\"href\"));\n            return false;\n        },\n        _onformsubmit: function(JSBNG__event) {\n            var fa = JSBNG__event.getTarget();\n            if (((l.getAttribute(fa, \"rel\") || l.getAttribute(fa, \"target\")))) {\n                return;\n            }\n        ;\n        ;\n            var ga = ca(\"form\", fa, JSBNG__event).set_namespace(\"page_transition\"), ha = a.ArbiterMonitor;\n            if (ha) {\n                ha.initUA(ga, [fa,]);\n            }\n        ;\n        ;\n            var ia = new s(((l.getAttribute(fa, \"action\") || \"\"))), ja = w(da._most_recent_uri, ia);\n            fa.setAttribute(\"action\", ja.toString());\n            if (((((l.getAttribute(fa, \"method\") || \"GET\")).toUpperCase() === \"GET\"))) {\n                da.go(ja.addQueryData(l.serialize(fa)));\n                JSBNG__event.kill();\n            }\n        ;\n        ;\n        },\n        go: function(fa, ga) {\n            var ha = new s(fa).removeQueryData(\"quickling\").getQualifiedURI();\n            n.create(\"pagetransition\").debug(\"go\", {\n                uri: ha.toString()\n            });\n            var ia = ha.getUnqualifiedURI();\n            delete da._scroll_positions[ia];\n            ((!ga && ca(\"uri\", {\n                href: ha.toString()\n            }, null, \"INDIRECT\")));\n            ea.lookBusy();\n            da._loadPage(ha, function(ja) {\n                if (ja) {\n                    m.go(ha.toString(), false, ga);\n                }\n                 else z(window.JSBNG__location, ha, ga);\n            ;\n            ;\n            });\n        },\n        _historyManagerHandler: function(fa) {\n            if (((fa.charAt(0) != \"/\"))) {\n                return false;\n            }\n        ;\n        ;\n            ca(\"h\", {\n                href: fa\n            }, null);\n            da._loadPage(new s(fa), function(ga) {\n                if (!ga) {\n                    z(window.JSBNG__location, fa, true);\n                }\n            ;\n            ;\n            });\n            return true;\n        },\n        _loadPage: function(fa, ga) {\n            if (((s(fa).getFragment() && v(s(fa).setFragment(null).getQualifiedURI(), s(da._current_uri).setFragment(null).getQualifiedURI())))) {\n                da._current_uri = da._most_recent_uri = fa;\n                da.restoreScrollPosition();\n                ea.stopLookingBusy();\n                return;\n            }\n        ;\n        ;\n            var ha = da._scroll_positions[da._current_uri];\n            da._current_uri = null;\n            da._next_uri = fa;\n            if (ha) {\n                j.JSBNG__scrollTo(ha, false);\n            }\n        ;\n        ;\n            var ia = function() {\n                da._scroll_locked = true;\n                var ka = da._handleTransition(fa);\n                ((ga && ga(ka)));\n            }, ja = p.runHooks(\"JSBNG__onbeforeleavehooks\");\n            if (ja) {\n                ea.stopLookingBusy();\n                da._warnBeforeLeaving(ja, ia);\n            }\n             else ia();\n        ;\n        ;\n        },\n        _handleTransition: function(fa) {\n            window.JSBNG__onbeforeleavehooks = undefined;\n            ea.lookBusy();\n            if (!fa.isSameOrigin()) {\n                return false;\n            }\n        ;\n        ;\n            var ga = ((window.AsyncRequest && window.AsyncRequest.getLastID()));\n            g.inform(\"pre_page_transition\", {\n                from: da.getMostRecentURI(),\n                to: fa\n            });\n            for (var ha = ((da._transition_handlers.length - 1)); ((ha >= 0)); --ha) {\n                var ia = da._transition_handlers[ha];\n                if (!ia) {\n                    continue;\n                }\n            ;\n            ;\n                for (var ja = ((ia.length - 1)); ((ja >= 0)); --ja) {\n                    if (((ia[ja](fa) === true))) {\n                        var ka = {\n                            sender: this,\n                            uri: fa,\n                            id: ga\n                        };\n                        try {\n                            g.inform(\"page_transition\", ka);\n                        } catch (la) {\n                        \n                        };\n                    ;\n                        return true;\n                    }\n                     else ia.splice(ja, 1);\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n            return false;\n        },\n        unifyURI: function() {\n            da._current_uri = da._most_recent_uri = da._next_uri;\n        },\n        transitionComplete: function(fa) {\n            da._executeCompletionCallback();\n            ea.stopLookingBusy();\n            da.unifyURI();\n            if (!fa) {\n                da.restoreScrollPosition();\n            }\n        ;\n        ;\n            try {\n                if (((JSBNG__document.activeElement && ((JSBNG__document.activeElement.nodeName === \"A\"))))) {\n                    JSBNG__document.activeElement.JSBNG__blur();\n                }\n            ;\n            ;\n            } catch (ga) {\n            \n            };\n        ;\n        },\n        _executeCompletionCallback: function() {\n            if (da._completionCallback) {\n                da._completionCallback();\n            }\n        ;\n        ;\n            da._completionCallback = null;\n        },\n        setCompletionCallback: function(fa) {\n            da._completionCallback = fa;\n        },\n        rewriteCurrentURI: function(fa, ga) {\n            da.registerHandler(function() {\n                if (((fa == da.getMostRecentURI().getUnqualifiedURI().toString()))) {\n                    da.transitionComplete();\n                    return true;\n                }\n            ;\n            ;\n            });\n            da.go(ga, true);\n        },\n        _warnBeforeLeaving: function(fa, ga) {\n            new h().setTitle(\"Are you sure you want to leave this page?\").setBody(q(fa)).setButtons([{\n                JSBNG__name: \"leave_page\",\n                label: \"Leave this Page\",\n                handler: ga\n            },{\n                JSBNG__name: \"continue_editing\",\n                label: \"Stay on this Page\",\n                className: \"inputaux\"\n            },]).setModal(true).show();\n        },\n        restoreScrollPosition: function() {\n            da._scroll_locked = false;\n            var fa = da._current_uri, ga = da._scroll_positions[fa];\n            if (ga) {\n                j.JSBNG__scrollTo(ga, false);\n                return;\n            }\n        ;\n        ;\n            function ha(ka) {\n                if (!ka) {\n                    return null;\n                }\n            ;\n            ;\n                var la = ((((\"a[name='\" + r(ka))) + \"']\"));\n                return ((i.scry(JSBNG__document.body, la)[0] || y(ka)));\n            };\n        ;\n            var ia = ha(s(fa).getFragment());\n            if (ia) {\n                var ja = u.getElementPosition(ia);\n                ja.x = 0;\n                j.JSBNG__scrollTo(ja);\n            }\n        ;\n        ;\n        }\n    }, ea = ((window._BusyUIManager || {\n        _looking_busy: false,\n        _original_cursors: [],\n        lookBusy: function(fa) {\n            if (fa) {\n                ea._giveProgressCursor(fa);\n            }\n        ;\n        ;\n            if (ea._looking_busy) {\n                return;\n            }\n        ;\n        ;\n            ea._looking_busy = true;\n            ea._giveProgressCursor(JSBNG__document.documentElement);\n        },\n        stopLookingBusy: function() {\n            if (!ea._looking_busy) {\n                return;\n            }\n        ;\n        ;\n            ea._looking_busy = false;\n            while (ea._original_cursors.length) {\n                var fa = ea._original_cursors.pop(), ga = fa[0], ha = fa[1];\n                if (ga.style) {\n                    ga.style.cursor = ((ha || \"\"));\n                }\n            ;\n            ;\n            };\n        ;\n        },\n        _giveProgressCursor: function(fa) {\n            if (!t.safari()) {\n                ea._original_cursors.push([fa,fa.style.cursor,]);\n                fa.style.cursor = \"progress\";\n            }\n        ;\n        ;\n        }\n    }));\n    e.exports = da;\n});\n__d(\"TextInputControl\", [\"event-extensions\",\"function-extensions\",\"Class\",\"DOMControl\",\"Input\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Class\"), h = b(\"DOMControl\"), i = b(\"Input\"), j = b(\"copyProperties\");\n    function k(l) {\n        this.parent.construct(this, l);\n        var m = this.getRoot(), n = function() {\n            this.update.bind(this).defer();\n        }.bind(this);\n        JSBNG__Event.listen(m, {\n            keydown: n,\n            paste: n\n        });\n    };\n;\n    g.extend(k, h);\n    j(k.prototype, {\n        setMaxLength: function(l) {\n            i.setMaxLength(this.getRoot(), l);\n            return this;\n        },\n        getValue: function() {\n            return i.getValue(this.getRoot());\n        },\n        isEmpty: function() {\n            return i.isEmpty(this.getRoot());\n        },\n        setValue: function(l) {\n            i.setValue(this.getRoot(), l);\n            this.update();\n            return this;\n        },\n        clear: function() {\n            return this.setValue(\"\");\n        },\n        setPlaceholderText: function(l) {\n            i.setPlaceholder(this.getRoot(), l);\n            return this;\n        }\n    });\n    e.exports = k;\n});\n__d(\"JSBNG__TextMetrics\", [\"array-extensions\",\"event-extensions\",\"DOM\",\"Style\",\"UserAgent\",\"debounce\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    var g = b(\"DOM\"), h = b(\"Style\"), i = b(\"UserAgent\"), j = b(\"debounce\"), k;\n    function l() {\n        if (((typeof k === \"undefined\"))) {\n            var n = g.create(\"div\", {\n                className: \"webkitZoomTest\"\n            }), o = function() {\n                g.appendContent(JSBNG__document.body, n);\n                k = ((100 / n.clientHeight));\n                g.remove(n);\n            };\n            JSBNG__Event.listen(window, \"resize\", j(o, 100));\n            o();\n        }\n    ;\n    ;\n        return k;\n    };\n;\n    function m(n, o) {\n        this._node = n;\n        this._flexible = !!o;\n        var p = \"textarea\", q = \"textMetrics\";\n        if (this._flexible) {\n            p = \"div\";\n            q += \" textMetricsInline\";\n        }\n    ;\n    ;\n        this._shadow = g.create(p, {\n            className: q\n        });\n        var r = [\"fontSize\",\"fontStyle\",\"fontWeight\",\"fontFamily\",\"wordWrap\",];\n        r.forEach(function(t) {\n            h.set(this._shadow, t, h.get(n, t));\n        }.bind(this));\n        var s = h.get(n, \"lineHeight\");\n        if (((i.JSBNG__chrome() || i.safari()))) {\n            s = ((Math.round(((parseInt(s, 10) * l()))) + \"px\"));\n        }\n    ;\n    ;\n        h.set(this._shadow, \"lineHeight\", s);\n        JSBNG__document.body.appendChild(this._shadow);\n    };\n;\n    m.prototype.measure = function(n) {\n        var o = this._node, p = this._shadow;\n        n = ((((n || o.value)) + \"...\"));\n        if (!this._flexible) {\n            var q = ((((o.clientWidth - h.getFloat(o, \"paddingLeft\"))) - h.getFloat(o, \"paddingRight\")));\n            h.set(p, \"width\", ((Math.max(q, 0) + \"px\")));\n        }\n    ;\n    ;\n        g.setContent(p, n);\n        return {\n            width: p.scrollWidth,\n            height: p.scrollHeight\n        };\n    };\n    m.prototype.destroy = function() {\n        g.remove(this._shadow);\n    };\n    e.exports = m;\n});\n__d(\"TextAreaControl\", [\"event-extensions\",\"Arbiter\",\"ArbiterMixin\",\"Class\",\"CSS\",\"DOMControl\",\"Style\",\"TextInputControl\",\"JSBNG__TextMetrics\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"Class\"), j = b(\"CSS\"), k = b(\"DOMControl\"), l = b(\"Style\"), m = b(\"TextInputControl\"), n = b(\"JSBNG__TextMetrics\"), o = b(\"copyProperties\");\n    function p(q) {\n        this.autogrow = j.hasClass(q, \"uiTextareaAutogrow\");\n        this.parent.construct(this, q);\n        this.width = null;\n        JSBNG__Event.listen(q, \"JSBNG__focus\", this._handleFocus.bind(this));\n    };\n;\n    i.extend(p, m);\n    o(p.prototype, h, {\n        setAutogrow: function(q) {\n            this.autogrow = q;\n            return this;\n        },\n        JSBNG__onupdate: function() {\n            this.parent.JSBNG__onupdate();\n            if (this.autogrow) {\n                var q = this.getRoot();\n                if (!this.metrics) {\n                    this.metrics = new n(q);\n                }\n            ;\n            ;\n                if (((typeof this.initialHeight === \"undefined\"))) {\n                    this.isBorderBox = ((((((l.get(q, \"box-sizing\") === \"border-box\")) || ((l.get(q, \"-moz-box-sizing\") === \"border-box\")))) || ((l.get(q, \"-webkit-box-sizing\") === \"border-box\"))));\n                    this.borderBoxOffset = ((((((l.getFloat(q, \"padding-top\") + l.getFloat(q, \"padding-bottom\"))) + l.getFloat(q, \"border-top-width\"))) + l.getFloat(q, \"border-bottom-width\")));\n                    this.initialHeight = ((q.offsetHeight - this.borderBoxOffset));\n                }\n            ;\n            ;\n                var r = this.metrics.measure(), s = Math.max(this.initialHeight, r.height);\n                if (this.isBorderBox) {\n                    s += this.borderBoxOffset;\n                }\n            ;\n            ;\n                if (((s !== this.height))) {\n                    this.height = s;\n                    l.set(q, \"height\", ((s + \"px\")));\n                    g.inform(\"reflow\");\n                    this.inform(\"resize\");\n                }\n            ;\n            ;\n            }\n             else if (this.metrics) {\n                this.metrics.destroy();\n                this.metrics = null;\n            }\n            \n        ;\n        ;\n        },\n        resetHeight: function() {\n            this.height = -1;\n            this.update();\n        },\n        _handleFocus: function() {\n            this.width = null;\n        }\n    });\n    p.getInstance = function(q) {\n        return ((k.getInstance(q) || new p(q)));\n    };\n    e.exports = p;\n});\n__d(\"URLScraper\", [\"event-extensions\",\"ArbiterMixin\",\"Class\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"Class\"), i = b(\"copyProperties\");\n    function j(ga) {\n        this.input = ga;\n        this.enable();\n    };\n;\n    i(j.prototype, g, {\n        reset: function() {\n            this.lastPermissiveMatch = null;\n        },\n        enable: function() {\n            if (this.events) {\n                return;\n            }\n        ;\n        ;\n            var ga = function(ha) {\n                JSBNG__setTimeout(this.check.bind(this, ha), 30);\n            };\n            this.events = JSBNG__Event.listen(this.input, {\n                paste: ga.bind(this, false),\n                keydown: ga.bind(this, true)\n            });\n        },\n        disable: function() {\n            if (!this.events) {\n                return;\n            }\n        ;\n        ;\n            for (var JSBNG__event in this.events) {\n                this.events[JSBNG__event].remove();\n            ;\n            };\n        ;\n            this.events = null;\n        },\n        check: function(ga) {\n            var ha = this.input.value;\n            if (((ga && j.trigger(ha)))) {\n                return;\n            }\n        ;\n        ;\n            var ia = j.match(ha), ja = j.permissiveMatch(ha);\n            if (((ja && ((ja != this.lastPermissiveMatch))))) {\n                this.lastPermissiveMatch = ja;\n                this.inform(\"match\", {\n                    url: ia,\n                    alt_url: ja\n                });\n            }\n        ;\n        ;\n        }\n    });\n    var k = \"!\\\"#%&'()*,-./:;\\u003C\\u003E?@[\\\\]^_`{|}\", l = \"\\u2000-\\u206f\\u00ab\\u00bb\", m = \"(?:25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9]?[0-9])\", n = \"(?:(?:ht|f)tps?)://\", o = ((((((((\"(?:(?:\" + m)) + \"[.]){3}\")) + m)) + \")\")), p = \"(?:\\\\b)www\\\\d{0,3}[.]\", q = ((((((\"[^\\\\s\" + k)) + l)) + \"]\")), r = ((((((((\"(?:(?:[.:\\\\-_%@]|\" + q)) + \")*\")) + q)) + \")\")), s = \"(?:[.][a-z]{2,4})\", t = \"(?::\\\\d+){0,1}\", u = \"(?=[/?#])\", v = ((((((((((((((((((((((((((((((((((((((((((((\"(?:\" + \"(?:\")) + n)) + r)) + t)) + \")|\")) + \"(?:\")) + o)) + t)) + \")|\")) + \"(?:\")) + p)) + r)) + s)) + t)) + \")|\")) + \"(?:\")) + r)) + s)) + t)) + u)) + \")\")) + \")\")), w = \"[/#?]\", x = \"\\\\([^\\\\s()\\u003C\\u003E]+\\\\)\", y = \"[^\\\\s()\\u003C\\u003E?#]+\", z = ((((((\"[^\\\\s\" + k)) + l)) + \"]\")), aa = ((((((((((((((((((((((((((((((((\"(?:\" + \"(?:\")) + w)) + \")\")) + \"(?:\")) + \"(?:\")) + x)) + \"|\")) + y)) + \")*\")) + \"(?:\")) + x)) + \"|\")) + z)) + \")\")) + \")*\")) + \")*\")), ba = new RegExp(((((((((((((((\"(\" + \"(?:\")) + v)) + \")\")) + \"(?:\")) + aa)) + \")\")) + \")\")), \"im\"), ca = ((((((((((((((((((((((\"(?:\" + \"(?:\")) + w)) + \")\")) + \"(?:\")) + \"(?:\")) + x)) + \"|\")) + y)) + \")*\")) + \")*\")) + \")*\")), da = new RegExp(((((((((((((((\"(\" + \"(?:\")) + v)) + \")\")) + \"(?:\")) + ca)) + \")\")) + \")\")), \"im\"), ea = new RegExp(((((((((((((((((((((((((\"(\" + \"(?:\")) + n)) + r)) + t)) + \")|\")) + \"(?:\")) + p)) + r)) + s)) + t)) + \")\")) + \")\"))), fa = /[\\s'\";]/;\n    j.match = function(ga) {\n        return j.matchToPattern(ga, ba);\n    };\n    j.permissiveMatch = function(ga) {\n        return j.matchToPattern(ga, da);\n    };\n    j.matchToPattern = function(ga, ha) {\n        var ia = ((((ha.exec(ga) || []))[1] || null));\n        if (((ia && ((ia.indexOf(\"@\") != -1))))) {\n            return (((ea.exec(ia)) ? ia : null));\n        }\n         else return ia\n    ;\n    };\n    j.trigger = function(ga) {\n        return !fa.test(ga.charAt(((ga.length - 1))));\n    };\n    e.exports = j;\n});\n__d(\"Composer\", [\"function-extensions\",\"Arbiter\",\"ArbiterMixin\",\"Button\",\"Class\",\"CSS\",\"DOM\",\"Env\",\"FileForm\",\"HTML\",\"Input\",\"PageTransitions\",\"Parent\",\"Run\",\"ServerJS\",\"TextAreaControl\",\"URI\",\"URLScraper\",\"$\",\"copyProperties\",\"ge\",\"tx\",\"event-extensions\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"Button\"), j = b(\"Class\"), k = b(\"CSS\"), l = b(\"DOM\"), m = b(\"Env\"), n = b(\"FileForm\"), o = b(\"HTML\"), p = b(\"Input\"), q = b(\"PageTransitions\"), r = b(\"Parent\"), s = b(\"Run\"), t = b(\"ServerJS\"), u = b(\"TextAreaControl\"), v = b(\"URI\"), w = b(\"URLScraper\"), x = b(\"$\"), y = b(\"copyProperties\"), z = b(\"ge\"), aa = b(\"tx\");\n    b(\"event-extensions\");\n    var ba = b(\"event-extensions\").$E, ca = 1, da = 4, ea = {\n    }, fa = function() {\n        var ja = l.scry(this.root, \"span.linkAttachment\")[0];\n        if (((!ja && this.isMetaComposer))) {\n            ja = l.scry(this.root, \"span.attachmentAcceptsLink\")[0];\n        }\n    ;\n    ;\n        if (!ja) {\n            return;\n        }\n    ;\n    ;\n        var ka = r.byTag(ja, \"form\");\n        this.scraper = new w(this.input);\n        this.scraper.subscribe(\"match\", function(la, ma) {\n            if (this.isMetaComposer) {\n                var na = this.form.xhpc_targetid, oa = new v(\"/ajax/metacomposer/attachment/link/scraper.php\");\n                oa.addQueryData({\n                    scrape_url: encodeURIComponent(ma.url),\n                    alt_scrape_url: encodeURIComponent(ma.alt_url),\n                    targetid: na.value\n                });\n                ka.action = oa.toString();\n            }\n             else {\n                k.show(ja);\n                ka.action = ((\"/ajax/composer/attachment/link/scraper.php?scrape_url=\" + encodeURIComponent(ma.url)));\n            }\n        ;\n        ;\n            ka.xhpc.value = ja.id;\n            ka.xhpc.disabled = false;\n            ka.xhpc.click();\n        }.bind(this));\n        ((this.isMetaComposer && this.scraper.check()));\n    }, ga = function(ja) {\n        if (((this.inform(\"submit\") === false))) {\n            ja.kill();\n            return false;\n        }\n    ;\n    ;\n        if (this.submitHandler) {\n            return (new Function(this.submitHandler)).apply(this.form);\n        }\n    ;\n    ;\n    };\n    function ha(ja, ka, la, ma, na) {\n        ea[ja.id] = this;\n        this.root = ja;\n        this.resetCfg = ka;\n        this.dataSource = ma;\n        this.lazyEndpoint = ((this.resetCfg && this.resetCfg.lazyEndpoint));\n        this.JSBNG__focus = l.JSBNG__find(ja, \"div.focus_target\");\n        this.form = l.JSBNG__find(ja, \"form.attachmentForm\");\n        this.JSBNG__content = l.JSBNG__find(ja, \"div.attachmentContent\");\n        this.isMetaComposer = la;\n        if (this.isMetaComposer) {\n            this.messageBox = l.JSBNG__find(ja, \"div.uiMetaComposerMessageBox\");\n            this.metaArea = l.JSBNG__find(ja, \"div.attachmentMetaArea\");\n            this.bottomArea = l.JSBNG__find(ja, \"div.attachmentBottomArea\");\n            this.barArea = l.JSBNG__find(ja, \"div.attachmentBarArea\");\n            this.auxBarArea = l.JSBNG__find(ja, \".attachmentAuxBarArea\");\n            this.blurb = l.JSBNG__find(ja, \"div.uiMetaComposerMessageBox div.textBlurb\");\n            this.input = l.JSBNG__find(ja, \"div.uiMetaComposerMessageBox textarea.input\");\n            this.button = l.JSBNG__find(ja, \"div.uiMetaComposerMessageBox label.submitBtn\");\n            this.privacy = l.JSBNG__find(ja, \"div.uiMetaComposerMessageBox li.privacyWidget\");\n            this.boosting = l.scry(ja, \"div.uiMetaComposerMessageBox li.boostingWidget\");\n        }\n         else {\n            this.blurb = l.JSBNG__find(ja, \"div.uiComposerMessageBox div.textBlurb\");\n            this.input = l.JSBNG__find(ja, \"div.uiComposerMessageBox textarea.input\");\n            this.button = l.JSBNG__find(ja, \"div.uiComposerMessageBox label.submitBtn\");\n            this.privacy = l.JSBNG__find(ja, \"div.uiComposerMessageBox li.privacyWidget\");\n            this.boosting = [];\n        }\n    ;\n    ;\n        JSBNG__Event.listen(this.form, \"submit\", ga.bind(this));\n        if (this.isMetaComposer) {\n            JSBNG__Event.listen(this.input, \"JSBNG__focus\", this.JSBNG__onFocus.bind(this));\n            if (na) {\n                if (((JSBNG__document.activeElement === this.input))) {\n                    this.JSBNG__onFocus.bind(this).defer();\n                }\n            ;\n            ;\n            }\n             else if (r.byClass(this.input, \"child_was_focused\")) {\n                this.JSBNG__onFocus.bind(this).defer();\n            }\n            \n        ;\n        ;\n        }\n    ;\n    ;\n        g.inform(((\"xhpc/construct/\" + ja.id)), this, g.BEHAVIOR_STATE);\n    };\n;\n    y(ha.prototype, h, {\n        init: function(ja) {\n            this.mentionsInput = ja;\n            if (this.mentionsInput) {\n                this.mentionsInput.subscribe(\"init\", function() {\n                    var ka = this.mentionsInput.getTypeahead().getView();\n                    ka.subscribe([\"reset\",\"render\",], function(la) {\n                        k.conditionClass(this.root, \"uiComposerMention\", ((la == \"render\")));\n                    }.bind(this));\n                }.bind(this));\n            }\n        ;\n        ;\n            fa.call(this);\n            this.inform(\"init\", null, g.BEHAVIOR_PERSISTENT);\n            this.setupListen();\n            s.JSBNG__onBeforeUnload(this._handleUnsavedChanges.bind(this));\n        },\n        setupListen: function() {\n            JSBNG__Event.listen(this.root, \"click\", this.clickHandler.bind(this));\n        },\n        clickHandler: function(JSBNG__event) {\n            var ja = JSBNG__event.getTarget();\n            if (r.byClass(ja, \"collapsedPostButton\")) {\n                this.focusInput.bind(this).defer();\n            }\n        ;\n        ;\n        },\n        setBlurb: function(ja) {\n            l.setContent(this.blurb, ja);\n        },\n        setEnabled: function(ja) {\n            i.setEnabled(this.button, ja);\n        },\n        getEndpoint: function() {\n            return this.form.getAttribute(\"action\");\n        },\n        setEndpoint: function(ja) {\n            this.form.setAttribute(\"action\", ja);\n        },\n        setLoading: function(ja) {\n            k.conditionClass(this.root, \"async_saving\", !!ja);\n        },\n        setContentVisible: function(ja) {\n            k.conditionClass(this.root, \"uiComposerHideContent\", !ja);\n        },\n        setMessageBoxVisible: function(ja) {\n            k.conditionClass(this.root, \"uiComposerHideMessageBox\", !ja);\n        },\n        setInputVisible: function(ja) {\n            k.conditionClass(this.root, \"uiComposerHideInput\", !ja);\n        },\n        setStatusBoxVisible: function(ja) {\n            k.conditionClass(this.root, \"uiComposerHideStatusBox\", !ja);\n        },\n        setTopicTaggerVisible: function(ja) {\n            k.conditionClass(this.root, \"uiTagComposerHidden\", !ja);\n        },\n        mutate: function(ja) {\n            if (this.lastComposerInput) {\n                p.setValue(this.input, p.getValue(z(this.lastComposerInput)));\n            }\n        ;\n        ;\n            var ka = z(ja.xhpc);\n            if (ka) {\n                var la = l.scry(this.root, \".uiComposerAttachmentSelected\")[0];\n                if (((ja.confirmAugmentation && ((la !== ka))))) {\n                    return;\n                }\n            ;\n            ;\n                ((la && k.removeClass(la, \"uiComposerAttachmentSelected\")));\n                k.addClass(ka, \"uiComposerAttachmentSelected\");\n                if (!ja.disableCache) {\n                    JSBNG__Event.listen(ka, \"click\", function(na) {\n                        ba(na).JSBNG__stop();\n                        ja.disableCache = true;\n                        this.mutate(ja);\n                    }.bind(this));\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            if (!ja.keepContentAreas) {\n                this.setContentVisible(false);\n                l.empty(this.JSBNG__content);\n                if (this.isMetaComposer) {\n                    ((this.mentionsInput && this.mentionsInput.setAuxContent(null)));\n                    l.empty(this.metaArea);\n                    l.empty(this.bottomArea);\n                    l.empty(this.barArea);\n                    l.empty(this.auxBarArea);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            if (ja.JSBNG__content) {\n                l.setContent(this.JSBNG__content, o(ja.JSBNG__content));\n                this.setContentVisible(true);\n            }\n        ;\n        ;\n            if (this.isMetaComposer) {\n                ((ja.metaContent && l.setContent(this.metaArea, o(ja.metaContent))));\n                ((ja.bottomContent && l.setContent(this.bottomArea, o(ja.bottomContent))));\n                ((ja.barContent && l.setContent(this.barArea, o(ja.barContent))));\n                ((ja.auxBarContent && l.setContent(this.auxBarArea, o(ja.auxBarContent))));\n            }\n        ;\n        ;\n            this.setMessageBoxVisible(!ja.messageBoxHidden);\n            k.conditionClass(this.root, \"uiComposerWhiteMessageBox\", ((((!ja.messageBoxHidden && !ja.inputHidden)) && !ja.JSBNG__content)));\n            this.setInputVisible(!ja.inputHidden);\n            this.setStatusBoxVisible(!ja.statusBoxHidden);\n            k.conditionShow(this.privacy, !ja.privacyWidgetHidden);\n            if (((this.boosting.length > 0))) {\n                k.conditionShow(this.boosting[0], !ja.boostingWidgetHidden);\n            }\n        ;\n        ;\n            if (!ja.keepContentAreas) {\n                p.setPlaceholder(this.input, ja.placeholder);\n                i.setLabel(this.button, ja.buttonLabel);\n            }\n        ;\n        ;\n            this.setBlurb(o(ja.blurb));\n            if (ja.autoscrape) {\n                ((this.scraper && this.scraper.enable()));\n            }\n             else ((this.scraper && this.scraper.disable()));\n        ;\n        ;\n            this.setEnabled(!ja.disabled);\n            this.setTopicTaggerVisible(!ja.hideTopicTagger);\n            this.setEndpoint(ja.endpoint);\n            if (((ja.formType == ca))) {\n                this.form.setAttribute(\"rel\", \"async\");\n            }\n             else this.form.removeAttribute(\"rel\");\n        ;\n        ;\n            this.form.removeAttribute(\"target\");\n            if (((ja.formType == da))) {\n                if (!this._fileForm) {\n                    this._fileForm = new n(this.form);\n                    this._fileForm.setAllowCrossOrigin(m.allowCrossOriginComposerUpload);\n                    this._fileForm.subscribe(\"submit\", this.setLoading.bind(this, true));\n                    this._fileForm.subscribe(\"failure\", this.setLoading.bind(this, false));\n                }\n            ;\n            ;\n            }\n             else if (this._fileForm) {\n                this._fileForm.destroy();\n                this._fileForm = null;\n            }\n            \n        ;\n        ;\n            this.submitHandler = ja.submitHandler;\n            this.lazyEndpoint = ja.lazyEndpoint;\n            k.addClass(this.root, \"uiComposerInteracted\");\n            k.addClass(this.root, \"uiComposerOpen\");\n            if (ja.messageBoxFocused) {\n                var ma = JSBNG__document.activeElement;\n                if (((((ma === JSBNG__document.body)) || r.byClass(ma, \"attachmentLink\")))) {\n                    this.focusInput.bind(this).defer();\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            if (ja.inputElement) {\n                p.setValue(z(ja.inputElement), p.getValue(this.input));\n                u.getInstance(z(ja.inputElement)).update();\n            }\n             else u.getInstance(this.input).update();\n        ;\n        ;\n            this.lastComposerInput = ja.inputElement;\n            g.inform(\"composer/mutate\", this);\n        },\n        subscribeToMutate: function(ja) {\n            return g.subscribe(\"composer/mutate\", function(ka, la) {\n                if (((la === this))) {\n                    ja();\n                }\n            ;\n            ;\n            }.bind(this));\n        },\n        unsubscribeFromMutate: function(ja) {\n            ja.unsubscribe();\n        },\n        reset: function(ja) {\n            if (this.isMetaComposer) {\n                l.empty(this.metaArea);\n                l.empty(this.bottomArea);\n                l.empty(this.barArea);\n                l.empty(this.auxBarArea);\n            }\n        ;\n        ;\n            if (this.resetCfg) {\n                this.mutate(this.resetCfg);\n            }\n             else {\n                var ka = l.scry(this.root, \".uiComposerAttachmentSelected\")[0];\n                if (ka) {\n                    k.removeClass(ka, \"uiComposerAttachmentSelected\");\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            if (!ja) {\n                p.reset(this.input);\n                ((this.mentionsInput && this.mentionsInput.reset()));\n                ((this.scraper && this.scraper.reset()));\n            }\n        ;\n        ;\n            k.removeClass(this.root, \"uiComposerInteracted\");\n            k.setClass(this.JSBNG__focus, \"focus_target\");\n            this.setLoading(false);\n            g.inform(\"composer/reset\");\n        },\n        JSBNG__onFocus: function() {\n            if (this.lazyEndpoint) {\n                var ja = l.JSBNG__find(this.root, \"form.attachmentSelectForm\"), ka = new v(this.lazyEndpoint);\n                ka.addQueryData({\n                    isAugmentation: true\n                });\n                ja.action = ka.toString();\n                var la = l.scry(this.root, \".uiComposerAttachmentSelected\")[0];\n                ja.xhpc.value = ((la && la.id));\n                ja.xhpc.click();\n                k.removeClass.curry(this.root, \"async_saving\").defer();\n            }\n        ;\n        ;\n            this.inform(\"JSBNG__focus\");\n        },\n        focusInput: function() {\n            p.JSBNG__focus(this.input);\n        },\n        getInput: function() {\n            return this.input;\n        },\n        updateDataSourceToken: function(ja) {\n            if (this.dataSource) {\n                this.dataSource.updateToken(ja);\n            }\n        ;\n        ;\n        },\n        _handleUnsavedChanges: function() {\n            var ja = q.getNextURI();\n            if (ja.getQueryData().hasOwnProperty(\"theater\")) {\n                return;\n            }\n        ;\n        ;\n            if (((((((this.input.offsetParent !== null)) && !p.isEmpty(this.input))) && !((a.Dialog && a.Dialog.getCurrent()))))) {\n                return \"You haven't finished your post yet. Do you want to leave without finishing?\";\n            }\n        ;\n        ;\n        }\n    });\n    var ia;\n    y(ha, {\n        setNodeToConfigure: function(ja) {\n            ia = ja;\n        },\n        configure: function(ja, ka, la) {\n            var ma = r.byClass(ia, \"uiComposer\").id, na = g.subscribe(((\"xhpc/construct/\" + ma)), function(oa, pa) {\n                (function() {\n                    na.unsubscribe();\n                }).defer();\n                pa.mutate(ja);\n                pa.subscribe(\"init\", function() {\n                    new t().handle(ka);\n                    new Function(la)();\n                    if (ja.attachmentJS) {\n                        new Function(ja.attachmentJS).call(pa);\n                    }\n                ;\n                ;\n                });\n            });\n        },\n        publish: function(ja, ka) {\n            ka = ((ka || {\n            }));\n            ka.composer_id = ja;\n            ka.composer = ha.getInstance(ja);\n            ((ka.composer && ka.composer.reset(false)));\n            if (ka.streamNode) {\n                ka.streamStory = ka.streamNode;\n            }\n             else if (ka.streamMarkup) {\n                ka.streamStory = o(ka.streamMarkup).getRootNode();\n            }\n            \n        ;\n        ;\n            g.inform(\"composer/publish\", ka);\n        },\n        finish: function(ja) {\n            ha.getInstance(ja).setLoading(false);\n        },\n        getInstance: function(ja) {\n            var ka = r.byClass(x(ja), \"uiComposer\");\n            return ((ka ? ea[ka.id] : null));\n        }\n    });\n    e.exports = ha;\n});\n__d(\"legacy:Composer\", [\"Composer\",], function(a, b, c, d) {\n    a.Composer = b(\"Composer\");\n}, 3);\nfunction MetaComposerMessageBox() {\n\n};\n;\ncopyProperties(MetaComposerMessageBox.prototype, {\n    init: function(a, b) {\n        this.inputContainer = DOM.scry(a, \"div.inputContainer\")[0];\n        this.textInput = DOM.scry(a, \"textarea.mentionsTextarea\")[0];\n        this.metaArea = DOM.scry(a, \"div.attachmentMetaArea\")[0];\n        this.bottomArea = DOM.scry(a, \"div.attachmentBottomArea\")[0];\n        this.barArea = DOM.scry(a, \"div.attachmentBarArea\")[0];\n        JSBNG__Event.listen(this.inputContainer, \"click\", function(c) {\n            var d = c.getTarget();\n            if (((!DOM.contains(this.metaArea, d) && ((d !== this.textInput))))) {\n                this.textInput.JSBNG__focus();\n            }\n        ;\n        ;\n        }.bind(this));\n    }\n});\n__d(\"FBDesktopDetect\", [\"UserAgent\",], function(a, b, c, d, e, f) {\n    var g = b(\"UserAgent\"), h = \"facebook.desktopplugin\", i = {\n        mimeType: \"application/x-facebook-desktop-1\",\n        isPluginInstalled: function() {\n            if (g.osx()) {\n                return false;\n            }\n        ;\n        ;\n            var j = null;\n            if (a.ActiveXObject) {\n                try {\n                    j = new a.ActiveXObject(h);\n                    if (j) {\n                        return true;\n                    }\n                ;\n                ;\n                } catch (k) {\n                \n                };\n            ;\n            }\n             else if (((a.JSBNG__navigator && a.JSBNG__navigator.plugins))) {\n                a.JSBNG__navigator.plugins.refresh(false);\n                for (var l = 0, m = a.JSBNG__navigator.plugins.length; ((l < m)); l++) {\n                    j = a.JSBNG__navigator.plugins[l];\n                    if (((j.length && ((j[0].type === this.mimeType))))) {\n                        return true;\n                    }\n                ;\n                ;\n                };\n            ;\n            }\n            \n        ;\n        ;\n            return false;\n        }\n    };\n    e.exports = i;\n});\n__d(\"CacheStorage\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\"), h = {\n        localstorage: i\n    };\n    function i() {\n        this._store = a.JSBNG__localStorage;\n    };\n;\n    i.available = function() {\n        return !!a.JSBNG__localStorage;\n    };\n    g(i.prototype, {\n        keys: function() {\n            var k = [];\n            for (var l = 0; ((l < this._store.length)); l++) {\n                k.push(this._store.key(l));\n            ;\n            };\n        ;\n            return k;\n        },\n        get: function(k) {\n            return this._store.getItem(k);\n        },\n        set: function(k, l) {\n            this._store.setItem(k, l);\n        },\n        remove: function(k) {\n            this._store.removeItem(k);\n        },\n        clear: function() {\n            this._store.clear();\n        }\n    });\n    function j(k, l) {\n        this._key_prefix = ((l || \"_cs_\"));\n        this._magic_prefix = \"_@_\";\n        if (((k == \"AUTO\"))) {\n            for (var m in h) {\n                var n = h[m];\n                if (n.available()) {\n                    k = m;\n                    break;\n                }\n            ;\n            ;\n            };\n        }\n    ;\n    ;\n        if (k) {\n            if (((!h[k] || !h[k].available()))) {\n                this._backend = null;\n            }\n             else this._backend = new h[k]();\n        ;\n        }\n    ;\n    ;\n        this._memcache = {\n        };\n    };\n;\n    g(j.prototype, {\n        keys: function() {\n            var k = [];\n            if (this._backend) {\n                var l = this._backend.keys();\n                for (var m = 0; ((m < l.length)); m++) {\n                    if (((l[m].substr(0, this._key_prefix.length) == this._key_prefix))) {\n                        k.push(l[m].substr(this._key_prefix.length));\n                    }\n                ;\n                ;\n                };\n            ;\n                return k;\n            }\n        ;\n        ;\n            for (var n in this._memcache) {\n                k.push(n);\n            ;\n            };\n        ;\n            return k;\n        },\n        set: function(k, l) {\n            this._memcache[k] = l;\n            if (this._backend) {\n                if (((typeof l == \"string\"))) {\n                    l = ((this._magic_prefix + l));\n                }\n                 else l = JSON.stringify(l);\n            ;\n            ;\n                this._backend.set(((this._key_prefix + k)), l);\n            }\n        ;\n        ;\n        },\n        get: function(k, l) {\n            if (((this._memcache[k] !== undefined))) {\n                return this._memcache[k];\n            }\n        ;\n        ;\n            var m;\n            if (this._backend) {\n                m = this._backend.get(((this._key_prefix + k)));\n                if (((m !== null))) {\n                    if (((m.substr(0, this._magic_prefix.length) == this._magic_prefix))) {\n                        m = m.substr(this._magic_prefix.length);\n                    }\n                     else try {\n                        m = JSON.parse(m);\n                    } catch (n) {\n                        m = undefined;\n                    }\n                ;\n                ;\n                    if (((m !== undefined))) {\n                        this._memcache[k] = m;\n                    }\n                ;\n                ;\n                }\n                 else m = undefined;\n            ;\n            ;\n            }\n        ;\n        ;\n            if (((((m === undefined)) && ((l !== undefined))))) {\n                m = l;\n                this._memcache[k] = m;\n                if (this._backend) {\n                    var o;\n                    if (((typeof m == \"string\"))) {\n                        o = ((this._magic_prefix + m));\n                    }\n                     else o = JSON.stringify(m);\n                ;\n                ;\n                    this._backend.set(((this._key_prefix + k)), o);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            return m;\n        },\n        remove: function(k) {\n            delete this._memcache[k];\n            if (this._backend) {\n                this._backend.remove(((this._key_prefix + k)));\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = j;\n});\n__d(\"FBDesktopPlugin\", [\"CacheStorage\",\"DOM\",\"Env\",\"FBDesktopDetect\",\"HTML\",\"URI\",\"$\",], function(a, b, c, d, e, f) {\n    var g = b(\"CacheStorage\"), h = b(\"DOM\"), i = b(\"Env\"), j = b(\"FBDesktopDetect\"), k = b(\"HTML\"), l = b(\"URI\"), m = b(\"$\"), n = new g(\"localstorage\", \"_socialfox_\"), o = {\n        _plugin: \"_not_checked\",\n        arbiterInform: function(p, q) {\n            var r = JSON.stringify({\n                JSBNG__name: p,\n                payload: q\n            });\n            this._transmitCommand(\"arbiterinform\", r);\n        },\n        bringToFront: function() {\n            this._transmitCommand(\"bringtofront\");\n        },\n        dock: function() {\n            this._transmitCommand(\"dock\");\n        },\n        getPlugin: function() {\n            if (((this._plugin === \"_not_checked\"))) {\n                this._plugin = null;\n                if (j.isPluginInstalled()) {\n                    var p = h.create(\"div\");\n                    JSBNG__document.body.appendChild(p);\n                    h.setContent(p, k(((((((((\"\\u003Cobject id=\\\"kiwi_plugin\\\" \" + \"type=\\\"\")) + j.mimeType)) + \"\\\" width=\\\"0\\\" height=\\\"0\\\"\\u003E\")) + \"\\u003C/object\\u003E\"))));\n                    this._plugin = m(\"kiwi_plugin\");\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            return this._plugin;\n        },\n        getUserID: function() {\n            var p = this.getPlugin();\n            return ((((p && ((\"getUserID\" in p)))) && p.getUserID()));\n        },\n        isAppRunning: function() {\n            var p = this.getPlugin();\n            return ((((p && ((\"isAppRunning\" in p)))) && p.isAppRunning()));\n        },\n        launchApp: function() {\n            var p = this.getPlugin();\n            return ((((p && ((\"launchApp\" in p)))) && p.launchApp()));\n        },\n        logout: function(p) {\n            p = ((p || \"0\"));\n            var q = this.getPlugin();\n            if (q) {\n                q.logout(p);\n            }\n        ;\n        ;\n        },\n        recheck: function() {\n            if (((this._plugin === null))) {\n                this._plugin = \"_not_checked\";\n            }\n        ;\n        ;\n        },\n        shouldSuppressBeeper: function() {\n            return this.isAppRunning();\n        },\n        shouldSuppressMessages: function() {\n            var p = this.getUserID();\n            if (p) {\n                return ((p === i.user));\n            }\n             else return this.isAppRunning()\n        ;\n        },\n        shouldSuppressSidebar: function() {\n            var p = this.getPlugin(), q = ((((p && ((\"isAppDocked\" in p)))) && p.isAppDocked())), r = ((n && ((n.get(\"active\") === \"true\"))));\n            return ((q || r));\n        },\n        transferAuthToken: function(p, q) {\n            if (((p && ((p.length > 0))))) {\n                var r = this.getPlugin();\n                if (r) {\n                    r.setAccessToken(p, q);\n                    var s = JSBNG__setInterval(function() {\n                        r.setAccessToken(p, q);\n                    }, 500);\n                    JSBNG__setTimeout(function() {\n                        JSBNG__clearInterval(s);\n                    }, ((10 * 1000)));\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            if (this.redirectHome) {\n                window.JSBNG__location.href = l().setPath().toString();\n            }\n        ;\n        ;\n        },\n        _transmitCommand: function(p, q) {\n            q = ((q || \"\"));\n            var r = this.getPlugin();\n            if (((r && ((\"transmitCommand\" in r))))) {\n                r.transmitCommand(p, q);\n            }\n        ;\n        ;\n        }\n    };\n    e.exports = o;\n});\n__d(\"ARIA\", [\"DOM\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"ge\"), i, j, k = function() {\n        i = h(\"ariaAssertiveAlert\");\n        if (!i) {\n            i = g.create(\"div\", {\n                id: \"ariaAssertiveAlert\",\n                className: \"accessible_elem\",\n                role: \"JSBNG__alert\",\n                \"aria-live\": \"assertive\"\n            });\n            g.appendContent(JSBNG__document.body, i);\n        }\n    ;\n    ;\n        j = h(\"ariaPoliteAlert\");\n        if (!j) {\n            j = i.cloneNode(false);\n            j.setAttribute(\"id\", \"ariaPoliteAlert\");\n            j.setAttribute(\"aria-live\", \"polite\");\n            g.appendContent(JSBNG__document.body, j);\n        }\n    ;\n    ;\n        k = bagofholding;\n    };\n    function l(n, o) {\n        k();\n        var p = ((o ? i : j));\n        g.setContent(p, n);\n    };\n;\n    var m = {\n        owns: function(n, o) {\n            n.setAttribute(\"aria-owns\", g.getID(o));\n        },\n        setPopup: function(n, o) {\n            var p = g.getID(o);\n            n.setAttribute(\"aria-owns\", p);\n            n.setAttribute(\"aria-controls\", p);\n            n.setAttribute(\"aria-haspopup\", \"true\");\n            if (((n.tabIndex == -1))) {\n                n.tabIndex = 0;\n            }\n        ;\n        ;\n        },\n        announce: function(n) {\n            l(n, true);\n        },\n        notify: function(n) {\n            l(n);\n        }\n    };\n    e.exports = m;\n});\n__d(\"ContextualDialogFooterLink\", [\"event-extensions\",\"copyProperties\",\"CSS\",\"DOM\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"copyProperties\"), h = b(\"CSS\"), i = b(\"DOM\");\n    function j(k) {\n        this._layer = k;\n    };\n;\n    g(j.prototype, {\n        _subscriptions: null,\n        enable: function() {\n            var k = this._layer.getRoot(), l = i.scry(k, \".uiContextualDialogFooterLink\")[0], m = \"uiContextualDialogHoverFooterArrow\";\n            this._subscriptions = [JSBNG__Event.listen(l, \"mouseenter\", h.addClass.curry(k, m)),JSBNG__Event.listen(l, \"mouseleave\", h.removeClass.curry(k, m)),];\n        },\n        disable: function() {\n            this._subscriptions.forEach(function(k) {\n                k.remove();\n            });\n            this._subscriptions = null;\n        }\n    });\n    e.exports = j;\n});\n__d(\"ContextualThing\", [\"DOM\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"ge\");\n    function i(k) {\n        var l;\n        while (k) {\n            if (((k.getAttribute && (l = k.getAttribute(\"data-ownerid\"))))) {\n                return h(l);\n            }\n        ;\n        ;\n            k = k.parentNode;\n        };\n    ;\n        return null;\n    };\n;\n    var j = {\n        register: function(k, l) {\n            k.setAttribute(\"data-ownerid\", g.getID(l));\n        },\n        remove: function(k) {\n            k.removeAttribute(\"data-ownerid\");\n        },\n        containsIncludingLayers: function(k, l) {\n            while (l) {\n                if (g.contains(k, l)) {\n                    return true;\n                }\n            ;\n            ;\n                l = i(l);\n            };\n        ;\n            return false;\n        }\n    };\n    e.exports = j;\n});\n__d(\"BootloadedReact\", [\"Bootloader\",], function(a, b, c, d, e, f) {\n    var g = b(\"Bootloader\"), h = function(j) {\n        g.loadModules([\"React\",], j);\n    }, i = {\n        isValidComponent: function(j) {\n            return ((((j && ((typeof j.genMarkup === \"function\")))) && ((typeof j.handleUpdateProps === \"function\"))));\n        },\n        initializeTouchEvents: function(j, k) {\n            h(function(l) {\n                l.initializeTouchEvents(j);\n                ((k && k()));\n            });\n        },\n        createComponent: function(j, k) {\n            h(function(l) {\n                var m = l.createComponent(j);\n                ((k && k(m)));\n            });\n        },\n        renderComponent: function(j, k, l) {\n            h(function(m) {\n                var n = m.renderComponent(j, k);\n                ((l && l(n)));\n            });\n        },\n        renderOrUpdateComponent: function(j, k, l) {\n            h(function(m) {\n                var n = m.renderOrUpdateComponent(j, k);\n                ((l && l(n)));\n            });\n        },\n        destroyAndReleaseReactRootNode: function(j, k) {\n            h(function(l) {\n                l.destroyAndReleaseReactRootNode(j);\n                ((k && k()));\n            });\n        }\n    };\n    e.exports = i;\n});\n__d(\"KeyEventController\", [\"event-extensions\",\"DOM\",\"Run\",\"copyProperties\",\"isEmpty\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"DOM\"), h = b(\"Run\"), i = b(\"event-extensions\").$E, j = b(\"copyProperties\"), k = b(\"isEmpty\");\n    function l() {\n        this.handlers = {\n        };\n        JSBNG__document.JSBNG__onkeyup = this.JSBNG__onkeyevent.bind(this, \"JSBNG__onkeyup\");\n        JSBNG__document.JSBNG__onkeydown = this.JSBNG__onkeyevent.bind(this, \"JSBNG__onkeydown\");\n        JSBNG__document.JSBNG__onkeypress = this.JSBNG__onkeyevent.bind(this, \"JSBNG__onkeypress\");\n    };\n;\n    j(l, {\n        instance: null,\n        getInstance: function() {\n            return ((l.instance || (l.instance = new l())));\n        },\n        defaultFilter: function(JSBNG__event, m) {\n            JSBNG__event = i(JSBNG__event);\n            return ((((l.filterEventTypes(JSBNG__event, m) && l.filterEventTargets(JSBNG__event, m))) && l.filterEventModifiers(JSBNG__event, m)));\n        },\n        filterEventTypes: function(JSBNG__event, m) {\n            if (((m === \"JSBNG__onkeydown\"))) {\n                return true;\n            }\n        ;\n        ;\n            return false;\n        },\n        filterEventTargets: function(JSBNG__event, m) {\n            var n = JSBNG__event.getTarget();\n            if (((n.contentEditable === \"true\"))) {\n                return false;\n            }\n        ;\n        ;\n            return ((((!g.isNodeOfType(n, l._interactiveElements) || ((n.type in l._uninterestingTypes)))) || ((((g.isNodeOfType(n, [\"input\",\"textarea\",]) && ((n.value.length === 0)))) && ((JSBNG__event.keyCode in l._controlKeys))))));\n        },\n        filterEventModifiers: function(JSBNG__event, m) {\n            if (((((((JSBNG__event.ctrlKey || JSBNG__event.altKey)) || JSBNG__event.metaKey)) || JSBNG__event.repeat))) {\n                return false;\n            }\n        ;\n        ;\n            return true;\n        },\n        registerKey: function(m, n, o, p) {\n            if (((o === undefined))) {\n                o = l.defaultFilter;\n            }\n        ;\n        ;\n            var q = l.getInstance(), r = q.mapKey(m);\n            if (k(q.handlers)) {\n                h.JSBNG__onLeave(q.resetHandlers.bind(q));\n            }\n        ;\n        ;\n            var s = {\n            };\n            for (var t = 0; ((t < r.length)); t++) {\n                m = r[t];\n                if (((!q.handlers[m] || p))) {\n                    q.handlers[m] = [];\n                }\n            ;\n            ;\n                var u = {\n                    callback: n,\n                    filter: o\n                };\n                s[m] = u;\n                q.handlers[m].push(u);\n            };\n        ;\n            return {\n                remove: function() {\n                    for (var v in s) {\n                        if (((q.handlers[v] && q.handlers[v].length))) {\n                            var w = q.handlers[v].indexOf(s[v]);\n                            ((((w >= 0)) && q.handlers[v].splice(w, 1)));\n                        }\n                    ;\n                    ;\n                        delete s[v];\n                    };\n                ;\n                }\n            };\n        },\n        keyCodeMap: {\n            BACKSPACE: [8,],\n            TAB: [9,],\n            RETURN: [13,],\n            ESCAPE: [27,],\n            LEFT: [37,63234,],\n            UP: [38,63232,],\n            RIGHT: [39,63235,],\n            DOWN: [40,63233,],\n            DELETE: [46,],\n            COMMA: [188,],\n            PERIOD: [190,],\n            \"`\": [192,],\n            \"[\": [219,],\n            \"]\": [221,]\n        },\n        _interactiveElements: [\"input\",\"select\",\"textarea\",\"object\",\"embed\",],\n        _uninterestingTypes: {\n            checkbox: 1,\n            radio: 1,\n            submit: 1\n        },\n        _controlKeys: {\n            8: 1,\n            9: 1,\n            13: 1,\n            27: 1,\n            37: 1,\n            63234: 1,\n            38: 1,\n            63232: 1,\n            39: 1,\n            63235: 1,\n            40: 1,\n            63233: 1,\n            46: 1\n        }\n    });\n    j(l.prototype, {\n        mapKey: function(m) {\n            if (((((m >= 0)) && ((m <= 9))))) {\n                if (((typeof (m) != \"number\"))) {\n                    m = ((m.charCodeAt(0) - 48));\n                }\n            ;\n            ;\n                return [((48 + m)),((96 + m)),];\n            }\n        ;\n        ;\n            var n = l.keyCodeMap[m.toUpperCase()];\n            if (n) {\n                return n;\n            }\n        ;\n        ;\n            return [m.toUpperCase().charCodeAt(0),];\n        },\n        JSBNG__onkeyevent: function(m, n) {\n            n = i(n);\n            var o = ((this.handlers[n.keyCode] || this.handlers[n.which])), p, q, r;\n            if (o) {\n                for (var s = 0; ((s < o.length)); s++) {\n                    p = o[s].callback;\n                    q = o[s].filter;\n                    try {\n                        if (((!q || q(n, m)))) {\n                            r = p(n, m);\n                            if (((r === false))) {\n                                return JSBNG__Event.kill(n);\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                    } catch (t) {\n                    \n                    };\n                ;\n                };\n            }\n        ;\n        ;\n            return true;\n        },\n        resetHandlers: function() {\n            this.handlers = {\n            };\n        }\n    });\n    e.exports = l;\n});\n__d(\"Layer\", [\"event-extensions\",\"ArbiterMixin\",\"BehaviorsMixin\",\"BootloadedReact\",\"Class\",\"ContextualThing\",\"CSS\",\"DataStore\",\"DOM\",\"HTML\",\"KeyEventController\",\"Style\",\"$\",\"copyProperties\",\"ge\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"BehaviorsMixin\"), i = b(\"BootloadedReact\"), j = b(\"Class\"), k = b(\"ContextualThing\"), l = b(\"CSS\"), m = b(\"DataStore\"), n = b(\"DOM\"), o = b(\"HTML\"), p = b(\"KeyEventController\"), q = b(\"Style\"), r = b(\"$\"), s = b(\"copyProperties\"), t = b(\"ge\"), u = [];\n    function v(w, x) {\n        this._config = ((w || {\n        }));\n        if (x) {\n            this._configure(this._config, x);\n            var y = ((this._config.addedBehaviors || []));\n            this.enableBehaviors(this._getDefaultBehaviors().concat(y));\n        }\n    ;\n    ;\n    };\n;\n    s(v, g);\n    s(v, {\n        init: function(w, x) {\n            w.init(x);\n        },\n        initAndShow: function(w, x) {\n            w.init(x).show();\n        },\n        show: function(w) {\n            w.show();\n        }\n    });\n    s(v.prototype, g, h, {\n        _initialized: false,\n        _root: null,\n        _shown: false,\n        _hiding: false,\n        _causalElement: null,\n        _reactContainer: null,\n        init: function(w) {\n            this._configure(this._config, w);\n            var x = ((this._config.addedBehaviors || []));\n            this.enableBehaviors(this._getDefaultBehaviors().concat(x));\n            this._initialized = true;\n            return this;\n        },\n        _configure: function(w, x) {\n            if (x) {\n                var y = n.isNode(x), z = ((((typeof x === \"string\")) || o.isHTML(x)));\n                this.containsReactComponent = i.isValidComponent(x);\n                if (z) {\n                    x = o(x).getRootNode();\n                }\n                 else if (this.containsReactComponent) {\n                    var aa = JSBNG__document.createElement(\"div\");\n                    i.renderComponent(x, aa);\n                    x = this._reactContainer = aa;\n                }\n                \n            ;\n            ;\n            }\n        ;\n        ;\n            this._root = this._buildWrapper(w, x);\n            l.addClass(this._root, \"uiLayer\");\n            if (w.causalElement) {\n                this._causalElement = t(w.causalElement);\n            }\n        ;\n        ;\n            m.set(this._root, \"layer\", this);\n        },\n        _getDefaultBehaviors: function() {\n            return [];\n        },\n        getCausalElement: function() {\n            return this._causalElement;\n        },\n        setCausalElement: function(w) {\n            this._causalElement = w;\n        },\n        getInsertParent: function() {\n            return ((this._insertParent || JSBNG__document.body));\n        },\n        getRoot: function() {\n            return this._root;\n        },\n        _getContentRoot: function() {\n            return this._root;\n        },\n        _buildWrapper: function(w, x) {\n            return x;\n        },\n        setInsertParent: function(w) {\n            if (w) {\n                if (((this._shown && ((w !== this.getInsertParent()))))) {\n                    n.appendContent(w, this.getRoot());\n                    this.updatePosition();\n                }\n            ;\n            ;\n                this._insertParent = w;\n            }\n        ;\n        ;\n            return this;\n        },\n        show: function() {\n            if (this._shown) {\n                return this;\n            }\n        ;\n        ;\n            var w = this.getRoot();\n            this.inform(\"beforeshow\");\n            q.set(w, \"visibility\", \"hidden\");\n            q.set(w, \"overflow\", \"hidden\");\n            l.show(w);\n            n.appendContent(this.getInsertParent(), w);\n            if (((this.updatePosition() !== false))) {\n                u.push(this);\n                this._shown = true;\n                this.inform(\"show\");\n                v.inform(\"show\", this);\n            }\n             else n.remove(w);\n        ;\n        ;\n            q.set(w, \"visibility\", \"\");\n            q.set(w, \"overflow\", \"\");\n            this.inform(\"aftershow\");\n            return this;\n        },\n        hide: function() {\n            if (((((this._hiding || !this._shown)) || ((this.inform(\"beforehide\") === false))))) {\n                return this;\n            }\n        ;\n        ;\n            this._hiding = true;\n            if (((this.inform(\"starthide\") !== false))) {\n                this.finishHide();\n            }\n        ;\n        ;\n            return this;\n        },\n        finishHide: function() {\n            if (this._shown) {\n                u.remove(this);\n                this._hiding = false;\n                this._shown = false;\n                n.remove(this.getRoot());\n                this.inform(\"hide\");\n                v.inform(\"hide\", this);\n            }\n        ;\n        ;\n        },\n        isShown: function() {\n            return this._shown;\n        },\n        updatePosition: function() {\n            return true;\n        },\n        destroy: function() {\n            if (this.containsReactComponent) {\n                i.destroyAndReleaseReactRootNode(this._reactContainer);\n            }\n        ;\n        ;\n            this.finishHide();\n            this.destroyBehaviors();\n            this.inform(\"destroy\");\n            v.inform(\"destroy\", this);\n            m.remove(this._root, \"layer\");\n            this._root = this._causalElement = null;\n        }\n    });\n    JSBNG__Event.listen(JSBNG__document.documentElement, \"keydown\", function(JSBNG__event) {\n        if (p.filterEventTargets(JSBNG__event, \"keydown\")) {\n            for (var w = ((u.length - 1)); ((w >= 0)); w--) {\n                if (((u[w].inform(\"key\", JSBNG__event) === false))) {\n                    return false;\n                }\n            ;\n            ;\n            };\n        }\n    ;\n    ;\n    }, JSBNG__Event.Priority.URGENT);\n    JSBNG__Event.listen(JSBNG__document.documentElement, \"click\", function(JSBNG__event) {\n        var w = JSBNG__event.getTarget(), x, y;\n        for (var z = ((u.length - 1)); ((z >= 0)); z--) {\n            x = u[z];\n            y = x._getContentRoot();\n            if (k.containsIncludingLayers(y, w)) {\n                return;\n            }\n        ;\n        ;\n            if (((x.inform(\"JSBNG__blur\", JSBNG__event) === false))) {\n                return;\n            }\n        ;\n        ;\n        };\n    ;\n    });\n    e.exports = v;\n});\n__d(\"LayerAutoFocus\", [\"function-extensions\",\"copyProperties\",\"DOMQuery\",\"Input\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"copyProperties\"), h = b(\"DOMQuery\"), i = b(\"Input\");\n    function j(k) {\n        this._layer = k;\n    };\n;\n    g(j.prototype, {\n        _subscription: null,\n        enable: function() {\n            this._subscription = this._layer.subscribe(\"aftershow\", this._focus.bind(this));\n        },\n        disable: function() {\n            this._subscription.unsubscribe();\n            this._subscription = null;\n        },\n        _focus: function() {\n            var k = h.scry(this._layer.getRoot(), \".autofocus\")[0];\n            ((k && i.JSBNG__focus(k)));\n        }\n    });\n    e.exports = j;\n});\n__d(\"LayerButtons\", [\"event-extensions\",\"Parent\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Parent\"), h = b(\"copyProperties\");\n    function i(j) {\n        this._layer = j;\n    };\n;\n    h(i.prototype, {\n        _listener: null,\n        enable: function() {\n            this._listener = JSBNG__Event.listen(this._layer.getRoot(), \"click\", this._handle.bind(this));\n        },\n        disable: function() {\n            this._listener.remove();\n            this._listener = null;\n        },\n        _handle: function(j) {\n            var k = j.getTarget(), l = g.byClass(k, \"layerConfirm\");\n            if (l) {\n                if (((this._layer.inform(\"JSBNG__confirm\", l) === false))) {\n                    j.prevent();\n                }\n            ;\n            ;\n                return;\n            }\n        ;\n        ;\n            var m = g.byClass(k, \"layerCancel\");\n            if (m) {\n                if (((this._layer.inform(\"cancel\", m) !== false))) {\n                    this._layer.hide();\n                }\n            ;\n            ;\n                j.prevent();\n                return;\n            }\n        ;\n        ;\n            var n = g.byClass(k, \"layerButton\");\n            if (n) {\n                if (((this._layer.inform(\"button\", n) === false))) {\n                    j.prevent();\n                }\n            ;\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = i;\n});\n__d(\"LayerDestroyOnHide\", [\"function-extensions\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"copyProperties\");\n    function h(i) {\n        this._layer = i;\n    };\n;\n    g(h.prototype, {\n        _subscription: null,\n        enable: function() {\n            this._subscription = this._layer.subscribe(\"hide\", Function.prototype.defer.shield(this._layer.destroy.bind(this._layer)));\n        },\n        disable: function() {\n            if (this._subscription) {\n                this._subscription.unsubscribe();\n                this._subscription = null;\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = h;\n});\n__d(\"LayerFadeOnHide\", [\"Animation\",\"Layer\",\"Style\",\"UserAgent\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Animation\"), h = b(\"Layer\"), i = b(\"Style\"), j = b(\"UserAgent\"), k = b(\"copyProperties\");\n    function l(m) {\n        this._layer = m;\n    };\n;\n    k(l.prototype, {\n        _subscription: null,\n        enable: function() {\n            if (((j.ie() < 9))) {\n                return;\n            }\n        ;\n        ;\n            this._subscription = this._layer.subscribe(\"starthide\", this._handleStartHide.bind(this));\n        },\n        disable: function() {\n            if (this._subscription) {\n                this._subscription.unsubscribe();\n                this._subscription = null;\n            }\n        ;\n        ;\n        },\n        _handleStartHide: function() {\n            var m = true, n = h.subscribe(\"show\", function() {\n                n.unsubscribe();\n                m = false;\n            });\n            (function() {\n                n.unsubscribe();\n                n = null;\n                if (m) {\n                    this._animate();\n                }\n                 else this._layer.finishHide();\n            ;\n            ;\n            }).bind(this).defer();\n            return false;\n        },\n        _animate: function() {\n            new g(this._layer.getRoot()).from(\"opacity\", 1).to(\"opacity\", 0).duration(150).JSBNG__ondone(this._finish.bind(this)).go();\n        },\n        _finish: function() {\n            i.set(this._layer.getRoot(), \"opacity\", \"\");\n            this._layer.finishHide();\n        }\n    });\n    e.exports = l;\n});\n__d(\"LayerFadeOnShow\", [\"Animation\",\"Style\",\"UserAgent\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Animation\"), h = b(\"Style\"), i = b(\"UserAgent\"), j = b(\"copyProperties\");\n    function k(l) {\n        this._layer = l;\n    };\n;\n    j(k.prototype, {\n        _subscriptions: null,\n        enable: function() {\n            if (((i.ie() < 9))) {\n                return;\n            }\n        ;\n        ;\n            this._subscriptions = [this._layer.subscribe(\"beforeshow\", function() {\n                h.set(this._layer.getRoot(), \"opacity\", 0);\n            }.bind(this)),this._layer.subscribe(\"show\", this._animate.bind(this)),];\n        },\n        disable: function() {\n            if (this._subscriptions) {\n                while (this._subscriptions.length) {\n                    this._subscriptions.pop().unsubscribe();\n                ;\n                };\n            ;\n                this._subscriptions = null;\n            }\n        ;\n        ;\n        },\n        _animate: function() {\n            var l = this._layer.getRoot();\n            new g(l).from(\"opacity\", 0).to(\"opacity\", 1).duration(100).JSBNG__ondone(h.set.curry(l, \"opacity\", \"\")).go();\n        }\n    });\n    e.exports = k;\n});\n__d(\"LayerFormHooks\", [\"event-extensions\",\"Form\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Form\"), h = b(\"copyProperties\");\n    function i(j) {\n        this._layer = j;\n    };\n;\n    h(i.prototype, {\n        _subscriptions: null,\n        enable: function() {\n            var j = this._layer.getRoot();\n            this._subscriptions = [JSBNG__Event.listen(j, \"submit\", this._onSubmit.bind(this)),JSBNG__Event.listen(j, \"success\", this._onSuccess.bind(this)),JSBNG__Event.listen(j, \"error\", this._onError.bind(this)),];\n        },\n        disable: function() {\n            this._subscriptions.forEach(function(j) {\n                j.remove();\n            });\n            this._subscriptions = null;\n        },\n        _onSubmit: function(JSBNG__event) {\n            if (((this._layer.inform(\"submit\", JSBNG__event) === false))) {\n                JSBNG__event.kill();\n            }\n        ;\n        ;\n        },\n        _onSuccess: function(JSBNG__event) {\n            if (((this._layer.inform(\"success\", JSBNG__event) === false))) {\n                JSBNG__event.kill();\n            }\n        ;\n        ;\n        },\n        _onError: function(JSBNG__event) {\n            var j = JSBNG__event.getData();\n            if (((this._layer.inform(\"error\", {\n                response: j.response\n            }) === false))) {\n                JSBNG__event.kill();\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = i;\n});\n__d(\"LayerHideOnBlur\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\");\n    function h(i) {\n        this._layer = i;\n    };\n;\n    g(h.prototype, {\n        _subscriptions: null,\n        _onBlur: null,\n        enable: function() {\n            this._subscriptions = [this._layer.subscribe(\"show\", this._attach.bind(this)),this._layer.subscribe(\"hide\", this._detach.bind(this)),];\n            if (this._layer.isShown()) {\n                this._attach();\n            }\n        ;\n        ;\n        },\n        disable: function() {\n            this._detach();\n            while (this._subscriptions.length) {\n                this._subscriptions.pop().unsubscribe();\n            ;\n            };\n        ;\n            this._subscriptions = null;\n        },\n        _detach: function() {\n            ((this._onBlur && this._onBlur.unsubscribe()));\n            this._onBlur = null;\n        },\n        _attach: function() {\n            (function() {\n                this._onBlur = this._layer.subscribe(\"JSBNG__blur\", this._layer.hide.shield(this._layer));\n            }).bind(this).defer();\n        }\n    });\n    e.exports = h;\n});\n__d(\"LayerHideOnEscape\", [\"event-extensions\",\"copyProperties\",\"Input\",\"Keys\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"copyProperties\"), h = b(\"Input\"), i = b(\"Keys\");\n    function j(k) {\n        this._layer = k;\n    };\n;\n    g(j.prototype, {\n        _subscription: null,\n        enable: function() {\n            this._subscription = this._layer.subscribe(\"key\", this._handle.bind(this));\n        },\n        disable: function() {\n            this._subscription.unsubscribe();\n            this._subscription = null;\n        },\n        _handle: function(k, JSBNG__event) {\n            if (((JSBNG__Event.getKeyCode(JSBNG__event) === i.ESC))) {\n                var l = this._layer.getCausalElement();\n                if (l) {\n                    if (((l.tabIndex != -1))) {\n                        h.JSBNG__focus(l);\n                    }\n                ;\n                }\n            ;\n            ;\n                this._layer.hide();\n                return false;\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = j;\n});\n__d(\"LayerHideOnSuccess\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\");\n    function h(i) {\n        this._layer = i;\n    };\n;\n    g(h.prototype, {\n        _subscription: null,\n        enable: function() {\n            this._subscription = this._layer.subscribe(\"success\", this._layer.hide.bind(this._layer));\n        },\n        disable: function() {\n            if (this._subscription) {\n                this._subscription.unsubscribe();\n                this._subscription = null;\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = h;\n});\n__d(\"LayerHideOnTransition\", [\"Arbiter\",\"Class\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"Class\"), i = b(\"copyProperties\");\n    function j(k) {\n        this._layer = k;\n    };\n;\n    i(j.prototype, {\n        _subscription: null,\n        enable: function() {\n            this._subscription = g.subscribe(\"page_transition\", this._layer.hide.shield(this._layer), g.SUBSCRIBE_NEW);\n        },\n        disable: function() {\n            if (this._subscription) {\n                this._subscription.unsubscribe();\n                this._subscription = null;\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = j;\n});\n__d(\"TabbableElements\", [\"Style\",\"createArrayFrom\",], function(a, b, c, d, e, f) {\n    var g = b(\"Style\"), h = b(\"createArrayFrom\"), i = {\n        JSBNG__find: function(j) {\n            function k(n) {\n                if (((n.tabIndex > 0))) {\n                    return true;\n                }\n            ;\n            ;\n                switch (n.tagName) {\n                  case \"A\":\n                    return ((n.href && ((n.rel != \"ignore\"))));\n                  case \"INPUT\":\n                    return ((((((n.type != \"hidden\")) && ((n.type != \"file\")))) && !n.disabled));\n                  case \"SELECT\":\n                    return !n.disabled;\n                  case \"TEXTAREA\":\n                    return !n.disabled;\n                  default:\n                    return false;\n                };\n            ;\n            };\n        ;\n            function l(n) {\n                if (((((n.offsetHeight === 0)) && ((n.offsetWidth === 0))))) {\n                    return true;\n                }\n            ;\n            ;\n                var o = n;\n                while (((((o && ((o != j)))) && ((g.get(o, \"visibility\") !== \"hidden\"))))) {\n                    o = o.parentNode;\n                ;\n                };\n            ;\n                return ((o !== j));\n            };\n        ;\n            var m = h(j.getElementsByTagName(\"*\"));\n            return m.filter(function(n) {\n                return ((k(n) && !l(n)));\n            });\n        }\n    };\n    e.exports = i;\n});\n__d(\"LayerTabIsolation\", [\"event-extensions\",\"copyProperties\",\"TabbableElements\",\"Keys\",\"Input\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"copyProperties\"), h = b(\"TabbableElements\"), i = b(\"Keys\"), j = b(\"Input\");\n    function k(l) {\n        this._layer = l;\n    };\n;\n    g(k.prototype, {\n        _tabHandler: null,\n        _subscriptions: [],\n        enable: function() {\n            this._subscriptions = [this._layer.subscribe(\"show\", this._attachHandler.bind(this)),this._layer.subscribe(\"hide\", this._detachHandler.bind(this)),];\n        },\n        disable: function() {\n            while (this._subscriptions.length) {\n                this._subscriptions.pop().unsubscribe();\n            ;\n            };\n        ;\n            this._detachHandler();\n        },\n        _attachHandler: function() {\n            var l = this._layer.getRoot();\n            this._tabHandler = JSBNG__Event.listen(l, \"keydown\", function(m) {\n                if (((JSBNG__Event.getKeyCode(m) == i.TAB))) {\n                    var n = m.getTarget();\n                    if (n) {\n                        var o = h.JSBNG__find(l), p = o[0], q = o[((o.length - 1))], r = m.getModifiers().shift;\n                        if (((r && ((n == p))))) {\n                            m.preventDefault();\n                            j.JSBNG__focus(q);\n                        }\n                         else if (((!r && ((n == q))))) {\n                            m.preventDefault();\n                            j.JSBNG__focus(p);\n                        }\n                        \n                    ;\n                    ;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            });\n        },\n        _detachHandler: function() {\n            if (this._tabHandler) {\n                this._tabHandler.remove();\n                this._tabHandler = null;\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = k;\n});\n__d(\"LayerMouseHooks\", [\"event-extensions\",\"function-extensions\",\"ContextualThing\",\"DOM\",\"Layer\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"ContextualThing\"), h = b(\"DOM\"), i = b(\"Layer\"), j = b(\"copyProperties\");\n    function k(l) {\n        this._layer = l;\n    };\n;\n    j(k.prototype, {\n        _mouseSubscriptions: [],\n        _layerSubscriptions: [],\n        enable: function() {\n            var l = this._layer.getRoot();\n            this._mouseSubscriptions = [JSBNG__Event.listen(l, \"mouseenter\", this._onMouseEnter.bind(this)),JSBNG__Event.listen(l, \"mouseleave\", this._onMouseLeave.bind(this)),];\n            this._layerSubscriptions = [i.subscribe(\"show\", this._onLayerShow.bind(this)),i.subscribe(\"hide\", this._onLayerHide.bind(this)),];\n        },\n        disable: function() {\n            this._mouseSubscriptions.forEach(function(l) {\n                l.remove();\n            });\n            this._mouseSubscriptions = [];\n            this._layerSubscriptions.forEach(function(l) {\n                i.unsubscribe(l);\n            });\n            this._layerSubscriptions = [];\n        },\n        _onMouseEnter: function(l) {\n            this._fireMouseLeaveOnLayerHide = false;\n            if (!this._spawnedLayer) {\n                this._layer.inform(\"mouseenter\");\n            }\n        ;\n        ;\n        },\n        _onMouseLeave: function(l) {\n            if (!this._spawnedLayer) {\n                this._layer.inform(\"mouseleave\");\n            }\n        ;\n        ;\n            this._fireMouseLeaveOnLayerHide = !!this._spawnedLayer;\n        },\n        _onLayerShow: function(l, m) {\n            var n = ((m.getContext && m.getContext()));\n            if (n) {\n                if (h.contains(this._layer.getRoot(), n)) {\n                    this._spawnedLayer = m;\n                }\n            ;\n            }\n        ;\n        ;\n        },\n        _onLayerHide: function(l, m) {\n            if (((m === this._spawnedLayer))) {\n                this._spawnedLayer = null;\n                if (this._fireMouseLeaveOnLayerHide) {\n                    this._onMouseLeave.bind(this).defer();\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = k;\n});\n__d(\"Overlay\", [\"Arbiter\",\"Class\",\"CSS\",\"DataStore\",\"DOM\",\"Layer\",\"LayerAutoFocus\",\"LayerButtons\",\"LayerDestroyOnHide\",\"LayerFadeOnHide\",\"LayerFadeOnShow\",\"LayerFormHooks\",\"LayerHideOnBlur\",\"LayerHideOnEscape\",\"LayerHideOnSuccess\",\"LayerHideOnTransition\",\"LayerTabIsolation\",\"LayerMouseHooks\",\"$\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"Class\"), i = b(\"CSS\"), j = b(\"DataStore\"), k = b(\"DOM\"), l = b(\"Layer\"), m = b(\"LayerAutoFocus\"), n = b(\"LayerButtons\"), o = b(\"LayerDestroyOnHide\"), p = b(\"LayerFadeOnHide\"), q = b(\"LayerFadeOnShow\"), r = b(\"LayerFormHooks\"), s = b(\"LayerHideOnBlur\"), t = b(\"LayerHideOnEscape\"), u = b(\"LayerHideOnSuccess\"), v = b(\"LayerHideOnTransition\"), w = b(\"LayerTabIsolation\"), x = b(\"LayerMouseHooks\"), y = b(\"$\"), z = b(\"copyProperties\");\n    function aa(ba, ca) {\n        ba = z({\n            buildWrapper: true\n        }, ((ba || {\n        })));\n        this._shouldBuildWrapper = ba.buildWrapper;\n        this.parent.construct(this, ba, ca);\n    };\n;\n    h.extend(aa, l);\n    z(aa.prototype, {\n        _configure: function(ba, ca) {\n            this.parent._configure(ba, ca);\n            var da = this.getRoot();\n            this._overlay = ((k.scry(da, \"div.uiOverlay\")[0] || da));\n            i.hide(da);\n            k.appendContent(this.getInsertParent(), da);\n            j.set(this._overlay, \"overlay\", this);\n            var ea = j.get(this._overlay, \"width\");\n            ((ea && this.setWidth(ea)));\n            if (this.setFixed) {\n                this.setFixed(((j.get(this._overlay, \"fixed\") == \"true\")));\n            }\n        ;\n        ;\n            if (((j.get(this._overlay, \"fadeonshow\") != \"false\"))) {\n                this.enableBehavior(q);\n            }\n        ;\n        ;\n            if (((j.get(this._overlay, \"fadeonhide\") != \"false\"))) {\n                this.enableBehavior(p);\n            }\n        ;\n        ;\n            if (((j.get(this._overlay, \"hideonsuccess\") != \"false\"))) {\n                this.enableBehavior(u);\n            }\n        ;\n        ;\n            if (((j.get(this._overlay, \"hideonblur\") == \"true\"))) {\n                this.enableBehavior(s);\n            }\n        ;\n        ;\n            if (((j.get(this._overlay, \"destroyonhide\") != \"false\"))) {\n                this.enableBehavior(o);\n            }\n        ;\n        ;\n            return this;\n        },\n        _getDefaultBehaviors: function() {\n            return this.parent._getDefaultBehaviors().concat([m,n,r,x,t,v,w,]);\n        },\n        initWithoutBuildingWrapper: function() {\n            this._shouldBuildWrapper = false;\n            return this.init.apply(this, arguments);\n        },\n        _buildWrapper: function(ba, ca) {\n            ca = this.parent._buildWrapper(ba, ca);\n            if (!this._shouldBuildWrapper) {\n                this._contentRoot = ca;\n                return ca;\n            }\n        ;\n        ;\n            this._contentRoot = k.create(\"div\", {\n                className: \"uiOverlayContent\"\n            }, ca);\n            return k.create(\"div\", {\n                className: \"uiOverlay\"\n            }, this._contentRoot);\n        },\n        _getContentRoot: function() {\n            return this._contentRoot;\n        },\n        destroy: function() {\n            j.remove(this.getRoot(), \"overlay\");\n            this.parent.destroy();\n        }\n    });\n    e.exports = aa;\n});\n__d(\"Toggler\", [\"array-extensions\",\"event-extensions\",\"Arbiter\",\"ArbiterMixin\",\"Class\",\"ContextualDialogX\",\"ContextualThing\",\"CSS\",\"DataStore\",\"Dialog\",\"DOM\",\"copyProperties\",\"createArrayFrom\",\"ge\",\"getObjectValues\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"Class\"), j = b(\"ContextualDialogX\"), k = b(\"ContextualThing\"), l = b(\"CSS\"), m = b(\"DataStore\"), n = b(\"Dialog\"), o = b(\"DOM\"), p = b(\"copyProperties\"), q = b(\"createArrayFrom\"), r = b(\"ge\"), s = b(\"getObjectValues\"), t = [], u;\n    function v() {\n        v = bagofholding;\n        JSBNG__Event.listen(JSBNG__document.documentElement, \"click\", function(JSBNG__event) {\n            var z = JSBNG__event.getTarget();\n            t.forEach(function(aa) {\n                aa.clickedTarget = z;\n                ((((((((((aa.active && !aa.sticky)) && !k.containsIncludingLayers(aa.getActive(), z))) && !aa.inTargetFlyout(z))) && aa.inActiveDialog())) && aa.hide()));\n            });\n        }, JSBNG__Event.Priority.URGENT);\n    };\n;\n    var w = function() {\n        this.active = null;\n        this.togglers = {\n        };\n        this.setSticky(false);\n        t.push(this);\n        this.subscribe([\"show\",\"hide\",], w.inform.bind(w));\n        return v();\n    };\n    p(w.prototype, h, {\n        show: function(z) {\n            var aa = x(this, z), ba = aa.active;\n            if (((z !== ba))) {\n                ((ba && aa.hide()));\n                aa.active = z;\n                l.addClass(z, \"openToggler\");\n                var ca = o.scry(z, \"a[rel=\\\"toggle\\\"]\");\n                if (((((ca.length > 0)) && ca[0].getAttribute(\"data-target\")))) {\n                    l.removeClass(r(ca[0].getAttribute(\"data-target\")), \"toggleTargetClosed\");\n                }\n            ;\n            ;\n                o.appendContent(z, aa.getToggler(\"next\"));\n                o.prependContent(z, aa.getToggler(\"prev\"));\n                aa.inform(\"show\", aa);\n            }\n        ;\n        ;\n        },\n        hide: function(z) {\n            var aa = x(this, z), ba = aa.active;\n            if (((ba && ((!z || ((z === ba))))))) {\n                l.removeClass(ba, \"openToggler\");\n                var ca = o.scry(ba, \"a[rel=\\\"toggle\\\"]\");\n                if (((((ca.length > 0)) && ca[0].getAttribute(\"data-target\")))) {\n                    l.addClass(r(ca[0].getAttribute(\"data-target\")), \"toggleTargetClosed\");\n                }\n            ;\n            ;\n                s(aa.togglers).forEach(o.remove);\n                aa.inform(\"hide\", aa);\n                aa.active = null;\n            }\n        ;\n        ;\n        },\n        toggle: function(z) {\n            var aa = x(this, z);\n            if (((aa.active === z))) {\n                aa.hide();\n            }\n             else aa.show(z);\n        ;\n        ;\n        },\n        getActive: function() {\n            return x(this).active;\n        },\n        isShown: function() {\n            return ((x(this).active && l.hasClass(x(this).active, \"openToggler\")));\n        },\n        inTargetFlyout: function(z) {\n            var aa = y(this.getActive());\n            return ((aa && k.containsIncludingLayers(aa, z)));\n        },\n        inActiveDialog: function() {\n            var z = n.getCurrent();\n            return ((!z || o.contains(z.getRoot(), this.getActive())));\n        },\n        getToggler: function(z) {\n            var aa = x(this);\n            if (!aa.togglers[z]) {\n                aa.togglers[z] = o.create(\"button\", {\n                    className: \"hideToggler\",\n                    JSBNG__onfocus: function() {\n                        var ba = o.scry(aa.active, \"a[rel=\\\"toggle\\\"]\")[0];\n                        ((ba && ba.JSBNG__focus()));\n                        aa.hide();\n                    }\n                });\n                aa.togglers[z].setAttribute(\"type\", \"button\");\n            }\n        ;\n        ;\n            return this.togglers[z];\n        },\n        setSticky: function(z) {\n            var aa = x(this);\n            z = ((z !== false));\n            if (((z !== aa.sticky))) {\n                aa.sticky = z;\n                if (z) {\n                    ((aa._pt && aa._pt.unsubscribe()));\n                }\n                 else aa._pt = g.subscribe(\"page_transition\", aa.hide.bind(aa, null));\n            ;\n            ;\n            }\n        ;\n        ;\n            return aa;\n        }\n    });\n    p(w, w.prototype);\n    p(w, {\n        bootstrap: function(z) {\n            var aa = z.parentNode;\n            w.getInstance(aa).toggle(aa);\n        },\n        createInstance: function(z) {\n            var aa = new w().setSticky(true);\n            m.set(z, \"toggler\", aa);\n            return aa;\n        },\n        getInstance: function(z) {\n            while (z) {\n                var aa = m.get(z, \"toggler\");\n                if (aa) {\n                    return aa;\n                }\n            ;\n            ;\n                if (l.hasClass(z, \"uiToggleContext\")) {\n                    return w.createInstance(z);\n                }\n            ;\n            ;\n                z = z.parentNode;\n            };\n        ;\n            return (u = ((u || new w())));\n        },\n        listen: function(z, aa, ba) {\n            return w.subscribe(q(z), function(ca, da) {\n                if (((da.getActive() === aa))) {\n                    return ba(ca, da);\n                }\n            ;\n            ;\n            });\n        },\n        subscribe: (function(z) {\n            return function(aa, ba) {\n                aa = q(aa);\n                if (aa.contains(\"show\")) {\n                    t.forEach(function(ca) {\n                        if (ca.getActive()) {\n                            ba.curry(\"show\", ca).defer();\n                        }\n                    ;\n                    ;\n                    });\n                }\n            ;\n            ;\n                return z(aa, ba);\n            };\n        })(w.subscribe.bind(w))\n    });\n    function x(z, aa) {\n        if (((z instanceof w))) {\n            return z;\n        }\n    ;\n    ;\n        return w.getInstance(aa);\n    };\n;\n    function y(z) {\n        var aa = o.scry(z, \"a[rel=\\\"toggle\\\"]\");\n        if (((((aa.length > 0)) && aa[0].getAttribute(\"data-target\")))) {\n            return r(aa[0].getAttribute(\"data-target\"));\n        }\n    ;\n    ;\n    };\n;\n    e.exports = w;\n});\n__d(\"Dock\", [\"event-extensions\",\"function-extensions\",\"Arbiter\",\"ArbiterMixin\",\"ChatQuietLinks\",\"CSS\",\"DataStore\",\"DOM\",\"Parent\",\"Style\",\"Toggler\",\"Vector\",\"copyProperties\",\"ge\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"ChatQuietLinks\"), j = b(\"CSS\"), k = b(\"DataStore\"), l = b(\"DOM\"), m = b(\"Parent\"), n = b(\"Style\"), o = b(\"Toggler\"), p = b(\"Vector\"), q = b(\"copyProperties\"), r = b(\"ge\");\n    function s() {\n    \n    };\n;\n    q(s, h, {\n        MIN_HEIGHT: 140,\n        INITIAL_FLYOUT_HEIGHT_OFFSET: 10,\n        init: function(t) {\n            this.init = bagofholding;\n            this.rootEl = t;\n            this.calculateViewportDimensions();\n            this.calculateFlyoutHeightOffset();\n            i.removeEmptyHrefs(this.rootEl);\n            JSBNG__Event.listen(t, \"click\", this._onClick.bind(this));\n            JSBNG__Event.listen(window, \"resize\", this._onWindowResize.bind(this));\n            o.subscribe([\"show\",\"hide\",], function(u, v) {\n                var w = v.getActive();\n                if (!l.contains(t, w)) {\n                    return;\n                }\n            ;\n            ;\n                if (j.hasClass(w, \"fbNub\")) {\n                    this.notifyNub(w, u);\n                    if (((u === \"show\"))) {\n                        this._resizeNubFlyout(w);\n                    }\n                ;\n                ;\n                }\n                 else {\n                    var x = m.byClass(w, \"fbNubFlyout\");\n                    if (x) {\n                        j.conditionClass(x, \"menuOpened\", ((u === \"show\")));\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            }.bind(this));\n            this.inform(\"init\", {\n            }, g.BEHAVIOR_PERSISTENT);\n        },\n        calculateViewportDimensions: function() {\n            return (this.viewportDimensions = p.getViewportDimensions());\n        },\n        calculateFlyoutHeightOffset: function() {\n            this.flyoutHeightOffset = ((this.INITIAL_FLYOUT_HEIGHT_OFFSET + p.getElementDimensions(this.rootEl).y));\n            var t = r(\"blueBar\");\n            if (t) {\n                var u = ((n.isFixed(t) ? \"viewport\" : \"JSBNG__document\"));\n                this.flyoutHeightOffset += ((p.getElementPosition(t, u).y + p.getElementDimensions(t).y));\n            }\n        ;\n        ;\n        },\n        toggle: function(t) {\n            var u = this._findFlyout(t);\n            if (!u) {\n                return;\n            }\n        ;\n        ;\n            this.subscribe(\"init\", function() {\n                o.toggle(t);\n            });\n        },\n        show: function(t) {\n            this.subscribe(\"init\", function() {\n                o.show(t);\n            });\n        },\n        showNub: function(t) {\n            j.show(t);\n        },\n        hide: function(t) {\n            this.subscribe(\"init\", function() {\n                var u = o.getInstance(t);\n                ((l.contains(t, u.getActive()) && u.hide()));\n            });\n        },\n        hideNub: function(t) {\n            j.hide(t);\n            this.hide(t);\n        },\n        setUseMaxHeight: function(t, u) {\n            j.conditionClass(t, \"maxHeight\", ((u !== false)));\n            this._resizeNubFlyout(t);\n        },\n        _resizeNubFlyout: function(t) {\n            var u = this._findFlyout(t);\n            if (((!u || !((j.hasClass(t, \"openToggler\") || j.hasClass(t, \"opened\")))))) {\n                return;\n            }\n        ;\n        ;\n            var v = l.JSBNG__find(u, \"div.fbNubFlyoutOuter\"), w = l.JSBNG__find(v, \"div.fbNubFlyoutInner\"), x = l.JSBNG__find(w, \"div.fbNubFlyoutBody\"), y = x.scrollTop, z = x.offsetHeight;\n            n.set(x, \"height\", \"auto\");\n            var aa = p.getElementPosition(u, \"viewport\"), ba = p.getElementDimensions(u), ca = p.getElementDimensions(x), da = ((Math.max(this.MIN_HEIGHT, ((this.viewportDimensions.y - this.flyoutHeightOffset))) - ((((this.viewportDimensions.y - aa.y)) - ba.y))));\n            da = Math.max(da, 0);\n            n.set(u, \"max-height\", ((da + \"px\")));\n            n.set(v, \"max-height\", ((da + \"px\")));\n            ba = p.getElementDimensions(u);\n            var ea = p.getElementDimensions(w), fa = ((ea.y - ca.y));\n            if (((ba.y > fa))) {\n                n.set(x, \"height\", ((((ba.y - fa)) + \"px\")));\n            }\n        ;\n        ;\n            j.removeClass(u, \"swapDirection\");\n            var ga = p.getElementPosition(u).x;\n            j.conditionClass(u, \"swapDirection\", function() {\n                if (((ga < 0))) {\n                    return true;\n                }\n            ;\n            ;\n                return ((((ga + ba.x)) > this.viewportDimensions.x));\n            }.bind(this)());\n            if (((((y + z)) >= ca.y))) {\n                x.scrollTop = ca.y;\n            }\n             else x.scrollTop = y;\n        ;\n        ;\n            this.notifyNub(t, \"resize\");\n        },\n        resizeAllFlyouts: function() {\n            var t = l.scry(this.rootEl, \"div.fbNub.openToggler\");\n            t = t.concat(l.scry(this.rootEl, \"div.fbNub.opened\"));\n            var u = t.length;\n            while (u--) {\n                this._resizeNubFlyout(t[u]);\n            ;\n            };\n        ;\n        },\n        _onClick: function(JSBNG__event) {\n            var t = JSBNG__event.getTarget(), u = m.byClass(t, \"fbNub\");\n            if (u) {\n                if (m.byClass(t, \"fbNubFlyoutTitlebar\")) {\n                    var v = m.byTag(t, \"a\");\n                    if (!v) {\n                        this.hide(u);\n                        return false;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                this.notifyNub(u, \"click\");\n            }\n        ;\n        ;\n        },\n        _onWindowResize: function(JSBNG__event) {\n            this.calculateViewportDimensions();\n            this.resizeAllFlyouts();\n        },\n        _findFlyout: function(t) {\n            return ((j.hasClass(t, \"fbNubFlyout\") ? t : ((l.scry(t, \"div.fbNubFlyout\")[0] || null))));\n        },\n        registerNubController: function(t, u) {\n            k.set(t, \"dock:nub:controller\", u);\n            u.subscribe(\"nub/button/content-changed\", this.inform.shield(this, \"resize\", t));\n            u.subscribe(\"nub/flyout/content-changed\", this._resizeNubFlyout.shield(this, t));\n        },\n        unregisterNubController: function(t) {\n            k.remove(t, \"dock:nub:controller\");\n        },\n        notifyNub: function(t, u, v) {\n            var w = k.get(t, \"dock:nub:controller\");\n            ((w && w.inform(u, v)));\n        }\n    });\n    e.exports = ((a.Dock || s));\n});\n__d(\"NubController\", [\"ArbiterMixin\",\"Class\",\"Dock\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"ArbiterMixin\"), h = b(\"Class\"), i = b(\"Dock\"), j = b(\"copyProperties\");\n    function k() {\n    \n    };\n;\n    j(k.prototype, g, {\n        init: function(l) {\n            this.el = l;\n            i.registerNubController(l, this);\n            return this;\n        },\n        buttonContentChanged: function() {\n            this.inform(\"nub/button/content-changed\");\n        },\n        flyoutContentChanged: function() {\n            this.inform(\"nub/flyout/content-changed\");\n        },\n        hide: function() {\n            i.hide(this.el);\n        },\n        show: function() {\n            i.show(this.el);\n        }\n    });\n    e.exports = k;\n});\n__d(\"NavigationMessage\", [], function(a, b, c, d, e, f) {\n    var g = {\n        NAVIGATION_BEGIN: \"NavigationMessage/navigationBegin\",\n        NAVIGATION_SELECT: \"NavigationMessage/navigationSelect\",\n        NAVIGATION_FIRST_RESPONSE: \"NavigationMessage/navigationFirstResponse\",\n        NAVIGATION_COMPLETED: \"NavigationMessage/navigationCompleted\",\n        NAVIGATION_FAILED: \"NavigationMessage/navigationFailed\",\n        NAVIGATION_COUNT_UPDATE: \"NavigationMessage/navigationCount\",\n        NAVIGATION_FAVORITE_UPDATE: \"NavigationMessage/navigationFavoriteUpdate\",\n        NAVIGATION_ITEM_REMOVED: \"NavigationMessage/navigationItemRemoved\",\n        NAVIGATION_ITEM_HIDDEN: \"NavigationMessage/navigationItemHidden\",\n        INTERNAL_LOADING_BEGIN: \"NavigationMessage/internalLoadingBegin\",\n        INTERNAL_LOADING_COMPLETED: \"NavigationMessage/internalLoadingCompleted\"\n    };\n    e.exports = g;\n});\n__d(\"legacy:ui-side-nav-message\", [\"NavigationMessage\",], function(a, b, c, d) {\n    a.NavigationMessage = b(\"NavigationMessage\");\n}, 3);\n__d(\"DropdownContextualHelpLink\", [\"copyProperties\",\"DOM\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\"), h = b(\"DOM\"), i = b(\"ge\"), j = {\n        set: function(k) {\n            var l = i(\"navHelpCenter\");\n            if (((l !== null))) {\n                h.replace(l, k);\n            }\n        ;\n        ;\n        }\n    };\n    e.exports = j;\n});\n__d(\"SimpleDrag\", [\"event-extensions\",\"ArbiterMixin\",\"Class\",\"UserAgent\",\"Vector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"Class\"), i = b(\"UserAgent\"), j = b(\"Vector\"), k = b(\"copyProperties\");\n    function l(m) {\n        this.minDragDistance = 0;\n        JSBNG__Event.listen(m, \"mousedown\", this._start.bind(this));\n    };\n;\n    k(l.prototype, g, {\n        setMinDragDistance: function(m) {\n            this.minDragDistance = m;\n        },\n        _start: function(JSBNG__event) {\n            var m = false, n = true, o = null;\n            if (this.inform(\"mousedown\", JSBNG__event)) {\n                n = false;\n            }\n        ;\n        ;\n            if (this.minDragDistance) {\n                o = j.getEventPosition(JSBNG__event);\n            }\n             else {\n                m = true;\n                if (this.inform(\"start\", JSBNG__event)) {\n                    n = false;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            var p = ((((i.ie() < 9)) ? JSBNG__document.documentElement : window)), q = JSBNG__Event.listen(p, {\n                selectstart: ((n ? JSBNG__Event.prevent : bagofholding)),\n                mousemove: function(JSBNG__event) {\n                    if (!m) {\n                        var r = j.getEventPosition(JSBNG__event);\n                        if (((o.distanceTo(r) < this.minDragDistance))) {\n                            return;\n                        }\n                    ;\n                    ;\n                        m = true;\n                        this.inform(\"start\", JSBNG__event);\n                    }\n                ;\n                ;\n                    this.inform(\"update\", JSBNG__event);\n                }.bind(this),\n                mouseup: function(JSBNG__event) {\n                    for (var r in q) {\n                        q[r].remove();\n                    ;\n                    };\n                ;\n                    if (m) {\n                        this.inform(\"end\", JSBNG__event);\n                    }\n                     else this.inform(\"click\", JSBNG__event);\n                ;\n                ;\n                }.bind(this)\n            });\n            return !n;\n        }\n    });\n    e.exports = l;\n});\n__d(\"isRTL\", [], function(a, b, c, d, e, f) {\n    function g(i) {\n        for (var j = 0, k = i.length; ((j < k)); j++) {\n            var l = i.charCodeAt(j);\n            if (((((l >= 1470)) && ((l <= 1920))))) {\n                return true;\n            }\n        ;\n        ;\n        };\n    ;\n        return false;\n    };\n;\n    function h(i) {\n        var j = 0, k = 0;\n        i.split(/\\s/, 10).forEach(function(l) {\n            j++;\n            ((g(l) && k++));\n        });\n        return ((j && ((((k / j)) >= 162025))));\n    };\n;\n    e.exports = h;\n});\n__d(\"legacy:bind\", [\"bind\",], function(a, b, c, d) {\n    a.bind = b(\"bind\");\n}, 3);\n__d(\"ScrollAwareDOM\", [\"ArbiterMixin\",\"CSS\",\"DOM\",\"DOMDimensions\",\"DOMPosition\",\"DOMQuery\",\"HTML\",\"Vector\",\"ViewportBounds\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"ArbiterMixin\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"DOMDimensions\"), k = b(\"DOMPosition\"), l = b(\"DOMQuery\"), m = b(\"HTML\"), n = b(\"Vector\"), o = b(\"ViewportBounds\"), p = b(\"copyProperties\");\n    function q(v, w) {\n        return function() {\n            u.monitor(arguments[v], w.curry.apply(w, arguments));\n        };\n    };\n;\n    function r(v) {\n        if (!((v instanceof Array))) {\n            v = [v,];\n        }\n    ;\n    ;\n        for (var w = 0; ((w < v.length)); w++) {\n            var x = m.replaceJSONWrapper(v[w]);\n            if (((x instanceof m))) {\n                return x.getRootNode();\n            }\n             else if (i.isNode(x)) {\n                return x;\n            }\n            \n        ;\n        ;\n        };\n    ;\n        return null;\n    };\n;\n    function s(v) {\n        return ((k.getElementPosition(v).y >= o.getTop()));\n    };\n;\n    function t(v) {\n        var w = ((k.getElementPosition(v).y + j.getElementDimensions(v).height)), x = ((j.getViewportDimensions().height - o.getBottom()));\n        return ((w >= x));\n    };\n;\n    var u = p({\n        monitor: function(v, w) {\n            var x = r(v);\n            if (x) {\n                var y = !!x.offsetParent;\n                if (((y && ((s(x) || t(x)))))) {\n                    return w();\n                }\n            ;\n            ;\n                var z = n.getDocumentDimensions(), aa = w();\n                if (((y || ((x.offsetParent && !s(x)))))) {\n                    var ba = n.getDocumentDimensions().sub(z), ca = {\n                        delta: ba,\n                        target: x\n                    };\n                    if (((u.inform(\"JSBNG__scroll\", ca) !== false))) {\n                        ba.scrollElementBy(l.getDocumentScrollElement());\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                return aa;\n            }\n             else return w()\n        ;\n        },\n        replace: function(v, w) {\n            var x = r(w);\n            if (((!x || h.hasClass(x, \"hidden_elem\")))) {\n                x = v;\n            }\n        ;\n        ;\n            return u.monitor(x, function() {\n                i.replace(v, w);\n            });\n        },\n        prependContent: q(1, i.prependContent),\n        insertAfter: q(1, i.insertAfter),\n        insertBefore: q(1, i.insertBefore),\n        setContent: q(0, i.setContent),\n        appendContent: q(1, i.appendContent),\n        remove: q(0, i.remove),\n        empty: q(0, i.empty)\n    }, g);\n    e.exports = u;\n});\n__d(\"legacy:ScrollAwareDOM\", [\"ScrollAwareDOM\",], function(a, b, c, d) {\n    a.ScrollAwareDOM = b(\"ScrollAwareDOM\");\n}, 3);\n__d(\"legacy:Style\", [\"Style\",], function(a, b, c, d) {\n    a.Style = b(\"Style\");\n}, 3);\n__d(\"legacy:dom-form\", [\"Form\",], function(a, b, c, d) {\n    a.Form = b(\"Form\");\n}, 3);\n__d(\"legacy:dom-html\", [\"HTML\",], function(a, b, c, d) {\n    a.HTML = b(\"HTML\");\n}, 3);\nfunction show() {\n    for (var a = 0; ((a < arguments.length)); a++) {\n        var b = ge(arguments[a]);\n        if (((b && b.style))) {\n            b.style.display = \"\";\n        }\n    ;\n    ;\n    };\n;\n    return false;\n};\n;\nfunction hide() {\n    for (var a = 0; ((a < arguments.length)); a++) {\n        var b = ge(arguments[a]);\n        if (((b && b.style))) {\n            b.style.display = \"none\";\n        }\n    ;\n    ;\n    };\n;\n    return false;\n};\n;\nfunction shown(a) {\n    a = ge(a);\n    return ((((a.style.display != \"none\")) && !((((a.style.display == \"\")) && ((a.offsetWidth == 0))))));\n};\n;\nfunction toggle() {\n    for (var a = 0; ((a < arguments.length)); a++) {\n        var b = $(arguments[a]);\n        b.style.display = ((((Style.get(b, \"display\") == \"block\")) ? \"none\" : \"block\"));\n    };\n;\n    return false;\n};\n;\nfunction toggleDisplayNone() {\n    for (var a = 0; ((a < arguments.length)); a++) {\n        var b = $(arguments[a]);\n        if (shown(b)) {\n            hide(b);\n        }\n         else show(b);\n    ;\n    ;\n    };\n;\n    return false;\n};\n;\n__d(\"legacy:dom-scroll\", [\"DOMScroll\",], function(a, b, c, d) {\n    a.DOMScroll = b(\"DOMScroll\");\n}, 3);\n__d(\"SystemEvents\", [\"Arbiter\",\"Env\",\"ErrorUtils\",\"UserAgent\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"Env\"), i = b(\"ErrorUtils\"), j = b(\"UserAgent\"), k = b(\"copyProperties\"), l = new g(), m = [], n = 1000;\n    JSBNG__setInterval(function() {\n        for (var w = 0; ((w < m.length)); w++) {\n            m[w]();\n        ;\n        };\n    ;\n    }, n, false);\n    function o() {\n        return ((((/c_user=(\\d+)/.test(JSBNG__document.cookie) && RegExp.$1)) || 0));\n    };\n;\n    var p = h.user, q = JSBNG__navigator.JSBNG__onLine;\n    function r() {\n        if (!q) {\n            q = true;\n            l.inform(l.ONLINE, q);\n        }\n    ;\n    ;\n    };\n;\n    function s() {\n        if (q) {\n            q = false;\n            l.inform(l.ONLINE, q);\n        }\n    ;\n    ;\n    };\n;\n    if (j.ie()) {\n        if (((j.ie() >= 8))) {\n            window.JSBNG__attachEvent(\"JSBNG__onload\", function() {\n                JSBNG__document.body.JSBNG__ononline = r;\n                JSBNG__document.body.JSBNG__onoffline = s;\n            });\n        }\n         else m.push(function() {\n            ((JSBNG__navigator.JSBNG__onLine ? r : s))();\n        });\n    ;\n    ;\n    }\n     else if (window.JSBNG__addEventListener) {\n        if (!j.JSBNG__chrome()) {\n            window.JSBNG__addEventListener(\"JSBNG__online\", r, false);\n            window.JSBNG__addEventListener(\"offline\", s, false);\n        }\n    ;\n    }\n    \n;\n;\n    var t = p;\n    m.push(function() {\n        var w = o();\n        if (((t != w))) {\n            l.inform(l.USER, w);\n            t = w;\n        }\n    ;\n    ;\n    });\n    var u = JSBNG__Date.now();\n    function v() {\n        var w = JSBNG__Date.now(), x = ((w - u)), y = ((((x < 0)) || ((x > 10000))));\n        u = w;\n        if (y) {\n            l.inform(l.TIME_TRAVEL, x);\n        }\n    ;\n    ;\n        return y;\n    };\n;\n    m.push(v);\n    m.push(function() {\n        if (((window.JSBNG__onerror != i.JSBNG__onerror))) {\n            window.JSBNG__onerror = i.JSBNG__onerror;\n        }\n    ;\n    ;\n    });\n    a.SystemEvents = e.exports = k(l, {\n        USER: \"SystemEvents/USER\",\n        ONLINE: \"SystemEvents/ONLINE\",\n        TIME_TRAVEL: \"SystemEvents/TIME_TRAVEL\",\n        isPageOwner: function(w) {\n            return ((((w || o())) == p));\n        },\n        isOnline: function() {\n            return ((j.JSBNG__chrome() || q));\n        },\n        checkTimeTravel: v\n    });\n}, 3);\n__d(\"legacy:link-controller\", [\"LinkController\",], function(a, b, c, d) {\n    a.LinkController = b(\"LinkController\");\n}, 3);\n__d(\"IntlDateFormats\", [], function(a, b, c, d, e, f) {\n    var g = {\n    }, h = {\n        setFormats: function(i, j) {\n            g = j;\n        },\n        getFormat: function(i) {\n            if (!((i in g))) {\n                return i;\n            }\n        ;\n        ;\n            return g[i];\n        }\n    };\n    e.exports = h;\n});\n__d(\"legacy:vector\", [\"Vector\",], function(a, b, c, d) {\n    a.Vector2 = b(\"Vector\");\n}, 3);\n__d(\"AsyncRequestNectarLogging\", [\"AsyncRequest\",\"Env\",\"copyProperties\",\"startsWith\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncRequest\"), h = b(\"Env\"), i = b(\"copyProperties\"), j = b(\"startsWith\");\n    i(g.prototype, {\n        setNectarModuleData: function(k) {\n            if (((this.method == \"POST\"))) {\n                var l = h.module;\n                if (((k && ((l === undefined))))) {\n                    var m = {\n                        fbpage_fan_confirm: 1\n                    }, n = null;\n                    for (var o = k; ((o && ((o != JSBNG__document.body)))); o = o.parentNode) {\n                        if (((!o.id || ((typeof o.id !== \"string\"))))) {\n                            continue;\n                        }\n                    ;\n                    ;\n                        if (j(o.id, \"pagelet_\")) {\n                            l = o.id;\n                            break;\n                        }\n                    ;\n                    ;\n                        if (((!n && m[o.id]))) {\n                            n = o.id;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    if (((((l === undefined)) && n))) {\n                        l = n;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                if (((l !== undefined))) {\n                    if (((this.data.nctr === undefined))) {\n                        this.data.nctr = {\n                        };\n                    }\n                ;\n                ;\n                    this.data.nctr._mod = l;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        setNectarImpressionId: function() {\n            if (((this.method == \"POST\"))) {\n                var k = h.impid;\n                if (((k !== undefined))) {\n                    if (((this.data.nctr === undefined))) {\n                        this.data.nctr = {\n                        };\n                    }\n                ;\n                ;\n                    this.data.nctr._impid = k;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        }\n    });\n});\n__d(\"legacy:async-postlude\", [\"AsyncRequestNectarLogging\",], function(a, b, c, d) {\n    b(\"AsyncRequestNectarLogging\");\n}, 3);\n__d(\"Base64\", [], function(a, b, c, d, e, f) {\n    var g = \"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/\";\n    function h(l) {\n        l = ((((((l.charCodeAt(0) << 16)) | ((l.charCodeAt(1) << 8)))) | l.charCodeAt(2)));\n        return String.fromCharCode(g.charCodeAt(((l >>> 18))), g.charCodeAt(((((l >>> 12)) & 63))), g.charCodeAt(((((l >>> 6)) & 63))), g.charCodeAt(((l & 63))));\n    };\n;\n    var i = ((((\"\\u003E___?456789:;\\u003C=_______\" + \"\\u0000\\u0001\\u0002\\u0003\\u0004\\u0005\\u0006\\u0007\\u0008\\u0009\\u000a\\u000b\\u000c\\u000d\\u000e\\u000f\\u0010\\u0011\\u0012\\u0013\\u0014\\u0015\\u0016\\u0017\\u0018\\u0019\")) + \"______\\u001a\\u001b\\u001c\\u001d\\u001e\\u001f !\\\"#$%&'()*+,-./0123\"));\n    function j(l) {\n        l = ((((((((i.charCodeAt(((l.charCodeAt(0) - 43))) << 18)) | ((i.charCodeAt(((l.charCodeAt(1) - 43))) << 12)))) | ((i.charCodeAt(((l.charCodeAt(2) - 43))) << 6)))) | i.charCodeAt(((l.charCodeAt(3) - 43)))));\n        return String.fromCharCode(((l >>> 16)), ((((l >>> 8)) & 255)), ((l & 255)));\n    };\n;\n    var k = {\n        encode: function(l) {\n            l = unescape(encodeURI(l));\n            var m = ((((l.length + 2)) % 3));\n            l = ((l + \"\\u0000\\u0000\".slice(m))).replace(/[\\s\\S]{3}/g, h);\n            return ((l.slice(0, ((((l.length + m)) - 2))) + \"==\".slice(m)));\n        },\n        decode: function(l) {\n            l = l.replace(/[^A-Za-z0-9+\\/]/g, \"\");\n            var m = ((((l.length + 3)) & 3));\n            l = ((l + \"AAA\".slice(m))).replace(/..../g, j);\n            l = l.slice(0, ((((l.length + m)) - 3)));\n            try {\n                return decodeURIComponent(escape(l));\n            } catch (n) {\n                throw new Error(\"Not valid UTF-8\");\n            };\n        ;\n        },\n        encodeObject: function(l) {\n            return k.encode(JSON.stringify(l));\n        },\n        decodeObject: function(l) {\n            return JSON.parse(k.decode(l));\n        },\n        encodeNums: function(l) {\n            return String.fromCharCode.apply(String, l.map(function(m) {\n                return g.charCodeAt(((((((m | -((m > 63)))) & -((m > 0)))) & 63)));\n            }));\n        }\n    };\n    e.exports = k;\n});\n__d(\"legacy:base64\", [\"Base64\",], function(a, b, c, d) {\n    a.Base64 = b(\"Base64\");\n}, 3);\n__d(\"date-extensions\", [\"IntlDateFormats\",\"copyProperties\",\"tx\",], function(a, b, c, d, e, f) {\n    var g = b(\"IntlDateFormats\"), h = b(\"copyProperties\"), i = b(\"tx\"), j = [\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\",], k = [\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\",], l = [\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\",], m = [\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\",];\n    function n(o, p) {\n        p = ((p || 2));\n        o = ((\"\" + o));\n        while (((o.length < p))) {\n            o = ((\"0\" + o));\n        ;\n        };\n    ;\n        return o;\n    };\n;\n    JSBNG__Date.format = function(o, p, q) {\n        var r = ((p ? new JSBNG__Date(((p * 1000))) : new JSBNG__Date()));\n        return r.format(o, q);\n    };\n    h(JSBNG__Date.prototype, {\n        format: function(o, p) {\n            if (!o) {\n                return \"\";\n            }\n        ;\n        ;\n            var q = [], r = null, s = null, t = ((p ? \"getUTC\" : \"get\")), u = this[((t + \"JSBNG__Date\"))](), v = this[((t + \"Day\"))](), w = this[((t + \"Month\"))](), x = this[((t + \"FullYear\"))](), y = this[((t + \"Hours\"))](), z = this[((t + \"Minutes\"))](), aa = this[((t + \"Seconds\"))](), ba = this[((t + \"Milliseconds\"))]();\n            for (var ca = 0; ((ca < o.length)); ca++) {\n                s = o.charAt(ca);\n                if (((s == \"\\\\\"))) {\n                    ca++;\n                    q.push(o.charAt(ca));\n                    continue;\n                }\n            ;\n            ;\n                switch (s) {\n                  case \"d\":\n                    r = n(u);\n                    break;\n                  case \"D\":\n                    r = j[v];\n                    break;\n                  case \"j\":\n                    r = u;\n                    break;\n                  case \"l\":\n                    r = k[v];\n                    break;\n                  case \"F\":\n                    r = m[w];\n                    break;\n                  case \"m\":\n                    r = n(((w + 1)));\n                    break;\n                  case \"M\":\n                    r = l[w];\n                    break;\n                  case \"n\":\n                    r = ((w + 1));\n                    break;\n                  case \"Y\":\n                    r = x;\n                    break;\n                  case \"y\":\n                    r = ((\"\" + x)).slice(2);\n                    break;\n                  case \"a\":\n                    r = ((((y < 12)) ? \"am\" : \"pm\"));\n                    break;\n                  case \"A\":\n                    r = ((((y < 12)) ? \"AM\" : \"PM\"));\n                    break;\n                  case \"g\":\n                    r = ((((((y == 0)) || ((y == 12)))) ? 12 : ((y % 12))));\n                    break;\n                  case \"G\":\n                    r = y;\n                    break;\n                  case \"h\":\n                    r = ((((((y == 0)) || ((y == 12)))) ? 12 : n(((y % 12)))));\n                    break;\n                  case \"H\":\n                    r = n(y);\n                    break;\n                  case \"i\":\n                    r = n(z);\n                    break;\n                  case \"s\":\n                    r = n(aa);\n                    break;\n                  case \"S\":\n                    r = n(ba, 3);\n                    break;\n                  default:\n                    r = s;\n                };\n            ;\n                q.push(r);\n            };\n        ;\n            return q.join(\"\");\n        }\n    });\n    a.IntlDateFormats = g;\n}, 3);\n__d(\"legacy:ua\", [\"UserAgent\",], function(a, b, c, d) {\n    a.ua = b(\"UserAgent\");\n}, 3);\n__d(\"legacy:dialog\", [\"Dialog\",], function(a, b, c, d) {\n    var e = b(\"Dialog\");\n    a.Dialog = e;\n}, 3);\n__d(\"csx\", [], function(a, b, c, d, e, f) {\n    function g(h) {\n        throw new Error(\"csx(...): Unexpected class selector transformation.\");\n    };\n;\n    e.exports = g;\n});\n__d(\"AccessibleLayer\", [\"event-extensions\",\"CSS\",\"DOM\",\"Input\",\"copyProperties\",\"csx\",\"tx\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"Input\"), j = b(\"copyProperties\"), k = b(\"csx\"), l = b(\"tx\");\n    function m(n) {\n        this._layer = n;\n    };\n;\n    j(m.prototype, {\n        enable: function() {\n            var n = this._layer.getRoot();\n            if (((n.tabIndex == -1))) {\n                n.tabIndex = 0;\n            }\n        ;\n        ;\n            var o = h.create(\"a\", {\n                className: \"accessible_elem\",\n                href: \"#\"\n            }, [\"Close popup and return\",]);\n            h.appendContent(n, o);\n            this._listener = JSBNG__Event.listen(o, \"click\", this._closeListener.bind(this));\n            this._afterShowSubscription = this._layer.subscribe(\"aftershow\", this._onAfterShow.bind(this));\n        },\n        disable: function() {\n            this._listener.remove();\n            this._afterShowSubscription.unsubscribe();\n            this._listener = this._afterShowSubscription = null;\n        },\n        _closeListener: function(JSBNG__event) {\n            var n = this._layer.getCausalElement();\n            if (n) {\n                if (((n.tabIndex == -1))) {\n                    n.tabIndex = 0;\n                    g.addClass(n, \"-cx-PRIVATE-accessibleLayer__noOutline\");\n                }\n            ;\n            ;\n                i.JSBNG__focus(n);\n            }\n        ;\n        ;\n            this._layer.hide();\n        },\n        _onAfterShow: function() {\n            var n = JSBNG__document.activeElement, o = this._layer.getRoot();\n            if (((!h.isNodeOfType(n, [\"input\",\"textarea\",]) && !h.contains(o, n)))) {\n                i.JSBNG__focus(o);\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = m;\n});\n__d(\"JSBNG__Rect\", [\"Vector\",\"$\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Vector\"), h = b(\"$\"), i = b(\"copyProperties\");\n    function j(k, l, m, n, o) {\n        if (((arguments.length === 1))) {\n            if (((k instanceof j))) {\n                return k;\n            }\n        ;\n        ;\n            if (((k instanceof g))) {\n                return new j(k.y, k.x, k.y, k.x, k.domain);\n            }\n        ;\n        ;\n            return j.getElementBounds(h(k));\n        }\n    ;\n    ;\n        i(this, {\n            t: k,\n            r: l,\n            b: m,\n            l: n,\n            domain: ((o || \"pure\"))\n        });\n    };\n;\n    i(j.prototype, {\n        w: function() {\n            return ((this.r - this.l));\n        },\n        h: function() {\n            return ((this.b - this.t));\n        },\n        toString: function() {\n            return ((((((((((((((((\"((\" + this.l)) + \", \")) + this.t)) + \"), (\")) + this.r)) + \", \")) + this.b)) + \"))\"));\n        },\n        contains: function(k) {\n            k = new j(k).convertTo(this.domain);\n            var l = this;\n            return ((((((((l.l <= k.l)) && ((l.r >= k.r)))) && ((l.t <= k.t)))) && ((l.b >= k.b))));\n        },\n        add: function(k, l) {\n            if (((arguments.length == 1))) {\n                if (((k.domain != \"pure\"))) {\n                    k = k.convertTo(this.domain);\n                }\n            ;\n            ;\n                return this.add(k.x, k.y);\n            }\n        ;\n        ;\n            var m = parseFloat(k), n = parseFloat(l);\n            return new j(((this.t + n)), ((this.r + m)), ((this.b + n)), ((this.l + m)), this.domain);\n        },\n        sub: function(k, l) {\n            if (((arguments.length == 1))) {\n                return this.add(k.mul(-1));\n            }\n             else return this.add(-k, -l)\n        ;\n        },\n        boundWithin: function(k) {\n            var l = 0, m = 0;\n            if (((this.l < k.l))) {\n                l = ((k.l - this.l));\n            }\n             else if (((this.r > k.r))) {\n                l = ((k.r - this.r));\n            }\n            \n        ;\n        ;\n            if (((this.t < k.t))) {\n                m = ((k.t - this.t));\n            }\n             else if (((this.b > k.b))) {\n                m = ((k.b - this.b));\n            }\n            \n        ;\n        ;\n            return this.add(l, m);\n        },\n        getCenter: function() {\n            return new g(((this.l + ((this.w() / 2)))), ((this.t + ((this.h() / 2)))), this.domain);\n        },\n        getPositionVector: function() {\n            return new g(this.l, this.t, this.domain);\n        },\n        getDimensionVector: function() {\n            return new g(this.w(), this.h(), \"pure\");\n        },\n        convertTo: function(k) {\n            if (((this.domain == k))) {\n                return this;\n            }\n        ;\n        ;\n            if (((k == \"pure\"))) {\n                return new j(this.t, this.r, this.b, this.l, \"pure\");\n            }\n        ;\n        ;\n            if (((this.domain == \"pure\"))) {\n                return new j(0, 0, 0, 0);\n            }\n        ;\n        ;\n            var l = new g(this.l, this.t, this.domain).convertTo(k);\n            return new j(l.y, ((l.x + this.w())), ((l.y + this.h())), l.x, k);\n        }\n    });\n    i(j, {\n        deserialize: function(k) {\n            var l = k.split(\":\");\n            return new j(parseFloat(l[1]), parseFloat(l[2]), parseFloat(l[3]), parseFloat(l[0]));\n        },\n        newFromVectors: function(k, l) {\n            return new j(k.y, ((k.x + l.x)), ((k.y + l.y)), k.x, k.domain);\n        },\n        getElementBounds: function(k) {\n            return j.newFromVectors(g.getElementPosition(k), g.getElementDimensions(k));\n        },\n        getViewportBounds: function() {\n            return j.newFromVectors(g.getScrollPosition(), g.getViewportDimensions());\n        },\n        minimumBoundingBox: function(k) {\n            var l = new j(Math.min(), Math.max(), Math.max(), Math.min()), m;\n            for (var n = 0; ((n < k.length)); n++) {\n                m = k[n];\n                l.t = Math.min(l.t, m.t);\n                l.r = Math.max(l.r, m.r);\n                l.b = Math.max(l.b, m.b);\n                l.l = Math.min(l.l, m.l);\n            };\n        ;\n            return l;\n        }\n    });\n    e.exports = j;\n});\n__d(\"Hovercard\", [\"ClickRef\",\"event-extensions\",\"function-extensions\",\"AccessibleLayer\",\"Arbiter\",\"AsyncRequest\",\"AsyncSignal\",\"ContextualDialogX\",\"CSS\",\"DOM\",\"DOMQuery\",\"LayerDestroyOnHide\",\"LayerFadeOnHide\",\"LayerFadeOnShow\",\"Parent\",\"JSBNG__Rect\",\"UserAgent\",\"URI\",\"Vector\",\"ViewportBounds\",\"tx\",\"userAction\",], function(a, b, c, d, e, f) {\n    b(\"ClickRef\");\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"AccessibleLayer\"), h = b(\"Arbiter\"), i = b(\"AsyncRequest\"), j = b(\"AsyncSignal\"), k = b(\"ContextualDialogX\"), l = b(\"CSS\"), m = b(\"DOM\"), n = b(\"DOMQuery\"), o = b(\"LayerDestroyOnHide\"), p = b(\"LayerFadeOnHide\"), q = b(\"LayerFadeOnShow\"), r = b(\"Parent\"), s = b(\"JSBNG__Rect\"), t = b(\"UserAgent\"), u = b(\"URI\"), v = b(\"Vector\"), w = b(\"ViewportBounds\"), x = b(\"tx\"), y = b(\"userAction\"), z = 450, aa = 385, ba = {\n    }, ca = {\n    }, da = null, ea = null, fa = null, ga = 150, ha = 700, ia = 1000, ja = 250, ka = null, la = null, ma = null, na = null;\n    function oa() {\n        if (((t.ie() < 7))) {\n            return;\n        }\n    ;\n    ;\n        JSBNG__Event.listen(JSBNG__document.documentElement, \"mouseover\", pa);\n        JSBNG__Event.listen(window, \"JSBNG__scroll\", function() {\n            kb.hide(true);\n        });\n        h.subscribe(\"page_transition\", function() {\n            va();\n            kb.dirtyAll();\n        }, h.SUBSCRIBE_NEW);\n        h.subscribe(\"layer_shown\", function(lb, mb) {\n            if (((((mb.type != \"Hovercard\")) && ((mb.type != \"ContextualDialog\"))))) {\n                va();\n            }\n        ;\n        ;\n        }, h.SUBSCRIBE_NEW);\n        k.subscribe(\"arrow_rendered\", xa, h.SUBSCRIBE_NEW);\n    };\n;\n    function pa(JSBNG__event) {\n        var lb = r.byTag(JSBNG__event.getTarget(), \"a\");\n        ((kb.processNode(lb) && JSBNG__event.JSBNG__stop()));\n    };\n;\n    function qa(lb) {\n        ea = lb;\n        if (!ra(lb)) {\n            var mb;\n            if (((!lb || !(mb = sa(lb))))) {\n                ((ca.moveToken && ca.moveToken.remove()));\n                ca = {\n                };\n                return false;\n            }\n        ;\n        ;\n            if (((ca.node != lb))) {\n                ((ca.moveToken && ca.moveToken.remove()));\n                ca = {\n                    node: lb,\n                    endpoint: mb,\n                    pos: null\n                };\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        return true;\n    };\n;\n    function ra(lb) {\n        return ((((lb && da)) && ((ca.node == lb))));\n    };\n;\n    function sa(lb) {\n        return lb.getAttribute(\"data-hovercard\");\n    };\n;\n    function ta(lb) {\n        var mb = JSBNG__Event.listen(lb, \"mouseout\", function() {\n            JSBNG__clearTimeout(ka);\n            JSBNG__clearTimeout(la);\n            mb.remove();\n            ea = null;\n            kb.hide();\n        });\n        if (!ca.moveToken) {\n            ca.moveToken = JSBNG__Event.listen(lb, \"mousemove\", function(JSBNG__event) {\n                ca.pos = v.getEventPosition(JSBNG__event);\n            });\n        }\n    ;\n    ;\n        JSBNG__clearTimeout(ka);\n        JSBNG__clearTimeout(la);\n        JSBNG__clearTimeout(na);\n        var nb = ga, ob = ((da ? ja : ha));\n        if (lb.getAttribute(\"data-hovercard-instant\")) {\n            nb = ob = 50;\n        }\n    ;\n    ;\n        ka = JSBNG__setTimeout(gb.curry(lb), nb);\n        la = JSBNG__setTimeout(ua.curry(lb), ob);\n    };\n;\n    function ua(lb, mb) {\n        if (((ca.node != lb))) {\n            return;\n        }\n    ;\n    ;\n        var nb = ba[sa(lb)];\n        if (nb) {\n            wa(nb);\n        }\n         else if (mb) {\n            wa(ib());\n        }\n         else {\n            var ob = ((da ? ja : ha));\n            ma = JSBNG__setTimeout(ua.curry(lb, true), ((ia - ob)));\n        }\n        \n    ;\n    ;\n    };\n;\n    function va() {\n        kb.hide(true);\n        JSBNG__clearTimeout(la);\n    };\n;\n    function wa(lb) {\n        var mb = ca.node, nb = da, ob = ((nb != mb));\n        if (da) {\n            var pb = k.getInstance(da);\n            ((pb && pb.hide()));\n        }\n    ;\n    ;\n        if (!m.contains(JSBNG__document.body, mb)) {\n            kb.hide(true);\n            return;\n        }\n    ;\n    ;\n        da = mb;\n        fa = lb;\n        cb();\n        lb.setContext(mb).show();\n        if (ob) {\n            (function() {\n                new j(\"/ajax/hovercard/shown.php\").send();\n                y(\"himp\", da, null, \"FORCE\", {\n                    ft: {\n                        evt: 39\n                    }\n                });\n            }).defer();\n            if (nb) {\n                h.inform(\"Hovercard/hide\", {\n                    node: nb\n                });\n            }\n             else h.inform(\"layer_shown\", {\n                type: \"Hovercard\"\n            });\n        ;\n        ;\n            h.inform(\"Hovercard/show\", {\n                node: mb\n            });\n        }\n    ;\n    ;\n    };\n;\n    function xa(lb, mb) {\n        var nb = ba[ca.endpoint];\n        if (((((((((mb.type !== \"ContextualDialog\")) || !nb)) || !mb.root)) || ((mb.position !== \"JSBNG__top\"))))) {\n            return;\n        }\n    ;\n    ;\n        var ob = n.scry(mb.root, \".CustomArrow\")[0];\n        if (!ob) {\n            return;\n        }\n    ;\n    ;\n        var pb = n.scry(ob, \".ArrowShadow\")[0];\n        if (!pb) {\n            return;\n        }\n    ;\n    ;\n        var qb = null;\n        if (((ob.style.webkitMaskPosition !== undefined))) {\n            qb = ab;\n        }\n         else if (ya(ob)) {\n            qb = bb;\n        }\n        \n    ;\n    ;\n        if (qb) {\n            l.addClass(mb.root, \"withCustomArrow\");\n            JSBNG__setTimeout(function() {\n                qb(ob, pb, mb);\n            }, 0);\n        }\n    ;\n    ;\n    };\n;\n    function ya(lb) {\n        if (!lb) {\n            lb = JSBNG__document.body;\n        }\n    ;\n    ;\n        var mb = [\"transform\",\"WebkitTransform\",\"msTransform\",\"MozTransform\",\"OTransform\",], nb;\n        while (nb = mb.shift()) {\n            if (((lb.style[nb] !== undefined))) {\n                return nb;\n            }\n        ;\n        ;\n        };\n    ;\n        return null;\n    };\n;\n    function za(lb, mb, nb) {\n        var ob = lb.parentNode.offsetWidth, pb = Math.round(((((ob * nb.offset_percent)) / 100)));\n        if (((nb.side === \"left\"))) {\n            pb = ((pb + nb.side_margin));\n        }\n         else if (((nb.side === \"right\"))) {\n            pb = ((((((ob - pb)) - nb.side_margin)) - 18));\n        }\n        \n    ;\n    ;\n        return pb;\n    };\n;\n    function ab(lb, mb, nb) {\n        l.addClass(nb.root, \"usingMask\");\n        var ob = za(lb, mb, nb);\n        lb.style.webkitMaskPositionX = ((ob + \"px\"));\n        mb.style.left = ((ob + \"px\"));\n    };\n;\n    function bb(lb, mb, nb) {\n        var ob = n.scry(lb, \".CoverPhoto\")[0];\n        if (!ob) {\n            return;\n        }\n    ;\n    ;\n        var pb = ya(lb);\n        if (!pb) {\n            return;\n        }\n    ;\n    ;\n        l.addClass(nb.root, \"usingRotate\");\n        var qb = ((za(lb, mb, nb) + 9)), rb = Math.ceil(((qb / Math.SQRT2)));\n        ob.style[pb] = ((((((((\"translate(\" + (-rb))) + \"px, \")) + rb)) + \"px) rotate(-45deg)\"));\n        lb.style[pb] = ((((\"translate(\" + qb)) + \"px, 0) rotate(45deg)\"));\n    };\n;\n    function cb() {\n        var lb = v.getViewportDimensions(), mb = v.getElementPosition(da, \"viewport\"), nb = mb.convertTo(\"JSBNG__document\"), ob = fb(da), pb = \"above\", qb = \"left\", rb = eb(nb, ob, \"above\");\n        if (((((mb.y + rb)) <= aa))) {\n            var sb = eb(nb, ob, \"below\");\n            if (((((((((mb.y + sb)) + da.offsetHeight)) + aa)) < lb.y))) {\n                pb = \"below\";\n                rb = sb;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        var tb = ((lb.x - w.getRight())), ub = db(nb, ob, \"left\");\n        if (((((((mb.x + ub)) + z)) >= tb))) {\n            var vb = db(nb, ob, \"right\");\n            if (((((((mb.x + vb)) + da.offsetWidth)) > z))) {\n                qb = \"right\";\n                ub = vb;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        fa.setPosition(pb).setAlignH(qb).setOffsetX(ub).setOffsetY(rb);\n    };\n;\n    function db(lb, mb, nb) {\n        if (((nb == \"left\"))) {\n            return ((mb.l - lb.x));\n        }\n    ;\n    ;\n        return ((mb.r - ((lb.x + da.offsetWidth))));\n    };\n;\n    function eb(lb, mb, nb) {\n        if (((nb == \"above\"))) {\n            return ((mb.t - lb.y));\n        }\n    ;\n    ;\n        return ((mb.b - ((lb.y + da.offsetHeight))));\n    };\n;\n    function fb(lb) {\n        var mb = ca.pos, nb = lb.getClientRects();\n        if (((!mb || ((nb.length === 0))))) {\n            return s.getElementBounds(lb);\n        }\n    ;\n    ;\n        var ob, pb = false;\n        for (var qb = 0; ((qb < nb.length)); qb++) {\n            var rb = new s(Math.round(nb[qb].JSBNG__top), Math.round(nb[qb].right), Math.round(nb[qb].bottom), Math.round(nb[qb].left), \"viewport\").convertTo(\"JSBNG__document\"), sb = rb.getPositionVector(), tb = sb.add(rb.getDimensionVector());\n            if (((!ob || ((((sb.x <= ob.l)) && ((sb.y > ob.t))))))) {\n                if (pb) {\n                    break;\n                }\n            ;\n            ;\n                ob = new s(sb.y, tb.x, tb.y, sb.x, \"JSBNG__document\");\n            }\n             else {\n                ob.t = Math.min(ob.t, sb.y);\n                ob.b = Math.max(ob.b, tb.y);\n                ob.r = tb.x;\n            }\n        ;\n        ;\n            if (rb.contains(mb)) {\n                pb = true;\n            }\n        ;\n        ;\n        };\n    ;\n        return ob;\n    };\n;\n    function gb(lb) {\n        if (((lb.id && ((ba[lb.id] != null))))) {\n            return;\n        }\n    ;\n    ;\n        var mb = sa(lb);\n        if (((ba[mb] != null))) {\n            return;\n        }\n    ;\n    ;\n        hb(mb);\n        var nb = function() {\n            kb.dirty(mb);\n            va();\n        };\n        new i(mb).setData({\n            endpoint: mb\n        }).setMethod(\"GET\").setReadOnly(true).setErrorHandler(nb).setTransportErrorHandler(nb).send();\n    };\n;\n    function hb(lb) {\n        ba[lb] = false;\n    };\n;\n    var ib = function() {\n        var lb = new k({\n        }, m.create(\"div\", {\n            className: \"HovercardLoading\"\n        }, \"Loading...\"));\n        lb.disableBehavior(g).disableBehavior(o).disableBehavior(q).disableBehavior(p);\n        jb(lb);\n        ib = bagof(lb);\n        return lb;\n    };\n    function jb(lb) {\n        lb.subscribe(\"mouseenter\", function() {\n            JSBNG__clearTimeout(na);\n            ea = ca.node;\n        });\n        lb.subscribe(\"mouseleave\", function() {\n            kb.hide(false);\n            ea = null;\n        });\n    };\n;\n    var kb = {\n        hide: function(lb) {\n            if (!da) {\n                return;\n            }\n        ;\n        ;\n            if (lb) {\n                if (fa) {\n                    h.inform(\"layer_hidden\", {\n                        type: \"Hovercard\"\n                    });\n                    h.inform(\"Hovercard/hide\", {\n                        node: da\n                    });\n                    fa.hide();\n                }\n            ;\n            ;\n                ea = null;\n                da = null;\n                fa = null;\n            }\n             else na = JSBNG__setTimeout(kb.hide.curry(true), ja);\n        ;\n        ;\n        },\n        setDialog: function(lb, mb) {\n            mb.disableBehavior(g);\n            ba[lb] = mb;\n            jb(mb);\n            if (((((ca.endpoint == lb)) && ((ea == ca.node))))) {\n                wa(mb);\n            }\n        ;\n        ;\n        },\n        getDialog: function(lb) {\n            return ba[lb];\n        },\n        contains: function(lb) {\n            if (fa) {\n                return m.contains(fa.getRoot(), lb);\n            }\n        ;\n        ;\n            return false;\n        },\n        dirty: function(lb) {\n            var mb = ba[lb];\n            if (mb) {\n                mb.destroy();\n                delete ba[lb];\n            }\n        ;\n        ;\n        },\n        dirtyAll: function() {\n            for (var lb in ba) {\n                var mb = ba[lb];\n                ((mb && kb.dirty(lb)));\n            };\n        ;\n            h.inform(\"Hovercard/dirty\");\n        },\n        processNode: function(lb) {\n            if (((lb && qa(lb)))) {\n                ta(lb);\n                return true;\n            }\n        ;\n        ;\n            return false;\n        }\n    };\n    if (!a.Hovercard) {\n        oa();\n    }\n     else kb = a.Hovercard;\n;\n;\n    e.exports = kb;\n    a.Hovercard = e.exports;\n});\n__d(\"legacy:array-utils\", [\"createArrayFrom\",\"hasArrayNature\",], function(a, b, c, d) {\n    a.$A = b(\"createArrayFrom\");\n    a.hasArrayNature = b(\"hasArrayNature\");\n}, 3);\n__d(\"legacy:env\", [\"Env\",], function(a, b, c, d) {\n    var e = b(\"Env\");\n    a.Env = e;\n}, 3);\n__d(\"legacy:page-transitions\", [\"computeRelativeURI\",\"HistoryManager\",\"PageTransitions\",], function(a, b, c, d) {\n    a.computeRelativeURI = b(\"computeRelativeURI\");\n    a.HistoryManager = ((a.HistoryManager || b(\"HistoryManager\")));\n    a.PageTransitions = ((a.PageTransitions || b(\"PageTransitions\")));\n}, 3);\n__d(\"FlipDirectionOnKeypress\", [\"event-extensions\",\"DOM\",\"Input\",\"Style\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"DOM\"), h = b(\"Input\"), i = b(\"Style\");\n    JSBNG__Event.listen(JSBNG__document.documentElement, \"keyup\", function(JSBNG__event) {\n        var j = JSBNG__event.getTarget();\n        if (!g.isNodeOfType(j, [\"input\",\"textarea\",])) {\n            return;\n        }\n    ;\n    ;\n        if (((g.isNodeOfType(j, \"input\") && ((j.type == \"password\"))))) {\n            return;\n        }\n    ;\n    ;\n        if (j.getAttribute(\"data-prevent-auto-flip\")) {\n            return;\n        }\n    ;\n    ;\n        var k = h.getValue(j), l = ((j.style && j.style.direction));\n        if (!l) {\n            var m = 0, n = true;\n            for (var o = 0; ((o < k.length)); o++) {\n                var p = k.charCodeAt(o);\n                if (((p >= 48))) {\n                    if (n) {\n                        n = false;\n                        m++;\n                    }\n                ;\n                ;\n                    if (((((p >= 1470)) && ((p <= 1920))))) {\n                        i.set(j, \"direction\", \"rtl\");\n                        return;\n                    }\n                ;\n                ;\n                    if (((m == 5))) {\n                        i.set(j, \"direction\", \"ltr\");\n                        return;\n                    }\n                ;\n                ;\n                }\n                 else n = true;\n            ;\n            ;\n            };\n        ;\n        }\n         else if (((k.length === 0))) {\n            i.set(j, \"direction\", \"\");\n        }\n        \n    ;\n    ;\n    });\n});\n__d(\"PlaceholderOnsubmitFormListener\", [\"event-extensions\",\"Input\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Input\");\n    JSBNG__Event.listen(JSBNG__document.documentElement, \"submit\", function(h) {\n        var i = h.getTarget().getElementsByTagName(\"*\");\n        for (var j = 0; ((j < i.length)); j++) {\n            if (((i[j].getAttribute(\"placeholder\") && g.isEmpty(i[j])))) {\n                g.setValue(i[j], \"\");\n            }\n        ;\n        ;\n        };\n    ;\n    });\n});\n__d(\"RequiredFormListener\", [\"event-extensions\",\"Input\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Input\");\n    JSBNG__Event.listen(JSBNG__document.documentElement, \"submit\", function(h) {\n        var i = h.getTarget().getElementsByTagName(\"*\");\n        for (var j = 0; ((j < i.length)); j++) {\n            if (((i[j].getAttribute(\"required\") && g.isEmpty(i[j])))) {\n                i[j].JSBNG__focus();\n                return false;\n            }\n        ;\n        ;\n        };\n    ;\n    }, JSBNG__Event.Priority.URGENT);\n});\n__d(\"Live\", [\"Arbiter\",\"AsyncDOM\",\"AsyncSignal\",\"ChannelConstants\",\"DOM\",\"DataStore\",\"ServerJS\",\"createArrayFrom\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AsyncDOM\"), i = b(\"AsyncSignal\"), j = b(\"ChannelConstants\"), k = b(\"DOM\"), l = b(\"DataStore\"), m = b(\"ServerJS\"), n = b(\"createArrayFrom\");\n    function o(q, r) {\n        r = JSON.parse(JSON.stringify(r));\n        new m().setRelativeTo(q).handle(r);\n    };\n;\n    var p = {\n        logAll: false,\n        startup: function() {\n            p.startup = bagofholding;\n            g.subscribe(j.getArbiterType(\"live\"), p.handleMessage.bind(p));\n        },\n        lookupLiveNode: function(q, r) {\n            var s = k.scry(JSBNG__document.body, ((((((\".live_\" + q)) + \"_\")) + r)));\n            s.forEach(function(t) {\n                if (((l.get(t, \"seqnum\") === undefined))) {\n                    var u = JSON.parse(t.getAttribute(\"data-live\"));\n                    l.set(t, \"seqnum\", u.seq);\n                }\n            ;\n            ;\n            });\n            return s;\n        },\n        handleMessage: function(q, r) {\n            var s = r.obj, t = s.fbid, u = s.assoc, v = this.lookupLiveNode(t, u);\n            if (!v) {\n                return false;\n            }\n        ;\n        ;\n            v.forEach(function(w) {\n                if (s.expseq) {\n                    var x = l.get(w, \"seqnum\"), y = l.get(w, \"message_buffer\");\n                    if (((y === undefined))) {\n                        y = {\n                        };\n                        l.set(w, \"message_buffer\", y);\n                    }\n                ;\n                ;\n                    var z = {\n                        obj: s\n                    };\n                    y[s.expseq] = z;\n                    if (((s.expseq != x))) {\n                        p.log(\"mismatch\", s.fbid, s.expseq, x);\n                        return false;\n                    }\n                ;\n                ;\n                    while (true) {\n                        x = l.get(w, \"seqnum\");\n                        var aa = y[x];\n                        if (aa) {\n                            h.invoke(aa.obj.updates, w);\n                            if (aa.obj.js) {\n                                o(w, aa.obj.js);\n                            }\n                        ;\n                        ;\n                            p.log(\"seqmatch\", s.fbid, \"exp\", s.expseq, \"cur\", x);\n                            delete y[x];\n                        }\n                         else break;\n                    ;\n                    ;\n                    };\n                ;\n                }\n                 else {\n                    h.invoke(s.updates, w);\n                    if (s.js) {\n                        o(w, s.js);\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            });\n        },\n        log: function() {\n            if (p.logAll) {\n                var q = n(arguments).join(\":\");\n                new i(\"/common/scribe_endpoint.php\", {\n                    c: \"live_sequence\",\n                    m: q\n                }).send();\n            }\n        ;\n        ;\n        }\n    };\n    e.exports = p;\n});\n__d(\"legacy:live-js\", [\"Live\",], function(a, b, c, d) {\n    a.Live = b(\"Live\");\n}, 3);\n__d(\"legacy:JSLogger\", [\"JSLogger\",], function(a, b, c, d) {\n    a.JSLogger = b(\"JSLogger\");\n}, 3);\n__d(\"RenderManager\", [\"function-extensions\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"copyProperties\");\n    function h(i) {\n        this._isDirty = false;\n        this._obj = i;\n    };\n;\n    g(h.prototype, {\n        dirty: function() {\n            if (!this._isDirty) {\n                this._isDirty = true;\n                this._doPaint.bind(this).defer();\n            }\n        ;\n        ;\n        },\n        _doPaint: function() {\n            this._isDirty = false;\n            this._obj.paint();\n        }\n    });\n    e.exports = h;\n});\n__d(\"CounterDisplay\", [\"Arbiter\",\"CSS\",\"DOM\",\"RenderManager\",\"Run\",\"$\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"RenderManager\"), k = b(\"Run\"), l = b(\"$\"), m = b(\"copyProperties\");\n    function n(o, p, q, r, s, t) {\n        m(this, {\n            _name: o,\n            _valueNode: l(p),\n            _wrapperNode: ((l(q) || null)),\n            _statusClass: s,\n            _rm: new j(this),\n            _arbiterSubscription: null,\n            _count: 0\n        });\n        var u = this._valueNode.firstChild;\n        if (u) {\n            var v = parseInt(u.nodeValue, 10);\n            if (!isNaN(v)) {\n                this._count = v;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        this._statusNode = ((r ? l(r) : null));\n        this._subscribeAll();\n        n.instances.push(this);\n        if (!t) {\n            k.JSBNG__onLeave(this._destroy.bind(this), true);\n        }\n    ;\n    ;\n    };\n;\n    m(n, {\n        EVENT_TYPE_ADJUST: \"CounterDisplay/adjust\",\n        EVENT_TYPE_UPDATE: \"CounterDisplay/update\",\n        instances: [],\n        adjustCount: function(o, p) {\n            g.inform(((((n.EVENT_TYPE_ADJUST + \"/\")) + o)), p);\n        },\n        setCount: function(o, p) {\n            g.inform(((((n.EVENT_TYPE_UPDATE + \"/\")) + o)), p);\n        }\n    });\n    m(n.prototype, {\n        _destroy: function() {\n            delete this._valueNode;\n            delete this._wrapperNode;\n            if (this._arbiterSubscription) {\n                this._arbiterSubscription.unsubscribe();\n                delete this._arbiterSubscription;\n            }\n        ;\n        ;\n            n.instances.remove(this);\n        },\n        adjustCount: function(o) {\n            this._count = Math.max(0, ((this._count + o)));\n            this._rm.dirty();\n            return this;\n        },\n        setCount: function(o) {\n            this._count = Math.max(0, o);\n            this._rm.dirty();\n            return this;\n        },\n        paint: function() {\n            i.setContent(this._valueNode, this._count);\n            this._toggleNodes();\n        },\n        _toggleNodes: function() {\n            if (this._wrapperNode) {\n                h.conditionClass(this._wrapperNode, \"hidden_elem\", ((this._count <= 0)));\n            }\n        ;\n        ;\n            if (((this._statusClass && this._statusNode))) {\n                h.conditionClass(this._statusNode, this._statusClass, ((this._count > 0)));\n            }\n        ;\n        ;\n        },\n        _subscribeAll: function() {\n            var o = [((((n.EVENT_TYPE_ADJUST + \"/\")) + this._name)),((((n.EVENT_TYPE_UPDATE + \"/\")) + this._name)),];\n            this._arbiterSubscription = g.subscribe(o, this._onInform.bind(this), g.SUBSCRIBE_NEW);\n        },\n        _onInform: function(o, p) {\n            p = parseInt(p);\n            if (isNaN(p)) {\n                return;\n            }\n        ;\n        ;\n            if (((o.indexOf(n.EVENT_TYPE_ADJUST) != -1))) {\n                this.adjustCount(p);\n            }\n             else if (((o.indexOf(n.EVENT_TYPE_UPDATE) != -1))) {\n                this.setCount(p);\n            }\n             else return\n            \n        ;\n            return;\n        }\n    });\n    e.exports = n;\n});\n__d(\"Amoeba\", [\"Run\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Run\"), h = b(\"copyProperties\"), i = {\n    };\n    h(i, {\n        _instrumentQueue: [],\n        _logger: null,\n        instrument: function(j, k) {\n            if (i._logger) {\n                i._logger.instrument(j, k);\n            }\n             else i._instrumentQueue.push([j,k,]);\n        ;\n        ;\n        },\n        flushQueue: function(j) {\n            if (j) {\n                i._instrumentQueue.map(j);\n            }\n        ;\n        ;\n            i._instrumentQueue = [];\n        },\n        setLogger: function(j) {\n            i._logger = j;\n        }\n    });\n    g.JSBNG__onLeave(function() {\n        i.flushQueue(null);\n    });\n    e.exports = i;\n});\n__d(\"cx\", [], function(a, b, c, d, e, f) {\n    function g(h) {\n        throw new Error(\"cx(...): Unexpected class transformation.\");\n    };\n;\n    e.exports = g;\n});\n__d(\"ModalLayer\", [\"event-extensions\",\"CSS\",\"DOMQuery\",\"ScrollAwareDOM\",\"Style\",\"URI\",\"UserAgent\",\"Vector\",\"copyProperties\",\"csx\",\"debounce\",\"ge\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"CSS\"), h = b(\"DOMQuery\"), i = b(\"ScrollAwareDOM\"), j = b(\"Style\"), k = b(\"URI\"), l = b(\"UserAgent\"), m = b(\"Vector\"), n = b(\"copyProperties\"), o = b(\"csx\"), p = b(\"debounce\"), q = b(\"ge\"), r = 0, s = null, t = null;\n    function u() {\n        if (!t) {\n            t = h.scry(JSBNG__document.body, \".-cx-PRIVATE-fbLayout__root\")[0];\n        }\n    ;\n    ;\n        return t;\n    };\n;\n    function v() {\n        h.scry(JSBNG__document.body, \"div.swfObject\").forEach(function(x) {\n            var y = x.getAttribute(\"data-swfid\");\n            if (((y && window[y]))) {\n                var z = window[y];\n                z.addParam(\"autostart\", \"false\");\n                z.addParam(\"autoplay\", \"false\");\n                z.addParam(\"play\", \"false\");\n                z.addVariable(\"video_autoplay\", \"0\");\n                z.addVariable(\"autoplay\", \"0\");\n                z.addVariable(\"play\", \"0\");\n                var aa = k(z.getAttribute(\"swf\"));\n                aa.addQueryData({\n                    autoplay: \"0\"\n                });\n                aa.setPath(aa.getPath().replace(\"autoplay=1\", \"autoplay=0\"));\n                z.setAttribute(\"swf\", aa.toString());\n                z.write(x);\n            }\n        ;\n        ;\n        });\n    };\n;\n    function w(x) {\n        this._layer = x;\n    };\n;\n    n(w.prototype, {\n        _subscription: null,\n        _resizeListener: null,\n        enable: function() {\n            if (!u()) {\n                return;\n            }\n        ;\n        ;\n            this._subscription = this._layer.subscribe([\"show\",\"hide\",], function(x) {\n                ((((x == \"show\")) ? this._addModal() : this._removeModal()));\n            }.bind(this));\n            if (this._layer.isShown()) {\n                this._addModal();\n            }\n        ;\n        ;\n        },\n        disable: function() {\n            if (!u()) {\n                return;\n            }\n        ;\n        ;\n            this._subscription.unsubscribe();\n            this._subscription = null;\n            if (this._layer.isShown()) {\n                this._removeModal();\n            }\n        ;\n        ;\n        },\n        _addModal: function() {\n            g.addClass(this._layer.getRoot(), \"modalWrapper\");\n            if (((r++ === 0))) {\n                s = m.getScrollPosition();\n                var x = u(), y = ((x.offsetTop - s.y));\n                j.set(x, \"JSBNG__top\", ((y + \"px\")));\n                g.addClass(JSBNG__document.documentElement, \"modalOpen\");\n                if (((l.ie() < 7))) {\n                    var z = this._layer.getRoot(), aa = function() {\n                        var ca = ((-y + Math.max(z.offsetHeight, z.scrollHeight)));\n                        j.set(x, \"height\", ((ca + \"px\")));\n                    };\n                    aa();\n                    this._resizeListener = JSBNG__Event.listen(window, \"resize\", p(aa, 100));\n                }\n            ;\n            ;\n                var ba = h.getDocumentScrollElement();\n                ba.scrollTop = 0;\n                this._scrollSubscription = i.subscribe(\"JSBNG__scroll\", function(ca, da) {\n                    var ea = ((x.offsetTop - da.delta.y));\n                    j.set(x, \"JSBNG__top\", ((ea + \"px\")));\n                    s = s.add(da.delta);\n                    return false;\n                });\n                if (((l.firefox() < 13))) {\n                    v.defer();\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        _removeModal: function() {\n            g.removeClass(this._layer.getRoot(), \"modalWrapper\");\n            if (((--r === 0))) {\n                g.removeClass(JSBNG__document.documentElement, \"modalOpen\");\n                var x = u();\n                j.set(x, \"JSBNG__top\", \"\");\n                if (((l.ie() < 7))) {\n                    j.set(x, \"height\", \"\");\n                    this._resizeListener.remove();\n                    this._resizeListener = null;\n                }\n            ;\n            ;\n                var y = h.getDocumentScrollElement();\n                y.scrollTop = s.y;\n                this._scrollSubscription.unsubscribe();\n                this._scrollSubscription = null;\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = w;\n});\n__d(\"DialogX\", [\"event-extensions\",\"function-extensions\",\"AccessibleLayer\",\"Arbiter\",\"ArbiterMixin\",\"Class\",\"DOM\",\"Layer\",\"LayerButtons\",\"LayerFormHooks\",\"ModalLayer\",\"Parent\",\"Style\",\"UserAgent\",\"Vector\",\"copyProperties\",\"cx\",\"debounce\",\"getOverlayZIndex\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"AccessibleLayer\"), h = b(\"Arbiter\"), i = b(\"ArbiterMixin\"), j = b(\"Class\"), k = b(\"DOM\"), l = b(\"Layer\"), m = b(\"LayerButtons\"), n = b(\"LayerFormHooks\"), o = b(\"ModalLayer\"), p = b(\"Parent\"), q = b(\"Style\"), r = b(\"UserAgent\"), s = b(\"Vector\"), t = b(\"copyProperties\"), u = b(\"cx\"), v = b(\"debounce\"), w = b(\"getOverlayZIndex\");\n    function x(z, aa) {\n        this.parent.construct(this, z, aa);\n    };\n;\n    j.extend(x, l);\n    t(x, i);\n    t(x.prototype, {\n        _modal: false,\n        _ie: null,\n        _wrapper: null,\n        _configure: function(z, aa) {\n            this.parent._configure(z, aa);\n            if (z.modal) {\n                this._modal = true;\n                this.enableBehavior(o);\n            }\n        ;\n        ;\n            if (z.autohide) {\n                var ba = this.subscribe(\"show\", function() {\n                    ba.unsubscribe();\n                    this.hide.shield(this).defer(z.autohide);\n                }.bind(this));\n            }\n        ;\n        ;\n        },\n        _getDefaultBehaviors: function() {\n            return this.parent._getDefaultBehaviors().concat([y,g,m,n,]);\n        },\n        _buildWrapper: function(z, aa) {\n            var ba = k.create(\"div\", {\n                className: \"-cx-PRIVATE-uiDialog__content\"\n            }, aa), ca;\n            this._ie = r.ie();\n            if (((((this._ie > 6)) && ((this._ie < 9))))) {\n                ca = [k.create(\"div\", {\n                    className: \"-cx-PRIVATE-uiDialog__vertical\"\n                }),k.create(\"div\", {\n                    className: \"-cx-PRIVATE-uiDialog__horizontal\"\n                }),k.create(\"div\", {\n                    className: \"-cx-PRIVATE-uiDialog__topLeft\"\n                }),k.create(\"div\", {\n                    className: \"-cx-PRIVATE-uiDialog__topRight\"\n                }),k.create(\"div\", {\n                    className: \"-cx-PRIVATE-uiDialog__bottomLeft\"\n                }),k.create(\"div\", {\n                    className: \"-cx-PRIVATE-uiDialog__bottomRight\"\n                }),ba,];\n            }\n             else ca = k.create(\"div\", {\n                className: \"-cx-PUBLIC-uiDialog__border\"\n            }, ba);\n        ;\n        ;\n            this._wrapper = k.create(\"div\", {\n                className: \"-cx-PUBLIC-uiDialog__wrapper\"\n            }, ca);\n            this.setWidth(z.width);\n            var da = \"-cx-PRIVATE-uiDialog__positioner\";\n            if (z.className) {\n                da += ((\" \" + z.className));\n            }\n        ;\n        ;\n            var ea = k.create(\"div\", {\n                className: da\n            }, this._wrapper);\n            if (z.id) {\n                ea.id = z.id;\n            }\n        ;\n        ;\n            return ea;\n        },\n        _getContentRoot: function() {\n            return this._wrapper;\n        },\n        updatePosition: function() {\n            var z = ((s.getViewportDimensions().y - s.getElementDimensions(this._wrapper).y)), aa;\n            if (((z < 250))) {\n                if (((z > 80))) {\n                    aa = ((z / 2));\n                }\n                 else aa = 40;\n            ;\n            ;\n            }\n             else aa = 125;\n        ;\n        ;\n            if (((!this._modal && ((!this._ie || ((this._ie < 7))))))) {\n                if (((aa <= 40))) {\n                    this.enableBehavior(o);\n                }\n                 else this.disableBehavior(o);\n            ;\n            }\n        ;\n        ;\n            if (((this._ie < 7))) {\n                var ba = s.getScrollPosition().y;\n                q.set(this._wrapper, \"JSBNG__top\", ((((aa + ba)) + \"px\")));\n            }\n             else q.set(this._wrapper, \"margin-top\", ((aa + \"px\")));\n        ;\n        ;\n            if (this._causalElement) {\n                var ca = w(this._causalElement, this.getInsertParent());\n                q.set(this.getRoot(), \"z-index\", ((((ca > 200)) ? ca : \"\")));\n            }\n        ;\n        ;\n        },\n        setWidth: function(z) {\n            z = Math.floor(z);\n            if (((((this._ie > 6)) && ((this._ie < 9))))) {\n                z -= 20;\n            }\n        ;\n        ;\n            q.set(this._wrapper, \"width\", ((z + \"px\")));\n        }\n    });\n    function y(z) {\n        this._layer = z;\n    };\n;\n    t(y.prototype, {\n        _subscription: null,\n        _resize: null,\n        enable: function() {\n            this._subscription = this._layer.subscribe([\"show\",\"hide\",], function(z) {\n                if (((z === \"show\"))) {\n                    this._attach();\n                    h.inform(\"layer_shown\", {\n                        type: \"DialogX\"\n                    });\n                }\n                 else {\n                    this._detach();\n                    h.inform(\"layer_hidden\", {\n                        type: \"DialogX\"\n                    });\n                }\n            ;\n            ;\n            }.bind(this));\n        },\n        disable: function() {\n            this._subscription.unsubscribe();\n            this._subscription = null;\n            ((this._resize && this._detach()));\n        },\n        _attach: function() {\n            this._layer.updatePosition();\n            this._resize = JSBNG__Event.listen(window, \"resize\", v(this._layer.updatePosition.bind(this._layer)));\n        },\n        _detach: function() {\n            this._resize.remove();\n            this._resize = null;\n        }\n    });\n    e.exports = x;\n});\n__d(\"AsyncDialog\", [\"AsyncRequest\",\"Bootloader\",\"copyProperties\",\"CSS\",\"cx\",\"DialogX\",\"DOM\",\"Env\",\"Parent\",\"tx\",\"URI\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncRequest\"), h = b(\"Bootloader\"), i = b(\"copyProperties\"), j = b(\"CSS\"), k = b(\"cx\"), l = b(\"DialogX\"), m = b(\"DOM\"), n = b(\"Env\"), o = b(\"Parent\"), p = b(\"tx\"), q = b(\"URI\"), r = new l({\n        width: 465,\n        className: \"-cx-PRIVATE-uiDialog__loadingDialog\"\n    }, m.create(\"div\", {\n        className: \"-cx-PRIVATE-uiDialog__loadingText\"\n    }, \"Loading...\")), s = 1, t = [], u = 0;\n    function v() {\n        u--;\n        if (!u) {\n            r.hide();\n        }\n    ;\n    ;\n    };\n;\n    function w(y, z) {\n        var aa = s++;\n        t[aa] = z;\n        i(y.getData(), {\n            __asyncDialog: aa\n        });\n        var ba = false;\n        u++;\n        r.show();\n        function ca() {\n            if (!ba) {\n                v();\n            }\n        ;\n        ;\n        };\n    ;\n        y.setInterceptHandler(function(da) {\n            ba = true;\n            v();\n        });\n        y.setFinallyHandler(function(da) {\n            var ea = da.getPayload();\n            if (((ea && ea.asyncURL))) {\n                x.send(new g(ea.asyncURL));\n            }\n        ;\n        ;\n            ca();\n        });\n        y.setAbortHandler(ca);\n        y.send();\n    };\n;\n    var x = {\n        send: function(y, z) {\n            w(y, ((z || bagofholding)));\n        },\n        bootstrap: function(y, z, aa) {\n            if (!y) {\n                return;\n            }\n        ;\n        ;\n            var ba = ((o.byClass(z, \"stat_elem\") || z));\n            if (((ba && j.hasClass(ba, \"async_saving\")))) {\n                return false;\n            }\n        ;\n        ;\n            var ca = new q(y).getQueryData();\n            ca.causal_element = ((z ? m.getID(z) : null));\n            var da = ((aa === \"dialog\")), ea = new g().setURI(y).setData(ca).setMethod(((da ? \"GET\" : \"POST\"))).setReadOnly(da).setRelativeTo(z).setStatusElement(ba).setNectarModuleDataSafe(z);\n            if (n.is_desktop) {\n                h.loadModules([\"FbdDialogProvider\",], function(fa) {\n                    fa.sendDialog(ea, x.send);\n                });\n                return;\n            }\n        ;\n        ;\n            x.send(ea);\n        },\n        respond: function(y, z) {\n            var aa = t[y];\n            if (aa) {\n                aa(z);\n                delete t[y];\n            }\n        ;\n        ;\n        },\n        getLoadingDialog: function() {\n            return r;\n        }\n    };\n    e.exports = x;\n});\n__d(\"AsyncLayout\", [\"AjaxPipeRequest\",\"Arbiter\",\"AsyncResponse\",\"AsyncRequest\",\"CSS\",\"DOM\",\"HTML\",\"NavigationMessage\",\"PageTransitions\",\"URI\",\"$\",\"copyProperties\",\"ge\",\"goURI\",], function(a, b, c, d, e, f) {\n    var g = b(\"AjaxPipeRequest\"), h = b(\"Arbiter\"), i = b(\"AsyncResponse\"), j = b(\"AsyncRequest\"), k = b(\"CSS\"), l = b(\"DOM\"), m = b(\"HTML\"), n = b(\"NavigationMessage\"), o = b(\"PageTransitions\"), p = b(\"URI\"), q = b(\"$\"), r = b(\"copyProperties\"), s = b(\"ge\"), t = b(\"goURI\");\n    function u(v) {\n        this.canvasID = v;\n        if (s(\"rightCol\")) {\n            this.auxiliaryID = \"rightCol\";\n        }\n    ;\n    ;\n        if (s(\"headerArea\")) {\n            this.headerID = \"headerArea\";\n        }\n    ;\n    ;\n        if (s(\"toolbarContainer\")) {\n            this.toolbarID = \"toolbarContainer\";\n        }\n    ;\n    ;\n        this.waitingForAux = false;\n        o.registerHandler(this.catchPageTransition.bind(this));\n        this.subscription = h.subscribe(n.NAVIGATION_BEGIN, this.JSBNG__onNavigate.bind(this));\n    };\n;\n    r(u.prototype, {\n        catchPageTransition: function(v) {\n            this.subscription.unsubscribe();\n            return false;\n        },\n        getCanvasID: function(v) {\n            return ((v.sidecol ? \"contentCol\" : \"contentArea\"));\n        },\n        JSBNG__onNavigate: function(v, w) {\n            var x = w.useAjaxPipe;\n            w = w.params;\n            if (w.endpoint) {\n                if (this.request) {\n                    this.request.setFinallyHandler(bagofholding);\n                    this.request.abort();\n                }\n            ;\n            ;\n                if (this.sideRequest) {\n                    this.sideRequest.abort();\n                }\n            ;\n            ;\n                if (x) {\n                    this.request = new g().setURI(w.endpoint).setData(w).setCanvasId(this.getCanvasID(w)).setFinallyHandler(this.finallyHandler.bind(this)).setErrorHandler(this.errorHandler.bind(this)).setFirstResponseCallback(this.firstResponseCallback.bind(this)).send();\n                }\n                 else {\n                    w.handled = true;\n                    this.waitingForAux = w.sidecol;\n                    var y = !!w.iframe, z = new j().setOption(\"useIframeTransport\", y).setURI(new p(w.endpoint)).setReadOnly(true).setMethod(\"GET\").setData(w).setHandler(this.JSBNG__onResponse.bind(this)).setErrorHandler(this.errorHandler.bind(this)).setFinallyHandler(this.finallyHandler.bind(this));\n                    this.request = z;\n                    z.send();\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        JSBNG__onSideResponse: function(v) {\n            var w = v.getPayload();\n            if (((w && this.auxiliaryID))) {\n                this.receivedAux(w);\n            }\n        ;\n        ;\n        },\n        receivedAux: function(v) {\n            !this.waitingForAux;\n            this.waitingForAux = false;\n            l.setContent(q(this.auxiliaryID), m(v));\n        },\n        JSBNG__onResponse: function(v) {\n            var w = v.getPayload();\n            if (w.redirect) {\n                t(w.redirect);\n            }\n             else {\n                var x = ((w.html || w));\n                l.setContent(q(this.canvasID), m(x));\n                if (((w.side_html && this.auxiliaryID))) {\n                    this.receivedAux(w.side_html);\n                }\n            ;\n            ;\n                if (((this.headerID && !w.keep_header))) {\n                    var y = q(this.headerID);\n                    l.setContent(y, m(((w.header_html || \"\"))));\n                    k.conditionShow(y, w.header_html);\n                }\n            ;\n            ;\n                if (((w.toolbar_html && this.toolbarID))) {\n                    l.setContent(q(this.toolbarID), m(w.toolbar_html));\n                }\n            ;\n            ;\n                if (w.js) {\n                    (new Function(w.js))();\n                }\n            ;\n            ;\n                k.conditionClass(\"contentCol\", \"hasRightCol\", ((this.auxiliaryID && !w.noRightSide)));\n                var z = s(\"rightCol\");\n                if (((z && w.noRightSide))) {\n                    l.empty(z);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            var aa = v.getRequest().getData();\n            h.inform(n.NAVIGATION_COMPLETED, aa.key);\n        },\n        errorHandler: function(v) {\n            i.verboseErrorHandler(v);\n            h.inform(n.NAVIGATION_FAILED);\n            this.request = null;\n        },\n        firstResponseCallback: function(v) {\n            window.JSBNG__scrollTo(0, 0);\n            h.inform(n.NAVIGATION_FIRST_RESPONSE);\n        },\n        finallyHandler: function(v) {\n            this.request = null;\n            o.transitionComplete(true);\n            h.inform(n.NAVIGATION_COMPLETED);\n        }\n    });\n    e.exports = u;\n});\n__d(\"ContextualLayer\", [\"array-extensions\",\"event-extensions\",\"Arbiter\",\"ARIA\",\"Class\",\"ContextualThing\",\"CSS\",\"DataStore\",\"DOM\",\"Layer\",\"LayerHideOnTransition\",\"Locale\",\"Parent\",\"Style\",\"Vector\",\"copyProperties\",\"getOverlayZIndex\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ARIA\"), i = b(\"Class\"), j = b(\"ContextualThing\"), k = b(\"CSS\"), l = b(\"DataStore\"), m = b(\"DOM\"), n = b(\"Layer\"), o = b(\"LayerHideOnTransition\"), p = b(\"Locale\"), q = b(\"Parent\"), r = b(\"Style\"), s = b(\"Vector\"), t = b(\"copyProperties\"), u = b(\"getOverlayZIndex\");\n    function v(aa) {\n        return ((((aa.getPosition() === \"left\")) || ((aa.isVertical() && ((aa.getAlignment() === \"right\"))))));\n    };\n;\n    function w(aa) {\n        var ba = aa.offsetParent;\n        if (((((ba === JSBNG__document.body)) && ((r.get(ba, \"position\") === \"static\"))))) {\n            ba = JSBNG__document.documentElement;\n        }\n    ;\n    ;\n        return ba;\n    };\n;\n    function x(aa, ba) {\n        this.parent.construct(this, aa, ba);\n    };\n;\n    var y = [];\n    g.subscribe(\"reflow\", function() {\n        y.forEach(function(aa) {\n            if (((aa.updatePosition() === false))) {\n                aa.hide();\n            }\n        ;\n        ;\n        });\n    });\n    i.extend(x, n);\n    t(x.prototype, {\n        _contentWrapper: null,\n        _content: null,\n        _contextNode: null,\n        _contextSelector: null,\n        _parentLayer: null,\n        _parentSubscription: null,\n        _orientation: null,\n        _orientationClass: null,\n        _configure: function(aa, ba) {\n            this.parent._configure(aa, ba);\n            if (aa.context) {\n                this.setContext(aa.context);\n            }\n             else if (aa.contextID) {\n                this._setContextID(aa.contextID);\n            }\n             else if (aa.contextSelector) {\n                this._setContextSelector(aa.contextSelector);\n            }\n            \n            \n        ;\n        ;\n            ((aa.position && this.setPosition(aa.position)));\n            ((aa.alignment && this.setAlignment(aa.alignment)));\n            ((aa.offsetX && this.setOffsetX(aa.offsetX)));\n            ((aa.offsetY && this.setOffsetY(aa.offsetY)));\n            this._content = ba;\n        },\n        _getDefaultBehaviors: function() {\n            return this.parent._getDefaultBehaviors().concat([o,]);\n        },\n        _buildWrapper: function(aa, ba) {\n            this._contentWrapper = m.create(\"div\", {\n                className: \"uiContextualLayer\"\n            }, ba);\n            return m.create(\"div\", {\n                className: \"uiContextualLayerPositioner\"\n            }, this._contentWrapper);\n        },\n        getInsertParent: function() {\n            var aa = this._insertParent;\n            if (!aa) {\n                var ba = this.getContext();\n                if (ba) {\n                    aa = q.byClass(ba, \"uiContextualLayerParent\");\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            return ((aa || this.parent.getInsertParent()));\n        },\n        setContent: function(aa) {\n            this._content = aa;\n            m.setContent(this._contentWrapper, this._content);\n            ((this._shown && this.updatePosition()));\n            return this;\n        },\n        setContext: function(aa) {\n            this._contextNode = aa;\n            this._contextSelector = this._contextScrollParent = null;\n            if (this._shown) {\n                j.register(this.getRoot(), this._contextNode);\n                this.updatePosition();\n            }\n        ;\n        ;\n            this._setParentSubscription();\n            h.setPopup(this.getCausalElement(), this.getRoot());\n            return this;\n        },\n        _setContextID: function(aa) {\n            this._contextSelector = ((\"#\" + aa));\n            this._contextNode = null;\n        },\n        _setContextSelector: function(aa) {\n            this._contextSelector = aa;\n            this._contextNode = null;\n        },\n        getCausalElement: function() {\n            return ((this.parent.getCausalElement() || this.getContext()));\n        },\n        _setParentSubscription: function() {\n            var aa = this.getContext(), ba = null;\n            while (((aa !== null))) {\n                ba = l.get(aa, \"layer\");\n                if (ba) {\n                    break;\n                }\n            ;\n            ;\n                aa = aa.parentNode;\n            };\n        ;\n            if (((ba === this._parentLayer))) {\n                return;\n            }\n        ;\n        ;\n            if (((this._parentLayer && this._parentSubscription))) {\n                this._parentLayer.unsubscribe(this._parentSubscription);\n                this._parentSubscription = null;\n            }\n        ;\n        ;\n            if (ba) {\n                this._parentSubscription = ba.subscribe(\"hide\", this.hide.bind(this));\n            }\n        ;\n        ;\n            this._parentLayer = ba;\n        },\n        setPosition: function(aa) {\n            this._getOrientation().setDefaultPosition(aa);\n            ((this._shown && this.updatePosition()));\n            return this;\n        },\n        setAlignment: function(aa) {\n            this._getOrientation().setDefaultAlignment(aa);\n            ((this._shown && this.updatePosition()));\n            return this;\n        },\n        setOffsetX: function(aa) {\n            this._getOrientation().setDefaultOffsetX(aa);\n            ((this._shown && this.updatePosition()));\n            return this;\n        },\n        setOffsetY: function(aa) {\n            this._getOrientation().setDefaultOffsetY(aa);\n            ((this._shown && this.updatePosition()));\n            return this;\n        },\n        _getOrientation: function() {\n            if (!this._orientation) {\n                this._orientation = new z();\n            }\n        ;\n        ;\n            return this._orientation;\n        },\n        _getContentRoot: function() {\n            return this._contentWrapper;\n        },\n        getContent: function() {\n            return this._content;\n        },\n        getContext: function() {\n            if (!this._contextNode) {\n                this._contextNode = m.JSBNG__find(JSBNG__document, this._contextSelector);\n            }\n        ;\n        ;\n            return this._contextNode;\n        },\n        getContextScrollParent: function() {\n            if (!this._contextScrollParent) {\n                this._contextScrollParent = r.getScrollParent(this.getContext());\n            }\n        ;\n        ;\n            return this._contextScrollParent;\n        },\n        setInsertParent: function(aa) {\n            this._insertScrollParent = null;\n            return this.parent.setInsertParent(aa);\n        },\n        getInsertScrollParent: function() {\n            if (!this._insertScrollParent) {\n                this._insertScrollParent = r.getScrollParent(this.getInsertParent());\n            }\n        ;\n        ;\n            return this._insertScrollParent;\n        },\n        show: function() {\n            this.parent.show();\n            if (this._shown) {\n                j.register(this.getRoot(), this.getContext());\n                y.push(this);\n                this._resizeListener = ((this._resizeListener || JSBNG__Event.listen(window, \"resize\", this.updatePosition.bind(this))));\n            }\n        ;\n        ;\n            return this;\n        },\n        hide: function() {\n            j.remove(this.getRoot());\n            y.remove(this);\n            ((this._resizeListener && this._resizeListener.remove()));\n            this._resizeListener = null;\n            return this.parent.hide();\n        },\n        updatePosition: function() {\n            var aa = this.getContext();\n            if (!aa) {\n                return false;\n            }\n        ;\n        ;\n            var ba = ((r.isFixed(aa) && !r.isFixed(this.getInsertParent())));\n            if (((!ba && !aa.offsetParent))) {\n                return false;\n            }\n        ;\n        ;\n            var ca = this._getOrientation();\n            this.inform(\"adjust\", ca.reset());\n            if (!ca.isValid()) {\n                return false;\n            }\n        ;\n        ;\n            this._updateWrapperPosition(ca);\n            this._updateWrapperClass(ca);\n            var da = this.getRoot();\n            k.conditionClass(da, \"uiContextualLayerPositionerFixed\", ba);\n            var ea, fa, ga = ((ba ? \"viewport\" : \"JSBNG__document\")), ha = ((ba ? JSBNG__document.documentElement : w(da)));\n            if (((ha === JSBNG__document.documentElement))) {\n                ea = new s(0, 0);\n                fa = JSBNG__document.documentElement.clientWidth;\n            }\n             else if (!ha) {\n                return false;\n            }\n             else {\n                ea = s.getElementPosition(ha, ga);\n                fa = ha.offsetWidth;\n                if (((ha !== JSBNG__document.body))) {\n                    ea = ea.sub(new s(ha.scrollLeft, ha.scrollTop));\n                }\n            ;\n            ;\n            }\n            \n        ;\n        ;\n            var ia = s.getElementPosition(aa, ga), ja = ((ia.x - ea.x)), ka = ((ia.y - ea.y)), la = p.isRTL();\n            if (((ca.getPosition() === \"below\"))) {\n                ka += aa.offsetHeight;\n            }\n        ;\n        ;\n            if (((((((ca.getPosition() === \"right\")) || ((ca.isVertical() && ((ca.getAlignment() === \"right\")))))) != la))) {\n                ja += aa.offsetWidth;\n            }\n        ;\n        ;\n            var ma = ca.getOffsetX();\n            if (((ca.isVertical() && ((ca.getAlignment() === \"center\"))))) {\n                ma += ((((aa.offsetWidth - this._content.offsetWidth)) / 2));\n            }\n        ;\n        ;\n            if (la) {\n                ma *= -1;\n            }\n        ;\n        ;\n            var na = \"left\", oa = ((ja + ma));\n            if (((v(ca) !== la))) {\n                na = \"right\";\n                oa = ((fa - oa));\n            }\n        ;\n        ;\n            r.set(da, na, ((oa + \"px\")));\n            r.set(da, ((((na === \"left\")) ? \"right\" : \"left\")), \"\");\n            var pa = this.getInsertScrollParent(), qa;\n            if (((pa !== window))) {\n                qa = pa.clientWidth;\n            }\n             else qa = JSBNG__document.documentElement.clientWidth;\n        ;\n        ;\n            var ra = s.getElementPosition(da).x;\n            if (((na === \"left\"))) {\n                if (((((qa - ra)) > 0))) {\n                    r.set(da, \"width\", ((((qa - ra)) + \"px\")));\n                }\n                 else r.set(da, \"width\", \"\");\n            ;\n            ;\n            }\n             else r.set(da, \"width\", ((((ra + da.offsetWidth)) + \"px\")));\n        ;\n        ;\n            r.set(da, \"JSBNG__top\", ((((ka + ca.getOffsetY())) + \"px\")));\n            var sa = u(aa, this.getInsertParent());\n            r.set(da, \"z-index\", ((((sa > 200)) ? sa : \"\")));\n            this.inform(\"reposition\", ca);\n            return true;\n        },\n        _updateWrapperPosition: function(aa) {\n            var ba = ((aa.getPosition() === \"above\"));\n            r.set(this._contentWrapper, \"bottom\", ((ba ? \"0\" : null)));\n            var ca = ((p.isRTL() ? \"left\" : \"right\")), da = v(aa);\n            r.set(this._contentWrapper, ca, ((da ? \"0\" : null)));\n        },\n        _updateWrapperClass: function(aa) {\n            var ba = aa.getClassName();\n            if (((ba === this._orientationClass))) {\n                return;\n            }\n        ;\n        ;\n            if (this._orientationClass) {\n                k.removeClass(this._contentWrapper, this._orientationClass);\n            }\n        ;\n        ;\n            this._orientationClass = ba;\n            k.addClass(this._contentWrapper, ba);\n        },\n        simulateOrientation: function(aa, ba) {\n            var ca = aa.getClassName();\n            if (((ca === this._orientationClass))) {\n                return ba();\n            }\n             else {\n                if (this._orientationClass) {\n                    k.removeClass(this._contentWrapper, this._orientationClass);\n                }\n            ;\n            ;\n                k.addClass(this._contentWrapper, ca);\n                var da = ba();\n                k.removeClass(this._contentWrapper, ca);\n                if (this._orientationClass) {\n                    k.addClass(this._contentWrapper, this._orientationClass);\n                }\n            ;\n            ;\n                return da;\n            }\n        ;\n        ;\n        },\n        destroy: function() {\n            this.parent.destroy();\n            this._contentWrapper = null;\n            this._content = null;\n            return this;\n        }\n    });\n    function z() {\n        this._default = {\n            _position: \"above\",\n            _alignment: \"left\",\n            _offsetX: 0,\n            _offsetY: 0,\n            _valid: true\n        };\n        this.reset();\n    };\n;\n    z.OPPOSITE = {\n        above: \"below\",\n        below: \"above\",\n        left: \"right\",\n        right: \"left\"\n    };\n    t(z.prototype, {\n        setPosition: function(aa) {\n            this._position = aa;\n            return this;\n        },\n        setAlignment: function(aa) {\n            this._alignment = aa;\n            return this;\n        },\n        getOppositePosition: function() {\n            return z.OPPOSITE[this.getPosition()];\n        },\n        invalidate: function() {\n            this._valid = false;\n            return this;\n        },\n        getPosition: function() {\n            return ((this._position || \"above\"));\n        },\n        getAlignment: function() {\n            return ((this._alignment || \"left\"));\n        },\n        getOffsetX: function() {\n            var aa = ((this._offsetX || 0));\n            if (!this.isVertical()) {\n                if (((this._default._position !== this._position))) {\n                    aa *= -1;\n                }\n            ;\n            ;\n            }\n             else if (((this._default._alignment !== this._alignment))) {\n                aa *= -1;\n            }\n            \n        ;\n        ;\n            return aa;\n        },\n        getOffsetY: function() {\n            var aa = ((this._offsetY || 0));\n            if (((this.isVertical() && ((this._default._position !== this._position))))) {\n                aa *= -1;\n            }\n        ;\n        ;\n            return aa;\n        },\n        getClassName: function() {\n            var aa = this.getAlignment(), ba = this.getPosition();\n            if (((ba === \"below\"))) {\n                if (((aa === \"left\"))) {\n                    return \"uiContextualLayerBelowLeft\";\n                }\n                 else if (((aa === \"right\"))) {\n                    return \"uiContextualLayerBelowRight\";\n                }\n                 else return \"uiContextualLayerBelowCenter\"\n                \n            ;\n            }\n             else if (((ba === \"above\"))) {\n                if (((aa === \"left\"))) {\n                    return \"uiContextualLayerAboveLeft\";\n                }\n                 else if (((aa === \"right\"))) {\n                    return \"uiContextualLayerAboveRight\";\n                }\n                 else return \"uiContextualLayerAboveCenter\"\n                \n            ;\n            }\n             else if (((ba === \"left\"))) {\n                return \"uiContextualLayerLeft\";\n            }\n             else return \"uiContextualLayerRight\"\n            \n            \n        ;\n        },\n        isValid: function() {\n            return this._valid;\n        },\n        isVertical: function() {\n            return ((((this.getPosition() === \"above\")) || ((this.getPosition() === \"below\"))));\n        },\n        reset: function(aa, ba) {\n            t(this, this._default);\n            return this;\n        },\n        setDefaultPosition: function(aa) {\n            this._default._position = aa;\n            return this;\n        },\n        setDefaultAlignment: function(aa) {\n            this._default._alignment = aa;\n            return this;\n        },\n        setDefaultOffsetX: function(aa) {\n            this._default._offsetX = aa;\n            return this;\n        },\n        setDefaultOffsetY: function(aa) {\n            this._default._offsetY = aa;\n            return this;\n        }\n    });\n    e.exports = x;\n});\n__d(\"KeyStatus\", [\"event-extensions\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = null, h = null;\n    function i() {\n        if (!h) {\n            h = JSBNG__Event.listen(window, \"JSBNG__blur\", function() {\n                g = null;\n                j();\n            });\n        }\n    ;\n    ;\n    };\n;\n    function j() {\n        if (h) {\n            h.remove();\n            h = null;\n        }\n    ;\n    ;\n    };\n;\n    JSBNG__Event.listen(JSBNG__document.documentElement, \"keydown\", function(l) {\n        g = JSBNG__Event.getKeyCode(l);\n        i();\n    }, JSBNG__Event.Priority.URGENT);\n    JSBNG__Event.listen(JSBNG__document.documentElement, \"keyup\", function(l) {\n        g = null;\n        j();\n    }, JSBNG__Event.Priority.URGENT);\n    var k = {\n        isKeyDown: function() {\n            return !!g;\n        },\n        getKeyDownCode: function() {\n            return g;\n        }\n    };\n    e.exports = k;\n});\n__d(\"Menu\", [\"event-extensions\",\"Arbiter\",\"CSS\",\"DataStore\",\"DOM\",\"HTML\",\"Keys\",\"Parent\",\"Run\",\"Style\",\"UserAgent\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"CSS\"), i = b(\"DataStore\"), j = b(\"DOM\"), k = b(\"HTML\"), l = b(\"Keys\"), m = b(\"Parent\"), n = b(\"Run\"), o = b(\"Style\"), p = b(\"UserAgent\"), q = b(\"copyProperties\"), r = null, s = \"menu:mouseover\", t = null;\n    function u(ca) {\n        if (h.hasClass(ca, \"uiMenuContainer\")) {\n            return ca;\n        }\n    ;\n    ;\n        return m.byClass(ca, \"uiMenu\");\n    };\n;\n    function v(ca) {\n        return m.byClass(ca, \"uiMenuItem\");\n    };\n;\n    function w(ca) {\n        if (JSBNG__document.activeElement) {\n            var da = v(JSBNG__document.activeElement);\n            return ca.indexOf(da);\n        }\n    ;\n    ;\n        return -1;\n    };\n;\n    function x(ca) {\n        return j.JSBNG__find(ca, \"a.itemAnchor\");\n    };\n;\n    function y(ca) {\n        return h.hasClass(ca, \"checked\");\n    };\n;\n    function z(ca) {\n        return ((!h.hasClass(ca, \"disabled\") && ((o.get(ca, \"display\") !== \"none\"))));\n    };\n;\n    function aa(JSBNG__event) {\n        var ca = JSBNG__document.activeElement;\n        if (((((!ca || !m.byClass(ca, \"uiMenu\"))) || !j.isNodeOfType(ca, [\"input\",\"textarea\",])))) {\n            var da = v(JSBNG__event.getTarget());\n            ((da && r.focusItem(da)));\n        }\n    ;\n    ;\n    };\n;\n    function ba(ca) {\n        ((p.firefox() && x(ca).JSBNG__blur()));\n        r.inform(\"select\", {\n            menu: u(ca),\n            item: ca\n        });\n    };\n;\n    n.JSBNG__onLoad(function() {\n        var ca = {\n        };\n        ca.click = function(JSBNG__event) {\n            var da = v(JSBNG__event.getTarget());\n            if (((da && z(da)))) {\n                ba(da);\n                var ea = x(da), fa = ea.href, ga = ea.getAttribute(\"rel\");\n                return ((((ga && ((ga !== \"ignore\")))) || ((fa && ((fa.charAt(((fa.length - 1))) !== \"#\"))))));\n            }\n        ;\n        ;\n        };\n        ca.keydown = function(JSBNG__event) {\n            var da = JSBNG__event.getTarget();\n            if (JSBNG__event.getModifiers().any) {\n                return;\n            }\n        ;\n        ;\n            if (((!t || j.isNodeOfType(da, [\"input\",\"textarea\",])))) {\n                return;\n            }\n        ;\n        ;\n            var ea = JSBNG__Event.getKeyCode(JSBNG__event), fa;\n            switch (ea) {\n              case l.UP:\n            \n              case l.DOWN:\n                var ga = r.getEnabledItems(t);\n                fa = w(ga);\n                r.focusItem(ga[((fa + ((((ea === l.UP)) ? -1 : 1))))]);\n                return false;\n              case l.SPACE:\n                var ha = v(da);\n                if (ha) {\n                    ba(ha);\n                    JSBNG__event.prevent();\n                }\n            ;\n            ;\n                break;\n              default:\n                var ia = String.fromCharCode(ea).toLowerCase(), ja = r.getEnabledItems(t);\n                fa = w(ja);\n                var ka = fa, la = ja.length;\n                while (((((~fa && (((ka = ((++ka % la))) !== fa)))) || ((!~fa && ((++ka < la))))))) {\n                    var ma = r.getItemLabel(ja[ka]);\n                    if (((ma && ((ma.charAt(0).toLowerCase() === ia))))) {\n                        r.focusItem(ja[ka]);\n                        return false;\n                    }\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n        };\n        JSBNG__Event.listen(JSBNG__document.documentElement, ca);\n    });\n    r = e.exports = q(new g(), {\n        focusItem: function(ca) {\n            if (((ca && z(ca)))) {\n                this._removeSelected(u(ca));\n                h.addClass(ca, \"selected\");\n                x(ca).JSBNG__focus();\n            }\n        ;\n        ;\n        },\n        getEnabledItems: function(ca) {\n            return r.getItems(ca).filter(z);\n        },\n        getCheckedItems: function(ca) {\n            return r.getItems(ca).filter(y);\n        },\n        getItems: function(ca) {\n            return j.scry(ca, \"li.uiMenuItem\");\n        },\n        getItemLabel: function(ca) {\n            return ((ca.getAttribute(\"data-label\", 2) || \"\"));\n        },\n        isItemChecked: function(ca) {\n            return h.hasClass(ca, \"checked\");\n        },\n        register: function(ca, da) {\n            ca = u(ca);\n            if (!i.get(ca, s)) {\n                i.set(ca, s, JSBNG__Event.listen(ca, \"mouseover\", aa));\n            }\n        ;\n        ;\n            if (((da !== false))) {\n                t = ca;\n            }\n        ;\n        ;\n        },\n        setItemEnabled: function(ca, da) {\n            if (((!da && !j.scry(ca, \"span.disabledAnchor\")[0]))) {\n                j.appendContent(ca, j.create(\"span\", {\n                    className: ((j.JSBNG__find(ca, \"a\").className + \" disabledAnchor\"))\n                }, k(x(ca).innerHTML)));\n            }\n        ;\n        ;\n            h.conditionClass(ca, \"disabled\", !da);\n        },\n        toggleItem: function(ca) {\n            var da = !r.isItemChecked(ca);\n            r.setItemChecked(ca, da);\n        },\n        setItemChecked: function(ca, da) {\n            h.conditionClass(ca, \"checked\", da);\n            x(ca).setAttribute(\"aria-checked\", da);\n        },\n        unregister: function(ca) {\n            ca = u(ca);\n            var da = i.remove(ca, s);\n            ((da && da.remove()));\n            t = null;\n            this._removeSelected(ca);\n        },\n        _removeSelected: function(ca) {\n            r.getItems(ca).filter(function(da) {\n                return h.hasClass(da, \"selected\");\n            }).forEach(function(da) {\n                h.removeClass(da, \"selected\");\n            });\n        }\n    });\n});\n__d(\"ContextualLayerDimensions\", [\"DOM\",\"Locale\",\"JSBNG__Rect\",\"Vector\",\"ViewportBounds\",\"ge\",\"getOverlayZIndex\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"Locale\"), i = b(\"JSBNG__Rect\"), j = b(\"Vector\"), k = b(\"ViewportBounds\"), l = b(\"ge\"), m = b(\"getOverlayZIndex\"), n = {\n        getViewportRect: function(o) {\n            var p = l(\"globalContainer\"), q = o.getContext(), r = ((((p && g.contains(p, q))) || ((m(q) < 300)))), s = i.getViewportBounds();\n            if (r) {\n                s.t += k.getTop();\n                if (h.isRTL()) {\n                    s.l += k.getRight();\n                }\n                 else s.r -= k.getRight();\n            ;\n            ;\n            }\n        ;\n        ;\n            return s;\n        },\n        getLayerRect: function(o, p) {\n            var q = o.getContext(), r = j.getElementPosition(q, \"viewport\"), s = o.simulateOrientation(p, function() {\n                return j.getElementDimensions(o.getContent());\n            }), t = ((r.y + p.getOffsetY()));\n            if (((p.getPosition() === \"above\"))) {\n                t -= s.y;\n            }\n             else if (((p.getPosition() === \"below\"))) {\n                t += q.offsetHeight;\n            }\n            \n        ;\n        ;\n            var u = ((r.x + p.getOffsetX()));\n            if (p.isVertical()) {\n                var v = p.getAlignment();\n                if (((v === \"center\"))) {\n                    u += ((((q.offsetWidth - s.x)) / 2));\n                }\n                 else if (((((v === \"right\")) !== h.isRTL()))) {\n                    u += ((q.offsetWidth - s.x));\n                }\n                \n            ;\n            ;\n            }\n             else if (((((p.getPosition() === \"right\")) !== h.isRTL()))) {\n                u += q.offsetWidth;\n            }\n             else u -= s.x;\n            \n        ;\n        ;\n            return new i(t, ((u + s.x)), ((t + s.y)), u, \"viewport\");\n        }\n    };\n    e.exports = n;\n});\n__d(\"ContextualLayerAutoFlip\", [\"array-extensions\",\"event-extensions\",\"ContextualLayerDimensions\",\"DOM\",\"Vector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    var g = b(\"ContextualLayerDimensions\"), h = b(\"DOM\"), i = b(\"Vector\"), j = b(\"copyProperties\");\n    function k(l) {\n        this._layer = l;\n    };\n;\n    j(k.prototype, {\n        _subscription: null,\n        enable: function() {\n            this._subscription = this._layer.subscribe(\"adjust\", this._adjustOrientation.bind(this));\n            if (this._layer.isShown()) {\n                this._layer.updatePosition();\n            }\n        ;\n        ;\n        },\n        disable: function() {\n            this._subscription.unsubscribe();\n            this._subscription = null;\n            if (this._layer.isShown()) {\n                this._layer.updatePosition();\n            }\n        ;\n        ;\n        },\n        _adjustOrientation: function(l, m) {\n            var n = this._getValidPositions(m);\n            if (!n.length) {\n                m.invalidate();\n                return;\n            }\n        ;\n        ;\n            var o = g.getViewportRect(this._layer), p = this._getValidAlignments(m);\n            for (var q = 0; ((q < p.length)); q++) {\n                m.setAlignment(p[q]);\n                for (var r = 0; ((r < n.length)); r++) {\n                    m.setPosition(n[r]);\n                    var s = g.getLayerRect(this._layer, m);\n                    if (o.contains(s)) {\n                        return;\n                    }\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n            m.setPosition(((n.contains(\"below\") ? \"below\" : n[0]))).setAlignment(p[0]);\n        },\n        _getValidPositions: function(l) {\n            var m = [l.getPosition(),l.getOppositePosition(),], n = this._layer.getContextScrollParent();\n            if (((((n === window)) || ((n === h.getDocumentScrollElement()))))) {\n                return m;\n            }\n        ;\n        ;\n            var o = this._layer.getContext(), p = i.getElementPosition(n, \"viewport\").y, q = i.getElementPosition(o, \"viewport\").y;\n            if (l.isVertical()) {\n                return m.filter(function(s) {\n                    if (((s === \"above\"))) {\n                        return ((q >= p));\n                    }\n                     else {\n                        var t = ((p + n.offsetHeight)), u = ((q + o.offsetHeight));\n                        return ((u <= t));\n                    }\n                ;\n                ;\n                });\n            }\n             else {\n                var r = ((p + n.offsetHeight));\n                if (((((q >= p)) && ((((q + o.offsetHeight)) <= r))))) {\n                    return m;\n                }\n                 else return []\n            ;\n            }\n        ;\n        ;\n        },\n        _getValidAlignments: function(l) {\n            var m = [\"left\",\"center\",\"right\",], n = l.getAlignment(), o = m.indexOf(n);\n            if (((o > 0))) {\n                m.splice(o, 1);\n                m.unshift(n);\n            }\n        ;\n        ;\n            return m;\n        }\n    });\n    e.exports = k;\n});\n__d(\"Selector\", [\"event-extensions\",\"Arbiter\",\"Button\",\"ContextualLayer\",\"copyProperties\",\"CSS\",\"DataStore\",\"DOM\",\"HTML\",\"Input\",\"Keys\",\"KeyStatus\",\"Menu\",\"Parent\",\"Style\",\"Toggler\",\"Tooltip\",\"Vector\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"Button\"), i = b(\"ContextualLayer\"), j = b(\"copyProperties\"), k = b(\"CSS\"), l = b(\"DataStore\"), m = b(\"DOM\"), n = b(\"HTML\"), o = b(\"Input\"), p = b(\"Keys\"), q = b(\"KeyStatus\"), r = b(\"Menu\"), s = b(\"Parent\"), t = b(\"Style\"), u = b(\"Toggler\"), v = b(\"Tooltip\"), w = b(\"Vector\"), x, y, z = [], aa;\n    function ba(ma) {\n        return s.byClass(ma, \"uiSelector\");\n    };\n;\n    function ca(ma) {\n        return s.byClass(ma, \"uiSelectorButton\");\n    };\n;\n    function da() {\n        if (!y) {\n            y = new i({\n                position: \"below\"\n            }, m.create(\"div\"));\n            k.addClass(y.getRoot(), \"uiSelectorContextualLayer\");\n        }\n    ;\n    ;\n        return y;\n    };\n;\n    function ea(ma) {\n        return m.scry(ma, \"select\")[0];\n    };\n;\n    function fa(ma) {\n        return m.JSBNG__find(ma, \"div.uiSelectorMenuWrapper\");\n    };\n;\n    function ga() {\n        ga = bagofholding;\n        r.subscribe(\"select\", function(ma, na) {\n            if (((((!x || !na)) || ((na.menu !== la.getSelectorMenu(x)))))) {\n                return;\n            }\n        ;\n        ;\n            var oa = ha(x), pa = ia(na.item);\n            if (pa) {\n                var qa = x, ra = la.isOptionSelected(na.item), sa = la.inform(\"select\", {\n                    selector: qa,\n                    option: na.item,\n                    clone: aa\n                });\n                if (((sa === false))) {\n                    return;\n                }\n            ;\n            ;\n                if (((oa || !ra))) {\n                    la.setSelected(qa, la.getOptionValue(na.item), !ra);\n                    la.inform(\"toggle\", {\n                        selector: qa,\n                        option: na.item\n                    });\n                    la.inform(\"change\", {\n                        selector: qa\n                    });\n                    g.inform(\"Form/change\", {\n                        node: qa\n                    });\n                    if (ja(qa)) {\n                        l.set(qa, \"dirty\", true);\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            if (((!oa || !pa))) {\n                ((x && la.toggle(x)));\n            }\n        ;\n        ;\n        });\n    };\n;\n    function ha(ma) {\n        return !!ma.getAttribute(\"data-multiple\");\n    };\n;\n    function ia(ma) {\n        return k.hasClass(ma, \"uiSelectorOption\");\n    };\n;\n    function ja(ma) {\n        return !!ma.getAttribute(\"data-autosubmit\");\n    };\n;\n    var ka = {\n        keydown: function(JSBNG__event) {\n            var ma = JSBNG__event.getTarget();\n            if (m.isNodeOfType(ma, [\"input\",\"textarea\",])) {\n                return;\n            }\n        ;\n        ;\n            switch (JSBNG__Event.getKeyCode(JSBNG__event)) {\n              case p.DOWN:\n            \n              case p.SPACE:\n            \n              case p.UP:\n                if (ca(ma)) {\n                    var na = ba(ma);\n                    la.toggle(na);\n                    return false;\n                }\n            ;\n            ;\n                break;\n              case p.ESC:\n                if (x) {\n                    la.toggle(x);\n                    return false;\n                }\n            ;\n            ;\n                break;\n            };\n        ;\n        },\n        mouseover: function(JSBNG__event) {\n            var ma = s.byAttribute(JSBNG__event.getTarget(), \"ajaxify\");\n            if (((ma && k.hasClass(ma, \"uiSelectorButton\")))) {\n                la.loadMenu(ba(ma));\n            }\n        ;\n        ;\n        }\n    };\n    JSBNG__Event.listen(JSBNG__document.documentElement, ka);\n    u.subscribe([\"show\",\"hide\",], function(ma, na) {\n        var oa = ba(na.getActive());\n        if (oa) {\n            ga();\n            var pa = la.getSelectorButton(oa), qa = la.getSelectorMenu(oa), ra = ((ma === \"show\"));\n            pa.setAttribute(\"aria-expanded\", ((ra ? \"true\" : \"false\")));\n            if (ra) {\n                x = oa;\n                if (k.hasClass(pa, \"uiButtonDisabled\")) {\n                    la.setEnabled(oa, false);\n                    return false;\n                }\n            ;\n            ;\n                qa = ((qa || la.loadMenu(oa)));\n                var sa = t.getScrollParent(oa), ta = ((((sa !== window)) && ((sa !== m.getDocumentScrollElement()))));\n                if (((ta || k.hasClass(oa, \"uiSelectorUseLayer\")))) {\n                    if (ta) {\n                        z.push(JSBNG__Event.listen(sa, \"JSBNG__scroll\", function() {\n                            na.hide();\n                        }));\n                    }\n                ;\n                ;\n                    aa = m.create(\"div\", {\n                        className: oa.className\n                    });\n                    k.addClass(aa, \"invisible_elem\");\n                    w.getElementDimensions(oa).setElementDimensions(aa);\n                    m.replace(oa, aa);\n                    var ua = k.hasClass(oa, \"uiSelectorRight\"), va = k.hasClass(oa, \"uiSelectorBottomUp\");\n                    da().setContext(aa).setContent(oa).setPosition(((va ? \"above\" : \"below\"))).setAlignment(((ua ? \"right\" : \"left\"))).show();\n                }\n            ;\n            ;\n                r.register(qa);\n                if (q.isKeyDown()) {\n                    var wa = r.getCheckedItems(qa);\n                    if (!wa.length) {\n                        wa = r.getEnabledItems(qa);\n                    }\n                ;\n                ;\n                    r.focusItem(wa[0]);\n                }\n            ;\n            ;\n            }\n             else {\n                x = null;\n                if (aa) {\n                    while (z.length) {\n                        z.pop().remove();\n                    ;\n                    };\n                ;\n                    m.replace(aa, oa);\n                    da().hide();\n                    aa = null;\n                }\n            ;\n            ;\n                ((qa && r.unregister(qa)));\n                if (((ja(oa) && l.get(oa, \"dirty\")))) {\n                    var xa = m.scry(oa, \"input.submitButton\")[0];\n                    ((xa && xa.click()));\n                    l.remove(oa, \"dirty\");\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            k.conditionClass(la.getSelectorButton(oa), \"selected\", ra);\n            la.inform(((ra ? \"open\" : \"close\")), {\n                selector: oa,\n                clone: aa\n            });\n        }\n    ;\n    ;\n    });\n    var la = j(new g(), {\n        attachMenu: function(ma, na, oa) {\n            ma = ba(ma);\n            if (ma) {\n                ((x && r.unregister(la.getSelectorMenu(x))));\n                m.setContent(fa(ma), na);\n                ((x && r.register(la.getSelectorMenu(ma))));\n                ((aa && da().updatePosition()));\n                if (oa) {\n                    var pa = ma.getAttribute(\"data-name\");\n                    ((pa && oa.setAttribute(\"JSBNG__name\", pa)));\n                    if (!ha(ma)) {\n                        oa.setAttribute(\"multiple\", false);\n                    }\n                ;\n                ;\n                    var qa = ea(ma);\n                    if (qa) {\n                        m.replace(qa, oa);\n                    }\n                     else m.insertAfter(ma.firstChild, oa);\n                ;\n                ;\n                }\n            ;\n            ;\n                return true;\n            }\n        ;\n        ;\n        },\n        getOption: function(ma, na) {\n            var oa = la.getOptions(ma), pa = oa.length;\n            while (pa--) {\n                if (((na === la.getOptionValue(oa[pa])))) {\n                    return oa[pa];\n                }\n            ;\n            ;\n            };\n        ;\n            return null;\n        },\n        getOptions: function(ma) {\n            var na = r.getItems(la.getSelectorMenu(ma));\n            return na.filter(ia);\n        },\n        getEnabledOptions: function(ma) {\n            var na = r.getEnabledItems(la.getSelectorMenu(ma));\n            return na.filter(ia);\n        },\n        getSelectedOptions: function(ma) {\n            return r.getCheckedItems(la.getSelectorMenu(ma));\n        },\n        getOptionText: function(ma) {\n            return r.getItemLabel(ma);\n        },\n        getOptionValue: function(ma) {\n            var na = ba(ma), oa = ea(na), pa = la.getOptions(na).indexOf(ma);\n            return ((((pa >= 0)) ? oa.options[((pa + 1))].value : \"\"));\n        },\n        getSelectorButton: function(ma) {\n            return m.JSBNG__find(ma, \"a.uiSelectorButton\");\n        },\n        getSelectorMenu: function(ma) {\n            return m.scry(ma, \"div.uiSelectorMenu\")[0];\n        },\n        getValue: function(ma) {\n            var na = ea(ma);\n            if (!na) {\n                return null;\n            }\n        ;\n        ;\n            if (!ha(ma)) {\n                return na.value;\n            }\n        ;\n        ;\n            var oa = [], pa = na.options;\n            for (var qa = 1, ra = pa.length; ((qa < ra)); qa++) {\n                if (pa[qa].selected) {\n                    oa.push(pa[qa].value);\n                }\n            ;\n            ;\n            };\n        ;\n            return oa;\n        },\n        isOptionSelected: function(ma) {\n            return r.isItemChecked(ma);\n        },\n        listen: function(ma, na, oa) {\n            return this.subscribe(na, function(pa, qa) {\n                if (((qa.selector === ma))) {\n                    return oa(qa, pa);\n                }\n            ;\n            ;\n            });\n        },\n        loadMenu: function(ma) {\n            var na = la.getSelectorMenu(ma);\n            if (!na) {\n                var oa = la.getSelectorButton(ma), pa = oa.getAttribute(\"ajaxify\");\n                if (pa) {\n                    d([\"AsyncRequest\",], function(ra) {\n                        ra.bootstrap(pa, oa);\n                    });\n                    var qa = n(((((((((((((\"\\u003Cdiv class=\\\"uiSelectorMenuWrapper uiToggleFlyout\\\"\\u003E\" + \"\\u003Cdiv class=\\\"uiMenu uiSelectorMenu loading\\\"\\u003E\")) + \"\\u003Cul class=\\\"uiMenuInner\\\"\\u003E\")) + \"\\u003Cli\\u003E\\u003Cspan\\u003E\\u003C/span\\u003E\\u003C/li\\u003E\")) + \"\\u003C/ul\\u003E\")) + \"\\u003C/div\\u003E\")) + \"\\u003C/div\\u003E\")));\n                    m.appendContent(oa.parentNode, qa);\n                    na = la.getSelectorMenu(ma);\n                    oa.removeAttribute(\"JSBNG__onmouseover\");\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            return na;\n        },\n        setButtonLabel: function(ma, na) {\n            var oa = la.getSelectorButton(ma), pa = parseInt(oa.getAttribute(\"data-length\"), 10);\n            na = ((((na || oa.getAttribute(\"data-label\"))) || \"\"));\n            h.setLabel(oa, na);\n            if (((typeof na === \"string\"))) {\n                k.conditionClass(oa, \"uiSelectorBigButtonLabel\", ((na.length > pa)));\n                if (((pa && ((na.length > pa))))) {\n                    oa.setAttribute(\"title\", na);\n                }\n                 else oa.removeAttribute(\"title\");\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        setButtonTooltip: function(ma, na) {\n            var oa = la.getSelectorButton(ma), pa = s.byTag(oa, \"a\");\n            ((pa && v.set(pa, ((((na || oa.getAttribute(\"data-tooltip\"))) || \"\")))));\n        },\n        updateButtonARIALabel: function(ma, na) {\n            var oa = la.getSelectorButton(ma), pa = s.byTag(oa, \"a\");\n            if (pa) {\n                var qa = oa.getAttribute(\"data-ariaprefix\");\n                if (qa) {\n                    oa.setAttribute(\"aria-label\", ((((qa + \": \")) + na)));\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        setEnabled: function(ma, na) {\n            if (((((!na && x)) && ((ba(ma) === x))))) {\n                la.toggle(ma);\n            }\n        ;\n        ;\n            h.setEnabled(la.getSelectorButton(ma), na);\n        },\n        setOptionEnabled: function(ma, na) {\n            r.setItemEnabled(ma, na);\n        },\n        setSelected: function(ma, na, oa) {\n            oa = ((oa !== false));\n            var pa = la.getOption(ma, na);\n            if (!pa) {\n                return;\n            }\n        ;\n        ;\n            var qa = la.isOptionSelected(pa);\n            if (((oa !== qa))) {\n                if (((!ha(ma) && !qa))) {\n                    var ra = la.getSelectedOptions(ma)[0];\n                    ((ra && r.toggleItem(ra)));\n                }\n            ;\n            ;\n                r.toggleItem(pa);\n            }\n        ;\n        ;\n            la.updateSelector(ma);\n        },\n        toggle: function(ma) {\n            u.toggle(m.scry(ba(ma), \"div.wrap\")[0]);\n        },\n        updateSelector: function(ma) {\n            var na = la.getOptions(ma), oa = la.getSelectedOptions(ma), pa = ea(ma).options, qa = [], ra = [];\n            for (var sa = 0, ta = na.length; ((sa < ta)); sa++) {\n                var ua = oa.contains(na[sa]);\n                pa[((sa + 1))].selected = ua;\n                if (ua) {\n                    var va = la.getOptionText(na[sa]);\n                    qa.push(va);\n                    ra.push(((na[sa].getAttribute(\"data-tooltip\") || va)));\n                }\n            ;\n            ;\n            };\n        ;\n            pa[0].selected = !oa.length;\n            var wa = k.hasClass(ma, \"uiSelectorDynamicLabel\"), xa = k.hasClass(ma, \"uiSelectorDynamicTooltip\");\n            if (((wa || xa))) {\n                var ya = \"\";\n                if (ha(ma)) {\n                    var za = la.getSelectorButton(ma);\n                    ya = ((za.getAttribute(\"data-delimiter\") || \", \"));\n                }\n            ;\n            ;\n                qa = qa.join(ya);\n                ra = ra.join(ya);\n                if (wa) {\n                    la.setButtonLabel(ma, qa);\n                    la.updateButtonARIALabel(ma, qa);\n                }\n            ;\n            ;\n                ((xa && la.setButtonTooltip(ma, ra)));\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = la;\n});\n__d(\"DynamicIconSelector\", [\"Button\",\"CSS\",\"DOM\",\"Selector\",], function(a, b, c, d, e, f) {\n    var g = b(\"Button\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"Selector\"), k = {\n        swapIcon: function(l) {\n            var m = j.getSelectedOptions(l)[0], n = ((m && i.scry(m, \".itemIcon\")[0])), o = j.getSelectorButton(l);\n            if (n) {\n                g.setIcon(o, n.cloneNode(true));\n            }\n             else {\n                var p = i.scry(o, \".img\")[0];\n                ((p && i.remove(p)));\n            }\n        ;\n        ;\n            h.conditionClass(o, \"uiSelectorChevronOnly\", !n);\n        }\n    };\n    j.subscribe(\"change\", function(l, m) {\n        var n = m.selector;\n        if (h.hasClass(n, \"dynamicIconSelector\")) {\n            k.swapIcon(n);\n        }\n    ;\n    ;\n    });\n    e.exports = k;\n});\n__d(\"AudienceSelector\", [\"Arbiter\",\"CSS\",\"DOM\",\"DynamicIconSelector\",\"PrivacyConst\",\"Selector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"DynamicIconSelector\"), k = b(\"PrivacyConst\"), l = b(\"Selector\"), m = b(\"copyProperties\");\n    l.subscribe(\"select\", function(p, q) {\n        if (!h.hasClass(q.selector, \"audienceSelector\")) {\n            return;\n        }\n    ;\n    ;\n        var r = l.getOptionValue(q.option);\n        g.inform(\"AudienceSelector/changed\", q);\n        if (((((r == k.BaseValue.CUSTOM)) && !h.hasClass(q.option, \"noDialog\")))) {\n            l.toggle(q.selector);\n            return false;\n        }\n    ;\n    ;\n        if (h.hasClass(q.selector, \"dataTooltip\")) {\n            var s = i.JSBNG__find(q.option, \".itemAnchor\").getAttribute(\"data-tooltip\");\n            l.setButtonTooltip(q.selector, ((s || null)));\n        }\n    ;\n    ;\n        if (!h.hasClass(q.option, \"specialOption\")) {\n            return;\n        }\n    ;\n    ;\n        var t = i.JSBNG__find(q.option, \"a\").getAttribute(\"data-type\");\n        if (h.hasClass(q.option, \"moreOption\")) {\n            h.addClass(q.selector, t);\n            h.addClass(q.selector, \"showSecondaryOptions\");\n            return false;\n        }\n         else if (h.hasClass(q.option, \"returnOption\")) {\n            h.removeClass(q.selector, \"showSecondaryOptions\");\n            h.removeClass(q.selector, \"friendList\");\n            return false;\n        }\n        \n    ;\n    ;\n    });\n    var n = {\n    }, o = {\n        hasTags: function(p) {\n            return n.hasOwnProperty(p);\n        },\n        setHasTags: function(p) {\n            if (!p) {\n                return;\n            }\n        ;\n        ;\n            n[p] = true;\n        }\n    };\n    g.subscribe(\"CustomPrivacyOption/update\", function(p, q) {\n        if (!h.hasClass(q.selector, \"audienceSelector\")) {\n            return;\n        }\n    ;\n    ;\n        l.setSelected(q.selector, l.getOptionValue(q.option));\n        j.swapIcon(q.selector);\n        l.setButtonTooltip(q.selector, q.tooltip);\n        g.inform(\"AudienceSelector/update\", q.selector);\n    });\n    e.exports = o;\n});\n__d(\"ContextualDialogArrow\", [\"CSS\",\"DOM\",\"Locale\",\"Style\",\"Vector\",\"copyProperties\",\"cx\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"Locale\"), j = b(\"Style\"), k = b(\"Vector\"), l = b(\"copyProperties\"), m = b(\"cx\"), n = 15, o = 16, p = {\n        bottom: \"-cx-PRIVATE-uiContextualDialog__arrowBottom\",\n        JSBNG__top: \"-cx-PRIVATE-uiContextualDialog__arrowTop\",\n        right: \"-cx-PRIVATE-uiContextualDialog__arrowRight\",\n        left: \"-cx-PRIVATE-uiContextualDialog__arrowLeft\"\n    }, q = {\n        above: \"bottom\",\n        below: \"JSBNG__top\",\n        left: \"right\",\n        right: \"left\"\n    };\n    function r(s) {\n        this._layer = s;\n    };\n;\n    l(r.prototype, {\n        _subscription: null,\n        _arrow: null,\n        enable: function() {\n            this._subscription = this._layer.subscribe([\"adjust\",\"reposition\",], this._handle.bind(this));\n        },\n        disable: function() {\n            this._subscription.unsubscribe();\n            this._subscription = null;\n        },\n        _handle: function(s, t) {\n            if (((s === \"adjust\"))) {\n                this._repositionArrow(t);\n            }\n             else this._repositionRoot(t);\n        ;\n        ;\n        },\n        _repositionRoot: function(s) {\n            var t = this._layer.getRoot();\n            if (!s.isVertical()) {\n                var u = parseInt(j.get(t, \"JSBNG__top\"), 10);\n                u -= n;\n                j.set(t, \"JSBNG__top\", ((u + \"px\")));\n            }\n        ;\n        ;\n        },\n        _repositionArrow: function(s) {\n            var t = this._layer._contentWrapper, u = 0, v = s.getAlignment(), w = s.getPosition();\n            if (((((w == \"above\")) || ((w == \"below\"))))) {\n                if (((v == \"center\"))) {\n                    u = 50;\n                }\n                 else if (((v == \"right\"))) {\n                    u = 100;\n                }\n                \n            ;\n            }\n        ;\n        ;\n            var x = q[w];\n            for (var y in p) {\n                g.conditionClass(t, p[y], ((x === y)));\n            ;\n            };\n        ;\n            if (((w == \"none\"))) {\n                return;\n            }\n        ;\n        ;\n            if (!this._arrow) {\n                this._arrow = this._drawArrow();\n                h.appendContent(t, this._arrow);\n            }\n        ;\n        ;\n            g.conditionClass(t, \"-cx-PRIVATE-uiContextualDialog__withFooter\", this._layer.getFooter());\n            j.set(this._arrow, \"JSBNG__top\", \"\");\n            j.set(this._arrow, \"left\", \"\");\n            j.set(this._arrow, \"right\", \"\");\n            j.set(this._arrow, \"margin\", \"\");\n            var z = ((((x == \"JSBNG__top\")) || ((x == \"bottom\")))), aa = ((z ? ((i.isRTL() ? \"right\" : \"left\")) : \"JSBNG__top\"));\n            u = ((u || 0));\n            j.set(this._arrow, aa, ((u + \"%\")));\n            var ba = ((o + ((n * 2)))), ca = n;\n            if (((z && ((v != \"center\"))))) {\n                var da = this._layer.getContext(), ea = k.getElementDimensions(da).x;\n                if (((ea < ba))) {\n                    ca = Math.max(((((ea / 2)) - ((o / 2)))), 0);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            j.set(this._arrow, ((\"margin-\" + aa)), ((-((((((ba * u)) / 100)) - ca)) + \"px\")));\n        },\n        _drawArrow: function() {\n            return h.create(\"i\", {\n                className: \"-cx-PRIVATE-uiContextualDialog__arrow\"\n            });\n        }\n    });\n    r.OFFSET = n;\n    r.LENGTH = o;\n    e.exports = r;\n});\n__d(\"ContextualDialogFitInViewport\", [\"event-extensions\",\"ContextualDialogArrow\",\"ContextualLayerDimensions\",\"Style\",\"Vector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ContextualDialogArrow\"), h = b(\"ContextualLayerDimensions\"), i = b(\"Style\"), j = b(\"Vector\"), k = b(\"copyProperties\"), l = g.OFFSET, m = g.LENGTH, n = ((l + m));\n    function o(p) {\n        this._layer = p;\n    };\n;\n    k(o.prototype, {\n        _scrollListener: null,\n        _subscription: null,\n        _minimumTop: null,\n        enable: function() {\n            this._subscription = this._layer.subscribe([\"show\",\"hide\",\"reposition\",], function(p, q) {\n                if (((p == \"reposition\"))) {\n                    this._calculateMinimumTop(q);\n                }\n                 else if (((p == \"show\"))) {\n                    this._attachScroll();\n                    this._adjustForScroll();\n                }\n                 else this._detachScroll();\n                \n            ;\n            ;\n            }.bind(this));\n            if (this._layer.isShown()) {\n                this._attachScroll();\n            }\n        ;\n        ;\n        },\n        disable: function() {\n            if (this._layer.isShown()) {\n                this._detachScroll();\n            }\n        ;\n        ;\n            this._subscription.unsubscribe();\n            this._subscription = null;\n        },\n        _attachScroll: function() {\n            this._scrollListener = JSBNG__Event.listen(((this._layer.getContextScrollParent() || window)), \"JSBNG__scroll\", this._adjustForScroll.bind(this));\n        },\n        _detachScroll: function() {\n            this._scrollListener.remove();\n            this._scrollListener = null;\n        },\n        _getContentHeight: function() {\n            return j.getElementDimensions(this._layer._contentWrapper).y;\n        },\n        _getContextY: function() {\n            return j.getElementPosition(this._layer.getContext()).y;\n        },\n        _calculateMinimumTop: function(p) {\n            if (p.isVertical()) {\n                return;\n            }\n        ;\n        ;\n            this._minimumTop = ((((this._getContextY() - ((this._getContentHeight() - n)))) + p.getOffsetY()));\n        },\n        _adjustForScroll: function() {\n            var p = this._layer._getOrientation();\n            if (p.isVertical()) {\n                return;\n            }\n        ;\n        ;\n            var q = h.getViewportRect(this._layer), r = ((q.b - this._minimumTop));\n            if (((r < 0))) {\n                return;\n            }\n        ;\n        ;\n            var s = this._getContentHeight(), t = ((s - ((n + l)))), u = Math.max(0, Math.min(t, ((t - ((r - s))))));\n            i.set(this._layer.getContent(), \"JSBNG__top\", ((-u + \"px\")));\n        }\n    });\n    e.exports = o;\n});\n__d(\"ContextualDialog\", [\"AccessibleLayer\",\"Class\",\"ContextualDialogFitInViewport\",\"ContextualLayer\",\"CSS\",\"DOM\",\"LayerButtons\",\"LayerFormHooks\",\"LayerMouseHooks\",\"Style\",\"copyProperties\",\"csx\",\"cx\",], function(a, b, c, d, e, f) {\n    var g = b(\"AccessibleLayer\"), h = b(\"Class\"), i = b(\"ContextualDialogFitInViewport\"), j = b(\"ContextualLayer\"), k = b(\"CSS\"), l = b(\"DOM\"), m = b(\"LayerButtons\"), n = b(\"LayerFormHooks\"), o = b(\"LayerMouseHooks\"), p = b(\"Style\"), q = b(\"copyProperties\"), r = b(\"csx\"), s = b(\"cx\");\n    function t(u, v) {\n        this.parent.construct(this, u, v);\n    };\n;\n    h.extend(t, j);\n    q(t.prototype, {\n        _footer: null,\n        _configure: function(u, v) {\n            u.addedBehaviors.push(u.arrowBehavior);\n            var w = l.scry(v, \"div.-cx-PRIVATE-uiContextualDialog__footer\");\n            if (w.length) {\n                this._footer = w[0];\n            }\n        ;\n        ;\n            this.parent._configure(u, v);\n        },\n        _getDefaultBehaviors: function() {\n            return this.parent._getDefaultBehaviors().concat([g,i,m,n,o,]);\n        },\n        _buildWrapper: function(u, v) {\n            k.addClass(v, \"-cx-PRIVATE-uiContextualDialog__content\");\n            var w = this.parent._buildWrapper(u, v);\n            k.addClass(this._contentWrapper, \"-cx-PRIVATE-uiContextualDialog__wrapper\");\n            if (u.width) {\n                this.setWidth(u.width);\n            }\n        ;\n        ;\n            return w;\n        },\n        setWidth: function(u) {\n            this._width = Math.floor(u);\n            p.set(this._contentWrapper, \"width\", ((u + \"px\")));\n            return this;\n        },\n        getFooter: function() {\n            return this._footer;\n        }\n    });\n    q(t, {\n        setContext: function(u, v) {\n            u.setContext(v);\n        }\n    });\n    e.exports = t;\n});\n__d(\"ContextualLayerHideOnScroll\", [\"event-extensions\",\"Class\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Class\"), h = b(\"copyProperties\");\n    function i(j) {\n        this._layer = j;\n    };\n;\n    h(i.prototype, {\n        _subscriptions: [],\n        enable: function() {\n            this._subscriptions = [this._layer.subscribe(\"contextchange\", this._handleContextChange.bind(this)),this._layer.subscribe(\"show\", this.attach.bind(this)),this._layer.subscribe(\"hide\", this.detach.bind(this)),];\n        },\n        disable: function() {\n            while (this._subscriptions.length) {\n                this._subscriptions.pop().unsubscribe();\n            ;\n            };\n        ;\n            this.detach();\n        },\n        attach: function() {\n            if (this._listener) {\n                return;\n            }\n        ;\n        ;\n            var j = this._layer.getContextScrollParent();\n            if (((j === window))) {\n                return;\n            }\n        ;\n        ;\n            this._listener = JSBNG__Event.listen(j, \"JSBNG__scroll\", this._layer.hide.bind(this._layer));\n        },\n        detach: function() {\n            ((this._listener && this._listener.remove()));\n            this._listener = null;\n        },\n        _handleContextChange: function() {\n            this.detach();\n            if (this._layer.isShown()) {\n                this.attach();\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = i;\n});\n__d(\"ContextualLayerUpdateOnScroll\", [\"event-extensions\",\"Class\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Class\"), h = b(\"copyProperties\");\n    function i(j) {\n        this._layer = j;\n    };\n;\n    h(i.prototype, {\n        _subscriptions: [],\n        enable: function() {\n            this._subscriptions = [this._layer.subscribe(\"show\", this._attachScrollListener.bind(this)),this._layer.subscribe(\"hide\", this._removeScrollListener.bind(this)),];\n        },\n        disable: function() {\n            while (this._subscriptions.length) {\n                this._subscriptions.pop().unsubscribe();\n            ;\n            };\n        ;\n            this.detach();\n        },\n        _attachScrollListener: function() {\n            if (this._listener) {\n                return;\n            }\n        ;\n        ;\n            var j = this._layer.getContextScrollParent();\n            this._listener = JSBNG__Event.listen(j, \"JSBNG__scroll\", this._layer.updatePosition.bind(this._layer));\n        },\n        _removeScrollListener: function() {\n            ((this._listener && this._listener.remove()));\n            this._listener = null;\n        }\n    });\n    e.exports = i;\n});\n__d(\"BasicTypeaheadRenderer\", [\"DOM\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\");\n    function h(i, j) {\n        var k = [];\n        if (i.icon) {\n            k.push(g.create(\"img\", {\n                alt: \"\",\n                src: i.icon\n            }));\n        }\n    ;\n    ;\n        if (i.text) {\n            k.push(g.create(\"span\", {\n                className: \"text\"\n            }, [i.text,]));\n        }\n    ;\n    ;\n        if (i.subtext) {\n            k.push(g.create(\"span\", {\n                className: \"subtext\"\n            }, [i.subtext,]));\n        }\n    ;\n    ;\n        var l = g.create(\"li\", {\n            className: ((i.type || \"\"))\n        }, k);\n        l.setAttribute(\"role\", \"option\");\n        if (i.text) {\n            l.setAttribute(\"aria-label\", i.text);\n        }\n    ;\n    ;\n        return l;\n    };\n;\n    h.className = \"basic\";\n    e.exports = h;\n});\n__d(\"TypeaheadView\", [\"event-extensions\",\"ArbiterMixin\",\"ARIA\",\"BasicTypeaheadRenderer\",\"Class\",\"CSS\",\"DOM\",\"Parent\",\"$\",\"copyProperties\",\"ge\",\"tx\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"ARIA\"), i = b(\"BasicTypeaheadRenderer\"), j = b(\"Class\"), k = b(\"CSS\"), l = b(\"DOM\"), m = b(\"Parent\"), n = b(\"$\"), o = b(\"copyProperties\"), p = b(\"ge\"), q = b(\"tx\");\n    function r(s, t) {\n        this.element = this.JSBNG__content = n(s);\n        o(this, t);\n    };\n;\n    o(r.prototype, g, {\n        events: [\"highlight\",\"render\",\"reset\",\"select\",\"beforeRender\",\"next\",\"prev\",],\n        renderer: i,\n        autoSelect: false,\n        accessibleResultsText: \"Autocomplete results are available. Use the up and down arrow keys to navigate the results.\",\n        accessibleEmptyText: \"No autocomplete results are available.\",\n        ignoreMouseover: false,\n        init: function() {\n            this.init = bagofholding;\n            this.initializeEvents();\n            this.reset();\n        },\n        initializeEvents: function() {\n            JSBNG__Event.listen(this.element, {\n                mouseup: this.mouseup.bind(this),\n                mouseover: this.mouseover.bind(this)\n            });\n        },\n        setTypeahead: function(s) {\n            this.typeahead = s;\n        },\n        getElement: function() {\n            return this.element;\n        },\n        mouseup: function(JSBNG__event) {\n            if (((JSBNG__event.button != 2))) {\n                this.select(true);\n                JSBNG__event.kill();\n            }\n        ;\n        ;\n        },\n        mouseover: function(JSBNG__event) {\n            if (this.ignoreMouseover) {\n                this.ignoreMouseover = false;\n                return;\n            }\n        ;\n        ;\n            if (this.visible) {\n                this.highlight(this.getIndex(JSBNG__event));\n            }\n        ;\n        ;\n        },\n        reset: function(s) {\n            if (!s) {\n                this.disableAutoSelect = false;\n            }\n        ;\n        ;\n            this.justRendered = false;\n            this.justShown = false;\n            this.index = -1;\n            this.items = [];\n            this.results = [];\n            this.value = \"\";\n            this.JSBNG__content.innerHTML = \"\";\n            this.inform(\"reset\");\n            return this;\n        },\n        getIndex: function(JSBNG__event) {\n            return this.items.indexOf(m.byTag(JSBNG__event.getTarget(), \"li\"));\n        },\n        JSBNG__getSelection: function() {\n            var s = ((this.results[this.index] || null));\n            return ((this.visible ? s : null));\n        },\n        isEmpty: function() {\n            return !this.results.length;\n        },\n        isVisible: function() {\n            return this.visible;\n        },\n        show: function() {\n            k.show(this.element);\n            if (((this.results && this.results.length))) {\n                if (this.autoSelect) {\n                    h.notify(q._(\"{name} is auto-selected. Use the up and down arrow keys to navigate more results.\", {\n                        JSBNG__name: this.getItemText(this.selected)\n                    }));\n                }\n                 else h.notify(this.accessibleResultsText);\n            ;\n            }\n        ;\n        ;\n            ((this.typeahead && this.element.setAttribute(\"aria-expanded\", \"true\")));\n            this.visible = true;\n            return this;\n        },\n        hide: function() {\n            k.hide(this.element);\n            h.notify(\"\");\n            ((this.typeahead && this.typeahead.setAttribute(\"aria-expanded\", \"false\")));\n            this.visible = false;\n            return this;\n        },\n        render: function(s, t, u) {\n            this.value = s;\n            if (!t.length) {\n                if (((this.results.length && s))) {\n                    h.notify(this.accessibleEmptyText);\n                }\n            ;\n            ;\n                this.reset(true);\n                return;\n            }\n        ;\n        ;\n            this.justRendered = true;\n            if (!this.results.length) {\n                this.justShown = true;\n                if (((((!this.autoSelect && this.isVisible())) && t.length))) {\n                    h.notify(this.accessibleResultsText);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            var v = {\n                results: t,\n                value: s\n            };\n            this.inform(\"beforeRender\", v);\n            t = v.results;\n            var w = this.getDefaultIndex(t);\n            if (((((this.index > 0)) && ((this.index !== this.getDefaultIndex(this.results)))))) {\n                var x = this.results[this.index];\n                for (var y = 0, z = t.length; ((y < z)); ++y) {\n                    if (((x.uid == t[y].uid))) {\n                        w = y;\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            this.results = t;\n            l.setContent(this.JSBNG__content, this.buildResults(t));\n            this.items = this.getItems();\n            this.highlight(w, false);\n            this.inform(\"render\", t);\n        },\n        getItems: function() {\n            return l.scry(this.JSBNG__content, \"li\");\n        },\n        buildResults: function(s) {\n            var t, u = null;\n            if (((typeof this.renderer == \"function\"))) {\n                t = this.renderer;\n                u = ((this.renderer.className || \"\"));\n            }\n             else {\n                t = a.TypeaheadRenderers[this.renderer];\n                u = this.renderer;\n            }\n        ;\n        ;\n            t = t.bind(this);\n            var v = s.map(function(x, y) {\n                return ((x.node || t(x, y)));\n            }), w = l.create(\"ul\", {\n                className: u,\n                id: ((\"typeahead_list_\" + ((this.typeahead ? l.getID(this.typeahead) : l.getID(this.element)))))\n            }, v);\n            w.setAttribute(\"role\", \"listbox\");\n            return w;\n        },\n        getDefaultIndex: function(s) {\n            var t = ((this.autoSelect && !this.disableAutoSelect));\n            return ((((((this.index < 0)) && !t)) ? -1 : 0));\n        },\n        next: function() {\n            this.highlight(((this.index + 1)));\n            this.inform(\"next\", this.selected);\n        },\n        prev: function() {\n            this.highlight(((this.index - 1)));\n            this.inform(\"prev\", this.selected);\n        },\n        getItemText: function(s) {\n            var t = \"\";\n            if (s) {\n                t = s.getAttribute(\"aria-label\");\n                if (!t) {\n                    t = l.getText(s);\n                    s.setAttribute(\"aria-label\", t);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            return t;\n        },\n        setIsViewingSelectedItems: function(s) {\n            this.viewingSelected = s;\n            return this;\n        },\n        getIsViewingSelectedItems: function() {\n            return this.viewingSelected;\n        },\n        highlight: function(s, t) {\n            var u = true;\n            ((this.selected && k.removeClass(this.selected, \"selected\")));\n            if (((s > ((this.items.length - 1))))) {\n                s = -1;\n            }\n             else if (((s < -1))) {\n                s = ((this.items.length - 1));\n            }\n            \n        ;\n        ;\n            if (((((s >= 0)) && ((s < this.items.length))))) {\n                if (((this.selected && ((this.getItemText(this.items[s]) === this.getItemText(this.selected)))))) {\n                    u = false;\n                }\n            ;\n            ;\n                this.selected = this.items[s];\n                k.addClass(this.selected, \"selected\");\n            }\n        ;\n        ;\n            this.index = s;\n            this.disableAutoSelect = ((s == -1));\n            var v = ((s !== -1)), w = this.getItemText(this.selected);\n            if (((((((((s !== -1)) && this.isVisible())) && w)) && this.autoSelect))) {\n                if (this.justShown) {\n                    h.notify(q._(\"{name} is auto-selected. Use the up and down arrow keys to navigate more results.\", {\n                        JSBNG__name: w\n                    }));\n                    this.justRendered = false;\n                    this.justShown = false;\n                    v = false;\n                }\n                 else if (((u && this.justRendered))) {\n                    h.notify(q._(\"{name} is auto-selected.\", {\n                        JSBNG__name: w\n                    }));\n                    this.justRendered = false;\n                    v = false;\n                }\n                \n            ;\n            }\n        ;\n        ;\n            if (((u && v))) {\n                h.announce(w);\n            }\n        ;\n        ;\n            if (((t !== false))) {\n                this.inform(\"highlight\", {\n                    index: s,\n                    selected: this.results[s],\n                    element: this.selected\n                });\n            }\n        ;\n        ;\n        },\n        select: function(s) {\n            var t = this.index, u = this.results[t];\n            if (u) {\n                this.inform(\"select\", {\n                    index: t,\n                    clicked: !!s,\n                    selected: u\n                });\n                this.inform(\"afterSelect\");\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = r;\n});\n__d(\"BucketedTypeaheadView\", [\"Class\",\"DOM\",\"TypeaheadView\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Class\"), h = b(\"DOM\"), i = b(\"TypeaheadView\"), j = b(\"copyProperties\");\n    function k(l, m) {\n        this.parent.construct(this, l, m);\n    };\n;\n    g.extend(k, i);\n    j(k.prototype, {\n        render: function(l, m, n) {\n            m = this.buildBuckets(l, m);\n            return this.parent.render(l, m, n);\n        },\n        highlight: function(l, m) {\n            if (((((l == -1)) && ((this.index !== 0))))) {\n                l = this.index;\n            }\n        ;\n        ;\n            if (((((((l >= 0)) && ((l < this.items.length)))) && ((this.results[l].type == \"header\"))))) {\n                l = ((l + 1));\n            }\n        ;\n        ;\n            this.parent.highlight(l, m);\n        },\n        buildBuckets: function(l, m) {\n            if (!this.typeObjects) {\n                return m;\n            }\n        ;\n        ;\n            var n = [], o = {\n            };\n            for (var p = 0; ((p < m.length)); ++p) {\n                var q = m[p], r = ((q.render_type || q.type));\n                if (!o.hasOwnProperty(r)) {\n                    o[r] = n.length;\n                    n.push([this.buildBucketHeader(r),]);\n                }\n            ;\n            ;\n                q.classNames = r;\n                q.groupIndex = o[r];\n                q.indexInGroup = ((n[q.groupIndex].length - 1));\n                n[q.groupIndex].push(q);\n            };\n        ;\n            var s = [];\n            for (var t = 0; ((t < n.length)); ++t) {\n                s = s.concat(n[t]);\n            ;\n            };\n        ;\n            return s;\n        },\n        buildBucketHeader: function(l) {\n            var m = this.typeObjects[l];\n            if (m.markup) {\n                m.text = m.markup;\n                delete m.markup;\n            }\n        ;\n        ;\n            return this.typeObjects[l];\n        },\n        buildResults: function(l) {\n            var m = this.parent.buildResults(l);\n            if (this.typeObjects) {\n                return h.create(\"div\", {\n                    className: \"bucketed\"\n                }, [m,]);\n            }\n             else return m\n        ;\n        },\n        select: function(l) {\n            var m = this.results[this.index];\n            if (((m && ((m.type != \"header\"))))) {\n                this.parent.select(l);\n            }\n        ;\n        ;\n        },\n        getDefaultIndex: function(l) {\n            var m = ((this.autoSelect && !this.disableAutoSelect)), n = ((((l.length === 0)) ? -1 : ((((l[0].type == \"header\")) ? 1 : 0))));\n            return ((((((this.index < 0)) && !m)) ? -1 : n));\n        },\n        prev: function() {\n            var l = this.results[((this.index - 1))];\n            if (((l && ((l.type == \"header\"))))) {\n                this.index--;\n            }\n        ;\n        ;\n            return this.parent.prev();\n        },\n        next: function() {\n            var l = this.results[((this.index + 1))];\n            if (((l && ((l.type == \"header\"))))) {\n                this.index++;\n            }\n        ;\n        ;\n            return this.parent.next();\n        }\n    });\n    e.exports = k;\n});\n__d(\"ContextualTypeaheadView\", [\"event-extensions\",\"Class\",\"ContextualLayer\",\"ContextualLayerAutoFlip\",\"ContextualLayerHideOnScroll\",\"CSS\",\"DOM\",\"Style\",\"BucketedTypeaheadView\",\"Vector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Class\"), h = b(\"ContextualLayer\"), i = b(\"ContextualLayerAutoFlip\"), j = b(\"ContextualLayerHideOnScroll\"), k = b(\"CSS\"), l = b(\"DOM\"), m = b(\"Style\"), n = b(\"BucketedTypeaheadView\"), o = b(\"Vector\"), p = b(\"copyProperties\");\n    function q(r, s) {\n        this.parent.construct(this, r, s);\n    };\n;\n    g.extend(q, n);\n    p(q.prototype, {\n        init: function() {\n            this.initializeLayer();\n            this.parent.init();\n        },\n        initializeLayer: function() {\n            this.context = this.getContext();\n            this.wrapper = l.create(\"div\");\n            l.appendContent(this.wrapper, this.element);\n            k.addClass(this.element, \"uiContextualTypeaheadView\");\n            this.layer = new h({\n                context: this.context,\n                position: \"below\",\n                causalElement: this.causalElement\n            }, this.wrapper);\n            this.layer.enableBehavior(j);\n            if (m.isFixed(this.context)) {\n                this.layer.enableBehavior(i);\n            }\n        ;\n        ;\n            this.subscribe(\"render\", this.renderLayer.bind(this));\n        },\n        show: function() {\n            this.layer.show();\n            o.getElementDimensions(this.context).setElementWidth(this.wrapper);\n            return this.parent.show();\n        },\n        hide: function() {\n            this.layer.hide();\n            return this.parent.hide();\n        },\n        renderLayer: function() {\n            if (!this.isVisible()) {\n                return;\n            }\n        ;\n        ;\n            if (this.layer.isShown()) {\n                this.layer.updatePosition();\n            }\n             else this.layer.show();\n        ;\n        ;\n        },\n        getContext: function() {\n            return this.element.parentNode;\n        }\n    });\n    e.exports = q;\n});\n__d(\"CustomPrivacyOption\", [\"event-extensions\",\"AsyncRequest\",\"Dialog\",\"DOM\",\"Form\",\"Parent\",\"Selector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"AsyncRequest\"), h = b(\"Dialog\"), i = b(\"DOM\"), j = b(\"Form\"), k = b(\"Parent\"), l = b(\"Selector\"), m = b(\"copyProperties\");\n    function n() {\n    \n    };\n;\n    m(n, {\n        _instances: {\n        },\n        update: function(o, p, q, r) {\n            var s = n._instances[o];\n            s._update(p, q)._updateOption(q, r);\n            Arbiter.inform(\"Form/change\", {\n                node: s._container\n            });\n        },\n        getData: function(o) {\n            return n._instances[o]._privacyData;\n        }\n    });\n    m(n.prototype, {\n        init: function(o, p, q, r, s) {\n            (function() {\n                var t = this.initCustomState(o, p);\n                if (!t) {\n                    return;\n                }\n            ;\n            ;\n                JSBNG__Event.listen(t, \"click\", function(JSBNG__event) {\n                    this.openCustomDialog(JSBNG__event, o, q, s);\n                }.bind(this));\n                this._initSelector(t, r);\n            }).bind(this).defer();\n        },\n        _initSelector: function(o, p) {\n            this._selector = k.byClass(o, \"uiSelector\");\n            l.listen(this._selector, \"select\", function(q) {\n                if (((q.option._id != this._id))) {\n                    this.clearCustomState();\n                }\n            ;\n            ;\n            }.bind(this));\n            if (p) {\n                l.setButtonTooltip(this._selector, p);\n            }\n        ;\n        ;\n        },\n        _updateOption: function(o, p) {\n            var q = ((l.getOption(this._selector, o) || l.getOption(this._selector, ((PrivacyBaseValue.CUSTOM + \"\")))));\n            Arbiter.inform(\"CustomPrivacyOption/update\", {\n                selector: this._selector,\n                option: q,\n                tooltip: p\n            });\n            return this;\n        },\n        _update: function(o, p) {\n            var q = ((((p == PrivacyBaseValue.CUSTOM)) || !l.getOption(this._selector, p))), r = this._selector.getAttribute(\"data-name\");\n            this.updateCustomState(o, q, r);\n            return this;\n        },\n        initCustomState: function(o, p) {\n            var q = ge(o);\n            if (!q) {\n                return q;\n            }\n        ;\n        ;\n            n._instances[o] = this;\n            this._container = i.JSBNG__find(q, \".customPrivacyInputs\");\n            this._id = p;\n            this._privacyData = {\n            };\n            var r = j.serialize(this._container);\n            if (r.audience) {\n                this._privacyData = r.audience[p];\n            }\n        ;\n        ;\n            return q;\n        },\n        openCustomDialog: function(JSBNG__event, o, p, q) {\n            var r = new g(\"/ajax/privacy/custom_dialog/\").setData({\n                option_id: o,\n                id: this._id,\n                privacy_data: this._privacyData,\n                explain_tags: p,\n                autosave: q\n            });\n            new h().setAsync(r).setModal(true).setCausalElement(JSBNG__event.getTarget()).show();\n        },\n        updateCustomState: function(o, p, q) {\n            this.clearCustomState();\n            this._privacyData = m({\n            }, o);\n            if (p) {\n                if (q) {\n                    q = q.slice(0, -\"[value]\".length);\n                    var r = {\n                    };\n                    r[q] = o;\n                    j.createHiddenInputs(r, this._container, null, true);\n                }\n            ;\n            }\n        ;\n        ;\n        },\n        clearCustomState: function() {\n            this._privacyData = {\n            };\n            i.empty(this._container);\n        }\n    });\n    e.exports = n;\n});\n__d(\"TypeaheadUtil\", [\"function-extensions\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = /[ ]+/g, h = /[^ ]+/g, i = /[.,+*?$|#{}()\\^\\-\\[\\]\\\\\\/!@%'\"~=<>_:;\\u2010\\u2011\\u2012\\u2013\\u2014\\u2015\\u30fb\\uff1a]/g, j = {\n    }, k = {\n        a: \"\\u0430 \\u00e0 \\u00e1 \\u00e2 \\u00e3 \\u00e4 \\u00e5\",\n        b: \"\\u0431\",\n        c: \"\\u0446 \\u00e7 \\u010d\",\n        d: \"\\u0434 \\u00f0 \\u010f \\u0111\",\n        e: \"\\u044d \\u0435 \\u00e8 \\u00e9 \\u00ea \\u00eb \\u011b\",\n        f: \"\\u0444\",\n        g: \"\\u0433 \\u011f\",\n        h: \"\\u0445 \\u0127\",\n        i: \"\\u0438 \\u00ec \\u00ed \\u00ee \\u00ef \\u0131\",\n        j: \"\\u0439\",\n        k: \"\\u043a \\u0138\",\n        l: \"\\u043b \\u013e \\u013a \\u0140 \\u0142\",\n        m: \"\\u043c\",\n        n: \"\\u043d \\u00f1 \\u0148 \\u0149 \\u014b\",\n        o: \"\\u043e \\u00f8 \\u00f6 \\u00f5 \\u00f4 \\u00f3 \\u00f2\",\n        p: \"\\u043f\",\n        r: \"\\u0440 \\u0159 \\u0155\",\n        s: \"\\u0441 \\u015f \\u0161 \\u017f\",\n        t: \"\\u0442 \\u0165 \\u0167 \\u00fe\",\n        u: \"\\u0443 \\u044e \\u00fc \\u00fb \\u00fa \\u00f9 \\u016f\",\n        v: \"\\u0432\",\n        y: \"\\u044b \\u00ff \\u00fd\",\n        z: \"\\u0437 \\u017e\",\n        ae: \"\\u00e6\",\n        oe: \"\\u0153\",\n        ts: \"\\u0446\",\n        ch: \"\\u0447\",\n        ij: \"\\u0133\",\n        sh: \"\\u0448\",\n        ss: \"\\u00df\",\n        ya: \"\\u044f\"\n    };\n    for (var l in k) {\n        var m = k[l].split(\" \");\n        for (var n = 0; ((n < m.length)); n++) {\n            j[m[n]] = l;\n        ;\n        };\n    ;\n    };\n;\n    var o = {\n    };\n    function p(v) {\n        return ((v ? v.replace(i, \" \") : \"\"));\n    };\n;\n    function q(v) {\n        v = ((\"\" + v)).toLowerCase();\n        var w = \"\", x = \"\";\n        for (var y = v.length; y--; ) {\n            x = v.charAt(y);\n            w = ((((j[x] || x)) + w));\n        };\n    ;\n        return w.replace(g, \" \");\n    };\n;\n    function r(v) {\n        var w = [], x = h.exec(v);\n        while (x) {\n            x = x[0];\n            w.push(x);\n            x = h.exec(v);\n        };\n    ;\n        return w;\n    };\n;\n    function s(v, w) {\n        v = ((\"\" + v));\n        if (!o.hasOwnProperty(v)) {\n            var x = q(v), y = p(x);\n            o[v] = {\n                value: v,\n                flatValue: x,\n                tokens: r(y),\n                isPrefixQuery: ((y && ((y[((y.length - 1))] != \" \"))))\n            };\n        }\n    ;\n    ;\n        if (((w && ((typeof o[v].sortedTokens == \"undefined\"))))) {\n            o[v].sortedTokens = o[v].tokens.slice();\n            o[v].sortedTokens.sort(function(z, aa) {\n                return ((aa.length - z.length));\n            });\n        }\n    ;\n    ;\n        return o[v];\n    };\n;\n    function t(v, w, x) {\n        var y = s(w, ((v == \"prefix\"))), z = ((((v == \"prefix\")) ? y.sortedTokens : y.tokens)), aa = s(x).tokens, ba = {\n        }, ca = ((((y.isPrefixQuery && ((v == \"query\")))) ? ((z.length - 1)) : null)), da = function(ea, fa) {\n            for (var ga = 0; ((ga < aa.length)); ++ga) {\n                var ha = aa[ga];\n                if (((!ba[ga] && ((((ha == ea)) || ((((((((v == \"query\")) && ((fa === ca)))) || ((v == \"prefix\")))) && ((ha.indexOf(ea) === 0))))))))) {\n                    return (ba[ga] = true);\n                }\n            ;\n            ;\n            };\n        ;\n            return false;\n        };\n        return ((z.length && z.every(da)));\n    };\n;\n    var u = {\n        parse: s,\n        isExactMatch: t.curry(\"exact\"),\n        isQueryMatch: t.curry(\"query\"),\n        isPrefixMatch: t.curry(\"prefix\")\n    };\n    e.exports = u;\n});\n__d(\"DataSource\", [\"array-extensions\",\"ArbiterMixin\",\"AsyncRequest\",\"Class\",\"TypeaheadUtil\",\"copyProperties\",\"createArrayFrom\",\"createObjectFrom\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"AsyncRequest\"), i = b(\"Class\"), j = b(\"TypeaheadUtil\"), k = b(\"copyProperties\"), l = b(\"createArrayFrom\"), m = b(\"createObjectFrom\");\n    function n(o) {\n        this._maxResults = ((o.maxResults || 10));\n        this.token = o.token;\n        this.queryData = ((o.queryData || {\n        }));\n        this.queryEndpoint = ((o.queryEndpoint || \"\"));\n        this.bootstrapData = ((o.bootstrapData || {\n        }));\n        this.bootstrapEndpoint = ((o.bootstrapEndpoint || \"\"));\n        this._exclusions = ((o.exclusions || []));\n        this._indexedFields = ((o.indexedFields || [\"text\",\"tokens\",]));\n        this._alwaysPrefixMatch = ((o.alwaysPrefixMatch || false));\n        this._deduplicationKey = ((o.deduplicationKey || null));\n        this._minExactMatchLength = 4;\n        this._filters = [];\n    };\n;\n    k(n.prototype, g, {\n        events: [\"bootstrap\",\"query\",\"respond\",],\n        init: function() {\n            this.init = bagofholding;\n            this._fields = m(this._indexedFields);\n            this._activeQueries = 0;\n            this.dirty();\n        },\n        dirty: function() {\n            this.value = \"\";\n            this._bootstrapped = false;\n            this._bootstrapping = false;\n            this._data = {\n            };\n            this.localCache = {\n            };\n            this.queryCache = {\n            };\n            this.inform(\"dirty\", {\n            });\n            return this;\n        },\n        bootstrap: function() {\n            if (this._bootstrapped) {\n                return;\n            }\n        ;\n        ;\n            this.bootstrapWithoutToken();\n            this._bootstrapped = true;\n            this._bootstrapping = true;\n            this.inform(\"bootstrap\", {\n                bootstrapping: true\n            });\n        },\n        bootstrapWithoutToken: function() {\n            this.fetch(this.bootstrapEndpoint, this.bootstrapData, {\n                bootstrap: true,\n                token: this.token\n            });\n        },\n        bootstrapWithToken: function() {\n            var o = k({\n            }, this.bootstrapData);\n            o.token = this.token;\n            this.fetch(this.bootstrapEndpoint, o, {\n                bootstrap: true,\n                replaceCache: true\n            });\n        },\n        query: function(o, p, q) {\n            this.inform(\"beforeQuery\", {\n                value: o\n            });\n            var r = this.buildUids(o, [], q), s = this.respond(o, r);\n            this.value = o;\n            this.inform(\"query\", {\n                value: o,\n                results: s\n            });\n            var t = j.parse(o).flatValue;\n            if (((((((((p || !t)) || !this.queryEndpoint)) || this.getQueryCache().hasOwnProperty(t))) || !this.shouldFetchMoreResults(s)))) {\n                return false;\n            }\n        ;\n        ;\n            this.inform(\"queryEndpoint\", {\n                value: o\n            });\n            this.fetch(this.queryEndpoint, this.getQueryData(o, r), {\n                value: o,\n                exclusions: q\n            });\n            return true;\n        },\n        shouldFetchMoreResults: function(o) {\n            return ((o.length < this._maxResults));\n        },\n        getQueryData: function(o, p) {\n            var q = k({\n                value: o\n            }, ((this.queryData || {\n            })));\n            p = ((p || []));\n            if (p.length) {\n                q.existing_ids = p.join(\",\");\n            }\n        ;\n        ;\n            if (this._bootstrapping) {\n                q.bsp = true;\n            }\n        ;\n        ;\n            return q;\n        },\n        setQueryData: function(o, p) {\n            if (p) {\n                this.queryData = {\n                };\n            }\n        ;\n        ;\n            k(this.queryData, o);\n            return this;\n        },\n        setBootstrapData: function(o, p) {\n            if (p) {\n                this.bootstrapData = {\n                };\n            }\n        ;\n        ;\n            k(this.bootstrapData, o);\n            return this;\n        },\n        getExclusions: function() {\n            return l(this._exclusions);\n        },\n        setExclusions: function(o) {\n            this._exclusions = ((o || []));\n        },\n        addFilter: function(o) {\n            var p = this._filters;\n            p.push(o);\n            return {\n                remove: function() {\n                    p.splice(p.indexOf(o), 1);\n                }\n            };\n        },\n        clearFilters: function() {\n            this._filters = [];\n        },\n        respond: function(o, p, q) {\n            var r = this.buildData(p);\n            this.inform(\"respond\", {\n                value: o,\n                results: r,\n                isAsync: !!q\n            });\n            return r;\n        },\n        asyncErrorHandler: bagofholding,\n        fetch: function(o, p, q) {\n            if (!o) {\n                return;\n            }\n        ;\n        ;\n            var r = new h().setURI(o).setData(p).setMethod(\"GET\").setReadOnly(true).setHandler(function(s) {\n                this.fetchHandler(s, ((q || {\n                })));\n            }.bind(this));\n            if (((o === this.queryEndpoint))) {\n                r.setFinallyHandler(function() {\n                    this._activeQueries--;\n                    if (!this._activeQueries) {\n                        this.inform(\"activity\", {\n                            activity: false\n                        });\n                    }\n                ;\n                ;\n                }.bind(this));\n            }\n        ;\n        ;\n            r.setErrorHandler(this.asyncErrorHandler);\n            this.inform(\"beforeFetch\", {\n                request: r,\n                fetch_context: q\n            });\n            r.send();\n            if (((o === this.queryEndpoint))) {\n                if (!this._activeQueries) {\n                    this.inform(\"activity\", {\n                        activity: true\n                    });\n                }\n            ;\n            ;\n                this._activeQueries++;\n            }\n        ;\n        ;\n        },\n        fetchHandler: function(o, p) {\n            var q = p.value, r = p.exclusions;\n            if (((!q && p.replaceCache))) {\n                this.localCache = {\n                };\n            }\n        ;\n        ;\n            this.addEntries(o.getPayload().entries, q);\n            this.inform(\"fetchComplete\", {\n                response: o,\n                value: q,\n                fetch_context: p\n            });\n            var s = ((((!q && this.value)) ? this.value : q));\n            this.respond(s, this.buildUids(s, [], r), true);\n            if (!q) {\n                if (this._bootstrapping) {\n                    this._bootstrapping = false;\n                    this.inform(\"bootstrap\", {\n                        bootstrapping: false\n                    });\n                }\n            ;\n            ;\n                if (((p.token && ((o.getPayload().token !== p.token))))) {\n                    this.bootstrapWithToken();\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        addEntries: function(o, p) {\n            var q = this.processEntries(l(((o || []))), p), r = this.buildUids(p, q);\n            if (p) {\n                var s = this.getQueryCache();\n                s[j.parse(p).flatValue] = r;\n            }\n             else this.fillCache(r);\n        ;\n        ;\n        },\n        processEntries: function(o, p) {\n            return o.map(function(q, r) {\n                var s = (q.uid = ((q.uid + \"\"))), t = this.getEntry(s);\n                if (!t) {\n                    t = q;\n                    t.query = p;\n                    this.setEntry(s, t);\n                }\n                 else k(t, q);\n            ;\n            ;\n                ((((t.index === undefined)) && (t.index = r)));\n                return s;\n            }, this);\n        },\n        getAllEntries: function() {\n            return ((this._data || {\n            }));\n        },\n        getEntry: function(o) {\n            return ((this._data[o] || null));\n        },\n        setEntry: function(o, p) {\n            this._data[o] = p;\n        },\n        fillCache: function(o) {\n            var p = this.localCache;\n            o.forEach(function(q) {\n                var r = this.getEntry(q);\n                if (!r) {\n                    return;\n                }\n            ;\n            ;\n                r.bootstrapped = true;\n                var s = j.parse(this.getTextToIndex(r)).tokens;\n                for (var t = 0, u = s.length; ((t < u)); ++t) {\n                    var v = s[t];\n                    if (!p.hasOwnProperty(v)) {\n                        p[v] = {\n                        };\n                    }\n                ;\n                ;\n                    p[v][q] = true;\n                };\n            ;\n            }, this);\n        },\n        getTextToIndex: function(o) {\n            if (((o.textToIndex && !o.needs_update))) {\n                return o.textToIndex;\n            }\n        ;\n        ;\n            var p = [];\n            for (var q in this._fields) {\n                var r = o[q];\n                if (r) {\n                    p.push(((r.join ? r.join(\" \") : r)));\n                }\n            ;\n            ;\n            };\n        ;\n            o.needs_update = false;\n            return (o.textToIndex = p.join(\" \"));\n        },\n        mergeUids: function(o, p, q, r) {\n            var s = function(t, u) {\n                var v = this.getEntry(t), w = this.getEntry(u);\n                if (((v.extended_match !== w.extended_match))) {\n                    return ((v.extended_match ? 1 : -1));\n                }\n            ;\n            ;\n                if (((v.index !== w.index))) {\n                    return ((v.index - w.index));\n                }\n            ;\n            ;\n                if (((v.text.length !== w.text.length))) {\n                    return ((v.text.length - w.text.length));\n                }\n            ;\n            ;\n                return ((v.uid < w.uid));\n            }.bind(this);\n            this._checkExtendedMatch(r, o);\n            return this.deduplicateByKey(o.sort(s).concat(p, q));\n        },\n        _checkExtendedMatch: function(o, p) {\n            var q = ((this._alwaysPrefixMatch ? j.isPrefixMatch : j.isQueryMatch));\n            for (var r = 0; ((r < p.length)); ++r) {\n                var s = this.getEntry(p[r]);\n                s.extended_match = ((s.tokens ? !q(o, s.text) : false));\n            };\n        ;\n        },\n        buildUids: function(o, p, q) {\n            if (!p) {\n                p = [];\n            }\n        ;\n        ;\n            if (!o) {\n                return p;\n            }\n        ;\n        ;\n            if (!q) {\n                q = [];\n            }\n        ;\n        ;\n            var r = this.buildCacheResults(o, this.localCache), s = this.buildQueryResults(o), t = this.mergeUids(r, s, p, o), u = m(q.concat(this._exclusions)), v = t.filter(function(w) {\n                if (((u.hasOwnProperty(w) || !this.getEntry(w)))) {\n                    return false;\n                }\n            ;\n            ;\n                for (var x = 0; ((x < this._filters.length)); ++x) {\n                    if (!this._filters[x](this.getEntry(w), o)) {\n                        return false;\n                    }\n                ;\n                ;\n                };\n            ;\n                return (u[w] = true);\n            }, this);\n            return this.uidsIncludingExact(o, v, u);\n        },\n        uidsIncludingExact: function(o, p, q) {\n            var r = p.length;\n            if (((((o.length < this._minExactMatchLength)) || ((r <= this._maxResults))))) {\n                return p;\n            }\n        ;\n        ;\n            for (var s = 0; ((s < r)); ++s) {\n                var t = this.getEntry(p[s]);\n                ((t.text_lower || (t.text_lower = t.text.toLowerCase())));\n                if (((t.text_lower === j.parse(o).flatValue))) {\n                    if (((s >= this._maxResults))) {\n                        var u = p.splice(s, 1);\n                        p.splice(((this._maxResults - 1)), 0, u);\n                    }\n                ;\n                ;\n                    break;\n                }\n            ;\n            ;\n            };\n        ;\n            return p;\n        },\n        buildData: function(o) {\n            var p = [], q = Math.min(o.length, this._maxResults);\n            for (var r = 0; ((r < q)); ++r) {\n                p.push(this.getEntry(o[r]));\n            ;\n            };\n        ;\n            return p;\n        },\n        findQueryCache: function(o) {\n            var p = 0, q = null, r = this.getQueryCache();\n            for (var s in r) {\n                if (((((o.indexOf(s) === 0)) && ((s.length > p))))) {\n                    p = s.length;\n                    q = s;\n                }\n            ;\n            ;\n            };\n        ;\n            return ((r[q] || []));\n        },\n        buildQueryResults: function(o) {\n            var p = j.parse(o).flatValue, q = this.findQueryCache(p);\n            if (this.getQueryCache().hasOwnProperty(p)) {\n                return q;\n            }\n        ;\n        ;\n            return this.filterQueryResults(o, q);\n        },\n        filterQueryResults: function(o, p) {\n            var q = ((this._alwaysPrefixMatch ? j.isPrefixMatch : j.isQueryMatch));\n            return p.filter(function(r) {\n                return q(o, this.getTextToIndex(this.getEntry(r)));\n            }, this);\n        },\n        buildCacheResults: function(o, p) {\n            var q = j.parse(o, this._alwaysPrefixMatch), r = ((this._alwaysPrefixMatch ? q.sortedTokens : q.tokens)), s = r.length, t = ((q.isPrefixQuery ? ((s - 1)) : null)), u = {\n            }, v = {\n            }, w = {\n            }, x = [], y = false, z = {\n            }, aa = 0;\n            for (var ba = 0; ((ba < s)); ++ba) {\n                var ca = r[ba];\n                if (!z.hasOwnProperty(ca)) {\n                    aa++;\n                    z[ca] = true;\n                }\n                 else continue;\n            ;\n            ;\n                for (var da in p) {\n                    if (((((!u.hasOwnProperty(da) && ((da === ca)))) || ((((this._alwaysPrefixMatch || ((t === ba)))) && ((da.indexOf(ca) === 0))))))) {\n                        if (((da === ca))) {\n                            if (v.hasOwnProperty(da)) {\n                                y = true;\n                            }\n                        ;\n                        ;\n                            u[da] = true;\n                        }\n                         else {\n                            if (((u.hasOwnProperty(da) || v.hasOwnProperty(da)))) {\n                                y = true;\n                            }\n                        ;\n                        ;\n                            v[da] = true;\n                        }\n                    ;\n                    ;\n                        for (var ea in p[da]) {\n                            if (((((ba === 0)) || ((w.hasOwnProperty(ea) && ((w[ea] == ((aa - 1))))))))) {\n                                w[ea] = aa;\n                            }\n                        ;\n                        ;\n                        };\n                    ;\n                    }\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n            for (var fa in w) {\n                if (((w[fa] == aa))) {\n                    x.push(fa);\n                }\n            ;\n            ;\n            };\n        ;\n            if (((y || ((aa < s))))) {\n                x = this.filterQueryResults(o, x);\n            }\n        ;\n        ;\n            return x;\n        },\n        deduplicateByKey: function(o) {\n            if (!this._deduplicationKey) {\n                return o;\n            }\n        ;\n        ;\n            var p = m(o.map(this._getDeduplicationKey.bind(this)), o);\n            return o.filter(function(q) {\n                return ((p[this._getDeduplicationKey(q)] == q));\n            }.bind(this));\n        },\n        _getDeduplicationKey: function(o) {\n            var p = this.getEntry(o);\n            return ((p[this._deduplicationKey] || ((((\"__\" + o)) + \"__\"))));\n        },\n        getQueryCache: function() {\n            return this.queryCache;\n        },\n        setMaxResults: function(o) {\n            this._maxResults = o;\n            ((this.value && this.respond(this.value, this.buildUids(this.value))));\n        },\n        updateToken: function(o) {\n            this.token = o;\n            this.dirty();\n            return this;\n        }\n    });\n    e.exports = n;\n});\n__d(\"Dcode\", [], function(a, b, c, d, e, f) {\n    var g, h = {\n    }, i = {\n        _: \"%\",\n        A: \"%2\",\n        B: \"000\",\n        C: \"%7d\",\n        D: \"%7b%22\",\n        E: \"%2c%22\",\n        F: \"%22%3a\",\n        G: \"%2c%22ut%22%3a1\",\n        H: \"%2c%22bls%22%3a\",\n        I: \"%2c%22n%22%3a%22%\",\n        J: \"%22%3a%7b%22i%22%3a0%7d\",\n        K: \"%2c%22pt%22%3a0%2c%22vis%22%3a\",\n        L: \"%2c%22ch%22%3a%7b%22h%22%3a%22\",\n        M: \"%7b%22v%22%3a2%2c%22time%22%3a1\",\n        N: \".channel%22%2c%22sub%22%3a%5b\",\n        O: \"%2c%22sb%22%3a1%2c%22t%22%3a%5b\",\n        P: \"%2c%22ud%22%3a100%2c%22lc%22%3a0\",\n        Q: \"%5d%2c%22f%22%3anull%2c%22uct%22%3a\",\n        R: \".channel%22%2c%22sub%22%3a%5b1%5d\",\n        S: \"%22%2c%22m%22%3a0%7d%2c%7b%22i%22%3a\",\n        T: \"%2c%22blc%22%3a1%2c%22snd%22%3a1%2c%22ct%22%3a\",\n        U: \"%2c%22blc%22%3a0%2c%22snd%22%3a1%2c%22ct%22%3a\",\n        V: \"%2c%22blc%22%3a0%2c%22snd%22%3a0%2c%22ct%22%3a\",\n        W: \"%2c%22s%22%3a0%2c%22blo%22%3a0%7d%2c%22bl%22%3a%7b%22ac%22%3a\",\n        X: \"%2c%22ri%22%3a0%7d%2c%22state%22%3a%7b%22p%22%3a0%2c%22ut%22%3a1\",\n        Y: \"%2c%22pt%22%3a0%2c%22vis%22%3a1%2c%22bls%22%3a0%2c%22blc%22%3a0%2c%22snd%22%3a1%2c%22ct%22%3a\",\n        Z: \"%2c%22sb%22%3a1%2c%22t%22%3a%5b%5d%2c%22f%22%3anull%2c%22uct%22%3a0%2c%22s%22%3a0%2c%22blo%22%3a0%7d%2c%22bl%22%3a%7b%22ac%22%3a\"\n    };\n    (function() {\n        var k = [];\n        for (var l in i) {\n            h[i[l]] = l;\n            k.push(i[l]);\n        };\n    ;\n        k.reverse();\n        g = new RegExp(k.join(\"|\"), \"g\");\n    })();\n    var j = {\n        encode: function(k) {\n            return encodeURIComponent(k).replace(/([_A-Z])|%../g, function(l, m) {\n                return ((m ? ((\"%\" + m.charCodeAt(0).toString(16))) : l));\n            }).toLowerCase().replace(g, function(l) {\n                return h[l];\n            });\n        },\n        decode: function(k) {\n            return decodeURIComponent(k.replace(/[_A-Z]/g, function(l) {\n                return i[l];\n            }));\n        }\n    };\n    e.exports = j;\n});\n__d(\"DialogHideOnSuccess\", [\"copyProperties\",\"CSS\",\"cx\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\"), h = b(\"CSS\"), i = b(\"cx\");\n    function j(k) {\n        this._layer = k;\n    };\n;\n    g(j.prototype, {\n        _subscription: null,\n        enable: function() {\n            this._subscription = this._layer.subscribe(\"success\", this._handle.bind(this));\n        },\n        disable: function() {\n            this._subscription.unsubscribe();\n            this._subscription = null;\n        },\n        _handle: function(k, JSBNG__event) {\n            if (h.hasClass(JSBNG__event.getTarget(), \"-cx-PRIVATE-uiDialog__form\")) {\n                this._layer.hide();\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = j;\n});\n__d(\"DocRPC\", [], function(a, b, c, d, e, f) {\n    var g = {\n        _apis: {\n        },\n        _dispatch: function(h) {\n            var i;\n            try {\n                h = JSON.parse(h);\n            } catch (j) {\n                throw new Error(((((\"DocRPC unparsable dispatch: \\\"\" + h)) + \"\\\"\")));\n            };\n        ;\n            if (g._apis.hasOwnProperty(h.api)) {\n                var k = g._apis[h.api];\n                if (k[h.method]) {\n                    i = k[h.method].apply(k, h.args);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            if (((i === undefined))) {\n                i = null;\n            }\n        ;\n        ;\n            return JSON.stringify(i);\n        },\n        publish: function(h, i) {\n            g._apis[i] = h;\n        },\n        proxy: function(h, i, j) {\n            var k = {\n            };\n            j.forEach(function(l) {\n                k[l] = function() {\n                    var m = {\n                        api: i,\n                        method: l,\n                        args: Array.prototype.slice.call(arguments)\n                    }, n = h.DocRPC._dispatch(JSON.stringify(m));\n                    if (((typeof (n) == \"string\"))) {\n                        try {\n                            n = JSON.parse(n);\n                        } catch (o) {\n                            throw new Error(((((((((((((\"DocRPC \" + i)) + \".\")) + l)) + \" unparsable return: \\\"\")) + n)) + \"\\\"\")));\n                        };\n                    }\n                ;\n                ;\n                    return n;\n                };\n            });\n            return k;\n        }\n    };\n    e.exports = a.DocRPC = g;\n});\n__d(\"DocumentTitle\", [\"Arbiter\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = JSBNG__document.title, i = null, j = 1500, k = [], l = 0, m = null, n = false;\n    function o() {\n        if (((k.length > 0))) {\n            if (!n) {\n                p(k[l].title);\n                l = ((++l % k.length));\n            }\n             else q();\n        ;\n        ;\n        }\n         else {\n            JSBNG__clearInterval(m);\n            m = null;\n            q();\n        }\n    ;\n    ;\n    };\n;\n    function p(s) {\n        JSBNG__document.title = s;\n        n = true;\n    };\n;\n    function q() {\n        r.set(((i || h)), true);\n        n = false;\n    };\n;\n    var r = {\n        get: function() {\n            return h;\n        },\n        set: function(s, t) {\n            JSBNG__document.title = s;\n            if (!t) {\n                h = s;\n                i = null;\n                g.inform(\"update_title\", s);\n            }\n             else i = s;\n        ;\n        ;\n        },\n        blink: function(s) {\n            var t = {\n                title: s\n            };\n            k.push(t);\n            if (((m === null))) {\n                m = JSBNG__setInterval(o, j);\n            }\n        ;\n        ;\n            return {\n                JSBNG__stop: function() {\n                    var u = k.indexOf(t);\n                    if (((u >= 0))) {\n                        k.splice(u, 1);\n                        if (((l > u))) {\n                            l--;\n                        }\n                         else if (((((l == u)) && ((l == k.length))))) {\n                            l = 0;\n                        }\n                        \n                    ;\n                    ;\n                    }\n                ;\n                ;\n                }\n            };\n        }\n    };\n    e.exports = r;\n});\n__d(\"Emote\", [\"DOM\",\"Env\",\"htmlize\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"Env\"), i = b(\"htmlize\"), j = e.exports = {\n        _initialized: false,\n        _imageBase: null,\n        _emoteMap: null,\n        _emoteOrderMap: null,\n        _fbidEmoticonPattern: \"\\\\[\\\\[([A-Za-z0-9\\\\.]+)\\\\]\\\\]\",\n        _fbidEmoticonRegex: null,\n        _imageURLs: null,\n        _regex: null,\n        _regexWithoutFBIDs: null,\n        _init: function() {\n            var k = h.static_base;\n            j._imageBase = ((k + \"images/emote/\"));\n            j._blankImgSrc = ((k + \"images/blank.gif\"));\n            var l = [\"smile\",\"frown\",\"tongue\",\"grin\",\"gasp\",\"wink\",\"glasses\",\"sunglasses\",\"grumpy\",\"unsure\",\"cry\",\"devil\",\"angel\",\"kiss\",\"heart\",\"kiki\",\"squint\",\"confused\",\"upset\",\"pacman\",\"colonthree\",\"like\",];\n            j._emoteMap = {\n                \":-)\": [\"\\\\:\\\\-\\\\)\",\"smile\",],\n                \":)\": [\"\\\\:\\\\)\",\"smile\",],\n                \":]\": [\"\\\\:\\\\]\",\"smile\",],\n                \"=)\": [\"=\\\\)\",\"smile\",],\n                \":-(\": [\"\\\\:\\\\-\\\\(\",\"frown\",],\n                \":(\": [\"\\\\:\\\\(\",\"frown\",],\n                \":[\": [\"\\\\:\\\\[\",\"frown\",],\n                \"=(\": [\"=\\\\(\",\"frown\",],\n                \":-P\": [\"\\\\:\\\\-P\",\"tongue\",],\n                \":P\": [\"\\\\:P\",\"tongue\",],\n                \":-p\": [\"\\\\:\\\\-p\",\"tongue\",],\n                \":p\": [\"\\\\:p\",\"tongue\",],\n                \"=P\": [\"=P\",\"tongue\",],\n                \":-D\": [\"\\\\:\\\\-D\",\"grin\",],\n                \":D\": [\"\\\\:D\",\"grin\",],\n                \"=D\": [\"=D\",\"grin\",],\n                \":-O\": [\"\\\\:\\\\-O\",\"gasp\",],\n                \":O\": [\"\\\\:O\",\"gasp\",],\n                \":-o\": [\"\\\\:\\\\-o\",\"gasp\",],\n                \":o\": [\"\\\\:o\",\"gasp\",],\n                \";-)\": [\"\\\\;\\\\-\\\\)\",\"wink\",],\n                \";)\": [\"\\\\;\\\\)\",\"wink\",],\n                \"8-)\": [\"8\\\\-\\\\)\",\"glasses\",],\n                \"8)\": [\"8\\\\)\",\"glasses\",],\n                \"B-)\": [\"B\\\\-\\\\)\",\"glasses\",],\n                \"B)\": [\"B\\\\)\",\"glasses\",],\n                \"8-|\": [\"8\\\\-\\\\|\",\"sunglasses\",],\n                \"8|\": [\"8\\\\|\",\"sunglasses\",],\n                \"B-|\": [\"B\\\\-\\\\|\",\"sunglasses\",],\n                \"B|\": [\"B\\\\|\",\"sunglasses\",],\n                \"\\u003E:(\": [\"\\u003E\\\\:\\\\(\",\"grumpy\",],\n                \"\\u003E:-(\": [\"\\u003E\\\\:\\\\-\\\\(\",\"grumpy\",],\n                \":/\": [\"\\\\:/\",\"unsure\",],\n                \":-/\": [\"\\\\:\\\\-/\",\"unsure\",],\n                \":\\\\\": [\"\\\\:\\\\\\\\\",\"unsure\",],\n                \":-\\\\\": [\"\\\\:\\\\-\\\\\\\\\",\"unsure\",],\n                \":'(\": [\"\\\\:'\\\\(\",\"cry\",],\n                \"3:)\": [\"3\\\\:\\\\)\",\"devil\",],\n                \"3:-)\": [\"3\\\\:\\\\-\\\\)\",\"devil\",],\n                \"O:)\": [\"O\\\\:\\\\)\",\"angel\",],\n                \"O:-)\": [\"O\\\\:\\\\-\\\\)\",\"angel\",],\n                \":-*\": [\"\\\\:\\\\-\\\\*\",\"kiss\",],\n                \":*\": [\"\\\\:\\\\*\",\"kiss\",],\n                \"\\u003C3\": [\"\\u003C3\",\"heart\",],\n                \"&lt;3\": [\"&lt\\\\;3\",\"heart\",],\n                \"\\u2665\": [\"\\u2665\",\"heart\",],\n                \"^_^\": [\"\\\\^_\\\\^\",\"kiki\",],\n                \"-_-\": [\"\\\\-_\\\\-\",\"squint\",],\n                \"o.O\": [\"o\\\\.O\",\"confused\",],\n                \"O.o\": [\"O\\\\.o\",\"confused\",],\n                \"\\u003E:O\": [\"\\u003E\\\\:O\",\"upset\",],\n                \"\\u003E:-O\": [\"\\u003E\\\\:\\\\-O\",\"upset\",],\n                \"\\u003E:o\": [\"\\u003E\\\\:o\",\"upset\",],\n                \"\\u003E:-o\": [\"\\u003E\\\\:\\\\-o\",\"upset\",],\n                \"\\u003E_\\u003C\": [\"\\u003E_\\u003C\",\"upset\",],\n                \"\\u003E.\\u003C\": [\"\\u003E\\\\.\\u003C\",\"upset\",],\n                \":v\": [\"\\\\:v\",\"pacman\",],\n                \":|]\": [\"\\\\:\\\\|\\\\]\",\"robot\",],\n                \":3\": [\"\\\\:3\",\"colonthree\",],\n                \"\\u003C(\\\")\": [\"\\u003C\\\\(\\\\\\\"\\\\)\",\"penguin\",],\n                \":putnam:\": [\"\\\\:putnam\\\\:\",\"putnam\",],\n                \"(^^^)\": [\"\\\\(\\\\^\\\\^\\\\^\\\\)\",\"shark\",],\n                \":42:\": [\"\\\\:42\\\\:\",\"42\",],\n                \":like:\": [\"\\\\:like\\\\:\",\"like\",],\n                \"(y)\": [\"\\\\(y\\\\)\",\"like\",],\n                \"(Y)\": [\"\\\\(Y\\\\)\",\"like\",]\n            };\n            var m = [], n = [];\n            if (h.fbid_emoticons) {\n                j._fbidEmoticonRegex = new RegExp(j._fbidEmoticonPattern);\n                m.push(j._fbidEmoticonPattern);\n            }\n        ;\n        ;\n            for (var o in j._emoteMap) {\n                var p = j._emoteMap[o][0];\n                m.push(p);\n                n.push(p);\n            };\n        ;\n            var q = ((((\"(?:^|\\\\s|'|\\\"|\\\\.)(\" + m.join(\"|\"))) + \")(?:\\\\s|'|\\\"|\\\\.|,|!|\\\\?|\\u003Cbr\\u003E|$)\")), r = ((((\"(?:^|\\\\s|'|\\\"|\\\\.)(\" + n.join(\"|\"))) + \")(?:\\\\s|'|\\\"|\\\\.|,|!|\\\\?|\\u003Cbr\\u003E|$)\"));\n            j._regex = new RegExp(q);\n            j._regexWithoutFBIDs = new RegExp(r);\n            j._emoteOrderMap = {\n            };\n            for (var s = 0; ((s < l.length)); s++) {\n                j._emoteOrderMap[l[s]] = s;\n            ;\n            };\n        ;\n            j._initialized = true;\n        },\n        htmlEmote: function(k, l) {\n            return j._htmlEmote(k, l, true);\n        },\n        htmlEmoteWithoutFBID: function(k, l) {\n            return j._htmlEmote(k, l, false);\n        },\n        _getRegex: function(k) {\n            return ((k ? j._regex : j._regexWithoutFBIDs));\n        },\n        _htmlEmote: function(k, l, m) {\n            if (((typeof l != \"function\"))) {\n                l = i;\n            }\n        ;\n        ;\n            if (!j._initialized) {\n                j._init();\n            }\n        ;\n        ;\n            var n = k, o = [];\n            while (true) {\n                var p = j._getRegex(m), q = p.exec(n);\n                if (((!q || !q.length))) {\n                    break;\n                }\n            ;\n            ;\n                var r = q[1], s = n.indexOf(r), t = n.substring(0, s);\n                if (t) {\n                    o.push(l(t));\n                }\n            ;\n            ;\n                o.push(\"\\u003Cspan class=\\\"emote_text\\\"\\u003E\");\n                o.push(r);\n                o.push(\"\\u003C/span\\u003E\");\n                var u = {\n                    title: r\n                }, v = ((j._fbidEmoticonRegex && ((j._fbidEmoticonRegex.exec(r) || []))[1]));\n                if (v) {\n                    u.className = \"emote_custom\";\n                    u.src = ((((((window.JSBNG__location.protocol + \"//graph.facebook.com/\")) + encodeURIComponent(v))) + \"/picture\"));\n                }\n                 else {\n                    var w = j._emoteMap[r][1], x = j._emoteOrderMap[w];\n                    if (((x === undefined))) {\n                        u.className = \"emote_custom\";\n                        u.src = ((((j._imageBase + w)) + \".gif\"));\n                    }\n                     else {\n                        var y = ((x * -16));\n                        u.className = \"emote_img\";\n                        u.src = j._blankImgSrc;\n                        u.style = {\n                            backgroundPosition: ((y + \"px 0\"))\n                        };\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                var z = g.create(\"img\", u);\n                o.push(g.create(\"span\", {\n                }, z).innerHTML);\n                n = n.substring(((s + r.length)));\n            };\n        ;\n            if (n) {\n                o.push(l(n));\n            }\n        ;\n        ;\n            return o.join(\"\");\n        }\n    };\n});\n__d(\"SupportedEmoji\", [\"cx\",], function(a, b, c, d, e, f) {\n    var g = b(\"cx\");\n    e.exports = {\n        utf16Regex: /\\u203C|\\u2049|[\\u2100-\\u21FF]|[\\u2300-\\u27FF]|[\\u2900-\\u29FF]|[\\u2B00-\\u2BFF]|[\\u3000-\\u30FF]|[\\u3200-\\u32FF]|\\uD83C[\\uDC00-\\uDFFF]|\\uD83D[\\uDC00-\\uDEFF]/,\n        emoji: {\n            127744: \"-cx-PRIVATE-fbEmoji__icon_1f300\",\n            127746: \"-cx-PRIVATE-fbEmoji__icon_1f302\",\n            127754: \"-cx-PRIVATE-fbEmoji__icon_1f30a\",\n            127769: \"-cx-PRIVATE-fbEmoji__icon_1f319\",\n            127775: \"-cx-PRIVATE-fbEmoji__icon_1f31f\",\n            127793: \"-cx-PRIVATE-fbEmoji__icon_1f331\",\n            127796: \"-cx-PRIVATE-fbEmoji__icon_1f334\",\n            127797: \"-cx-PRIVATE-fbEmoji__icon_1f335\",\n            127799: \"-cx-PRIVATE-fbEmoji__icon_1f337\",\n            127800: \"-cx-PRIVATE-fbEmoji__icon_1f338\",\n            127801: \"-cx-PRIVATE-fbEmoji__icon_1f339\",\n            127802: \"-cx-PRIVATE-fbEmoji__icon_1f33a\",\n            127803: \"-cx-PRIVATE-fbEmoji__icon_1f33b\",\n            127806: \"-cx-PRIVATE-fbEmoji__icon_1f33e\",\n            127808: \"-cx-PRIVATE-fbEmoji__icon_1f340\",\n            127809: \"-cx-PRIVATE-fbEmoji__icon_1f341\",\n            127810: \"-cx-PRIVATE-fbEmoji__icon_1f342\",\n            127811: \"-cx-PRIVATE-fbEmoji__icon_1f343\",\n            127818: \"-cx-PRIVATE-fbEmoji__icon_1f34a\",\n            127822: \"-cx-PRIVATE-fbEmoji__icon_1f34e\",\n            127827: \"-cx-PRIVATE-fbEmoji__icon_1f353\",\n            127828: \"-cx-PRIVATE-fbEmoji__icon_1f354\",\n            127864: \"-cx-PRIVATE-fbEmoji__icon_1f378\",\n            127866: \"-cx-PRIVATE-fbEmoji__icon_1f37a\",\n            127873: \"-cx-PRIVATE-fbEmoji__icon_1f381\",\n            127875: \"-cx-PRIVATE-fbEmoji__icon_1f383\",\n            127876: \"-cx-PRIVATE-fbEmoji__icon_1f384\",\n            127877: \"-cx-PRIVATE-fbEmoji__icon_1f385\",\n            127880: \"-cx-PRIVATE-fbEmoji__icon_1f388\",\n            127881: \"-cx-PRIVATE-fbEmoji__icon_1f389\",\n            127885: \"-cx-PRIVATE-fbEmoji__icon_1f38d\",\n            127886: \"-cx-PRIVATE-fbEmoji__icon_1f38e\",\n            127887: \"-cx-PRIVATE-fbEmoji__icon_1f38f\",\n            127888: \"-cx-PRIVATE-fbEmoji__icon_1f390\",\n            127891: \"-cx-PRIVATE-fbEmoji__icon_1f393\",\n            127925: \"-cx-PRIVATE-fbEmoji__icon_1f3b5\",\n            127926: \"-cx-PRIVATE-fbEmoji__icon_1f3b6\",\n            127932: \"-cx-PRIVATE-fbEmoji__icon_1f3bc\",\n            128013: \"-cx-PRIVATE-fbEmoji__icon_1f40d\",\n            128014: \"-cx-PRIVATE-fbEmoji__icon_1f40e\",\n            128017: \"-cx-PRIVATE-fbEmoji__icon_1f411\",\n            128018: \"-cx-PRIVATE-fbEmoji__icon_1f412\",\n            128020: \"-cx-PRIVATE-fbEmoji__icon_1f414\",\n            128023: \"-cx-PRIVATE-fbEmoji__icon_1f417\",\n            128024: \"-cx-PRIVATE-fbEmoji__icon_1f418\",\n            128025: \"-cx-PRIVATE-fbEmoji__icon_1f419\",\n            128026: \"-cx-PRIVATE-fbEmoji__icon_1f41a\",\n            128027: \"-cx-PRIVATE-fbEmoji__icon_1f41b\",\n            128031: \"-cx-PRIVATE-fbEmoji__icon_1f41f\",\n            128032: \"-cx-PRIVATE-fbEmoji__icon_1f420\",\n            128033: \"-cx-PRIVATE-fbEmoji__icon_1f421\",\n            128037: \"-cx-PRIVATE-fbEmoji__icon_1f425\",\n            128038: \"-cx-PRIVATE-fbEmoji__icon_1f426\",\n            128039: \"-cx-PRIVATE-fbEmoji__icon_1f427\",\n            128040: \"-cx-PRIVATE-fbEmoji__icon_1f428\",\n            128041: \"-cx-PRIVATE-fbEmoji__icon_1f429\",\n            128043: \"-cx-PRIVATE-fbEmoji__icon_1f42b\",\n            128044: \"-cx-PRIVATE-fbEmoji__icon_1f42c\",\n            128045: \"-cx-PRIVATE-fbEmoji__icon_1f42d\",\n            128046: \"-cx-PRIVATE-fbEmoji__icon_1f42e\",\n            128047: \"-cx-PRIVATE-fbEmoji__icon_1f42f\",\n            128048: \"-cx-PRIVATE-fbEmoji__icon_1f430\",\n            128049: \"-cx-PRIVATE-fbEmoji__icon_1f431\",\n            128051: \"-cx-PRIVATE-fbEmoji__icon_1f433\",\n            128052: \"-cx-PRIVATE-fbEmoji__icon_1f434\",\n            128053: \"-cx-PRIVATE-fbEmoji__icon_1f435\",\n            128055: \"-cx-PRIVATE-fbEmoji__icon_1f437\",\n            128056: \"-cx-PRIVATE-fbEmoji__icon_1f438\",\n            128057: \"-cx-PRIVATE-fbEmoji__icon_1f439\",\n            128058: \"-cx-PRIVATE-fbEmoji__icon_1f43a\",\n            128059: \"-cx-PRIVATE-fbEmoji__icon_1f43b\",\n            128062: \"-cx-PRIVATE-fbEmoji__icon_1f43e\",\n            128064: \"-cx-PRIVATE-fbEmoji__icon_1f440\",\n            128066: \"-cx-PRIVATE-fbEmoji__icon_1f442\",\n            128067: \"-cx-PRIVATE-fbEmoji__icon_1f443\",\n            128068: \"-cx-PRIVATE-fbEmoji__icon_1f444\",\n            128069: \"-cx-PRIVATE-fbEmoji__icon_1f445\",\n            128070: \"-cx-PRIVATE-fbEmoji__icon_1f446\",\n            128071: \"-cx-PRIVATE-fbEmoji__icon_1f447\",\n            128072: \"-cx-PRIVATE-fbEmoji__icon_1f448\",\n            128073: \"-cx-PRIVATE-fbEmoji__icon_1f449\",\n            128074: \"-cx-PRIVATE-fbEmoji__icon_1f44a\",\n            128075: \"-cx-PRIVATE-fbEmoji__icon_1f44b\",\n            128076: \"-cx-PRIVATE-fbEmoji__icon_1f44c\",\n            128077: \"-cx-PRIVATE-fbEmoji__icon_1f44d\",\n            128078: \"-cx-PRIVATE-fbEmoji__icon_1f44e\",\n            128079: \"-cx-PRIVATE-fbEmoji__icon_1f44f\",\n            128080: \"-cx-PRIVATE-fbEmoji__icon_1f450\",\n            128102: \"-cx-PRIVATE-fbEmoji__icon_1f466\",\n            128103: \"-cx-PRIVATE-fbEmoji__icon_1f467\",\n            128104: \"-cx-PRIVATE-fbEmoji__icon_1f468\",\n            128105: \"-cx-PRIVATE-fbEmoji__icon_1f469\",\n            128107: \"-cx-PRIVATE-fbEmoji__icon_1f46b\",\n            128110: \"-cx-PRIVATE-fbEmoji__icon_1f46e\",\n            128111: \"-cx-PRIVATE-fbEmoji__icon_1f46f\",\n            128113: \"-cx-PRIVATE-fbEmoji__icon_1f471\",\n            128114: \"-cx-PRIVATE-fbEmoji__icon_1f472\",\n            128115: \"-cx-PRIVATE-fbEmoji__icon_1f473\",\n            128116: \"-cx-PRIVATE-fbEmoji__icon_1f474\",\n            128117: \"-cx-PRIVATE-fbEmoji__icon_1f475\",\n            128118: \"-cx-PRIVATE-fbEmoji__icon_1f476\",\n            128119: \"-cx-PRIVATE-fbEmoji__icon_1f477\",\n            128120: \"-cx-PRIVATE-fbEmoji__icon_1f478\",\n            128123: \"-cx-PRIVATE-fbEmoji__icon_1f47b\",\n            128124: \"-cx-PRIVATE-fbEmoji__icon_1f47c\",\n            128125: \"-cx-PRIVATE-fbEmoji__icon_1f47d\",\n            128126: \"-cx-PRIVATE-fbEmoji__icon_1f47e\",\n            128127: \"-cx-PRIVATE-fbEmoji__icon_1f47f\",\n            128128: \"-cx-PRIVATE-fbEmoji__icon_1f480\",\n            128130: \"-cx-PRIVATE-fbEmoji__icon_1f482\",\n            128131: \"-cx-PRIVATE-fbEmoji__icon_1f483\",\n            128133: \"-cx-PRIVATE-fbEmoji__icon_1f485\",\n            128139: \"-cx-PRIVATE-fbEmoji__icon_1f48b\",\n            128143: \"-cx-PRIVATE-fbEmoji__icon_1f48f\",\n            128144: \"-cx-PRIVATE-fbEmoji__icon_1f490\",\n            128145: \"-cx-PRIVATE-fbEmoji__icon_1f491\",\n            128147: \"-cx-PRIVATE-fbEmoji__icon_1f493\",\n            128148: \"-cx-PRIVATE-fbEmoji__icon_1f494\",\n            128150: \"-cx-PRIVATE-fbEmoji__icon_1f496\",\n            128151: \"-cx-PRIVATE-fbEmoji__icon_1f497\",\n            128152: \"-cx-PRIVATE-fbEmoji__icon_1f498\",\n            128153: \"-cx-PRIVATE-fbEmoji__icon_1f499\",\n            128154: \"-cx-PRIVATE-fbEmoji__icon_1f49a\",\n            128155: \"-cx-PRIVATE-fbEmoji__icon_1f49b\",\n            128156: \"-cx-PRIVATE-fbEmoji__icon_1f49c\",\n            128157: \"-cx-PRIVATE-fbEmoji__icon_1f49d\",\n            128162: \"-cx-PRIVATE-fbEmoji__icon_1f4a2\",\n            128164: \"-cx-PRIVATE-fbEmoji__icon_1f4a4\",\n            128166: \"-cx-PRIVATE-fbEmoji__icon_1f4a6\",\n            128168: \"-cx-PRIVATE-fbEmoji__icon_1f4a8\",\n            128169: \"-cx-PRIVATE-fbEmoji__icon_1f4a9\",\n            128170: \"-cx-PRIVATE-fbEmoji__icon_1f4aa\",\n            128187: \"-cx-PRIVATE-fbEmoji__icon_1f4bb\",\n            128189: \"-cx-PRIVATE-fbEmoji__icon_1f4bd\",\n            128190: \"-cx-PRIVATE-fbEmoji__icon_1f4be\",\n            128191: \"-cx-PRIVATE-fbEmoji__icon_1f4bf\",\n            128192: \"-cx-PRIVATE-fbEmoji__icon_1f4c0\",\n            128222: \"-cx-PRIVATE-fbEmoji__icon_1f4de\",\n            128224: \"-cx-PRIVATE-fbEmoji__icon_1f4e0\",\n            128241: \"-cx-PRIVATE-fbEmoji__icon_1f4f1\",\n            128242: \"-cx-PRIVATE-fbEmoji__icon_1f4f2\",\n            128250: \"-cx-PRIVATE-fbEmoji__icon_1f4fa\",\n            128276: \"-cx-PRIVATE-fbEmoji__icon_1f514\",\n            128513: \"-cx-PRIVATE-fbEmoji__icon_1f601\",\n            128514: \"-cx-PRIVATE-fbEmoji__icon_1f602\",\n            128515: \"-cx-PRIVATE-fbEmoji__icon_1f603\",\n            128516: \"-cx-PRIVATE-fbEmoji__icon_1f604\",\n            128518: \"-cx-PRIVATE-fbEmoji__icon_1f606\",\n            128521: \"-cx-PRIVATE-fbEmoji__icon_1f609\",\n            128523: \"-cx-PRIVATE-fbEmoji__icon_1f60b\",\n            128524: \"-cx-PRIVATE-fbEmoji__icon_1f60c\",\n            128525: \"-cx-PRIVATE-fbEmoji__icon_1f60d\",\n            128527: \"-cx-PRIVATE-fbEmoji__icon_1f60f\",\n            128530: \"-cx-PRIVATE-fbEmoji__icon_1f612\",\n            128531: \"-cx-PRIVATE-fbEmoji__icon_1f613\",\n            128532: \"-cx-PRIVATE-fbEmoji__icon_1f614\",\n            128534: \"-cx-PRIVATE-fbEmoji__icon_1f616\",\n            128536: \"-cx-PRIVATE-fbEmoji__icon_1f618\",\n            128538: \"-cx-PRIVATE-fbEmoji__icon_1f61a\",\n            128540: \"-cx-PRIVATE-fbEmoji__icon_1f61c\",\n            128541: \"-cx-PRIVATE-fbEmoji__icon_1f61d\",\n            128542: \"-cx-PRIVATE-fbEmoji__icon_1f61e\",\n            128544: \"-cx-PRIVATE-fbEmoji__icon_1f620\",\n            128545: \"-cx-PRIVATE-fbEmoji__icon_1f621\",\n            128546: \"-cx-PRIVATE-fbEmoji__icon_1f622\",\n            128547: \"-cx-PRIVATE-fbEmoji__icon_1f623\",\n            128548: \"-cx-PRIVATE-fbEmoji__icon_1f624\",\n            128549: \"-cx-PRIVATE-fbEmoji__icon_1f625\",\n            128552: \"-cx-PRIVATE-fbEmoji__icon_1f628\",\n            128553: \"-cx-PRIVATE-fbEmoji__icon_1f629\",\n            128554: \"-cx-PRIVATE-fbEmoji__icon_1f62a\",\n            128555: \"-cx-PRIVATE-fbEmoji__icon_1f62b\",\n            128557: \"-cx-PRIVATE-fbEmoji__icon_1f62d\",\n            128560: \"-cx-PRIVATE-fbEmoji__icon_1f630\",\n            128561: \"-cx-PRIVATE-fbEmoji__icon_1f631\",\n            128562: \"-cx-PRIVATE-fbEmoji__icon_1f632\",\n            128563: \"-cx-PRIVATE-fbEmoji__icon_1f633\",\n            128565: \"-cx-PRIVATE-fbEmoji__icon_1f635\",\n            128567: \"-cx-PRIVATE-fbEmoji__icon_1f637\",\n            128568: \"-cx-PRIVATE-fbEmoji__icon_1f638\",\n            128569: \"-cx-PRIVATE-fbEmoji__icon_1f639\",\n            128570: \"-cx-PRIVATE-fbEmoji__icon_1f63a\",\n            128571: \"-cx-PRIVATE-fbEmoji__icon_1f63b\",\n            128572: \"-cx-PRIVATE-fbEmoji__icon_1f63c\",\n            128573: \"-cx-PRIVATE-fbEmoji__icon_1f63d\",\n            128575: \"-cx-PRIVATE-fbEmoji__icon_1f63f\",\n            128576: \"-cx-PRIVATE-fbEmoji__icon_1f640\",\n            128587: \"-cx-PRIVATE-fbEmoji__icon_1f64b\",\n            128588: \"-cx-PRIVATE-fbEmoji__icon_1f64c\",\n            128589: \"-cx-PRIVATE-fbEmoji__icon_1f64d\",\n            128591: \"-cx-PRIVATE-fbEmoji__icon_1f64f\",\n            9757: \"-cx-PRIVATE-fbEmoji__icon_261d\",\n            9786: \"-cx-PRIVATE-fbEmoji__icon_263a\",\n            9889: \"-cx-PRIVATE-fbEmoji__icon_26a1\",\n            9924: \"-cx-PRIVATE-fbEmoji__icon_26c4\",\n            9994: \"-cx-PRIVATE-fbEmoji__icon_270a\",\n            9995: \"-cx-PRIVATE-fbEmoji__icon_270b\",\n            9996: \"-cx-PRIVATE-fbEmoji__icon_270c\",\n            9728: \"-cx-PRIVATE-fbEmoji__icon_2600\",\n            9729: \"-cx-PRIVATE-fbEmoji__icon_2601\",\n            9748: \"-cx-PRIVATE-fbEmoji__icon_2614\",\n            9749: \"-cx-PRIVATE-fbEmoji__icon_2615\",\n            10024: \"-cx-PRIVATE-fbEmoji__icon_2728\",\n            10084: \"-cx-PRIVATE-fbEmoji__icon_2764\"\n        }\n    };\n});\n__d(\"Utf16\", [], function(a, b, c, d, e, f) {\n    var g = {\n        decode: function(h) {\n            switch (h.length) {\n              case 1:\n                return h.charCodeAt(0);\n              case 2:\n                return ((((65536 | ((((h.charCodeAt(0) - 55296)) * 1024)))) | ((h.charCodeAt(1) - 56320))));\n            };\n        ;\n        },\n        encode: function(h) {\n            if (((h < 65536))) {\n                return String.fromCharCode(h);\n            }\n             else return ((String.fromCharCode(((55296 + ((((h - 65536)) >> 10))))) + String.fromCharCode(((56320 + ((h % 1024)))))))\n        ;\n        }\n    };\n    e.exports = g;\n});\n__d(\"Emoji\", [\"cx\",\"DOM\",\"Emote\",\"SupportedEmoji\",\"htmlize\",\"Utf16\",], function(a, b, c, d, e, f) {\n    var g = b(\"cx\"), h = b(\"DOM\"), i = b(\"Emote\"), j = b(\"SupportedEmoji\"), k = b(\"htmlize\"), l = b(\"Utf16\"), m = e.exports = {\n        htmlEmojiAndEmote: function(n, o) {\n            return m.htmlEmoji(n, function(p) {\n                return i.htmlEmote(p, o);\n            });\n        },\n        htmlEmoji: function(n, o) {\n            if (((typeof o != \"function\"))) {\n                o = k;\n            }\n        ;\n        ;\n            var p = n, q = [];\n            while (true) {\n                var r = j.utf16Regex.exec(p);\n                if (((!r || !r.length))) {\n                    break;\n                }\n            ;\n            ;\n                var s = r[0], t = p.indexOf(s);\n                q.push(o(p.substring(0, t)));\n                var u = l.decode(s);\n                if (j.emoji[u]) {\n                    var v = ((((\"-cx-PRIVATE-fbEmoji__icon -cx-PRIVATE-fbEmoji__size_16\" + \" \")) + j.emoji[u])), w = h.create(\"span\", {\n                        className: v\n                    });\n                    q.push(h.create(\"span\", {\n                    }, w).innerHTML);\n                }\n                 else q.push(o(s));\n            ;\n            ;\n                p = p.substring(((t + s.length)));\n            };\n        ;\n            q.push(o(p));\n            return q.join(\"\");\n        }\n    };\n});\n__d(\"ErrorDialog\", [\"Dialog\",], function(a, b, c, d, e, f) {\n    var g = b(\"Dialog\"), h = {\n        showAsyncError: function(i) {\n            try {\n                return h.show(i.getErrorSummary(), i.getErrorDescription());\n            } catch (j) {\n                JSBNG__alert(i);\n            };\n        ;\n        },\n        show: function(i, j, k, l) {\n            return (new g()).setTitle(i).setBody(j).setButtons([g.OK,]).setStackable(true).setModal(true).setHandler(((k || bagofholding))).setButtonsMessage(((l || \"\"))).show();\n        }\n    };\n    e.exports = h;\n});\n__d(\"throttle\", [\"debounce\",], function(a, b, c, d, e, f) {\n    var g = b(\"debounce\");\n    function h(i, j, k) {\n        return g(i, j, k, false, true);\n    };\n;\n    e.exports = h;\n});\n__d(\"FullScreen\", [\"event-extensions\",\"Arbiter\",\"CSS\",\"UserAgent\",\"copyProperties\",\"throttle\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"CSS\"), i = b(\"UserAgent\"), j = b(\"copyProperties\"), k = b(\"throttle\"), l = j(new g(), {\n        listenForEvent: function(m) {\n            var n = k(this.JSBNG__onChange, 0, this);\n            JSBNG__Event.listen(m, {\n                webkitfullscreenchange: n,\n                mozfullscreenchange: n,\n                fullscreenchange: n\n            });\n            JSBNG__Event.listen(JSBNG__document, {\n                webkitfullscreenchange: n,\n                mozfullscreenchange: n,\n                fullscreenchange: n\n            });\n        },\n        enableFullScreen: function(m) {\n            this.listenForEvent(m);\n            if (m.webkitRequestFullScreen) {\n                if (i.JSBNG__chrome()) {\n                    m.webkitRequestFullScreen(JSBNG__Element.ALLOW_KEYBOARD_INPUT);\n                }\n                 else m.webkitRequestFullScreen();\n            ;\n            ;\n            }\n             else if (m.mozRequestFullScreen) {\n                m.mozRequestFullScreen();\n            }\n             else if (m.requestFullScreen) {\n                m.requestFullScreen();\n            }\n             else return false\n            \n            \n        ;\n            return true;\n        },\n        disableFullScreen: function() {\n            if (JSBNG__document.webkitCancelFullScreen) {\n                JSBNG__document.webkitCancelFullScreen();\n            }\n             else if (JSBNG__document.mozCancelFullScreen) {\n                JSBNG__document.mozCancelFullScreen();\n            }\n             else if (JSBNG__document.cancelFullScreen) {\n                JSBNG__document.cancelFullScreen();\n            }\n             else if (JSBNG__document.exitFullScreen) {\n                JSBNG__document.exitFullScreen();\n            }\n             else return false\n            \n            \n            \n        ;\n            return true;\n        },\n        isFullScreen: function() {\n            return ((((JSBNG__document.webkitIsFullScreen || JSBNG__document.JSBNG__fullScreen)) || JSBNG__document.mozFullScreen));\n        },\n        toggleFullScreen: function(m) {\n            if (this.isFullScreen()) {\n                this.disableFullScreen();\n                return false;\n            }\n             else return this.enableFullScreen(m)\n        ;\n            return false;\n        },\n        JSBNG__onChange: function() {\n            var m = this.isFullScreen();\n            h.conditionClass(JSBNG__document.body, \"JSBNG__fullScreen\", m);\n            this.inform(\"changed\");\n        },\n        isSupported: function() {\n            return ((((((((JSBNG__document.webkitCancelFullScreen && i.JSBNG__chrome())) || JSBNG__document.mozCancelFullScreen)) || JSBNG__document.cancelFullScreen)) || JSBNG__document.exitFullScreen));\n        }\n    });\n    e.exports = l;\n});\n__d(\"ImageUtils\", [\"UserAgent\",], function(a, b, c, d, e, f) {\n    var g = b(\"UserAgent\"), h = {\n        hasLoaded: function(i) {\n            if (((i.naturalWidth !== undefined))) {\n                return ((i.complete && ((i.width !== 0))));\n            }\n             else if (((((((i.height == 20)) && ((i.width == 20)))) && i.complete))) {\n                return false;\n            }\n             else if (((((i.complete === undefined)) && ((g.safari() < 500))))) {\n                var j = new JSBNG__Image();\n                j.src = i.src;\n                return j.complete;\n            }\n            \n            \n        ;\n        ;\n            return i.complete;\n        }\n    };\n    e.exports = h;\n});\n__d(\"flattenArray\", [], function(a, b, c, d, e, f) {\n    function g(h) {\n        var i = [];\n        while (h.length) {\n            var j = h.pop();\n            if (Array.isArray(j)) {\n                Array.prototype.push.apply(h, j);\n            }\n             else i.push(j);\n        ;\n        ;\n        };\n    ;\n        return i.reverse();\n    };\n;\n    e.exports = g;\n});\n__d(\"JSXDOM\", [\"DOM\",\"flattenArray\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"flattenArray\"), i = [\"a\",\"br\",\"button\",\"checkbox\",\"dd\",\"div\",\"dl\",\"dt\",\"form\",\"h1\",\"h2\",\"h3\",\"h4\",\"h5\",\"h6\",\"hr\",\"i\",\"div\",\"img\",\"input\",\"label\",\"li\",\"option\",\"p\",\"pre\",\"select\",\"span\",\"strong\",\"table\",\"td\",\"textarea\",\"th\",\"tr\",\"ul\",], j = {\n    };\n    i.forEach(function(k) {\n        var l = function(m) {\n            var n;\n            if (m.children) {\n                n = ((Array.isArray(m.children) ? h(m.children) : h([m.children,])));\n                delete m.children;\n            }\n        ;\n        ;\n            return g.create(k, m, n);\n        };\n        j[k] = l;\n    });\n    e.exports = j;\n});\n__d(\"LayerStopBlur\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\");\n    function h(i) {\n        this._layer = i;\n    };\n;\n    g(h.prototype, {\n        _subscriptions: null,\n        _onBlur: null,\n        enable: function() {\n            this._subscriptions = [this._layer.subscribe(\"show\", this._attach.bind(this)),this._layer.subscribe(\"hide\", this._detach.bind(this)),];\n            if (this._layer.isShown()) {\n                this._attach();\n            }\n        ;\n        ;\n        },\n        disable: function() {\n            this._detach();\n            while (this._subscriptions.length) {\n                this._subscriptions.pop().unsubscribe();\n            ;\n            };\n        ;\n            this._subscriptions = null;\n        },\n        _detach: function() {\n            ((this._onBlur && this._onBlur.unsubscribe()));\n            this._onBlur = null;\n        },\n        _attach: function() {\n            (function() {\n                this._onBlur = this._layer.subscribe(\"JSBNG__blur\", function() {\n                    return false;\n                });\n            }).bind(this).defer();\n        }\n    });\n    e.exports = h;\n});\n__d(\"ScrollableArea\", [\"array-extensions\",\"event-extensions\",\"Animation\",\"ArbiterMixin\",\"CSS\",\"DataStore\",\"DOM\",\"Parent\",\"Run\",\"SimpleDrag\",\"Style\",\"UserAgent\",\"Vector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    var g = b(\"Animation\"), h = b(\"ArbiterMixin\"), i = b(\"CSS\"), j = b(\"DataStore\"), k = b(\"DOM\"), l = b(\"Parent\"), m = b(\"Run\"), n = b(\"SimpleDrag\"), o = b(\"Style\"), p = b(\"UserAgent\"), q = b(\"Vector\"), r = b(\"copyProperties\");\n    function s(t, u) {\n        if (!t) {\n            return;\n        }\n    ;\n    ;\n        u = ((u || {\n        }));\n        this._elem = t;\n        this._wrap = k.JSBNG__find(t, \"div.uiScrollableAreaWrap\");\n        this._body = k.JSBNG__find(this._wrap, \"div.uiScrollableAreaBody\");\n        this._content = k.JSBNG__find(this._body, \"div.uiScrollableAreaContent\");\n        this._track = k.JSBNG__find(t, \"div.uiScrollableAreaTrack\");\n        this._gripper = k.JSBNG__find(this._track, \"div.uiScrollableAreaGripper\");\n        this._options = u;\n        this.adjustGripper.bind(this).defer();\n        this._listeners = [JSBNG__Event.listen(this._wrap, \"JSBNG__scroll\", this._handleScroll.bind(this)),];\n        if (((u.fade !== false))) {\n            this._listeners.push(JSBNG__Event.listen(t, \"mouseenter\", this.showScrollbar.shield(this)), JSBNG__Event.listen(t, \"mousemove\", this._handleMousemove.bind(this)), JSBNG__Event.listen(t, \"mouseout\", this.hideScrollbar.shield(this)));\n        }\n    ;\n    ;\n        if (((p.safari() || p.JSBNG__chrome()))) {\n            this._listeners.push(JSBNG__Event.listen(t, \"mousedown\", function() {\n                var v = JSBNG__Event.listen(window, \"mouseup\", function() {\n                    if (t.scrollLeft) {\n                        t.scrollLeft = 0;\n                    }\n                ;\n                ;\n                    v.remove();\n                });\n            }));\n        }\n         else if (p.firefox()) {\n            this._wrap.JSBNG__addEventListener(\"DOMMouseScroll\", function(JSBNG__event) {\n                ((((JSBNG__event.axis === JSBNG__event.HORIZONTAL_AXIS)) && JSBNG__event.preventDefault()));\n            }, false);\n        }\n        \n    ;\n    ;\n        this.initDrag();\n        j.set(this._elem, \"ScrollableArea\", this);\n        if (!u.persistent) {\n            m.JSBNG__onLeave(this.destroy.bind(this));\n        }\n    ;\n    ;\n    };\n;\n    r(s, {\n        renderDOM: function() {\n            var t = k.create(\"div\", {\n                className: \"uiScrollableAreaContent\"\n            }), u = k.create(\"div\", {\n                className: \"uiScrollableAreaBody\"\n            }, t), v = k.create(\"div\", {\n                className: \"uiScrollableAreaWrap\"\n            }, u), w = k.create(\"div\", {\n                className: \"uiScrollableArea native\"\n            }, v);\n            return {\n                root: w,\n                wrap: v,\n                body: u,\n                JSBNG__content: t\n            };\n        },\n        fromNative: function(t, u) {\n            if (((!i.hasClass(t, \"uiScrollableArea\") || !i.hasClass(t, \"native\")))) {\n                return;\n            }\n        ;\n        ;\n            u = ((u || {\n            }));\n            i.removeClass(t, \"native\");\n            var v = k.create(\"div\", {\n                className: \"uiScrollableAreaTrack\"\n            }, k.create(\"div\", {\n                className: \"uiScrollableAreaGripper\"\n            }));\n            if (((u.fade !== false))) {\n                i.addClass(t, \"fade\");\n                i.addClass(v, \"invisible_elem\");\n            }\n             else i.addClass(t, \"nofade\");\n        ;\n        ;\n            k.appendContent(t, v);\n            var w = new s(t, u);\n            w.resize();\n            return w;\n        },\n        getInstance: function(t) {\n            var u = l.byClass(t, \"uiScrollableArea\");\n            return ((u ? j.get(u, \"ScrollableArea\") : null));\n        },\n        poke: function(t) {\n            var u = s.getInstance(t);\n            ((u && u.poke()));\n        }\n    });\n    r(s.prototype, h, {\n        initDrag: function() {\n            var t = new n(this._gripper);\n            t.subscribe(\"start\", function(u, JSBNG__event) {\n                if (!((((JSBNG__event.which && ((JSBNG__event.which === 1)))) || ((JSBNG__event.button && ((JSBNG__event.button === 1))))))) {\n                    return;\n                }\n            ;\n            ;\n                var v = q.getEventPosition(JSBNG__event).y, w = this._gripper.offsetTop, x = t.subscribe(\"update\", function(z, JSBNG__event) {\n                    var aa = ((q.getEventPosition(JSBNG__event).y - v)), ba = this._elem.clientHeight, ca = this._content.offsetHeight, da = this._track.offsetHeight, ea = ((((ba / ca)) * da)), fa = ((ca - this._wrap.offsetHeight)), ga = ((w + aa)), ha = ((da - ea));\n                    ga = Math.max(Math.min(ga, ha), 0);\n                    var ia = ((((ga / ha)) * fa));\n                    this._wrap.scrollTop = ia;\n                }.bind(this)), y = t.subscribe(\"end\", function() {\n                    t.unsubscribe(x);\n                    t.unsubscribe(y);\n                });\n            }.bind(this));\n        },\n        adjustGripper: function() {\n            var t = this._elem.clientHeight, u = this._content.offsetHeight, v = this._track.offsetHeight, w = ((((t / u)) * v));\n            if (((w < v))) {\n                o.set(this._gripper, \"height\", ((w + \"px\")));\n                var x = ((((this._wrap.scrollTop / u)) * v));\n                o.set(this._gripper, \"JSBNG__top\", ((x + \"px\")));\n                i.show(this._gripper);\n            }\n             else i.hide(this._gripper);\n        ;\n        ;\n            this._checkContentBoundaries();\n            return this;\n        },\n        _checkContentBoundaries: function() {\n            i.conditionClass(this._elem, \"contentBefore\", ((this._wrap.scrollTop > 0)));\n            i.conditionClass(this._elem, \"contentAfter\", !this.isScrolledToBottom());\n        },\n        destroy: function() {\n            this._listeners.forEach(function(t) {\n                t.remove();\n            });\n            this._listeners.length = 0;\n        },\n        _handleMousemove: function(JSBNG__event) {\n            var t = q.getElementPosition(this._track).x, u = q.getElementDimensions(this._track).x;\n            if (((Math.abs(((((t + ((u / 2)))) - q.getEventPosition(JSBNG__event).x))) < 25))) {\n                this.showScrollbar(false);\n            }\n             else this.hideScrollbar();\n        ;\n        ;\n        },\n        _handleScroll: function(JSBNG__event) {\n            this.adjustGripper();\n            if (((this._options.fade !== false))) {\n                this.showScrollbar();\n            }\n        ;\n        ;\n            this.inform(\"JSBNG__scroll\");\n        },\n        hideScrollbar: function(t) {\n            if (!this._scrollbarVisible) {\n                return this;\n            }\n        ;\n        ;\n            this._scrollbarVisible = false;\n            if (this._hideTimeout) {\n                JSBNG__clearTimeout(this._hideTimeout);\n                this._hideTimeout = null;\n            }\n        ;\n        ;\n            if (t) {\n                o.set(this._track, \"opacity\", 0);\n                i.addClass.curry(this._track, \"invisible_elem\");\n            }\n             else this._hideTimeout = function() {\n                if (this._hideAnimation) {\n                    this._hideAnimation.JSBNG__stop();\n                    this._hideAnimation = null;\n                }\n            ;\n            ;\n                this._hideAnimation = (new g(this._track)).from(\"opacity\", 1).to(\"opacity\", 0).duration(250).JSBNG__ondone(i.addClass.curry(this._track, \"invisible_elem\")).go();\n            }.bind(this).defer(750);\n        ;\n        ;\n            return this;\n        },\n        resize: function() {\n            var t = q.getElementDimensions(this._elem).x;\n            if (!this._options.fade) {\n                t -= 10;\n            }\n        ;\n        ;\n            t = Math.max(0, t);\n            o.set(this._body, \"width\", ((t + \"px\")));\n            return this;\n        },\n        showScrollbar: function(t) {\n            this.adjustGripper();\n            if (this._scrollbarVisible) {\n                return this;\n            }\n        ;\n        ;\n            this._scrollbarVisible = true;\n            if (this._hideTimeout) {\n                JSBNG__clearTimeout(this._hideTimeout);\n                this._hideTimeout = null;\n            }\n        ;\n        ;\n            if (this._hideAnimation) {\n                this._hideAnimation.JSBNG__stop();\n                this._hideAnimation = null;\n            }\n        ;\n        ;\n            o.set(this._track, \"opacity\", 1);\n            i.removeClass(this._track, \"invisible_elem\");\n            if (((t !== false))) {\n                this.hideScrollbar();\n            }\n        ;\n        ;\n            return this;\n        },\n        isScrolledToBottom: function() {\n            return ((this._wrap.scrollTop >= ((this._wrap.scrollHeight - this._wrap.clientHeight))));\n        },\n        scrollToBottom: function(t) {\n            this.setScrollTop(this._wrap.scrollHeight, t);\n        },\n        scrollToTop: function(t) {\n            this.setScrollTop(0, t);\n        },\n        scrollIntoView: function(t, u) {\n            var v = this._wrap.clientHeight, w = t.offsetHeight, x = this._wrap.scrollTop, y = ((x + v)), z = t.offsetTop, aa = ((z + w));\n            if (((((z < x)) || ((v < w))))) {\n                this.setScrollTop(z, u);\n            }\n             else if (((aa > y))) {\n                this.setScrollTop(((x + ((aa - y)))), u);\n            }\n            \n        ;\n        ;\n        },\n        poke: function() {\n            var t = this._wrap.scrollTop;\n            this._wrap.scrollTop += 1;\n            this._wrap.scrollTop -= 1;\n            this._wrap.scrollTop = t;\n            return this.showScrollbar(false);\n        },\n        getScrollTop: function() {\n            return this._wrap.scrollTop;\n        },\n        getScrollHeight: function() {\n            return this._wrap.scrollHeight;\n        },\n        setScrollTop: function(t, u) {\n            if (((u !== false))) {\n                if (this._scrollTopAnimation) {\n                    this._scrollTopAnimation.JSBNG__stop();\n                }\n            ;\n            ;\n                this._scrollTopAnimation = (new g(this._wrap)).to(\"scrollTop\", t).ease(g.ease.end).go();\n            }\n             else this._wrap.scrollTop = t;\n        ;\n        ;\n        }\n    });\n    e.exports = s;\n});\n__d(\"ScrollableTypeaheadBehavior\", [\"DOM\",\"CSS\",\"Style\",\"Parent\",\"cx\",\"ScrollableArea\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"CSS\"), i = b(\"Style\"), j = b(\"Parent\"), k = b(\"cx\"), l = b(\"ScrollableArea\"), m = b(\"copyProperties\");\n    function n(o) {\n        this._typeahead = o;\n    };\n;\n    m(n.prototype, {\n        _subscriptions: null,\n        _scrollableElems: null,\n        _scrollableArea: null,\n        _showScrollbar: null,\n        enable: function() {\n            this._scrollableElems = (l.renderDOM());\n            h.addClass(this._scrollableElems.root, \"-cx-PRIVATE-scrollableTypeahead__ScrollableTypeaheadArea\");\n            g.appendContent(this._typeahead.getView().element, this._scrollableElems.root);\n            this._typeahead.getView().JSBNG__content = this._scrollableElems.JSBNG__content;\n            this._scrollableArea = (l.fromNative(this._scrollableElems.root, {\n                fade: false\n            }));\n            this._subscriptions = [this._typeahead.getView().subscribe(\"reset\", this._reset.bind(this)),this._typeahead.getView().subscribe(\"render\", this._render.bind(this)),this._typeahead.getView().subscribe(\"beforeRender\", this._beforeRender.bind(this)),this._typeahead.getView().subscribe(\"next\", this._scrollHelper.bind(this)),this._typeahead.getView().subscribe(\"prev\", this._scrollHelper.bind(this)),];\n            i.set(this._scrollableElems.wrap, \"height\", \"0px\");\n            h.removeClass(this._scrollableElems.root, \"-cx-PRIVATE-scrollableTypeahead__hasResults\");\n        },\n        disable: function() {\n            while (this._subscriptions.length) {\n                this._subscriptions.pop().unsubscribe();\n            ;\n            };\n        ;\n            this._subscriptions = null;\n        },\n        _reset: function() {\n            i.set(this._scrollableElems.wrap, \"height\", \"0px\");\n            h.removeClass(this._scrollableElems.root, \"-cx-PRIVATE-scrollableTypeahead__hasResults\");\n            this._scrollableArea.scrollToTop();\n        },\n        _render: function() {\n            this._scrollableArea.poke();\n            ((this._showScrollbar ? this._scrollableArea.showScrollbar(false) : this._scrollableArea.hideScrollbar(true)));\n            h.addClass(this._scrollableElems.root, \"-cx-PRIVATE-scrollableTypeahead__hasResults\");\n        },\n        _beforeRender: function(o, p) {\n            var q = 5;\n            if (((this._typeahead.getView().maxResults < 10))) {\n                q = 3;\n            }\n        ;\n        ;\n            i.set(this._scrollableElems.body, \"width\", ((this._scrollableElems.wrap.offsetWidth + \"px\")));\n            if (((p.results.length < q))) {\n                i.set(this._scrollableElems.wrap, \"height\", ((((((38 * p.results.length)) + 4)) + \"px\")));\n                this._showScrollbar = false;\n            }\n             else {\n                this._scrollableArea.showScrollbar(false);\n                i.set(this._scrollableElems.wrap, \"height\", ((((((38 * q)) + 4)) + \"px\")));\n                this._showScrollbar = true;\n            }\n        ;\n        ;\n        },\n        _scrollHelper: function(o, p) {\n            if (!j.byClass(p, \"uiScrollableArea\")) {\n                return;\n            }\n        ;\n        ;\n            this._typeahead.getView().ignoreMouseover = true;\n            var q = j.byClass(p, \"uiScrollableAreaWrap\"), r = ((p.offsetTop - q.offsetTop));\n            if (((r < q.scrollTop))) {\n                q.scrollTop = r;\n                return;\n            }\n        ;\n        ;\n            var s = ((r + p.offsetHeight));\n            if (((s > ((q.scrollTop + q.offsetHeight))))) {\n                q.scrollTop = ((s - q.offsetHeight));\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = n;\n});\n__d(\"legacy:LegacyScrollableTypeaheadBehavior\", [\"ScrollableTypeaheadBehavior\",], function(a, b, c, d) {\n    var e = b(\"ScrollableTypeaheadBehavior\");\n    if (!a.TypeaheadBehaviors) {\n        a.TypeaheadBehaviors = {\n        };\n    }\n;\n;\n    a.TypeaheadBehaviors.scrollArea = function(f) {\n        f.enableBehavior(e);\n    };\n}, 3);\n__d(\"MultiBootstrapDataSource\", [\"Class\",\"DataSource\",], function(a, b, c, d, e, f) {\n    var g = b(\"Class\"), h = b(\"DataSource\");\n    function i(j) {\n        this._bootstrapEndpoints = j.bootstrapEndpoints;\n        this.parent.construct(this, j);\n    };\n;\n    g.extend(i, h);\n    i.prototype.bootstrapWithoutToken = function() {\n        for (var j = 0; ((j < this._bootstrapEndpoints.length)); j++) {\n            this.fetch(this._bootstrapEndpoints[j].endpoint, ((this._bootstrapEndpoints[j].data || {\n            })), {\n                bootstrap: true\n            });\n        ;\n        };\n    ;\n    };\n    e.exports = i;\n});\n__d(\"OnVisible\", [\"event-extensions\",\"Arbiter\",\"DOM\",\"Run\",\"Vector\",\"copyProperties\",\"throttle\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"DOM\"), i = b(\"Run\"), j = b(\"Vector\"), k = b(\"copyProperties\"), l = b(\"throttle\");\n    function m(n, o, p, q) {\n        this.element = n;\n        this.handler = o;\n        this.strict = p;\n        this.buffer = ((q || 300));\n        this.scrollHandler = null;\n        this.reset();\n        i.JSBNG__onLeave(this.remove.bind(this));\n    };\n;\n    k(m.prototype, {\n        reset: function() {\n            if (this.scrollListener) {\n                return;\n            }\n        ;\n        ;\n            this.removed = false;\n            this.scrollHandler = l(function(n) {\n                var o = j.getElementPosition(this.element);\n                if (((!o || this.removed))) {\n                    this.remove();\n                    return;\n                }\n            ;\n            ;\n                this.targetY = o.y;\n                var p = j.getScrollPosition().y, q = j.getViewportDimensions().y, r = ((((p + q)) + this.buffer));\n                if (((r > this.targetY))) {\n                    var s = ((!this.strict || ((((p - this.buffer)) < ((this.targetY + j.getElementDimensions(this.element).y))))));\n                    if (s) {\n                        this.remove();\n                        this.handler(!n);\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                return true;\n            }, 100, this);\n            (function() {\n                this.scrollListener = JSBNG__Event.listen(window, \"JSBNG__scroll\", this.scrollHandler);\n                this.resizeListener = JSBNG__Event.listen(window, \"resize\", this.scrollHandler);\n                this.domScrollListener = g.subscribe(\"dom-scroll\", this.scrollHandler);\n                this.scrollHandler.defer();\n            }).bind(this).defer();\n        },\n        remove: function() {\n            this.removed = true;\n            if (this.scrollListener) {\n                this.scrollListener.remove();\n                this.resizeListener.remove();\n                this.domScrollListener.unsubscribe();\n                this.scrollListener = this.resizeListener = this.domScrollListener = null;\n            }\n        ;\n        ;\n        },\n        setBuffer: function(n) {\n            this.buffer = n;\n            ((this.scrollHandler && this.scrollHandler.defer()));\n        }\n    });\n    e.exports = m;\n});\n__d(\"Poller\", [\"AsyncRequest\",\"Cookie\",\"copyProperties\",\"Env\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncRequest\"), h = b(\"Cookie\"), i = b(\"copyProperties\"), j = b(\"Env\");\n    function k(l, m, n) {\n        this._clearOnQuicklingEvent = !n;\n        this._requestCallback = m;\n        this.setTimePeriod(l);\n    };\n;\n    k.MIN_TIME_PERIOD = 2000;\n    i(k.prototype, {\n        JSBNG__stop: function() {\n            JSBNG__clearTimeout(this._token);\n            this._token = null;\n            this._cancelRequest();\n        },\n        scheduleRequest: function() {\n            this.JSBNG__stop();\n            if (this._timePeriod) {\n                this._token = this._makeRequest.bind(this).defer(this._timePeriod, this._clearOnQuicklingEvent);\n            }\n        ;\n        ;\n        },\n        requestNow: function() {\n            this.JSBNG__stop();\n            this._makeRequest();\n        },\n        _timePeriod: null,\n        setTimePeriod: function(l) {\n            l = ((l || null));\n            if (((l && ((isNaN(l) || ((l < k.MIN_TIME_PERIOD))))))) {\n                return;\n            }\n        ;\n        ;\n            if (((l && ((this._timePeriod == null))))) {\n                this._token = this._makeRequest.bind(this).defer(l, this._clearOnQuicklingEvent);\n            }\n        ;\n        ;\n            this._timePeriod = l;\n        },\n        _makeRequest: function() {\n            this._cancelRequest();\n            if (!this._isLoadUser()) {\n                return;\n            }\n        ;\n        ;\n            var l = new g(), m = true;\n            l.setInitialHandler(function() {\n                return m;\n            });\n            this._cancelRequest = function() {\n                m = false;\n            };\n            l.setFinallyHandler(this.scheduleRequest.bind(this));\n            l.setInitialHandler = bagofholding;\n            l.setFinallyHandler = bagofholding;\n            this._requestCallback(l);\n            if (m) {\n                l.send();\n            }\n        ;\n        ;\n        },\n        _isLoadUser: function() {\n            return ((j.user == h.get(\"c_user\")));\n        },\n        _cancelRequest: bagofholding,\n        getTimePeriod: function() {\n            return this._timePeriod;\n        }\n    });\n    e.exports = k;\n});\n__d(\"Popover\", [\"event-extensions\",\"Arbiter\",\"ArbiterMixin\",\"Class\",\"ContextualLayer\",\"ContextualLayerHideOnScroll\",\"CSS\",\"DataStore\",\"DOM\",\"Input\",\"KeyStatus\",\"LayerHideOnEscape\",\"Toggler\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"Class\"), j = b(\"ContextualLayer\"), k = b(\"ContextualLayerHideOnScroll\"), l = b(\"CSS\"), m = b(\"DataStore\"), n = b(\"DOM\"), o = b(\"Input\"), p = b(\"KeyStatus\"), q = b(\"LayerHideOnEscape\"), r = b(\"Toggler\"), s = b(\"copyProperties\");\n    r.subscribe([\"show\",\"hide\",], function(u, v) {\n        var w = m.get(v.getActive(), \"Popover\");\n        if (w) {\n            if (((u === \"show\"))) {\n                w.showLayer();\n            }\n             else w.hideLayer();\n        ;\n        }\n    ;\n    ;\n    });\n    function t(u, v, w, x) {\n        this._root = u;\n        this._triggerElem = v;\n        this._behaviors = w;\n        this._config = x;\n        if (!((((v.nodeName === \"A\")) && ((v.rel === \"toggle\"))))) {\n            JSBNG__Event.listen(v, \"click\", function() {\n                r.bootstrap(v);\n            });\n        }\n    ;\n    ;\n        m.set(u, \"Popover\", this);\n    };\n;\n    s(t.prototype, h, {\n        _layer: null,\n        _closeListener: null,\n        ensureInit: function() {\n            if (!this._layer) {\n                this._init();\n            }\n        ;\n        ;\n        },\n        showLayer: function() {\n            this.ensureInit();\n            this._layer.show();\n            r.show(this._root);\n            l.addClass(this._root, \"selected\");\n            this.inform(\"show\");\n            this._triggerElem.setAttribute(\"aria-expanded\", \"true\");\n        },\n        hideLayer: function() {\n            this._layer.hide();\n            this._triggerElem.setAttribute(\"aria-expanded\", \"false\");\n        },\n        isShown: function() {\n            return this._layer.isShown();\n        },\n        setLayerContent: function(u) {\n            this.ensureInit();\n            this._layer.setContent(u);\n        },\n        _init: function() {\n            var u = new j({\n                context: this._triggerElem,\n                position: \"below\"\n            }, n.create(\"div\"));\n            u.enableBehaviors([k,q,]);\n            r.createInstance(u.getRoot()).setSticky(false);\n            u.subscribe(\"hide\", this._onLayerHide.bind(this));\n            ((this._behaviors && u.enableBehaviors(this._behaviors)));\n            this._layer = u;\n            if (this._config.alignh) {\n                this._layer.setAlignment(this._config.alignh);\n            }\n        ;\n        ;\n            if (this._config.layer_content) {\n                this._layer.setContent(this._config.layer_content);\n            }\n        ;\n        ;\n            this.inform(\"init\", null, g.BEHAVIOR_PERSISTENT);\n        },\n        _onLayerHide: function() {\n            r.hide(this._root);\n            l.removeClass(this._root, \"selected\");\n            this.inform(\"hide\");\n            if (p.isKeyDown()) {\n                o.JSBNG__focus(this._triggerElem);\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = t;\n});\n__d(\"PopoverMenuInterface\", [\"Arbiter\",\"ArbiterMixin\",\"Class\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"Class\"), j = b(\"copyProperties\");\n    function k() {\n    \n    };\n;\n    j(k.prototype, h, {\n        getRoot: bagofholding,\n        JSBNG__onShow: bagofholding,\n        JSBNG__onHide: bagofholding,\n        focusAnItem: bagof(false),\n        JSBNG__blur: bagofholding,\n        handleKeydown: bagof(false),\n        done: function() {\n            this.inform(\"done\");\n        }\n    });\n    e.exports = k;\n});\n__d(\"PopoverAsyncMenuLoading\", [\"Class\",\"copyProperties\",\"DOM\",\"PopoverMenuInterface\",], function(a, b, c, d, e, f) {\n    var g = b(\"Class\"), h = b(\"copyProperties\"), i = b(\"DOM\"), j = b(\"PopoverMenuInterface\");\n    function k(l) {\n        this.parent.construct(this);\n        this._className = ((l || \"\"));\n    };\n;\n    g.extend(k, j);\n    h(k.prototype, {\n        _root: null,\n        getRoot: function() {\n            if (!this._root) {\n                this._root = i.create(\"div\", {\n                    className: this._className\n                }, i.create(\"div\", {\n                    className: \"uiMenuXBorder\"\n                }, i.create(\"div\", {\n                    className: \"uiMenuX uiMenuXLoading\"\n                }, i.create(\"span\", {\n                    className: \"spinner\"\n                }))));\n            }\n        ;\n        ;\n            return this._root;\n        }\n    });\n    e.exports = k;\n});\n__d(\"PopoverMenu\", [\"event-extensions\",\"Arbiter\",\"ArbiterMixin\",\"ARIA\",\"BehaviorsMixin\",\"Class\",\"Input\",\"Keys\",\"KeyStatus\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"ARIA\"), j = b(\"BehaviorsMixin\"), k = b(\"Class\"), l = b(\"Input\"), m = b(\"Keys\"), n = b(\"KeyStatus\"), o = b(\"copyProperties\");\n    function p(q, r, s, t) {\n        this._popover = q;\n        this._triggerElem = r;\n        this._initialMenu = s;\n        q.subscribe(\"init\", this._onLayerInit.bind(this));\n        q.subscribe(\"show\", this._onPopoverShow.bind(this));\n        q.subscribe(\"hide\", this._onPopoverHide.bind(this));\n        ((t && this.enableBehaviors(t)));\n    };\n;\n    o(p.prototype, h, j);\n    o(p.prototype, {\n        _keydownListener: null,\n        _popoverShown: false,\n        setMenu: function(q) {\n            this._menu = q;\n            var r = q.getRoot();\n            this._popover.setLayerContent(r);\n            q.subscribe(\"done\", this._onMenuDone.bind(this));\n            if (this._popoverShown) {\n                this._menu.JSBNG__onShow();\n            }\n        ;\n        ;\n            i.owns(this._triggerElem, r);\n            this.inform(\"setMenu\", null, g.BEHAVIOR_PERSISTENT);\n        },\n        getPopover: function() {\n            return this._popover;\n        },\n        getTriggerElem: function() {\n            return this._triggerElem;\n        },\n        getMenu: function() {\n            return this._menu;\n        },\n        _onLayerInit: function() {\n            this.setMenu(this._initialMenu);\n        },\n        _onPopoverShow: function() {\n            if (this._menu) {\n                this._menu.JSBNG__onShow();\n                if (n.isKeyDown()) {\n                    this._menu.focusAnItem();\n                }\n            ;\n            ;\n                this._keydownListener = JSBNG__Event.listen(JSBNG__document.documentElement, \"keydown\", this._handleKeydown.bind(this));\n            }\n        ;\n        ;\n            this._popoverShown = true;\n        },\n        _onPopoverHide: function() {\n            if (this._menu) {\n                this._menu.JSBNG__onHide();\n            }\n        ;\n        ;\n            if (this._keydownListener) {\n                this._keydownListener.remove();\n                this._keydownListener = null;\n            }\n        ;\n        ;\n            this._popoverShown = false;\n        },\n        _handleKeydown: function(q) {\n            if (q.getModifiers().any) {\n                return;\n            }\n        ;\n        ;\n            var r = JSBNG__Event.getKeyCode(q);\n            switch (r) {\n              case m.RETURN:\n                return;\n              case m.UP:\n            \n              case m.DOWN:\n                this._menu.handleKeydown(r);\n                break;\n              default:\n                if (((this._menu.handleKeydown(r) === false))) {\n                    this._menu.JSBNG__blur();\n                    this._menu.handleKeydown(r);\n                }\n            ;\n            ;\n                break;\n            };\n        ;\n            q.prevent();\n        },\n        _onMenuDone: function(q) {\n            this._popover.hideLayer.bind(this._popover).defer();\n            if (n.isKeyDown()) {\n                l.JSBNG__focus(this._triggerElem);\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = p;\n});\n__d(\"PopoverAsyncMenu\", [\"event-extensions\",\"AsyncRequest\",\"Class\",\"CSS\",\"DOM\",\"PopoverAsyncMenuLoading\",\"PopoverMenu\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"AsyncRequest\"), h = b(\"Class\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"PopoverAsyncMenuLoading\"), l = b(\"PopoverMenu\"), m = b(\"copyProperties\"), n = {\n    }, o = 0;\n    function p(q, r, s, t, u) {\n        this._endpoint = t;\n        this._loadingMenu = s;\n        this._instanceId = o++;\n        n[this._instanceId] = this;\n        this._mouseoverListener = JSBNG__Event.listen(r, \"mouseover\", this._fetchMenu.bind(this));\n        this.parent.construct(this, q, r, null, u);\n    };\n;\n    p.setMenu = function(q, r) {\n        n[q].setMenu(r);\n    };\n    h.extend(p, l);\n    m(p.prototype, {\n        _fetched: false,\n        _mouseoverListener: null,\n        _onLayerInit: function() {\n            if (!this._menu) {\n                this.setMenu(this._loadingMenu);\n            }\n        ;\n        ;\n            this._fetchMenu();\n        },\n        _fetchMenu: function() {\n            if (this._fetched) {\n                return;\n            }\n        ;\n        ;\n            new g().setURI(this._endpoint).setData({\n                pmid: this._instanceId\n            }).send();\n            this._fetched = true;\n            if (this._mouseoverListener) {\n                this._mouseoverListener.remove();\n                this._mouseoverListener = null;\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = p;\n});\n__d(\"PopoverMenuOverlappingBorder\", [\"function-extensions\",\"CSS\",\"DOM\",\"Style\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"Style\"), j = b(\"copyProperties\");\n    function k(l) {\n        this._popoverMenu = l;\n        this._popover = l.getPopover();\n        this._triggerElem = l.getTriggerElem();\n    };\n;\n    j(k.prototype, {\n        _shortBorder: null,\n        _setMenuSubscription: null,\n        _showSubscription: null,\n        _menuSubscription: null,\n        enable: function() {\n            this._setMenuSubscription = this._popoverMenu.subscribe(\"setMenu\", this._onSetMenu.bind(this));\n        },\n        disable: function() {\n            this._popoverMenu.unsubscribe(this._setMenuSubscription);\n            this._setMenuSubscription = null;\n            this._removeBorderSubscriptions();\n            this._removeShortBorder();\n        },\n        _onSetMenu: function() {\n            this._removeBorderSubscriptions();\n            this._menu = this._popoverMenu.getMenu();\n            this._renderShortBorder(this._menu.getRoot());\n            this._showSubscription = this._popover.subscribe(\"show\", this._updateBorder.bind(this));\n            this._menuSubscription = this._menu.subscribe([\"change\",\"resize\",], Function.prototype.defer.shield(this._updateBorder.bind(this)));\n            this._updateBorder();\n        },\n        _updateBorder: function() {\n            var l = this._menu.getRoot(), m = this._triggerElem.offsetWidth;\n            i.set(l, \"min-width\", ((m + \"px\")));\n            var n = Math.max(((l.offsetWidth - m)), 0);\n            i.set(this._shortBorder, \"width\", ((n + \"px\")));\n        },\n        _renderShortBorder: function(l) {\n            this._shortBorder = h.create(\"div\", {\n                className: \"uiMenuXShortBorder\"\n            });\n            h.appendContent(l, this._shortBorder);\n            g.addClass(l, \"uiMenuXWithShortBorder\");\n        },\n        _removeShortBorder: function() {\n            if (this._shortBorder) {\n                h.remove(this._shortBorder);\n                this._shortBorder = null;\n                g.removeClass(this._popoverMenu.getMenu().getRoot(), \"uiMenuXShortBorder\");\n            }\n        ;\n        ;\n        },\n        _removeBorderSubscriptions: function() {\n            if (this._showSubscription) {\n                this._popover.unsubscribe(this._showSubscription);\n                this._showSubscription = null;\n            }\n        ;\n        ;\n            if (this._menuSubscription) {\n                this._menu.unsubscribe(this._menuSubscription);\n                this._menuSubscription = null;\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = k;\n});\n__d(\"PrivacyModel\", [\"PrivacyConst\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"PrivacyConst\"), h = b(\"copyProperties\");\n    function i() {\n        this.value = g.BaseValue.ALL_FRIENDS;\n        this.friends = g.FriendsValue.NO_FRIENDS;\n        this.networks = [];\n        this.objects = [];\n        this.lists = [];\n        this.lists_x = [];\n        this.list_anon = 0;\n        this.ids_anon = [];\n        this.list_x_anon = 0;\n        this.ids_x_anon = [];\n        this.tdata = {\n        };\n        return this;\n    };\n;\n    h(i.prototype, {\n        init: function(j, k, l, m, n, o, p, q, r, s, t) {\n            this.value = j;\n            this.friends = k;\n            this.networks = l.slice();\n            this.objects = m.slice();\n            this.lists = n.slice();\n            this.lists_x = o.slice();\n            this.list_anon = p;\n            this.ids_anon = q.slice();\n            this.list_x_anon = r;\n            this.ids_x_anon = s.slice();\n            t = ((t || {\n            }));\n            h(this.tdata, t);\n        },\n        clone: function() {\n            var j = new i();\n            j.init(this.value, this.friends, this.networks, this.objects, this.lists, this.lists_x, this.list_anon, this.ids_anon, this.list_x_anon, this.ids_x_anon, this.tdata);\n            return j;\n        },\n        getData: function() {\n            var j = [\"value\",\"friends\",\"networks\",\"objects\",\"lists\",\"lists_x\",\"list_anon\",\"ids_anon\",\"list_x_anon\",\"ids_x_anon\",], k = {\n            };\n            for (var l = 0; ((l < j.length)); ++l) {\n                var m = j[l];\n                k[m] = this[m];\n            };\n        ;\n            return k;\n        }\n    });\n    e.exports = i;\n});\n__d(\"UIPagelet\", [\"AjaxPipeRequest\",\"AsyncRequest\",\"DOM\",\"HTML\",\"ScriptPathState\",\"URI\",\"copyProperties\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"AjaxPipeRequest\"), h = b(\"AsyncRequest\"), i = b(\"DOM\"), j = b(\"HTML\"), k = b(\"ScriptPathState\"), l = b(\"URI\"), m = b(\"copyProperties\"), n = b(\"ge\");\n    function o(p, q, r, s) {\n        this._id = ((p || null));\n        this._element = n(((p || i.create(\"div\"))));\n        this._src = ((q || null));\n        this._context_data = ((r || {\n        }));\n        this._data = ((s || {\n        }));\n        this._handler = bagofholding;\n        this._request = null;\n        this._use_ajaxpipe = false;\n        this._is_bundle = true;\n        this._allow_cross_page_transition = false;\n        this._append = false;\n        return this;\n    };\n;\n    o.loadFromEndpoint = function(p, q, r, s) {\n        s = ((s || {\n        }));\n        var t = \"/ajax/pagelet/generic.php/\";\n        if (s.intern) {\n            t = ((\"/intern\" + t));\n        }\n    ;\n    ;\n        var u = ((t + p)).replace(/\\/+/g, \"/\");\n        if (s.subdomain) {\n            u = l(u).setSubdomain(s.subdomain);\n        }\n    ;\n    ;\n        var v = new o(q, u, r).setUseAjaxPipe(s.usePipe).setPageletCacheMiss(s.pageletCacheMiss).setBundleOption(((((p.substring(0, 8) != \"/intern/\")) && ((s.bundle !== false))))).setAppend(s.append).setJSNonBlock(s.jsNonblock).setForceFinish(s.forceFinish).setAutomatic(s.automatic).setDisplayCallback(s.displayCallback).setConstHeight(s.constHeight).setAllowCrossPageTransition(s.crossPage);\n        ((s.handler && v.setHandler(s.handler)));\n        v.go();\n        return v;\n    };\n    m(o.prototype, {\n        getElement: function(p) {\n            p = ((p || false));\n            if (p) {\n                this._element = n(this._id);\n            }\n        ;\n        ;\n            return this._element;\n        },\n        setHandler: function(p) {\n            this._handler = p;\n            return this;\n        },\n        go: function(p, q) {\n            if (((((arguments.length >= 2)) || ((typeof p == \"string\"))))) {\n                this._src = p;\n                this._data = ((q || {\n                }));\n            }\n             else if (((arguments.length == 1))) {\n                this._data = p;\n            }\n            \n        ;\n        ;\n            this.refresh();\n            return this;\n        },\n        setAllowCrossPageTransition: function(p) {\n            this._allow_cross_page_transition = p;\n            return this;\n        },\n        setBundleOption: function(p) {\n            this._is_bundle = p;\n            return this;\n        },\n        refresh: function(p) {\n            var q = function(t) {\n                this._request = null;\n                if (((p && this._id))) {\n                    this._element = n(this._id);\n                }\n            ;\n            ;\n                var u = j(t.getPayload());\n                if (this._append) {\n                    i.appendContent(this._element, u);\n                }\n                 else i.setContent(this._element, u);\n            ;\n            ;\n                this._handler();\n            }.bind(this);\n            if (this._use_ajaxpipe) {\n                k.setIsUIPageletRequest(true);\n                this._request = new g();\n                this._request.setCanvasId(this._id).setAppend(this._append).setConstHeight(this._constHeight).setJSNonBlock(this._jsNonblock).setForceFinish(this._forceFinish).setAutomatic(this._automatic).setPageletCacheMiss(this._pageletCacheMiss).setDisplayCallback(this._displayCallback);\n            }\n             else {\n                var r = this._displayCallback;\n                this._request = new h().setMethod(\"GET\").setReadOnly(true).setOption(\"bundle\", this._is_bundle).setHandler(function(t) {\n                    if (r) {\n                        r(q.curry(t));\n                    }\n                     else q(t);\n                ;\n                ;\n                });\n            }\n        ;\n        ;\n            var s = {\n            };\n            m(s, this._context_data);\n            m(s, this._data);\n            this._request.setURI(this._src).setAllowCrossPageTransition(this._allow_cross_page_transition).setData({\n                data: JSON.stringify(s)\n            }).send();\n            return this;\n        },\n        cancel: function() {\n            if (this._request) {\n                this._request.abort();\n            }\n        ;\n        ;\n        },\n        setUseAjaxPipe: function(p) {\n            this._use_ajaxpipe = !!p;\n            return this;\n        },\n        setPageletCacheMiss: function(p) {\n            this._pageletCacheMiss = p;\n            return this;\n        },\n        setAppend: function(p) {\n            this._append = !!p;\n            return this;\n        },\n        setJSNonBlock: function(p) {\n            this._jsNonblock = !!p;\n            return this;\n        },\n        setForceFinish: function(p) {\n            this._forceFinish = !!p;\n            return this;\n        },\n        setAutomatic: function(p) {\n            this._automatic = !!p;\n            return this;\n        },\n        setDisplayCallback: function(p) {\n            this._displayCallback = p;\n            return this;\n        },\n        setConstHeight: function(p) {\n            this._constHeight = !!p;\n            return this;\n        }\n    });\n    e.exports = o;\n});\n__d(\"ScrollingPager\", [\"Arbiter\",\"copyProperties\",\"CSS\",\"OnVisible\",\"UIPagelet\",\"$\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"copyProperties\"), i = b(\"CSS\"), j = b(\"OnVisible\"), k = b(\"UIPagelet\"), l = b(\"$\"), m = b(\"ge\"), n = {\n    };\n    function o(p, q, r, s) {\n        this.scroll_loader_id = p;\n        this.pagelet_src = q;\n        this.data = r;\n        this.options = ((s || {\n        }));\n        if (this.options.target_id) {\n            this.target_id = this.options.target_id;\n            this.options.append = true;\n        }\n         else this.target_id = p;\n    ;\n    ;\n        this.handler = null;\n    };\n;\n    h(o, {\n        REGISTERED: \"ScrollingPager/registered\",\n        getInstance: function(p) {\n            return n[p];\n        }\n    });\n    h(o.prototype, {\n        setBuffer: function(p) {\n            this.options.buffer = p;\n            ((this.JSBNG__onvisible && this.JSBNG__onvisible.setBuffer(p)));\n        },\n        getBuffer: function() {\n            return this.options.buffer;\n        },\n        register: function() {\n            this.JSBNG__onvisible = new j(l(this.scroll_loader_id), this.getHandler(), false, this.options.buffer, this.options);\n            n[this.scroll_loader_id] = this;\n            g.inform(o.REGISTERED, {\n                id: this.scroll_loader_id\n            });\n        },\n        getInstance: function(p) {\n            return n[p];\n        },\n        getHandler: function() {\n            if (this.handler) {\n                return this.handler;\n            }\n        ;\n        ;\n            function p(q) {\n                var r = m(this.scroll_loader_id);\n                if (!r) {\n                    this.JSBNG__onvisible.remove();\n                    return;\n                }\n            ;\n            ;\n                i.addClass(r.firstChild, \"async_saving\");\n                var s = this.options.handler;\n                this.options.handler = function() {\n                    g.inform(\"ScrollingPager/loadingComplete\");\n                    ((s && s.apply(null, arguments)));\n                };\n                if (q) {\n                    this.data.pager_fired_on_init = true;\n                }\n            ;\n            ;\n                k.loadFromEndpoint(this.pagelet_src, this.target_id, this.data, this.options);\n            };\n        ;\n            return p.bind(this);\n        },\n        setHandler: function(p) {\n            this.handler = p;\n        },\n        removeOnVisible: function() {\n            this.JSBNG__onvisible.remove();\n        }\n    });\n    e.exports = o;\n});\n__d(\"InputSelection\", [\"DOM\",\"Input\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"Input\"), i = {\n        get: function(j) {\n            if (!JSBNG__document.selection) {\n                return {\n                    start: j.selectionStart,\n                    end: j.selectionEnd\n                };\n            }\n        ;\n        ;\n            var k = JSBNG__document.selection.createRange();\n            if (((k.parentElement() !== j))) {\n                return {\n                    start: 0,\n                    end: 0\n                };\n            }\n        ;\n        ;\n            var l = j.value.length;\n            if (g.isNodeOfType(j, \"input\")) {\n                return {\n                    start: -k.moveStart(\"character\", -l),\n                    end: -k.moveEnd(\"character\", -l)\n                };\n            }\n             else {\n                var m = k.duplicate();\n                m.moveToElementText(j);\n                m.setEndPoint(\"StartToEnd\", k);\n                var n = ((l - m.text.length));\n                m.setEndPoint(\"StartToStart\", k);\n                return {\n                    start: ((l - m.text.length)),\n                    end: n\n                };\n            }\n        ;\n        ;\n        },\n        set: function(j, k, l) {\n            if (((typeof l == \"undefined\"))) {\n                l = k;\n            }\n        ;\n        ;\n            if (JSBNG__document.selection) {\n                if (((j.tagName == \"TEXTAREA\"))) {\n                    var m = ((j.value.slice(0, k).match(/\\r/g) || [])).length, n = ((j.value.slice(k, l).match(/\\r/g) || [])).length;\n                    k -= m;\n                    l -= ((m + n));\n                }\n            ;\n            ;\n                var o = j.createTextRange();\n                o.collapse(true);\n                o.moveStart(\"character\", k);\n                o.moveEnd(\"character\", ((l - k)));\n                o.select();\n            }\n             else {\n                j.selectionStart = k;\n                j.selectionEnd = Math.min(l, j.value.length);\n                h.JSBNG__focus(j);\n            }\n        ;\n        ;\n        }\n    };\n    e.exports = i;\n});\n__d(\"ControlledReferer\", [\"event-extensions\",\"URI\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"URI\"), h = {\n        useFacebookReferer: function(i, j, k) {\n            var l = false;\n            function m() {\n                if (l) {\n                    return;\n                }\n            ;\n            ;\n                l = true;\n                i.contentWindow.JSBNG__document.body.style.margin = 0;\n                j();\n            };\n        ;\n            var n;\n            if (((JSBNG__document.domain !== \"facebook.com\"))) {\n                n = \"/intern/common/referer_frame.php\";\n            }\n             else if (g().isSecure()) {\n                n = \"https://s-static.ak.facebook.com/common/referer_frame.php\";\n            }\n             else n = \"http://static.ak.facebook.com/common/referer_frame.php\";\n            \n        ;\n        ;\n            if (k) {\n                n += ((\"?fb_source=\" + k));\n            }\n        ;\n        ;\n            JSBNG__Event.listen(i, \"load\", m);\n            i.src = n;\n        },\n        useFacebookRefererHtml: function(i, j, k) {\n            h.useFacebookReferer(i, function() {\n                i.contentWindow.JSBNG__document.body.innerHTML = j;\n            }, k);\n        }\n    };\n    e.exports = h;\n});\n__d(\"swfobject\", [\"AsyncRequest\",\"Bootloader\",\"ControlledReferer\",\"copyProperties\",\"CSS\",\"DOM\",\"function-extensions\",\"ge\",\"htmlSpecialChars\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncRequest\"), h = b(\"Bootloader\"), i = b(\"ControlledReferer\"), j = b(\"copyProperties\"), k = b(\"CSS\"), l = b(\"DOM\");\n    b(\"function-extensions\");\n    var m = b(\"ge\"), n = b(\"htmlSpecialChars\");\n    if (((typeof o == \"undefined\"))) {\n        var o = {\n        };\n    }\n;\n;\n    if (((typeof o.util == \"undefined\"))) {\n        o.util = {\n        };\n    }\n;\n;\n    if (((typeof o.SWFObjectUtil == \"undefined\"))) {\n        o.SWFObjectUtil = {\n        };\n    }\n;\n;\n    o.SWFObject = function(u, v, w, x, y, z, aa, ba, ca, da) {\n        if (!JSBNG__document.getElementById) {\n            return;\n        }\n    ;\n    ;\n        this.DETECT_KEY = ((da ? da : \"detectflash\"));\n        this.skipDetect = o.util.getRequestParameter(this.DETECT_KEY);\n        this.params = {\n        };\n        this.variables = {\n        };\n        this.attributes = [];\n        this.fallback_html = \"\";\n        this.fallback_js_fcn = function() {\n        \n        };\n        if (u) {\n            this.setAttribute(\"swf\", u);\n        }\n    ;\n    ;\n        if (v) {\n            this.setAttribute(\"id\", v);\n        }\n    ;\n    ;\n        if (w) {\n            this.setAttribute(\"width\", w);\n        }\n    ;\n    ;\n        if (x) {\n            this.setAttribute(\"height\", x);\n        }\n    ;\n    ;\n        this.installedVer = o.SWFObjectUtil.getPlayerVersion();\n        if (y) {\n            if (!((y instanceof Array))) {\n                y = [y,];\n            }\n        ;\n        ;\n            var ea;\n            y.forEach(function(ha) {\n                ea = new o.PlayerVersion(ha.toString().split(\".\"));\n                if (((ea.major == this.installedVer.major))) {\n                    this.setAttribute(\"version\", ea);\n                    return;\n                }\n                 else if (((!this.getAttribute(\"version\") || ((ea.major < this.getAttribute(\"version\").major))))) {\n                    this.setAttribute(\"version\", ea);\n                }\n                \n            ;\n            ;\n            }.bind(this));\n        }\n    ;\n    ;\n        if (((((!window.JSBNG__opera && JSBNG__document.all)) && ((this.installedVer.major > 7))))) {\n            if (!o.unloadSet) {\n                o.SWFObjectUtil.prepUnload = function() {\n                    var ha = function() {\n                    \n                    }, ia = function() {\n                    \n                    };\n                    window.JSBNG__attachEvent(\"JSBNG__onunload\", o.SWFObjectUtil.cleanupSWFs);\n                };\n                window.JSBNG__attachEvent(\"JSBNG__onbeforeunload\", o.SWFObjectUtil.prepUnload);\n                o.unloadSet = true;\n            }\n        ;\n        }\n    ;\n    ;\n        if (z) {\n            this.addParam(\"bgcolor\", z);\n        }\n    ;\n    ;\n        var fa = ((aa ? aa : \"high\"));\n        this.addParam(\"quality\", fa);\n        this.setAttribute(\"useExpressInstall\", false);\n        this.setAttribute(\"doExpressInstall\", false);\n        var ga = (((ba) ? ba : window.JSBNG__location));\n        this.setAttribute(\"xiRedirectUrl\", ga);\n        this.setAttribute(\"redirectUrl\", \"\");\n        if (ca) {\n            this.setAttribute(\"redirectUrl\", ca);\n        }\n    ;\n    ;\n        this.setAttribute(\"useIframe\", false);\n    };\n    o.SWFObject.ieWorkaroundApplied = false;\n    o.SWFObject.ensureIEWorkaroundAttached = function() {\n        if (((!o.SWFObject.ieWorkaroundApplied && JSBNG__document.JSBNG__attachEvent))) {\n            o.SWFObject.ieWorkaroundApplied = true;\n            JSBNG__document.JSBNG__attachEvent(\"JSBNG__onpropertychange\", o.SWFObject.JSBNG__onDocumentPropertyChange);\n        }\n    ;\n    ;\n    };\n    o.SWFObject.JSBNG__onDocumentPropertyChange = function(JSBNG__event) {\n        if (((JSBNG__event.propertyName == \"title\"))) {\n            var u = JSBNG__document.title;\n            if (((((u != null)) && ((u.indexOf(\"#!\") != -1))))) {\n                u = u.substring(0, u.indexOf(\"#!\"));\n                JSBNG__document.title = u;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    };\n    j(o.SWFObject.prototype, {\n        useExpressInstall: function(u) {\n            this.xiSWFPath = ((!u ? \"/swf/expressinstall.swf\" : u));\n            this.setAttribute(\"useExpressInstall\", true);\n        },\n        setAttribute: function(u, v) {\n            this.attributes[u] = v;\n        },\n        getAttribute: function(u) {\n            return ((this.attributes[u] || \"\"));\n        },\n        addParam: function(u, v) {\n            this.params[u] = v;\n        },\n        getParams: function() {\n            return this.params;\n        },\n        addVariable: function(u, v) {\n            this.variables[u] = v;\n        },\n        getVariable: function(u) {\n            return ((this.variables[u] || \"\"));\n        },\n        getVariables: function() {\n            return this.variables;\n        },\n        getVariablePairs: function() {\n            var u = [], v, w = this.getVariables();\n            for (v in w) {\n                u[u.length] = ((((v + \"=\")) + w[v]));\n            ;\n            };\n        ;\n            return u.join(\"&\");\n        },\n        getSWFHTML: function() {\n            var u, v, w;\n            if (((((JSBNG__navigator.plugins && JSBNG__navigator.mimeTypes)) && JSBNG__navigator.mimeTypes.length))) {\n                if (this.getAttribute(\"doExpressInstall\")) {\n                    this.addVariable(\"MMplayerType\", \"PlugIn\");\n                    this.setAttribute(\"swf\", this.xiSWFPath);\n                }\n            ;\n            ;\n                v = {\n                    type: \"application/x-shockwave-flash\",\n                    src: this.getAttribute(\"swf\"),\n                    width: this.getAttribute(\"width\"),\n                    height: this.getAttribute(\"height\"),\n                    style: ((this.getAttribute(\"style\") || \"display: block;\")),\n                    id: this.getAttribute(\"id\"),\n                    JSBNG__name: this.getAttribute(\"id\")\n                };\n                var x = this.getParams();\n                for (var y in x) {\n                    v[y] = x[y];\n                ;\n                };\n            ;\n                w = this.getVariablePairs();\n                if (w) {\n                    v.flashvars = w;\n                }\n            ;\n            ;\n                u = t(\"embed\", v, null);\n            }\n             else {\n                if (this.getAttribute(\"doExpressInstall\")) {\n                    this.addVariable(\"MMplayerType\", \"ActiveX\");\n                    this.setAttribute(\"swf\", this.xiSWFPath);\n                }\n            ;\n            ;\n                v = {\n                    id: this.getAttribute(\"id\"),\n                    classid: \"clsid:D27CDB6E-AE6D-11cf-96B8-444553540000\",\n                    width: this.getAttribute(\"width\"),\n                    height: this.getAttribute(\"height\"),\n                    style: ((this.getAttribute(\"style\") || \"display: block;\"))\n                };\n                var z = t(\"param\", {\n                    JSBNG__name: \"movie\",\n                    value: this.getAttribute(\"swf\")\n                }, null), x = this.getParams();\n                for (var y in x) {\n                    z += t(\"param\", {\n                        JSBNG__name: y,\n                        value: x[y]\n                    }, null);\n                ;\n                };\n            ;\n                w = this.getVariablePairs();\n                if (w) {\n                    z += t(\"param\", {\n                        JSBNG__name: \"flashvars\",\n                        value: w\n                    }, null);\n                }\n            ;\n            ;\n                u = t(\"object\", v, z);\n            }\n        ;\n        ;\n            return u;\n        },\n        write: function(u) {\n            if (this.getAttribute(\"useExpressInstall\")) {\n                var v = new o.PlayerVersion([6,0,65,]);\n                if (((this.installedVer.versionIsValid(v) && !this.installedVer.versionIsValid(this.getAttribute(\"version\"))))) {\n                    this.setAttribute(\"doExpressInstall\", true);\n                    this.addVariable(\"MMredirectURL\", escape(this.getAttribute(\"xiRedirectUrl\")));\n                    JSBNG__document.title = ((JSBNG__document.title.slice(0, 47) + \" - Flash Player Installation\"));\n                    this.addVariable(\"MMdoctitle\", JSBNG__document.title);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            var w = ((((typeof u == \"string\")) ? JSBNG__document.getElementById(u) : u));\n            if (!w) {\n                return false;\n            }\n        ;\n        ;\n            k.addClass(w, \"swfObject\");\n            w.setAttribute(\"data-swfid\", this.getAttribute(\"id\"));\n            if (((((this.skipDetect || this.getAttribute(\"doExpressInstall\"))) || this.installedVer.versionIsValid(this.getAttribute(\"version\"))))) {\n                if (!this.getAttribute(\"useIframe\")) {\n                    o.SWFObject.ensureIEWorkaroundAttached();\n                    w.innerHTML = this.getSWFHTML();\n                }\n                 else this._createIframe(w);\n            ;\n            ;\n                return true;\n            }\n             else {\n                if (((this.getAttribute(\"redirectUrl\") != \"\"))) {\n                    JSBNG__document.JSBNG__location.replace(this.getAttribute(\"redirectUrl\"));\n                }\n            ;\n            ;\n                var x = ((((((((((((this.getAttribute(\"version\").major + \".\")) + this.getAttribute(\"version\").minor)) + \".\")) + this.getAttribute(\"version\").release)) + \".\")) + this.getAttribute(\"version\").build)), y = ((((((((((((this.installedVer.major + \".\")) + this.installedVer.minor)) + \".\")) + this.installedVer.release)) + \".\")) + this.installedVer.build));\n                this.fallback_js_fcn(y, x);\n                w.innerHTML = this.fallback_html;\n            }\n        ;\n        ;\n            return false;\n        },\n        _createIframe: function(u) {\n            var v = l.create(\"div\", {\n                width: this.getAttribute(\"width\"),\n                height: this.getAttribute(\"height\"),\n                frameBorder: 0\n            });\n            l.empty(u);\n            u.appendChild(v);\n            i.useFacebookRefererHtml.bind(null, v, this.getSWFHTML(), this.getAttribute(\"iframeSource\")).defer();\n        }\n    });\n    o.SWFObjectUtil.getPlayerVersion = function() {\n        var u = new o.PlayerVersion([0,0,0,0,]), v;\n        if (((JSBNG__navigator.plugins && JSBNG__navigator.mimeTypes.length))) {\n            for (var w = 0; ((w < JSBNG__navigator.plugins.length)); w++) {\n                try {\n                    var y = JSBNG__navigator.plugins[w];\n                    if (((y.JSBNG__name == \"Shockwave Flash\"))) {\n                        v = new o.PlayerVersion(y.description.replace(/([a-zA-Z]|\\s)+/, \"\").replace(/(\\s+(r|d)|\\s+b[0-9]+)/, \".\").split(\".\"));\n                        if (((((((typeof u == \"undefined\")) || ((v.major > u.major)))) || ((((v.major == u.major)) && ((((v.minor > u.minor)) || ((((v.minor == u.minor)) && ((((v.release > u.release)) || ((((v.release == u.release)) && ((v.build > u.build))))))))))))))) {\n                            u = v;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                } catch (x) {\n                \n                };\n            ;\n            };\n        ;\n        }\n         else if (((JSBNG__navigator.userAgent && ((JSBNG__navigator.userAgent.indexOf(\"Windows CE\") >= 0))))) {\n            var z = 1, aa = 3;\n            while (z) {\n                try {\n                    aa++;\n                    z = new ActiveXObject(((\"ShockwaveFlash.ShockwaveFlash.\" + aa)));\n                    u = new o.PlayerVersion([aa,0,0,]);\n                } catch (ba) {\n                    z = null;\n                };\n            ;\n            };\n        ;\n        }\n         else {\n            try {\n                var z = new ActiveXObject(\"ShockwaveFlash.ShockwaveFlash.7\");\n            } catch (ca) {\n                try {\n                    var z = new ActiveXObject(\"ShockwaveFlash.ShockwaveFlash.6\");\n                    u = new o.PlayerVersion([6,0,21,]);\n                    z.AllowScriptAccess = \"always\";\n                } catch (da) {\n                    if (((u.major == 6))) {\n                        return u;\n                    }\n                ;\n                ;\n                };\n            ;\n                try {\n                    z = new ActiveXObject(\"ShockwaveFlash.ShockwaveFlash\");\n                } catch (ea) {\n                \n                };\n            ;\n            };\n        ;\n            if (((z != null))) {\n                u = new o.PlayerVersion(z.GetVariable(\"$version\").split(\" \")[1].split(\",\"));\n            }\n        ;\n        ;\n        }\n        \n    ;\n    ;\n        return u;\n    };\n    o.PlayerVersion = function(u) {\n        this.major = ((((u[0] != null)) ? parseInt(u[0], 10) : 0));\n        this.minor = ((((u[1] != null)) ? parseInt(u[1], 10) : 0));\n        this.release = ((((u[2] != null)) ? parseInt(u[2], 10) : 0));\n        this.build = ((((u[3] != null)) ? parseInt(u[3], 10) : 0));\n    };\n    o.PlayerVersion.prototype.versionIsValid = function(u) {\n        if (((this.major < u.major))) {\n            return false;\n        }\n    ;\n    ;\n        if (((this.major > u.major))) {\n            return true;\n        }\n    ;\n    ;\n        if (((this.minor < u.minor))) {\n            return false;\n        }\n    ;\n    ;\n        if (((this.minor > u.minor))) {\n            return true;\n        }\n    ;\n    ;\n        if (((this.release < u.release))) {\n            return false;\n        }\n    ;\n    ;\n        if (((this.release > u.release))) {\n            return true;\n        }\n    ;\n    ;\n        if (((this.build < u.build))) {\n            return false;\n        }\n    ;\n    ;\n        return true;\n    };\n    o.util = {\n        getRequestParameter: function(u) {\n            var v = ((JSBNG__document.JSBNG__location.search || JSBNG__document.JSBNG__location.hash));\n            if (((u == null))) {\n                return v;\n            }\n        ;\n        ;\n            if (v) {\n                var w = v.substring(1).split(\"&\");\n                for (var x = 0; ((x < w.length)); x++) {\n                    if (((w[x].substring(0, w[x].indexOf(\"=\")) == u))) {\n                        return w[x].substring(((w[x].indexOf(\"=\") + 1)));\n                    }\n                ;\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            return \"\";\n        }\n    };\n    o.SWFObjectUtil.cleanupSWFs = function() {\n        var u = JSBNG__document.getElementsByTagName(\"OBJECT\");\n        for (var v = ((u.length - 1)); ((v >= 0)); v--) {\n            u[v].style.display = \"none\";\n            for (var w in u[v]) {\n                if (((typeof u[v][w] == \"function\"))) {\n                    u[v][w] = function() {\n                    \n                    };\n                }\n            ;\n            ;\n            };\n        ;\n        };\n    ;\n    };\n    if (((!JSBNG__document.getElementById && JSBNG__document.all))) {\n        JSBNG__document.getElementById = function(u) {\n            return JSBNG__document.all[u];\n        };\n    }\n;\n;\n    var p = o.util.getRequestParameter, q = o.SWFObject, r = o.SWFObject;\n    o.spawn_flash_update_dialog = function() {\n        new g().setURI(\"/ajax/flash_update_dialog.php\").setMethod(\"GET\").setReadOnly(true).send();\n    };\n    function s(u, v) {\n        var w = m(u), x = o.SWFObjectUtil.getPlayerVersion(), y;\n        v.forEach(function(ba) {\n            ba = new o.PlayerVersion(ba.toString().split(\".\"));\n            if (((ba.major == x.major))) {\n                y = ba;\n                return;\n            }\n             else if (((((typeof y == \"undefined\")) || ((ba.major < y.major))))) {\n                y = ba;\n            }\n            \n        ;\n        ;\n        }.bind(this));\n        if (((w && ((x.major > 0))))) {\n            var z = ((((((((((((x.major + \".\")) + x.minor)) + \".\")) + x.release)) + \".\")) + x.build)), aa = ((((((((((((y.major + \".\")) + y.minor)) + \".\")) + y.release)) + \".\")) + y.build));\n            l.setContent(w, l.tx._(\"Flash {required-version} is required to view this content. Your current version is {current-version}. Please download the latest Flash Player.\", {\n                \"required-version\": aa,\n                \"current-version\": z\n            }));\n        }\n    ;\n    ;\n    };\n;\n    o.showFlashErrorDialog = function(u, v) {\n        h.loadModules([\"ErrorDialog\",], function(w) {\n            w.show(u, v);\n        });\n    };\n    function t(u, v, w) {\n        var x = /^[A-Za-z0-9\\-]+$/;\n        if (!u.match(x)) {\n            throw new Error(((\"Invalid tag \" + u)));\n        }\n    ;\n    ;\n        var y = ((\"\\u003C\" + u));\n        for (var z in v) {\n            if (!z.match(x)) {\n                throw new Error(((\"Invalid attr \" + z)));\n            }\n        ;\n        ;\n            y += ((((((((\" \" + z)) + \"=\\\"\")) + n(v[z]))) + \"\\\"\"));\n        };\n    ;\n        if (((w === null))) {\n            return ((y + \"/\\u003E\"));\n        }\n         else return ((((((((((y + \"\\u003E\")) + w)) + \"\\u003C/\")) + u)) + \"\\u003E\"))\n    ;\n    };\n;\n    e.exports = ((a.deconcept || o));\n});\n__d(\"SoundPlayer\", [\"Arbiter\",\"ChatConfig\",\"Env\",\"swfobject\",\"swfobject2\",\"URI\",\"createArrayFrom\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ChatConfig\"), i = b(\"Env\"), j = b(\"swfobject\").SWFObject, k = b(\"swfobject2\"), l = b(\"URI\"), m = b(\"createArrayFrom\"), n = {\n    }, o = null, p = false, q = \"so_sound_player\", r = \"/swf/SoundPlayerHater.swf\", s = \"10.0.22.87\", t = null, u = h.get(\"sound.useswfobject_2\", false), v = h.get(\"sound.force_flash\", false);\n    function w(ea) {\n        var fa = l(ea);\n        if (!fa.getDomain()) {\n            return l(i.static_base).setPath(fa.getPath()).toString();\n        }\n    ;\n    ;\n        return ea;\n    };\n;\n    function x(ea) {\n        if (/\\.mp3$/.test(ea)) {\n            return \"audio/mpeg\";\n        }\n    ;\n    ;\n        if (/\\.og[ga]$/.test(ea)) {\n            return \"audio/ogg\";\n        }\n    ;\n    ;\n        return \"\";\n    };\n;\n    function y() {\n        if (((!t && !v))) {\n            var ea = JSBNG__document.createElement(\"audio\");\n            if (((!ea || !ea.canPlayType))) {\n                return null;\n            }\n        ;\n        ;\n            ea.setAttribute(\"preload\", \"auto\");\n            JSBNG__document.body.appendChild(ea);\n            t = ea;\n        }\n    ;\n    ;\n        return t;\n    };\n;\n    function z() {\n        var ea = ((JSBNG__document[q] || window[q]));\n        if (ea) {\n            if (((!ea.playSound && ea.length))) {\n                ea = ea[0];\n            }\n        ;\n        }\n    ;\n    ;\n        return ((((((ea && ea.playSound)) && ea.loopSound)) ? ea : null));\n    };\n;\n    function aa() {\n        return p;\n    };\n;\n    function ba(ea, fa, ga) {\n        o = {\n            path: ea,\n            sync: fa,\n            loop: ga\n        };\n    };\n;\n    function ca() {\n        p = true;\n        if (o) {\n            var ea = z();\n            if (o.loop) {\n                ea.loopSound(o.path, o.sync);\n            }\n             else ea.playSound(o.path, o.sync);\n        ;\n        ;\n        }\n    ;\n    ;\n    };\n;\n    var da = {\n        init: function(ea) {\n            ea = m(ea);\n            var fa;\n            for (var ga = 0; ((ga < ea.length)); ++ga) {\n                fa = ea[ga];\n                if (n[fa]) {\n                    return;\n                }\n            ;\n            ;\n            };\n        ;\n            var ha = y();\n            for (ga = 0; ((ha && ((ga < ea.length)))); ++ga) {\n                fa = ea[ga];\n                if (ha.canPlayType(fa)) {\n                    n[fa] = true;\n                    return;\n                }\n            ;\n            ;\n            };\n        ;\n            n[\"audio/mpeg\"] = true;\n            if (z()) {\n                return;\n            }\n        ;\n        ;\n            try {\n                g.registerCallback(ca, [\"sound/player_ready\",\"sound/ready\",]);\n                var ja = JSBNG__document.createElement(\"div\");\n                ja.id = \"sound_player_holder\";\n                JSBNG__document.body.appendChild(ja);\n                if (u) {\n                    k.embedSWF(r, ja.id, \"1px\", \"1px\", s, null, {\n                        swf_id: q\n                    }, {\n                        allowscriptaccess: \"always\",\n                        wmode: \"transparent\"\n                    }, null, function(la) {\n                        window[q] = la.ref;\n                        g.inform(\"sound/player_ready\");\n                    });\n                }\n                 else {\n                    var ka = new j(r, q, \"1px\", \"1px\", [s,], \"#ffffff\");\n                    ka.addParam(\"allowscriptaccess\", \"always\");\n                    ka.addParam(\"wmode\", \"transparent\");\n                    ka.addVariable(\"swf_id\", q);\n                    ka.fallback_html = \" \";\n                    ka.write(ja.id);\n                    window[q] = ka;\n                    g.inform(\"sound/player_ready\");\n                }\n            ;\n            ;\n            } catch (ia) {\n            \n            };\n        ;\n        },\n        play: function(ea, fa) {\n            ea = m(ea);\n            var ga = y(), ha, ia;\n            for (var ja = 0; ((ga && ((ja < ea.length)))); ++ja) {\n                ha = ea[ja];\n                ia = x(ha);\n                if (!ga.canPlayType(ia)) {\n                    continue;\n                }\n            ;\n            ;\n                da.init([ia,]);\n                ga.src = w(ha);\n                if (fa) {\n                    ga.setAttribute(\"loop\", \"\");\n                }\n                 else ga.removeAttribute(\"loop\");\n            ;\n            ;\n                ga.play();\n                return;\n            };\n        ;\n            for (ja = 0; ((ja < ea.length)); ++ja) {\n                ha = w(ea[ja]);\n                ia = x(ha);\n                if (((ia != \"audio/mpeg\"))) {\n                    continue;\n                }\n            ;\n            ;\n                da.init([ia,]);\n                var ka = z();\n                if (!aa()) {\n                    ba(ha, true, fa);\n                    return;\n                }\n                 else if (ka) {\n                    if (fa) {\n                        ka.loopSound(ha, true);\n                    }\n                     else ka.playSound(ha, true);\n                ;\n                ;\n                    return;\n                }\n                \n            ;\n            ;\n            };\n        ;\n        },\n        JSBNG__stop: function(ea) {\n            ea = m(ea);\n            for (var fa = 0; ((fa < ea.length)); ++fa) {\n                var ga = w(ea[fa]), ha = y(), ia = z();\n                if (((ha && ((ha.src == ga))))) {\n                    ha.pause();\n                    ha.src = undefined;\n                }\n                 else ((ia && ia.stopSound(ga)));\n            ;\n            ;\n            };\n        ;\n        }\n    };\n    e.exports = da;\n});\n__d(\"SoundSynchronizer\", [\"event-extensions\",\"hasArrayNature\",\"SoundPlayer\",\"createArrayFrom\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"hasArrayNature\"), h = b(\"SoundPlayer\"), i = b(\"createArrayFrom\"), j = \"fb_sounds_playing3\";\n    function k() {\n        if (window.JSBNG__localStorage) {\n            try {\n                var p = window.JSBNG__localStorage[j];\n                if (p) {\n                    p = JSON.parse(p);\n                    if (g(p)) {\n                        return p;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            } catch (o) {\n            \n            };\n        }\n    ;\n    ;\n        return [];\n    };\n;\n    function l(o) {\n        if (window.JSBNG__localStorage) {\n            var p = k();\n            p.push(o);\n            while (((p.length > 5))) {\n                p.shift();\n            ;\n            };\n        ;\n            try {\n                window.JSBNG__localStorage[j] = JSON.stringify(p);\n            } catch (q) {\n            \n            };\n        ;\n        }\n    ;\n    ;\n    };\n;\n    function m(o) {\n        return k().some(function(p) {\n            return ((p === o));\n        });\n    };\n;\n    var n = {\n        play: function(o, p, q) {\n            o = i(o);\n            p = ((p || ((o[0] + Math.floor(((JSBNG__Date.now() / 1000)))))));\n            if (m(p)) {\n                return;\n            }\n        ;\n        ;\n            h.play(o, q);\n            l(p);\n        },\n        isSupported: function() {\n            return !!window.JSBNG__localStorage;\n        }\n    };\n    e.exports = n;\n});\n__d(\"SoundRPC\", [\"event-extensions\",\"SoundSynchronizer\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"SoundSynchronizer\");\n    function h(j, k, l) {\n        g.play(j, k, l);\n    };\n;\n    var i = {\n        playLocal: h,\n        playRemote: function(j, k, l, m) {\n            var n = {\n                paths: k,\n                sync: l,\n                loop: m\n            };\n            j.JSBNG__postMessage(JSON.stringify(n), \"*\");\n        },\n        supportsRPC: function() {\n            return !!window.JSBNG__postMessage;\n        },\n        _listen: function() {\n            JSBNG__Event.listen(window, \"message\", function(j) {\n                if (!/\\.facebook.com$/.test(j.origin)) {\n                    return;\n                }\n            ;\n            ;\n                var k = JSON.parse(j.data);\n                h(k.paths, k.sync, k.loop);\n            });\n        }\n    };\n    e.exports = i;\n});\n__d(\"Sound\", [\"SoundPlayer\",\"SoundRPC\",\"SoundSynchronizer\",\"UserAgent\",], function(a, b, c, d, e, f) {\n    var g = b(\"SoundPlayer\"), h = b(\"SoundRPC\"), i = b(\"SoundSynchronizer\"), j = b(\"UserAgent\"), k = null, l = {\n        init: function(o) {\n            if (!k) {\n                g.init(o);\n            }\n        ;\n        ;\n        },\n        play: function(o, p, q) {\n            if (k) {\n                h.playRemote(k.contentWindow, o, p, false);\n            }\n             else h.playLocal(o, p, q);\n        ;\n        ;\n        },\n        JSBNG__stop: function(o) {\n            if (!k) {\n                g.JSBNG__stop(o);\n            }\n        ;\n        ;\n        }\n    }, m = JSBNG__location.host.replace(/^[^.]+/, \"www\");\n    function n() {\n        if (((j.ie() < 9))) {\n            return false;\n        }\n    ;\n    ;\n        return ((i.isSupported() && h.supportsRPC()));\n    };\n;\n    if (((((JSBNG__location.host !== m)) && n()))) {\n        k = JSBNG__document.createElement(\"div\");\n        k.setAttribute(\"src\", ((((\"//\" + m)) + \"/sound_iframe.php\")));\n        k.style.display = \"none\";\n        JSBNG__document.body.appendChild(k);\n    }\n;\n;\n    e.exports = l;\n});\n__d(\"Token\", [\"CSS\",\"DataStore\",\"DOM\",\"copyProperties\",\"tx\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"DataStore\"), i = b(\"DOM\"), j = b(\"copyProperties\"), k = b(\"tx\");\n    function l(m, n) {\n        this.info = m;\n        this.paramName = n;\n    };\n;\n    j(l.prototype, {\n        getInfo: function() {\n            return this.info;\n        },\n        getText: function() {\n            return this.info.text;\n        },\n        getValue: function() {\n            return this.info.uid;\n        },\n        isFreeform: function() {\n            return !!this.info.freeform;\n        },\n        getElement: function() {\n            if (!this.element) {\n                this.setElement(this.createElement());\n            }\n        ;\n        ;\n            return this.element;\n        },\n        setElement: function(m) {\n            h.set(m, \"Token\", this);\n            this.element = m;\n            return this;\n        },\n        isRemovable: function() {\n            return g.hasClass(this.element, \"removable\");\n        },\n        createElement: function() {\n            var m = this.paramName, n = this.getText(), o = this.getValue(), p = i.create(\"a\", {\n                href: \"#\",\n                \"aria-label\": k._(\"Remove {item}\", {\n                    item: n\n                }),\n                className: \"remove uiCloseButton uiCloseButtonSmall\"\n            }), q = i.create(\"input\", {\n                type: \"hidden\",\n                value: o,\n                JSBNG__name: ((m + \"[]\")),\n                autocomplete: \"off\"\n            }), r = i.create(\"input\", {\n                type: \"hidden\",\n                value: n,\n                JSBNG__name: ((((\"text_\" + m)) + \"[]\")),\n                autocomplete: \"off\"\n            }), s = i.create(\"span\", {\n                className: \"removable uiToken\"\n            }, [n,q,r,p,]);\n            return s;\n        }\n    });\n    e.exports = l;\n});\n__d(\"StickyPlaceholderInput\", [\"event-extensions\",\"CSS\",\"DOM\",\"Input\",\"Parent\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"Input\"), j = b(\"Parent\");\n    function k(o) {\n        return j.byClass(o, \"uiStickyPlaceholderInput\");\n    };\n;\n    function l(o) {\n        return h.scry(o, \".placeholder\")[0];\n    };\n;\n    function m(o) {\n        o = ((o || window.JSBNG__event));\n        var p = ((o.target || o.srcElement));\n        if (h.isNodeOfType(p, [\"input\",\"textarea\",])) {\n            var q = k(p);\n            if (q) {\n                var r = o.type;\n                (function() {\n                    if (((((((r === \"keydown\")) || ((r === \"paste\")))) && p.value.length))) {\n                        g.removeClass(q, \"uiStickyPlaceholderEmptyInput\");\n                    }\n                ;\n                ;\n                    if (((((((r === \"JSBNG__blur\")) || ((r === \"focusout\")))) && !p.value.length))) {\n                        g.addClass(q, \"uiStickyPlaceholderEmptyInput\");\n                    }\n                ;\n                ;\n                }).defer();\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    };\n;\n    var n = {\n        init: function() {\n            n.init = bagofholding;\n            JSBNG__Event.listen(JSBNG__document.documentElement, {\n                keydown: m,\n                paste: m\n            });\n            if (JSBNG__document.documentElement.JSBNG__addEventListener) {\n                JSBNG__document.documentElement.JSBNG__addEventListener(\"JSBNG__blur\", m, true);\n            }\n             else JSBNG__Event.listen(JSBNG__document.documentElement, \"focusout\", m);\n        ;\n        ;\n        },\n        registerInput: function(o) {\n            n.init();\n            var p = ((o.getAttribute(\"placeholder\") || \"\"));\n            if (p.length) {\n                if (((JSBNG__document.activeElement === o))) {\n                    var q = JSBNG__Event.listen(o, \"JSBNG__blur\", function() {\n                        n.manipulateInput(o, p);\n                        q.remove();\n                    });\n                }\n                 else n.manipulateInput(o, p);\n            ;\n            }\n        ;\n        ;\n        },\n        manipulateInput: function(o, p) {\n            var q = h.create(\"div\", {\n                className: \"placeholder\",\n                \"aria-hidden\": \"true\"\n            }, p), r = h.create(\"div\", {\n                className: \"uiStickyPlaceholderInput\"\n            }, q);\n            if (h.isNodeOfType(o, \"textarea\")) {\n                g.addClass(r, \"uiStickyPlaceholderTextarea\");\n            }\n        ;\n        ;\n            JSBNG__Event.listen(q, \"click\", function() {\n                o.JSBNG__focus();\n            });\n            if (((o.value === p))) {\n                o.value = \"\";\n            }\n        ;\n        ;\n            g.removeClass(o, \"DOMControl_placeholder\");\n            o.setAttribute(\"placeholder\", \"\");\n            h.replace(o, r);\n            h.appendContent(r, o);\n            g.conditionClass(r, \"uiStickyPlaceholderEmptyInput\", !o.value.length);\n        },\n        setPlaceholderText: function(o, p) {\n            var q = k(o);\n            if (!q) {\n                i.setPlaceholder(o, p);\n            }\n             else {\n                var r = l(q);\n                ((r && h.setContent(r, p)));\n            }\n        ;\n        ;\n        },\n        getPlaceholderText: function(o) {\n            var p = k(o), q = l(p);\n            return ((q && h.getText(q)));\n        },\n        update: function(o) {\n            var p = k(o);\n            if (p) {\n                g.conditionClass(p, \"uiStickyPlaceholderEmptyInput\", !o.value.length);\n            }\n        ;\n        ;\n        },\n        getVisibleText: function(o) {\n            var p = k(o);\n            if (g.hasClass(p, \"uiStickyPlaceholderEmptyInput\")) {\n                var q = l(p);\n                return ((q && h.getText(q)));\n            }\n             else return o.value\n        ;\n        }\n    };\n    e.exports = n;\n});\n__d(\"Tokenizer\", [\"array-extensions\",\"event-extensions\",\"Arbiter\",\"ArbiterMixin\",\"Class\",\"CSS\",\"DataStore\",\"DOM\",\"DOMQuery\",\"Input\",\"Keys\",\"Parent\",\"StickyPlaceholderInput\",\"Style\",\"JSBNG__TextMetrics\",\"Token\",\"UserAgent\",\"copyProperties\",\"createObjectFrom\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"Class\"), j = b(\"CSS\"), k = b(\"DataStore\"), l = b(\"DOM\"), m = b(\"DOMQuery\"), n = b(\"Input\"), o = b(\"Keys\"), p = b(\"Parent\"), q = b(\"StickyPlaceholderInput\"), r = b(\"Style\"), s = b(\"JSBNG__TextMetrics\"), t = b(\"Token\"), u = b(\"UserAgent\"), v = b(\"copyProperties\"), w = b(\"createObjectFrom\");\n    function x(y, z) {\n        this.element = y;\n        this.typeahead = z;\n        this.input = z.getCore().getElement();\n        k.set(this.element, \"Tokenizer\", this);\n    };\n;\n    x.getInstance = function(y) {\n        var z = p.byClass(y, \"uiTokenizer\");\n        return ((z ? k.get(z, \"Tokenizer\") : null));\n    };\n    v(x.prototype, h, {\n        inline: false,\n        maxTokens: null,\n        excludeDuplicates: true,\n        placeholder: \"\",\n        init: function(y, z, aa, ba) {\n            this.init = bagofholding;\n            this.tokenarea = y;\n            this.paramName = z;\n            if (!this.placeholder) {\n                this.placeholder = ((this.input.getAttribute(\"data-placeholder\") || \"\"));\n            }\n        ;\n        ;\n            v(this, ((ba || {\n            })));\n            this.initEvents();\n            this.initTypeahead();\n            this.reset(aa);\n            this.initBehaviors();\n            g.inform(\"Tokenizer/init\", this, g.BEHAVIOR_PERSISTENT);\n        },\n        reset: function(y) {\n            this.tokens = [];\n            this.unique = {\n            };\n            if (y) {\n                this.populate(y);\n            }\n             else l.empty(this.tokenarea);\n        ;\n        ;\n            this.updateTokenarea();\n        },\n        populate: function(y) {\n            var z = [];\n            this.tokens = this.getTokenElements().map(function(aa, ba) {\n                var ca = y[ba];\n                z.push(this._tokenKey(ca));\n                return this.createToken(ca, aa);\n            }, this);\n            this.unique = w(z, this.tokens);\n        },\n        getElement: function() {\n            return this.element;\n        },\n        getTypeahead: function() {\n            return this.typeahead;\n        },\n        getInput: function() {\n            return this.input;\n        },\n        initBehaviors: function() {\n            this.behaviors = ((this.behaviors || []));\n            if (((this.behaviors instanceof Array))) {\n                this.behaviors.forEach(function(aa) {\n                    aa.behavior(this, aa.config);\n                }.bind(this));\n            }\n             else for (var y in ((this.behaviors || {\n            }))) {\n                var z = ((window.TokenizerBehaviors && window.TokenizerBehaviors[y]));\n                z.call(null, this, this.behaviors[y]);\n            }\n        ;\n        ;\n        },\n        initTypeahead: function() {\n            var y = this.typeahead.getCore();\n            y.resetOnSelect = true;\n            y.setValueOnSelect = false;\n            y.preventFocusChangeOnTab = true;\n            if (this.inline) {\n                var z = this.typeahead.getView();\n                j.addClass(z.getElement(), \"uiInlineTokenizerView\");\n            }\n        ;\n        ;\n            this.typeahead.subscribe(\"select\", function(aa, ba) {\n                var ca = ba.selected;\n                if (((\"uid\" in ca))) {\n                    this.updateInput();\n                    this.addToken(this.createToken(ca));\n                }\n            ;\n            ;\n            }.bind(this));\n            this.typeahead.subscribe(\"JSBNG__blur\", this.handleBlur.bind(this));\n        },\n        handleBlur: function(JSBNG__event) {\n            this.inform(\"JSBNG__blur\", {\n                JSBNG__event: JSBNG__event\n            });\n            this.updatePlaceholder();\n        },\n        initEvents: function() {\n            var y = this.handleEvents.bind(this), z = ((((u.firefox() < 4)) ? \"keypress\" : \"keydown\"));\n            JSBNG__Event.listen(this.tokenarea, {\n                click: y,\n                keydown: y\n            });\n            JSBNG__Event.listen(this.input, \"paste\", this.paste.bind(this));\n            JSBNG__Event.listen(this.input, z, this.keydown.bind(this));\n        },\n        handleEvents: function(JSBNG__event) {\n            var y = JSBNG__event.getTarget(), z = ((y && this.getTokenElementFromTarget(y)));\n            if (!z) {\n                return;\n            }\n        ;\n        ;\n            if (((((JSBNG__event.type != \"keydown\")) || ((JSBNG__Event.getKeyCode(JSBNG__event) == o.RETURN))))) {\n                this.processEvents(JSBNG__event, y, z);\n            }\n        ;\n        ;\n        },\n        processEvents: function(JSBNG__event, y, z) {\n            if (p.byClass(y, \"remove\")) {\n                var aa = z.nextSibling;\n                aa = ((aa && m.scry(z.nextSibling, \".remove\")[0]));\n                var ba = this.getTokenFromElement(z);\n                ba = this.addTokenData(ba, y);\n                this.removeToken(ba);\n                this.focusOnTokenRemoval(JSBNG__event, aa);\n                JSBNG__event.kill();\n            }\n        ;\n        ;\n        },\n        focusOnTokenRemoval: function(JSBNG__event, y) {\n            n.JSBNG__focus(((((((JSBNG__event.type == \"keydown\")) && y)) || this.input)));\n        },\n        addTokenData: function(y, z) {\n            return y;\n        },\n        keydown: function(JSBNG__event) {\n            this.inform(\"keydown\", {\n                JSBNG__event: JSBNG__event\n            });\n            var y = JSBNG__Event.getKeyCode(JSBNG__event), z = this.input;\n            if (((((this.inline && ((y == o.BACKSPACE)))) && n.isEmpty(z)))) {\n                var aa = this.getLastToken();\n                if (((aa && aa.isRemovable()))) {\n                    this.removeToken(aa);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            this.updateInput();\n        },\n        paste: function(JSBNG__event) {\n            this.inform(\"paste\", {\n                JSBNG__event: JSBNG__event\n            });\n            this.updateInput(true);\n        },\n        focusInput: function() {\n            n.JSBNG__focus(this.input);\n        },\n        updateInput: function(y) {\n            if (!this.inline) {\n                return;\n            }\n        ;\n        ;\n            JSBNG__setTimeout(function() {\n                this.adjustWidth(this.input.value);\n                if (y) {\n                    this.input.value = this.input.value;\n                }\n            ;\n            ;\n            }.bind(this), 20);\n            q.setPlaceholderText(this.input, \"\");\n        },\n        setPlaceholder: function(y) {\n            this.placeholder = y;\n            if (this.stickyPlaceholder) {\n                q.setPlaceholderText(this.input, y);\n            }\n        ;\n        ;\n            this.updatePlaceholder();\n        },\n        updatePlaceholder: function() {\n            if (((!this.inline || this.input.value))) {\n                return;\n            }\n        ;\n        ;\n            var y = !this.tokens.length, z = \"\";\n            if (((y || this.stickyPlaceholder))) {\n                this.adjustWidth(this.placeholder);\n                z = this.placeholder;\n            }\n        ;\n        ;\n            q.setPlaceholderText(this.input, z);\n        },\n        adjustWidth: function(y) {\n            if (((!this.inline || !this._getIsInDOM()))) {\n                return;\n            }\n        ;\n        ;\n            if (((((!y && this.stickyPlaceholder)) && ((this.input.value === \"\"))))) {\n                y = this.placeholder;\n            }\n        ;\n        ;\n            var z = this._getMetrics().measure(y), aa = ((((z.width + this._getWidthOffset())) + 10));\n            r.set(this.input, \"width\", ((aa + \"px\")));\n        },\n        getToken: function(y) {\n            return ((this.unique[y] || null));\n        },\n        getTokens: function() {\n            return ((this.tokens || []));\n        },\n        getTokenElements: function() {\n            return m.scry(this.tokenarea, \"span.uiToken\");\n        },\n        getTokenElementFromTarget: function(y) {\n            return p.byClass(y, \"uiToken\");\n        },\n        getTokenFromElement: function(y) {\n            return k.get(y, \"Token\");\n        },\n        getTokenValues: function() {\n            return this.tokens.map(function(y) {\n                return y.getValue();\n            });\n        },\n        getFirstToken: function() {\n            return ((this.tokens[0] || null));\n        },\n        getLastToken: function() {\n            return ((this.tokens[((this.tokens.length - 1))] || null));\n        },\n        hasMaxTokens: function() {\n            return ((this.maxTokens && ((this.maxTokens <= this.tokens.length))));\n        },\n        createToken: function(y, z) {\n            var aa = this.getToken(this._tokenKey(y));\n            aa = ((aa || new t(y, this.paramName)));\n            ((z && aa.setElement(z)));\n            return aa;\n        },\n        addToken: function(y) {\n            if (this.hasMaxTokens()) {\n                return;\n            }\n        ;\n        ;\n            var z = this._tokenKey(y.getInfo());\n            if (((z in this.unique))) {\n                return;\n            }\n        ;\n        ;\n            this.unique[z] = y;\n            this.tokens.push(y);\n            this.insertToken(y);\n            this.updateTokenarea();\n            this.inform(\"addToken\", y);\n            g.inform(\"Form/change\", {\n                node: this.element\n            });\n        },\n        insertToken: function(y) {\n            l.appendContent(this.tokenarea, y.getElement());\n        },\n        removeToken: function(y) {\n            if (!y) {\n                return;\n            }\n        ;\n        ;\n            var z = this.tokens.indexOf(y);\n            if (((z < 0))) {\n                return;\n            }\n        ;\n        ;\n            this.tokens.splice(this.tokens.indexOf(y), 1);\n            delete this.unique[this._tokenKey(y.getInfo())];\n            l.remove(y.getElement());\n            this.updateTokenarea();\n            this.inform(\"removeToken\", y);\n            g.inform(\"Form/change\", {\n                node: this.element\n            });\n        },\n        removeAllTokens: function() {\n            this.reset();\n            this.inform(\"removeAllTokens\");\n        },\n        updateTokenarea: function() {\n            var y = this.typeahead.getCore(), z = this.getTokenValues();\n            if (this.excludeDuplicates) {\n                ((this._exclusions || (this._exclusions = y.getExclusions())));\n                y.setExclusions(z.concat(this._exclusions));\n            }\n        ;\n        ;\n            y.setEnabled(!this.hasMaxTokens());\n            this.updateTokenareaVisibility();\n            this.updatePlaceholder();\n            this.adjustWidth(this.placeholder);\n        },\n        updateTokenareaVisibility: function() {\n            j.conditionShow(this.tokenarea, ((this.tokens.length !== 0)));\n        },\n        _tokenKey: function(y) {\n            return ((y.uid + ((y.freeform ? \":\" : \"\"))));\n        },\n        _widthOffset: null,\n        _getWidthOffset: function() {\n            if (((this._widthOffset === null))) {\n                var y = this.input.clientWidth, z = r.getFloat(this.input, \"width\");\n                if (((y == z))) {\n                    this._widthOffset = ((r.getFloat(this.input, \"paddingLeft\") + r.getFloat(this.input, \"paddingRight\")));\n                }\n                 else this._widthOffset = 0;\n            ;\n            ;\n            }\n        ;\n        ;\n            return this._widthOffset;\n        },\n        _metrics: null,\n        _getMetrics: function() {\n            if (!this._metrics) {\n                this._metrics = new s(this.input, this.inline);\n            }\n        ;\n        ;\n            return this._metrics;\n        },\n        _getIsInDOM: function() {\n            return ((this._isInDOM || (this._isInDOM = m.contains(JSBNG__document.body, this.input))));\n        }\n    });\n    e.exports = x;\n});\n__d(\"Typeahead\", [\"array-extensions\",\"event-extensions\",\"ArbiterMixin\",\"BehaviorsMixin\",\"Class\",\"DataStore\",\"DOM\",\"Parent\",\"Run\",\"copyProperties\",\"ge\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"BehaviorsMixin\"), i = b(\"Class\"), j = b(\"DataStore\"), k = b(\"DOM\"), l = b(\"Parent\"), m = b(\"Run\"), n = b(\"copyProperties\"), o = b(\"ge\");\n    function p(q, r, s, t) {\n        this.args = {\n            data: q,\n            view: r,\n            core: s\n        };\n        j.set(t, \"Typeahead\", this);\n        this.element = t;\n    };\n;\n    p.getInstance = function(q) {\n        var r = l.byClass(q, \"uiTypeahead\");\n        return ((r ? j.get(r, \"Typeahead\") : null));\n    };\n    n(p.prototype, g, h, {\n        init: function(q) {\n            this.init = bagofholding;\n            this.getCore();\n            this.proxyEvents();\n            this.initBehaviors(((q || [])));\n            this.inform(\"init\", this);\n            this.data.bootstrap();\n            this.core.JSBNG__focus();\n        },\n        getData: function() {\n            if (!this.data) {\n                var q = this.args.data;\n                this.data = q;\n                this.data.init();\n            }\n        ;\n        ;\n            return this.data;\n        },\n        getView: function() {\n            if (!this.view) {\n                var q = this.args.view, r = o(q.node_id);\n                if (!r) {\n                    r = k.create(\"div\", {\n                        className: \"uiTypeaheadView\"\n                    });\n                    k.appendContent(this.element, r);\n                }\n            ;\n            ;\n                if (((typeof q.ctor === \"string\"))) {\n                    this.view = new window[q.ctor](r, ((q.options || {\n                    })));\n                }\n                 else this.view = new q.ctor(r, ((q.options || {\n                })));\n            ;\n            ;\n                this.view.init();\n                this.view.setTypeahead(this.element);\n            }\n        ;\n        ;\n            return this.view;\n        },\n        getCore: function() {\n            if (!this.core) {\n                var q = this.args.core;\n                if (((typeof q.ctor === \"string\"))) {\n                    this.core = new window[q.ctor](((q.options || {\n                    })));\n                }\n                 else this.core = new q.ctor(((q.options || {\n                })));\n            ;\n            ;\n                this.core.init(this.getData(), this.getView(), this.getElement());\n            }\n        ;\n        ;\n            return this.core;\n        },\n        getElement: function() {\n            return this.element;\n        },\n        swapData: function(q) {\n            var r = this.core;\n            this.data = this.args.data = q;\n            q.init();\n            if (r) {\n                r.data = q;\n                r.initData();\n                r.reset();\n            }\n        ;\n        ;\n            q.bootstrap();\n            return q;\n        },\n        proxyEvents: function() {\n            [this.data,this.view,this.core,].forEach(function(q) {\n                q.subscribe(q.events, this.inform.bind(this));\n            }, this);\n        },\n        initBehaviors: function(q) {\n            q.forEach(function(r) {\n                if (((typeof r === \"string\"))) {\n                    if (((a.TypeaheadBehaviors && a.TypeaheadBehaviors[r]))) {\n                        a.TypeaheadBehaviors[r](this);\n                    }\n                     else m.JSBNG__onLoad(function() {\n                        if (a.TypeaheadBehaviors) {\n                            ((a.TypeaheadBehaviors[r] || bagofholding))(this);\n                        }\n                    ;\n                    ;\n                    }.bind(this));\n                ;\n                ;\n                }\n                 else this.enableBehavior(r);\n            ;\n            ;\n            }, this);\n        }\n    });\n    p.initNow = function(q, r, s) {\n        if (s) {\n            s.init(q);\n        }\n    ;\n    ;\n        q.init(r);\n    };\n    p.init = function(q, r, s, t) {\n        if (!k.isNodeOfType(q, [\"input\",\"textarea\",])) {\n            q = ((k.scry(q, \"input\")[0] || k.scry(q, \"textarea\")[0]));\n        }\n    ;\n    ;\n        var u = false;\n        try {\n            u = ((JSBNG__document.activeElement === q));\n        } catch (v) {\n        \n        };\n    ;\n        if (u) {\n            p.initNow(r, s, t);\n        }\n         else var w = JSBNG__Event.listen(q, \"JSBNG__focus\", function() {\n            p.initNow(r, s, t);\n            w.remove();\n        })\n    ;\n    };\n    e.exports = p;\n});\n__d(\"TypeaheadCore\", [\"event-extensions\",\"Arbiter\",\"ArbiterMixin\",\"Class\",\"CSS\",\"DOM\",\"Input\",\"InputSelection\",\"Keys\",\"UserAgent\",\"bind\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"Class\"), j = b(\"CSS\"), k = b(\"DOM\"), l = b(\"Input\"), m = b(\"InputSelection\"), n = b(\"Keys\"), o = b(\"UserAgent\"), p = b(\"bind\"), q = b(\"copyProperties\");\n    function r(s) {\n        q(this, s);\n    };\n;\n    q(r.prototype, h, {\n        events: [\"JSBNG__blur\",\"JSBNG__focus\",\"click\",\"unselect\",\"loading\",],\n        keepFocused: true,\n        resetOnSelect: false,\n        resetOnKeyup: true,\n        setValueOnSelect: false,\n        queryTimeout: 250,\n        preventFocusChangeOnTab: false,\n        init: function(s, t, u) {\n            this.init = bagofholding;\n            this.data = s;\n            this.view = t;\n            this.root = u;\n            this.initInput();\n            this.inputWrap = k.JSBNG__find(u, \"div.wrap\");\n            this.hiddenInput = k.JSBNG__find(u, \"input.hiddenInput\");\n            this.value = \"\";\n            this.nextQuery = null;\n            this.selectedText = null;\n            if (((this.setValueOnSelect && j.hasClass(this.inputWrap, \"selected\")))) {\n                this.selectedText = this.getValue();\n            }\n        ;\n        ;\n            this.initView();\n            this.initData();\n            this.initEvents();\n            this.initToggle();\n            this._exclusions = [];\n        },\n        initInput: function() {\n            this.element = k.JSBNG__find(this.root, \".textInput\");\n            var s = k.scry(this.element, \"input\")[0];\n            if (s) {\n                this.element = s;\n            }\n        ;\n        ;\n        },\n        initView: function() {\n            this.view.subscribe(\"highlight\", function(s, t) {\n                this.element.JSBNG__focus();\n                this.element.setAttribute(\"aria-activedescendant\", ((((t.index !== -1)) ? k.getID(t.element) : \"\")));\n            }.bind(this));\n            this.view.subscribe(\"select\", function(s, t) {\n                this.select(t.selected);\n            }.bind(this));\n            this.view.subscribe(\"afterSelect\", function() {\n                this.afterSelect();\n            }.bind(this));\n        },\n        initData: function() {\n            this.data.subscribe(\"respond\", function(s, t) {\n                if (((t.forceDisplay || ((((t.value == this.getValue())) && !this.element.disabled))))) {\n                    this.view.render(t.value, t.results, t.isAsync);\n                }\n            ;\n            ;\n            }.bind(this));\n            this.data.subscribe(\"activity\", function(s, t) {\n                this.fetching = t.activity;\n                if (!this.fetching) {\n                    ((this.nextQuery && this.performQuery()));\n                }\n            ;\n            ;\n                if (((this.loading != this.fetching))) {\n                    this.loading = this.fetching;\n                    this.inform(\"loading\", {\n                        loading: this.loading\n                    });\n                }\n            ;\n            ;\n            }.bind(this));\n        },\n        initEvents: function() {\n            JSBNG__Event.listen(this.view.getElement(), {\n                mouseup: this.viewMouseup.bind(this),\n                mousedown: this.viewMousedown.bind(this)\n            });\n            var s = {\n                JSBNG__blur: p(this, \"JSBNG__blur\"),\n                JSBNG__focus: p(this, \"JSBNG__focus\"),\n                click: p(this, \"click\"),\n                keyup: p(this, \"keyup\"),\n                keydown: p(this, \"keydown\")\n            };\n            if (o.firefox()) {\n                s.text = s.keyup;\n            }\n        ;\n        ;\n            if (((o.firefox() < 4))) {\n                s.keypress = s.keydown;\n                delete s.keydown;\n            }\n        ;\n        ;\n            JSBNG__Event.listen(this.element, s);\n            JSBNG__Event.listen(this.element, \"keypress\", p(this, \"keypress\"));\n        },\n        initToggle: function() {\n            this.subscribe(\"JSBNG__blur\", this.view.hide.bind(this.view));\n            this.subscribe(\"JSBNG__focus\", this.view.show.bind(this.view));\n        },\n        viewMousedown: function() {\n            this.selecting = true;\n        },\n        viewMouseup: function() {\n            this.selecting = false;\n        },\n        JSBNG__blur: function() {\n            if (this.selecting) {\n                this.selecting = false;\n                return;\n            }\n        ;\n        ;\n            this.inform(\"JSBNG__blur\");\n        },\n        click: function() {\n            var s = m.get(this.element);\n            if (((s.start == s.end))) {\n                this.element.select();\n            }\n        ;\n        ;\n            this.inform(\"click\");\n        },\n        JSBNG__focus: function() {\n            this.checkValue();\n            this.inform(\"JSBNG__focus\");\n        },\n        keyup: function() {\n            if (((this.resetOnKeyup && !this.getValue()))) {\n                this.view.reset();\n            }\n        ;\n        ;\n            this.checkValue();\n        },\n        keydown: function(JSBNG__event) {\n            if (((!this.view.isVisible() || this.view.isEmpty()))) {\n                this.checkValue.bind(this).defer();\n                return;\n            }\n        ;\n        ;\n            switch (JSBNG__Event.getKeyCode(JSBNG__event)) {\n              case n.TAB:\n                this.handleTab(JSBNG__event);\n                return;\n              case n.UP:\n                this.view.prev();\n                break;\n              case n.DOWN:\n                this.view.next();\n                break;\n              case n.ESC:\n                this.view.reset();\n                break;\n              default:\n                this.checkValue.bind(this).defer();\n                return;\n            };\n        ;\n            JSBNG__event.kill();\n        },\n        keypress: function(JSBNG__event) {\n            if (((this.view.JSBNG__getSelection() && ((JSBNG__Event.getKeyCode(JSBNG__event) == n.RETURN))))) {\n                this.view.select();\n                JSBNG__event.kill();\n            }\n        ;\n        ;\n        },\n        handleTab: function(JSBNG__event) {\n            if (this.preventFocusChangeOnTab) {\n                if (this.view.JSBNG__getSelection()) {\n                    JSBNG__event.kill();\n                }\n                 else JSBNG__event.preventDefault();\n            ;\n            }\n        ;\n        ;\n            this.view.select();\n        },\n        select: function(s) {\n            if (((s && this.setValueOnSelect))) {\n                this.setValue(s.text);\n                this.setHiddenValue(s.uid);\n                this.selectedText = s.text;\n                j.addClass(this.inputWrap, \"selected\");\n            }\n        ;\n        ;\n        },\n        afterSelect: function() {\n            ((this.keepFocused ? this.element.JSBNG__focus() : this.element.JSBNG__blur()));\n            ((this.resetOnSelect ? this.reset() : this.view.reset()));\n        },\n        unselect: function() {\n            if (this.setValueOnSelect) {\n                this.selectedText = null;\n                j.removeClass(this.inputWrap, \"selected\");\n            }\n        ;\n        ;\n            this.setHiddenValue();\n            this.inform(\"unselect\", this);\n        },\n        setEnabled: function(s) {\n            var t = ((s === false));\n            this.element.disabled = t;\n            j.conditionClass(this.root, \"uiTypeaheadDisabled\", t);\n        },\n        reset: function() {\n            this.unselect();\n            this.setValue();\n            ((!this.keepFocused && l.reset(this.element)));\n            this.view.reset();\n            this.inform(\"reset\");\n        },\n        getElement: function() {\n            return this.element;\n        },\n        setExclusions: function(s) {\n            this._exclusions = s;\n        },\n        getExclusions: function() {\n            return this._exclusions;\n        },\n        setValue: function(s) {\n            this.value = this.nextQuery = ((s || \"\"));\n            l.setValue(this.element, this.value);\n        },\n        setHiddenValue: function(s) {\n            this.hiddenInput.value = ((((s || ((s === 0)))) ? s : \"\"));\n            g.inform(\"Form/change\", {\n                node: this.hiddenInput\n            });\n        },\n        getValue: function() {\n            return l.getValue(this.element);\n        },\n        getHiddenValue: function() {\n            return ((this.hiddenInput.value || \"\"));\n        },\n        checkValue: function() {\n            var s = this.getValue();\n            if (((s == this.value))) {\n                return;\n            }\n        ;\n        ;\n            if (((this.selectedText && ((this.selectedText != s))))) {\n                this.unselect();\n            }\n        ;\n        ;\n            var t = JSBNG__Date.now(), u = ((t - this.time));\n            this.time = t;\n            this.value = this.nextQuery = s;\n            this.performQuery(u);\n        },\n        performQuery: function(s) {\n            if (this.selectedText) {\n                return;\n            }\n        ;\n        ;\n            s = ((s || 0));\n            if (((this.fetching && ((s < this.queryTimeout))))) {\n                this.data.query(this.nextQuery, true, this._exclusions);\n            }\n             else {\n                this.data.query(this.nextQuery, false, this._exclusions);\n                this.nextQuery = null;\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = r;\n});\n__d(\"UntrustedLink\", [\"DOM\",\"event-extensions\",\"URI\",\"UserAgent\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"event-extensions\"), i = b(\"URI\"), j = b(\"UserAgent\"), k = b(\"copyProperties\");\n    function l(m, n, o, p) {\n        this.dom = m;\n        this.url = m.href;\n        this.hash = n;\n        this.func_get_params = ((p || function() {\n            return {\n            };\n        }));\n        JSBNG__Event.listen(this.dom, \"click\", this.JSBNG__onclick.bind(this));\n        JSBNG__Event.listen(this.dom, \"mousedown\", this.JSBNG__onmousedown.bind(this));\n        JSBNG__Event.listen(this.dom, \"mouseup\", this.JSBNG__onmouseup.bind(this));\n        JSBNG__Event.listen(this.dom, \"mouseout\", this.JSBNG__onmouseout.bind(this));\n        this.JSBNG__onmousedown(h.$E(o));\n    };\n;\n    l.bootstrap = function(m, n, o, p) {\n        if (m.__untrusted) {\n            return;\n        }\n    ;\n    ;\n        m.__untrusted = true;\n        new l(m, n, o, p);\n    };\n    l.prototype.getRewrittenURI = function() {\n        var m = k({\n            u: this.url,\n            h: this.hash\n        }, this.func_get_params(this.dom)), n = new i(\"/l.php\");\n        return n.setQueryData(m).setSubdomain(\"www\").setProtocol(\"http\");\n    };\n    l.prototype.JSBNG__onclick = function() {\n        (function() {\n            this.setHref(this.url);\n        }).bind(this).defer(100);\n        this.setHref(this.getRewrittenURI());\n    };\n    l.prototype.JSBNG__onmousedown = function(m) {\n        if (((m.button == 2))) {\n            this.setHref(this.getRewrittenURI());\n        }\n    ;\n    ;\n    };\n    l.prototype.JSBNG__onmouseup = function() {\n        this.setHref(this.getRewrittenURI());\n    };\n    l.prototype.JSBNG__onmouseout = function() {\n        this.setHref(this.url);\n    };\n    l.prototype.setHref = function(m) {\n        if (((j.ie() < 9))) {\n            var n = g.create(\"span\");\n            g.appendContent(this.dom, n);\n            this.dom.href = m;\n            g.remove(n);\n        }\n         else this.dom.href = m;\n    ;\n    ;\n    };\n    e.exports = l;\n});\n__d(\"UIIntentionalStreamMessage\", [], function(a, b, c, d, e, f) {\n    var g = {\n        SET_AUTO_INSERT: \"UIIntentionalStream/setAutoInsert\",\n        UPDATE_STREAM: \"UIIntentionalStreamRefresh/updateStream\",\n        REFRESH_STREAM: \"UIIntentionalStreamRefresh/refreshStream\",\n        UPDATE_AUTOREFRESH_CONFIG: \"UIIntentionalStream/updateAutoRefreshConfig\",\n        UPDATE_HTML_CONTENT: \"UIIntentionalStream/updateHtmlContent\",\n        UPDATE_LAST_REFRESH_TIME: \"UIIntentionalStream/updateLastRefreshTime\",\n        INSERT_STORIES: \"UIIntentionalStream/updateLastRefreshTime\",\n        UNLOAD: \"UIIntentionalStream/unload\"\n    };\n    e.exports = g;\n});\n__d(\"collectSubtreeData\", [], function(a, b, c, d, e, f) {\n    function g(i, j, k, l, m) {\n        if (((((i.offsetWidth === 0)) && ((i.offsetHeight === 0))))) {\n            return m;\n        }\n    ;\n    ;\n        var n = {\n        };\n        if (i.getAttribute) {\n            for (r = 0; ((r < j.length)); r++) {\n                t = j[r];\n                var o = i.getAttribute(k[t]);\n                if (o) {\n                    n[t] = {\n                    };\n                    var p = JSON.parse(o);\n                    for (var q in l) {\n                        if (((p[q] !== undefined))) {\n                            n[t][q] = true;\n                            if (((m[t] === undefined))) {\n                                m[t] = {\n                                };\n                            }\n                        ;\n                        ;\n                            if (((m[t][q] === undefined))) {\n                                m[t][q] = [];\n                            }\n                        ;\n                        ;\n                            if (((l[q].length > 0))) {\n                                m[t][q].push(l[q]);\n                            }\n                        ;\n                        ;\n                            m[t][q].push(((\"(\" + p[q])));\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n            };\n        }\n    ;\n    ;\n        for (var r = 0; ((r < i.childNodes.length)); r++) {\n            var s = i.childNodes[r];\n            g(s, j, k, l, m);\n        };\n    ;\n        for (var t in n) {\n            for (var u in n[t]) {\n                var v = m[t][u][((m[t][u].length - 1))];\n                if (((((v.length > 0)) && ((v.charAt(0) == \"(\"))))) {\n                    m[t][u][((m[t][u].length - 1))] = v.substr(1);\n                }\n                 else m[t][u].push(\")\");\n            ;\n            ;\n            };\n        ;\n        };\n    ;\n        return m;\n    };\n;\n    function h(i, j) {\n        var k = {\n        };\n        for (var l = 0; ((l < j.length)); ++l) {\n            k[j[l]] = ((\"data-\" + j[l]));\n        ;\n        };\n    ;\n        var m = {\n            tn: \"\",\n            \"tn-debug\": \",\"\n        }, n = {\n        };\n        g(i, j, k, m, n);\n        for (var o in n) {\n            for (var p in n[o]) {\n                n[o][p] = n[o][p].join(\"\");\n            ;\n            };\n        ;\n        };\n    ;\n        return n;\n    };\n;\n    e.exports = h;\n});\n__d(\"ViewportTracking\", [\"event-extensions\",\"Arbiter\",\"DOM\",\"NavigationMessage\",\"Run\",\"Style\",\"UIIntentionalStreamMessage\",\"Vector\",\"$\",\"collectSubtreeData\",\"copyProperties\",\"debounce\",\"userAction\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"DOM\"), i = b(\"NavigationMessage\"), j = b(\"Run\"), k = b(\"Style\"), l = b(\"UIIntentionalStreamMessage\"), m = b(\"Vector\"), n = b(\"$\"), o = b(\"collectSubtreeData\"), p = b(\"copyProperties\"), q = b(\"debounce\"), r = b(\"userAction\"), s = \"vpv\";\n    function t() {\n    \n    };\n;\n    p(t.prototype, {\n        init: function(u) {\n            p(this, {\n                readStoryIDs: {\n                },\n                minSizeToBeVisible: 200,\n                listeners: [],\n                arbiterSubscriptions: []\n            });\n            this.getDataFromConfig(u);\n            this.fireTimer();\n            var v = q(this.fireTimer, this.getTimeout(), this);\n            this.listeners.push(JSBNG__Event.listen(window, \"JSBNG__scroll\", v));\n            this.listeners.push(JSBNG__Event.listen(window, \"resize\", v));\n            this.arbiterSubscriptions.push(g.subscribe(l.UPDATE_HTML_CONTENT, v));\n            j.JSBNG__onLeave(this.cleanup.bind(this));\n            this.arbiterSubscriptions.push(g.subscribe(i.NAVIGATION_BEGIN, this.cleanup.bind(this)));\n        },\n        cleanup: function() {\n            this.listeners.forEach(function(u) {\n                u.remove();\n            });\n            this.listeners = [];\n            this.arbiterSubscriptions.forEach(function(u) {\n                u.unsubscribe();\n            });\n            this.arbiterSubscriptions = [];\n        },\n        fireTimer: function() {\n            this.getStoriesInView().forEach(this.markStoryRead.bind(this));\n        },\n        getStoriesInView: function() {\n            var u = this.getAllStories(), v = [], w = false;\n            for (var x = 0; ((x < u.length)); x++) {\n                var y = u[x], z = this.getStoryID(y);\n                if (this.hasBeenVisible(z)) {\n                    continue;\n                }\n            ;\n            ;\n                if (this.isVisible(y)) {\n                    v.push(y);\n                    w = true;\n                }\n                 else if (w) {\n                    break;\n                }\n                \n            ;\n            ;\n            };\n        ;\n            return v;\n        },\n        hasBeenVisible: function(u) {\n            return ((u in this.readStoryIDs));\n        },\n        isVisible: function(u) {\n            var v = m.getViewportDimensions(), w = m.getElementPosition(u, \"viewport\"), x = m.getElementDimensions(u), y = Math.max(w.y, 0), z = Math.min(((w.y + x.y)), v.y), aa = Math.min(x.y, this.minSizeToBeVisible);\n            return ((((z - y)) >= aa));\n        },\n        markStoryRead: function(u) {\n            var v = this.getStoryID(u);\n            if (!v) {\n                return;\n            }\n        ;\n        ;\n            if (!this.hasBeenVisible(v)) {\n                this.readStoryIDs[v] = true;\n                var w = this.getDataToLog(u);\n                r(s, u, null, \"FORCE\", w);\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = t;\n});\n__d(\"XHPTemplate\", [\"event-extensions\",\"DataStore\",\"DOM\",\"HTML\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"DataStore\"), h = b(\"DOM\"), i = b(\"HTML\"), j = b(\"copyProperties\");\n    function k(m) {\n        this._model = m;\n    };\n;\n    j(k.prototype, {\n        render: function() {\n            if (i.isHTML(this._model)) {\n                this._model = h.setContent(JSBNG__document.createDocumentFragment(), this._model)[0];\n            }\n        ;\n        ;\n            return this._model.cloneNode(true);\n        },\n        build: function() {\n            return new l(this.render());\n        }\n    });\n    j(k, {\n        getNode: function(m, n) {\n            return k.getNodes(m)[n];\n        },\n        getNodes: function(m) {\n            var n = g.get(m, \"XHPTemplate:nodes\");\n            if (!n) {\n                n = {\n                };\n                var o = h.scry(m, \"[data-jsid]\");\n                o.push(m);\n                var p = o.length;\n                while (p--) {\n                    var q = o[p];\n                    n[q.getAttribute(\"data-jsid\")] = q;\n                    q.removeAttribute(\"data-jsid\");\n                };\n            ;\n                g.set(m, \"XHPTemplate:nodes\", n);\n            }\n        ;\n        ;\n            return n;\n        }\n    });\n    function l(m) {\n        this._root = m;\n        this._populateNodes();\n    };\n;\n    j(l.prototype, {\n        _populateNodes: function() {\n            this._nodes = {\n            };\n            this._leaves = {\n            };\n            var m = this._root.getElementsByTagName(\"*\");\n            for (var n = 0, o = m.length; ((n < o)); n++) {\n                var p = m[n], q = p.getAttribute(\"data-jsid\");\n                if (q) {\n                    p.removeAttribute(\"data-jsid\");\n                    this._nodes[q] = p;\n                    this._leaves[q] = !p.childNodes.length;\n                }\n            ;\n            ;\n            };\n        ;\n        },\n        getRoot: function() {\n            return this._root;\n        },\n        getNode: function(m) {\n            return this._nodes[m];\n        },\n        setNodeProperty: function(m, n, o) {\n            this.getNode(m)[n] = o;\n            return this;\n        },\n        setNodeContent: function(m, n) {\n            if (!this._leaves[m]) {\n                throw new Error(((\"Can't setContent on non-leaf node: \" + m)));\n            }\n        ;\n        ;\n            h.setContent(this.getNode(m), n);\n            return this;\n        }\n    });\n    e.exports = k;\n});\n__d(\"enforceMaxLength\", [\"event-extensions\",\"function-extensions\",\"DOM\",\"Input\",\"InputSelection\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"DOM\"), h = b(\"Input\"), i = b(\"InputSelection\"), j = function(m, n) {\n        var o = h.getValue(m), p = o.length, q = ((p - n));\n        if (((q > 0))) {\n            var r, s;\n            try {\n                r = i.get(m);\n                s = r.end;\n            } catch (t) {\n                r = null;\n                s = 0;\n            };\n        ;\n            if (((s >= q))) {\n                p = s;\n            }\n        ;\n        ;\n            var u = ((p - q));\n            if (((u && ((((o.charCodeAt(((u - 1))) & 64512)) === 55296))))) {\n                u--;\n            }\n        ;\n        ;\n            s = Math.min(s, u);\n            h.setValue(m, ((o.slice(0, u) + o.slice(p))));\n            if (r) {\n                i.set(m, Math.min(r.start, s), s);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    }, k = function(JSBNG__event) {\n        var m = JSBNG__event.getTarget(), n = ((m.getAttribute && parseInt(m.getAttribute(\"maxlength\"), 10)));\n        if (((((n > 0)) && g.isNodeOfType(m, [\"input\",\"textarea\",])))) {\n            j.bind(null, m, n).defer();\n        }\n    ;\n    ;\n    }, l = ((((\"maxLength\" in g.create(\"input\"))) && ((\"maxLength\" in g.create(\"textarea\")))));\n    if (!l) {\n        JSBNG__Event.listen(JSBNG__document.documentElement, {\n            keydown: k,\n            paste: k\n        });\n    }\n;\n;\n    e.exports = j;\n});\n__d(\"htmlHyperlink\", [\"Env\",\"htmlize\",\"UntrustedLink\",\"URI\",\"URLScraper\",], function(a, b, c, d, e, f) {\n    var g = b(\"Env\"), h = b(\"htmlize\"), i = b(\"UntrustedLink\"), j = b(\"URI\"), k = b(\"URLScraper\");\n    function l(m, n, o, p) {\n        if (((((typeof m === \"undefined\")) || !m.toString))) {\n            return \"\";\n        }\n    ;\n    ;\n        if (((typeof n !== \"function\"))) {\n            n = h;\n        }\n    ;\n    ;\n        if (((typeof o !== \"function\"))) {\n            o = h;\n        }\n    ;\n    ;\n        var m = m.toString(), q = [], r;\n        while ((r = k.match(m))) {\n            var s = m.indexOf(r);\n            if (((s >= 0))) {\n                q.push(n(m.substring(0, s)));\n            }\n        ;\n        ;\n            var t = o(r), u = r.replace(/\"/g, \"%22\");\n            if (!(/^[a-z][a-z0-9\\-+.]+:\\/\\//i.test(r))) {\n                u = ((\"http://\" + u));\n            }\n        ;\n        ;\n            q.push(((((\"\\u003Ca target=\\\"_blank\\\" rel=\\\"nofollow\\\" href=\\\"\" + u)) + \"\\\"\")));\n            if (((p && !j(u).isFacebookURI()))) {\n                a.UntrustedLink = i;\n                q.push(((((\" onmousedown=\\\"UntrustedLink.bootstrap(this, '\" + g.lhsh)) + \"', event)\\\"\")));\n            }\n        ;\n        ;\n            q.push(((((\"\\u003E\" + t)) + \"\\u003C/a\\u003E\")));\n            m = m.substring(((s + r.length)));\n        };\n    ;\n        ((m && q.push(n(m))));\n        return q.join(\"\");\n    };\n;\n    e.exports = l;\n});\n__d(\"randomInt\", [], function(a, b, c, d, e, f) {\n    function g(h, i) {\n        if (((arguments.length === 1))) {\n            i = h;\n            h = 0;\n        }\n    ;\n    ;\n        var j = ((this.JSBNG__random || Math.JSBNG__random));\n        return Math.floor(((h + ((j() * ((i - h)))))));\n    };\n;\n    e.exports = g;\n});\n__d(\"setIntervalAcrossTransitions\", [], function(a, b, c, d, e, f) {\n    function g(h, i) {\n        return JSBNG__setInterval(h, i, false);\n    };\n;\n    e.exports = g;\n});\n__d(\"setTimeoutAcrossTransitions\", [], function(a, b, c, d, e, f) {\n    function g(h, i) {\n        return JSBNG__setTimeout(h, i, false);\n    };\n;\n    e.exports = g;\n});\n__d(\"submitForm\", [\"DOM\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = function(i) {\n        var j = g.scry(i, \"input[type=\\\"submit\\\"]\")[0];\n        if (j) {\n            j.click();\n        }\n         else {\n            j = g.create(\"input\", {\n                type: \"submit\",\n                className: \"hidden_elem\"\n            });\n            g.appendContent(i, j);\n            j.click();\n            g.remove(j);\n        }\n    ;\n    ;\n    };\n    e.exports = h;\n});\n__d(\"debounceAcrossTransitions\", [\"debounce\",], function(a, b, c, d, e, f) {\n    var g = b(\"debounce\");\n    function h(i, j, k) {\n        return g(i, j, k, true);\n    };\n;\n    e.exports = h;\n});\n__d(\"legacy:onvisible\", [\"OnVisible\",], function(a, b, c, d) {\n    a.OnVisible = b(\"OnVisible\");\n}, 3);\n__d(\"PhotoEverstoreLogger\", [\"event-extensions\",\"AsyncRequest\",\"copyProperties\",\"ImageUtils\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"AsyncRequest\"), h = b(\"copyProperties\"), i = b(\"ImageUtils\"), j = {\n        BATCH_WINDOW_MS: 500,\n        storedLog: []\n    };\n    function k() {\n    \n    };\n;\n    h(k, {\n        _log: function(m) {\n            j.storedLog.push(m);\n            if (((j.storedLog.length == 1))) {\n                JSBNG__setTimeout(l, j.BATCH_WINDOW_MS, false);\n            }\n        ;\n        ;\n        },\n        logImmediately: function(m) {\n            k._log(m);\n        },\n        registerForLogging: function(m) {\n            if (i.hasLoaded(m)) {\n                k._log(m.src);\n            }\n             else JSBNG__Event.listen(m, \"load\", function(JSBNG__event) {\n                k._log(m.src);\n            });\n        ;\n        ;\n        }\n    });\n    function l() {\n        var m = j.storedLog;\n        j.storedLog = [];\n        var n = JSON.stringify(m);\n        new g().setURI(\"/ajax/photos/logging/everstore_logging.php\").setData({\n            loggedUrls: n\n        }).setMethod(\"POST\").setOption(\"suppressErrorHandlerWarning\", true).setOption(\"suppressErrorAlerts\", true).send();\n    };\n;\n    e.exports = k;\n});\n__d(\"PhotoSessionLog\", [\"AsyncRequest\",\"Run\",\"Vector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncRequest\"), h = b(\"Run\"), i = b(\"Vector\"), j = b(\"copyProperties\");\n    function k() {\n    \n    };\n;\n    j(k, {\n        UNKNOWN: 0,\n        ESC: 1,\n        X: 2,\n        OUTSIDE: 3,\n        UNLOAD: 4,\n        NAVIGATE: 5,\n        AGGREGATE: 6,\n        LEAVE: 7,\n        PERMALINK: 0,\n        SNOWLIFT: 6,\n        AGGREGATION_COUNT: 20,\n        set: null,\n        time: null,\n        views: 0,\n        fbidList: [],\n        details: {\n        },\n        width: 0,\n        height: 0,\n        first: false,\n        last: false,\n        logIds: false,\n        version: null,\n        buttonLikes: 0,\n        pagingAction: \"\",\n        faceTagImpressions: 0,\n        cycle: false,\n        endOfRelevant: false,\n        relevantCount: 0,\n        initLogging: function(l) {\n            this.set = null;\n            this.time = new JSBNG__Date();\n            this.views = 0;\n            this.hiResLoads = 0;\n            this.fullScreenViews = {\n            };\n            this.first = true;\n            this.last = false;\n            this.logIds = false;\n            this.version = l;\n            this.buttonLikes = 0;\n            this.pagingAction = \"\";\n            this.faceTagImpressions = 0;\n            this.cycle = false;\n            this.endOfRelevant = false;\n            this.relevantCount = 0;\n            if (((l === k.SNOWLIFT))) {\n                var m = i.getViewportDimensions();\n                this.width = m.x;\n                this.height = m.y;\n            }\n        ;\n        ;\n        },\n        setLogFbids: function(l) {\n            this.logIds = l;\n        },\n        setPhotoSet: function(l) {\n            this.set = l;\n        },\n        addButtonLike: function() {\n            this.buttonLikes++;\n        },\n        setPagingAction: function(l) {\n            this.pagingAction = l;\n        },\n        addFaceTagImpression: function() {\n            this.faceTagImpressions++;\n        },\n        setCycle: function(l) {\n            this.cycle = l;\n        },\n        setEndOfRelevant: function(l) {\n            this.endOfRelevant = l;\n        },\n        setRelevantCount: function(l) {\n            this.relevantCount = l;\n        },\n        setEndMetrics: function(l) {\n            this.endMetrics = l;\n        },\n        addPhotoView: function(l, m, n) {\n            if (((this.logIds && ((this.views >= this.AGGREGATION_COUNT))))) {\n                this.logPhotoViews(this.AGGREGATE);\n            }\n        ;\n        ;\n            this.views++;\n            if (l) {\n                this.fbidList.push([l.fbid,l.owner,JSBNG__Date.now(),]);\n            }\n        ;\n        ;\n            if (m) {\n                this.hiResLoads++;\n            }\n        ;\n        ;\n            if (n) {\n                this.fullScreenViews[l.fbid] = true;\n            }\n        ;\n        ;\n        },\n        logEnterFullScreen: function(l) {\n            this.fullScreenViews[l] = true;\n        },\n        addDetailData: function(l, m) {\n            if (!this.details[l]) {\n                this.details[l] = {\n                    t: m.num_tags,\n                    l: m.has_location,\n                    c: m.has_caption,\n                    cm: m.comment_count,\n                    lk: m.like_count,\n                    w: m.width,\n                    h: m.height,\n                    ad: \"{}\",\n                    p: this.pagingAction\n                };\n            }\n        ;\n        ;\n        },\n        updateAdData: function(l, m) {\n            if (this.details[l]) {\n                this.details[l].ad = JSON.stringify(m);\n            }\n        ;\n        ;\n        },\n        logPhotoViews: function(l) {\n            if ((((!this.views) || ((((this.version === k.SNOWLIFT)) && ((l == k.LEAVE))))))) {\n                return;\n            }\n        ;\n        ;\n            if (((l != this.AGGREGATE))) {\n                this.last = true;\n            }\n        ;\n        ;\n            var m = {\n                set: this.set,\n                time: ((new JSBNG__Date() - this.time)),\n                fbids: ((this.logIds ? this.fbidList : [])),\n                details: ((this.logIds ? this.details : {\n                })),\n                first: this.first,\n                last: this.last,\n                close: ((l ? l : this.UNKNOWN)),\n                button_likes: this.buttonLikes,\n                version: this.version,\n                face_imp: this.faceTagImpressions,\n                endmetric: this.endMetrics,\n                cycle: this.cycle,\n                end_relev: this.endOfRelevant,\n                relev_count: this.relevantCount\n            };\n            if (((this.version === k.SNOWLIFT))) {\n                var n = i.getViewportDimensions();\n                m.width = ((n.x || this.width));\n                m.height = ((n.y || this.height));\n                if (((this.hiResLoads > 0))) {\n                    m.hires_loads = this.hiResLoads;\n                }\n            ;\n            ;\n                if (this.last) {\n                    var o = Object.keys(this.fullScreenViews).length;\n                    if (((o > 0))) {\n                        m.fullscreen = o;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            new g().setURI(\"/ajax/photos/logging/session_logging.php\").setAllowCrossPageTransition(true).setOption(\"asynchronous\", ((l != k.UNLOAD))).setOption(\"suppressErrorHandlerWarning\", true).setData(m).send();\n            this.views = 0;\n            this.hiResLoads = 0;\n            this.fbidList = [];\n            this.details = {\n            };\n            this.first = false;\n            this.buttonLikes = 0;\n            if (this.last) {\n                this.set = null;\n                this.logIds = false;\n                this.fullScreenViews = {\n                };\n            }\n        ;\n        ;\n        }\n    });\n    h.JSBNG__onUnload(function() {\n        k.logPhotoViews(k.UNLOAD);\n    });\n    h.JSBNG__onLeave(function() {\n        k.logPhotoViews(k.LEAVE);\n    });\n    e.exports = k;\n});\n__d(\"PhotosConst\", [], function(a, b, c, d, e, f) {\n    var g = {\n        VIEWER_PERMALINK: 0,\n        VIEWER_SNOWLIFT: 6,\n        VIEWER_VAULTBOX: 8,\n        BULK_EDITOR: 3,\n        FLASH_UPLOADER: 4,\n        HTML5_UPLOADER: 10,\n        SIZE_NORMAL: \"n\"\n    };\n    e.exports = g;\n});\n__d(\"PhotosUtils\", [\"copyProperties\",\"JSBNG__Rect\",\"Vector\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\"), h = b(\"JSBNG__Rect\"), i = b(\"Vector\");\n    function j() {\n    \n    };\n;\n    g(j, {\n        getNearestBox: function(k, l) {\n            var m = Infinity, n = null;\n            for (var o in k) {\n                var p = k[o];\n                if (p.contains(l)) {\n                    var q = l.distanceTo(p.getCenter());\n                    if (((q < m))) {\n                        m = q;\n                        n = o;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            return n;\n        },\n        absoluteToNormalizedPosition: function(k, l) {\n            var m = i.getElementPosition(k), n = i.getElementDimensions(k), o = l.sub(m).mul(((100 / n.x)), ((100 / n.y)));\n            o.domain = \"pure\";\n            return o;\n        },\n        normalizedToAbsolutePosition: function(k, l) {\n            var m = i.getElementPosition(k), n = i.getElementDimensions(k), o = l.mul(((n.x / 100)), ((n.y / 100))).add(m);\n            o.domain = \"JSBNG__document\";\n            return o;\n        },\n        isFacebox: function(k) {\n            return k.match(/^face:/);\n        }\n    });\n    e.exports = j;\n});\n__d(\"PhotoStreamCache\", [\"array-extensions\",\"HTML\",\"PhotosConst\",\"PhotoEverstoreLogger\",\"JSBNG__Rect\",\"UIPagelet\",\"URI\",\"Vector\",\"copyProperties\",\"createArrayFrom\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    var g = b(\"HTML\"), h = b(\"PhotosConst\"), i = b(\"PhotoEverstoreLogger\"), j = b(\"JSBNG__Rect\"), k = b(\"UIPagelet\"), l = b(\"URI\"), m = b(\"Vector\"), n = b(\"copyProperties\"), o = b(\"createArrayFrom\");\n    function p() {\n    \n    };\n;\n    n(p, {\n        ERROR: \"error\",\n        HTML: \"html\",\n        IMAGE_DATA: \"image\",\n        EXTRA: \"extra\",\n        BUFFER_SIZE: 3,\n        INIT_BUCKET_SIZE: 4,\n        FULL_BUCKET_SIZE: 12,\n        ERROR_ID: -1,\n        INIT_PLACEHOLDER: 1\n    });\n    n(p.prototype, {\n        init: function(q, r) {\n            this.version = q;\n            this.pageletName = r;\n            this.bufferSize = p.BUFFER_SIZE;\n            this.fullBucketSize = p.FULL_BUCKET_SIZE;\n            this.initError = false;\n            this.isActive = true;\n            this.leftLock = false;\n            this.rightLock = false;\n            this.reset();\n        },\n        reset: function() {\n            this.cache = {\n                image: {\n                },\n                extra: {\n                },\n                html: {\n                }\n            };\n            this.fbidList = [];\n            this.loaded = false;\n            this.allLoaded = false;\n            this.permalinkMap = {\n            };\n            this.position = 0;\n            this.totalCount = null;\n            this.firstCursor = null;\n            this.firstCursorIndex = null;\n        },\n        waitForInitData: function() {\n            this.fbidList.push(p.INIT_PLACEHOLDER);\n        },\n        destroy: function() {\n            this.reset();\n            this.isActive = false;\n        },\n        isLoaded: function() {\n            return this.loaded;\n        },\n        canPage: function() {\n            if (!this.isLoaded()) {\n                return false;\n            }\n        ;\n        ;\n            if (((this.totalCount !== null))) {\n                return ((this.totalCount > 1));\n            }\n        ;\n        ;\n            return ((this.getLength() > 1));\n        },\n        errorInCurrent: function() {\n            if (this.initError) {\n                return true;\n            }\n             else if (!this.isLoaded()) {\n                return false;\n            }\n            \n        ;\n        ;\n            return this.checkErrorAt(this.getCursor());\n        },\n        getLength: function() {\n            return this.fbidList.length;\n        },\n        getPhotoSet: function() {\n            return this.photoSetQuery.set;\n        },\n        getPhotoSetQuery: function() {\n            return this.photoSetQuery;\n        },\n        getCurrentImageData: function() {\n            return this.getImageData(this.getCursor());\n        },\n        getImageData: function(q) {\n            return this.getCacheContent(q, p.IMAGE_DATA);\n        },\n        getCurrentHtml: function() {\n            return this.getCacheContent(this.getCursor(), p.HTML);\n        },\n        getCurrentExtraData: function() {\n            return this.getCacheContent(this.getCursor(), p.EXTRA);\n        },\n        getCacheContent: function(q, r) {\n            if (((((!q || ((q === p.ERROR_ID)))) || ((q === p.INIT_PLACEHOLDER))))) {\n                return null;\n            }\n        ;\n        ;\n            return this.cache[r][q];\n        },\n        getCursorPos: function() {\n            return this.position;\n        },\n        getCursor: function() {\n            if (((((this.position >= 0)) && ((this.position < this.getLength()))))) {\n                return this.fbidList[this.position];\n            }\n        ;\n        ;\n            return null;\n        },\n        getCursorForURI: function(q) {\n            return this.permalinkMap[q];\n        },\n        calculatePositionForMovement: function(q) {\n            var r = ((this.position + q));\n            if (this.allLoaded) {\n                var s = this.getLength();\n                r = ((((s + ((r % s)))) % s));\n            }\n        ;\n        ;\n            return r;\n        },\n        isValidMovement: function(q) {\n            if (((!this.isLoaded() || !this.canPage()))) {\n                return false;\n            }\n        ;\n        ;\n            var r = this.calculatePositionForMovement(q);\n            return ((((this.getCursor() > 0)) || ((((r >= 0)) && ((r < this.getLength()))))));\n        },\n        moveCursor: function(q) {\n            if (!this.isValidMovement(q)) {\n                return;\n            }\n        ;\n        ;\n            this.position = this.calculatePositionForMovement(q);\n            if (((q !== 0))) {\n                this.loadMoreIfNeccessary(((q > 0)));\n            }\n        ;\n        ;\n        },\n        checkErrorAt: function(q) {\n            if (!this.isLoaded()) {\n                return false;\n            }\n        ;\n        ;\n            if (((q === p.ERROR_ID))) {\n                return true;\n            }\n        ;\n        ;\n            return false;\n        },\n        getRelativeMovement: function(q) {\n            for (var r = 0; ((r < this.getLength())); r++) {\n                if (((this.fbidList[r] == q))) {\n                    return ((r - this.position));\n                }\n            ;\n            ;\n            };\n        ;\n            return null;\n        },\n        preloadImages: function(q) {\n            var r, s, t = this.getLength(), u = this.cache.image, v = p.BUFFER_SIZE;\n            if (((t > ((v * 2))))) {\n                r = ((((((this.position + t)) - ((v % t)))) % t));\n                s = ((((this.position + v)) % t));\n            }\n             else {\n                r = 0;\n                s = ((t - 1));\n            }\n        ;\n        ;\n            while (((r != s))) {\n                var w = this.fbidList[r];\n                if (((u[w] && u[w].url))) {\n                    if (((q && !u[w].resource))) {\n                        u[w].resource = new JSBNG__Image();\n                        u[w].resource.src = u[w].url;\n                        if (((u[w].everstoreLogThis === true))) {\n                            i.logImmediately(u[w].resource.src);\n                        }\n                    ;\n                    ;\n                    }\n                     else if (((!q && !u[w].small))) {\n                        u[w].small = new JSBNG__Image();\n                        u[w].small.src = ((u[w].smallurl || u[w].url));\n                        if (((u[w].everstoreLogThis === true))) {\n                            i.logImmediately(u[w].small.src);\n                        }\n                    ;\n                    ;\n                    }\n                    \n                ;\n                }\n            ;\n            ;\n                r = ((((r + 1)) % t));\n            };\n        ;\n        },\n        loadMoreIfNeccessary: function(q) {\n            if (((((this.allLoaded || ((q && this.rightLock)))) || ((!q && this.leftLock))))) {\n                return;\n            }\n        ;\n        ;\n            var r = ((q ? 1 : -1)), s = ((this.position + ((this.bufferSize * r))));\n            if (((((s < 0)) && !this.checkErrorAt(this.getEndCursor(false))))) {\n                this.leftLock = true;\n                this.fetch(this.fullBucketSize, false);\n            }\n             else if (((((s > this.getLength())) && !this.checkErrorAt(this.getEndCursor(true))))) {\n                this.rightLock = true;\n                this.fetch(this.fullBucketSize, true);\n            }\n            \n        ;\n        ;\n        },\n        getEndCursor: function(q) {\n            return ((q ? this.fbidList[((this.getLength() - 1))] : this.fbidList[0]));\n        },\n        calculateRelativeIndex: function(q, r, s) {\n            if (!this.totalCount) {\n                return null;\n            }\n        ;\n        ;\n            var t = this.fbidList.indexOf(r), u = this.fbidList.indexOf(s);\n            if (((((t === -1)) || ((u === -1))))) {\n                return null;\n            }\n        ;\n        ;\n            var v = ((u - t));\n            return ((((((q + v)) + this.totalCount)) % this.totalCount));\n        },\n        calculateDistance: function(q, r) {\n            var s = this.fbidList.indexOf(q), t = this.fbidList.indexOf(r);\n            if (((((s === -1)) || ((t === -1))))) {\n                return null;\n            }\n        ;\n        ;\n            return ((((((t - s)) + this.getLength())) % this.getLength()));\n        },\n        fetch: function(q, r) {\n            var s = this.getEndCursor(r), t = n({\n                cursor: s,\n                version: this.version,\n                end: this.getEndCursor(!r),\n                fetchSize: ((r ? q : ((-1 * q)))),\n                relevant_count: this.relevantCount\n            }, this.photoSetQuery);\n            if (((this.totalCount && ((this.firstCursorIndex !== null))))) {\n                t.total = this.totalCount;\n                t.cursorIndex = this.calculateRelativeIndex(this.firstCursorIndex, this.firstCursor, s);\n            }\n        ;\n        ;\n            k.loadFromEndpoint(this.pageletName, null, t, {\n                usePipe: true,\n                jsNonblock: true,\n                crossPage: true\n            });\n        },\n        storeToCache: function(q) {\n            var r = {\n            };\n            if (!this.isActive) {\n                return r;\n            }\n        ;\n        ;\n            if (((\"error\" in q))) {\n                this.processErrorResult(q.error);\n                r.error = true;\n                return r;\n            }\n        ;\n        ;\n            if (((\"init\" in q))) {\n                this.processInitResult(q.init);\n                r.init = {\n                    logids: q.init.logids,\n                    fbid: q.init.fbid,\n                    loggedin: q.init.loggedin,\n                    fromad: q.init.fromad\n                };\n            }\n        ;\n        ;\n            if (((\"image\" in q))) {\n                this.processImageResult(q.image);\n                r.image = true;\n            }\n        ;\n        ;\n            if (((\"data\" in q))) {\n                this.processDataResult(q.data);\n                r.data = true;\n            }\n        ;\n        ;\n            return r;\n        },\n        processInitResult: function(q) {\n            if (this.loaded) {\n                return;\n            }\n        ;\n        ;\n            this.loaded = true;\n            this.photoSetQuery = q.query;\n            if (q.bufferSize) {\n                this.bufferSize = q.bufferSize;\n            }\n        ;\n        ;\n            if (q.fullBucketSize) {\n                this.fullBucketSize = q.fullBucketSize;\n            }\n        ;\n        ;\n            if (((this.fbidList.length === 0))) {\n                this.fbidList.push(q.fbid);\n                this.rightLock = true;\n            }\n             else {\n                var r = this.fbidList.indexOf(p.INIT_PLACEHOLDER);\n                if (((r != -1))) {\n                    this.fbidList[r] = q.fbid;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            this.firstCursor = q.fbid;\n            if (((((\"initIndex\" in q)) && ((\"totalCount\" in q))))) {\n                this.firstCursorIndex = q.initIndex;\n                this.totalCount = q.totalCount;\n            }\n        ;\n        ;\n            if (((this.version == h.VIEWER_PERMALINK))) {\n                this.fetch(p.INIT_BUCKET_SIZE, true);\n            }\n        ;\n        ;\n        },\n        processImageResult: function(q) {\n            for (var r in q) {\n                if (((((r === this.firstCursor)) && q[r].everstoreLogThis))) {\n                    i.logImmediately(q[r].url);\n                }\n            ;\n            ;\n                this.cache.image[r] = q[r];\n                if (q[r].dimensions) {\n                    this.cache.image[r].dimensions = m.deserialize(q[r].dimensions);\n                }\n            ;\n            ;\n                if (q[r].smalldims) {\n                    this.cache.image[r].smalldims = m.deserialize(q[r].smalldims);\n                }\n            ;\n            ;\n                this.permalinkMap[l(q[r].info.permalink).getUnqualifiedURI().toString()] = r;\n            };\n        ;\n        },\n        attachToFbidsList: function(q, r, s) {\n            if (this.allLoaded) {\n                return;\n            }\n        ;\n        ;\n            if (((r === -1))) {\n                for (var t = ((q.length - 1)); ((t >= 0)); t--) {\n                    this.fbidList.unshift(q[t]);\n                    this.position++;\n                };\n            ;\n                this.leftLock = false;\n            }\n             else {\n                for (var u = 0; ((u < q.length)); u++) {\n                    this.fbidList.push(q[u]);\n                ;\n                };\n            ;\n                this.rightLock = false;\n            }\n        ;\n        ;\n            if (s) {\n                this.setAllLoaded();\n            }\n        ;\n        ;\n        },\n        setAllLoaded: function() {\n            this.allLoaded = true;\n            if (((this.getCursor() === null))) {\n                this.position = this.calculatePositionForMovement(0);\n            }\n        ;\n        ;\n        },\n        processDataResult: function(q) {\n            for (var r in q) {\n                if (!this.cache.html[r]) {\n                    this.cache.html[r] = {\n                    };\n                }\n            ;\n            ;\n                for (var s in q[r].html) {\n                    var t = q[r].html[s];\n                    if (((typeof t === \"string\"))) {\n                        t = g(t).getRootNode();\n                    }\n                ;\n                ;\n                    this.cache.html[r][s] = o(t.childNodes);\n                };\n            ;\n                if (!((\"extra\" in q[r]))) {\n                    this.cache.extra[r] = null;\n                    continue;\n                }\n            ;\n            ;\n                this.cache.extra[r] = {\n                    tagRects: {\n                    }\n                };\n                if (!Array.isArray(q[r].extra.tagRects)) {\n                    for (var u in q[r].extra.tagRects) {\n                        if (q[r].extra.tagRects[u]) {\n                            this.cache.extra[r].tagRects[u] = j.deserialize(q[r].extra.tagRects[u]);\n                        }\n                    ;\n                    ;\n                    };\n                }\n            ;\n            ;\n            };\n        ;\n        },\n        processErrorResult: function(q) {\n            if (!this.isLoaded()) {\n                this.initError = true;\n                return;\n            }\n        ;\n        ;\n            var r = q.side, s = [p.ERROR_ID,];\n            this.attachToFbidsList(s, r);\n        },\n        setTotalCount: function(q) {\n            this.totalCount = q;\n        },\n        setFirstCursorIndex: function(q) {\n            this.firstCursorIndex = q;\n        }\n    });\n    e.exports = p;\n});\n__d(\"PhotoSnowliftAds\", [\"array-extensions\",\"event-extensions\",\"copyProperties\",\"CSS\",\"csx\",\"DataStore\",\"DOM\",\"PhotoSessionLog\",\"UIPagelet\",\"URI\",\"Vector\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    var g = b(\"copyProperties\"), h = b(\"CSS\"), i = b(\"csx\"), j = b(\"DataStore\"), k = b(\"DOM\"), l = b(\"PhotoSessionLog\"), m = b(\"UIPagelet\"), n = b(\"URI\"), o = b(\"Vector\"), p = {\n        DEFAULT_UNITS_REFRESH_RATE: 30000,\n        UNITS_REGISTER_DELAY: 1000,\n        root: null,\n        availableDimensions: null,\n        loadQuery: null,\n        lastLoadTime: 0,\n        minAds: 100,\n        units: null,\n        isLogAdData: null,\n        showSmallerAd: false,\n        egoEnabled: false,\n        refreshUnitsRate: null,\n        adsStatus: \"null\",\n        adsEvents: {\n        },\n        resetEvents: function() {\n            this.adsStatus = \"reset\";\n            this.adsEvents = {\n            };\n        },\n        addEvent: function(q, r) {\n            if (r) {\n                this.adsStatus = q;\n            }\n        ;\n        ;\n            var s = JSBNG__Date.now();\n            this.adsEvents[((((q + \"_\")) + s))] = s;\n        },\n        init: function(q, r, s) {\n            this.reset();\n            this.root = q;\n            this.snowlift = r;\n            this.showSmallerAd = s.showsmallerad;\n            this.egoEnabled = s.ego_enabled;\n            this.minAds = s.min_ads;\n            this.addEvent(\"init\", true);\n            this.refreshUnitsRate = p.DEFAULT_UNITS_REFRESH_RATE;\n            if (s.refresh_fast) {\n                this.refreshUnitsRate = s.refresh_rate;\n            }\n        ;\n        ;\n        },\n        reset: function() {\n            this.lastLoadTime = 0;\n            this.units = [];\n            this.resetEvents();\n            this.addEvent(\"reset\", true);\n        },\n        resize: function(q) {\n            this.availableDimensions = q;\n            this.loadQuery = this.snowlift.getLoadQuery();\n            this.processResize();\n        },\n        calculateUnitSizes: function(q, r) {\n            var s = {\n            };\n            q.forEach(function(t) {\n                var u = t.root.firstChild.offsetHeight;\n                t.units.forEach(function(w) {\n                    if (!h.hasClass(w, \"hidden\")) {\n                        var x = this.getHeight(w.firstChild, r);\n                        u -= x;\n                    }\n                ;\n                ;\n                }.bind(this));\n                var v = {\n                    height: u,\n                    visible: false\n                };\n                t.units.forEach(function(w) {\n                    var x = this.getIsAds(w), y = this.getHeight(w.firstChild, r), z = this.getUnitId(w);\n                    s[z] = {\n                        height: y,\n                        visible: false,\n                        priority: 0,\n                        is_ads: x,\n                        section_ref: v\n                    };\n                }.bind(this));\n            }.bind(this));\n            return s;\n        },\n        calculateVisibleUnits: function(q, r, s) {\n            var t = 0, u = this.getUnitPriority(r);\n            u.forEach(function(v) {\n                if (r.hasOwnProperty(v)) {\n                    var w = r[v], x = w.height;\n                    if (!w.section_ref.visible) {\n                        x += w.section_ref.height;\n                    }\n                ;\n                ;\n                    w.height_below = ((s - x));\n                    w.visible = ((((w.height_below >= 0)) && ((x > 0))));\n                    if (w.visible) {\n                        w.section_ref.visible = true;\n                        s -= x;\n                        t++;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            }.bind(this));\n            return r;\n        },\n        displayUnits: function(q, r) {\n            q.forEach(function(s) {\n                var t = false;\n                s.units.forEach(function(u) {\n                    var v = this.getUnitId(u), w = r[v], x = w.visible, y = w.height_below, z = w.is_ads;\n                    h.conditionClass(u, \"hidden\", !x);\n                    t = ((t || x));\n                    this.calcUnitStats(this.units[z][v], x, y);\n                }.bind(this));\n                h.conditionClass(s.root, \"hidden\", !t);\n            }.bind(this));\n        },\n        getUnitPriority: function(q) {\n            var r = [], s = 0, t = 0;\n            for (var u in q) {\n                var v = q[u];\n                r.push(u);\n                var w = ((((this.minAds + s)) + t));\n                if (v.is_ads) {\n                    if (((t < this.minAds))) {\n                        w = t;\n                    }\n                ;\n                ;\n                    t++;\n                }\n                 else s++;\n            ;\n            ;\n                v.priority = w;\n            };\n        ;\n            r = r.sort(function(x, y) {\n                var z = q[x], aa = q[y];\n                return ((z.priority - aa.priority));\n            }.bind(this));\n            return r;\n        },\n        updateUnitsStatus: function() {\n            var q = this.availableDimensions.x, r = this.availableDimensions.y, s = this.calculateUnitSizes(this.sections, q);\n            s = this.calculateVisibleUnits(this.sections, s, r);\n            this.displayUnits(this.sections, s);\n        },\n        calcUnitStats: function(q, r, s) {\n            var t = JSBNG__Date.now();\n            if (q.visible) {\n                q.totalTime += ((t - q.lastShowTime));\n            }\n        ;\n        ;\n            if (((((q.trackingCode !== null)) && ((q.totalTime >= this.UNITS_REGISTER_DELAY))))) {\n                var u = q.trackingCode;\n                q.trackingCode = null;\n                this.registerImpression(u, q.registerUrl);\n            }\n        ;\n        ;\n            q.visible = r;\n            q.heightBelow = s;\n            q.lastShowTime = t;\n        },\n        prepareResize: function() {\n            var q = function(r) {\n                var s = k.create(\"div\", {\n                    className: \"JSBNG__inner\"\n                }), t = k.create(\"div\", {\n                    className: \"wrapper\"\n                }, s);\n                k.replace(r, t);\n                k.setContent(s, r);\n                return t;\n            };\n            this.sections = k.scry(this.root, \"div.ego_section\").map(function(r) {\n                return {\n                    root: q(r),\n                    units: k.scry(r, \"div.ego_unit\").map(q)\n                };\n            });\n        },\n        processResize: function() {\n            if (((((this.isLoading || ((this.lastLoadTime === 0)))) || ((this.availableDimensions === null))))) {\n                this.setLogData();\n                return;\n            }\n        ;\n        ;\n            this.updateUnitsStatus();\n            this.setLogData();\n            var q = this.nextRegisterTime();\n            if (((q !== Infinity))) {\n                this.processResize.bind(this).defer(q, true);\n            }\n        ;\n        ;\n        },\n        setIsLogAdData: function(q) {\n            this.isLogAdData = q;\n            this.addEvent(\"setIsLogAdData\", false);\n            this.setLogData();\n        },\n        setLogData: function() {\n            var q = this.snowlift.getImageId();\n            if (((this.isLogAdData && q))) {\n                var r = o.getElementDimensions(this.snowlift.getImage()), s = o.getElementDimensions(this.snowlift.getRHCHeader()), t = o.getElementDimensions(this.snowlift.getRHCBody()), u = o.getElementDimensions(this.snowlift.getRHCFooter()), v = {\n                    query_set: this.snowlift.getLoadQuery().set,\n                    window_x: window.JSBNG__innerWidth,\n                    window_y: window.JSBNG__innerHeight,\n                    image_x: r.x,\n                    image_y: r.y,\n                    header_x: s.x,\n                    header_y: s.y,\n                    body_x: t.x,\n                    body_y: t.y,\n                    footer_x: u.x,\n                    footer_y: u.y,\n                    ads_below_space: this.getAdsBelowSpace(),\n                    time: JSBNG__Date.now(),\n                    adsStatus: this.adsStatus,\n                    adsEvents: this.adsEvents\n                };\n                l.updateAdData(q, v);\n            }\n        ;\n        ;\n        },\n        getAdsBelowSpace: function() {\n            var q = [], r = this.units[1];\n            for (var s in r) {\n                if (r.hasOwnProperty(s)) {\n                    q.push(r[s].heightBelow);\n                }\n            ;\n            ;\n            };\n        ;\n            return q;\n        },\n        getIsAds: function(q) {\n            var r = k.scry(q, \"div.-cx-PRIVATE-fbAdUnit__root\");\n            return r.length;\n        },\n        getUnitId: function(q) {\n            if (this.getIsAds(q)) {\n                return this.getAdId(q);\n            }\n             else return this.getEgoId(q)\n        ;\n        },\n        getEgoId: function(q) {\n            var r = k.JSBNG__find(q, \"div.fbEgoUnit\"), s = r.getAttribute(\"data-ego\"), t = JSON.parse(s).egoid;\n            return t;\n        },\n        getAdId: function(q) {\n            var r = k.JSBNG__find(q, \"div.-cx-PRIVATE-fbAdUnit__root\"), s = r.getAttribute(\"data-ad\"), t = JSON.parse(s).adid;\n            return t;\n        },\n        nextRegisterTime: function() {\n            var q = Infinity, r = g(g({\n            }, this.units[0]), this.units[1]);\n            for (var s in r) {\n                if (r.hasOwnProperty(s)) {\n                    var t = r[s];\n                    if (((((t.trackingCode !== null)) && t.visible))) {\n                        q = Math.min(q, ((this.UNITS_REGISTER_DELAY - t.totalTime)));\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            return q;\n        },\n        getHeight: function(q, r) {\n            var s = j.get(q, \"height\");\n            if (((s && ((s.x === r))))) {\n                return s.y;\n            }\n        ;\n        ;\n            return this.cacheHeight(q, r);\n        },\n        cacheHeight: function(q, r) {\n            var s = {\n                x: r,\n                y: q.offsetHeight\n            };\n            j.set(q, \"height\", s);\n            return s.y;\n        },\n        loadAdsAndEgo: function() {\n            this.resetEvents();\n            this.addEvent(\"adsRequested\", true);\n            m.loadFromEndpoint(\"WebEgoPane\", this.root, {\n                pid: 34,\n                data: [this.loadQuery.set,true,this.egoEnabled,]\n            }, {\n                crossPage: true,\n                bundle: false\n            });\n        },\n        unitsLoaded: function(q, r) {\n            var s;\n            if (r) {\n                s = \"/ai.php\";\n                this.addEvent(\"adsLoaded\", true);\n            }\n             else {\n                s = \"/ajax/ei.php\";\n                this.addEvent(\"egoLoaded\", true);\n            }\n        ;\n        ;\n            var t = {\n            };\n            for (var u in q) {\n                if (q.hasOwnProperty(u)) {\n                    t[u] = {\n                        trackingCode: q[u],\n                        totalTime: 0,\n                        lastShowTime: 0,\n                        heightBelow: -10000,\n                        visible: false,\n                        registerUrl: s\n                    };\n                }\n            ;\n            ;\n            };\n        ;\n            this.units[r] = t;\n            if (r) {\n                this.waitForImages(this.imagesLoaded.bind(this));\n            }\n        ;\n        ;\n        },\n        imagesLoaded: function() {\n            this.prepareResize();\n            this.addEvent(\"imagesLoaded\", true);\n            this.lastLoadTime = JSBNG__Date.now();\n            this.isLoading = false;\n            this.processResize();\n            h.removeClass(this.root, \"loading\");\n        },\n        loadAdsFromUserActivity: function() {\n            var q = JSBNG__Date.now(), r = this.refreshUnitsRate;\n            if (((!this.isLoading && ((((q - this.lastLoadTime)) > r))))) {\n                h.addClass(this.root, \"loading\");\n                this.isLoading = true;\n                this.loadAdsAndEgo();\n            }\n        ;\n        ;\n        },\n        registerImpression: function(q, r) {\n            var s = k.create(\"div\", {\n                src: n(r).addQueryData({\n                    aed: q\n                }),\n                width: 0,\n                height: 0,\n                frameborder: 0,\n                scrolling: \"no\",\n                className: \"fbEmuTracking\"\n            });\n            s.setAttribute(\"aria-hidden\", \"true\");\n            k.appendContent(this.root, s);\n        },\n        waitForImages: function(q) {\n            var r = k.scry(this.root, \"img.img\"), s = r.length, t = s;\n            if (((t === 0))) {\n                q();\n            }\n        ;\n        ;\n            var u = function() {\n                t--;\n                if (((t === 0))) {\n                    q.defer();\n                }\n            ;\n            ;\n            };\n            for (var v = 0; ((v < s)); v++) {\n                var w = r[v];\n                if (w.complete) {\n                    u();\n                }\n                 else JSBNG__Event.listen(w, {\n                    load: u,\n                    error: u,\n                    abort: u\n                });\n            ;\n            ;\n            };\n        ;\n        }\n    };\n    e.exports = p;\n});\n__d(\"PhotoViewer\", [\"Bootloader\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Bootloader\"), h = b(\"copyProperties\");\n    function i() {\n        this.image = null;\n        this.root = null;\n        this.stream = null;\n    };\n;\n    h(i, {\n        bootstrap: function(j, k) {\n            g.loadModules([\"PhotoSnowlift\",], function(l) {\n                l.bootstrap(j, k);\n            });\n        }\n    });\n    h(i.prototype, {\n        getEventPrefix: bagof(null),\n        getEventString: function(j) {\n            var k = this.getEventPrefix();\n            if (k) {\n                return ((((k + \".\")) + j));\n            }\n        ;\n        ;\n            return null;\n        },\n        getImage: function() {\n            return this.image;\n        },\n        getPosition: function() {\n            return ((this.stream ? this.stream.getCursor() : null));\n        },\n        getRoot: function() {\n            return this.root;\n        },\n        getSourceString: bagof(null),\n        getVersionConst: bagof(null)\n    });\n    e.exports = i;\n});\n__d(\"PhotoSnowlift\", [\"array-extensions\",\"event-extensions\",\"function-extensions\",\"Amoeba\",\"Arbiter\",\"AsyncDialog\",\"AsyncRequest\",\"Bootloader\",\"Class\",\"CSS\",\"Dialog\",\"DOM\",\"DOMControl\",\"DOMScroll\",\"FullScreen\",\"ImageUtils\",\"KeyEventController\",\"Keys\",\"LinkController\",\"Locale\",\"PageTransitions\",\"Parent\",\"PhotosConst\",\"PhotoSessionLog\",\"PhotoSnowliftAds\",\"PhotoStreamCache\",\"PhotosUtils\",\"PhotoViewer\",\"JSBNG__Rect\",\"ScrollableArea\",\"Style\",\"Toggler\",\"UIPagelet\",\"URI\",\"UserAgent\",\"Vector\",\"$\",\"computeRelativeURI\",\"copyProperties\",\"createArrayFrom\",\"ge\",\"goURI\",\"tx\",\"csx\",\"userAction\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Amoeba\"), h = b(\"Arbiter\"), i = b(\"AsyncDialog\"), j = b(\"AsyncRequest\"), k = b(\"Bootloader\"), l = b(\"Class\"), m = b(\"CSS\"), n = b(\"Dialog\"), o = b(\"DOM\"), p = b(\"DOMControl\"), q = b(\"DOMScroll\"), r = b(\"FullScreen\"), s = b(\"ImageUtils\"), t = b(\"KeyEventController\"), u = b(\"Keys\"), v = b(\"LinkController\"), w = b(\"Locale\"), x = b(\"PageTransitions\"), y = b(\"Parent\"), z = b(\"PhotosConst\"), aa = b(\"PhotoSessionLog\"), ba = b(\"PhotoSnowliftAds\"), ca = b(\"PhotoStreamCache\"), da = b(\"PhotosUtils\"), ea = b(\"PhotoViewer\"), fa = b(\"JSBNG__Rect\"), ga = b(\"ScrollableArea\"), ha = b(\"Style\"), ia = b(\"Toggler\"), ja = b(\"UIPagelet\"), ka = b(\"URI\"), la = b(\"UserAgent\"), ma = b(\"Vector\"), na = b(\"$\"), oa = b(\"computeRelativeURI\"), pa = b(\"copyProperties\"), qa = b(\"createArrayFrom\"), ra = b(\"ge\"), sa = b(\"goURI\"), ta = b(\"tx\"), ua = b(\"csx\"), va = b(\"userAction\"), wa = b(\"event-extensions\").$E;\n    function xa() {\n        this.parent.construct(this);\n    };\n;\n    pa(xa, {\n        STATE_ERROR: \"error\",\n        STATE_HTML: \"html\",\n        STATE_IMAGE_PIXELS: \"image_pixels\",\n        STATE_IMAGE_DATA: \"image\",\n        LOADING_TIMEOUT: 2000,\n        PAGER_FADE: 3000,\n        FULL_SCREEN_PADDING: 10,\n        STAGE_HIRES_MAX: {\n            x: 2048,\n            y: 2048\n        },\n        STAGE_NORMAL_MAX: {\n            x: 960,\n            y: 960\n        },\n        STAGE_MIN: {\n            x: 520,\n            y: 520\n        },\n        SIDEBAR_SIZE_MAX: 340,\n        SIDEBAR_SIZE_MIN: 285,\n        STAGE_CHROME: {\n            x: 102,\n            y: 42\n        },\n        VIDEO_BOTTOM_BAR_SPACE: 40,\n        GOPREV_AREA: 120,\n        TIMELINE_STRETCH_WIDTH: 843,\n        TIMELINE_STRETCH_MIN: 480,\n        MIN_TAG_DISTANCE: 83,\n        PADDING_MIN: 40,\n        _instance: null,\n        getInstance: function() {\n            if (!xa._instance) {\n                xa._instance = new xa();\n            }\n        ;\n        ;\n            return xa._instance;\n        },\n        initInstance: function(ya, za) {\n            xa.getInstance().init(ya, za);\n        },\n        addPhotoFbids: function(ya, za, ab, bb) {\n            xa.getInstance().addPhotoFbids(ya, za, ab, bb);\n        },\n        attachFollowFlyout: function(ya) {\n            o.insertAfter(na(\"fbPhotoSnowliftSubscribe\"), ya);\n        },\n        attachSubscribeFlyout: function(ya) {\n            o.insertAfter(na(\"fbPhotoSnowliftSubscribe\"), ya);\n        },\n        attachTagger: function(ya) {\n            xa.getInstance().attachTagger(ya);\n        },\n        preload: function(ya, za) {\n            xa.getInstance().preload(ya, za);\n        },\n        bootstrap: function(ya, za) {\n            if (za.getAttribute(\"data-vaultbox\")) {\n                k.loadModules([\"VaultBox\",], function(ab) {\n                    ab.bootstrap(ya, za);\n                });\n                return;\n            }\n        ;\n        ;\n            if (((ya && ka(ya).getQueryData().hasOwnProperty(\"share_id\")))) {\n                k.loadModules([\"SpotlightShareViewer\",], function(ab) {\n                    ab.bootstrap(ya, za);\n                });\n                return;\n            }\n        ;\n        ;\n            xa.getInstance().bootstrap(ya, za);\n        },\n        closeRefresh: function() {\n            xa.getInstance().closeRefresh();\n        },\n        deletePhoto: function(ya) {\n            xa.getInstance().deletePhoto(ya);\n        },\n        getImage: function() {\n            return xa.getInstance().getImage();\n        },\n        getImageId: function() {\n            return xa.getInstance().getImageId();\n        },\n        getLoadQuery: function() {\n            return xa.getInstance().getLoadQuery();\n        },\n        getRHCBody: function() {\n            return xa.getInstance().getRHCBody();\n        },\n        getRHCFooter: function() {\n            return xa.getInstance().getRHCFooter();\n        },\n        getRHCHeader: function() {\n            return xa.getInstance().getRHCHeader();\n        },\n        getRoot: function() {\n            return xa.getInstance().getRoot();\n        },\n        likePhotoSkipConfirmation: function(ya) {\n            xa.getInstance().likePhotoSkipConfirmation(ya);\n        },\n        saveTagsFromPayload: function(ya) {\n            xa.getInstance().saveTagsFromPayload(ya);\n        },\n        saveTagsFromPayloadDelayed: function(ya) {\n            xa.saveTagsFromPayload.curry(ya).defer(2000);\n        },\n        handleServerError: function(ya, za) {\n            xa.getInstance().handleServerError(ya, za);\n        },\n        storeFromData: function(ya) {\n            xa.getInstance().storeFromData(ya);\n        },\n        swapData: function() {\n            xa.getInstance().swapData();\n        },\n        touchMarkup: bagofholding,\n        updateTotalCount: function(ya, za, ab) {\n            xa.getInstance().updateTotalCount(ya, za, ab);\n        }\n    });\n    l.extend(xa, ea);\n    pa(xa.prototype, {\n        switchTimer: null,\n        imageRefreshTimer: null,\n        imageLoadingTimer: null,\n        lastPage: 0,\n        currentMinSize: null,\n        extraClass: null,\n        currentImageSize: null,\n        resetUriStack: true,\n        thumbSrc: null,\n        shouldStretch: false,\n        stageMax: xa.STAGE_NORMAL_MAX,\n        stageChrome: xa.STAGE_CHROME,\n        stagePagerPrev: null,\n        ua: null,\n        PhotoTagger: null,\n        showHiRes: false,\n        showHover: false,\n        skipLikePhotoConfirmation: false,\n        isShowingLikePhotoConfirmation: false,\n        preload: function(ya, za) {\n            k.loadModules([\"PhotoTagger\",\"fb-photos-snowlift-css\",\"Live\",\"PhotoTagApproval\",\"PhotoTags\",\"TagTokenizer\",\"fb-photos-snowlift-fullscreen-css\",], function(bb) {\n                this.PhotoTagger = bb;\n            }.bind(this));\n            var ab = this.getImageSrc(ka(ya).getQueryData());\n            if (ab) {\n                (new JSBNG__Image()).src = ab;\n            }\n        ;\n        ;\n        },\n        bootstrap: function(ya, za) {\n            this.preload(ya, za);\n            ba.reset();\n            this.resetUriStack = true;\n            if (this.isOpen) {\n                if (this.openExplicitly) {\n                    this.closeCleanup();\n                    this.resetUriStack = false;\n                }\n                 else return\n            ;\n            }\n        ;\n        ;\n            this.ua = va(\"snowlift\", za, null, \"FORCE\").set_namespace(\"snowlift\").set_ua_id(\"open\");\n            this.returningToStart = false;\n            ((this.loading && m.removeClass(this.loading, \"loading\")));\n            if (za) {\n                m.addClass((this.loading = za), \"loading\");\n                this.getThumbAndSize(za);\n            }\n             else this.loading = null;\n        ;\n        ;\n            h.inform(\"PhotoSnowlift.GO\", ya, h.BEHAVIOR_STATE);\n            this.loadFrameIfUninitialized();\n        },\n        getEventPrefix: function() {\n            return \"PhotoSnowlift\";\n        },\n        getRoot: function() {\n            return this.root;\n        },\n        getSourceString: function() {\n            return \"snowlift\";\n        },\n        getVersionConst: function() {\n            return z.VIEWER_SNOWLIFT;\n        },\n        getImage: function() {\n            return this.image;\n        },\n        getImageId: function() {\n            return this.stream.getCursor();\n        },\n        getRHCHeader: function() {\n            return this.rhcHeader;\n        },\n        getRHCBody: function() {\n            return this.ufiForm;\n        },\n        getRHCFooter: function() {\n            return this.rhcFooter;\n        },\n        getLoadQuery: function() {\n            return this.loadQuery;\n        },\n        getOwnerId: function() {\n            var ya = this.stream.getCurrentImageData();\n            if (ya) {\n                return ya.info.owner;\n            }\n        ;\n        ;\n            return null;\n        },\n        getThumbAndSize: function(ya) {\n            this.currentImageSize = null;\n            this.thumbSrc = null;\n            var za = ka(ya.getAttribute(\"ajaxify\")).getQueryData();\n            if (!za.size) {\n                return;\n            }\n        ;\n        ;\n            var ab = ma.deserialize(za.size);\n            if (((!ab.x || !ab.y))) {\n                return;\n            }\n        ;\n        ;\n            this.currentImageSize = ab;\n            if (((((!m.hasClass(ya, \"uiMediaThumb\") && !m.hasClass(ya, \"uiPhotoThumb\"))) && !m.hasClass(ya, \"uiScaledThumb\")))) {\n                return;\n            }\n        ;\n        ;\n            if (ya.getAttribute(\"data-cropped\")) {\n                return;\n            }\n        ;\n        ;\n            var bb = o.scry(ya, \"img\")[0], cb = o.scry(ya, \"i\")[0], db = y.byAttribute(ya, \"data-size\");\n            this.shouldStretch = ((((((((((((db && this.currentImageSize)) && bb)) && ((db.getAttribute(\"data-size\") === \"2\")))) && ((this.currentImageSize.x > this.currentImageSize.y)))) && ((this.currentImageSize.x <= xa.TIMELINE_STRETCH_WIDTH)))) && ((bb.offsetWidth === xa.TIMELINE_STRETCH_WIDTH))));\n            var eb;\n            if (bb) {\n                eb = bb.src;\n            }\n             else if (cb) {\n                eb = ha.get(cb, \"backgroundImage\").replace(/.*url\\(\"?([^\"]*)\"?\\).*/, \"$1\");\n            }\n             else return\n            \n        ;\n            this.thumbSrc = eb;\n        },\n        loadFrameIfUninitialized: function() {\n            if (this.root) {\n                return;\n            }\n        ;\n        ;\n            new j(\"/ajax/photos/snowlift/init.php\").setAllowCrossPageTransition(true).setMethod(\"GET\").setReadOnly(true).send();\n        },\n        init: function(ya, za) {\n            this.showHiRes = za.hires;\n            this.showHover = za.pivot_hover;\n            aa.setEndMetrics(za.pivot_end_metric);\n            this.showEndPivot = za.pivot_end;\n            this.fullscreen = ((za.hires && r.isSupported()));\n            this.showOGVideos = za.og_videos;\n            this.stageMax = ((this.showHiRes ? xa.STAGE_HIRES_MAX : xa.STAGE_NORMAL_MAX));\n            var ab = ra(\"fbPhotoSnowlift\");\n            if (!ab) {\n                ab = o.appendContent(JSBNG__document.body, ya)[0];\n                this.initialLoad = false;\n            }\n        ;\n        ;\n            if (((this.root == ab))) {\n                return;\n            }\n        ;\n        ;\n            this.initializeNodes(ab);\n            ba.init(this.sideAdUnit, this, za);\n            if (!this.subscription) {\n                v.registerHandler(this.handleNavigateAway.bind(this));\n                this.subscription = h.subscribe(\"PhotoSnowlift.GO\", function(bb, cb) {\n                    this.openExplicitly = true;\n                    ((this.loading && m.removeClass(this.loading, \"loading\")));\n                    this.open(cb);\n                }.bind(this));\n            }\n        ;\n        ;\n            this.transitionHandlerRegistered = false;\n            this.returningToStart = false;\n            x.registerHandler(this.openHandler.bind(this));\n            this.openHandlerRegistered = true;\n            h.subscribe(\"PhotoTagApproval.HILITE_TAG\", this.JSBNG__onHiliteTag.bind(this));\n            h.subscribe(\"PhotoTagApproval.UPDATE_TAG_BOX\", this.JSBNG__onUpdateTagBox.bind(this));\n            if (this.fullscreen) {\n                r.subscribe(\"changed\", this.JSBNG__onFullScreenChange.bind(this));\n            }\n        ;\n        ;\n        },\n        JSBNG__onFullScreenChange: function() {\n            if (r.isFullScreen()) {\n                if (!m.hasClass(this.root, \"fbPhotoSnowliftEditMode\")) {\n                    this.collapseRHC();\n                }\n            ;\n            ;\n                var ya = this.stream.getCurrentImageData();\n                if (((((((ya && ya.url)) && ((this.image.src !== ya.url)))) && this.shouldShowHiRes(ya)))) {\n                    this.switchImage(ya.url);\n                }\n            ;\n            ;\n                this.adjustForResize();\n            }\n             else this.uncollapseRHC();\n        ;\n        ;\n            ia.hide();\n        },\n        initializeNodes: function(ya) {\n            this.root = ya;\n            this.container = o.JSBNG__find(ya, \"div.fbPhotoSnowliftContainer\");\n            g.instrument(this.container, \"snowlift\");\n            this.snowliftPopup = o.JSBNG__find(this.container, \"div.fbPhotoSnowliftPopup\");\n            this.rhc = o.JSBNG__find(this.snowliftPopup, \"div.rhc\");\n            this.rhcHeader = o.JSBNG__find(this.rhc, \"div.rhcHeader\");\n            this.rhcFooter = o.JSBNG__find(this.rhc, \"div.rhcFooter\");\n            this.ufiForm = o.JSBNG__find(this.rhc, \"form.fbPhotosSnowliftFeedbackForm\");\n            this.ufiInputContainer = na(\"fbPhotoSnowliftFeedbackInput\");\n            this.scroller = o.JSBNG__find(this.ufiForm, \"div.rhcScroller\");\n            this.scrollerBody = o.JSBNG__find(this.scroller, \"div.uiScrollableAreaBody\");\n            this.stageWrapper = o.JSBNG__find(this.snowliftPopup, \"div.stageWrapper\");\n            this.overlay = o.JSBNG__find(this.snowliftPopup, \"div.snowliftOverlay\");\n            this.errorBox = o.JSBNG__find(this.stageWrapper, \"div.stageError\");\n            this.image = o.JSBNG__find(this.stageWrapper, \"img.spotlight\");\n            this.stage = o.JSBNG__find(this.stageWrapper, \"div.stage\");\n            this.videoStage = o.JSBNG__find(this.stageWrapper, \"div.videoStage\");\n            this.prevPager = o.JSBNG__find(this.snowliftPopup, \"a.snowliftPager.prev\");\n            g.instrument(this.prevPager, \"prev_pager\");\n            this.nextPager = o.JSBNG__find(this.snowliftPopup, \"a.snowliftPager.next\");\n            g.instrument(this.nextPager, \"next_pager\");\n            this.stageActions = o.JSBNG__find(ya, \"div.stageActions\");\n            this.buttonActions = o.JSBNG__find(this.stageActions, \"div.fbPhotosPhotoButtons\");\n            this.sideAdUnit = o.JSBNG__find(ya, \".-cx-PRIVATE-snowliftAds__root\");\n            m.conditionClass(this.root, \"fullScreenAvailable\", this.fullscreen);\n        },\n        initializeScroller: function() {\n            this.initializeScroller = bagofholding;\n            this.scrollableArea = ga.fromNative(this.scroller, {\n                fade: true,\n                persistent: true\n            });\n            var ya = function(JSBNG__event) {\n                var za = wa(JSBNG__event).getTarget();\n                if (o.contains(this.ufiInputContainer, za)) {\n                    var ab = p.getInstance(za);\n                    if (ab) {\n                        this.scrollableArea.scrollToBottom();\n                        var bb = ab.subscribe(\"resize\", function() {\n                            var db = this.scrollableArea.isScrolledToBottom();\n                            this.adjustScroller();\n                            ((db && this.scrollableArea.scrollToBottom()));\n                        }.bind(this)), cb = JSBNG__Event.listen(za, \"JSBNG__blur\", function() {\n                            ab.unsubscribe(bb);\n                            cb.remove();\n                        });\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            }.bind(this);\n            h.subscribe(\"ufi/comment\", function(za, ab) {\n                if (((this.ufiForm === ab.form))) {\n                    this.adjustScrollerIfNecessary();\n                    this.scrollableArea.scrollToBottom();\n                }\n            ;\n            ;\n            }.bind(this));\n            JSBNG__Event.listen(this.rhc, \"click\", function(JSBNG__event) {\n                var za = JSBNG__event.getTarget();\n                if (((((y.byTag(za, \"a\") || y.byTag(za, \"button\"))) || o.isNodeOfType(za, \"input\")))) {\n                    this.adjustScrollerIfNecessary();\n                }\n            ;\n            ;\n            }.bind(this));\n            h.subscribe(\"reflow\", function() {\n                if (this.isOpen) {\n                    this.adjustScroller();\n                }\n            ;\n            ;\n            }.bind(this));\n            h.subscribe([\"reflow\",\"CommentUFI.Pager\",], function() {\n                if (this.isOpen) {\n                    this.adjustScroller();\n                }\n            ;\n            ;\n            }.bind(this));\n            if (this.ufiForm.JSBNG__attachEvent) {\n                this.ufiForm.JSBNG__attachEvent(\"JSBNG__onfocusin\", ya);\n            }\n             else this.ufiForm.JSBNG__addEventListener(\"JSBNG__focus\", ya, true);\n        ;\n        ;\n        },\n        openHandler: function(ya) {\n            if (((((((((((this.isOpen || ((ya.getPath() != \"/photo.php\")))) || this.returningToStart)) || ya.getQueryData().closeTheater)) || ya.getQueryData().permPage)) || ya.getQueryData().makeprofile))) {\n                this.openHandlerRegistered = false;\n                return false;\n            }\n        ;\n        ;\n            this.open(ya);\n            this._uriStack.push(ka(ya).getQualifiedURI().toString());\n            x.transitionComplete();\n            return true;\n        },\n        getImageSrc: function(ya) {\n            if (ya.smallsrc) {\n                if (!ya.size) {\n                    return ya.smallsrc;\n                }\n            ;\n            ;\n                var za = ma.deserialize(ya.size), ab = this.getStageSize(za);\n                if (((((ab.x <= xa.STAGE_NORMAL_MAX.x)) && ((ab.y <= xa.STAGE_NORMAL_MAX.y))))) {\n                    return ya.smallsrc;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            return ya.src;\n        },\n        open: function(ya) {\n            var za = ka(ya).getQueryData(), ab = this.getImageSrc(za);\n            if (ab) {\n                delete za.src;\n                delete za.smallsrc;\n            }\n        ;\n        ;\n            if (this.resetUriStack) {\n                this._uriStack = [];\n            }\n        ;\n        ;\n            if (!this.initialLoad) {\n                za.firstLoad = true;\n                this.initialLoad = true;\n            }\n        ;\n        ;\n            this.sessionID = JSBNG__Date.now();\n            this.loadQuery = pa(za, {\n                ssid: this.sessionID\n            });\n            this.isOpen = true;\n            this.pagersShown = false;\n            this.refreshOnClose = false;\n            this.hilitedTag = null;\n            this.loadingStates = {\n                image: false,\n                html: false\n            };\n            this.replaceUrl = false;\n            this.stream = new ca();\n            this.stream.init(z.VIEWER_SNOWLIFT, \"PhotoViewerPagelet\");\n            this.fetchInitialData();\n            this.setLoadingState(xa.STATE_HTML, true);\n            this.rhcCollapsed = false;\n            this.keyHandlers = [t.registerKey(\"ESCAPE\", this.closeListener.bind(this)),];\n            k.loadModules([\"fb-photos-snowlift-css\",], this._open.bind(this, ya, ab));\n            if (this.showEndPivot) {\n                k.loadModules([\"PhotoPivot\",], function(bb) {\n                    this.pivots = bb.getInstance();\n                    if (za.relevant_count) {\n                        this.pivots.setRelevantCount(za.relevant_count);\n                    }\n                ;\n                ;\n                }.bind(this));\n            }\n        ;\n        ;\n            k.loadModules([\"PhotosButtonTooltips\",], function(bb) {\n                bb.init();\n            });\n        },\n        _open: function(ya, za) {\n            this.createLoader(za);\n            m.show(this.root);\n            (function() {\n                var cb = ma.getScrollPosition();\n                m.addClass(JSBNG__document.documentElement, \"theaterMode\");\n                var db = q.getScrollbarSize();\n                if (((db === 0))) {\n                    this.extraClass = \"zeroScrollbar\";\n                }\n                 else if (((db === 20))) {\n                    this.extraClass = \"scrollbar20\";\n                }\n                 else this.extraClass = \"defaultScrollbar\";\n                \n            ;\n            ;\n                m.addClass(JSBNG__document.body, this.extraClass);\n                q.JSBNG__scrollTo(cb, 0);\n            }).defer();\n            ((this.ua && this.ua.add_event(\"frame\")));\n            h.inform(\"layer_shown\", {\n                type: \"PhotoSnowlift\"\n            });\n            h.inform(\"PhotoSnowlift.OPEN\");\n            this.stageHandlers = [JSBNG__Event.listen(window, \"resize\", this.adjustForResize.bind(this)),JSBNG__Event.listen(this.root, \"click\", this.closeListener.bind(this)),JSBNG__Event.listen(this.stageWrapper, \"click\", this.buttonListener.bind(this)),JSBNG__Event.listen(this.stageWrapper, \"mouseleave\", function(JSBNG__event) {\n                this.unhiliteAllTags();\n                this.hidePagers();\n            }.bind(this)),JSBNG__Event.listen(this.stageWrapper, \"mousemove\", this.hilitePagerOnMouseMove.bind(this)),JSBNG__Event.listen(this.stageWrapper, \"mousemove\", this.hiliteTagsOnMouseMove.bind(this)),JSBNG__Event.listen(this.overlay, \"mouseenter\", this.unhiliteAllTags.bind(this)),];\n            this.stageHandlers.push(JSBNG__Event.listen(this.container, \"click\", (function(JSBNG__event) {\n                var cb = JSBNG__event.getTarget();\n                if (y.byClass(cb, \"rotateRight\")) {\n                    this.rotate(\"right\");\n                }\n                 else if (y.byClass(cb, \"rotateLeft\")) {\n                    this.rotate(\"left\");\n                }\n                 else if (this.fullscreen) {\n                    if (y.byClass(cb, \"fbPhotoSnowliftFullScreen\")) {\n                        this.toggleFullScreen();\n                    }\n                     else if (y.byClass(cb, \"fbPhotoSnowliftCollapse\")) {\n                        this.toggleCollapse();\n                    }\n                    \n                ;\n                }\n                \n                \n            ;\n            ;\n            }).bind(this)));\n            var ab = ra(\"fbPhotoSnowliftFeedback\");\n            if (ab) {\n                this.stageHandlers.push(JSBNG__Event.listen(ab, \"click\", function(JSBNG__event) {\n                    if (((y.byClass(JSBNG__event.getTarget(), \"like_link\") || y.byClass(JSBNG__event.getTarget(), \"UFILikeLink\")))) {\n                        this.toggleLikeButton();\n                    }\n                ;\n                ;\n                    var cb = y.byClass(JSBNG__event.getTarget(), \"uiUfiCollapsedComment\");\n                    if (cb) {\n                        m.addClass(cb, \"uiUfiCollapsedCommentToggle\");\n                    }\n                ;\n                ;\n                }.bind(this)));\n            }\n        ;\n        ;\n            var bb = ra(\"fbPhotoSnowliftOnProfile\");\n            if (bb) {\n                this.stageHandlers.push(JSBNG__Event.listen(bb, \"click\", function(JSBNG__event) {\n                    if (y.byClass(JSBNG__event.getTarget(), \"fbPhotoRemoveFromProfileLink\")) {\n                        this.refreshOnClose = true;\n                    }\n                ;\n                ;\n                }.bind(this)));\n            }\n        ;\n        ;\n            if (this.resetUriStack) {\n                this.startingURI = ka.getMostRecentURI().addQueryData({\n                    closeTheater: 1\n                }).getUnqualifiedURI();\n            }\n        ;\n        ;\n            if (!za) {\n                this.setLoadingState(xa.STATE_IMAGE_DATA, true);\n            }\n        ;\n        ;\n            if (!this.transitionHandlerRegistered) {\n                x.registerHandler(this.transitionHandler.bind(this));\n                this.transitionHandlerRegistered = true;\n            }\n        ;\n        ;\n            aa.initLogging(aa.SNOWLIFT);\n            if (this.pivots) {\n                aa.setRelevantCount(this.pivots.relevantCount);\n            }\n        ;\n        ;\n            if (((la.firefox() < 13))) {\n                this.turnFlashAutoplayOff.defer();\n            }\n        ;\n        ;\n            (function() {\n                this.root.JSBNG__focus();\n            }).bind(this).defer();\n        },\n        toggleFullScreen: function() {\n            var ya = r.toggleFullScreen(JSBNG__document.documentElement);\n            if (ya) {\n                var za = this.stream.getCurrentImageData();\n                if (((((((za && za.url)) && ((this.image.src !== za.url)))) && this.shouldShowHiRes(za)))) {\n                    (new JSBNG__Image()).src = za.url;\n                }\n            ;\n            ;\n                aa.logEnterFullScreen(this.stream.getCursor());\n            }\n        ;\n        ;\n        },\n        getStream: function() {\n            return this.stream;\n        },\n        fetchInitialData: function() {\n            ((this.ua && this.ua.add_event(\"init_data\")));\n            this.stream.waitForInitData();\n            ja.loadFromEndpoint(\"PhotoViewerInitPagelet\", null, this.loadQuery, {\n                usePipe: true,\n                jsNonblock: true,\n                crossPage: true\n            });\n        },\n        turnFlashAutoplayOff: function() {\n            o.scry(JSBNG__document, \"div.swfObject\").forEach(function(ya) {\n                var za = ya.getAttribute(\"data-swfid\");\n                if (((za && window[za]))) {\n                    var ab = window[za];\n                    ab.addParam(\"autostart\", \"false\");\n                    ab.addParam(\"autoplay\", \"false\");\n                    ab.addParam(\"play\", \"false\");\n                    ab.addVariable(\"video_autoplay\", \"0\");\n                    ab.addVariable(\"autoplay\", \"0\");\n                    ab.addVariable(\"play\", \"0\");\n                    var bb = ka(ab.getAttribute(\"swf\"));\n                    bb.addQueryData({\n                        autoplay: \"0\"\n                    });\n                    bb.setPath(bb.getPath().replace(\"autoplay=1\", \"autoplay=0\"));\n                    ab.setAttribute(\"swf\", bb.toString());\n                    ab.write(ya);\n                }\n            ;\n            ;\n            });\n        },\n        toggleCollapse: function() {\n            if (this.rhcCollapsed) {\n                this.uncollapseRHC();\n            }\n             else this.collapseRHC();\n        ;\n        ;\n        },\n        collapseRHC: function() {\n            this.rhcCollapsed = true;\n            m.addClass(this.root, \"collapseRHC\");\n            this.adjustForResize();\n        },\n        uncollapseRHC: function() {\n            this.rhcCollapsed = false;\n            m.removeClass(this.root, \"collapseRHC\");\n            this.adjustForResize();\n        },\n        closeHandler: function() {\n            if (!this.isOpen) {\n                return;\n            }\n        ;\n        ;\n            if (((ka.getMostRecentURI().addQueryData({\n                closeTheater: 1\n            }).getUnqualifiedURI().toString() == this.startingURI.toString()))) {\n                this.close();\n                return;\n            }\n        ;\n        ;\n            this.close();\n            this.returnToStartingURI(this.refreshOnClose);\n        },\n        returnToStartingURI: function(ya, za) {\n            if (!ya) {\n                if (za) {\n                    this.squashNextTransition(sa.curry(za));\n                }\n                 else this.squashNextTransition();\n            ;\n            }\n        ;\n        ;\n            this.returningToStart = true;\n            var ab = h.subscribe(\"page_transition\", function() {\n                this.returningToStart = false;\n                ab.unsubscribe();\n            }), bb = ((ya || isNaN(la.JSBNG__opera()))), cb = this._uriStack.length;\n            if (((bb && ((cb < window.JSBNG__history.length))))) {\n                window.JSBNG__history.go(-cb);\n            }\n             else {\n                var db = this.startingURI, eb = new ka(db).removeQueryData(\"closeTheater\");\n                if (((((db.getQueryData().sk == \"approve\")) && ((db.getPath() == \"/profile.php\"))))) {\n                    eb.removeQueryData(\"highlight\");\n                    eb.removeQueryData(\"notif_t\");\n                }\n            ;\n            ;\n                sa(eb);\n            }\n        ;\n        ;\n        },\n        squashNextTransition: function(ya) {\n            this.squashNext = true;\n            x.registerHandler(function za() {\n                if (this.squashNext) {\n                    this.squashNext = false;\n                    if (ya) {\n                        ya.defer();\n                    }\n                ;\n                ;\n                    x.transitionComplete();\n                    return true;\n                }\n            ;\n            ;\n                return false;\n            }.bind(this), 7);\n        },\n        handleNavigateAway: function(ya) {\n            var za = oa(x._most_recent_uri.getQualifiedURI(), ya.getAttribute(\"href\"));\n            if (((((((this.isOpen && ((za instanceof ka)))) && ((za.getUnqualifiedURI().toString() != this.startingURI.toString())))) && ((za.getPath() != \"/photo.php\"))))) {\n                if (!this.closingAction) {\n                    this.closingAction = aa.NAVIGATE;\n                }\n            ;\n            ;\n                this.close();\n                this.returnToStartingURI(false, za);\n                return false;\n            }\n        ;\n        ;\n            return true;\n        },\n        closeListener: function(JSBNG__event) {\n            if (((this.isOpen && !n.getCurrent()))) {\n                if (((JSBNG__Event.getKeyCode(JSBNG__event) == u.ESC))) {\n                    if (((!m.hasClass(this.root, \"taggingMode\") && !m.hasClass(this.root, \"fbPhotoSnowliftEditMode\")))) {\n                        this.closingAction = aa.ESC;\n                        JSBNG__Event.kill(JSBNG__event);\n                        this.closeHandler();\n                    }\n                ;\n                ;\n                    return;\n                }\n            ;\n            ;\n                var ya = JSBNG__event.getTarget(), za = y.byClass(ya, \"closeTheater\"), ab = ((((((za || ((ya == this.root)))) || ((ya == o.JSBNG__find(this.root, \"div.fbPhotoSnowliftOuter\"))))) || ((ya == o.JSBNG__find(this.root, \"div.fbPhotoSnowliftInner\")))));\n                if (ab) {\n                    if (r.isFullScreen()) {\n                        if (za) {\n                            r.toggleFullScreen();\n                        }\n                    ;\n                    ;\n                        return;\n                    }\n                ;\n                ;\n                    if (za) {\n                        this.closingAction = aa.X;\n                    }\n                     else this.closingAction = aa.OUTSIDE;\n                ;\n                ;\n                    JSBNG__Event.kill(JSBNG__event);\n                    this.closeHandler();\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        close: function() {\n            if (!this.isOpen) {\n                return;\n            }\n        ;\n        ;\n            if (this.fullscreen) {\n                r.disableFullScreen();\n            }\n        ;\n        ;\n            va(\"snowlift\", null, null, \"FORCE\").set_namespace(\"snowlift\").set_ua_id(\"close\");\n            m.hide(this.root);\n            this.openExplicitly = false;\n            this.closeCleanup.bind(this).defer();\n        },\n        closeCleanup: function() {\n            var ya = ma.getScrollPosition();\n            m.removeClass(JSBNG__document.documentElement, \"theaterMode\");\n            m.removeClass(JSBNG__document.body, this.extraClass);\n            q.JSBNG__scrollTo(ya, 0);\n            m.removeClass(this.root, \"dataLoaded\");\n            this.keyHandlers.forEach(function(ab) {\n                ab.remove();\n            });\n            this.keyHandlers = null;\n            aa.logPhotoViews(this.closingAction);\n            this.destroy();\n            m.hide(this.errorBox);\n            m.hide(this.image);\n            this.currentImageSize = null;\n            this.thumbSrc = null;\n            this.shouldStretch = false;\n            this.resetUriStack = true;\n            m.removeClass(this.stageWrapper, \"showVideo\");\n            o.empty(this.videoStage);\n            this.uncollapseRHC();\n            this.currentMinSize = null;\n            this.setStagePagersState(\"reset\");\n            this.recacheData();\n            o.empty(this.sideAdUnit);\n            this.stream.destroy();\n            var za = ((this.closingAction === aa.NAVIGATE));\n            this.closingAction = null;\n            if (!this.openHandlerRegistered) {\n                x.registerHandler(this.openHandler.bind(this));\n                this.openHandlerRegistered = true;\n            }\n        ;\n        ;\n            h.inform(\"layer_hidden\", {\n                type: \"PhotoSnowlift\"\n            });\n            h.inform(\"PhotoSnowlift.CLOSE\", za);\n            this.root.setAttribute(\"aria-busy\", \"true\");\n            this.isOpen = false;\n        },\n        createLoader: function(ya) {\n            if (((this.currentImageSize === null))) {\n                this.adjustStageSize(xa.STAGE_MIN);\n            }\n             else {\n                var za = this.getStageSize(this.currentImageSize);\n                za = new ma(Math.max(za.x, xa.STAGE_MIN.x), Math.max(za.y, xa.STAGE_MIN.y));\n                var ab = this.getImageSizeInStage(this.currentImageSize, za);\n                if (((this.thumbSrc === null))) {\n                    this.adjustStageSize(ab);\n                }\n                 else this.useImage(o.create(\"img\", {\n                    className: \"spotlight\",\n                    alt: \"\",\n                    src: this.thumbSrc,\n                    style: {\n                        width: ((ab.x + \"px\")),\n                        height: ((ab.y + \"px\"))\n                    }\n                }), ab, false);\n            ;\n            ;\n            }\n        ;\n        ;\n            this.setLoadingState(this.STATE_IMAGE_PIXELS, true);\n            if (ya) {\n                (function() {\n                    var bb = new JSBNG__Image();\n                    bb.JSBNG__onload = a.async_callback(function() {\n                        if (((!this.isOpen || ((this.pendingImageUrl != ya))))) {\n                            return;\n                        }\n                    ;\n                    ;\n                        if (((!this.stream || !this.stream.errorInCurrent()))) {\n                            this.switchImage(ya, this.currentImageSize);\n                            ((this.ua && this.ua.add_event(\"image\")));\n                            this.setLoadingState(xa.STATE_IMAGE_DATA, false);\n                        }\n                    ;\n                    ;\n                    }.bind(this), \"photo_theater\");\n                    bb.src = this.pendingImageUrl = ya;\n                }).bind(this).defer();\n            }\n        ;\n        ;\n            m.hide(this.stageActions);\n            this.setStagePagersState(\"disabled\");\n        },\n        initDataFetched: function(ya) {\n            aa.setPhotoSet(this.stream.getPhotoSet());\n            aa.setLogFbids(ya.logids);\n            var za = this.stream.getCurrentImageData();\n            aa.addPhotoView(za.info, this.shouldShowHiRes(za), ((this.fullscreen && r.isFullScreen())));\n            if (!this.pageHandlers) {\n                this.pageHandlers = [JSBNG__Event.listen(this.root, \"click\", this.pageListener.bind(this)),JSBNG__Event.listen(this.root, \"mouseleave\", this.mouseLeaveListener.bind(this)),];\n                this.keyHandlers = this.keyHandlers.concat([t.registerKey(\"LEFT\", this.pageListener.bind(this)),t.registerKey(\"RIGHT\", this.pageListener.bind(this)),t.registerKey(\"L\", this.likePhotoWithKey.bind(this), function(JSBNG__event, ab) {\n                    JSBNG__event = wa(JSBNG__event);\n                    return ((((((ab == \"JSBNG__onkeyup\")) && t.filterEventTargets(JSBNG__event, ab))) && t.filterEventModifiers(JSBNG__event, ab)));\n                }),]);\n            }\n        ;\n        ;\n            m.show(this.stageActions);\n            this.root.setAttribute(\"aria-busy\", \"false\");\n            this.isLoggedInViewer = ya.loggedin;\n            this.disableAds = ((!this.isLoggedInViewer || ya.fromad));\n            this.loadAds();\n        },\n        adjustScrollerIfNecessary: function() {\n            JSBNG__clearTimeout(this.scrollerTimeout);\n            this.scrollerTimeout = this.adjustScroller.bind(this).defer();\n        },\n        adjustScroller: function() {\n            JSBNG__clearTimeout(this.scrollerTimeout);\n            this.initializeScroller();\n            this.scrollableArea.resize();\n            var ya = ma.getElementDimensions(this.rhc), za = ya.y;\n            za -= ma.getElementDimensions(this.rhcHeader).y;\n            za -= ma.getElementDimensions(this.ufiInputContainer).y;\n            var ab = ma.getElementDimensions(this.scrollerBody).y;\n            if (((ab >= za))) {\n                ha.set(this.scroller, \"height\", ((za + \"px\")));\n                m.addClass(this.rhc, \"pinnedUfi\");\n                za = 0;\n            }\n             else {\n                ha.set(this.scroller, \"height\", \"auto\");\n                m.removeClass(this.rhc, \"pinnedUfi\");\n                za -= ab;\n            }\n        ;\n        ;\n            var bb = ma.getElementDimensions(this.ufiInputContainer).y;\n            ha.set(this.ufiForm, \"padding-bottom\", ((bb + \"px\")));\n            ba.resize(new ma(ya.x, za));\n            this.scrollableArea.adjustGripper();\n        },\n        adjustForResize: function() {\n            this.currentMinSize = null;\n            this.adjustStageSize();\n            this.adjustForNewData();\n        },\n        shouldShowHiRes: function(ya) {\n            if (((((!this.showHiRes || !ya)) || !ya.smallurl))) {\n                return false;\n            }\n        ;\n        ;\n            var za = this.getStageSize(ya.dimensions), ab = this.getImageSizeInStage(ya.dimensions, za);\n            return ((((ab.x > xa.STAGE_NORMAL_MAX.x)) || ((ab.y > xa.STAGE_NORMAL_MAX.y))));\n        },\n        getImageURL: function(ya) {\n            if (ya.video) {\n                return null;\n            }\n             else if (((ya.smallurl && !this.shouldShowHiRes(ya)))) {\n                return ya.smallurl;\n            }\n            \n        ;\n        ;\n            return ya.url;\n        },\n        getImageDimensions: function(ya) {\n            if (((ya.smalldims && ((!this.shouldShowHiRes(ya) || ((this.image.src === ya.smallurl))))))) {\n                return ya.smalldims;\n            }\n        ;\n        ;\n            return ya.dimensions;\n        },\n        getStageSize: function(ya, za) {\n            var ab = ma.getViewportDimensions(), bb = new ma(ya.x, ya.y);\n            if (za) {\n                bb = new ma(Math.max(ya.x, za.x), Math.max(ya.y, za.y));\n            }\n        ;\n        ;\n            var cb, db;\n            if (((this.fullscreen && r.isFullScreen()))) {\n                return new ma(((this.rhcCollapsed ? JSBNG__screen.width : ((JSBNG__screen.width - xa.SIDEBAR_SIZE_MAX)))), ((JSBNG__screen.height - ((xa.FULL_SCREEN_PADDING * 2)))));\n            }\n             else {\n                cb = Math.min(bb.x, this.stageMax.x, ((((ab.x - xa.SIDEBAR_SIZE_MAX)) - xa.STAGE_CHROME.x)));\n                db = Math.min(bb.y, this.stageMax.y, ((ab.y - xa.STAGE_CHROME.y)));\n            }\n        ;\n        ;\n            if (((((cb === 0)) && ((db === 0))))) {\n                return new ma(0, 0);\n            }\n        ;\n        ;\n            var eb = ((cb / db)), fb = ((bb.x / bb.y));\n            if (((eb < fb))) {\n                return new ma(cb, Math.ceil(((cb / fb))));\n            }\n        ;\n        ;\n            return new ma(Math.ceil(((db * fb))), db);\n        },\n        getImageSizeInStage: function(ya, za) {\n            var ab = ya.x, bb = ya.y;\n            if (((((ab >= za.x)) || ((bb >= za.y))))) {\n                var cb = ((za.x / za.y)), db = ((ab / bb));\n                if (((cb < db))) {\n                    ab = za.x;\n                    bb = Math.ceil(((ab / db)));\n                }\n                 else if (((cb > db))) {\n                    bb = za.y;\n                    ab = Math.ceil(((bb * db)));\n                }\n                 else {\n                    ab = za.x;\n                    bb = za.y;\n                }\n                \n            ;\n            ;\n            }\n        ;\n        ;\n            return new ma(ab, bb);\n        },\n        adjustStageSize: function(ya) {\n            var za = this.currentImageSize;\n            if (ya) {\n                za = ya;\n            }\n             else {\n                var ab = ((this.stream && this.stream.getCurrentImageData()));\n                if (ab) {\n                    za = this.getImageDimensions(ab);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            if (!za) {\n                return;\n            }\n        ;\n        ;\n            this.currentImageSize = za;\n            var bb = 0;\n            if (((((((((this.shouldStretch && !this.getVideoOnStage())) && ((za.x > za.y)))) && ((za.x <= xa.TIMELINE_STRETCH_WIDTH)))) && ((za.x >= xa.TIMELINE_STRETCH_MIN))))) {\n                za.y = Math.round(((((za.y * xa.TIMELINE_STRETCH_WIDTH)) / za.x)));\n                za.x = xa.TIMELINE_STRETCH_WIDTH;\n            }\n             else if (this.getVideoOnStage()) {\n                bb = ((xa.VIDEO_BOTTOM_BAR_SPACE * 2));\n                za.y += bb;\n            }\n            \n        ;\n        ;\n            var cb = this.getStageSize(za, this.currentMinSize);\n            if (!this.currentMinSize) {\n                this.currentMinSize = new ma(0, 0);\n            }\n        ;\n        ;\n            this.currentMinSize = new ma(Math.max(cb.x, xa.STAGE_MIN.x, this.currentMinSize.x), Math.max(cb.y, xa.STAGE_MIN.y, this.currentMinSize.y));\n            var db = this.getImageSizeInStage(za, this.currentMinSize), eb = ((this.currentMinSize.x - db.x)), fb = ((this.currentMinSize.y - db.y));\n            if (((((eb > 0)) && ((eb < xa.PADDING_MIN))))) {\n                this.currentMinSize.x -= eb;\n            }\n             else if (((((fb > 0)) && ((fb < xa.PADDING_MIN))))) {\n                this.currentMinSize.y -= fb;\n            }\n            \n        ;\n        ;\n            var gb = ((this.currentMinSize.x + xa.SIDEBAR_SIZE_MAX));\n            if (this.rhcCollapsed) {\n                gb = this.currentMinSize.x;\n            }\n        ;\n        ;\n            this.snowliftPopup.style.cssText = ((((((((((\"width:\" + gb)) + \"px;\")) + \"height:\")) + this.currentMinSize.y)) + \"px;\"));\n            var hb = ((((this.currentMinSize.y - bb)) + \"px\"));\n            if (((la.firefox() || ((la.ie() < 8))))) {\n                var ib = ha.get(this.stageWrapper, \"font-size\");\n                if (((la.ie() && ((ib.indexOf(\"px\") < 0))))) {\n                    var jb = o.create(\"div\");\n                    jb.style.fontSize = ib;\n                    jb.style.height = \"1em\";\n                    ib = jb.style.pixelHeight;\n                }\n            ;\n            ;\n                hb = ((((((this.currentMinSize.y - bb)) / parseFloat(ib))) + \"em\"));\n            }\n        ;\n        ;\n            this.stageWrapper.style.cssText = ((((((((((\"width:\" + this.currentMinSize.x)) + \"px;\")) + \"line-height:\")) + hb)) + \";\"));\n            if (((la.ie() < 8))) {\n                ha.set(this.root, \"height\", ((ma.getViewportDimensions().y + \"px\")));\n                ha.set(this.container, \"min-height\", ((((this.currentMinSize.y + xa.STAGE_CHROME.y)) + \"px\")));\n            }\n        ;\n        ;\n            this.image.style.cssText = ((((((((((\"width:\" + db.x)) + \"px;\")) + \"height:\")) + db.y)) + \"px;\"));\n            this.adjustScrollerIfNecessary();\n        },\n        adjustForNewData: function() {\n            if (!this.image) {\n                return;\n            }\n        ;\n        ;\n            var ya = o.scry(this.stage, \"div.tagsWrapper\")[0], za = ma.getElementDimensions(this.image);\n            if (ya) {\n                ha.set(ya, \"width\", ((za.x + \"px\")));\n                ha.set(ya, \"height\", ((za.y + \"px\")));\n                if (((la.ie() <= 7))) {\n                    var ab = o.scry(this.root, \"div.tagContainer\")[0];\n                    if (ab) {\n                        m.conditionClass(ya, \"ie7VerticalFix\", ((ma.getElementDimensions(ab).y > za.y)));\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        setLoadingState: function(ya, za) {\n            switch (ya) {\n              case xa.STATE_IMAGE_PIXELS:\n                m.conditionClass(this.root, \"imagePixelsLoading\", za);\n                break;\n              case xa.STATE_IMAGE_DATA:\n                this.loadingStates[ya] = za;\n                m.conditionClass(this.root, \"imageLoading\", za);\n                break;\n              case xa.STATE_HTML:\n                this.loadingStates[ya] = za;\n                m.conditionClass(this.root, \"dataLoading\", za);\n                this.rhc.setAttribute(\"aria-busy\", ((za ? \"true\" : \"false\")));\n                break;\n            };\n        ;\n        },\n        destroy: function() {\n            this.stageHandlers.forEach(function(ya) {\n                ya.remove();\n            });\n            if (this.pageHandlers) {\n                this.pageHandlers.forEach(function(ya) {\n                    ya.remove();\n                });\n                this.pageHandlers = null;\n            }\n        ;\n        ;\n        },\n        checkState: function(ya) {\n            if (((((ya != xa.STATE_ERROR)) && !this.loadingStates[ya]))) {\n                return;\n            }\n        ;\n        ;\n            switch (ya) {\n              case xa.STATE_IMAGE_DATA:\n                var za = this.stream.getCurrentImageData();\n                if (za) {\n                    var ab = this.getImageURL(za);\n                    if (ab) {\n                        this.switchImage(ab, null, true);\n                    }\n                     else if (za.video) {\n                        this.switchVideo(za.video, true);\n                    }\n                    \n                ;\n                ;\n                    this.setLoadingState(ya, false);\n                }\n            ;\n            ;\n                break;\n              case xa.STATE_HTML:\n                if (this.stream.getCurrentHtml()) {\n                    this.swapData();\n                    this.setLoadingState(ya, false);\n                }\n            ;\n            ;\n                break;\n              default:\n                if (this.stream.errorInCurrent()) {\n                    m.hide(this.image);\n                    m.show(this.errorBox);\n                }\n            ;\n            ;\n                break;\n            };\n        ;\n        },\n        buttonListener: function(JSBNG__event) {\n            var ya = JSBNG__event.getTarget(), za = JSBNG__Date.now();\n            if (y.byClass(ya, \"fbPhotoTagApprovalBox\")) {\n                return;\n            }\n        ;\n        ;\n            if (((((za - this.lastPage)) < 350))) {\n                return;\n            }\n        ;\n        ;\n            if (y.byClass(ya, \"fbPhotosPhotoLike\")) {\n                this.likePhoto();\n            }\n             else if (y.byClass(ya, \"tagApproveIgnore\")) {\n                this.updateTagBox(JSBNG__event, ya);\n            }\n            \n        ;\n        ;\n        },\n        likePhoto: function() {\n            aa.addButtonLike();\n            var ya = na(\"fbPhotoSnowliftFeedback\"), za = o.scry(ya, \"button.like_link\")[0];\n            if (!za) {\n                za = o.scry(ya, \"a.UFILikeLink\")[0];\n            }\n        ;\n        ;\n            za.click();\n        },\n        toggleLikeButton: function() {\n            var ya = o.scry(this.buttonActions, \"a.fbPhotosPhotoLike\")[0];\n            if (ya) {\n                m.toggleClass(ya, \"viewerLikesThis\");\n                m.removeClass(ya, \"viewerAlreadyLikedThis\");\n            }\n        ;\n        ;\n        },\n        likePhotoWithKey: function() {\n            if (this.isShowingLikePhotoConfirmation) {\n                return;\n            }\n        ;\n        ;\n            if (this.skipLikePhotoConfirmation) {\n                this.likePhoto();\n            }\n             else i.send(new j(\"/photos/confirm_like.php\"), function(ya) {\n                this.isShowingLikePhotoConfirmation = true;\n                ya.subscribe(\"JSBNG__confirm\", this.JSBNG__onCloseLikePhotoConfirmDialog.bind(this));\n                ya.subscribe(\"cancel\", this.JSBNG__onCloseLikePhotoConfirmDialog.bind(this));\n            }.bind(this));\n        ;\n        ;\n            return false;\n        },\n        likePhotoSkipConfirmation: function(ya) {\n            this.skipLikePhotoConfirmation = ya;\n            this.likePhoto();\n        },\n        JSBNG__onCloseLikePhotoConfirmDialog: function() {\n            this.isShowingLikePhotoConfirmation = false;\n        },\n        updateTagBox: function(ya, za) {\n            this.unhiliteAllTags();\n            var ab = ra(ya);\n            if (!ab) {\n                return;\n            }\n        ;\n        ;\n            m.addClass(ab, \"tagBox\");\n            m.addClass(ab, \"tagBoxPendingResponse\");\n            m.removeClass(ab, \"tagBoxPending\");\n            m.hide(o.JSBNG__find(ab, \"span.tagForm\"));\n            if (za) {\n                m.show(o.JSBNG__find(ab, \"span.tagApproved\"));\n            }\n             else m.show(o.JSBNG__find(ab, \"span.tagIgnored\"));\n        ;\n        ;\n        },\n        rotate: function(ya) {\n            var za = this.stream.getCursor();\n            if (this.getVideoOnStage()) {\n                var ab = ((((ya == \"left\")) ? 270 : 90));\n                k.loadModules([\"VideoRotate\",], function(cb) {\n                    new cb(za).motionRotate(ab);\n                });\n                return;\n            }\n        ;\n        ;\n            var bb = pa({\n                fbid: za,\n                cs_ver: z.VIEWER_SNOWLIFT\n            }, this.stream.getPhotoSetQuery());\n            bb[ya] = 1;\n            this.setLoadingState(xa.STATE_IMAGE_DATA, true);\n            this.setLoadingState(this.STATE_IMAGE_PIXELS, true);\n            m.hide(this.image);\n            new j(\"/ajax/photos/photo/rotate/\").setAllowCrossPageTransition(true).setData(bb).setErrorHandler(this.rotationError.bind(this, za)).setFinallyHandler(this.rotationComplete.bind(this, za)).setMethod(\"POST\").setReadOnly(false).send();\n        },\n        rotationComplete: function(ya, za) {\n            if (((ya == this.stream.getCursor()))) {\n                this.setLoadingState(xa.STATE_IMAGE_DATA, false);\n                this.switchImage(this.getImageURL(this.stream.getCurrentImageData()));\n                this.swapData();\n            }\n        ;\n        ;\n        },\n        rotationError: function(ya, za) {\n            if (((ya == this.stream.getCursor()))) {\n                this.setLoadingState(xa.STATE_IMAGE_DATA, false);\n                this.switchImage(this.getImageURL(this.stream.getCurrentImageData()));\n                k.loadModules([\"AsyncResponse\",], function(ab) {\n                    ab.defaultErrorHandler(za);\n                });\n            }\n        ;\n        ;\n        },\n        saveTagsFromPayload: function(ya) {\n            this.storeFromData(ya);\n            if (((((\"data\" in ya)) && ((this.stream.getCursor() in ya.data))))) {\n                this.swapData();\n            }\n        ;\n        ;\n        },\n        saveEdit: function() {\n            if (!m.hasClass(this.root, \"fbPhotoSnowliftEditMode\")) {\n                return;\n            }\n        ;\n        ;\n            k.loadModules([\"PhotoInlineEditor\",\"Form\",], function(ya, za) {\n                var ab = ya.getInstance(this.getViewerConst());\n                ((ab && za.bootstrap(ab.getForm().controller)));\n            }.bind(this));\n        },\n        mouseLeaveListener: function(JSBNG__event) {\n            this.unhiliteAllTags();\n            this.reHilitePendingTag();\n        },\n        hilitePagerOnMouseMove: function(JSBNG__event) {\n            var ya = ma.getEventPosition(JSBNG__event), za = ma.getElementPosition(this.stage);\n            if (w.isRTL()) {\n                var ab = ma.getElementDimensions(this.stage);\n                this.stagePagerPrev = ((((ab.x - ((ya.x - za.x)))) < xa.GOPREV_AREA));\n            }\n             else this.stagePagerPrev = ((((ya.x - za.x)) < xa.GOPREV_AREA));\n        ;\n        ;\n            m.conditionClass(this.prevPager, \"hilightPager\", this.stagePagerPrev);\n            m.conditionClass(this.nextPager, \"hilightPager\", !this.stagePagerPrev);\n            var bb, cb = JSBNG__event.getTarget();\n            if (((((!y.byClass(cb, \"snowliftOverlay\") && !y.byClass(cb, \"bottomBarActions\"))) && !y.byClass(cb, \"snowliftPager\")))) {\n                bb = xa.PAGER_FADE;\n            }\n        ;\n        ;\n            this.showPagers(bb);\n        },\n        showPagers: function(ya) {\n            JSBNG__clearTimeout(this.fadePagerTimer);\n            this.setStagePagersState(\"active\");\n            if (((typeof ya !== \"undefined\"))) {\n                this.fadePagerTimer = this.hidePagers.bind(this).defer(ya);\n            }\n        ;\n        ;\n        },\n        hidePagers: function() {\n            var ya = o.scry(this.getRoot(), \".fbPhotosPhotoActionsMenu\")[0];\n            if (ya) {\n                return;\n            }\n        ;\n        ;\n            JSBNG__clearTimeout(this.fadePagerTimer);\n            this.setStagePagersState(\"inactive\");\n        },\n        getTagger: function() {\n            if (!this.PhotoTagger) {\n                return null;\n            }\n        ;\n        ;\n            var ya = this.PhotoTagger.getInstance(z.VIEWER_SNOWLIFT);\n            if (((!ya || !ya.tagHoverFacebox))) {\n                return null;\n            }\n        ;\n        ;\n            return ya;\n        },\n        unhiliteAllTags: function() {\n            o.scry(this.stage, \"div.tagsWrapper div.hover\").forEach(function(za) {\n                m.removeClass(za, \"hover\");\n            });\n            this.hilitedTag = null;\n            if (!m.hasClass(this.root, \"taggingMode\")) {\n                var ya = this.getTagger();\n                if (ya) {\n                    ya.hideTagger();\n                    ya.setCurrentFacebox(null);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        switchHilitedTags: function(ya, za) {\n            if (((this.switchTimer !== null))) {\n                JSBNG__clearTimeout(this.switchTimer);\n                this.switchTimer = null;\n            }\n        ;\n        ;\n            this.unhiliteAllTags();\n            var ab = ra(ya);\n            if (ab) {\n                this.hilitedTag = ya;\n                if (((!m.hasClass(this.root, \"taggingMode\") && da.isFacebox(this.hilitedTag)))) {\n                    var bb = this.getTagger();\n                    if (bb) {\n                        m.addClass(ab, \"hover\");\n                        var cb = bb.getFacebox(ya);\n                        bb.setCurrentFacebox(cb);\n                        if (cb) {\n                            bb.addTagFromFacebox(cb);\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                }\n                 else m.addClass(ab, \"hover\");\n            ;\n            ;\n                if (((((m.hasClass(ab, \"tagBoxPending\") && !m.hasClass(ab, \"showPendingTagName\"))) && ((za === true))))) {\n                    o.scry(this.stage, \"div.tagsWrapper div.showPendingTagName\").forEach(function(db) {\n                        m.removeClass(db, \"showPendingTagName\");\n                    });\n                    m.addClass(ab, \"showPendingTagName\");\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        reHilitePendingTag: function() {\n            var ya = ra(this.hilitedTag);\n            if (((ya && m.hasClass(ya, \"showPendingTagName\")))) {\n                return;\n            }\n        ;\n        ;\n            var za = o.scry(this.stage, \"div.tagsWrapper div.showPendingTagName\")[0];\n            if (za) {\n                this.switchHilitedTags(za.id);\n            }\n        ;\n        ;\n        },\n        hiliteTagsOnMouseMove: function(JSBNG__event) {\n            if (((!this.stream.getCurrentExtraData() || this.getVideoOnStage()))) {\n                return;\n            }\n        ;\n        ;\n            if (((this.switchTimer !== null))) {\n                return;\n            }\n        ;\n        ;\n            var ya = JSBNG__event.getTarget();\n            if (((((((y.byClass(ya, \"snowliftOverlay\") || y.byClass(ya, \"fbPhotoSnowliftTagApproval\"))) || y.byClass(ya, \"tagPointer\"))) || y.byClass(ya, \"photoTagTypeahead\")))) {\n                return;\n            }\n        ;\n        ;\n            var za = y.byClass(ya, \"tagBoxPending\"), ab = false;\n            if (this.hilitedTag) {\n                var bb = ra(this.hilitedTag);\n                ab = ((bb && m.hasClass(bb, \"tagBoxPending\")));\n            }\n        ;\n        ;\n            var cb = ((((!this.hilitedTag && za)) || ((!ab && za))));\n            if (cb) {\n                this.switchHilitedTags(za.id);\n                return;\n            }\n        ;\n        ;\n            if (((za && ((za.id == this.hilitedTag))))) {\n                return;\n            }\n        ;\n        ;\n            var db = 250, eb = da.absoluteToNormalizedPosition(this.image, ma.getEventPosition(JSBNG__event));\n            if (this.currentTagHasPrecedence(eb)) {\n                return;\n            }\n        ;\n        ;\n            var fb = da.getNearestBox(this.stream.getCurrentExtraData().tagRects, eb);\n            if (!fb) {\n                if (!ab) {\n                    this.unhiliteAllTags();\n                    this.reHilitePendingTag();\n                }\n            ;\n            ;\n                return;\n            }\n        ;\n        ;\n            var gb = null;\n            if (ab) {\n                var hb = {\n                };\n                hb[this.hilitedTag] = this.stream.getCurrentExtraData().tagRects[this.hilitedTag];\n                gb = da.getNearestBox(hb, eb);\n            }\n        ;\n        ;\n            if (((((gb !== null)) && ab))) {\n                return;\n            }\n        ;\n        ;\n            if (((this.hilitedTag != fb))) {\n                if (ab) {\n                    this.switchTimer = this.switchHilitedTags.bind(this, fb).defer(db);\n                }\n                 else {\n                    if (this.showHover) {\n                        if (!this.seenTags) {\n                            this.seenTags = [];\n                        }\n                    ;\n                    ;\n                        if (!this.seenTags[fb]) {\n                            aa.addFaceTagImpression();\n                            this.seenTags[fb] = true;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    this.switchHilitedTags(fb);\n                }\n            ;\n            }\n        ;\n        ;\n        },\n        currentTagHasPrecedence: function(ya) {\n            if (!this.hilitedTag) {\n                return false;\n            }\n        ;\n        ;\n            var za = this.stream.getCurrentExtraData().tagRects[this.hilitedTag], ab = new fa(((za.t + ((za.h() / 2)))), za.r, ((za.b + ((da.isFacebox(this.hilitedTag) ? 10 : 0)))), za.l, za.domain);\n            return ab.contains(ya);\n        },\n        getVideoOnStage: function() {\n            var ya = ((this.stream && this.stream.getCurrentImageData()));\n            return ((ya && ya.video));\n        },\n        shouldPageOnAction: function(ya, za) {\n            if (((!this.isOpen || this.isShowingLikePhotoConfirmation))) {\n                return false;\n            }\n        ;\n        ;\n            var ab = ((o.isNode(za) && ((((y.byClass(za, \"snowliftPager\") || y.byClass(za, \"stagePagers\"))) || y.byClass(za, \"pivotPageColumn\"))))), bb = ((o.isNode(za) && y.byClass(za, \"stage\"))), cb = m.hasClass(za, \"faceBox\"), db = ((((((((((bb && m.hasClass(this.root, \"taggingMode\"))) || y.byClass(za, \"tagBoxPending\"))) || y.byClass(za, \"tagBoxPendingResponse\"))) || y.byClass(za, \"fbPhotoTagApprovalBox\"))) || y.byClass(za, \"tag\")));\n            if (db) {\n                return false;\n            }\n        ;\n        ;\n            return ((((((((((ya == u.LEFT)) || ((ya == u.RIGHT)))) || ((!m.hasClass(this.root, \"taggingMode\") && cb)))) || ab)) || bb));\n        },\n        pageListener: function(JSBNG__event) {\n            var ya = JSBNG__Event.getKeyCode(JSBNG__event), za = JSBNG__event.getTarget();\n            if (!this.shouldPageOnAction(ya, za)) {\n                return;\n            }\n        ;\n        ;\n            var ab = 0;\n            if (((ya == u.RIGHT))) {\n                ab = 1;\n                aa.setPagingAction(\"key_right\");\n            }\n             else if (((ya == u.LEFT))) {\n                ab = -1;\n                aa.setPagingAction(\"key_left\");\n            }\n             else if (y.byClass(za, \"next\")) {\n                ab = 1;\n                aa.setPagingAction(\"click_next\");\n            }\n             else if (y.byClass(za, \"prev\")) {\n                ab = -1;\n                aa.setPagingAction(\"click_prev\");\n            }\n             else if (!this.stagePagerPrev) {\n                ab = 1;\n                aa.setPagingAction(\"click_stage\");\n            }\n             else {\n                ab = -1;\n                aa.setPagingAction(\"click_stage_back\");\n            }\n            \n            \n            \n            \n        ;\n        ;\n            if (m.hasClass(this.root, \"fbPhotoSnowliftEditMode\")) {\n                this.warnLeavePage(ab);\n            }\n             else {\n                this.page(ab);\n                va(\"a\", za, JSBNG__event, \"FORCE\").set_namespace(\"snowlift\").set_ua_id(aa.pagingAction);\n            }\n        ;\n        ;\n        },\n        warnLeavePage: function(ya) {\n            new n().setTitle(\"Are you sure you want to leave this page?\").setBody(\"You have unsaved changes that will be lost if you leave the page.\").setButtons([{\n                JSBNG__name: \"leave_page\",\n                label: \"Leave this Page\",\n                handler: this.page.bind(this, ya)\n            },{\n                JSBNG__name: \"continue_editing\",\n                label: \"Stay on this Page\",\n                className: \"inputaux\"\n            },]).setModal(true).show();\n        },\n        page: function(ya, za) {\n            if (!this.stream.isValidMovement(ya)) {\n                this.showPagers(xa.PAGER_FADE);\n                return;\n            }\n        ;\n        ;\n            this.lastPage = JSBNG__Date.now();\n            this.unhiliteAllTags();\n            this.seenTags = [];\n            var ab = this.getVideoOnStage();\n            if (ab) {\n                this.switchVideo(ab, false);\n            }\n        ;\n        ;\n            if (((this.pivots && this.pivots.page(ya)))) {\n                return;\n            }\n        ;\n        ;\n            h.inform(\"PhotoSnowlift.PAGE\");\n            ia.hide();\n            this.recacheData();\n            this.stream.moveCursor(ya);\n            m.hide(this.image);\n            if (this.stream.errorInCurrent()) {\n                this.setLoadingState(xa.STATE_HTML, true);\n                m.show(this.errorBox);\n                return;\n            }\n        ;\n        ;\n            var bb = this.stream.getCurrentImageData();\n            if (bb) {\n                var cb = this.getImageURL(bb);\n                if (cb) {\n                    this.switchImage(cb, null, true);\n                }\n                 else if (bb.video) {\n                    this.switchVideo(bb.video, true);\n                }\n                \n            ;\n            ;\n                if (!za) {\n                    this.replaceUrl = true;\n                    sa(bb.info.permalink);\n                }\n            ;\n            ;\n                this.setLoadingState(xa.STATE_IMAGE_DATA, false);\n            }\n             else {\n                this.setLoadingState(xa.STATE_IMAGE_PIXELS, true);\n                this.setLoadingState(xa.STATE_IMAGE_DATA, true);\n            }\n        ;\n        ;\n            if (this.stream.getCurrentHtml()) {\n                this.swapData();\n            }\n             else this.setLoadingState(xa.STATE_HTML, true);\n        ;\n        ;\n            this.disableAds = !this.isLoggedInViewer;\n            this.loadAds();\n        },\n        logImpressionDetailsForPhoto: function() {\n            var ya = [].concat(o.scry(na(\"fbPhotoSnowliftTagList\"), \"input.photoImpressionDetails\"), o.scry(na(\"fbPhotoSnowliftFeedback\"), \"input.photoImpressionDetails\"));\n            if (((ya.length === 0))) {\n                return;\n            }\n        ;\n        ;\n            var za = {\n            };\n            for (var ab = 0; ((ab < ya.length)); ab++) {\n                za[ya[ab].JSBNG__name] = ya[ab].value;\n            ;\n            };\n        ;\n            if (this.getVideoOnStage()) {\n                za.width = 0;\n                za.height = 0;\n            }\n             else {\n                var bb = this.getImageDimensions(this.stream.getCurrentImageData());\n                za.width = bb.x;\n                za.height = bb.y;\n            }\n        ;\n        ;\n            aa.addDetailData(this.stream.getCursor(), za);\n            ba.setIsLogAdData(true);\n        },\n        loadAds: function() {\n            if (this.disableAds) {\n                return;\n            }\n        ;\n        ;\n            ba.loadAdsFromUserActivity();\n        },\n        transitionHandler: function(ya) {\n            if (((((((ya.getQueryData().closeTheater || ya.getQueryData().permPage)) || ya.getQueryData().makeprofile)) || this.returningToStart))) {\n                if (this.isOpen) {\n                    this.close();\n                }\n            ;\n            ;\n                this.transitionHandlerRegistered = false;\n                return false;\n            }\n        ;\n        ;\n            if (this.replaceUrl) {\n                this.replaceUrl = false;\n                this._uriStack.push(ya.getQualifiedURI().toString());\n                x.transitionComplete();\n                return true;\n            }\n        ;\n        ;\n            var za = this._uriStack.length;\n            if (((((za >= 2)) && ((this._uriStack[((za - 2))] == ya.getQualifiedURI().toString()))))) {\n                this._uriStack.pop();\n            }\n        ;\n        ;\n            var ab = this.stream.getCursorForURI(ya.getUnqualifiedURI().toString());\n            if (ab) {\n                var bb = this.stream.getRelativeMovement(ab);\n                this.page(bb, true);\n                x.transitionComplete();\n                return true;\n            }\n        ;\n        ;\n            if (this.isOpen) {\n                this.close();\n                x.transitionComplete();\n                return true;\n            }\n        ;\n        ;\n            this.transitionHandlerRegistered = false;\n            return false;\n        },\n        recacheData: function() {\n            if (!this.loadingStates.html) {\n                var ya = this.stream.getCurrentHtml();\n                for (var za in ya) {\n                    ya[za] = qa(na(za).childNodes);\n                    o.empty(na(za));\n                };\n            ;\n            }\n        ;\n        ;\n        },\n        reloadIfTimeout: function() {\n            if (!s.hasLoaded(this.image)) {\n                var ya = this.makeNewImage(this.image.src, true);\n                JSBNG__Event.listen(ya, \"load\", this.useImage.bind(this, ya, null, true));\n            }\n        ;\n        ;\n        },\n        useImage: function(ya, za, ab) {\n            if (((ab && s.hasLoaded(this.image)))) {\n                return;\n            }\n        ;\n        ;\n            o.replace(this.image, ya);\n            this.image = ya;\n            this.adjustStageSize(za);\n        },\n        makeNewImage: function(ya, za) {\n            if (this.imageLoadingTimer) {\n                JSBNG__clearTimeout(this.imageLoadingTimer);\n                this.imageLoadingTimer = null;\n            }\n             else if (!za) {\n                this.imageRefreshTimer = JSBNG__setTimeout(this.reloadIfTimeout.bind(this), xa.LOADING_TIMEOUT);\n            }\n            \n        ;\n        ;\n            var ab = o.create(\"img\", {\n                className: \"spotlight\",\n                alt: \"\"\n            });\n            ab.setAttribute(\"aria-describedby\", \"fbPhotosSnowliftCaption\");\n            ab.setAttribute(\"aria-busy\", \"true\");\n            JSBNG__Event.listen(ab, \"load\", a.async_callback(function() {\n                JSBNG__clearTimeout(this.imageRefreshTimer);\n                this.image.setAttribute(\"aria-busy\", \"false\");\n                this.setLoadingState(this.STATE_IMAGE_PIXELS, false);\n                (function() {\n                    if (this.isOpen) {\n                        this.adjustStageSize();\n                        this.adjustForNewData();\n                    }\n                ;\n                ;\n                }).bind(this).defer();\n            }.bind(this), \"photo_theater\"));\n            ab.src = ya;\n            return ab;\n        },\n        switchImage: function(ya, za, ab) {\n            m.hide(this.image);\n            m.hide(this.errorBox);\n            this.setLoadingState(this.STATE_IMAGE_PIXELS, true);\n            var bb = ((this.stream && this.stream.getCurrentImageData()));\n            if (bb) {\n                aa.addPhotoView(bb.info, this.shouldShowHiRes(bb), ((this.fullscreen && r.isFullScreen())));\n            }\n        ;\n        ;\n            this.useImage(this.makeNewImage(ya, false), za, false);\n            if (ab) {\n                this.stream.preloadImages(this.shouldShowHiRes(bb));\n            }\n        ;\n        ;\n        },\n        switchVideo: function(ya, za) {\n            var ab = ((\"swf_\" + ya));\n            if (za) {\n                m.addClass(this.stageWrapper, \"showVideo\");\n                var bb = o.create(\"div\", {\n                    className: \"videoStageContainer\"\n                });\n                o.appendContent(this.videoStage, bb);\n                bb.id = ya;\n                if (((window[ab] && !ra(ab)))) {\n                    window[ab].write(ya);\n                }\n            ;\n            ;\n                this.adjustStageSizeForVideo.bind(this, ab).defer();\n            }\n             else {\n                ((window[ab] && window[ab].addVariable(\"video_autoplay\", 0)));\n                ((this.videoLoadTimer && JSBNG__clearTimeout(this.videoLoadTimer)));\n                o.empty(this.videoStage);\n                m.removeClass(this.stageWrapper, \"showVideo\");\n            }\n        ;\n        ;\n        },\n        checkVideoStatus: function(ya) {\n            if (this.videoLoadTimer) {\n                JSBNG__clearTimeout(this.videoLoadTimer);\n            }\n        ;\n        ;\n            var za = this.getVideoOnStage();\n            if (!za) {\n                return;\n            }\n             else {\n                var ab = ((\"swf_\" + za));\n                if (((ya !== ab))) {\n                    return;\n                }\n            ;\n            ;\n                this.adjustStageSizeForVideo(ya);\n            }\n        ;\n        ;\n        },\n        adjustStageSizeForVideo: function(ya) {\n            var za = ra(ya);\n            if (!za) {\n                this.videoLoadTimer = JSBNG__setTimeout(this.checkVideoStatus.bind(this, ya), 200);\n            }\n             else this.adjustStageSize(new ma(za.width, za.height));\n        ;\n        ;\n        },\n        handleServerError: function(ya, za) {\n            o.setContent(this.errorBox, ya);\n            this.storeFromData(za);\n        },\n        swapData: function() {\n            var ya, za = this.stream.getCurrentHtml();\n            if (za) {\n                this.setLoadingState(xa.STATE_HTML, false);\n                for (var ab in za) {\n                    ya = ra(ab);\n                    ((ya && o.setContent(ya, za[ab])));\n                };\n            ;\n                h.inform(\"PhotoSnowlift.DATA_CHANGE\", this.stream.getCurrentImageData().info, h.BEHAVIOR_STATE);\n                if (this.stream.getCurrentExtraData()) {\n                    h.inform(\"PhotoSnowlift.EXTRA_DATA_CHANGE\", this.stream.getCurrentExtraData(), h.BEHAVIOR_STATE);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            this.showPagers(xa.PAGER_FADE);\n            this.adjustScroller();\n            this.scrollableArea.showScrollbar(false);\n            this.adjustForNewData();\n            this.logImpressionDetailsForPhoto();\n        },\n        updateTotalCount: function(ya, za, ab) {\n            var bb = this.stream.getCurrentHtml();\n            if (bb) {\n                var cb = na(\"fbPhotoSnowliftPositionAndCount\");\n                o.replace(cb, ab);\n                cb = ab;\n                m.show(cb);\n                var db = \"fbPhotoSnowliftPositionAndCount\";\n                bb[db] = qa(cb.childNodes);\n            }\n        ;\n        ;\n            this.stream.setTotalCount(ya);\n            this.stream.setFirstCursorIndex(za);\n        },\n        addPhotoFbids: function(ya, za, ab, bb) {\n            if (((((bb && this.sessionID)) && ((bb != this.sessionID))))) {\n                return;\n            }\n        ;\n        ;\n            var cb = ((this.stream.getCursor() === null));\n            this.stream.attachToFbidsList(ya, za, ab);\n            if (((ab && cb))) {\n                this.page(0, true);\n            }\n        ;\n        ;\n            if (((this.pivots && ab))) {\n                this.pivots.setCycleCount(this.stream.calculateDistance(this.stream.getCursor(), this.stream.firstCursor));\n            }\n        ;\n        ;\n            if (((!this.pagersShown && this.stream.canPage()))) {\n                this.setStagePagersState(\"ready\");\n            }\n        ;\n        ;\n        },\n        attachTagger: function(ya) {\n            o.appendContent(this.stageActions, ya);\n        },\n        storeFromData: function(ya) {\n            if (!this.isOpen) {\n                return;\n            }\n        ;\n        ;\n            if (((((ya.ssid && this.sessionID)) && ((this.sessionID != ya.ssid))))) {\n                return;\n            }\n        ;\n        ;\n            var za = this.stream.storeToCache(ya);\n            if (((\"error\" in za))) {\n                this.checkState(xa.STATE_ERROR);\n                return;\n            }\n        ;\n        ;\n            if (((\"init\" in za))) {\n                this.initDataFetched(za.init);\n                if (this.openExplicitly) {\n                    this.replaceUrl = true;\n                    sa(this.stream.getCurrentImageData().info.permalink);\n                }\n            ;\n            ;\n                if (this.stream.canPage()) {\n                    this.setStagePagersState(\"ready\");\n                }\n            ;\n            ;\n                ((this.ua && this.ua.add_event(\"ufi\")));\n            }\n        ;\n        ;\n            if (((\"image\" in za))) {\n                this.checkState(xa.STATE_IMAGE_DATA);\n            }\n        ;\n        ;\n            if (((\"data\" in za))) {\n                this.checkState(xa.STATE_HTML);\n            }\n        ;\n        ;\n        },\n        setStagePagersState: function(ya) {\n            switch (ya) {\n              case \"ready\":\n                m.addClass(this.root, \"pagingReady\");\n                this.pagersShown = true;\n                ((this.ua && this.ua.add_event(\"arrows\")));\n                return;\n              case \"active\":\n                m.addClass(this.root, \"pagingActivated\");\n                return;\n              case \"inactive\":\n                m.removeClass(this.root, \"pagingActivated\");\n                return;\n              case \"disabled\":\n            \n              case \"reset\":\n                m.removeClass(this.root, \"pagingReady\");\n                return;\n            };\n        ;\n        },\n        deletePhoto: function(ya) {\n            this.closeRefresh();\n        },\n        closeRefresh: function() {\n            this.refreshOnClose = true;\n            this.closeHandler();\n        },\n        JSBNG__onHiliteTag: function(ya, za) {\n            if (((za.version != z.VIEWER_SNOWLIFT))) {\n                return;\n            }\n        ;\n        ;\n            var ab = za.tag;\n            if (ab) {\n                this.switchHilitedTags(ab, true);\n            }\n        ;\n        ;\n        },\n        JSBNG__onUpdateTagBox: function(ya, za) {\n            if (((za.version == z.VIEWER_SNOWLIFT))) {\n                this.updateTagBox(za.id, za.approve);\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = xa;\n});\n__d(\"legacy:AudienceSelector\", [\"AudienceSelector\",], function(a, b, c, d) {\n    b(\"AudienceSelector\");\n}, 3);\n__d(\"legacy:CustomPrivacyOption\", [\"CustomPrivacyOption\",], function(a, b, c, d) {\n    a.CustomPrivacyOption = b(\"CustomPrivacyOption\");\n}, 3);\n__d(\"legacy:Selector\", [\"Selector\",], function(a, b, c, d) {\n    a.Selector = b(\"Selector\");\n}, 3);\nvar FriendListPrivacyOptions = (function() {\n    var a = false, b = false, c = null, d = {\n    }, e = function(f) {\n        if (is_empty(d)) {\n            PageTransitions.registerHandler(function() {\n                d = {\n                };\n                a = false;\n                b = false;\n            });\n        }\n    ;\n    ;\n        var g = f.getAttribute(\"data-name\");\n        d[g] = f;\n        Selector.listen(f, \"select\", function(h) {\n            var i = h.option, j = DOM.JSBNG__find(i, \"a.itemAnchor\"), k = j.getAttribute(\"data-flid\");\n            if (!k) {\n                return;\n            }\n        ;\n        ;\n            var l = j.getAttribute(\"data-dynamic\");\n            if (((l && a))) {\n                FriendListPrivacyOptions.showSmartListNux(i, k);\n            }\n             else if (((!l && b))) {\n                FriendListPrivacyOptions.showDumbListNux([k,]);\n            }\n            \n        ;\n        ;\n        });\n    };\n    return {\n        listen: function(f, g, h) {\n            var i = ge(f);\n            if (!i) {\n                return;\n            }\n        ;\n        ;\n            var j = Parent.byClass(i, \"audienceSelector\");\n            if (j) {\n                e(j);\n                a = g;\n                b = h;\n            }\n        ;\n        ;\n        },\n        showSmartListNux: function(f, g) {\n            new AsyncRequest(\"/ajax/friends/lists/smart_list_publish_nux.php\").setData({\n                option_id: f.id,\n                flid: g\n            }).send();\n            a = false;\n        },\n        setContextualDialog: function(f, g) {\n            var h = Parent.byClass(g, \"audienceSelector\");\n            if (h) {\n                f.setContext(h);\n                f.show();\n                var i = Arbiter.subscribe(\"composer/publish\", function() {\n                    f.hide();\n                });\n                f.subscribe(\"hide\", function() {\n                    i.unsubscribe();\n                });\n            }\n        ;\n        ;\n        },\n        showDumbListNux: function(f) {\n            new AsyncRequest(\"/ajax/friends/lists/dumb_list_publish_nux.php\").setData({\n                flids: f\n            }).send();\n            b = false;\n        },\n        showBothListsNux: function(f, g) {\n            c = f;\n            FriendListPrivacyOptions.showDumbListNux(g);\n        },\n        setDialog: function() {\n            if (!c) {\n                return;\n            }\n        ;\n        ;\n            var f = Dialog.getCurrent();\n            if (f) {\n                f.setCloseHandler(function() {\n                    FriendListPrivacyOptions.showSmartListNux(c);\n                    c = null;\n                });\n            }\n        ;\n        ;\n        }\n    };\n})();\n__d(\"legacy:privacy-common\", [\"PrivacyConst\",\"PrivacyModel\",], function(a, b, c, d) {\n    var e = b(\"PrivacyConst\");\n    a.PrivacyModel = b(\"PrivacyModel\");\n    a.PrivacyBaseValue = e.BaseValue;\n    a.PrivacyFriendsValue = e.FriendsValue;\n}, 3);\nfunction OnlyMePrivacyOption() {\n\n};\n;\ncopyProperties(OnlyMePrivacyOption.prototype, {\n    init: function(a) {\n        this._selector = Parent.byClass(a, \"composerAudienceSelector\");\n        this._plusLabel = DOM.JSBNG__find(a, \".plusLabel\");\n        if (!this._selector) {\n            return;\n        }\n    ;\n    ;\n        this._elem = a;\n        this._taggedIDs = [];\n        this._tags = [];\n        this._eventTag = null;\n        this._recalculateTooltipAndLabel();\n        this._updateSelector();\n        Arbiter.subscribe(\"Composer/changedtags\", function(b, c) {\n            var d = this._eventTag;\n            this._eventTag = c.eventTag;\n            this._tags = c.withTags.map(function(f) {\n                return f.getText();\n            });\n            this._taggedIDs = c.withTags.map(function(f) {\n                return f.getValue();\n            });\n            for (var e in c.mention) {\n                if (((((c.mention[e].type == \"user\")) && ((c.mention[e].uid != Env.user))))) {\n                    this._tags.push(c.mention[e].text);\n                    this._taggedIDs.push(c.mention[e].uid);\n                }\n            ;\n            ;\n            };\n        ;\n            if (((((this._eventTag && ((d != this._eventTag)))) && Selector.isOptionSelected(this._elem)))) {\n                Arbiter.inform(\"EventTagged/changed\", this._getChangedData());\n            }\n        ;\n        ;\n            if (((this._recalculateTooltipAndLabel() && Selector.isOptionSelected(this._elem)))) {\n                this._updateSelector();\n                Arbiter.inform(\"SelectedPrivacyOption/changed\", this._getChangedData());\n            }\n        ;\n        ;\n        }.bind(this));\n        Selector.listen(this._selector, \"change\", this._updateSelector.bind(this));\n    },\n    _getChangedData: function() {\n        return {\n            eventTag: this._eventTag,\n            tags: this._taggedIDs,\n            privacy: PrivacyFriendsValue.SELF\n        };\n    },\n    _recalculateTooltipAndLabel: function() {\n        var a = this._tooltip, b = this._label;\n        if (this._taggedIDs.length) {\n            this._tooltip = \"Anyone tagged\";\n            this._label = ((\"Only Me\" + \" (+)\"));\n        }\n         else {\n            this._tooltip = \"Only you\";\n            this._label = \"Only Me\";\n        }\n    ;\n    ;\n        CSS.conditionShow(this._plusLabel, this._taggedIDs.length);\n        return ((((a != this._tooltip)) || ((b != this._label))));\n    },\n    _updateSelector: function() {\n        if (Selector.isOptionSelected(this._elem)) {\n            Selector.setButtonLabel(this._selector, this._label);\n            Selector.setButtonTooltip(this._selector, this._tooltip);\n            return false;\n        }\n    ;\n    ;\n        return true;\n    }\n});\n__d(\"legacy:ui-scrolling-pager-js\", [\"ScrollingPager\",], function(a, b, c, d) {\n    a.ScrollingPager = b(\"ScrollingPager\");\n}, 3);\n__d(\"TypeaheadBestName\", [\"TypeaheadUtil\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"TypeaheadUtil\"), h = b(\"copyProperties\");\n    function i(j) {\n        this._typeahead = j;\n    };\n;\n    h(i.prototype, {\n        _subscription: null,\n        enable: function() {\n            var j = this._typeahead.getView();\n            this._subscription = j.subscribe(\"beforeRender\", function(k, l) {\n                var m = l.value;\n                for (var n = 0; ((n < l.results.length)); ++n) {\n                    var o = l.results[n];\n                    if (((o.alternate_names == null))) {\n                        continue;\n                    }\n                ;\n                ;\n                    if (g.isQueryMatch(m, o.default_name)) {\n                        o.text = o.default_name;\n                        return;\n                    }\n                ;\n                ;\n                    for (var p = 0; ((p < o.alternate_names.length)); p++) {\n                        if (g.isQueryMatch(m, o.alternate_names[p])) {\n                            o.text = o.alternate_names[p];\n                            return;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    o.text = o.default_name;\n                };\n            ;\n            });\n        },\n        disable: function() {\n            this._typeahead.getView().unsubscribe(this._subscription);\n            this._subscription = null;\n        }\n    });\n    e.exports = i;\n});\n__d(\"legacy:BestNameTypeaheadBehavior\", [\"TypeaheadBestName\",], function(a, b, c, d) {\n    var e = b(\"TypeaheadBestName\");\n    if (!a.TypeaheadBehaviors) {\n        a.TypeaheadBehaviors = {\n        };\n    }\n;\n;\n    a.TypeaheadBehaviors.buildBestAvailableNames = function(f) {\n        f.enableBehavior(e);\n    };\n}, 3);\nvar StreamShareVideo = {\n    _endpoints: [],\n    _thumbs: [],\n    registerThumb: function(a, b, c, d) {\n        StreamShareVideo._endpoints[((((a + \" \")) + c))] = d;\n        StreamShareVideo._thumbs[((((a + \" \")) + c))] = b;\n    },\n    clickTitle: function(a, b, JSBNG__event) {\n        this.expandInlineOrRedirect(a, b, JSBNG__event);\n    },\n    expandInlineOrRedirect: function(a, b, JSBNG__event) {\n        if (StreamShareVideo._shouldFollowHref(JSBNG__event)) {\n            return true;\n        }\n    ;\n    ;\n        var c = StreamShareVideo._thumbs[((((a + \" \")) + b))], d = ge(c);\n        if (d) {\n            CSS.addClass(d, \"uiVideoThumbLoading\");\n            AsyncRequest.bootstrap(StreamShareVideo._endpoints[((((a + \" \")) + b))], d.parentElement);\n            return false;\n        }\n    ;\n    ;\n        return true;\n    },\n    clickTimeline: function(a, b, JSBNG__event) {\n        if (StreamShareVideo._shouldFollowHref(JSBNG__event)) {\n            return true;\n        }\n    ;\n    ;\n        CSS.addClass(a, \"-cx-PRIVATE-fbTimelineExternalShareUnit__loading\");\n        CSS.removeClass(a, \"-cx-PRIVATE-fbTimelineExternalShareUnit__video\");\n        AsyncRequest.bootstrap(b, a);\n        return false;\n    },\n    _shouldFollowHref: function(JSBNG__event) {\n        JSBNG__event = $E(JSBNG__event);\n        if (!JSBNG__event) {\n            return false;\n        }\n    ;\n    ;\n        if (((JSBNG__event.getModifiers().any || JSBNG__event.isMiddleClick()))) {\n            return true;\n        }\n    ;\n    ;\n        return false;\n    }\n};\nfunction tz_calculate(a) {\n    var b = new JSBNG__Date(), c = ((b.getTimezoneOffset() / 30)), d = ((b.getTime() / 1000)), e = Math.round(((((a - d)) / 1800))), f = ((Math.round(((c + e))) % 48));\n    if (((f == 0))) {\n        return 0;\n    }\n     else if (((f > 24))) {\n        f -= ((Math.ceil(((f / 48))) * 48));\n    }\n     else if (((f < -28))) {\n        f += ((Math.ceil(((f / -48))) * 48));\n    }\n    \n    \n;\n;\n    return ((f * 30));\n};\n;\nfunction tz_autoset(a, b) {\n    if (((!a || ((undefined == b))))) {\n        return;\n    }\n;\n;\n    if (window.tz_autoset.calculated) {\n        return;\n    }\n;\n;\n    window.tz_autoset.calculated = true;\n    var c = -tz_calculate(a);\n    if (((c != b))) {\n        var d = \"/ajax/autoset_timezone_ajax.php\";\n        new AsyncRequest().setURI(d).setData({\n            gmt_off: c\n        }).setErrorHandler(bagofholding).setTransportErrorHandler(bagofholding).setOption(\"suppressErrorAlerts\", true).send();\n    }\n;\n;\n};\n;\n__d(\"TypingDetector\", [\"event-extensions\",\"function-extensions\",\"ArbiterMixin\",\"Class\",\"Input\",\"Run\",\"copyProperties\",\"createObjectFrom\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"Class\"), i = b(\"Input\"), j = b(\"Run\"), k = b(\"copyProperties\"), l = b(\"createObjectFrom\");\n    function m(n) {\n        this._input = n;\n        this._ignoreKeys = {\n        };\n    };\n;\n    m.INACTIVE = 0;\n    m.TYPING = 1;\n    m.QUITTING = 2;\n    k(m.prototype, g, {\n        _timeout: 7000,\n        _currentState: m.INACTIVE,\n        init: function() {\n            this.init = bagofholding;\n            this.reset();\n            JSBNG__Event.listen(this._input, \"keyup\", this._update.bind(this));\n            j.JSBNG__onUnload(this._onunload.bind(this));\n        },\n        reset: function() {\n            JSBNG__clearTimeout(this._checkTimer);\n            this._checkTimer = null;\n            this._lastKeystrokeAt = null;\n            this._currentState = m.INACTIVE;\n        },\n        setIgnoreKeys: function(n) {\n            this._ignoreKeys = l(n);\n        },\n        _onunload: function() {\n            if (((this._currentState == m.TYPING))) {\n                this._transition(m.QUITTING);\n            }\n        ;\n        ;\n        },\n        _update: function(JSBNG__event) {\n            var n = JSBNG__Event.getKeyCode(JSBNG__event), o = this._currentState;\n            if (!this._ignoreKeys[n]) {\n                if (((i.getValue(this._input).trim().length === 0))) {\n                    if (((o == m.TYPING))) {\n                        this._transition(m.INACTIVE);\n                    }\n                ;\n                ;\n                }\n                 else if (((o == m.TYPING))) {\n                    this._recordKeystroke();\n                }\n                 else if (((o == m.INACTIVE))) {\n                    this._transition(m.TYPING);\n                    this._recordKeystroke();\n                }\n                \n                \n            ;\n            }\n        ;\n        ;\n        },\n        _transition: function(n) {\n            this.reset();\n            this._currentState = n;\n            this.inform(\"change\", n);\n        },\n        _recordKeystroke: function() {\n            this._lastKeystrokeTime = JSBNG__Date.now();\n            if (!this._checkTimer) {\n                this._checkTimer = this._checkTyping.bind(this).defer(this._timeout);\n            }\n        ;\n        ;\n        },\n        _checkTyping: function() {\n            var n = ((this._lastKeystrokeTime + this._timeout)), o = JSBNG__Date.now();\n            if (((o > n))) {\n                this._transition(m.INACTIVE);\n            }\n             else {\n                JSBNG__clearTimeout(this._checkTimer);\n                this._checkTimer = this._checkTyping.bind(this).defer(((((n - o)) + 10)));\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = m;\n});\n__d(\"MentionsInputMatchers\", [], function(a, b, c, d, e, f) {\n    var g = [\"@\",\"\\\\uff20\",\"+\",\"\\\\uff0b\",].join(\"\"), h = \".,*?$|#{}()\\\\^\\\\-\\\\[\\\\]\\\\\\\\/!%&'\\\"~=\\u003C\\u003E_:;\", i = ((((\"\\\\b[A-Z][^ A-Z\" + h)) + \"]\")), j = ((((((((((((((\"([^\" + g)) + h)) + \"]|[\")) + h)) + \"][^ \")) + h)) + \"])\")), k = ((((((((\"(?:^|\\\\s)(?:[\" + g)) + \"](\")) + j)) + \"{0,20}))\")), l = ((((((((\"(?:(?:\" + i)) + \"+)|\")) + k)) + \")\")), m = ((((\"(?:\" + i)) + \"{4,})\")), n = {\n        trigger: new RegExp(((((\"[\" + g)) + \"]$\"))),\n        mainMatcher: new RegExp(((k + \"$\"))),\n        autoMatcher: new RegExp(((l + \"$\"))),\n        userMatcher: new RegExp(((m + \"$\")))\n    };\n    e.exports = n;\n});\n__d(\"MentionsInput\", [\"event-extensions\",\"function-extensions\",\"Arbiter\",\"ArbiterMixin\",\"Class\",\"CSS\",\"DataStore\",\"DOM\",\"HTML\",\"Input\",\"InputSelection\",\"Parent\",\"htmlize\",\"Style\",\"Typeahead\",\"TypeaheadUtil\",\"UserAgent\",\"copyProperties\",\"MentionsInputMatchers\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"Class\"), j = b(\"CSS\"), k = b(\"DataStore\"), l = b(\"DOM\"), m = b(\"HTML\"), n = b(\"Input\"), o = b(\"InputSelection\"), p = b(\"Parent\"), q = b(\"htmlize\"), r = b(\"Style\"), s = b(\"Typeahead\"), t = b(\"TypeaheadUtil\"), u = b(\"UserAgent\"), v = b(\"copyProperties\"), w = b(\"MentionsInputMatchers\");\n    function x(y, z, aa, ba, ca, da) {\n        k.set(y, \"MentionsInput\", this);\n        this._root = y;\n        this._typeahead = z;\n        this._input = aa;\n        var ea = false;\n        try {\n            ea = ((JSBNG__document.activeElement === this._input));\n        } catch (fa) {\n        \n        };\n    ;\n        if (ea) {\n            this.init.bind(this, ba, ca, da).defer();\n        }\n         else var ga = JSBNG__Event.listen(this._input, \"JSBNG__focus\", function() {\n            this.init.bind(this, ba, ca, da).defer();\n            ga.remove();\n        }.bind(this))\n    ;\n    };\n;\n    x.getInstance = function(y) {\n        var z = p.byClass(y, \"uiMentionsInput\");\n        return ((z ? k.get(z, \"MentionsInput\") : null));\n    };\n    v(x.prototype, h, {\n        init: function(y, z, aa) {\n            this.init = Function.prototype;\n            this._initialized = true;\n            this._highlighter = l.JSBNG__find(this._root, \".highlighter\");\n            this._highlighterInner = this._highlighter.firstChild;\n            this._highlighterContent = l.JSBNG__find(this._root, \".highlighterContent\");\n            this._hiddenInput = l.JSBNG__find(this._root, \".mentionsHidden\");\n            this._placeholder = ((this._input.getAttribute(\"placeholder\") || \"\"));\n            this._maxMentions = ((y.max || 6));\n            this._metrics = aa;\n            if (((u.firefox() < 4))) {\n                this._input.JSBNG__blur();\n                JSBNG__setTimeout(function() {\n                    this._input.JSBNG__focus();\n                }.bind(this));\n            }\n        ;\n        ;\n            if (!this._hiddenInput.JSBNG__name) {\n                var ba = this._input.JSBNG__name;\n                this._input.JSBNG__name = ((ba + \"_text\"));\n                this._hiddenInput.JSBNG__name = ba;\n            }\n        ;\n        ;\n            this._initEvents();\n            this._initTypeahead();\n            this.reset(z);\n            this.inform(\"init\", null, g.BEHAVIOR_STATE);\n        },\n        reset: function(y) {\n            if (!this._initialized) {\n                return;\n            }\n        ;\n        ;\n            this._mentioned = {\n            };\n            this._orderedUIDs = [];\n            this._numMentioned = 0;\n            this._filterData = null;\n            ((this._hiddenInput && (this._hiddenInput.value = \"\")));\n            ((this._highlighterContent && l.empty(this._highlighterContent)));\n            ((this._highlighterAuxContent && l.remove(this._highlighterAuxContent)));\n            this._highlighterAuxContent = null;\n            n.setPlaceholder(this._input, this._placeholder);\n            r.set(this._typeahead.getElement(), \"height\", \"auto\");\n            if (y) {\n                n.setValue(this._input, y.flattened);\n                for (var z in y.mention_data) {\n                    this._addToken({\n                        uid: z,\n                        text: y.mention_data[z],\n                        type: \"unknown\"\n                    });\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            this._updateTypeahead();\n            this._updateWidth();\n            this._update();\n        },\n        getValue: function() {\n            return n.getValue(this._input);\n        },\n        getRawValue: function() {\n            this._update();\n            return n.getValue(this._hiddenInput);\n        },\n        checkValue: function() {\n            var y = this._typeahead.getCore().getValue();\n            if (((w.trigger.exec(y) || ((y === \"\"))))) {\n                this.inform(\"sessionEnd\", {\n                });\n            }\n        ;\n        ;\n        },\n        getTypeahead: function() {\n            return this._typeahead;\n        },\n        _initEvents: function() {\n            var y = this._update.bind(this);\n            JSBNG__Event.listen(this._input, {\n                input: y,\n                keyup: y,\n                change: y,\n                JSBNG__blur: this._handleBlur.bind(this),\n                JSBNG__focus: this._handleFocus.bind(this)\n            });\n            if (this._metrics) {\n                this._metrics._reset();\n                this._metrics.bindSessionStart(this._typeahead, \"render\", true);\n                this._metrics.bindSessionEnd(this._typeahead.getView(), \"select\", true);\n                this._metrics.bindSessionEnd(this, \"sessionEnd\", false);\n                JSBNG__Event.listen(this._input, \"keyup\", function(JSBNG__event) {\n                    this.checkValue.bind(this).defer();\n                }.bind(this));\n            }\n        ;\n        ;\n        },\n        _initTypeahead: function() {\n            this._typeahead.subscribe(\"select\", function(ca, da) {\n                var ea = da.selected;\n                this._addToken({\n                    uid: ea.uid,\n                    text: ea.text,\n                    type: ea.type\n                });\n                this.updateValue();\n            }.bind(this));\n            var y = this._input, z = null, aa = function() {\n                if (((z === null))) {\n                    z = n.getSubmitOnEnter(y);\n                    n.setSubmitOnEnter(y, false);\n                }\n            ;\n            ;\n            }, ba = function() {\n                if (((z !== null))) {\n                    n.setSubmitOnEnter(y, z);\n                    z = null;\n                }\n            ;\n            ;\n            };\n            this._typeahead.subscribe(\"render\", aa);\n            this._typeahead.subscribe(\"reset\", ba);\n            this._typeahead.subscribe(\"highlight\", function(ca, da) {\n                ((((da.index >= 0)) ? aa() : ba()));\n            });\n            this._typeahead.subscribe(\"query\", function() {\n                this._filterData = null;\n            }.bind(this));\n            this._typeahead.getCore().suffix = \"\";\n            this._handleFocus();\n        },\n        _handleBlur: function() {\n            if (this._filterToken) {\n                this._filterToken.remove();\n                this._filterToken = null;\n            }\n        ;\n        ;\n        },\n        _handleFocus: function() {\n            if (!this._filterToken) {\n                this._filterToken = this._typeahead.getData().addFilter(this._filterResults.bind(this));\n            }\n        ;\n        ;\n            this._updateWidth();\n        },\n        _filterResults: function(y) {\n            if (((this._filterData === null))) {\n                var z = ((o.get(this._input).start || 0));\n                for (var aa = 0; ((aa < this._offsets.length)); aa++) {\n                    var ba = this._offsets[aa];\n                    if (((((z > ba[0])) && ((z <= ba[1]))))) {\n                        this._filterData = {\n                            caretIsInsideMention: true\n                        };\n                        return false;\n                    }\n                ;\n                ;\n                };\n            ;\n                var ca = this._typeahead.getCore();\n                this._filterData = {\n                    value: ca.getValue(),\n                    rawValue: ca.getRawValue()\n                };\n            }\n        ;\n        ;\n            if (this._filterData.caretIsInsideMention) {\n                return false;\n            }\n        ;\n        ;\n            if (w.mainMatcher.test(this._filterData.rawValue)) {\n                return true;\n            }\n        ;\n        ;\n            if (((y.type != \"user\"))) {\n                return false;\n            }\n        ;\n        ;\n            if (w.userMatcher.test(this._filterData.value)) {\n                return true;\n            }\n        ;\n        ;\n            return t.isExactMatch(this._filterData.value, this._typeahead.getData().getTextToIndex(y));\n        },\n        _addToken: function(y) {\n            var z = y.uid;\n            if (!this._mentioned.hasOwnProperty(z)) {\n                this._mentioned[z] = y;\n                this._orderedUIDs.push(z);\n                this._numMentioned++;\n                this._updateTypeahead();\n            }\n        ;\n        ;\n        },\n        _removeToken: function(y) {\n            if (this._mentioned.hasOwnProperty(y)) {\n                delete this._mentioned[y];\n                this._orderedUIDs.remove(y);\n                this._numMentioned--;\n                this._updateTypeahead();\n            }\n        ;\n        ;\n        },\n        _reduceToken: function(y, z) {\n            var aa = z.split(\" \"), ba = [];\n            for (var ca = 0; ((ca < aa.length)); ca++) {\n                if (((y.indexOf(aa[ca]) != -1))) {\n                    ba.push(aa[ca]);\n                }\n            ;\n            ;\n            };\n        ;\n            aa = ba;\n            for (ca = 1; ((ca < aa.length)); ca++) {\n                for (var da = 1; ((da < ((aa[((ca - 1))].length + 1)))); da++) {\n                    if (((y.indexOf(((aa[((ca - 1))].substr(0, da) + aa[ca]))) != -1))) {\n                        aa.splice(((ca - 1)), 1);\n                    }\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n            while (((y.indexOf(aa.join(\" \")) == -1))) {\n                aa.splice(0, 1);\n            ;\n            };\n        ;\n            return aa.join(\" \");\n        },\n        _update: function() {\n            var y = this.getValue();\n            if (((y == this._value))) {\n                return;\n            }\n        ;\n        ;\n            this._updateTokens();\n            this.updateValue();\n            this._updateDirection();\n        },\n        _updateTokens: function() {\n            var y = this.getValue(), z = false;\n            for (var aa = 0; ((aa < this._orderedUIDs.length)); ++aa) {\n                var ba = this._orderedUIDs[aa], ca = this._mentioned[ba], da = ca.text, ea;\n                if (((((ca.type == \"user\")) && (((ea = this._reduceToken(y, da)) !== \"\"))))) {\n                    if (((((ea == da.substring(0, da.lastIndexOf(\" \")))) && ((y == this._value.substring(0, ((this._value.length - 1)))))))) {\n                        y = y.substring(0, y.lastIndexOf(\" \"));\n                        z = true;\n                    }\n                ;\n                ;\n                    ca.text = ea;\n                }\n                 else if (((((!da || ((y.indexOf(da) == -1)))) || ((typeof da !== \"string\"))))) {\n                    this._removeToken(ba);\n                }\n                \n            ;\n            ;\n            };\n        ;\n            this._value = y;\n            if (z) {\n                n.setValue(this._input, y);\n            }\n        ;\n        ;\n        },\n        updateValue: function() {\n            var y = this.getValue(), z = this._orderedUIDs, aa = [], ba, ca, da, ea;\n            for (ea = 0; ((ea < z.length)); ++ea) {\n                ca = this._mentioned[z[ea]].text;\n                y = y.replace(ca, function(fa, ga) {\n                    aa.push([ga,((ga + ca.length)),]);\n                    return ca;\n                });\n            };\n        ;\n            for (ea = 0; ((ea < z.length)); ++ea) {\n                da = z[ea];\n                ca = this._mentioned[da].text;\n                y = y.replace(ca, ((((\"@[\" + da)) + \":]\")));\n            };\n        ;\n            ba = q(y);\n            for (ea = 0; ((ea < z.length)); ++ea) {\n                da = z[ea];\n                ca = this._mentioned[da].text;\n                ba = ba.replace(((((\"@[\" + da)) + \":]\")), ((((\"\\u003Cb\\u003E\" + q(ca))) + \"\\u003C/b\\u003E\")));\n                ca = ca.replace(/[\\\\\\]:]/g, function(fa) {\n                    return ((\"\\\\\" + fa));\n                });\n                y = y.replace(((((\"@[\" + da)) + \":]\")), ((((((((\"@[\" + da)) + \":\")) + ca)) + \"]\")));\n            };\n        ;\n            if (u.ie()) {\n                ba = ba.replace(/ {2}/g, \"&nbsp;\\u003Cwbr /\\u003E&nbsp;\\u003Cwbr /\\u003E\");\n                ba = ba.replace(/ (?=[^\\/]|\\/[^>])/g, \"&nbsp;\\u003Cwbr /\\u003E\");\n            }\n        ;\n        ;\n            this._offsets = aa;\n            this._hiddenInput.value = y;\n            l.setContent(this._highlighterContent, m(ba));\n            this._updateHighlighter();\n            this._updateHeight();\n        },\n        _updateDirection: function() {\n            var y = r.get(this._input, \"direction\");\n            if (((y == this._dir))) {\n                return;\n            }\n        ;\n        ;\n            this._dir = y;\n            r.set(this._highlighter, \"direction\", y);\n            if (((y == \"rtl\"))) {\n                r.set(this._highlighter, \"text-align\", \"right\");\n            }\n             else r.set(this._highlighter, \"text-align\", \"left\");\n        ;\n        ;\n        },\n        _updateWidth: function() {\n            var y = r.getFloat.curry(this._input), z = ((((((((this._input.offsetWidth - y(\"paddingLeft\"))) - y(\"paddingRight\"))) - y(\"borderLeftWidth\"))) - y(\"borderRightWidth\")));\n            if (u.firefox()) {\n                z -= 2;\n            }\n        ;\n        ;\n            if (((u.ie() <= 7))) {\n                z -= r.getFloat(this._highlighterInner, \"paddingLeft\");\n                this._highlighter.style.zoom = 1;\n            }\n        ;\n        ;\n            this._highlighterInner.style.width = ((Math.max(z, 0) + \"px\"));\n        },\n        _updateHeight: function() {\n            if (this._highlighterAuxContent) {\n                var y = this._highlighter.offsetHeight, z = this._typeahead.getElement();\n                if (((y > z.offsetHeight))) {\n                    r.set(z, \"height\", ((y + \"px\")));\n                    g.inform(\"reflow\");\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        _updateTypeahead: function() {\n            var y = this._typeahead.getCore(), z = null;\n            if (((!this._maxMentions || ((this._numMentioned < this._maxMentions))))) {\n                z = w.autoMatcher;\n            }\n        ;\n        ;\n            y.matcher = z;\n            y.setExclusions(this._orderedUIDs);\n            this.inform(\"update\", {\n                mentioned: this._mentioned\n            });\n        },\n        setPlaceholder: function(y) {\n            this._placeholder = y;\n            if (!this.hasAuxContent()) {\n                n.setPlaceholder(this._input, y);\n            }\n        ;\n        ;\n        },\n        _updateHighlighter: function() {\n            if (this._highlighterContent) {\n                j.conditionShow(this._highlighterContent, ((((this._numMentioned > 0)) || this.hasAuxContent())));\n            }\n        ;\n        ;\n        },\n        setAuxContent: function(y) {\n            if (this._highlighterContent) {\n                if (!this._highlighterAuxContent) {\n                    this._highlighterAuxContent = l.create(\"span\", {\n                        className: \"highlighterAuxContent\"\n                    });\n                    l.insertAfter(this._highlighterContent, this._highlighterAuxContent);\n                }\n            ;\n            ;\n                l.setContent(this._highlighterAuxContent, y);\n                if (y) {\n                    n.setPlaceholder(this._input, \"\");\n                }\n                 else n.setPlaceholder(this._input, this._placeholder);\n            ;\n            ;\n                this._updateHighlighter();\n                this._updateHeight();\n            }\n        ;\n        ;\n        },\n        hasAuxContent: function() {\n            var y = this.getAuxContentRoot();\n            return ((y && ((y.innerHTML.length > 0))));\n        },\n        getAuxContentRoot: function() {\n            return this._highlighterAuxContent;\n        },\n        addMention: function(y) {\n            var z = this.getValue();\n            n.setValue(this._input, ((((z + \" \")) + y.text)));\n            this._addToken(y);\n            this._update();\n        },\n        getMentions: function() {\n            return this._mentioned;\n        }\n    });\n    e.exports = x;\n});\n__d(\"UFIUpdate\", [\"CommentPrelude\",\"CSS\",\"DOM\",\"DOMQuery\",\"HTML\",\"MentionsInput\",\"Parent\",\"ScrollableArea\",\"ScrollAwareDOM\",], function(a, b, c, d, e, f) {\n    var g = b(\"CommentPrelude\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"DOMQuery\"), k = b(\"HTML\"), l = b(\"MentionsInput\"), m = b(\"Parent\"), n = b(\"ScrollableArea\"), o = b(\"ScrollAwareDOM\"), p = {\n        expandFeedback: function(q, r, s) {\n            i.scry(q, r).forEach(function(t) {\n                g.expand(t, s);\n            });\n        },\n        uncollapseFeedback: function(q) {\n            g.uncollapse(m.byTag(i.JSBNG__find(q, \".fbUfi\"), \"form\"));\n        },\n        multiContentReplaceGlobal: function(q, r) {\n            this.multiContentReplace(JSBNG__document.documentElement, q, r);\n        },\n        multiContentReplace: function(q, r, s) {\n            s = ((((s instanceof k)) ? s.getRootNode() : s));\n            i.scry(q, r).forEach(function(t) {\n                o.replace(t, s.cloneNode(true));\n            });\n        },\n        refocusCommentBox: function(q, r) {\n            var s = i.JSBNG__find(q, \"textarea\");\n            s.value = s.style.height = \"\";\n            if (r) {\n                s.JSBNG__blur();\n                s.JSBNG__focus.defer();\n            }\n             else JSBNG__document.documentElement.JSBNG__onfocusin({\n                target: s\n            });\n        ;\n        ;\n        },\n        resetMentionsInput: function(q) {\n            var r = l.getInstance(i.JSBNG__find(q, \"div.uiMentionsInput\"));\n            ((r && r.reset()));\n        },\n        insertAtBottom: function(q, r, s, t) {\n            var u = i.scry(q, ((\".comment_\" + s))).length;\n            if (r) {\n                u += i.scry(q, ((\"#\" + r))).length;\n            }\n        ;\n        ;\n            if (!u) {\n                var v = i.JSBNG__find(q, \".commentList\"), w = n.getInstance(v), x = ((w && w.isScrolledToBottom()));\n                o.appendContent(v, t);\n                ((x && w.scrollToBottom(false)));\n            }\n        ;\n        ;\n        },\n        updateUnsubscribeLink: function(q, r) {\n            var s = i.scry(q, \".unsub_link\")[0];\n            if (s) {\n                i.replace(s, r);\n            }\n             else if (r) {\n                i.insertAfter(i.JSBNG__find(q, \".comment_link\"), [\" \\u00b7 \",r,]);\n            }\n            \n        ;\n        ;\n        },\n        updateSeenCount: function(q) {\n            j.scry(q, \".uiUfiSeenBar\").forEach(function(t) {\n                h.hide(t);\n            });\n            j.scry(q, \".uiUfiViewSeenCount\").forEach(function(t) {\n                h.hide(t);\n            });\n            var r = j.scry(q, \".uiUfiLike\")[0];\n            if (((r && ((r.childNodes.length === 0))))) {\n                r = null;\n            }\n        ;\n        ;\n            r = ((r || j.scry(q, \".uiUfiSeenBar\")[0]));\n            if (!r) {\n                return;\n            }\n        ;\n        ;\n            var s = j.scry(r, \".uiUfiViewSeenCount\")[0];\n            if (!s) {\n                return;\n            }\n        ;\n        ;\n            h.show(s);\n            h.show(r);\n        }\n    };\n    e.exports = p;\n});\nfunction ufi_add_ft_hidden_node(a) {\n    if (a.link_data) {\n        return;\n    }\n;\n;\n    var b = collect_data_attribs(a, [\"ft\",]).ft;\n    if (Object.keys(b).length) {\n        var c = DOM.create(\"input\", {\n            type: \"hidden\",\n            JSBNG__name: \"link_data\",\n            value: JSON.stringify(b)\n        });\n        a.appendChild(c);\n    }\n;\n;\n};\n;\nfunction ufi_add_all_link_data() {\n    Bootloader.loadComponents(\"dom-collect\", function() {\n        DOM.scry(JSBNG__document.body, \"form.commentable_item\").forEach(ufi_add_ft_hidden_node);\n    });\n};\n;\nfunction question_add_all_link_data() {\n    Bootloader.loadComponents(\"dom-collect\", function() {\n        DOM.scry(JSBNG__document.body, \"form.fbEigenpollForm\").forEach(ufi_add_ft_hidden_node);\n        DOM.scry(JSBNG__document.body, \"form.fbQuestionPollForm\").forEach(ufi_add_ft_hidden_node);\n    });\n};\n;\n__d(\"legacy:UIPagelet\", [\"UIPagelet\",], function(a, b, c, d) {\n    a.UIPagelet = b(\"UIPagelet\");\n}, 3);\n__d(\"Scrollable\", [\"event-extensions\",\"Parent\",\"UserAgent\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Parent\"), h = b(\"UserAgent\"), i = function(JSBNG__event) {\n        var k = g.byClass(JSBNG__event.getTarget(), \"scrollable\");\n        if (!k) {\n            return;\n        }\n    ;\n    ;\n        if (((((((typeof JSBNG__event.axis !== \"undefined\")) && ((JSBNG__event.axis === JSBNG__event.HORIZONTAL_AXIS)))) || ((JSBNG__event.wheelDeltaX && !JSBNG__event.wheelDeltaY))))) {\n            return;\n        }\n    ;\n    ;\n        var l = ((JSBNG__event.wheelDelta ? JSBNG__event.wheelDelta : -JSBNG__event.detail)), m = k.scrollHeight, n = k.clientHeight;\n        if (((m > n))) {\n            var o = k.scrollTop;\n            if (((((((l > 0)) && ((o === 0)))) || ((((l < 0)) && ((o >= ((m - n))))))))) {\n                JSBNG__event.prevent();\n            }\n             else if (((h.ie() < 9))) {\n                if (k.currentStyle) {\n                    var p = k.currentStyle.fontSize;\n                    if (((p.indexOf(\"px\") < 0))) {\n                        var q = JSBNG__document.createElement(\"div\");\n                        q.style.fontSize = p;\n                        q.style.height = \"1em\";\n                        p = q.style.pixelHeight;\n                    }\n                     else p = parseInt(p, 10);\n                ;\n                ;\n                    k.scrollTop = ((o - Math.round(((((l / 120)) * p)))));\n                    JSBNG__event.prevent();\n                }\n            ;\n            }\n            \n        ;\n        ;\n        }\n    ;\n    ;\n    }, j = JSBNG__document.documentElement;\n    if (h.firefox()) {\n        j.JSBNG__addEventListener(\"DOMMouseScroll\", i, false);\n    }\n     else JSBNG__Event.listen(j, \"mousewheel\", i);\n;\n;\n});\n__d(\"TinyViewport\", [\"event-extensions\",\"CSS\",\"DOM\",\"debounce\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"debounce\"), j = i(function() {\n        var k = JSBNG__document.documentElement, l = h.getDocumentScrollElement(), m = ((((k.clientHeight < 400)) || ((l.clientWidth < l.scrollWidth))));\n        g.conditionClass(k, \"tinyViewport\", m);\n        g.conditionClass(k, \"canHaveFixedElements\", !m);\n    });\n    j();\n    JSBNG__Event.listen(window, \"resize\", j);\n});\n__d(\"legacy:Toggler\", [\"Toggler\",], function(a, b, c, d) {\n    a.Toggler = b(\"Toggler\");\n}, 3);\n__d(\"legacy:Button\", [\"Button\",], function(a, b, c, d) {\n    a.Button = b(\"Button\");\n}, 3);\n__d(\"ButtonGroup\", [\"function-extensions\",\"copyProperties\",\"createArrayFrom\",\"CSS\",\"DataStore\",\"Parent\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"copyProperties\"), h = b(\"createArrayFrom\"), i = b(\"CSS\"), j = b(\"DataStore\"), k = b(\"Parent\"), l = \"firstItem\", m = \"lastItem\";\n    function n(s, t) {\n        var u = k.byClass(s, t);\n        if (!u) {\n            throw new Error(\"invalid use case\");\n        }\n    ;\n    ;\n        return u;\n    };\n;\n    function o(s) {\n        return ((i.shown(s) && h(s.childNodes).some(i.shown)));\n    };\n;\n    function p(s) {\n        var t, u, v;\n        h(s.childNodes).forEach(function(w) {\n            v = o(w);\n            i.removeClass(w, l);\n            i.removeClass(w, m);\n            i.conditionShow(w, v);\n            if (v) {\n                t = ((t || w));\n                u = w;\n            }\n        ;\n        ;\n        });\n        ((t && i.addClass(t, l)));\n        ((u && i.addClass(u, m)));\n        i.conditionShow(s, t);\n    };\n;\n    function q(s, t) {\n        var u = n(t, \"uiButtonGroupItem\");\n        s(u);\n        p(u.parentNode);\n    };\n;\n    function r(s) {\n        this._root = n(s, \"uiButtonGroup\");\n        j.set(this._root, \"ButtonGroup\", this);\n        p(this._root);\n    };\n;\n    r.getInstance = function(s) {\n        var t = n(s, \"uiButtonGroup\"), u = j.get(t, \"ButtonGroup\");\n        return ((u || new r(t)));\n    };\n    g(r.prototype, {\n        hideItem: q.curry(i.hide),\n        showItem: q.curry(i.show),\n        toggleItem: q.curry(i.toggle)\n    });\n    e.exports = r;\n});\n__d(\"legacy:MentionsInput\", [\"MentionsInput\",], function(a, b, c, d) {\n    a.MentionsInput = b(\"MentionsInput\");\n}, 3);\n__d(\"FormDisableOnSubmit\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\");\n    function h(i) {\n        this._form = i;\n    };\n;\n    g(h.prototype, {\n        _subscription: null,\n        _disabled: false,\n        enable: function() {\n            this._subscription = this._form.subscribe([\"submit\",\"reset\",], this._handle.bind(this));\n        },\n        disable: function() {\n            this._form.unsubscribe(this._subscription);\n            this._subscription = null;\n        },\n        _handle: function(i, j) {\n            if (((i == \"submit\"))) {\n                if (this._disabled) {\n                    return false;\n                }\n            ;\n            ;\n                this._disabled = true;\n                return true;\n            }\n        ;\n        ;\n            this._disabled = false;\n        }\n    });\n    e.exports = h;\n});\n__d(\"FormSubmitOnChange\", [\"event-extensions\",\"copyProperties\",\"submitForm\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"copyProperties\"), h = b(\"submitForm\");\n    function i(j) {\n        this._form = j;\n    };\n;\n    g(i.prototype, {\n        _listener: null,\n        enable: function() {\n            this._listener = JSBNG__Event.listen(this._form.getRoot(), \"change\", this._submit.bind(this));\n        },\n        disable: function() {\n            this._listener.remove();\n            this._listener = null;\n        },\n        _submit: function() {\n            h(this._form.getRoot());\n        }\n    });\n    e.exports = i;\n});\n__d(\"UIForm\", [\"event-extensions\",\"ArbiterMixin\",\"BehaviorsMixin\",\"Class\",\"DOM\",\"Form\",\"FormDisableOnSubmit\",\"FormSubmitOnChange\",\"Run\",\"areObjectsEqual\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"BehaviorsMixin\"), i = b(\"Class\"), j = b(\"DOM\"), k = b(\"Form\"), l = b(\"FormDisableOnSubmit\"), m = b(\"FormSubmitOnChange\"), n = b(\"Run\"), o = b(\"areObjectsEqual\"), p = b(\"copyProperties\");\n    function q(r, s, t, u) {\n        this._root = r;\n        this.controller = r;\n        this._message = s;\n        n.JSBNG__onAfterLoad(function() {\n            this._originalState = k.serialize(this._root);\n        }.bind(this));\n        this._forceDirty = t;\n        this._submitted = false;\n        JSBNG__Event.listen(this._root, \"submit\", this._handleSubmit.bind(this));\n        if (((u && u.length))) {\n            this.enableBehaviors(u);\n        }\n    ;\n    ;\n        var v = true;\n        n.JSBNG__onBeforeUnload(this.checkUnsaved.bind(this), v);\n    };\n;\n    p(q.prototype, g, h, {\n        getRoot: function() {\n            return this._root;\n        },\n        _handleSubmit: function() {\n            if (((this.inform(\"submit\") === false))) {\n                return false;\n            }\n        ;\n        ;\n            this._submitted = true;\n            return true;\n        },\n        reset: function() {\n            this.inform(\"reset\");\n            this._submitted = false;\n        },\n        isDirty: function() {\n            if (((this._submitted || !j.contains(JSBNG__document.body, this._root)))) {\n                return false;\n            }\n        ;\n        ;\n            if (this._forceDirty) {\n                return true;\n            }\n        ;\n        ;\n            var r = k.serialize(this._root);\n            return !o(r, this._originalState);\n        },\n        checkUnsaved: function() {\n            if (this.isDirty()) {\n                return this._message;\n            }\n        ;\n        ;\n            return null;\n        }\n    });\n    e.exports = ((a.UIForm || q));\n});\n__d(\"legacy:ScrollableArea\", [\"ScrollableArea\",], function(a, b, c, d) {\n    a.ScrollableArea = b(\"ScrollableArea\");\n}, 3);\n__d(\"TooltipLink\", [\"Parent\",\"Tooltip\",], function(a, b, c, d, e, f) {\n    var g = b(\"Parent\"), h = b(\"Tooltip\"), i = {\n        setTooltipText: function(j, k) {\n            j = g.byTag(j, \"a\");\n            ((j && h.set(j, k)));\n        }\n    };\n    e.exports = i;\n});\n__d(\"SubMenu\", [\"event-extensions\",\"Arbiter\",\"copyProperties\",\"CSS\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"copyProperties\"), i = b(\"CSS\");\n    function j() {\n    \n    };\n;\n    h(j.prototype, {\n        _subMenu: null,\n        _mainMenu: null,\n        _forward: null,\n        _backward: null,\n        init: function(k, l, m, n) {\n            this._subMenu = k;\n            this._mainMenu = l;\n            this._forward = m;\n            this._backward = n;\n            g.subscribe(\"SubMenu/Reset\", this._goToMainMenu.bind(this));\n            JSBNG__Event.listen(m, \"click\", this._goToSubMenu.bind(this));\n            JSBNG__Event.listen(n, \"click\", this._goToMainMenu.bind(this));\n        },\n        initAsyncChildMenu: function(k) {\n            JSBNG__Event.listen(this._forward, \"click\", function() {\n                this._goToSubMenu();\n                k.load();\n            }.bind(this));\n        },\n        _goToMainMenu: function() {\n            i.hide(this._subMenu);\n            i.show(this._mainMenu);\n        },\n        _goToSubMenu: function() {\n            i.hide(this._mainMenu);\n            i.show(this._subMenu);\n        }\n    });\n    e.exports = j;\n});\n__d(\"legacy:ui-submenu\", [\"SubMenu\",], function(a, b, c, d) {\n    a.SubMenu = b(\"SubMenu\");\n}, 3);\n__d(\"AsyncMenu\", [\"AsyncRequest\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncRequest\"), h = b(\"copyProperties\");\n    function i() {\n    \n    };\n;\n    h(i.prototype, {\n        _uri: null,\n        _elem: null,\n        init: function(j, k) {\n            this._uri = j;\n            this._elem = k;\n        },\n        load: function() {\n            this.load = bagofholding;\n            g.bootstrap(this._uri, this._elem);\n        }\n    });\n    e.exports = i;\n});\n__d(\"legacy:ui-asyncmenu\", [\"AsyncMenu\",], function(a, b, c, d) {\n    a.AsyncMenu = b(\"AsyncMenu\");\n}, 3);\nfunction FutureSideNav() {\n    ((FutureSideNav.instance && FutureSideNav.instance.uninstall()));\n    FutureSideNav.instance = this;\n};\n;\nFutureSideNav.instance = null;\nFutureSideNav.getInstance = function() {\n    return ((FutureSideNav.instance || new FutureSideNav()));\n};\ncopyProperties(FutureSideNav.prototype, {\n    init: function(a, b, c) {\n        this.root = a;\n        this.items = {\n        };\n        this.sections = {\n        };\n        this.editor = null;\n        this.editing = false;\n        this.selected = null;\n        this.loading = null;\n        this.keyParam = \"sk\";\n        this.defaultKey = b;\n        this.uri = URI.getRequestURI();\n        this.ajaxPipe = c;\n        this.ajaxPipeEndpoints = {\n        };\n        this.sidecol = true;\n        this._installed = true;\n        this._handlePageTransitions = true;\n        PageTransitions.registerHandler(function(d) {\n            return ((this._handlePageTransitions && this.handlePageTransition(d)));\n        }.bind(this));\n        this._eventHandlers = [];\n        this._arbiterSubscriptions = [Arbiter.subscribe(NavigationMessage.NAVIGATION_COMPLETED, this.navigationComplete.bind(this)),Arbiter.subscribe(NavigationMessage.NAVIGATION_FAILED, this.navigationFailed.bind(this)),Arbiter.subscribe(NavigationMessage.NAVIGATION_COUNT_UPDATE, this.navigationCountUpdate.bind(this)),Arbiter.subscribe(NavigationMessage.NAVIGATION_SELECT, this.navigationSelect.bind(this)),Arbiter.subscribe(ChannelConstants.getArbiterType(\"nav_update_counts\"), this.navigationCountUpdateFromPresence.bind(this)),];\n        this._explicitHover = [];\n        this._ensureHover(\"sideNavItem\");\n        this._eventHandlers.push(JSBNG__Event.listen(window, \"resize\", this._handleResize.bind(this)));\n        this._checkNarrow();\n        this._selectorSubscriptions = [];\n        ((window.Selector && this._selectorSubscriptions.push(Selector.subscribe([\"open\",\"close\",], function(d, e) {\n            var f = Parent.byClass(e.selector, \"sideNavItem\");\n            ((f && CSS.conditionClass(f, \"editMenuOpened\", ((d === \"open\")))));\n        }))));\n        JSBNG__onleaveRegister(this.uninstall.bind(this));\n        if (this._pendingSections) {\n            this._pendingSections.forEach(function(d) {\n                this.initSection.apply(this, d);\n            }.bind(this));\n        }\n    ;\n    ;\n    },\n    _handleResize: (function() {\n        var a;\n        return function() {\n            ((a && JSBNG__clearTimeout(a)));\n            a = this._checkNarrow.bind(this).defer(200);\n        };\n    })(),\n    _checkNarrow: function() {\n        CSS.conditionClass(this.root, \"uiNarrowSideNav\", ((Vector2.getElementPosition(this.root).x < 20)));\n    },\n    _ensureHover: function(a) {\n        if (((ua.ie() < 8))) {\n            Bootloader.loadComponents(\"explicit-hover\", function() {\n                this._explicitHover.push(new ExplicitHover(this.root, a));\n            }.bind(this));\n        }\n    ;\n    ;\n    },\n    uninstall: function() {\n        if (this._installed) {\n            this._installed = false;\n            this._handlePageTransitions = false;\n            this._arbiterSubscriptions.forEach(Arbiter.unsubscribe);\n            this._selectorSubscriptions.forEach(function(a) {\n                Selector.unsubscribe(a);\n            });\n            this._eventHandlers.forEach(function(a) {\n                a.remove();\n            });\n            this._explicitHover.forEach(function(a) {\n                a.uninstall();\n            });\n        }\n    ;\n    ;\n    },\n    initSection: function(a, b) {\n        if (!this._installed) {\n            this._pendingSections = ((this._pendingSections || []));\n            this._pendingSections.push(arguments);\n            return;\n        }\n    ;\n    ;\n        this._initItems(b);\n        this._initSection(a);\n    },\n    addItem: function(a, b) {\n        this._initItem(a, b);\n    },\n    _initItems: function(a) {\n        var b = function(c, d) {\n            var e = this._initItem(c, d);\n            if (c.children) {\n                c.children.forEach(function(f) {\n                    b(f, e);\n                });\n            }\n        ;\n        ;\n        }.bind(this);\n        $A(a).forEach(function(c) {\n            b(c, null);\n        });\n    },\n    _initItem: function(a, b) {\n        var c = this.items[a.id] = this._constructItem(a, b);\n        if (((c.equals(this.selected) || a.selected))) {\n            this.setSelected(c);\n        }\n    ;\n    ;\n        var d = c.getLinkNode();\n        ((d && this._eventHandlers.push(JSBNG__Event.listen(d, \"click\", function(JSBNG__event) {\n            return !this.editing;\n        }.bind(this)))));\n        return c;\n    },\n    _initSection: function(a) {\n        var b = this.sections[a.id] = this._constructSection(a);\n        this._eventHandlers.push(JSBNG__Event.listen(b.node, \"click\", this.handleSectionClick.bind(this, b)));\n        DOM.scry(b.node, \"div.bookmarksMenuButton\").forEach(CSS.show);\n        return b;\n    },\n    _constructItem: function(a, b) {\n        return new FutureSideNavItem(a, b);\n    },\n    _constructSection: function(a) {\n        return new FutureSideNavSection(a);\n    },\n    handleSectionClick: function(a, JSBNG__event) {\n        var b = this._getEventTarget(JSBNG__event, \"a\"), c = this._getItemForNode(b);\n        if (!b) {\n            return;\n        }\n         else if (CSS.hasClass(b.parentNode, \"uiMenuItem\")) {\n            this._handleMenuClick(a, c, b.parentNode, JSBNG__event);\n        }\n         else this._handleLinkClick(a, b, JSBNG__event);\n        \n    ;\n    ;\n    },\n    _getEventTarget: function(JSBNG__event, a) {\n        var b = JSBNG__event.getTarget();\n        if (((b.tagName !== a.toUpperCase()))) {\n            return Parent.byTag(b, a);\n        }\n         else return b\n    ;\n    },\n    _handleMenuClick: function(a, b, c, JSBNG__event) {\n        if (CSS.hasClass(c, \"rearrange\")) {\n            this.beginEdit(a);\n        }\n    ;\n    ;\n    },\n    _handleLinkClick: function(a, b, JSBNG__event) {\n        if (CSS.hasClass(b, \"navEditDone\")) {\n            ((this.editing ? this.endEdit() : this.beginEdit(a)));\n            JSBNG__event.kill();\n        }\n    ;\n    ;\n    },\n    getItem: function(a) {\n        if (this._isCurrentPath(a)) {\n            return this._getItemForKey(((this._getKey(a.getQueryData()) || this.defaultKey)));\n        }\n         else return this._getItemForPath(a.getPath())\n    ;\n    },\n    getNodeForKey: function(a) {\n        var b = this._getItemForKey(a);\n        if (b) {\n            return b.node;\n        }\n    ;\n    ;\n    },\n    _isCurrentPath: function(a) {\n        return ((((a.getDomain() === this.uri.getDomain())) && ((a.getPath() === this.uri.getPath()))));\n    },\n    _getKey: function(a) {\n        return a[this.keyParam];\n    },\n    _getItemForNode: function(a) {\n        a = Parent.byClass(a, \"sideNavItem\");\n        return ((a && this.items[a.id]));\n    },\n    _getItemForKey: function(a) {\n        return this._findItem(function(b) {\n            return b.matchKey(a);\n        });\n    },\n    _getItemForPath: function(a) {\n        return this._findItem(function(b) {\n            return b.matchPath(a);\n        });\n    },\n    _findItem: function(a) {\n        for (var b in this.items) {\n            if (a(this.items[b])) {\n                return this.items[b];\n            }\n        ;\n        ;\n        };\n    ;\n    },\n    removeItem: function(a) {\n        if (((a && this.items[a.id]))) {\n            DOM.remove(a.node);\n            delete this.items[a.id];\n        }\n    ;\n    ;\n    },\n    removeItemByKey: function(a) {\n        this.removeItem(this._getItemForKey(a));\n    },\n    moveItem: function(a, b, c) {\n        var d = DOM.JSBNG__find(a.node, \"ul.uiSideNav\");\n        ((c ? DOM.prependContent : DOM.appendContent))(d, b.node);\n    },\n    setLoading: function(a) {\n        ((this.loading && this.loading.hideLoading()));\n        this.loading = a;\n        ((this.loading && this.loading.showLoading()));\n    },\n    setSelected: function(a) {\n        this.setLoading(null);\n        if (this.selected) {\n            this.selected.hideSelected();\n            this.selected.getTop().hideChildren();\n        }\n    ;\n    ;\n        this.selected = a;\n        if (this.selected) {\n            this.selected.showSelected();\n            this.selected.getTop().showChildren();\n        }\n    ;\n    ;\n    },\n    handlePageTransition: function(a) {\n        var b = this.getItem(a), c = ((((b && b.endpoint)) && this._doPageTransition(b, a)));\n        return c;\n    },\n    _doPageTransition: function(a, b) {\n        this.setLoading(a);\n        this._sendPageTransition(a.endpoint, copyProperties(this._getTransitionData(a, b), b.getQueryData()));\n        return true;\n    },\n    _sendPageTransition: function(a, b) {\n        b.endpoint = a;\n        Arbiter.inform(NavigationMessage.NAVIGATION_BEGIN, {\n            useAjaxPipe: this._useAjaxPipe(a),\n            params: b\n        });\n    },\n    _getTransitionData: function(a, b) {\n        var c = {\n        };\n        c.sidecol = this.sidecol;\n        c.path = b.getPath();\n        c[this.keyParam] = a.textKey;\n        c.key = a.textKey;\n        return c;\n    },\n    _useAjaxPipe: function(a) {\n        return ((this.ajaxPipe || this.ajaxPipeEndpoints[a]));\n    },\n    navigationComplete: function() {\n        ((this.loading && this.setSelected(this.loading)));\n    },\n    navigationFailed: function() {\n        this.setLoading(null);\n    },\n    navigationSelect: function(a, b) {\n        var c = this._getItemForKey(this._getKey(b));\n        if (b.asLoading) {\n            this.setLoading(c);\n        }\n         else this.setSelected(c);\n    ;\n    ;\n    },\n    navigationCountUpdate: function(a, b) {\n        var c = this._getItemForKey(((b && b.key)));\n        if (c) {\n            if (((typeof b.count !== \"undefined\"))) {\n                c.setCount(b.count, b.hide);\n            }\n             else if (((typeof b.increment !== \"undefined\"))) {\n                c.incrementCount(b.increment, b.hide);\n            }\n            \n        ;\n        }\n    ;\n    ;\n    },\n    navigationCountUpdateFromPresence: function(a, b) {\n        b = b.obj;\n        if (b) {\n            if (((!b.class_name || ((b.class_name && CSS.hasClass(this.root, b.class_name)))))) {\n                if (b.items) {\n                    for (var c = 0; ((c < b.items.length)); c++) {\n                        this.navigationCountUpdate(a, b.items[c]);\n                    ;\n                    };\n                }\n            ;\n            }\n        ;\n        }\n    ;\n    ;\n    },\n    beginEdit: function(a) {\n        if (!this.editing) {\n            this.editing = true;\n            CSS.addClass(this.root, \"editMode\");\n            this._updateTrackingData();\n            Bootloader.loadComponents(\"sortable-side-nav-js\", this._initEditor.bind(this, a));\n        }\n    ;\n    ;\n    },\n    endEdit: function() {\n        if (this.editing) {\n            CSS.removeClass(this.root, \"editMode\");\n            this.editor.endEdit();\n            this.editor = null;\n            this.editing = false;\n            this._updateTrackingData();\n        }\n    ;\n    ;\n    },\n    _updateTrackingData: function(a) {\n        var b = ((this.root.getAttribute(\"data-gt\") || \"{}\"));\n        try {\n            b = JSON.parse(b);\n            if (this.editing) {\n                b.editing = true;\n            }\n             else delete b.editing;\n        ;\n        ;\n            this.root.setAttribute(\"data-gt\", JSON.stringify(b));\n        } catch (c) {\n        \n        };\n    ;\n    },\n    _initEditor: function(a) {\n        this.editor = a.getEditor();\n        this.editor.beginEdit();\n    }\n});\nfunction FutureSideNavSection(a) {\n    this.id = a.id;\n    this.node = ((this.node || $(a.id)));\n    this.editEndpoint = a.editEndpoint;\n};\n;\ncopyProperties(FutureSideNavSection.prototype, {\n    equals: function(a) {\n        return ((a && ((a.id === this.id))));\n    },\n    getEditor: function() {\n        return new SortableSideNav(DOM.JSBNG__find(this.node, \"ul.uiSideNav\"), this.editEndpoint);\n    }\n});\nfunction FutureSideNavItem(a, b) {\n    this.id = a.id;\n    this.up = b;\n    this.endpoint = a.endpoint;\n    this.type = a.type;\n    this.node = ((a.node || $(a.id)));\n    this.paths = ((a.path ? $A(a.path) : []));\n    this.keys = ((a.key ? $A(a.key) : []));\n    var c = this._findKeys(this.keys);\n    this.numericKey = ((c.numeric || this.keys[0]));\n    this.textKey = ((c.text || this.keys[0]));\n    this._pathPattern = this._buildRegex(this.paths);\n    this._keyPattern = this._buildRegex(this.keys);\n    this.hideLoading();\n    this.hideSelected();\n};\n;\ncopyProperties(FutureSideNavItem.prototype, {\n    equals: function(a) {\n        return ((a && ((a.id === this.id))));\n    },\n    getLinkNode: function() {\n        return ((DOM.scry(this.node, \"a.item\")[0] || DOM.scry(this.node, \"a.subitem\")[0]));\n    },\n    matchPath: function(a) {\n        return this._matchInput(this._pathPattern, a);\n    },\n    matchKey: function(a) {\n        return this._matchInput(this._keyPattern, a);\n    },\n    _matchInput: function(a, b) {\n        var c = ((a && a.exec(b)));\n        return ((c && c.slice(1)));\n    },\n    getTop: function() {\n        return ((this.isTop() ? this : this.up.getTop()));\n    },\n    isTop: function(a) {\n        return !this.up;\n    },\n    setCount: function(a, b) {\n        return this._updateCount(a, true);\n    },\n    incrementCount: function(a, b) {\n        return this._updateCount(a, false);\n    },\n    _updateCount: function(a, b, c) {\n        var d = DOM.scry(this.node, \"span.count\")[0], e = ((d && DOM.scry(d, \"span.countValue\")[0]));\n        if (e) {\n            var f = ((b ? 0 : parseInt(DOM.getText(e), 10))), g = Math.max(0, ((f + a))), h = ((this.isTop() ? \"hidden\" : \"hiddenSubitem\"));\n            DOM.setContent(e, g);\n            ((c && CSS.conditionClass(this.node, h, !g)));\n            CSS.conditionClass(d, \"hidden_elem\", !g);\n            if (this.isTop()) {\n                var i = DOM.scry(this.node, \"div.linkWrap\")[0];\n                if (i) {\n                    CSS.conditionClass(i, \"noCount\", !g);\n                    CSS.conditionClass(i, \"hasCount\", g);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        Arbiter.inform(\"NavigationMessage.COUNT_UPDATE_DONE\");\n    },\n    showLoading: function() {\n        CSS.addClass(this.node, \"loading\");\n    },\n    hideLoading: function() {\n        CSS.removeClass(this.node, \"loading\");\n    },\n    showSelected: function() {\n        CSS.addClass(this.node, \"selectedItem\");\n        ((CSS.hasClass(this.node, \"hider\") && CSS.addClass(this._getExpanderParent(), \"expandedMode\")));\n    },\n    hideSelected: function() {\n        CSS.removeClass(this.node, \"selectedItem\");\n    },\n    showChildren: function() {\n        CSS.addClass(this.node, \"open\");\n    },\n    hideChildren: function() {\n        CSS.removeClass(this.node, \"open\");\n    },\n    _getExpanderParent: function() {\n        return Parent.byClass(this.node, \"expandableSideNav\");\n    },\n    _buildRegex: function(a) {\n        if (a.length) {\n            var b = a.map(function(c) {\n                if (((typeof c === \"string\"))) {\n                    return c.replace(/([^a-z0-9_])/gi, \"\\\\$1\");\n                }\n                 else if (((c && c.regex))) {\n                    return c.regex;\n                }\n                \n            ;\n            ;\n            });\n            return new RegExp(((((\"^(?:\" + b.join(\"|\"))) + \")$\")));\n        }\n    ;\n    ;\n    },\n    _findKeys: function(a) {\n        var b = /^(app|group|fl)_/, c = {\n        };\n        for (var d = 0; ((d < a.length)); d++) {\n            var e = b.test(a[d]);\n            if (((e && !c.numeric))) {\n                c.numeric = a[d];\n            }\n             else if (((!e && !c.text))) {\n                c.text = a[d];\n            }\n            \n        ;\n        ;\n            if (((c.numeric && c.text))) {\n                break;\n            }\n        ;\n        ;\n        };\n    ;\n        return c;\n    }\n});\n__d(\"legacy:LayerDestroyOnHide\", [\"LayerDestroyOnHide\",], function(a, b, c, d) {\n    a.LayerDestroyOnHide = b(\"LayerDestroyOnHide\");\n}, 3);\n__d(\"legacy:ContextualDialogX\", [\"ContextualDialogX\",], function(a, b, c, d) {\n    a.ContextualDialogX = b(\"ContextualDialogX\");\n}, 3);\n__d(\"legacy:Tooltip\", [\"Tooltip\",], function(a, b, c, d) {\n    a.Tooltip = b(\"Tooltip\");\n}, 3);\n__d(\"ClearableTypeahead\", [\"event-extensions\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = {\n        resetOnCloseButtonClick: function(h, i) {\n            JSBNG__Event.listen(i, \"click\", function() {\n                var j = h.getCore();\n                j.reset();\n                j.getElement().JSBNG__focus();\n            });\n        }\n    };\n    e.exports = g;\n});\n__d(\"TypeaheadAreaCore\", [\"Class\",\"InputSelection\",\"TypeaheadCore\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Class\"), h = b(\"InputSelection\"), i = b(\"TypeaheadCore\"), j = b(\"copyProperties\");\n    function k(l) {\n        this.parent.construct(this, l);\n        this.matcher = new RegExp(((this.matcher + \"$\")));\n        this.preventFocusChangeOnTab = true;\n    };\n;\n    g.extend(k, i);\n    j(k.prototype, {\n        prefix: \"\",\n        suffix: \", \",\n        matcher: \"\\\\b[^,]*\",\n        click: bagofholding,\n        select: function(l) {\n            this.parent.select(l);\n            var m = this.element.value, n = ((((this.prefix + l.text)) + this.suffix));\n            this.expandBounds(m, n);\n            var o = m.substring(0, this.start), p = m.substring(this.end);\n            this.element.value = ((((o + n)) + p));\n            h.set(this.element, ((o.length + n.length)));\n        },\n        expandBounds: function(l, m) {\n            l = l.toLowerCase().trim();\n            m = m.toLowerCase();\n            var n, o, p, q, r = /\\s/;\n            o = l.substring(this.start, this.end);\n            p = m.indexOf(o);\n            n = this.start;\n            while (((((n >= 0)) && ((p >= 0))))) {\n                q = l.charAt(((n - 1)));\n                if (((!q || r.test(q)))) {\n                    this.start = n;\n                }\n            ;\n            ;\n                o = ((q + o));\n                p = m.indexOf(o);\n                n--;\n            };\n        ;\n            o = l.substring(this.start, this.end);\n            p = m.indexOf(o);\n            n = this.end;\n            while (((((n <= l.length)) && ((p >= 0))))) {\n                q = l.charAt(n);\n                if (((!q || r.test(q)))) {\n                    this.end = n;\n                }\n            ;\n            ;\n                o = ((o + q));\n                p = m.indexOf(o);\n                n++;\n            };\n        ;\n        },\n        getRawValue: function() {\n            var l = ((h.get(this.element).start || 0));\n            return this.parent.getValue().substring(0, l);\n        },\n        getValue: function() {\n            var l = ((this.matcher && this.matcher.exec(this.getRawValue())));\n            if (!l) {\n                return \"\";\n            }\n        ;\n        ;\n            var m = l[0], n = ((l.index + m.length));\n            m = m.replace(/^\\s/, \"\");\n            var o = m.length;\n            m = m.replace(/\\s$/, \"\");\n            var p = ((o - m.length));\n            this.start = ((n - o));\n            this.end = ((n + p));\n            return ((l[1] || l[0]));\n        }\n    });\n    e.exports = k;\n});\n__d(\"TypeaheadMetrics\", [\"event-extensions\",\"AsyncRequest\",\"copyProperties\",\"Typeahead\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"AsyncRequest\"), h = b(\"copyProperties\"), i = b(\"Typeahead\");\n    function j(k) {\n        this.extraData = {\n        };\n        h(this, k);\n    };\n;\n    h(j.prototype, {\n        endPoint: \"/ajax/typeahead/record_basic_metrics.php\",\n        init: function(k) {\n            this.init = bagofholding;\n            this.core = k.getCore();\n            this.view = k.getView();\n            this.data = k.getData();\n            this.stats = {\n            };\n            this.sessionActive = false;\n            this._sessionStartEvents = [];\n            this._sessionEndEvents = [];\n            this._reset();\n            this.initEvents();\n        },\n        _reset: function() {\n            this.stats = {\n            };\n            this.avgStats = {\n            };\n            this.sessionActive = false;\n            this.sid = Math.floor(((JSBNG__Date.now() * Math.JSBNG__random())));\n            this.data.setQueryData({\n                sid: this.sid\n            });\n        },\n        recordSelect: function(k) {\n            var l = k.selected;\n            if (((l.uid == null))) {\n                this.recordStat(\"selected_id\", \"SELECT_NULL\");\n            }\n             else this.recordStat(\"selected_id\", l.uid);\n        ;\n        ;\n            this.recordStat(\"selected_type\", l.type);\n            this.recordStat(\"selected_position\", k.index);\n            this.recordStat(\"selected_with_mouse\", ((k.clicked ? 1 : 0)));\n            this._sessionEnd();\n        },\n        bindSessionStart: function(k, JSBNG__event, l) {\n            if (l) {\n                for (var m = 0; ((m < this._sessionStartEvents.length)); ++m) {\n                    var n = this._sessionStartEvents[m];\n                    n.obj.unsubscribe(n.token);\n                };\n            }\n        ;\n        ;\n            this._sessionStartEvents.push({\n                obj: k,\n                token: k.subscribe(JSBNG__event, function(o, p) {\n                    this._sessionStart();\n                }.bind(this))\n            });\n        },\n        bindSessionEnd: function(k, JSBNG__event, l) {\n            if (l) {\n                for (var m = 0; ((m < this._sessionEndEvents.length)); ++m) {\n                    var n = this._sessionEndEvents[m];\n                    n.obj.unsubscribe(n.token);\n                };\n            }\n        ;\n        ;\n            this._sessionEndEvents.push({\n                obj: k,\n                token: k.subscribe(JSBNG__event, function(o, p) {\n                    this._sessionEnd();\n                }.bind(this))\n            });\n        },\n        initEvents: function() {\n            this.bindSessionStart(this.core, \"JSBNG__focus\", false);\n            this.bindSessionEnd(this.core, \"JSBNG__blur\", false);\n            this.view.subscribe(\"select\", function(k, l) {\n                this.recordSelect(l);\n            }.bind(this));\n            this.bindSessionEnd(this.view, \"select\", false);\n            this.view.subscribe(\"render\", function(k, l) {\n                this.results = l;\n            }.bind(this));\n            this.data.subscribe(\"beforeQuery\", function(k, l) {\n                if (!l.value) {\n                    return;\n                }\n            ;\n            ;\n                this.query = l.value;\n                this.recordCountStat(\"num_queries\");\n            }.bind(this));\n            this.data.subscribe(\"beforeFetch\", function(k, l) {\n                if (l.fetch_context.bootstrap) {\n                    this.bootstrapBegin = JSBNG__Date.now();\n                }\n                 else l.fetch_context.queryBegin = JSBNG__Date.now();\n            ;\n            ;\n            }.bind(this));\n            this.data.subscribe(\"fetchComplete\", function(k, l) {\n                if (l.fetch_context.bootstrap) {\n                    this.recordAvgStat(\"bootstrap_latency\", ((JSBNG__Date.now() - this.bootstrapBegin)));\n                    var m = {\n                    };\n                    l.response.payload.entries.forEach(function(n) {\n                        if (!m[n.type]) {\n                            m[n.type] = 1;\n                        }\n                         else m[n.type]++;\n                    ;\n                    ;\n                    });\n                    this.recordStat(\"bootstrap_response_types\", m);\n                    this.bootstrapped = true;\n                }\n                 else this.recordAvgStat(\"avg_query_latency\", ((JSBNG__Date.now() - l.fetch_context.queryBegin)));\n            ;\n            ;\n            }.bind(this));\n            this.data.subscribe(\"dirty\", function(k, l) {\n                this.bootstrapped = false;\n            });\n        },\n        _sessionStart: function() {\n            if (this.sessionActive) {\n                return;\n            }\n        ;\n        ;\n            this.sessionActive = true;\n        },\n        _sessionEnd: function() {\n            if (!this.sessionActive) {\n                return;\n            }\n        ;\n        ;\n            this.sessionActive = false;\n            this.submit();\n            this._reset();\n        },\n        recordStat: function(k, l) {\n            this.stats[k] = l;\n        },\n        recordCountStat: function(k) {\n            var l = this.stats[k];\n            this.stats[k] = ((l ? ((l + 1)) : 1));\n        },\n        recordAvgStat: function(k, l) {\n            if (this.avgStats[k]) {\n                this.avgStats[k][0] += l;\n                ++this.avgStats[k][1];\n            }\n             else this.avgStats[k] = [l,1,];\n        ;\n        ;\n        },\n        submit: function() {\n            if (Object.keys(this.stats).length) {\n                h(this.stats, this.extraData);\n                if (this.results) {\n                    var k = (this.results).map(function(n, o) {\n                        return n.uid;\n                    });\n                    this.recordStat(\"candidate_results\", JSON.stringify(k));\n                }\n            ;\n            ;\n                if (this.query) {\n                    this.recordStat(\"query\", this.query);\n                }\n            ;\n            ;\n                if (this.sid) {\n                    this.recordStat(\"sid\", this.sid);\n                }\n            ;\n            ;\n                if (this.bootstrapped) {\n                    this.recordStat(\"bootstrapped\", 1);\n                }\n            ;\n            ;\n                for (var l in this.avgStats) {\n                    var m = this.avgStats[l];\n                    this.stats[l] = ((m[0] / m[1]));\n                };\n            ;\n                new g().setURI(this.endPoint).setMethod(\"POST\").setData({\n                    stats: this.stats\n                }).send();\n                this._reset();\n            }\n        ;\n        ;\n        }\n    });\n    j.register = function(k, l, m) {\n        if (((JSBNG__document.activeElement === k))) {\n            l.init(m);\n        }\n         else var n = JSBNG__Event.listen(k, \"JSBNG__focus\", function() {\n            l.init(m);\n            n.remove();\n        })\n    ;\n    };\n    e.exports = j;\n});\n__d(\"TypeaheadHoistFriends\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\");\n    function h(i) {\n        this._typeahead = i;\n    };\n;\n    g(h.prototype, {\n        _subscription: null,\n        enable: function() {\n            var i = this._typeahead.getView();\n            this._subscription = i.subscribe(\"beforeRender\", function(j, k) {\n                var l = [], m = [];\n                for (var n = 0; ((n < k.results.length)); ++n) {\n                    var o = k.results[n];\n                    if (((((o.type == \"user\")) && o.bootstrapped))) {\n                        m.push(o);\n                    }\n                     else l.push(o);\n                ;\n                ;\n                };\n            ;\n                k.results = m.concat(l);\n            });\n        },\n        disable: function() {\n            this._typeahead.getView().unsubscribe(this._subscription);\n            this._subscription = null;\n        }\n    });\n    e.exports = h;\n});\n__d(\"legacy:HoistFriendsTypeaheadBehavior\", [\"TypeaheadHoistFriends\",], function(a, b, c, d) {\n    var e = b(\"TypeaheadHoistFriends\");\n    if (!a.TypeaheadBehaviors) {\n        a.TypeaheadBehaviors = {\n        };\n    }\n;\n;\n    a.TypeaheadBehaviors.hoistFriends = function(f) {\n        f.enableBehavior(e);\n    };\n}, 3);\n__d(\"TypeaheadShowLoadingIndicator\", [\"CSS\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"copyProperties\");\n    function i(j) {\n        this._typeahead = j;\n    };\n;\n    h(i.prototype, {\n        _subscription: null,\n        enable: function() {\n            this._subscription = this._typeahead.subscribe(\"loading\", function(j, k) {\n                g.conditionClass(this._typeahead.getElement(), \"typeaheadLoading\", k.loading);\n                g.conditionClass(this._typeahead.getView().getElement(), \"typeaheadViewLoading\", k.loading);\n            }.bind(this));\n        },\n        disable: function() {\n            this._typeahead.unsubscribe(this._subscription);\n            this._subscription = null;\n        }\n    });\n    e.exports = i;\n});\n__d(\"legacy:ShowLoadingIndicatorTypeaheadBehavior\", [\"TypeaheadShowLoadingIndicator\",], function(a, b, c, d) {\n    var e = b(\"TypeaheadShowLoadingIndicator\");\n    if (!a.TypeaheadBehaviors) {\n        a.TypeaheadBehaviors = {\n        };\n    }\n;\n;\n    a.TypeaheadBehaviors.showLoadingIndicator = function(f) {\n        f.enableBehavior(e);\n    };\n}, 3);");
// 2829
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"JOZ9R\",]);\n}\n;\n;\n__d(\"legacy:ad-logging\", [\"Arbiter\",\"AsyncRequest\",\"collectDataAttributes\",], function(a, b, c, d) {\n    var e = b(\"Arbiter\"), f = b(\"AsyncRequest\"), g = b(\"collectDataAttributes\"), h = {\n    };\n    function i(l) {\n        return ((((((((l.getAttribute && ((l.getAttribute(\"ajaxify\") || l.getAttribute(\"data-endpoint\"))))) || l.action)) || l.href)) || l.JSBNG__name));\n    };\n;\n    function j(l, m) {\n        if (((m.doublelog && ((typeof (m.ei) === \"string\"))))) {\n            new f(\"/ajax/ssinfeed/end/\").setData({\n                doublelog: true,\n                ei: m.ei\n            }).setAllowCrossPageTransition(true).setMethod(\"POST\").send();\n        }\n         else if (((((l !== null)) && ((typeof (l.ei) === \"string\"))))) {\n            var n = JSBNG__Date.now(), o = 500;\n            l.duplicate_click = ((!!h[l.ei] && ((((n - h[l.ei])) < o))));\n            h[l.ei] = n;\n            new f(\"/ajax/ssinfeed/end/\").setData(l).setAllowCrossPageTransition(true).setMethod(\"POST\").send();\n        }\n        \n    ;\n    ;\n    };\n;\n    function k(l, m) {\n        if (!m.node) {\n            return;\n        }\n    ;\n    ;\n        var n = i(m.node);\n        if (((((!n || !m.JSBNG__event)) || ((m.JSBNG__event.type !== \"click\"))))) {\n            return;\n        }\n    ;\n    ;\n        var o = g(m.node, [\"ft\",\"ad\",]);\n        o.ft.href = n;\n        j(o.ft, o.ad);\n    };\n;\n    e.subscribe(\"UserAction/new\", k);\n}, 3);\nwindow.__UIControllerRegistry = ((window.__UIControllerRegistry || {\n}));\nPageletCache = ((window.PageletCache || {\n    init: function() {\n        try {\n            PageletCache._cache = window.JSBNG__sessionStorage;\n        } catch (a) {\n        \n        };\n    ;\n        Arbiter.subscribe(\"pre_page_transition\", PageletCache.cleanup);\n    },\n    _processBeforeWrite: function(a) {\n        Bootloader.setResourceMap(a.resource_map);\n        var b = ((a.css || [])).concat(((a.js || [])));\n        for (var c in ((a.bootloadable || {\n        }))) {\n            b.concat(a.bootloadable[c]);\n        ;\n        };\n    ;\n        a.resource_map = ((a.resource_map || {\n        }));\n        for (var d = 0; ((d < b.length)); d++) {\n            var e = b[d];\n            if (!a.resource_map[e]) {\n                a.resource_map[e] = Bootloader.resolveResources([e,])[0];\n            }\n        ;\n        ;\n        };\n    ;\n        if (((a.cache_type == \"overwrite\"))) {\n            delete a.JSBNG__onload;\n            delete a.JSBNG__onafterload;\n            delete a.jscc_map;\n            delete a.jsmods;\n        }\n    ;\n    ;\n    },\n    write: function(a, b) {\n        if (((!PageletCache._cache || ((a.cache_type == \"base\"))))) {\n            return;\n        }\n    ;\n    ;\n        var c = this.getAndParse(a.id), d = {\n        };\n        copyProperties(d, a);\n        try {\n            PageletCache._processBeforeWrite(d);\n            var f = true;\n            if (((a.id in PageletCache._pagelets))) {\n                f = false;\n            }\n        ;\n        ;\n            c[a.key] = d;\n            PageletCache._cache.setItem(a.id, JSON.stringify(c));\n            PageletCache._pagelets[a.id] = d;\n            if (f) {\n                this.subscribeToInstantiateController(a, b);\n            }\n        ;\n        ;\n        } catch (e) {\n        \n        };\n    ;\n    },\n    loadFromCache: function(a, b) {\n        var c = {\n        };\n        copyProperties(c, PageletCache.read(a));\n        if (is_empty(c)) {\n            return a;\n        }\n    ;\n    ;\n        c.id = a.id;\n        c.cache_hit = true;\n        c.display_dependency = a.display_dependency;\n        c.phase = a.phase;\n        c.is_last = a.is_last;\n        this.subscribeToInstantiateController(c, b);\n        return c;\n    },\n    read: function(a) {\n        if (!PageletCache._cache) {\n            return null;\n        }\n    ;\n    ;\n        var b = a.id;\n        if (((b.substr(0, 6) == \"cached\"))) {\n            b = b.substr(7);\n        }\n    ;\n    ;\n        var c = this.getAndParse(b);\n        if (((c && c[a.key]))) {\n            PageletCache._pagelets[b] = c[a.key];\n            PageletCache._cache_hits[b] = true;\n            return c[a.key];\n        }\n    ;\n    ;\n        if (((a.cache_type == \"update\"))) {\n            Bootloader.loadComponents([\"UIPagelet\",\"uri\",], function() {\n                UIPagelet.loadFromEndpoint(a.controller_class, b, URI.getNextURI().getQueryData(), {\n                    usePipe: true,\n                    pageletCacheMiss: a,\n                    automatic: true\n                });\n            });\n        }\n    ;\n    ;\n        return null;\n    },\n    getAndParse: function(a) {\n        var b = PageletCache._cache.getItem(a);\n        if (b) {\n            try {\n                return JSON.parse(b);\n            } catch (c) {\n            \n            };\n        }\n    ;\n    ;\n        return {\n        };\n    },\n    isCacheHit: function(a) {\n        return !!PageletCache._cache_hits[a];\n    },\n    cleanup: function() {\n        PageletCache._cache_hits = {\n        };\n    },\n    subscribeToInstantiateController: function(a, b) {\n        var c = b.subscribe(\"pagelet_event\", function(d, e) {\n            if (((((e.id == a.id)) && ((e.JSBNG__event == \"preonload\"))))) {\n                c.unsubscribe();\n                new window[a.cache_controller](a.id, a.cache_type);\n            }\n        ;\n        ;\n        });\n    },\n    _cache: null,\n    _pagelets: {\n    },\n    _cache_hits: {\n    }\n}));\nfunction PageletCacheController(a, b, c) {\n    if (!PageletCache) {\n        return;\n    }\n;\n;\n    if (!a) {\n        return;\n    }\n;\n;\n    this._cacheKey = a;\n    this._cacheType = b;\n    this._subscriptions = [];\n    this._controller = null;\n    this._registerSnapshot(c);\n    PageletCacheController._instances[a] = this;\n    PageletCache.takeSnapshot(a, null, this.handlePageletDOMOnSnapshot.bind(this));\n};\n;\ncopyProperties(PageletCacheController, {\n    registerController: function(a, b) {\n        if (((!a || !b))) {\n            return null;\n        }\n    ;\n    ;\n        var c = PageletCacheController._instances[a];\n        if (c) {\n            c.setController(b);\n            if (((((c._cacheType == \"update\")) && PageletCache.isCacheHit(a)))) {\n                JSBNG__onafterloadRegister_DEPRECATED(c.updateAfterload.bind(c, b));\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        return c;\n    },\n    _instances: {\n    }\n});\ncopyProperties(PageletCacheController.prototype, {\n    registerCleanup: function(a) {\n        this._subscriptions.push(Arbiter.subscribe(a, this._cleanup.bind(this)));\n    },\n    setController: function(a) {\n        this._controller = a;\n        return this;\n    },\n    loadData: function() {\n        return PageletCache.fetchData(this._cacheKey);\n    },\n    populateControllerDataOnSnapshot: bagofholding,\n    handlePageletDOMOnSnapshot: bagofholding,\n    updateAfterload: bagofholding,\n    _registerSnapshot: function(a) {\n        for (var b = 0; ((b < a.length)); b++) {\n            this._subscriptions.push(Arbiter.subscribe(a[b], this._update.bind(this)));\n        ;\n        };\n    ;\n    },\n    _update: function() {\n        if (!$(this._cacheKey)) {\n            this._cleanup();\n            return;\n        }\n    ;\n    ;\n        var a = ((this._controller ? this.populateControllerDataOnSnapshot.bind(this, this._controller) : bagofholding));\n        PageletCache.takeSnapshot(this._cacheKey, a, this.handlePageletDOMOnSnapshot.bind(this));\n    },\n    _cleanup: function() {\n        this._subscriptions.forEach(Arbiter.unsubscribe);\n        this._subscriptions.length = 0;\n        delete PageletCacheController._instances[this._cacheKey];\n    }\n});\ncopyProperties(PageletCache, {\n    takeSnapshot: function(a, b, c) {\n        var d = PageletCache._pagelets[a];\n        if (d) {\n            var e = $(a);\n            if (e) {\n                var f = e.cloneNode(true);\n                if (c) {\n                    c(f);\n                }\n            ;\n            ;\n                d.JSBNG__content[a] = f.innerHTML;\n                if (b) {\n                    if (!d.data) {\n                        d.data = {\n                        };\n                    }\n                ;\n                ;\n                    b(d.data);\n                }\n            ;\n            ;\n                PageletCache.write(d);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    fetchData: function(a, b) {\n        var c = PageletCache._pagelets[a];\n        if (((c && c.data))) {\n            if (b) {\n                return c.data[b];\n            }\n             else return c.data\n        ;\n        }\n    ;\n    ;\n    }\n});\nfunction HomeNavigationCache(a, b) {\n    this.parent.construct(this, a, b, [\"NavigationMessage.FAVORITES_UPDATED\",]);\n};\n;\nClass.extend(HomeNavigationCache, \"PageletCacheController\");\ncopyProperties(HomeNavigationCache.prototype, {\n    handlePageletDOMOnSnapshot: function(a) {\n        var b = DOM.scry(a, \"li.sideNavItem\");\n        if (((b.length === 0))) {\n            return;\n        }\n    ;\n    ;\n        for (var c = 0; ((c < b.length)); c++) {\n            var d = b[c];\n            if (((d.id == \"navItem_app_4748854339\"))) {\n                CSS.addClass(d, \"selectedItem\");\n            }\n             else if (CSS.hasClass(d, \"selectedItem\")) {\n                CSS.removeClass(d, \"selectedItem\");\n                CSS.removeClass(d, \"open\");\n            }\n            \n        ;\n        ;\n            CSS.removeClass(d, \"loading\");\n        };\n    ;\n        var e = DOM.scry(a, \".uiFutureSideNav\")[0];\n        if (e) {\n            CSS.addClass(e, \"hideNavCounts\");\n        }\n    ;\n    ;\n    }\n});\n__d(\"legacy:DOMPosition\", [\"DOMPosition\",], function(a, b, c, d) {\n    var e = b(\"DOMPosition\");\n    a.DOMPosition = e;\n}, 3);\nvar NewHigh = {\n    reset: function() {\n        this.initialized = false;\n    },\n    ensureInitialized: function() {\n        if (this.initialized) {\n            return;\n        }\n    ;\n    ;\n        this.button = DOM.scry(JSBNG__document.body, \"a.stream_header_button\")[0];\n        this.composer = DOM.scry(JSBNG__document.body, \"div.UIComposer\")[0];\n        this.buttonArea = DOM.scry(this.composer, \"div.UIComposer_ButtonArea\")[0];\n        this.initialized = true;\n    },\n    showComposer: function(a) {\n        this.ensureInitialized();\n        if (this.composer) {\n            CSS.show(this.composer);\n            UIComposer.focusInstance(this.composer.id);\n            var b = UIComposer.getInstance(this.composer.id);\n            ((b && b.loadAttachment(parseInt(a, 10))));\n        }\n    ;\n    ;\n        ((this.button && CSS.hide(this.button)));\n    },\n    hideComposer: function(a) {\n        this.ensureInitialized();\n        if (this.composer) {\n            var b = UIComposer.getInstance(this.composer.id);\n            if (!a) {\n                ((((b && b.initialized)) && b.JSBNG__blur()));\n                CSS.hide(this.composer);\n                ((this.button && CSS.show(this.button)));\n            }\n             else {\n                ((((b && b.initialized)) && b.loadAttachment(0)));\n                CSS.show(this.composer);\n                ((this.buttonArea && CSS.hide(this.buttonArea)));\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    }\n};\n__d(\"UIIntentionalStreamRefresh\", [\"Arbiter\",\"LiveTimer\",\"Run\",\"UIIntentionalStreamMessage\",\"UserActivity\",\"coalesce\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"LiveTimer\"), i = b(\"Run\"), j = b(\"UIIntentionalStreamMessage\"), k = b(\"UserActivity\"), l = b(\"coalesce\"), m = b(\"copyProperties\");\n    function n(o, p) {\n        this.isAutoRefreshing = false;\n        this.lastRefresh = JSBNG__Date.now();\n        n.instance = this;\n        this.setAutoRefreshConfig(o);\n        this.updateConfigHandler = g.subscribe(j.UPDATE_AUTOREFRESH_CONFIG, this.updateAutoRefreshConfig.bind(this));\n        this.updateRefreshTimeHandler = g.subscribe(j.UPDATE_LAST_REFRESH_TIME, this.updateLastRefreshTime.bind(this));\n        i.JSBNG__onLeave(this.unload.bind(this));\n        this.userActivity();\n        this.uaToken = k.subscribe(this.userActivity.bind(this));\n        this.autoRefreshInterval = JSBNG__setInterval(this.checkAutoPageRefresh.bind(this), this.checkAutoRefreshTimeInterval);\n        this.activeRefreshInterval = JSBNG__setInterval(this.checkActiveRefresh.bind(this), this.checkActiveRefreshTimeInterval);\n        this.enableAutoRefresh(p);\n        g.subscribe(j.UPDATE_STREAM, h.loop.bind(h, true));\n        g.subscribe(j.REFRESH_STREAM, h.loop.bind(h, true));\n    };\n;\n    m(n, {\n        DISABLE_AUTOREFRESH_TIME: ((((4 * 60)) * 1000)),\n        CHECK_AUTOREFRESH_INTERVAL: ((((5 * 60)) * 1000)),\n        AUTOREFRESH_INACTIVE_TIME: ((((30 * 60)) * 1000)),\n        CHECK_ACTIVE_REFRESH_TIME: ((((5 * 60)) * 1000)),\n        ACTIVE_REFRESH_TIME: ((30 * 1000))\n    });\n    m(n.prototype, {\n        updateAutoRefreshConfig: function(o, p) {\n            if (((o == j.UPDATE_AUTOREFRESH_CONFIG))) {\n                this.setAutoRefreshConfig(p);\n            }\n        ;\n        ;\n        },\n        updateLastRefreshTime: function(o) {\n            if (((o == j.UPDATE_LAST_REFRESH_TIME))) {\n                this.lastRefresh = JSBNG__Date.now();\n            }\n        ;\n        ;\n        },\n        setAutoRefreshConfig: function(o) {\n            o = ((o || {\n            }));\n            var p = ((((((24 * 60)) * 60)) * 1000));\n            if (!this.storyInterval) {\n                this.storyInterval = l(o.story_interval, null);\n            }\n        ;\n        ;\n            this.allowAutoRefresh = l(o.allow_auto_refresh, false);\n            this.inactiveThreshold = l(o.inactive_threshold, 0);\n            this.activeRefreshTime = l(o.fast_refresh_rate, p);\n            this.inactiveRefreshTime = l(o.slow_refresh_rate, p);\n            this.allowPolling = l(o.allow_polling, false);\n            this.refreshFactor = l(o.refresh_factor, 10);\n            this.minRefreshInterval = l(o.min_refresh_interval, ((60 * 1000)));\n            this.activeRefresh = l(o.active_refresh, false);\n            this.checkActiveRefreshTimeInterval = l(o.check_active_refresh_interval, n.CHECK_ACTIVE_REFRESH_TIME);\n            this.activeRefreshTimeInterval = l(o.active_refresh_interval, n.ACTIVE_REFRESH_TIME);\n            this.disableAutoRefreshTime = l(o.disable_autorefresh_time, n.DISABLE_AUTOREFRESH_TIME);\n            this.checkAutoRefreshTimeInterval = l(o.check_autorefresh_time_interval, n.CHECK_AUTOREFRESH_INTERVAL);\n            this.autoRefreshInactiveTime = l(o.autorefresh_inactive_time, n.AUTOREFRESH_INACTIVE_TIME);\n            return this;\n        },\n        unload: function() {\n            this.enableAutoRefresh(false);\n            this.cleanupRefreshInterval();\n            k.unsubscribe(this.uaToken);\n            ((this.updateConfigHandler && this.updateConfigHandler.unsubscribe()));\n            ((this.updateRefreshTimeHandler && this.updateRefreshTimeHandler.unsubscribe()));\n        },\n        userActivity: function() {\n            var o = this.isInactive();\n            this.lastActivity = JSBNG__Date.now();\n            this.isAutoRefreshing = true;\n            if (((o && this.canAutoRefresh()))) {\n                this.runAutoRefresh();\n            }\n        ;\n        ;\n            return true;\n        },\n        isInactive: function() {\n            return ((this.getMSSinceLastActivity() > this.inactiveThreshold));\n        },\n        getMSSinceLastActivity: function() {\n            return ((JSBNG__Date.now() - this.lastActivity));\n        },\n        getMSSinceLastRefresh: function() {\n            return ((JSBNG__Date.now() - this.lastRefresh));\n        },\n        getRefreshInterval: function() {\n            if (this.isInactive()) {\n                return this.inactiveRefreshTime;\n            }\n             else if (((this.storyInterval != null))) {\n                var o = ((this.storyInterval * this.refreshFactor));\n                return Math.max(o, this.activeRefreshTime);\n            }\n             else return this.activeRefreshTime\n            \n        ;\n        },\n        canAutoRefresh: function() {\n            return ((this.isAutoRefreshing && this.allowAutoRefresh));\n        },\n        cancelUpdate: function() {\n            if (this.updateTask) {\n                JSBNG__clearTimeout(this.updateTask);\n                this.updateTask = null;\n            }\n        ;\n        ;\n        },\n        runUpdatePoll: function() {\n            this.updateTask = null;\n            if (this.canAutoRefresh()) {\n                this.runAutoRefresh();\n            }\n        ;\n        ;\n        },\n        runAutoRefresh: function() {\n            var o = 50;\n            if (((this.getMSSinceLastRefresh() >= ((this.minRefreshInterval - o))))) {\n                g.inform(j.UPDATE_STREAM);\n            }\n        ;\n        ;\n            this.schedulePoll(this.getRefreshInterval());\n        },\n        schedulePoll: function(o) {\n            this.cancelUpdate();\n            if (this.allowPolling) {\n                this.updateTask = JSBNG__setTimeout(this.runUpdatePoll.bind(this), o);\n            }\n        ;\n        ;\n        },\n        enableAutoRefresh: function(o, p) {\n            this.isAutoRefreshing = o;\n            if (o) {\n                var q = ((p ? 0 : this.getRefreshInterval()));\n                this.schedulePoll(q);\n            }\n             else this.cancelUpdate();\n        ;\n        ;\n        },\n        checkAutoPageRefresh: function() {\n            if (!this.allowAutoRefresh) {\n                return;\n            }\n        ;\n        ;\n            if (((this.isAutoRefreshing && ((this.getMSSinceLastActivity() > this.disableAutoRefreshTime))))) {\n                this.isAutoRefreshing = false;\n            }\n        ;\n        ;\n            if (((this.getMSSinceLastRefresh() < this.autoRefreshInactiveTime))) {\n                return;\n            }\n        ;\n        ;\n            var o = this.getMSSinceLastActivity();\n            if (((o > this.autoRefreshInactiveTime))) {\n                g.inform(j.REFRESH_STREAM, {\n                });\n            }\n        ;\n        ;\n        },\n        checkActiveRefresh: function() {\n            if (!this.allowAutoRefresh) {\n                return;\n            }\n        ;\n        ;\n            if (((this.getMSSinceLastRefresh() < this.activeRefreshTimeInterval))) {\n                return;\n            }\n        ;\n        ;\n            if (((this.getMSSinceLastActivity() < this.activeRefreshTimeInterval))) {\n                g.inform(j.UPDATE_STREAM);\n            }\n        ;\n        ;\n        },\n        cleanupRefreshInterval: function() {\n            if (this.autoRefreshInterval) {\n                JSBNG__clearInterval(this.autoRefreshInterval);\n                this.autoRefreshInterval = null;\n            }\n        ;\n        ;\n            if (this.activeRefreshInterval) {\n                JSBNG__clearInterval(this.activeRefreshInterval);\n                this.activeRefreshInterval = null;\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = n;\n});\n__d(\"UIIntentionalStream\", [\"event-extensions\",\"Animation\",\"Arbiter\",\"AsyncRequest\",\"AsyncResponse\",\"CSS\",\"DataStore\",\"DOM\",\"DOMScroll\",\"HTML\",\"JSLogger\",\"NavigationMessage\",\"OnVisible\",\"PageTransitions\",\"Run\",\"ScrollAwareDOM\",\"Style\",\"UIIntentionalStreamMessage\",\"UIIntentionalStreamRefresh\",\"UIPagelet\",\"URI\",\"Vector\",\"$\",\"coalesce\",\"copyProperties\",\"createArrayFrom\",\"ge\",\"isEmpty\",\"merge\",\"reportData\",\"startsWith\",\"userAction\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Animation\"), h = b(\"Arbiter\"), i = b(\"AsyncRequest\"), j = b(\"AsyncResponse\"), k = b(\"CSS\"), l = b(\"DataStore\"), m = b(\"DOM\"), n = b(\"DOMScroll\"), o = b(\"HTML\"), p = b(\"JSLogger\"), q = b(\"NavigationMessage\"), r = b(\"OnVisible\"), s = b(\"PageTransitions\"), t = b(\"Run\"), u = b(\"ScrollAwareDOM\"), v = b(\"Style\"), w = b(\"UIIntentionalStreamMessage\"), x = b(\"UIIntentionalStreamRefresh\"), y = b(\"UIPagelet\"), z = b(\"URI\"), aa = b(\"Vector\"), ba = b(\"$\"), ca = b(\"coalesce\"), da = b(\"copyProperties\"), ea = b(\"createArrayFrom\"), fa = b(\"ge\"), ga = b(\"isEmpty\"), ha = b(\"merge\"), ia = b(\"reportData\"), ja = b(\"startsWith\"), ka = b(\"userAction\");\n    function la() {\n        h.subscribe(w.SET_AUTO_INSERT, ma);\n    };\n;\n    function ma(oa, pa) {\n        if (((oa != w.SET_AUTO_INSERT))) {\n            return;\n        }\n    ;\n    ;\n        var qa = na.instance;\n        if (qa) {\n            qa.pauseAutoInsert = pa.pause;\n        }\n    ;\n    ;\n    };\n;\n    function na(oa, pa, qa, ra, sa, ta, ua, va, wa, xa, ya) {\n        if (!oa) {\n            throw new Error(\"UIIntentionalStream instantiated with no root.\");\n        }\n    ;\n    ;\n        var za = {\n        };\n        this.initPageletCache(za);\n        da(this, {\n            id: oa.id,\n            root: oa,\n            instanceName: pa,\n            newest: ((za.newest || qa)),\n            oldest: ra,\n            oldestMR: ra,\n            shouldShowHidden: false,\n            defaultFilter: sa,\n            currentFilterKey: xa,\n            sourceType: ta,\n            lastSeenTime: ya,\n            hasPendingRefresh: false,\n            pauseAutoInsert: false,\n            error: m.scry(oa, \"div.UIIntentionalStream_Error\")[0],\n            pager: m.scry(oa, \"div.uiMorePager\")[0],\n            filterNullState: m.scry(oa, \"div.friendListFilterNullState\")[0],\n            streamContent: m.JSBNG__find(oa, \".UIIntentionalStream_Content\"),\n            requestNum: 0,\n            scrollLoadCount: 1,\n            maxScrollLoadCount: 1,\n            scrollPosition: 0,\n            lastViewStateID: 0,\n            cachedScrollQID: 0,\n            jslog: p.create(\"stream\"),\n            scrollListener: null\n        });\n        this.addScrollTrace(\"init\", {\n        });\n        t.JSBNG__onLeave(this.unload.bind(this));\n        if (!na.instances) {\n            na.instances = {\n            };\n        }\n    ;\n    ;\n        na.instances[pa] = this;\n        na.instance = this;\n        la();\n        this.setupSubscriptions();\n    };\n;\n    da(na.prototype, {\n        initPageletCache: function(oa) {\n            if (window.PageletCacheController) {\n                this._cache = window.PageletCacheController.registerController(\"pagelet_home_stream\", this);\n                if (this._cache) {\n                    da(oa, this._cache.loadData());\n                    this._cache.registerCleanup(w.UNLOAD);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        subscribeToComposerPublish: function() {\n            this.subscriptions.push(h.subscribe(\"composer/publish\", function(JSBNG__event, oa) {\n                if (oa.streamStory) {\n                    this.addComposerContent(oa.streamStory, 500);\n                }\n            ;\n            ;\n            }.bind(this)));\n        },\n        setupSubscriptions: function() {\n            this.subscriptions = [];\n            this.subscribeToComposerPublish();\n            this.subscriptions.push(h.subscribe(w.UPDATE_STREAM, this.updateStream.bind(this)));\n            this.subscriptions.push(h.subscribe(w.REFRESH_STREAM, this.refreshStream.bind(this)));\n            this.scrollListener = JSBNG__Event.listen(window, \"JSBNG__scroll\", this.checkFirstScroll.bind(this));\n            this.checkFirstScroll();\n            t.JSBNG__onLoad(this.checkFirstStory.bind(this));\n        },\n        tearDownSubscriptions: function() {\n            if (!this.subscriptions) {\n                return;\n            }\n        ;\n        ;\n            this.subscriptions.forEach(h.unsubscribe);\n            this.subscriptions = null;\n            if (this.scrollListener) {\n                this.scrollListener.remove();\n                this.scrollListener = null;\n            }\n        ;\n        ;\n        },\n        unload: function() {\n            this.addScrollTrace(\"unload\", {\n            });\n            h.inform(w.UNLOAD);\n            this.tearDownSubscriptions();\n            na.instance = null;\n            na.instances[this.instanceName] = null;\n            this.clearScrollLoader(true);\n            window.disableScrollLoad = null;\n            ((x.instance && x.instance.unload()));\n        },\n        _getUpdateInsertType: function() {\n            return na.REFRESH_PREPEND;\n        },\n        updateStream: function(oa) {\n            if (((((((oa != w.UPDATE_STREAM)) || this.hasPendingRefresh)) || this.isAutoRefreshPaused()))) {\n                return;\n            }\n        ;\n        ;\n            this.loadNewer({\n                showLoader: false,\n                ignoreSelf: true,\n                insertType: this._getUpdateInsertType()\n            });\n        },\n        clearScrollLoader: function(oa) {\n            if (this.currentScrollListener) {\n                this.currentScrollListener.remove();\n                this.currentScrollListener = null;\n            }\n        ;\n        ;\n            if (((oa || ((this.scrollLoadCount >= this.maxScrollLoadCount))))) {\n                window.disableScrollLoad = true;\n            }\n        ;\n        ;\n        },\n        loadOlderPosts: function(oa) {\n            var pa = {\n                filter: this.getCurrentFilterKey(),\n                oldest: this.oldest,\n                oldestMR: this.oldestMR,\n                last_seen_time: this.lastSeenTime,\n                scroll_count: this.scrollLoadCount,\n                scroll_position: this.scrollPosition,\n                last_viewstate_id: this.lastViewStateID,\n                cached_scroll_qid: this.cachedScrollQID\n            };\n            pa = ha(pa, oa);\n            this.loadWithParams(pa);\n        },\n        loadWithParams: function(oa) {\n            var pa = m.scry(this.root, \"div.fbStreamPager.hasMorePosts\")[0];\n            if (pa) {\n                if (k.hasClass(pa, \"async_saving\")) {\n                    return;\n                }\n            ;\n            ;\n                k.addClass(pa, \"async_saving\");\n            }\n        ;\n        ;\n            this.addScrollTrace(\"loadwithparams\", oa);\n            y.loadFromEndpoint(\"MoreStoriesPagelet\", \"home_stream\", oa, {\n                usePipe: true,\n                append: true\n            });\n        },\n        setScrollLoadCount: function(oa) {\n            this.maxScrollLoadCount = oa;\n        },\n        loadMoreOnScroll: function(oa, pa) {\n            if (window.disableScrollLoad) {\n                return;\n            }\n        ;\n        ;\n            var qa = function() {\n                if (window.disableScrollLoad) {\n                    return;\n                }\n            ;\n            ;\n                var ta = a.ArbiterMonitor;\n                if (ta) {\n                    var ua = ka(\"JSBNG__scroll\", null, null, \"FORCE\", {\n                        gt: {\n                            ua_id: \"stream:scroll:auto\"\n                        }\n                    });\n                    ua.set_namespace(\"stream\");\n                    ta.initUA(ua);\n                }\n            ;\n            ;\n                var va = {\n                    delay_load_count: pa\n                };\n                this.loadOlderPosts(va);\n            }.bind(this), ra = m.scry(this.root, \"ul.uiStream li.genericStreamStory\");\n            if (!ra.length) {\n                return;\n            }\n        ;\n        ;\n            this.addScrollTrace(\"loadmoreonscroll\", {\n            });\n            var sa = ra[((((ra.length - oa)) - 1))];\n            if (sa) {\n                this.currentScrollListener = new r(sa, qa, null, 0);\n            }\n             else qa();\n        ;\n        ;\n        },\n        updateTimeRange: function(oa, pa) {\n            if (((!this.newest || ((this.newest < oa))))) {\n                this.newest = oa;\n                this.addScrollTrace(\"update_newest\", {\n                    newest: this.newest\n                });\n            }\n        ;\n        ;\n            if (((!this.oldest || ((pa && ((pa < this.oldest))))))) {\n                this.oldest = pa;\n                this.addScrollTrace(\"update_oldest\", {\n                    oldest: this.oldest\n                });\n            }\n        ;\n        ;\n        },\n        updateOldestMR: function(oa) {\n            if (((!this.oldestMR || ((oa < this.oldestMR))))) {\n                this.oldestMR = oa;\n                this.addScrollTrace(\"update_oldestmr\", {\n                    oldestmr: this.oldestMR\n                });\n            }\n        ;\n        ;\n        },\n        updateScrollPosition: function(oa) {\n            this.scrollPosition = oa;\n            this.addScrollTrace(\"update_scrollposition\", {\n                scrollposition: this.scrollPosition\n            });\n        },\n        updateLastViewStateID: function(oa) {\n            this.lastViewStateID = oa;\n            this.addScrollTrace(\"update_lastviewstateid\", {\n                lastviewstateid: this.lastViewStateID\n            });\n        },\n        updateCachedScrollQID: function(oa) {\n            this.cachedScrollQID = oa;\n            this.addScrollTrace(\"update_cachedscrollqid\", {\n                qid: this.cachedScrollQID\n            });\n        },\n        getID: function() {\n            return this.id;\n        },\n        getCurrentFilterKey: function() {\n            if (this.currentFilterKey) {\n                return this.currentFilterKey;\n            }\n        ;\n        ;\n            var oa = z.getMostRecentURI().getQueryData();\n            if (((oa && oa.sk))) {\n                this.currentFilterKey = oa.sk;\n            }\n             else if (((oa && oa.filter))) {\n                this.currentFilterKey = oa.filter;\n            }\n             else if (this.defaultFilter) {\n                this.currentFilterKey = this.defaultFilter;\n            }\n            \n            \n        ;\n        ;\n            return this.currentFilterKey;\n        },\n        resetFilterKey: function(oa) {\n            this.currentFilterKey = oa;\n        },\n        loadOlder: function(oa) {\n            oa = ((oa || {\n            }));\n            if (!this.oldest) {\n                return;\n            }\n        ;\n        ;\n            var pa = this.getCurrentParams();\n            pa.oldest = this.oldest;\n            this.refresh(na.REFRESH_APPEND, pa, oa);\n            return this;\n        },\n        loadNewer: function(oa) {\n            if (!this.newest) {\n                return;\n            }\n        ;\n        ;\n            oa = ((oa || {\n            }));\n            var pa = this.getCurrentParams();\n            pa.newest = this.newest;\n            if (oa.ignoreSelf) {\n                pa.ignore_self = true;\n            }\n        ;\n        ;\n            pa.load_newer = true;\n            var qa = ca(oa.insertType, na.REFRESH_PREPEND);\n            this.refresh(qa, pa, oa);\n            return this;\n        },\n        checkFirstStory: function() {\n            this.logFirstStory(\"first_story_load\");\n        },\n        checkFirstScroll: function() {\n            if (((this.scrollListener && ((aa.getScrollPosition().y > 0))))) {\n                this.scrollListener.remove();\n                this.scrollListener = null;\n                this.logFirstStory(\"first_scrolling\");\n            }\n        ;\n        ;\n        },\n        logFirstStory: function(oa) {\n            if (((((!fa(\"home_stream\") || !fa(\"home_stream\").childElementCount)) || !fa(\"home_stream\").children[0].getAttribute(\"data-ft\")))) {\n                return;\n            }\n        ;\n        ;\n            var pa = fa(\"home_stream\").children[0].getAttribute(\"data-ft\"), qa = JSON.parse(pa);\n            if (!((((\"mf_story_key\" in qa)) && ((\"qid\" in qa))))) {\n                return;\n            }\n        ;\n        ;\n            var ra = {\n                mf_story_key: qa.mf_story_key,\n                qid: qa.qid\n            };\n            ia(oa, {\n                ft: ra\n            });\n        },\n        getCurrentParams: function() {\n            var oa = {\n            }, pa = z.getMostRecentURI().getQueryData();\n            pa.filter = this.getCurrentFilterKey();\n            var qa = this.getValidParams();\n            if (qa) {\n                qa.forEach(function(ra) {\n                    oa[ra] = pa[ra];\n                });\n            }\n             else oa = pa;\n        ;\n        ;\n            return oa;\n        },\n        setHomeFilter: function(oa) {\n            this._homeFilter = oa;\n        },\n        setHomeFilterLoading: function(oa) {\n            if (this._homeFilter) {\n                this._homeFilter.setLoading(oa);\n            }\n        ;\n        ;\n        },\n        refresh: function(oa, pa, qa) {\n            h.inform(w.UPDATE_LAST_REFRESH_TIME);\n            this.addScrollTrace(\"refresh\", {\n                type: oa,\n                data: pa,\n                kwargs: qa\n            });\n            this.currentFilterKey = pa.filter;\n            if (((pa.filter == na.FEED_FILTER_KEY_DUAL_NEWS_FEED))) {\n                this.currentFilterKey = this.defaultFilter;\n            }\n             else if (((na.isHighlightsFilter(pa.filter) || ((pa.filter === na.FEED_FILTER_KEY_NEWS_FEED))))) {\n                this.defaultFilter = this.currentFilterKey;\n            }\n            \n        ;\n        ;\n            qa = ((qa || {\n            }));\n            var ra = ++this.requestNum, sa = ca(qa.showLoader, true), ta = this.instanceName, ua = function(ya) {\n                na.getInstance(ta).handleResponse(ra, oa, ya, qa);\n            }, va = function(ya) {\n                na.getInstance(ta).handleError(ra, oa, ya, qa);\n            }, wa = function(ya) {\n                na.getInstance(ta).handleFinally(oa, pa.filter, ya);\n            };\n            if (!(pa.request_type = oa)) {\n                pa.request_type = \"none\";\n            }\n        ;\n        ;\n            if (pa.filter) {\n                qa.show_hidden = ((pa.show_hidden ? pa.show_hidden : false));\n            }\n             else qa.show_hidden = this.shouldShowHidden;\n        ;\n        ;\n            pa = da(this.getCurrentParams(), pa);\n            this.hasPendingRefresh = true;\n            var xa;\n            if (((((oa == na.REFRESH_APPEND)) && sa))) {\n                xa = this.pager;\n            }\n        ;\n        ;\n            new i().setURI(this.getEndpoint()).setReadOnly(true).setOption(\"retries\", 0).setMethod(this.getRefreshMethod()).setData(pa).setHandler(ua).setStatusElement(xa).setErrorHandler(va).setFinallyHandler(wa).send();\n            if (((oa == na.REFRESH_TRANSITION))) {\n                if (this.pager) {\n                    this.pager.style.display = \"none\";\n                }\n            ;\n            ;\n                this.clearScrollLoader();\n                this.oldest = this.newest = null;\n            }\n        ;\n        ;\n            if (sa) {\n                this.setHomeFilterLoading(true);\n            }\n        ;\n        ;\n        },\n        addComposerContent: function(oa, pa) {\n            if (this.isOnNewsFeedFilter()) {\n                k.addClass(oa, \"uiStreamBoulderHighlight\");\n            }\n        ;\n        ;\n            this.addContentPrepend(oa, pa);\n        },\n        addContentPrepend: function(oa, pa) {\n            if (oa.length) {\n                ea(oa).reverse().forEach(function(va) {\n                    this.addContentPrepend(va, pa);\n                }.bind(this));\n                return;\n            }\n        ;\n        ;\n            var qa, ra = aa.getScrollPosition().y, sa = aa.getElementPosition(this.streamContent).y, ta = ((this.scrollOnPrepend && ((ra >= sa))));\n            if (ta) {\n                var ua = function(va) {\n                    var wa = m.JSBNG__find(va, \"^li.uiStreamStory\");\n                    if (!wa) {\n                        return;\n                    }\n                ;\n                ;\n                    l.set(wa, \"origHeight\", wa.offsetHeight);\n                    JSBNG__Event.listen(va, \"load\", function() {\n                        var xa = l.get(wa, \"origHeight\");\n                        if (((wa.offsetHeight != xa))) {\n                            window.JSBNG__scrollBy(0, ((wa.offsetHeight - xa)));\n                            l.set(wa, \"origHeight\", wa.offsetHeight);\n                        }\n                    ;\n                    ;\n                    });\n                };\n                qa = g.insert.curry(this.streamContent, oa, (function(va, wa) {\n                    m.prependContent(this.streamContent, wa);\n                    h.inform(\"reflow\");\n                    window.JSBNG__scrollBy(0, wa.offsetHeight);\n                    m.scry(wa, \"img\").forEach(ua);\n                }).bind(this));\n            }\n             else qa = (function() {\n                v.set(oa, \"opacity\", 0);\n                u.prependContent(this.streamContent, oa);\n                h.inform(\"reflow\");\n                new g(oa).from(\"opacity\", 0).to(\"opacity\", 1).duration(400).JSBNG__ondone(function() {\n                    h.inform(w.UPDATE_HTML_CONTENT);\n                }).go();\n            }).bind(this);\n        ;\n        ;\n            if (pa) {\n                k.hide(oa);\n                m.appendContent(JSBNG__document.body, oa);\n                JSBNG__setTimeout(function() {\n                    k.show(oa);\n                    qa();\n                }, pa);\n            }\n             else qa();\n        ;\n        ;\n        },\n        addContentAppend: function(oa) {\n            m.appendContent(this.streamContent, oa);\n        },\n        handleResponse: function(oa, pa, qa, ra) {\n            this.addScrollTrace(\"handle_response\", {\n                requestnum: oa,\n                type: pa,\n                kwargs: ra\n            });\n            ra = ((ra || {\n            }));\n            var sa = qa.getPayload();\n            ((this.filterNullState && m.remove(this.filterNullState)));\n            if (ga(sa)) {\n                return;\n            }\n        ;\n        ;\n            if (sa.autoRefreshConfig) {\n                h.inform(w.UPDATE_AUTOREFRESH_CONFIG, sa.autoRefreshConfig);\n            }\n        ;\n        ;\n            this.setHomeFilterLoading(false);\n            if (((pa == na.REFRESH_EXPAND))) {\n                var ta = m.JSBNG__find(ba(ra.expandStoryID), \"div.UIIntentionalStory_CollapsedStories\");\n                k.hide(ta);\n                k.removeClass(ta, \"UIIntentionalStory_CollapsedStoriesLoading\");\n            }\n        ;\n        ;\n            if (this.error) {\n                this.error.style.display = \"none\";\n            }\n        ;\n        ;\n            if (((oa != this.requestNum))) {\n                return;\n            }\n        ;\n        ;\n            if (((\"show_hidden\" in ra))) {\n                this.shouldShowHidden = ra.show_hidden;\n            }\n        ;\n        ;\n            if (((((\"newestStoryTime\" in sa)) && ((sa.newestStoryTime > this.newest))))) {\n                this.newest = sa.newestStoryTime;\n            }\n        ;\n        ;\n            if (((pa != na.REFRESH_PREPEND))) {\n                if (((((\"oldestStoryTime\" in sa)) && ((!this.oldest || ((sa.oldestStoryTime < this.oldest))))))) {\n                    this.oldest = sa.oldestStoryTime;\n                }\n            ;\n            ;\n                if (((\"scrollPosition\" in sa))) {\n                    this.scrollPosition = sa.scrollPosition;\n                }\n            ;\n            ;\n                if (((\"lastViewStateID\" in sa))) {\n                    this.lastViewStateID = sa.lastViewStateID;\n                }\n            ;\n            ;\n                if (((\"oldestMRStoryTime\" in sa))) {\n                    this.oldestMR = sa.oldestMRStoryTime;\n                }\n            ;\n            ;\n                if (((\"cachedScrollQID\" in sa))) {\n                    this.cachedScrollQID = sa.cachedScrollQID;\n                }\n                 else this.cachedScrollQID = 0;\n            ;\n            ;\n            }\n        ;\n        ;\n            if (sa.html) {\n                var ua = o(sa.html).getNodes();\n                switch (pa) {\n                  case na.REFRESH_PREPEND:\n                    this.addContentPrepend(ua);\n                    break;\n                  case na.REFRESH_APPEND:\n                    this.addContentAppend(ua);\n                    this.clearScrollLoader(true);\n                    break;\n                  case na.REFRESH_TRANSITION:\n                    m.setContent(this.streamContent, ua);\n                    this.scrollLoadCount = 1;\n                    if (!ra.noScroll) {\n                        n.JSBNG__scrollTo(new aa(0, 0, \"JSBNG__document\"), false);\n                    }\n                ;\n                ;\n                    break;\n                  case na.REFRESH_EXPAND:\n                    m.insertAfter(ba(ra.expandStoryID), ua);\n                    break;\n                  case na.DELAYED_STREAM:\n                    this.addContentAppend(ua);\n                    break;\n                };\n            ;\n                h.inform(w.UPDATE_HTML_CONTENT);\n            }\n        ;\n        ;\n        },\n        handleError: function(oa, pa, qa, ra) {\n            if (((oa != this.requestNum))) {\n                return;\n            }\n        ;\n        ;\n            this.setHomeFilterLoading(false);\n            var sa = qa.getError();\n            if (((sa == 1357001))) {\n                j.defaultErrorHandler(qa);\n            }\n        ;\n        ;\n            if (((pa == na.REFRESH_EXPAND))) {\n                var ta = m.JSBNG__find(ba(ra.expandStoryID), \"div.UIIntentionalStory_CollapsedStories\");\n                k.removeClass(ta, \"UIIntentionalStory_CollapsedStoriesLoading\");\n            }\n        ;\n        ;\n            if (((((!ra.delayLoadCount && ((pa != na.REFRESH_PREPEND)))) && this.error))) {\n                v.set(this.error, \"display\", \"block\");\n            }\n        ;\n        ;\n        },\n        handleFinally: function(oa, pa) {\n            if (((oa == na.REFRESH_TRANSITION))) {\n                s.transitionComplete();\n                h.inform(q.NAVIGATION_COMPLETED);\n            }\n        ;\n        ;\n            this.hasPendingRefresh = false;\n        },\n        getValidParams: function() {\n            return na.VALID_PARAMS;\n        },\n        getEndpoint: function() {\n            return na.ENDPOINT;\n        },\n        getRefreshMethod: function() {\n            return na.REFRESH_METHOD;\n        },\n        isOnNewHighlights: function() {\n            var oa = this.getCurrentFilterKey();\n            return ((na.isHighlightsFilter(oa) || ((((oa == na.FEED_FILTER_KEY_DUAL_NEWS_FEED)) && na.isHighlightsFilter(this.defaultFilter)))));\n        },\n        isLiveStreamBox: function() {\n            var oa = this.getCurrentFilterKey();\n            return ((oa && ((oa.indexOf(na.FEED_FILTER_KEY_LIVE_STREAM_BOX) === 0))));\n        },\n        isOnNewsFeedFilter: function() {\n            var oa = this.getCurrentFilterKey();\n            return ((((((oa == na.FEED_FILTER_KEY_NEWS_FEED)) || na.isHighlightsFilter(oa))) || ((oa == na.FEED_FILTER_KEY_DUAL_NEWS_FEED))));\n        },\n        isAutoRefreshPaused: function() {\n            if (((this.isOnNewHighlights() || this.isLiveStreamBox()))) {\n                return false;\n            }\n        ;\n        ;\n            return this.pauseAutoInsert;\n        },\n        addScrollTrace: function(oa, pa) {\n            this.jslog.debug(oa, pa);\n        },\n        refreshStream: function(oa, pa) {\n            if (((oa != w.REFRESH_STREAM))) {\n                return;\n            }\n        ;\n        ;\n            var qa = this.getCurrentFilterKey(), ra = {\n                filter: qa\n            }, sa = {\n                filter: qa\n            };\n            ((pa.noScroll && (sa.noScroll = 1)));\n            this.refresh(na.REFRESH_TRANSITION, ra, sa);\n        },\n        getNewest: function() {\n            return this.newest;\n        }\n    });\n    da(na, {\n        ANIMATION_DURATION: 300,\n        REFRESH_METHOD: \"GET\",\n        REFRESH_TRANSITION: 1,\n        REFRESH_PREPEND: 2,\n        REFRESH_APPEND: 3,\n        REFRESH_EXPAND: 5,\n        DELAYED_STREAM: 6,\n        FEED_FILTER_KEY_NEW_HIGHLIGHTS: \"h\",\n        FEED_FILTER_KEY_NEWS_FEED: \"lf\",\n        FEED_FILTER_KEY_DUAL_NEWS_FEED: \"nf\",\n        FEED_FILTER_KEY_LIVE_STREAM_BOX: \"pub\",\n        VALID_PARAMS: [\"filter\",\"show_hidden\",],\n        ENDPOINT: \"/ajax/intent.php\",\n        getInstance: function(oa) {\n            return na.instances[oa];\n        },\n        isHighlightsFilter: function(oa) {\n            if (!oa) {\n                return false;\n            }\n        ;\n        ;\n            return ja(oa, na.FEED_FILTER_KEY_NEW_HIGHLIGHTS);\n        },\n        getStoriesByAssoc: function(oa) {\n            return m.scry(na.instance.root, ((\"div.aid_\" + oa)));\n        }\n    });\n    e.exports = na;\n});\n__d(\"legacy:UIIntentionalStream\", [\"UIIntentionalStream\",], function(a, b, c, d) {\n    a.UIIntentionalStream = b(\"UIIntentionalStream\");\n}, 3);\nfunction FutureHomeSideNav() {\n    this.parent.construct(this);\n};\n;\nClass.extend(FutureHomeSideNav, \"FutureSideNav\");\ncopyProperties(FutureHomeSideNav.prototype, {\n    init: function() {\n        this.parent.init.apply(this, arguments);\n        this.ajaxPipe = true;\n        this.seeAllEndpoint = \"/ajax/home/generic.php\";\n        this.typeSections = {\n            favorites: \"pinnedNav\",\n            profiles: \"pinnedNav\",\n            apps: \"appsNav\",\n            groups: \"groupsNav\",\n            pages: \"pagesNav\",\n            lists: \"listsNav\",\n            interests: \"interestsNav\",\n            connect_apps: \"connectNav\"\n        };\n        this.switchingFromTitanFixedFrame = false;\n        this._arbiterSubscriptions.push(Arbiter.subscribe(\"titan_fixed_frame_changed\", this.handleFixedFrameChanged.bind(this)), Arbiter.subscribe(NavigationMessage.NAVIGATION_FAVORITE_UPDATE, this.updateFavorite.bind(this)), Arbiter.subscribe(NavigationMessage.NAVIGATION_FIRST_RESPONSE, this.navigationFirstResponse.bind(this)));\n        this._ensureHover(\"homeSideNav\");\n        this._initPageletCache();\n    },\n    _initPageletCache: function(a) {\n        if (window.PageletCacheController) {\n            this._cache = PageletCacheController.registerController(\"pagelet_navigation\", this);\n            if (this._cache) {\n                this._cache.registerCleanup(\"HomeNav/cleanup\");\n                JSBNG__onleaveRegister(function() {\n                    Arbiter.inform(\"HomeNav/cleanup\");\n                });\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    initMoreLink: function(a) {\n        this._eventHandlers.push(JSBNG__Event.listen(a, \"click\", this._showMoreSections.bind(this, a)));\n    },\n    _showMoreSections: function(a) {\n        var b = DOM.scry(this.root, \"div.belowThreshold\");\n        CSS.hide(a);\n        b.forEach(function(c) {\n            CSS.removeClass(c, \"belowThreshold\");\n        });\n    },\n    handleFixedFrameChanged: function(a, b, c) {\n        if (b) {\n            var d = function(e, f) {\n                var g = DOMPosition.getElementPosition(ge(f)).y;\n                UIPagelet.loadFromEndpoint(e, f, {\n                    fixed_frame: b,\n                    selected_key: c,\n                    v_pos: g\n                });\n            };\n            d(\"PinnedNavigationPagelet\", \"pagelet_pinned_nav\");\n            d(\"BookmarkNavigationPagelet\", \"pagelet_bookmark_nav\");\n            if (ge(\"chatFriendsOnline\")) {\n                CSS.hide(ge(\"chatFriendsOnline\"));\n            }\n        ;\n        ;\n        }\n         else this.switchingFromTitanFixedFrame = true;\n    ;\n    ;\n    },\n    handlePageTransition: function(a) {\n        if (this.switchingFromTitanFixedFrame) {\n            this.switchingFromTitanFixedFrame = false;\n            return false;\n        }\n         else return this.parent.handlePageTransition(a)\n    ;\n    },\n    _initSection: function(a) {\n        var b = this.parent._initSection(a);\n        for (var c in this.typeSections) {\n            var d = this.typeSections[c];\n            if (((b.id == d))) {\n                var e = DOM.scry(b.node, \"div.navHeader\")[0];\n                if (e) {\n                    var f = ((((\"/bookmarks/(\" + c)) + \")(/)?\"));\n                    b.seeall = this._initItem({\n                        node: e,\n                        id: b.id,\n                        endpoint: this.seeAllEndpoint,\n                        key: [\"bookmarks\",],\n                        path: [{\n                            regex: f\n                        },]\n                    });\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        };\n    ;\n        return b;\n    },\n    _constructItem: function(a, b) {\n        return new FutureHomeSideNavItem(a, b);\n    },\n    _constructSection: function(a) {\n        return new FutureHomeSideNavSection(a);\n    },\n    getSection: function(a) {\n        return ((this.typeSections[a] && this.sections[this.typeSections[a]]));\n    },\n    _getItemForKey: function(a) {\n        var b = this.parent._getItemForKey(\"nf\");\n        if (((b && b.matchKey(a)))) {\n            return b;\n        }\n         else return this.parent._getItemForKey(a)\n    ;\n    },\n    _isCurrentPath: function(a) {\n        return ((((a.getDomain() === this.uri.getDomain())) && ((((a.getPath() === \"/\")) || ((a.getPath() === \"/home.php\"))))));\n    },\n    _handleMenuClick: function(a, b, c, JSBNG__event) {\n        if (CSS.hasClass(c, \"favorite\")) {\n            Arbiter.inform(NavigationMessage.NAVIGATION_FAVORITE_UPDATE, {\n                key: b.numericKey,\n                favorite: !a.equals(this.getSection(\"favorites\")),\n                movetop: CSS.hasClass(c, \"movetop\")\n            });\n        }\n         else this.parent._handleMenuClick(a, b, c, JSBNG__event);\n    ;\n    ;\n    },\n    removeItemByKey: function(a) {\n        Arbiter.inform(NavigationMessage.NAVIGATION_ITEM_REMOVED, a);\n        this.parent.removeItemByKey(a);\n    },\n    toggleItemByKey: function(a, b) {\n        var c = this.getNodeForKey(a);\n        if (!b) {\n            Arbiter.inform(NavigationMessage.NAVIGATION_ITEM_HIDDEN, a);\n            ((c && CSS.hide(c)));\n        }\n         else ((c && CSS.show(c)));\n    ;\n    ;\n        var d = this._getItemForKey(a);\n        this.getSection(d.type).refresh();\n    },\n    removeItem: function(a) {\n        var b = this.getSection(a.type);\n        this.parent.removeItem(a);\n        b.refresh();\n    },\n    updateFavorite: function(a, b) {\n        var c = this._findItem(function(l) {\n            return ((l.matchKey(b.key) && l.canFavorite()));\n        }), d = this.getSection(\"favorites\"), e = bagofholding, f = ((b.favorite ? d.addEndpoint : d.removeEndpoint));\n        if (b.movetop) {\n            f = d.editEndpoint;\n        }\n    ;\n    ;\n        if (((!c && ((b.favorite || b.movetop))))) {\n            if (b.movetop) {\n                var g = DOM.scry(this.root, \".expandableSideNav\"), h = ((((g && g.length)) && CSS.hasClass(g[0], \"expandedMode\")));\n            }\n        ;\n        ;\n            e = function() {\n                UIPagelet.loadFromEndpoint(\"PinnedNavigationPagelet\", \"pagelet_pinned_nav\", {\n                    expanded: h\n                });\n            };\n        }\n         else if (!c) {\n            e = function() {\n                UIPagelet.loadFromEndpoint(\"BookmarkNavigationPagelet\", \"pagelet_bookmark_nav\");\n            };\n        }\n         else {\n            if (b.movetop) {\n                CSS.show(c.node);\n                this.moveItem(d, c);\n                var i = Parent.byClass(c.node, \"uiSideNav\");\n                if (((i && i.childNodes.length))) {\n                    var j = Parent.byClass(DOM.scry(i, \".sortableItem\")[0], \"sideNavItem\");\n                    DOM.insertBefore(j, c.node);\n                    CSS.removeClass(c.node, \"hidden\");\n                }\n            ;\n            ;\n            }\n             else {\n                var k = this.getSection(c.type);\n                if (b.favorite) {\n                    CSS.show(c.node);\n                    this.moveItem(d, c);\n                    c.showFavorite();\n                }\n                 else if (!k.equals(d)) {\n                    this.moveItem(k, c);\n                    c.hideFavorite();\n                }\n                 else this.removeItem(c);\n                \n            ;\n            ;\n                k.refresh();\n            }\n        ;\n        ;\n            d.refresh();\n            b.key = c.numericKey;\n            Arbiter.inform(\"NavigationMessage.FAVORITES_UPDATED\");\n        }\n        \n    ;\n    ;\n        new AsyncRequest().setURI(f).setData({\n            id: b.key,\n            movetop: b.movetop\n        }).setHandler(e).send();\n    },\n    _doPageTransition: function(a, b) {\n        this._unloadStreams();\n        var c = this.parent._doPageTransition(a, b);\n        if (((c && ((((((a.type == \"groups\")) || ((a.type == \"lists\")))) || ((a.type == \"interests\"))))))) {\n            a.setCount(0);\n            a.hideUnreadDot();\n        }\n    ;\n    ;\n        return c;\n    },\n    _unloadStreams: function() {\n        var a = ((window.UIIntentionalStream && UIIntentionalStream.instances)), b = [\"nile\",\"global\",\"friends\",\"blade\",];\n        ((a && b.forEach(function(c) {\n            ((a[c] && a[c].unload()));\n        })));\n    },\n    navigationFirstResponse: function() {\n        this.setSelected(this.loading);\n    }\n});\nfunction FutureHomeSideNavSection(a) {\n    this.parent.construct(this, a);\n    this.editEndpoint = \"/ajax/bookmark/edit/\";\n    this.addEndpoint = \"/ajax/bookmark/add/\";\n    this.removeEndpoint = \"/ajax/bookmark/delete/\";\n};\n;\nClass.extend(FutureHomeSideNavSection, \"FutureSideNavSection\");\ncopyProperties(FutureHomeSideNavSection.prototype, {\n    refresh: function() {\n        var a = DOM.scry(this.node, \"li.sideNavItem\"), b = DOM.scry(this.node, \"div.actionLinks\"), c = a.some(CSS.shown);\n        CSS.conditionShow(DOM.JSBNG__find(this.node, \"div.navHeader\"), c);\n        ((b.length && CSS.conditionShow(b[0], c)));\n    }\n});\nfunction FutureHomeSideNavItem(a, b) {\n    this.parent.construct(this, a, b);\n};\n;\nClass.extend(FutureHomeSideNavItem, \"FutureSideNavItem\");\ncopyProperties(FutureHomeSideNavItem.prototype, {\n    canFavorite: function() {\n        return !!this._getFavoriteLabel();\n    },\n    showFavorite: function() {\n        DOM.setContent(this._getFavoriteLabel(), \"Remove from Favorites\");\n    },\n    hideFavorite: function() {\n        DOM.setContent(this._getFavoriteLabel(), \"Add to Favorites\");\n    },\n    hideUnreadDot: function() {\n        var a = DOM.scry(this.node, \"img.unreadDot\")[0];\n        ((a && CSS.hide(a)));\n    },\n    _getFavoriteLabel: function() {\n        return DOM.scry(this.node, \"li.favorite span.itemLabel\")[0];\n    }\n});\n__d(\"FeedTrackingAsync\", [\"event-extensions\",\"collectDataAttributes\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"collectDataAttributes\"), h = b(\"copyProperties\");\n    function i(j) {\n        JSBNG__Event.listen(j, \"AsyncRequest/send\", function(JSBNG__event) {\n            var k = JSBNG__event.getTarget(), l = JSBNG__event.getData().request, m = l.getData(), n = g(k, [\"ft\",]);\n            h(m, n);\n        });\n    };\n;\n    e.exports = {\n        init: i\n    };\n});\n__d(\"AppRequestReminders\", [\"AsyncRequest\",\"CSS\",\"DOM\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncRequest\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"ge\"), k = 3, l = 0, m = 0, n = {\n    }, o = {\n    }, p = 1, q = j(\"OtherAppReqReminder\"), r = function(z, aa, ba) {\n        n[aa] = {\n            node: z,\n            seq: p++,\n            reqCount: ba\n        };\n    }, s = function(z, aa, ba, ca) {\n        if (ca) {\n            o[aa] = {\n                node: z,\n                seq: p++,\n                reqCount: ba\n            };\n        }\n         else l++;\n    ;\n    ;\n    }, t = function(z) {\n        m = z;\n    }, u = function(z) {\n        return z.id.split(\"_\")[1];\n    }, v = function(z) {\n        var aa = j(z), ba = aa.nextSibling;\n        if (((ba !== q))) {\n            h.show(ba);\n            m -= n[u(ba)].reqCount;\n        }\n    ;\n    ;\n        x(m);\n    }, w = function(z) {\n        var aa = j(z);\n        l--;\n        while (((((l < k)) && ((m > 0))))) {\n            aa = aa.nextSibling;\n            var ba = u(aa);\n            if (((((aa !== q)) && ((o[ba] !== undefined))))) {\n                h.show(aa);\n                m -= o[ba].reqCount;\n                delete o[ba];\n                l++;\n            }\n        ;\n        ;\n        };\n    ;\n        x(m);\n    }, x = function(z) {\n        new g().setURI(\"/ajax/reminders/update_count.php\").setData({\n            new_count: z\n        }).setMethod(\"POST\").send();\n    }, y = function(z, aa) {\n        if (((((q && aa)) && ((z > 0))))) {\n            i.setContent(j(\"OtherAppReqLabel\"), aa);\n        }\n         else if (q) {\n            h.hide(q);\n        }\n         else h.hide(j(\"OtherAppReqReminder\"));\n        \n    ;\n    ;\n    };\n    f.initNode = r;\n    f.initAggressiveNode = s;\n    f.handleRemove = v;\n    f.handleAggressiveRemove = w;\n    f.updateCount = y;\n    f.setTotalOtherCount = t;\n});\n__d(\"TickerReadStateTracking\", [\"event-extensions\",\"Style\",\"userAction\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Style\"), h = b(\"userAction\"), i = 73, j = \"ticker_hover\", k = [];\n    function l(n) {\n        var o = JSON.parse(n.getAttribute(\"data-ft\"));\n        if (!o) {\n            return null;\n        }\n    ;\n    ;\n        if (o.mf_story_key) {\n            return o.mf_story_key;\n        }\n    ;\n    ;\n        if (o.fbid) {\n            return o.fbid;\n        }\n    ;\n    ;\n        return null;\n    };\n;\n    function m(n) {\n        var o = l(n);\n        if (((!o || ((o in k))))) {\n            return;\n        }\n    ;\n    ;\n        k[o] = true;\n        var p = {\n            evt: i\n        };\n        h(j, n, null, \"FORCE\", {\n            ft: p\n        });\n    };\n;\n    e.exports.log = m;\n});\nfunction TickerRightHideController() {\n\n};\n;\nTickerRightHideController._markAsClosedHelper = function(a) {\n    var b = ge(\"pagelet_reminders\");\n    if (b) {\n        var c = DOM.scry(b, \"div.tickerToggleWrapper\")[0];\n        if (c) {\n            CSS.conditionClass(c, \"displayedTickerToggleWrapper\", a);\n        }\n    ;\n    ;\n    }\n;\n;\n    var d = ge(\"pagelet_rhc_ticker\");\n    if (d) {\n        var e = DOM.scry(d, \"div.tickerToggleWrapper\")[0];\n        if (e) {\n            CSS.conditionClass(e, \"displayedTickerToggleWrapper\", !a);\n        }\n    ;\n    ;\n        CSS.conditionClass(d, \"hidden_rhc_ticker\", a);\n    }\n;\n;\n};\nTickerRightHideController.markAsClosed = function() {\n    TickerRightHideController._markAsClosedHelper(true);\n};\nTickerRightHideController.markAsUnclosed = function() {\n    TickerRightHideController._markAsClosedHelper(false);\n};\n__d(\"TickerController\", [\"event-extensions\",\"Animation\",\"Arbiter\",\"AsyncRequest\",\"AsyncSignal\",\"Bootloader\",\"ChannelConstants\",\"ContextualDialogX\",\"CSS\",\"DOM\",\"HTML\",\"JSLogger\",\"Keys\",\"LayerFadeOnHide\",\"LiveTimer\",\"NavigationMessage\",\"Parent\",\"Run\",\"ScrollableArea\",\"Selector\",\"Style\",\"TickerReadStateTracking\",\"Toggler\",\"UIPagelet\",\"URI\",\"UserActivity\",\"UserAgent\",\"Vector\",\"$\",\"collectDataAttributes\",\"copyProperties\",\"ge\",\"goURI\",\"throttle\",\"userAction\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Animation\"), h = b(\"Arbiter\"), i = b(\"AsyncRequest\"), j = b(\"AsyncSignal\"), k = b(\"Bootloader\"), l = b(\"ChannelConstants\"), m = b(\"ContextualDialogX\"), n = b(\"CSS\"), o = b(\"DOM\"), p = b(\"HTML\"), q = b(\"JSLogger\"), r = b(\"Keys\"), s = b(\"LayerFadeOnHide\"), t = b(\"LiveTimer\"), u = b(\"NavigationMessage\"), v = b(\"Parent\"), w = b(\"Run\"), x = b(\"ScrollableArea\"), y = b(\"Selector\"), z = b(\"Style\"), aa = b(\"TickerReadStateTracking\"), ba = b(\"Toggler\"), ca = b(\"UIPagelet\"), da = b(\"URI\"), ea = b(\"UserActivity\"), fa = b(\"UserAgent\"), ga = b(\"Vector\"), ha = b(\"$\"), ia = b(\"collectDataAttributes\"), ja = b(\"copyProperties\"), ka = b(\"ge\"), la = b(\"goURI\"), ma = b(\"throttle\"), na = b(\"userAction\"), oa = 1, pa = 2, qa = 3, ra = 4, sa = q.create(\"ticker_controller\");\n    function ta() {\n    \n    };\n;\n    ja(ta, {\n        _instances: {\n        },\n        _activeInstance: null,\n        _placeholders: {\n        },\n        _logPositionChange: false,\n        getInstance: function(ua) {\n            var va = v.byClass(ha(ua), \"fbFeedTicker\");\n            return ((va ? ta._instances[va.id] : null));\n        },\n        isLoaded: function(ua) {\n            var va = ta._placeholders[ua.id];\n            return ((!va || ((va.JSBNG__status == qa))));\n        },\n        show: function(ua, va) {\n            va = ((va || bagofholding));\n            for (var wa in ta._instances) {\n                var xa = ka(wa);\n                if (((!xa || ((xa.parentNode.id == ua.id))))) {\n                    continue;\n                }\n            ;\n            ;\n                ta.hide(xa.parentNode);\n            };\n        ;\n            ta._doPositionChange(ua);\n            n.show(ua);\n            var ya = ta._placeholders[ua.id];\n            if (((ya && ((ya.JSBNG__status == oa))))) {\n                ta._fetchTickerForPlaceholder(ua, va);\n            }\n             else {\n                var za = o.scry(ua, \".fbFeedTicker\")[0], ab = ((za && ta.getInstance(za)));\n                ta._activeInstance = ab;\n                ((ab && ab._poll()));\n                ta._placeholders[ua.id] = {\n                    JSBNG__status: ra,\n                    callback: va\n                };\n                va();\n            }\n        ;\n        ;\n        },\n        _doPositionChange: function(ua) {\n            if (((!ta._logPositionChange || n.shown(ua)))) {\n                return;\n            }\n        ;\n        ;\n            new j(\"/common/ods_endpoint.php\", {\n                k: ((\"ticker.render.switch.\" + ua.id))\n            }).send();\n        },\n        hide: function(ua) {\n            var va = o.scry(ua, \".fbFeedTicker\")[0], wa = ((va && ta.getInstance(va)));\n            ((wa && wa.hideActiveStory()));\n            n.hide(ua);\n        },\n        hideStoriesByClass: function(ua) {\n            for (var va in ta._instances) {\n                o.scry(ha(va), ua).forEach(n.hide);\n            ;\n            };\n        ;\n        },\n        hideStory: function(ua) {\n            var va = ((ua && ta.getInstance(ua)));\n            ((va && va.hideStory(ua)));\n        },\n        undoHideStory: function(ua) {\n            var va = ((ua && ta.getInstance(ua)));\n            ((va && va.undoHideStory(ua)));\n        },\n        insertStoriesAtBottom: function(ua) {\n            ta._activeInstance.insertStoriesAtBottom(ua);\n        },\n        _fetchTickerForPlaceholder: function(ua, va) {\n            var wa = {\n                handler: function() {\n                    ta._placeholders[ua.id].JSBNG__status = qa;\n                    va();\n                }\n            };\n            ca.loadFromEndpoint(\"TickerPagelet\", ua.id, ta._placeholders[ua.id].pageletData, wa);\n            ta._placeholders[ua.id].JSBNG__status = pa;\n        },\n        registerStoryDialog: function(ua, va) {\n            h.subscribe(\"ticker/init\", function() {\n                var wa = ka(ua), xa = ((wa && ta.getInstance(wa)));\n                ((xa && xa.registerStoryDialog(wa, va)));\n            }, h.SUBSCRIBE_ALL);\n        },\n        registerPlaceholder: function(ua, va) {\n            var wa = ta._placeholders[ua];\n            ta._placeholders[ua] = {\n                JSBNG__status: oa,\n                pageletData: va\n            };\n            if (((wa && ((wa.JSBNG__status == ra))))) {\n                ta.show(ha(ua));\n                wa.callback();\n            }\n        ;\n        ;\n        }\n    });\n    ja(ta.prototype, {\n        ADS_IDLE_MS: 300000,\n        FLYOUT_MAX_HEIGHT: 450,\n        FLYOUT_OFFSET_THRESHOLD: 20,\n        FLYOUT_COMMENT_OFFSET: 15,\n        FLYOUT_VIEWPORT_PADDING: 75,\n        FLYOUT_TARGET_HEIGHT_OFFSET: 25,\n        init: function(ua, va, wa) {\n            ta._instances[ua.id] = this;\n            ta._activeInstance = this;\n            this._root = ua;\n            this._content = o.JSBNG__find(ua, \".ticker_stream\");\n            this._stories = o.JSBNG__find(this._root, \".tickerActivityStories\");\n            this._scrollableArea = va;\n            this._container = o.JSBNG__find(ua, \"div.uiScrollableAreaWrap\");\n            this._newestStory = {\n            };\n            this._storyIDs = [];\n            this._objectIDs = [];\n            this._fetchedStories = {\n            };\n            this._removedStoryIDs = [];\n            this._storiesToRemove = [];\n            var xa = JSBNG__Date.now();\n            this._initTime = xa;\n            this._lastUpdate = xa;\n            this._lastPull = xa;\n            this._lastInsert = xa;\n            this._lastCustomStory = 0;\n            this._pollOnly = false;\n            this._needNonCustomStoryNum = 0;\n            this._doCustomUpdate = true;\n            this._autoloadStoryIndex = 1;\n            this._scrollTopThreshold = 100;\n            this._scrollTopPrompt = o.JSBNG__find(this._root, \".scrollTopPrompt\");\n            this._scrollTopPromptVisible = false;\n            this._maxStoriesToKeep = 50;\n            this._minStoriesToKeep = 25;\n            this._tickerInSidebarMode = !!v.byClass(this._root, \"fbChatSidebar\");\n            this._loadStoriesWithActions();\n            this._ua = {\n                flyout: na(\"ticker_flyout\").set_namespace(\"ticker\").set_ua_id(\"flyout\"),\n                flyout_prefetch: na(\"ticker_flyout_prefetch\").set_namespace(\"ticker\").set_ua_id(\"flyout_prefetch\"),\n                flyout_loadtime: na(\"ticker_flyout_loadtime\").set_namespace(\"ticker\").set_ua_id(\"flyout_loadtime\"),\n                stream: na(\"ticker_stream\").set_namespace(\"ticker\").set_ua_id(\"stream\")\n            };\n            this._uaCurStoryIDFetch = null;\n            this._uaCurStoryIDPrefetch = null;\n            var ya = o.create(\"div\", {\n                className: \"storyQueue hidden_elem\"\n            });\n            this._storyQueue = ya;\n            o.appendContent(this._root, ya);\n            this._initObjectIDs();\n            this._initPageletCache(wa);\n            this._initConfig(wa);\n            this._resetMorePager();\n            this._initListeners();\n            this._initSubscriptions(wa);\n            h.inform(\"ticker/init\", this, h.BEHAVIOR_PERSISTENT);\n            this._poll();\n            if (this._prefetchAfterLoad) {\n                this._logUserEvent(\"stream\", \"prefetch\");\n                this._fetchStories(this._getInsertedStories().slice(0, 5));\n            }\n        ;\n        ;\n        },\n        _loadStoriesWithActions: function() {\n            var ua = ka(\"rightCol\");\n            if (!ua) {\n                return;\n            }\n        ;\n        ;\n            this._toggleWrapper = o.scry(ua, \".tickerToggleWrapper\")[0];\n            if (this._toggleWrapper) {\n                var va = o.scry(this._stories, \".tickerStoryWithButton\");\n                this._storiesWithActions = {\n                };\n                for (var wa = 0; ((wa < va.length)); wa++) {\n                    var xa = va[wa];\n                    this._storiesWithActions[xa.getAttribute(\"data-story-key\")] = xa;\n                };\n            ;\n            }\n        ;\n        ;\n        },\n        _initPageletCache: function(ua) {\n            if (window.PageletCacheController) {\n                this._cache = window.PageletCacheController.registerController(this._root.parentNode.id, this);\n                if (this._cache) {\n                    ja(ua, this._cache.loadData());\n                    this._cache.registerCleanup(\"Ticker/cleanup\");\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        _initConfig: function(ua) {\n            ja(this, {\n                _newest: ua.newest,\n                _page_newest: ua.newest,\n                _timeout: ua.timeout,\n                _heartbeatTimeout: Math.max(15000, ua.heartbeatTimeout),\n                _pullTimeout: Math.max(30000, ua.pullTimeout),\n                _insertTimeout: ua.insertTimeout,\n                _friendCount: ua.friendCount,\n                _maxQueueLength: ua.maxQueueLength,\n                _heartbeatEndpoint: ua.heartbeatEndpoint,\n                _noPoll: ua.nopoll,\n                _maxCustomQueueLength: ua.maxCustomQueueLength,\n                _customStoryInsertTimeout: Math.max(5000, ua.customStoryInsertTimeout),\n                _nonCustomToCustomStoryRatio: ua.nonCustomToCustomStoryRatio,\n                _minForceUpdateInterval: Math.max(ua.insertTimeout, ua.minForceUpdateInterval),\n                _popupOnHover: ua.popupOnHover,\n                _priorityAppId: ua.priorityAppId,\n                _prefetchOnHover: ua.prefetchStoriesOnHover,\n                _userIdleTimeout: ua.userIdleTimeout,\n                _firstCustomStoryDelay: ua.firstCustomStoryDelay,\n                _pollOnly: ua.pollOnly,\n                _tickerSource: ua.tickerSource,\n                _prefetchAfterLoad: ua.prefetchAfterLoad,\n                _logFlyouts: ua.logFlyouts,\n                _userScrollGaurdDelay: ua.userScrollGaurdDelay,\n                _rescheduleScrollToTopDelay: ua.rescheduleScrollToTopDelay,\n                _aggressiveRegulator: ua.aggressiveRegulator\n            });\n            this._queueCustomStories(ua.customStories);\n        },\n        _initListeners: function() {\n            this._listeners = JSBNG__Event.listen(this._root, {\n                click: this._handleClick.bind(this),\n                keydown: this._handleKeydown.bind(this),\n                mouseout: this._handleMouseout.bind(this),\n                mouseover: this._handleMouseover.bind(this),\n                mousedown: this._tickerDeClicker.bind(this),\n                mouseup: this._handleMouseup.bind(this)\n            });\n            this._listeners.JSBNG__scroll = JSBNG__Event.listen(this._container, \"JSBNG__scroll\", ma(this._handleScroll.bind(this)));\n            this._initInfiniteScrollListener.bind(this).defer();\n        },\n        _initSubscriptions: function(ua) {\n            w.JSBNG__onLeave(this._cleanup.bind(this));\n            this._subscriptions = [h.subscribe(u.NAVIGATION_BEGIN, this._onNavHandler.bind(this)),h.subscribe(l.getArbiterType(\"ticker_update\"), this._handleTickerPush.bind(this)),h.subscribe(\"composer/publish\", this._handleComposerPublish.bind(this)),h.subscribe(\"Ticker/storiesInserted\", this._handleStoriesInserted.bind(this)),h.subscribe(\"Ticker/fixed\", this._setFixed.bind(this, true)),h.subscribe(\"Ticker/unfixed\", this._setFixed.bind(this, false)),h.subscribe(\"Ticker/resized\", this._checkInfiniteScroll.bind(this)),h.subscribe(\"ufi/comment\", this._scrollDialogToBottom.bind(this)),h.subscribe(\"Ticker/chatOpened\", this._handleChatOpened.bind(this)),];\n            if (ua.pushChannel) {\n                this.setPushChannel(ua.pushChannel);\n            }\n        ;\n        ;\n        },\n        _handleClick: function(JSBNG__event) {\n            var ua = JSBNG__event.getTarget();\n            if (this._getButtonFromNode(ua)) {\n                this._logUserAction(ua, \"click\", JSBNG__event);\n                this._handleActionButton(JSBNG__event);\n                return;\n            }\n        ;\n        ;\n            var va = this._getStoryFromNode(ua), wa = v.byClass(ua, \"tickerStoryAllowClick\");\n            if (((((!va || ((va == this._selectedStory)))) || wa))) {\n                return;\n            }\n        ;\n        ;\n            if (this._storyIsHidden(va)) {\n                return;\n            }\n        ;\n        ;\n            if (((((va == this._activeStory)) && !this._selectedStory))) {\n                this._selecting = true;\n            }\n        ;\n        ;\n            this._clearNux();\n            this._logUserEvent(\"flyout\", \"click\");\n            this._logUserEvent(\"flyout_loadtime\", \"open\");\n            if (this._storyCanOpenExternally(va)) {\n                var xa = va.getAttribute(\"data-href\");\n                if (((xa && !ua.getAttribute(\"href\")))) {\n                    var ya = {\n                        href: xa\n                    }, za = ia(ua, [\"ft\",\"gt\",]);\n                    na(\"click\", ya, JSBNG__event, \"FORCE\", za);\n                }\n                 else this._logUserAction(ua, \"click\", JSBNG__event);\n            ;\n            ;\n                this._openStoryExternally(va, JSBNG__event);\n                return;\n            }\n        ;\n        ;\n            this._logUserAction(ua, \"flyout\", JSBNG__event);\n            this._activateStory(va, \"click\");\n            this._selectStory(va);\n        },\n        _handleMouseover: function(JSBNG__event) {\n            this._setLocked(true);\n            var ua = JSBNG__event.getTarget(), va = this._getOpenableStory(ua);\n            if (!va) {\n                return;\n            }\n        ;\n        ;\n            JSBNG__event.kill();\n            if (((this._prefetchOnHover || this._popupOnHover))) {\n                if (!((va.id in this._fetchedStories))) {\n                    this._logUserEvent(\"flyout_prefetch\", \"prefetch_on_hover\");\n                    this._uaCurStoryIDPrefetch = va.id;\n                }\n            ;\n            ;\n                this._fetchStory(va);\n            }\n        ;\n        ;\n            if (this._selectedStory) {\n                return;\n            }\n        ;\n        ;\n            if (this._popupOnHover) {\n                this._clearHoverTimeouts();\n                var wa = ((this._storyCanOpenExternally(va) ? 500 : 1000)), xa = ((this._activeStory ? 75 : wa));\n                if (((!window.JSBNG__addEventListener && JSBNG__document.createEventObject))) {\n                    JSBNG__event = JSBNG__document.createEventObject(JSBNG__event);\n                }\n            ;\n            ;\n                this._hoverShowTimeout = this._setTimeout(function() {\n                    this._logUserEvent(\"flyout\", \"hover\", xa);\n                    this._logUserEvent(\"flyout_loadtime\", \"open\");\n                    this._activateStory(va, \"hover\");\n                    this._logUserAction(ua, \"flyout\", JSBNG__event);\n                }.bind(this), xa);\n            }\n        ;\n        ;\n        },\n        _handleMouseout: function(JSBNG__event) {\n            var ua = JSBNG__event.getTarget();\n            this._setLocked(false);\n            if (((ua == this._getStoryFromNode(ua)))) {\n                var va = o.scry(ua.parentNode, \".openToggler\");\n                for (var wa = 0; ((wa < va.length)); wa++) {\n                    y.toggle(va[wa]);\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            this._clearClickedStory();\n            this._scheduleHide();\n        },\n        _handleKeydown: function(JSBNG__event) {\n            this._tickerDeClicker(JSBNG__event);\n            var ua = this._activeStory;\n            if (!ua) {\n                return;\n            }\n        ;\n        ;\n            var va = JSBNG__Event.getKeyCode(JSBNG__event);\n            switch (va) {\n              case r.UP:\n            \n              case r.DOWN:\n                var wa = this._getInsertedStories(), xa;\n                if (JSBNG__event.getModifiers().any) {\n                    xa = ((((va === r.UP)) ? 0 : ((wa.length - 1))));\n                }\n                 else xa = ((wa.indexOf(ua) + ((((va === r.UP)) ? -1 : 1))));\n            ;\n            ;\n                ua = wa[xa];\n                break;\n              case r.ESC:\n                this._deactivateStory(true);\n                return;\n              default:\n                return;\n            };\n        ;\n            if (!ua) {\n                return;\n            }\n        ;\n        ;\n            JSBNG__event.kill();\n            this._activateStory(ua, \"keypress\");\n            this._selectStory(ua);\n        },\n        _fadeTopmostStoryButton: function() {\n            var ua = 0, va = 15;\n            if (this._storiesWithActions) {\n                for (var wa in this._storiesWithActions) {\n                    var xa = this._storiesWithActions[wa], ya = o.scry(xa, \".tickerInlineActionButton\")[0], za = o.scry(ya, \".tickerActionIcon\")[0], ab = ((ga.getElementPosition(ya).y - ga.getElementPosition(this._toggleWrapper).y));\n                    if (((ab < ua))) {\n                        z.set(ya, \"opacity\", 0);\n                        z.set(za, \"opacity\", 0);\n                    }\n                     else if (((((ab >= ua)) && ((ab < va))))) {\n                        var bb = ((((ab - ua)) / ((va - ua))));\n                        z.set(ya, \"opacity\", bb);\n                        z.set(za, \"opacity\", bb);\n                        break;\n                    }\n                     else {\n                        z.set(ya, \"opacity\", 1);\n                        z.set(za, \"opacity\", 1);\n                    }\n                    \n                ;\n                ;\n                };\n            }\n        ;\n        ;\n        },\n        _handleScroll: function() {\n            this._fadeTopmostStoryButton();\n            ((!this._preventScrollDismiss && this._deactivateStory(true)));\n            this._checkInfiniteScroll();\n            this._setIsUserScrolling();\n            if (!this._scrollLogged) {\n                this._scrollLogged = true;\n                var ua = this._stories.childNodes.length, va = this._stories.getAttribute(\"data-gt\"), wa = {\n                    ticker_scroll: 1,\n                    number_stories: ua,\n                    source: va\n                };\n                na(\"JSBNG__scroll\", null, null, \"FORCE\", {\n                    gt: wa\n                }).set_namespace(\"ticker\");\n            }\n        ;\n        ;\n        },\n        _setIsUserScrolling: function() {\n            JSBNG__clearTimeout(this._userScrollingToken);\n            if (this._isScrolledToTop()) {\n                this._userScrolling = false;\n                return;\n            }\n        ;\n        ;\n            this._userScrolling = true;\n            this._userScrollingToken = JSBNG__setTimeout(function() {\n                this._userScrolling = false;\n                this._userScrollingToken = null;\n            }.bind(this), this._userScrollGaurdDelay);\n        },\n        _isUserScrolling: function() {\n            return this._userScrolling;\n        },\n        _handleStoriesInserted: function() {\n            this._initInfiniteScrollListener();\n            if (((this._scrollableArea instanceof x))) {\n                this._scrollableArea.adjustGripper();\n            }\n             else sa.error(\"wrong_scrollable_area\", {\n                JSBNG__dump: this\n            });\n        ;\n        ;\n            this._logUserEvent(\"stream\", \"insert\");\n        },\n        _handleActionButton: function(JSBNG__event) {\n            var ua = JSBNG__event.getTarget(), va = this._getButtonFromNode(ua), wa = this._getOpenableStory(ua), xa = this._getStoryDialog(wa);\n            if (xa) {\n                var ya = xa.subscribe(\"beforehide\", function() {\n                    xa.unsubscribe(ya);\n                    return false;\n                });\n            }\n        ;\n        ;\n        },\n        _handleScrollToTopClick: function() {\n            this._scrollToTop(this._poll.bind(this));\n        },\n        _scheduleScrollToTop: function() {\n            ((this._scrollToTopToken && JSBNG__clearTimeout(this._scrollToTopToken)));\n            this._scrollToTopToken = JSBNG__setTimeout(function() {\n                if (((this._isLocked() || this._isUserScrolling()))) {\n                    this._scheduleScrollToTop();\n                }\n                 else {\n                    this._scrollToTopToken = null;\n                    this._scrollToTop();\n                }\n            ;\n            ;\n            }.bind(this), this._rescheduleScrollToTopDelay);\n        },\n        _scrollToTop: function(ua) {\n            new g(this._container).to(\"scrollTop\", 0).ease(g.ease.end).JSBNG__ondone(ua).go();\n        },\n        _clearHoverTimeouts: function() {\n            JSBNG__clearTimeout(this._hoverShowTimeout);\n            JSBNG__clearTimeout(this._hoverHideTimeout);\n        },\n        _getAllStories: function() {\n            return o.scry(this._root, \"div.fbFeedTickerStory\");\n        },\n        _getInsertedStories: function() {\n            return this._getAllStories().filter(function(ua) {\n                return ((!n.hasClass(ua, \"queuedStory\") && !n.hasClass(ua, \"customStory\")));\n            });\n        },\n        _getQueuedStories: function() {\n            return o.scry(this._storyQueue, \".fbFeedTickerStory.queuedStory\");\n        },\n        _getQueuedCustomStories: function() {\n            return o.scry(this._storyQueue, \".fbFeedTickerStory.customStory\");\n        },\n        _getButtonFromNode: function(ua) {\n            return v.byClass(ua, \"tickerInlineOverlay\");\n        },\n        _getStoryFromNode: function(ua) {\n            return v.byClass(ua, \"fbFeedTickerStory\");\n        },\n        _getActionButtonFromStory: function(ua) {\n            return o.scry(ua, \".tickerInlineActionButton\")[0];\n        },\n        _getOpenableStory: function(ua) {\n            var va = this._getStoryFromNode(ua);\n            return ((this._storyCanOpenDialog(va) ? va : null));\n        },\n        _getStoryDialog: function(ua) {\n            return m.getInstance(ua);\n        },\n        _getStoryDialogEndpoint: function(ua) {\n            return ((((((ua && ((ua.getAttribute(\"data-rel\") == \"async\")))) && ua.getAttribute(\"data-ajaxify\"))) || null));\n        },\n        _storyCanOpenDialog: function(ua) {\n            return ((!!this._getStoryDialogEndpoint(ua) && !this._storyIsHidden(ua)));\n        },\n        _storyCanOpenExternally: function(ua) {\n            return ((!!ua.getAttribute(\"data-href\") || !this._storyCanOpenDialog(ua)));\n        },\n        _storyIsHidden: function(ua) {\n            return n.hasClass(ua, \"tickerStoryHidden\");\n        },\n        hideActiveStory: function() {\n            ((this._activeStory && this.hideStory(this._activeStory)));\n        },\n        hideStory: function(ua) {\n            this._deactivateStory();\n            n.addClass(ua, \"tickerStoryHidden\");\n            n.removeClass(ua, \"tickerStoryClickable\");\n        },\n        undoHideStory: function(ua) {\n            n.addClass(ua, \"tickerStoryClickable\");\n            n.removeClass(ua, \"tickerStoryHidden\");\n        },\n        insertStoriesAtBottom: function(ua) {\n            if (!ua) {\n                return;\n            }\n        ;\n        ;\n            var va = o.create(\"div\");\n            va.appendChild(ua);\n            var wa = o.scry(va, \".fbFeedTickerStory\"), xa = o.JSBNG__find(va, \".tickerMorePager\"), ya = [];\n            for (var za = 0; ((za < ((wa.length - 1)))); za++) {\n                if (!this.dedupeStory(wa[za])) {\n                    ya.push(wa[za]);\n                }\n            ;\n            ;\n            };\n        ;\n            if (ya.length) {\n                ya.push(xa);\n                o.replace(o.JSBNG__find(this._root, \".tickerMorePager\"), ya);\n            }\n        ;\n        ;\n            h.inform(\"Ticker/storiesInserted\");\n        },\n        _scheduleHide: function() {\n            if (((this._popupOnHover && !this._selectedStory))) {\n                this._clearHoverTimeouts();\n                this._hoverHideTimeout = this._setTimeout(this._deactivateStory.bind(this), 100);\n            }\n        ;\n        ;\n        },\n        _setScrollTopPromptVisible: function(ua) {\n            this._scrollTopPromptVisible = ua;\n            n.conditionShow(this._scrollTopPrompt, ua);\n            if (((ua && !this._listeners.scrollTop))) {\n                this._listeners.scrollTop = JSBNG__Event.listen(this._scrollTopPrompt, {\n                    click: this._handleScrollToTopClick.bind(this)\n                });\n            }\n             else if (((!ua && this._listeners.scrollTop))) {\n                this._listeners.scrollTop.click.remove();\n                this._listeners.scrollTop = null;\n            }\n            \n        ;\n        ;\n        },\n        _isUserIdle: function() {\n            return !ea.isActive(this._userIdleTimeout);\n        },\n        _schedulePoll: function() {\n            JSBNG__clearTimeout(this._pollToken);\n            this._pollToken = this._setTimeout(this._poll.bind(this), this._timeout);\n        },\n        _poll: function() {\n            if (!this._isTickerVisible()) {\n                return;\n            }\n        ;\n        ;\n            if (((this._storiesToRemove.length > 0))) {\n                if (this._isInsertingStory) {\n                    return this._schedulePoll();\n                }\n            ;\n            ;\n                var ua = this._storiesToRemove.pop();\n                this.removeStory(ua);\n            }\n        ;\n        ;\n            var va = ((!this._isScrolledToTop() && this._getQueuedStories().length));\n            this._setScrollTopPromptVisible(va);\n            var wa = JSBNG__Date.now(), xa = ((wa - this._lastInsert));\n            if (((((xa < this._insertTimeout)) || this._isLocked()))) {\n                return this._schedulePoll();\n            }\n        ;\n        ;\n            var ya = this._getQueuedStories(), za = this._getQueuedCustomStories(), ab = this._isUserIdle(), bb = ((ya.length > 0)), cb = ((((((((za.length > 0)) && !ab)) && ((((wa - this._initTime)) > this._firstCustomStoryDelay)))) && ((((this._needNonCustomStoryNum === 0)) || ((!bb && ((((wa - this._lastCustomStory)) > this._customStoryInsertTimeout))))))));\n            if (cb) {\n                this.insertStory(za.shift());\n                this._lastCustomStory = wa;\n                this._needNonCustomStoryNum = this._nonCustomToCustomStoryRatio;\n                return this._schedulePoll();\n            }\n        ;\n        ;\n            if (bb) {\n                this.insertStory(ya.shift());\n                this._needNonCustomStoryNum--;\n                if (((this._needNonCustomStoryNum < 0))) {\n                    this._needNonCustomStoryNum = 0;\n                }\n            ;\n            ;\n                return this._schedulePoll();\n            }\n        ;\n        ;\n            if (ab) {\n                return ea.subscribeOnce(this._poll.bind(this));\n            }\n        ;\n        ;\n            var db = ((((((((((za.length === 0)) && ((this._needNonCustomStoryNum === 0)))) && ((this._nonCustomToCustomStoryRatio > 0)))) && ea.isActive(this.ADS_IDLE_MS))) && ((((wa - this._lastUpdate)) > this._minForceUpdateInterval)))), eb = false, fb = false;\n            if (this._pollOnly) {\n                fb = ((((wa - this._lastUpdate)) > this._heartbeatTimeout));\n            }\n             else eb = ((((wa - this._lastPull)) > this._pullTimeout));\n        ;\n        ;\n            var gb = ((((((db && this._doCustomUpdate)) || eb)) || fb));\n            if (!gb) {\n                return this._schedulePoll();\n            }\n        ;\n        ;\n            if (db) {\n                this._doCustomUpdate = false;\n            }\n        ;\n        ;\n            this.update({\n                pull: eb,\n                fullpoll: fb,\n                needcustomstory: db\n            });\n        },\n        update: function(ua) {\n            if (((this._noPoll && !this._pollOnly))) {\n                return this._schedulePoll();\n            }\n        ;\n        ;\n            var va = {\n                newest: ((((ua.fullpoll || ua.cache_update)) ? this._newest : this._page_newest)),\n                storyids: this._storyIDs,\n                friendcount: this._friendCount,\n                priorityappid: this._priorityAppId,\n                source: this._tickerSource,\n                needcustomstory: ((this._nonCustomToCustomStoryRatio > 0))\n            };\n            ja(va, ua);\n            new i().setURI(this._heartbeatEndpoint).setReadOnly(true).setOption(\"retries\", 0).setData(va).setHandler(this._handleResponse.bind(this)).setFinallyHandler(this._poll.bind(this)).setAllowCrossPageTransition(true).send();\n            this._lastUpdate = JSBNG__Date.now();\n            if (va.pull) {\n                this._lastPull = this._lastUpdate;\n            }\n        ;\n        ;\n            this._storyIDs = [];\n        },\n        insertStory: function(ua, va, wa) {\n            this._lastInsert = JSBNG__Date.now();\n            ((window.LiveTimer && t.addTimeStamps(ua)));\n            n.removeClass(ua, \"queuedStory\");\n            n.removeClass(ua, \"customStory\");\n            if (((va !== false))) {\n                var xa = ((wa ? this._fadeStoryIn : this._flyStoryIn));\n                if (this._isUserScrolling()) {\n                    var ya = function() {\n                        this._container.scrollTop = ((this._container.scrollTop + this._stories.firstChild.offsetHeight));\n                        this._scheduleScrollToTop();\n                    }.bind(this);\n                    this._fadeStoryIn(ua, ya);\n                }\n                 else this._scrollToTop(xa.bind(this, ua));\n            ;\n            ;\n            }\n             else o.prependContent(this._stories, ua);\n        ;\n        ;\n            if (((this._storiesWithActions && n.hasClass(ua, \"tickerStoryWithButton\")))) {\n                this._storiesWithActions[ua.getAttribute(\"data-story-key\")] = ua;\n            }\n        ;\n        ;\n            this._removeOldStories();\n        },\n        _removeOldStories: function() {\n            var ua = this._getInsertedStories();\n            if (((ua.length <= this._maxStoriesToKeep))) {\n                return;\n            }\n        ;\n        ;\n            var va = this._minStoriesToKeep, wa = ua.slice(va);\n            wa.forEach(o.remove);\n            if (this._storiesWithActions) {\n                for (var xa = 0; ((xa < wa.length)); xa++) {\n                    delete this._storiesWithActions[wa[xa].getAttribute(\"data-story-key\")];\n                ;\n                };\n            }\n        ;\n        ;\n            this._resetMorePager();\n        },\n        _resetMorePager: function() {\n            var ua = this._getInsertedStories();\n            if (((!ua || !ua.length))) {\n                return;\n            }\n        ;\n        ;\n            var va = ua[((ua.length - 1))].getAttribute(\"data-ticker-timestamp\"), wa = o.scry(this._root, \".tickerMorePager a\")[0];\n            if (((!wa || !va))) {\n                return;\n            }\n        ;\n        ;\n            var xa = new da(wa.getAttribute(\"ajaxify\"));\n            xa.addQueryData({\n                oldest: va\n            });\n            wa.setAttribute(\"ajaxify\", xa);\n        },\n        _setLocked: function(ua) {\n            this._locked = ua;\n        },\n        _isLocked: function() {\n            return !!((this._locked || this._activeStory));\n        },\n        informAndRemoveStory: function(ua, va, wa) {\n            var xa = this._getStoryFromNode(ua), ya = xa.getAttribute(\"data-story-key\");\n            o.setContent(xa, va);\n            n.addClass(xa, \"highlightedStory\");\n            this._setTimeout(this.removeStory.bind(this, ya), ((wa || 6000)));\n        },\n        _getStoryByStoryKey: function(ua) {\n            var va = this._getAllStories();\n            for (var wa = 0; ((wa < va.length)); wa++) {\n                var xa = va[wa];\n                if (((xa.getAttribute(\"data-story-key\") == ua))) {\n                    return xa;\n                }\n            ;\n            ;\n            };\n        ;\n            return null;\n        },\n        removeStory: function(ua) {\n            this._removedStoryIDs[ua] = true;\n            var va = this._getStoryByStoryKey(ua);\n            if (!va) {\n                return;\n            }\n        ;\n        ;\n            if (this._storiesWithActions) {\n                delete this._storiesWithActions[ua];\n            }\n        ;\n        ;\n            if (((va == this._activeStory))) {\n                this._deactivateStory();\n            }\n        ;\n        ;\n            var wa = this._getStoryDialog(va);\n            ((wa && wa.destroy()));\n            if (n.hasClass(va, \"queuedStory\")) {\n                o.remove(va);\n                return;\n            }\n        ;\n        ;\n            this._animateStoryOut(va);\n        },\n        _isScrolledToTop: function() {\n            return ((this._container.scrollTop <= this._scrollTopThreshold));\n        },\n        _flyStoryIn: function(ua) {\n            var va = o.create(\"div\", {\n                style: {\n                    marginTop: \"-1000px\"\n                }\n            }, ua);\n            z.set(va, \"opacity\", 0);\n            o.prependContent(this._stories, va);\n            var wa = ga.getElementDimensions(va).y;\n            z.set(va, \"marginTop\", ((((\"-\" + wa)) + \"px\")));\n            this._isInsertingStory = true;\n            new g(va).to(\"marginTop\", 0).ease(g.ease.end).checkpoint(54718).to(\"opacity\", 1).JSBNG__ondone(function() {\n                o.replace(va, ua);\n                this._afterInsert(ua);\n                this._isInsertingStory = false;\n            }.bind(this)).go();\n        },\n        _fadeStoryIn: function(ua, va) {\n            new g(this._stories).to(\"opacity\", 54908).JSBNG__ondone(function() {\n                o.prependContent(this._stories, ua);\n                if (va) {\n                    va();\n                }\n            ;\n            ;\n                new g(this._stories).to(\"opacity\", 1).JSBNG__ondone(function() {\n                    this._afterInsert(ua);\n                }.bind(this)).go();\n            }.bind(this)).go();\n        },\n        _animateStoryOut: function(ua) {\n            var va = o.create(\"div\", {\n                style: {\n                    overflow: \"hidden\",\n                    position: \"relative\"\n                }\n            });\n            o.insertBefore(ua, va);\n            o.appendContent(va, ua);\n            new g(va).to(\"JSBNG__top\", 20).to(\"height\", 0).to(\"opacity\", 0).ease(g.ease.end).JSBNG__ondone(function() {\n                o.remove.curry(va);\n                h.inform(\"Ticker/animateOut\");\n            }.bind(this)).go();\n        },\n        _afterInsert: function(ua) {\n            h.inform(\"Ticker/afterInsert\");\n        },\n        setPushChannel: function(ua) {\n            ((this._pushSubscription && this._pushSubscription.unsubscribe()));\n            this._pushSubscription = h.subscribe(l.getArbiterType(ua), this._handleTickerPush.bind(this));\n            d([\"ChatConfig\",\"ChannelConnection\",], function(va, wa) {\n                this._channelConnection = wa;\n                this._checkChannelConnection();\n                this._channelConnectionSubscription = this._channelConnection.subscribe([this._channelConnection.CONNECTED,this._channelConnection.RECONNECTING,this._channelConnection.SHUTDOWN,this._channelConnection.MUTE_WARNING,this._channelConnection.UNMUTE_WARNING,], this._handleChannelConnection.bind(this));\n            }.bind(this));\n        },\n        _checkChannelConnection: function() {\n            n.conditionClass(this._root, \"disconnected\", this._channelConnection.disconnected());\n        },\n        setCurrentAppId: function(ua) {\n            this._priorityAppId = ua;\n        },\n        _handleTickerPush: function(ua, va) {\n            var wa = va.obj;\n            if (wa.delete_id) {\n                this._storiesToRemove.push(wa.delete_id);\n                return;\n            }\n        ;\n        ;\n            if (wa.fromups) {\n                if (wa.do_logging) {\n                    this._logDarkLaunch(wa);\n                }\n            ;\n            }\n        ;\n        ;\n            var xa = wa.story_xhp;\n            if (!xa) {\n                return;\n            }\n        ;\n        ;\n            this._newest = wa.story_time;\n            var ya = p(xa).getRootNode();\n            this.queueStory(ya, wa.flyout_js_cmds);\n            if (((this._aggressiveRegulator && ((wa.actor == this._newestStory.actorID))))) {\n                this.removeStory(this._newestStory.storyKey);\n                new j(\"/common/ods_endpoint.php\", {\n                    k: \"ticker.aggr.remove\"\n                }).send();\n            }\n        ;\n        ;\n            this._newestStory = {\n                actorID: wa.actor,\n                storyKey: ya.getAttribute(\"data-story-key\")\n            };\n        },\n        _handleComposerPublish: function(ua, va) {\n            ((va.tickerMarkup && this.insertStory(va.tickerMarkup)));\n        },\n        _clearNux: function() {\n            var ua = o.scry(JSBNG__document.body, \"div.tickerNUXContainer\");\n            if (ua.length) {\n                ua.forEach(function(va) {\n                    var wa = m.getInstance(va);\n                    ((wa && wa.hide()));\n                });\n                new i().setURI(\"/ajax/feed/ticker/nux.php\").send();\n            }\n        ;\n        ;\n            this._clearNux = bagofholding;\n        },\n        _logDarkLaunch: function(ua) {\n            var va = {\n                actor: ua.actor,\n                story_time: ua.story_time,\n                key: ua.story_obj_id,\n                dark: 1\n            };\n            new i().setURI(\"/alite/push/log.php\").setData({\n                msg: JSON.stringify(va)\n            }).send();\n        },\n        _logRender: function() {\n            if (this._loggedRender) {\n                return;\n            }\n        ;\n        ;\n            var ua = this._tickerInSidebarMode;\n            if (((ua || v.byClass(this._content, \"home_right_column\")))) {\n                new j(\"/ajax/log_ticker_render.php\", {\n                    sidebar_mode: ua\n                }).send();\n                this._loggedRender = true;\n            }\n        ;\n        ;\n        },\n        _isTickerVisible: function() {\n            var ua = ((ta._activeInstance == this));\n            ((ua && this._logRender()));\n            return ua;\n        },\n        _handleResponse: function(ua) {\n            var va = ua.getPayload();\n            if (va.newest) {\n                this._newest = this._page_newest = va.newest;\n            }\n        ;\n        ;\n            if (va.JSBNG__content) {\n                if (((va.cache_update && this._cache))) {\n                    this._cache.insertStory(va.JSBNG__content);\n                }\n                 else if (((va.JSBNG__content instanceof Array))) {\n                    for (var wa = 0; ((wa < va.JSBNG__content.length)); wa++) {\n                        this.queueStoryMarkup(va.JSBNG__content[wa]);\n                    ;\n                    };\n                ;\n                }\n                 else this.queueStoryMarkup(va.JSBNG__content);\n                \n            ;\n            }\n        ;\n        ;\n            if (((va.custom_stories && va.custom_stories.length))) {\n                this._queueCustomStories(va.custom_stories);\n                this._doCustomUpdate = true;\n            }\n        ;\n        ;\n        },\n        queueStoryMarkup: function(ua) {\n            var va = p(ua).getRootNode();\n            this.queueStory(va);\n        },\n        dedupeStory: function(ua) {\n            var va = ua.getAttribute(\"data-story-key\"), wa = ((va && ((!!this._objectIDs[va] || !!this._removedStoryIDs[va]))));\n            ((va && (this._objectIDs[va] = true)));\n            return wa;\n        },\n        queueStory: function(ua, va) {\n            if (this.dedupeStory(ua)) {\n                return;\n            }\n        ;\n        ;\n            n.addClass(ua, \"queuedStory\");\n            o.appendContent(this._storyQueue, ua);\n            var wa = ((va && va.length));\n            if (wa) {\n                va.forEach(function(ya) {\n                    new Function(ya).apply();\n                });\n            }\n        ;\n        ;\n            ua.setAttribute(\"id\", ((((ua.id + \"_\")) + this._root.id)));\n            var xa = this._getQueuedStories();\n            xa.slice(0, -this._maxQueueLength).forEach(o.remove);\n            if (wa) {\n                this._fetchedStories[ua.id] = true;\n            }\n        ;\n        ;\n        },\n        _queueCustomStories: function(ua) {\n            while (ua.length) {\n                var va = ua.shift();\n                va = p(va).getRootNode();\n                var wa = va.getAttribute(\"data-story-key\");\n                if (this.dedupeStory(va)) {\n                    continue;\n                }\n            ;\n            ;\n                n.addClass(va, \"customStory\");\n                o.appendContent(this._storyQueue, va);\n            };\n        ;\n            var xa = this._getQueuedCustomStories();\n            xa.slice(0, -this._maxQueueLength).forEach(o.remove);\n        },\n        _cleanup: function() {\n            ta._placeholders.pagelet_rhc_ticker = null;\n            if (!v.byClass(this._content, \"hasRightCol\")) {\n                return;\n            }\n        ;\n        ;\n            this._objectIDs = [];\n            this._subscriptions.forEach(h.unsubscribe);\n            ((this._channelConnectionSubscription && this._channelConnection.unsubscribe(this._channelConnectionSubscription)));\n            ((this._pushSubscription && this._pushSubscription.unsubscribe()));\n            for (var ua in this._listeners) {\n                ((this._listeners[ua] && this._listeners[ua].remove()));\n            ;\n            };\n        ;\n            JSBNG__clearTimeout(this._pollToken);\n            this._pollToken = null;\n            this._cleanupInputFocusListener();\n            this._cleanupContentResizeListener();\n            h.inform(\"Ticker/cleanup\");\n        },\n        _onNavHandler: function(ua, va) {\n            var wa = va.params.key;\n            if (((((wa != \"lf\")) && ((wa != \"h\"))))) {\n                this._cleanup();\n            }\n        ;\n        ;\n        },\n        registerStoryDialog: function(ua, va) {\n            if (((this._uaCurStoryIDFetch == ua.id))) {\n                this._uaCurStoryIDFetch = null;\n                this._logUserEvent(\"flyout\", \"fetch_success\");\n            }\n        ;\n        ;\n            if (((this._uaCurStoryIDPrefetch == ua.id))) {\n                this._uaCurStoryIDPrefetch = null;\n                this._logUserEvent(\"flyout_prefetch\", \"prefetch_success\");\n            }\n        ;\n        ;\n            this._fetchedStories[ua.id] = true;\n            va.setContext(ua);\n            va.subscribe(\"hide\", this._deactivateStory.bind(this, true));\n            va.subscribe(\"success\", this._focusStory.bind(this, ua));\n            va.subscribe(\"beforehide\", function() {\n                if (this._selecting) {\n                    this._selecting = false;\n                    return false;\n                }\n            ;\n            ;\n            }.bind(this));\n            if (this._popupOnHover) {\n                va.subscribe(\"mouseenter\", this._clearHoverTimeouts.bind(this));\n                va.subscribe(\"mouseleave\", this._scheduleHide.bind(this));\n                va.subscribe(\"show\", function() {\n                    this._highlightDialogScrollbar.bind(this, va).defer();\n                    var wa = JSBNG__Event.listen(va.getContent(), \"click\", function() {\n                        this._selectStory(ua);\n                        wa.remove();\n                    }.bind(this));\n                }.bind(this));\n            }\n        ;\n        ;\n            if (((ua == this._activeStory))) {\n                this._logUserEvent(\"flyout_loadtime\", \"show_fetched\");\n                this._logUserEvent(\"flyout\", \"show\");\n                this._openDialog(va);\n            }\n        ;\n        ;\n        },\n        _highlightDialogScrollbar: function(ua) {\n            var va = o.scry(ua.getContent(), \".uiScrollableArea\")[0];\n            ((va && x.poke(va)));\n        },\n        _openStoryExternally: function(ua, JSBNG__event) {\n            var va = ua.getAttribute(\"data-href\");\n            if (((!va || ((va == \"#\"))))) {\n                return;\n            }\n        ;\n        ;\n            var wa = ua.getAttribute(\"data-story-rel\");\n            switch (wa) {\n              case \"theater\":\n                this._deactivateAndClearStory();\n                k.loadModules([\"PhotoViewer\",], function(za) {\n                    za.bootstrap(va, ua);\n                });\n                return;\n              case \"async\":\n                this._deactivateAndClearStory();\n                i.bootstrap(va, ua);\n                return;\n            };\n        ;\n            var xa = ua.getAttribute(\"data-target\"), ya = ((((((JSBNG__event.which != 1)) || JSBNG__event.getModifiers().any)) || ((xa == \"_blank\"))));\n            ((ya ? window.open(va, \"_blank\") : la(va)));\n        },\n        _deactivateAndClearStory: function() {\n            this._clearHoverTimeouts();\n            this._deactivateStory();\n        },\n        _focusStory: function(ua) {\n            JSBNG__clearTimeout(this._scrollDismissal);\n            this._preventScrollDismiss = true;\n            this._scrollDismissal = this._setTimeout(function() {\n                this._preventScrollDismiss = false;\n            }.bind(this), 100);\n            ua.JSBNG__focus();\n        },\n        _selectStory: function(ua) {\n            this._selectedStory = ua;\n            n.addClass(ua, \"tickerStorySelected\");\n            n.addClass(this._root, \"tickerChildSelected\");\n        },\n        _activateStory: function(ua, va) {\n            this._clearHoverTimeouts();\n            if (((((ua == this._activeStory)) || !this._storyCanOpenDialog(ua)))) {\n                return;\n            }\n        ;\n        ;\n            this._deactivateStory();\n            this._focusStory(ua);\n            this._activeStory = ua;\n            n.addClass(ua, \"tickerStoryActive\");\n            ((window.Toggler && ba.hide()));\n            if (this._logFlyouts) {\n                va = ((va || \"unknown\"));\n                new j(\"/ajax/feed/ticker/flyout.php\", {\n                    src: va\n                }).send();\n            }\n        ;\n        ;\n            aa.log(ua);\n            var wa = this._getStoryDialog(ua);\n            if (wa) {\n                this._logUserEvent(\"flyout_loadtime\", \"show_prefetched\");\n                this._logUserEvent(\"flyout\", \"show\");\n                this._openDialog(wa);\n                return;\n            }\n        ;\n        ;\n            if (!((ua.id in this._fetchedStories))) {\n                this._uaCurStoryIDFetch = ua.id;\n                this._logUserEvent(\"flyout\", \"fetch\");\n            }\n        ;\n        ;\n            this._fetchStory(ua);\n        },\n        _deactivateStory: function(ua) {\n            if (((this._activeStory === this._deactivatingStory))) {\n                return;\n            }\n        ;\n        ;\n            this._deactivatingStory = this._activeStory;\n            if (this._dialog) {\n                if (((ua === true))) {\n                    this._dialog.enableBehavior(s);\n                }\n                 else this._dialog.disableBehavior(s);\n            ;\n            ;\n                this._dialog.hide();\n                this._logUserEvent(\"flyout\", \"close\");\n            }\n        ;\n        ;\n            if (this._activeStory) {\n                n.removeClass(this._activeStory, \"tickerStoryActive\");\n                n.removeClass(this._activeStory, \"tickerStorySelected\");\n                n.removeClass(this._root, \"tickerChildSelected\");\n            }\n        ;\n        ;\n            this._dialog = this._selectedStory = this._activeStory = null;\n            this._cleanupInputFocusListener();\n            this._cleanupContentResizeListener();\n            this._deactivatingStory = null;\n        },\n        _logUserAction: function(ua, va, JSBNG__event) {\n            na(va, ua, JSBNG__event, \"FORCE\");\n        },\n        _logUserEvent: function(ua, JSBNG__event) {\n            if (this._ua[ua]) {\n                this._ua[ua].add_event(JSBNG__event);\n            }\n        ;\n        ;\n        },\n        _fetchStory: function(ua) {\n            JSBNG__clearTimeout(this._fetchToken);\n            var va = [], wa = this._getInsertedStories(), xa = wa.indexOf(ua);\n            [-1,0,1,].forEach(function(ya) {\n                var za = wa[((xa + ya))];\n                ((za && va.push(za)));\n            }, this);\n            this._fetchToken = JSBNG__setTimeout(this._fetchStories.bind(this, va), 100);\n        },\n        _fetchStories: function(ua) {\n            var va = [], wa, xa = function(ya) {\n                JSBNG__clearTimeout(wa);\n                ua.forEach(function(za) {\n                    n.conditionClass(za, \"tickerStoryFetching\", ya);\n                });\n            };\n            ua = ua.filter(function(ya) {\n                if (((ya.id in this._fetchedStories))) {\n                    return false;\n                }\n            ;\n            ;\n                this._fetchedStories[ya.id] = true;\n                var za = this._getStoryDialogEndpoint(ya), ab = da(za).getQueryData();\n                if (((!za || !ab))) {\n                    return false;\n                }\n            ;\n            ;\n                ab.uniq_id = ya.getAttribute(\"id\");\n                ab.referrer = this._tickerSource;\n                va.push(ab);\n                return true;\n            }, this);\n            if (!va.length) {\n                return;\n            }\n        ;\n        ;\n            wa = this._setTimeout(xa.curry(true), 500);\n            new i(\"/ajax/feed/ticker/multi_story\").setFinallyHandler(xa.curry(false)).setErrorHandler(bagofholding).setData({\n                stories: va\n            }).setAllowCrossPageTransition(this._tickerInSidebarMode).send();\n        },\n        _tickerDeClicker: function(JSBNG__event) {\n            var ua = JSBNG__event.getTarget(), va = v.byTag(ua, \"a\"), wa = this._getStoryFromNode(ua), xa = this._getButtonFromNode(ua);\n            if (((((((((((wa && va)) && !xa)) && n.hasClass(wa, \"tickerStoryClickable\"))) && !n.hasClass(va, \"tickerStoryAllowClick\"))) && !this._storyIsHidden(wa)))) {\n                va.setAttribute(\"rel\", \"ignore\");\n                va.removeAttribute(\"JSBNG__onclick\");\n                va.removeAttribute(\"ajaxify\");\n                va.removeAttribute(\"href\");\n            }\n        ;\n        ;\n            var ya = ((JSBNG__event.button == 2)), za = ((wa && this._getActionButtonFromStory(wa)));\n            if (((!ya && za))) {\n                this._setClickedStory(wa);\n            }\n        ;\n        ;\n        },\n        _handleMouseup: function(JSBNG__event) {\n            this._clearClickedStory();\n        },\n        _setClickedStory: function(ua) {\n            this._clearClickedStory();\n            n.addClass(ua, \"tickerStoryClicked\");\n            this._clickedStory = ua;\n        },\n        _clearClickedStory: function() {\n            if (this._clickedStory) {\n                n.removeClass(this._clickedStory, \"tickerStoryClicked\");\n                this._clickedStory = null;\n            }\n        ;\n        ;\n        },\n        _initInfiniteScrollListener: function() {\n            var ua = this._getInsertedStories();\n            if (this._storiesWithActions) {\n                for (var va = 0; ((va < ua.length)); va++) {\n                    var wa = ua[va];\n                    if (n.hasClass(wa, \"tickerStoryWithButton\")) {\n                        this._storiesWithActions[wa.getAttribute(\"data-story-key\")] = wa;\n                    }\n                ;\n                ;\n                };\n            }\n        ;\n        ;\n            var xa = Math.max(0, ((ua.length - this._autoloadStoryIndex)));\n            this._infiniteScrollStory = ua[xa];\n            this._checkInfiniteScroll();\n        },\n        _checkInfiniteScroll: function() {\n            if (this._infiniteScrollStory) {\n                var ua = ga.getElementPosition(this._infiniteScrollStory).y, va = ((ga.getElementPosition(this._container).y + ga.getElementDimensions(this._container).y));\n                if (((ua < va))) {\n                    var wa = o.scry(this._root, \".tickerMorePager a\")[0];\n                    if (wa) {\n                        var xa = ((v.byClass(wa, \"stat_elem\") || wa)), ya = new i(wa.getAttribute(\"ajaxify\")).setReadOnly(true).setRelativeTo(wa).setStatusElement(xa).setAllowCrossPageTransition(true).send();\n                        this._logUserEvent(\"stream\", \"JSBNG__scroll\");\n                    }\n                ;\n                ;\n                    this._infiniteScrollStory = null;\n                    this._autoloadStoryIndex = 5;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        _setFixed: function(ua) {\n            if (!this._selectedStory) {\n                return;\n            }\n        ;\n        ;\n            var va = this._getStoryDialog(this._selectedStory);\n            if (va) {\n                va.setFixed(ua);\n                va.updatePosition();\n            }\n        ;\n        ;\n        },\n        _setTimeout: function(ua, va) {\n            return JSBNG__setTimeout(ua, va, !this._tickerInSidebarMode);\n        },\n        _scrollDialogToBottom: function() {\n            var ua = ((this._dialog && this._dialog.getContent())), va = ((ua && o.scry(ua, \".uiScrollableAreaWrap\")[0])), wa = ((va && x.getInstance(va)));\n            ((wa && wa.scrollToBottom()));\n        },\n        _openDialog: function(ua) {\n            this._dialog = ua.show();\n            this._updateDialogPosition();\n            this._writeSwfFrame(ua);\n            this._initCommentFocusListener.bind(this).defer();\n            this._initContentResizeListener.bind(this).defer();\n            this._stupidIE7VideoResizeHack(ua);\n        },\n        _stupidIE7VideoResizeHack: function(ua) {\n            if (((fa.ie() === 7))) {\n                var va = o.scry(ua.getContent(), \".uiVideoThumb .img\");\n                va.forEach(function(wa) {\n                    z.set(wa, \"width\", \"\");\n                });\n            }\n        ;\n        ;\n        },\n        _updateDialogPosition: function() {\n            var ua = ((this._tickerInSidebarMode || !!v.byClass(this._root, \"fixed_elem\")));\n            this._dialog.setFixed(ua);\n            this._adjustFlyoutContentHeight();\n            this._dialog.updatePosition();\n        },\n        _writeSwfFrame: function(ua) {\n            var va = ((this._dialog && this._dialog.getContent())), wa = o.scry(va, \".swfObject\")[0];\n            if (!wa) {\n                return;\n            }\n        ;\n        ;\n            var xa = wa.getAttribute(\"data-swfid\");\n            if (((xa && window[xa]))) {\n                var ya = window[xa];\n                ya.write(wa);\n            }\n        ;\n        ;\n        },\n        _initCommentFocusListener: function() {\n            var ua = ((this._dialog && this._dialog.getContent())), va = ((ua && o.scry(ua, \".tickerDialogFooter textarea\")[0]));\n            if (!va) {\n                return;\n            }\n        ;\n        ;\n            this._listeners.inputFocus = JSBNG__Event.listen(va, \"JSBNG__focus\", this._scrollDialogToBottom.bind(this));\n        },\n        _cleanupInputFocusListener: function() {\n            if (this._listeners.inputFocus) {\n                this._listeners.inputFocus.remove();\n                this._listeners.inputFocus = null;\n            }\n        ;\n        ;\n        },\n        _initContentResizeListener: function() {\n            var ua = ((this._dialog && this._dialog.getContent()));\n            if (!ua) {\n                return;\n            }\n        ;\n        ;\n            this._listeners.contentResize = JSBNG__Event.listen(ua, \"click\", function() {\n                this._dialog.updatePosition.bind(this._dialog).defer();\n            }.bind(this));\n        },\n        _cleanupContentResizeListener: function() {\n            if (this._listeners.contentResize) {\n                this._listeners.contentResize.remove();\n                this._listeners.contentResize = null;\n            }\n        ;\n        ;\n        },\n        _adjustFlyoutContentHeight: function() {\n            var ua = ((this._dialog && this._dialog.getContent())), va = ((ua && o.scry(ua, \".uiScrollableAreaWrap\")[0]));\n            if (!va) {\n                return;\n            }\n        ;\n        ;\n            var wa = ga.getElementDimensions(va), xa = ga.getElementPosition(va), ya = o.scry(va, \".uiUfi .uiUfiComment\"), za = ((ga.getViewportDimensions().y - this.FLYOUT_VIEWPORT_PADDING)), ab = Math.min(this.FLYOUT_MAX_HEIGHT, za), bb = ((ab - this.FLYOUT_TARGET_HEIGHT_OFFSET));\n            for (var cb = 0; ((cb < ya.length)); cb++) {\n                var db = ya[cb], eb = ga.getElementPosition(db), fb = ((eb.y - xa.y));\n                if (((Math.abs(((fb - bb))) <= this.FLYOUT_OFFSET_THRESHOLD))) {\n                    bb = ((fb + this.FLYOUT_COMMENT_OFFSET));\n                    break;\n                }\n            ;\n            ;\n            };\n        ;\n            if (((wa.y > bb))) {\n                z.set(va, \"height\", ((bb + \"px\")));\n                z.set(va, \"max-height\", null);\n            }\n             else {\n                z.set(va, \"max-height\", ((ab + \"px\")));\n                z.set(va, \"height\", null);\n            }\n        ;\n        ;\n        },\n        _initObjectIDs: function() {\n            var ua = this._getAllStories();\n            for (var va = 0; ((va < ua.length)); ++va) {\n                var wa = ua[va].getAttribute(\"data-story-key\");\n                ((wa && (this._objectIDs[wa] = true)));\n            };\n        ;\n        },\n        _handleChatOpened: function() {\n            this._deactivateStory(true);\n        },\n        _handleChannelConnection: function() {\n            this._checkChannelConnection();\n        },\n        getNewest: function() {\n            return this._newest;\n        }\n    });\n    e.exports = ta;\n});\n__d(\"legacy:TickerController\", [\"TickerController\",], function(a, b, c, d) {\n    a.TickerController = b(\"TickerController\");\n}, 3);\n__d(\"legacy:UIIntentionalStream-message\", [\"UIIntentionalStreamMessage\",], function(a, b, c, d) {\n    a.UIIntentionalStreamMessage = b(\"UIIntentionalStreamMessage\");\n}, 3);\nfunction HomeAdFirstRightColumnController() {\n\n};\n;\ncopyProperties(HomeAdFirstRightColumnController.prototype, {\n    init: function(a) {\n        copyProperties(this, {\n            _enableSidebar: a.enableSidebar,\n            _tickerHeightOffset: 200,\n            contentCol: $(\"contentCol\"),\n            blueBar: $(\"blueBar\"),\n            _tickerMaxHeight: ((a.tickerMaxHeight || 500)),\n            _listeners: [],\n            _subscriptions: []\n        });\n        this._topOffset = 0;\n        this.PADDING_TICKER_TO_TOP = 5;\n        this.PADDING_RHC_TO_BOTTOM = 60;\n        this._sidebarIsHidden = true;\n        this._listeners.push(JSBNG__Event.listen(window, \"resize\", this.handleResize.bind(this)));\n        this._blueBarHeight = Vector2.getElementDimensions(this.blueBar).y;\n        this.reloadRightCol();\n        this._initSubscriptions();\n        JSBNG__onunloadRegister(this.cleanup.bind(this));\n        this._listeners.push(JSBNG__Event.listen(window, \"JSBNG__scroll\", this._handleScroll.bind(this)));\n        if (!CSS.hasClass(JSBNG__document.documentElement, \"sidebarMode\")) {\n            this._onSidebarHide();\n        }\n         else if (this._enableSidebar) {\n            this._onSidebarShow();\n        }\n        \n    ;\n    ;\n        this.handleResize();\n    },\n    _initSubscriptions: function() {\n        this._subscriptions = [Arbiter.subscribe(\"Ticker/storiesInserted\", this.handleResize.bind(this)),Arbiter.subscribe(\"concierge/load\", this.handleResize.bind(this)),Arbiter.subscribe(UIIntentionalStreamMessage.INSERT_STORIES, this.handleResize.bind(this)),];\n        if (this._enableSidebar) {\n            this._subscriptions.push(Arbiter.subscribe(\"sidebar/hide\", this._onSidebarHide.bind(this)));\n            this._subscriptions.push(Arbiter.subscribe(\"sidebar/show\", this._onSidebarShow.bind(this)));\n        }\n    ;\n    ;\n    },\n    _onNavHandler: function(a, b) {\n        var c = b.params.key;\n        if (((((c != \"lf\")) && ((c != \"h\"))))) {\n            this.cleanup();\n        }\n    ;\n    ;\n    },\n    reloadRightCol: function() {\n        this.fixedScrollingContainer = ge(\"fixed_scrolling_container\");\n        this.fixedScrollingWrapper = DOM.scry(this.fixedScrollingContainer, \".fixed_scrolling_wrapper\")[0];\n        this.tickerPagelet = ge(\"pagelet_rhc_ticker\");\n        if (!this.tickerPagelet) {\n            return false;\n        }\n    ;\n    ;\n        this.tickerContainer = DOM.scry(this.tickerPagelet, \".ticker_container\")[0];\n        this.tickerStream = DOM.scry(this.tickerPagelet, \".ticker_stream\")[0];\n        return ((this.tickerContainer && this.tickerStream));\n    },\n    cleanup: function() {\n        this._subscriptions.forEach(Arbiter.unsubscribe);\n        this._subscriptions = [];\n        this._listeners.forEach(function(a) {\n            a.remove();\n        });\n        this._listeners = [];\n    },\n    _handleScroll: function() {\n        if (((((!this._sidebarIsHidden || !this.tickerStream)) || !this.fixedScrollingContainer))) {\n            return;\n        }\n    ;\n    ;\n        this._topOffset = ((this.PADDING_TICKER_TO_TOP + this._blueBarHeight));\n        var a = CSS.hasClass(JSBNG__document.documentElement, \"tinyViewport\"), b = !a;\n        if (b) {\n            var c = Vector2.getElementPosition(this.fixedScrollingContainer, \"viewport\");\n            if (((!c || ((c.y >= this._topOffset))))) {\n                b = false;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        if (((b !== CSS.hasClass(this.fixedScrollingWrapper, \"fixed_elem\")))) {\n            this._setFixedRightCol(b);\n        }\n    ;\n    ;\n    },\n    _setFixedRightCol: function(a) {\n        var b = ((a ? ((this._topOffset + \"px\")) : \"\"));\n        Style.set(this.fixedScrollingWrapper, \"JSBNG__top\", b);\n        CSS.conditionClass(this.fixedScrollingWrapper, \"fixed_elem\", a);\n        var c = ((a ? \"Ticker/fixed\" : \"Ticker/unfixed\"));\n        Arbiter.inform(c);\n    },\n    handleResize: function() {\n        if (((((!this._sidebarIsHidden || !this.tickerStream)) || CSS.hasClass(JSBNG__document.documentElement, \"tinyViewport\")))) {\n            return;\n        }\n    ;\n    ;\n        this._handleScroll();\n        var a = Vector2.getViewportDimensions().y, b = ((Vector2.getElementDimensions(this.fixedScrollingWrapper).y - Vector2.getElementDimensions(this.tickerContainer).y)), c = ((((((a - this._topOffset)) - b)) - this.PADDING_RHC_TO_BOTTOM)), d = Vector2.getElementDimensions(this.tickerStream).y, e = Math.min(c, d, this._tickerMaxHeight);\n        Style.set(this.tickerContainer, \"height\", ((e + \"px\")));\n    },\n    _onSidebarHide: function() {\n        this._sidebarIsHidden = true;\n        this.reloadRightCol();\n        var a = function() {\n            if (this.reloadRightCol()) {\n                this.handleResize();\n            }\n        ;\n        ;\n        };\n        ((this.tickerPagelet && TickerController.show(this.tickerPagelet, a.bind(this))));\n    },\n    _onSidebarShow: function() {\n        this._sidebarIsHidden = false;\n        this.reloadRightCol();\n        this._setFixedRightCol(false);\n        ((this.tickerPagelet && TickerController.hide(this.tickerPagelet)));\n    }\n});\n__d(\"HomeTickerFirstRightColumnController\", [\"$\",\"ge\",\"debounceAcrossTransitions\",\"throttle\",\"UIPagelet\",\"Arbiter\",\"Style\",\"csx\",\"CSS\",\"DOM\",\"Vector\",\"Run\",\"TickerController\",\"UIIntentionalStreamMessage\",\"event-extensions\",], function(a, b, c, d, e, f) {\n    var g = b(\"$\"), h = b(\"ge\"), i = b(\"debounceAcrossTransitions\"), j = b(\"throttle\"), k = b(\"UIPagelet\"), l = b(\"Arbiter\"), m = b(\"Style\"), n = b(\"csx\"), o = b(\"CSS\"), p = b(\"DOM\"), q = b(\"Vector\"), r = b(\"Run\"), s = b(\"TickerController\"), t = b(\"UIIntentionalStreamMessage\");\n    b(\"event-extensions\");\n    var u = null, v = 75, w = 50, x = 15, y = false, z = false, aa, ba, ca, da, ea, fa, ga, ha, ia, ja = [], ka = [], la, ma, na, oa, pa, qa, ra, sa, ta, ua, va;\n    function wa() {\n        var mb = ib;\n        function nb() {\n            mb.defer();\n        };\n    ;\n        var ob = p.scry(oa, \"img.img\");\n        ob.forEach(function(pb) {\n            if (!pb.complete) {\n                JSBNG__Event.listen(pb, {\n                    load: nb,\n                    error: nb,\n                    abort: nb\n                });\n            }\n        ;\n        ;\n        });\n        nb();\n    };\n;\n    function xa() {\n        ka = [l.subscribe(\"page_transition\", ab),l.subscribe(\"netego_loaded\", ib),l.subscribe(\"Ticker/storiesInserted\", ib),l.subscribe(\"concierge/load\", ib),l.subscribe(t.INSERT_STORIES, ib),];\n        if (u.enableSidebar) {\n            ka.push(l.subscribe(\"sidebar/hide\", jb));\n            ka.push(l.subscribe(\"sidebar/show\", kb));\n        }\n    ;\n    ;\n    };\n;\n    function ya() {\n        if (oa) {\n            var mb = p.scry(oa, \"div.-cx-PRIVATE-fbAdUnit__root\");\n            for (var nb = 0; ((nb < mb.length)); nb++) {\n                var ob = JSON.parse(mb[nb].getAttribute(\"data-ad\")).segment;\n                if (((ob === \"premium\"))) {\n                    return true;\n                }\n            ;\n            ;\n            };\n        ;\n        }\n    ;\n    ;\n        return false;\n    };\n;\n    function za() {\n        sa = p.scry(h(\"rightCol\"), \"div.home_right_column\")[0];\n        ta = p.JSBNG__find(sa, \"div.rightColumnWrapper\");\n        oa = ((h(\"pagelet_ego_pane_w\") || h(\"pagelet_ego_pane_m\")));\n        da = ((u.refreshPremiumAds || !ya()));\n        JSBNG__Event.listen(oa, \"mouseenter\", function() {\n            y = true;\n        });\n        JSBNG__Event.listen(oa, \"mouseleave\", function() {\n            y = false;\n        });\n        pa = h(\"pagelet_rhc_ticker\");\n        if (!pa) {\n            return false;\n        }\n    ;\n    ;\n        qa = p.scry(pa, \".ticker_container\")[0];\n        ra = p.scry(pa, \".ticker_stream\")[0];\n        return ((qa && ra));\n    };\n;\n    function ab(mb, nb) {\n        if (((((((mb === \"page_transition\")) && nb)) && nb.uri))) {\n            var ob = nb.uri;\n            if (((ob.path === \"/photo.php\"))) {\n                z = true;\n                return;\n            }\n        ;\n        ;\n            if (((z && ((ob.path === \"/\"))))) {\n                z = false;\n                return;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        ka.forEach(l.unsubscribe);\n        ka = [];\n        ja.forEach(function(pb) {\n            pb.remove();\n        });\n        ja = [];\n        la.reset();\n    };\n;\n    function bb() {\n        if (((ha || !aa))) {\n            ia = ((q.getElementPosition(oa, \"viewport\").y - q.getElementPosition(ta, \"viewport\").y));\n        }\n    ;\n    ;\n    };\n;\n    function cb() {\n        bb();\n        va = ((ua + q.getElementPosition(na, \"viewport\").y));\n        var mb = va, nb = q.getElementPosition(sa, \"viewport\").y;\n        if (((ba || !ra))) {\n            if (((u.fixAdsOnScroll && ((ga !== null))))) {\n                var ob = ((nb + ia)), pb = ((ob <= ((mb - ga))));\n                if (((ha || ((pb !== aa))))) {\n                    ha = false;\n                    var qb = ((((mb - ga)) - ia));\n                    hb(pb, qb);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            return;\n        }\n    ;\n    ;\n        var rb = ((nb <= ((mb + x))));\n        if (((rb !== aa))) {\n            hb(rb);\n        }\n    ;\n    ;\n    };\n;\n    function db() {\n        var mb = JSBNG__Date.now();\n        if (((((((da && !y)) && u.adsRefreshInterval)) && ((((mb - ea)) >= u.adsRefreshInterval))))) {\n            eb();\n        }\n    ;\n    ;\n    };\n;\n    function eb() {\n        ea = JSBNG__Date.now();\n        k.loadFromEndpoint(\"WebEgoPane\", oa, {\n            pid: 27,\n            data: {\n                organic_only: false,\n                ads_only: false,\n                refresh_num: ++fa\n            }\n        }, {\n            bundle: false,\n            crossPage: false,\n            handler: wa\n        });\n    };\n;\n    function fb() {\n        ha = true;\n        bb();\n        gb();\n        cb();\n    };\n;\n    function gb() {\n        if (!u.fixAdsOnScroll) {\n            return;\n        }\n    ;\n    ;\n        var mb = ((((q.getViewportDimensions().y - ua)) - w)), nb = q.getElementDimensions(ta).y;\n        if (((nb <= mb))) {\n            ga = ((((0 - ia)) - x));\n            return;\n        }\n    ;\n    ;\n        var ob = ((nb - ia)), pb = p.scry(oa, \"div.egoOrganicColumn\")[0];\n        if (((((ob <= mb)) && pb))) {\n            ga = 0;\n        }\n         else {\n            var qb = p.scry(oa, \"div.ego_unit\").reverse(), rb = p.scry(oa, \"div.-cx-PRIVATE-fbAdUnit__root\").length, sb = u.maxFixedAds;\n            if (((rb <= u.maxFixedAds))) {\n                sb = qb.length;\n            }\n        ;\n        ;\n            var tb = null;\n            for (var ub = 0; ((ub < sb)); ub++) {\n                var vb = qb[ub], wb = ((q.getElementPosition(vb, \"viewport\").y - q.getElementPosition(ta, \"viewport\").y)), xb = ((q.getElementDimensions(ta).y - wb));\n                if (((xb > mb))) {\n                    if (((ub > 0))) {\n                        tb = qb[((ub - 1))];\n                    }\n                ;\n                ;\n                    break;\n                }\n            ;\n            ;\n                if (((ub == ((sb - 1))))) {\n                    tb = vb;\n                }\n            ;\n            ;\n            };\n        ;\n            if (((tb == null))) {\n                ga = null;\n            }\n             else ga = ((q.getElementPosition(tb, \"viewport\").y - q.getElementPosition(oa, \"viewport\").y));\n        ;\n        ;\n        }\n    ;\n    ;\n    };\n;\n    function hb(mb, nb) {\n        aa = mb;\n        nb = ((nb || va));\n        var ob = ((mb ? ((nb + \"px\")) : \"\"));\n        m.set(ta, \"JSBNG__top\", ob);\n        o.conditionClass(ta, \"fixed_elem\", mb);\n        var pb = p.scry(ta, \"div.displayedTickerToggleWrapper\")[0];\n        ((pb && o.conditionClass(pb, \"toggleWrapperWithoutMargin\", ((((u.fixAdsOnScroll && mb)) && !ra)))));\n        if (ca) {\n            var qb = ((mb ? \"Ticker/fixed\" : \"Ticker/unfixed\"));\n            l.inform(qb);\n        }\n    ;\n    ;\n    };\n;\n    function ib() {\n        if (((((!ca || !ra)) || o.hasClass(JSBNG__document.documentElement, \"tinyViewport\")))) {\n            fb();\n            return;\n        }\n    ;\n    ;\n        cb();\n        var mb = q.getViewportDimensions().y, nb = 61, ob = ((q.getElementDimensions(ta).y - q.getElementDimensions(qa).y)), pb = q.getElementDimensions(ra).y, qb = ((((((((mb - ob)) - v)) - va)) - nb)), rb = ((u.tickerAbsMinHeight || 120)), sb = ((u.tickerMinHeight || 225));\n        ba = false;\n        if (((qb < rb))) {\n            ba = true;\n            hb(false);\n            qb = rb;\n        }\n         else if (((qb < sb))) {\n            if (((qb > ((sb - nb))))) {\n                qb = sb;\n            }\n             else qb += nb;\n        ;\n        }\n        \n    ;\n    ;\n        var tb = Math.min(qb, pb, ((u.tickerMaxHeight || 425)));\n        m.set(qa, \"height\", ((tb + \"px\")));\n    };\n;\n    function jb() {\n        ca = true;\n        za();\n        var mb = function() {\n            if (za()) {\n                ba = false;\n                cb();\n                ib();\n            }\n        ;\n        ;\n        };\n        ((pa && s.show(pa, mb)));\n    };\n;\n    function kb() {\n        ca = false;\n        za();\n        if (u.fixAdsOnScroll) {\n            fb();\n        }\n         else {\n            ba = true;\n            hb(false);\n        }\n    ;\n    ;\n        ((pa && s.hide(pa)));\n    };\n;\n    var lb = {\n        init: function(mb) {\n            u = mb;\n            ma = g(\"contentCol\");\n            na = g(\"blueBar\");\n            fa = 0;\n            ea = Infinity;\n            ea = JSBNG__Date.now();\n            la = i(db, u.adsRefreshDelay);\n            if (u.adsRefreshOnmove) {\n                ja.push(JSBNG__Event.listen(window, \"mousemove\", la));\n            }\n        ;\n        ;\n            ja.push(JSBNG__Event.listen(window, \"JSBNG__scroll\", la));\n            ja.push(JSBNG__Event.listen(window, \"resize\", la));\n            ja.push(JSBNG__Event.listen(window, \"resize\", j(ib)));\n            ua = q.getElementDimensions(na).y;\n            za();\n            xa();\n            r.JSBNG__onLeave(ab);\n            ja.push(JSBNG__Event.listen(window, \"JSBNG__scroll\", j(cb)));\n            if (!o.hasClass(JSBNG__document.documentElement, \"sidebarMode\")) {\n                jb();\n            }\n             else if (u.enableSidebar) {\n                kb();\n            }\n            \n        ;\n        ;\n            wa();\n        }\n    };\n    e.exports = lb;\n});\n__d(\"legacy:ARIA\", [\"ARIA\",], function(a, b, c, d) {\n    a.ARIA = b(\"ARIA\");\n}, 3);\n__d(\"legacy:CounterDisplay\", [\"CounterDisplay\",], function(a, b, c, d) {\n    a.CounterDisplay = b(\"CounterDisplay\");\n}, 3);\nfunction startMessagingNavCountUpdater(a) {\n    var b = FutureSideNav.getInstance().getNodeForKey(\"inbox\");\n    if (!b) {\n        return;\n    }\n;\n;\n    var c = FutureSideNav.getInstance().getNodeForKey(\"other\"), d = DOM.scry(c, \"span.count\")[0], e = DOM.scry(d, \"span.countValue\")[0], f = DOM.scry(d, \"span.maxCountIndicator\")[0];\n    new CounterMaxDisplay(\"other_unseen\", e, d, null, null, true).setMaxCounter(a, f);\n};\n;\nfunction CounterMaxDisplay() {\n    this._maxValue = null;\n    this._maxIndicatorNode = null;\n    var a = [this,].concat($A(arguments));\n    return this.parent.construct.apply(this.parent, a);\n};\n;\nClass.extend(CounterMaxDisplay, \"CounterDisplay\");\ncopyProperties(CounterMaxDisplay.prototype, {\n    setMaxCounter: function(a, b) {\n        this._maxValue = a;\n        this._maxIndicatorNode = b;\n    },\n    paint: function() {\n        var a = ((this._maxValue && ((this._count > this._maxValue)))), b = ((a ? this._maxValue : this._count));\n        if (this._maxIndicatorNode) {\n            DOM.setContent(this._maxIndicatorNode, ((a ? \"+\" : \"\")));\n        }\n         else if (a) {\n            b = ((b + \"+\"));\n        }\n        \n    ;\n    ;\n        DOM.setContent(this._valueNode, b);\n        this._toggleNodes();\n    }\n});\n__d(\"ComposerAudienceSelector\", [\"DynamicIconSelector\",\"CustomPrivacyOption\",\"PrivacyConst\",\"Selector\",], function(a, b, c, d, e, f) {\n    b(\"DynamicIconSelector\");\n    var g = b(\"CustomPrivacyOption\"), h = b(\"PrivacyConst\"), i = b(\"Selector\"), j = {\n    }, k = {\n    }, l = {\n        syncSelector: function(m) {\n            ((j[m] && i.setSelected(m, j[m])));\n            if (((((j[m] == h.BaseValue.CUSTOM)) && k[m]))) {\n                var n = i.getOption(m, ((h.BaseValue.CUSTOM + \"\"))), o = k[m];\n                (function() {\n                    g.update(n.id, o.data, o.audience, o.tooltip);\n                }).defer();\n            }\n        ;\n        ;\n        }\n    };\n    e.exports = l;\n});\n__d(\"ContextualLayerAsyncRelative\", [\"event-extensions\",\"copyProperties\",\"Parent\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"copyProperties\"), h = b(\"Parent\");\n    function i(j) {\n        this._layer = j;\n    };\n;\n    g(i.prototype, {\n        _layerSubscription: null,\n        _listener: null,\n        enable: function() {\n            this._layerSubscription = this._layer.subscribe(\"show\", this._attachListener.bind(this));\n            if (this._layer.isShown()) {\n                this._attachListener();\n            }\n        ;\n        ;\n        },\n        disable: function() {\n            this._layerSubscription.unsubscribe();\n            this._layerSubscription = null;\n            if (this._listener) {\n                this._listener.remove();\n                this._listener = null;\n            }\n        ;\n        ;\n        },\n        _attachListener: function() {\n            this._listener = JSBNG__Event.listen(this._layer.getRoot(), \"click\", this._onclick.bind(this));\n        },\n        _onclick: function(j) {\n            var k = h.byTag(j.getTarget(), \"A\");\n            if (!k) {\n                return;\n            }\n        ;\n        ;\n            var l = k.getAttribute(\"ajaxify\"), m = k.href, n = ((l || m));\n            if (((((k.rel === \"async\")) || ((k.rel === \"async-post\"))))) {\n                d([\"AsyncRequest\",], function(o) {\n                    o.bootstrap(n, this._layer.getContext(), ((k.rel === \"async-post\")));\n                }.bind(this));\n                return false;\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = i;\n});\n__d(\"MenuX\", [\"event-extensions\",\"Class\",\"copyProperties\",\"CSS\",\"DataStore\",\"DOM\",\"HTML\",\"Keys\",\"Parent\",\"PopoverMenuInterface\",\"ScrollableArea\",\"Style\",\"UserAgent\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Class\"), h = b(\"copyProperties\"), i = b(\"CSS\"), j = b(\"DataStore\"), k = b(\"DOM\"), l = b(\"HTML\"), m = b(\"Keys\"), n = b(\"Parent\"), o = b(\"PopoverMenuInterface\"), p = b(\"ScrollableArea\"), q = b(\"Style\"), r = b(\"UserAgent\");\n    function s(t, u, v, w) {\n        this.parent.construct(this);\n        this._id = t;\n        this._className = u;\n        this._items = [];\n        for (var x = 0; ((x < v.length)); x++) {\n            this._items[x] = new v[x].ctor(v[x]);\n        ;\n        };\n    ;\n        this._config = w;\n    };\n;\n    g.extend(s, o);\n    h(s.prototype, {\n        _focused: null,\n        _root: null,\n        addItem: function(t) {\n            this._items.push(t);\n            if (this._root) {\n                this._insertItem(t);\n            }\n        ;\n        ;\n        },\n        getRoot: function() {\n            if (!this._root) {\n                this._render();\n            }\n        ;\n        ;\n            return this._root;\n        },\n        JSBNG__onShow: function() {\n            if (this._config.maxheight) {\n                if (!this._scrollableArea) {\n                    q.set(this._scrollableElems.root, \"width\", ((this._scrollableElems.body.offsetWidth + \"px\")));\n                    this._scrollableArea = p.fromNative(this._scrollableElems.root, {\n                        fade: true\n                    });\n                    q.set(this._scrollableElems.wrap, \"max-height\", ((this._config.maxheight + \"px\")));\n                }\n                 else {\n                    q.set(this._scrollableElems.root, \"width\", \"\");\n                    q.set(this._scrollableElems.JSBNG__content, \"width\", \"\");\n                    if (((r.ie() <= 7))) {\n                        q.set(this._scrollableElems.root, \"width\", ((this._scrollableElems.JSBNG__content.offsetWidth + \"px\")));\n                    }\n                     else q.set(this._scrollableElems.root, \"width\", ((this._scrollableElems.JSBNG__content.offsetWidth + \"px\")));\n                ;\n                ;\n                    this._scrollableArea.resize();\n                }\n            ;\n            }\n        ;\n        ;\n        },\n        JSBNG__onHide: function() {\n            this.JSBNG__blur();\n        },\n        focusAnItem: function() {\n            return this._attemptFocus(0, 1);\n        },\n        JSBNG__blur: function() {\n            if (this._focused) {\n                this._focused.JSBNG__blur();\n                this._focused = null;\n                this.inform(\"JSBNG__blur\");\n            }\n        ;\n        ;\n        },\n        handleKeydown: function(t) {\n            var u = this._items.indexOf(this._focused);\n            switch (t) {\n              case m.UP:\n            \n              case m.DOWN:\n                var v = ((((t === m.UP)) ? -1 : 1));\n                if (((u !== -1))) {\n                    return this._attemptFocus(((u + v)), v);\n                }\n                 else if (((t === m.UP))) {\n                    return this._attemptFocus(((this._items.length - 1)), -1);\n                }\n                 else return this._attemptFocus(0, 1)\n                \n            ;\n                break;\n              case m.SPACE:\n                if (((this._items.indexOf(this._focused) !== -1))) {\n                    this._handleItemClick(this._focused);\n                    return true;\n                }\n            ;\n            ;\n                return false;\n              default:\n                var w = String.fromCharCode(t).toLowerCase(), x;\n                for (var y = ((u + 1)); ((y < this._items.length)); y++) {\n                    x = this._items[y].getAccessKey();\n                    if (((x && ((x.charAt(0).toLowerCase() === w))))) {\n                        if (this._focusItem(this._items[y])) {\n                            return true;\n                        }\n                    ;\n                    }\n                ;\n                ;\n                };\n            ;\n                return false;\n            };\n        ;\n        },\n        _render: function() {\n            this._ul = k.create(\"ul\", {\n                className: \"uiMenuX\"\n            });\n            this._ul.setAttribute(\"role\", \"menu\");\n            this._items.forEach(this._insertItem.bind(this));\n            JSBNG__Event.listen(this._ul, \"click\", this._handleClick.bind(this));\n            JSBNG__Event.listen(this._ul, \"mouseover\", this._handleMouseOver.bind(this));\n            JSBNG__Event.listen(this._ul, \"mouseout\", this._handleMouseOut.bind(this));\n            var t = this._ul;\n            if (this._config.maxheight) {\n                this._scrollableElems = p.renderDOM();\n                k.setContent(this._scrollableElems.JSBNG__content, this._ul);\n                t = this._scrollableElems.root;\n            }\n        ;\n        ;\n            var u = ((\"uiMenuXWrapper\" + ((this._className ? ((\" \" + this._className)) : \"\"))));\n            this._root = k.create(\"div\", {\n                className: u\n            }, k.create(\"div\", {\n                className: \"uiMenuXBorder\"\n            }, t));\n            ((this._id && this._root.setAttribute(\"id\", this._id)));\n        },\n        _handleClick: function(t) {\n            var u = this._getItemInstance(t.getTarget());\n            if (u) {\n                return this._handleItemClick(u);\n            }\n        ;\n        ;\n        },\n        _handleItemClick: function(t) {\n            this.inform(\"itemclick\", t);\n            if (t.hasAction()) {\n                this.done();\n            }\n        ;\n        ;\n            return t.handleClick();\n        },\n        _handleMouseOver: function(t) {\n            var u = this._getItemInstance(t.getTarget());\n            ((u && this._focusItem(u)));\n        },\n        _handleMouseOut: function(t) {\n            var u = this._getItemInstance(t.getTarget());\n            if (((u && ((this._focused === u))))) {\n                this.JSBNG__blur();\n            }\n        ;\n        ;\n        },\n        _insertItem: function(t) {\n            var u = t.getRoot();\n            i.addClass(u, \"__MenuXItem\");\n            j.set(u, \"MenuXItem\", t);\n            k.appendContent(this._ul, u);\n        },\n        _attemptFocus: function(t, u) {\n            var v = this._items[t];\n            if (v) {\n                if (this._focusItem(v)) {\n                    return true;\n                }\n                 else return this._attemptFocus(((t + u)), u)\n            ;\n            }\n        ;\n        ;\n            return false;\n        },\n        _focusItem: function(t) {\n            if (((t.JSBNG__focus() !== false))) {\n                if (((this._focused !== t))) {\n                    this.JSBNG__blur();\n                    this._focused = t;\n                    this.inform(\"JSBNG__focus\");\n                }\n            ;\n            ;\n                return true;\n            }\n        ;\n        ;\n            return false;\n        },\n        _getItemInstance: function(t) {\n            var u = n.byClass(t, \"__MenuXItem\");\n            return ((u ? j.get(u, \"MenuXItem\") : null));\n        }\n    });\n    e.exports = s;\n});\n__d(\"MenuXItemInterface\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\");\n    function h() {\n    \n    };\n;\n    g(h.prototype, {\n        _root: null,\n        getRoot: function() {\n            if (!this._root) {\n                this._root = this.render();\n            }\n        ;\n        ;\n            return this._root;\n        },\n        render: bagofholding,\n        getAccessKey: bagofholding,\n        hasAction: bagof(false),\n        JSBNG__focus: bagof(false),\n        JSBNG__blur: bagof(false),\n        handleClick: bagof(false)\n    });\n    e.exports = h;\n});\n__d(\"MenuXItemBase\", [\"Class\",\"copyProperties\",\"CSS\",\"DOM\",\"HTML\",\"MenuXItemInterface\",], function(a, b, c, d, e, f) {\n    var g = b(\"Class\"), h = b(\"copyProperties\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"HTML\"), l = b(\"MenuXItemInterface\");\n    function m(n) {\n        this.parent.construct(this);\n        this._data = n;\n    };\n;\n    g.extend(m, l);\n    h(m.prototype, {\n        render: function() {\n            var n = \"uiMenuXItem\";\n            if (this._data.className) {\n                n += ((\" \" + this._data.className));\n            }\n        ;\n        ;\n            var o = {\n                className: n,\n                \"aria-selected\": \"false\"\n            };\n            for (var p in this._data) {\n                if (((p.indexOf(\"data-\") === 0))) {\n                    o[p] = this._data[p];\n                }\n            ;\n            ;\n            };\n        ;\n            return j.create(\"li\", o, this._renderItemContent());\n        },\n        _renderItemContent: function() {\n            return k(this._data.markup).getNodes();\n        }\n    });\n    e.exports = m;\n});\n__d(\"MenuXSelectableItem\", [\"Class\",\"copyProperties\",\"CSS\",\"MenuXItem\",], function(a, b, c, d, e, f) {\n    var g = b(\"Class\"), h = b(\"copyProperties\"), i = b(\"CSS\"), j = b(\"MenuXItem\");\n    function k(l) {\n        this.parent.construct(this, l);\n    };\n;\n    g.extend(k, j);\n    h(k.prototype, {\n        _selected: false,\n        getLabel: function() {\n            return this._data.label;\n        },\n        getIcon: function() {\n            return this._data.icon;\n        },\n        isSelected: function() {\n            return this._selected;\n        },\n        select: function() {\n            i.addClass(this._root, \"checked\");\n            this._selected = true;\n        },\n        deselect: function() {\n            i.removeClass(this._root, \"checked\");\n            this._selected = false;\n        },\n        render: function() {\n            var l = this.parent.render();\n            if (this._data.selected) {\n                i.addClass(l, \"checked\");\n                this._selected = true;\n            }\n        ;\n        ;\n            return l;\n        }\n    });\n    e.exports = k;\n});\n__d(\"legacy:ComposerAudienceSelector\", [\"ComposerAudienceSelector\",], function(a, b, c, d) {\n    a.ComposerAudienceSelector = b(\"ComposerAudienceSelector\");\n}, 3);\nfunction FriendsPrivacyOption() {\n    this.parent.construct(this);\n};\n;\nClass.extend(FriendsPrivacyOption, \"OnlyMePrivacyOption\");\nFriendsPrivacyOption.prototype.init = function(a, b) {\n    this._hasRestricted = b;\n    this.parent.init(a);\n};\nFriendsPrivacyOption.prototype._getChangedData = function() {\n    return {\n        eventTag: this._eventTag,\n        tags: this._taggedIDs,\n        privacy: PrivacyFriendsValue.ALL_FRIENDS\n    };\n};\nFriendsPrivacyOption.prototype._recalculateTooltipAndLabel = function() {\n    var a = this._eventTag, b = this._tags.length, c = this._tooltip, d = this._label;\n    if (((b > 2))) {\n        if (a) {\n            this._tooltip = ((this._hasRestricted ? \"Your friends, friends of anyone tagged and anyone invited to this event; Except: Restricted\" : \"Your friends, friends of anyone tagged and anyone invited to this event\"));\n        }\n         else this._tooltip = ((this._hasRestricted ? \"Your friends and friends of anyone tagged; Except: Restricted\" : \"Your friends and friends of anyone tagged\"));\n    ;\n    ;\n    }\n     else if (((b == 2))) {\n        if (a) {\n            if (this._hasRestricted) {\n                this._tooltip = \"Your friends, friends of anyone tagged and anyone invited to this event; Except: Restricted\";\n            }\n             else this._tooltip = \"Your friends, friends of anyone tagged and anyone invited to this event\";\n        ;\n        ;\n        }\n         else if (this._hasRestricted) {\n            this._tooltip = tx._(\"Your friends, {user}'s friends and {user2}'s friends; Except: Restricted \", {\n                user: this._tags[0],\n                user2: this._tags[1]\n            });\n        }\n         else this._tooltip = tx._(\"Your friends, {user}'s friends and {user2}'s friends\", {\n            user: this._tags[0],\n            user2: this._tags[1]\n        });\n        \n    ;\n    ;\n    }\n     else if (((b == 1))) {\n        if (a) {\n            if (this._hasRestricted) {\n                this._tooltip = tx._(\"Your friends, {user}'s friends and anyone invited to this event; Except: Restricted\", {\n                    user: this._tags[0]\n                });\n            }\n             else this._tooltip = tx._(\"Your friends, {user}'s friends and anyone invited to this event\", {\n                user: this._tags[0]\n            });\n        ;\n        ;\n        }\n         else if (this._hasRestricted) {\n            this._tooltip = tx._(\"Your friends and {user}'s friends; Except: Restricted\", {\n                user: this._tags[0]\n            });\n        }\n         else this._tooltip = tx._(\"Your friends and {user}'s friends\", {\n            user: this._tags[0]\n        });\n        \n    ;\n    ;\n    }\n     else if (a) {\n        this._tooltip = ((this._hasRestricted ? \"Your friends and anyone invited to this event; Except: Restricted\" : \"Your friends and anyone invited to this event\"));\n    }\n     else this._tooltip = ((this._hasRestricted ? \"Your friends; Except: Restricted\" : \"Your friends\"));\n    \n    \n    \n;\n;\n    CSS.conditionShow(this._plusLabel, this._tags.length);\n    this._label = this._elem.getAttribute(\"data-label\");\n    if (((this._tags.length || this._eventTag))) {\n        this._label += \" (+)\";\n    }\n;\n;\n    return ((((c != this._tooltip)) || ((d != this._label))));\n};\nfunction MetaComposerEdDialog() {\n\n};\n;\ncopyProperties(MetaComposerEdDialog.prototype, {\n    init: function(a, b, c, d, e, f, g) {\n        MetaComposerEdDialog.timesTagEduShown = c;\n        MetaComposerEdDialog.timesEventTagEduShown = e;\n        MetaComposerEdDialog.timesStickyEduShown = g;\n        if (MetaComposerEdDialog.singleton) {\n            a.destroy();\n            return;\n        }\n    ;\n    ;\n        MetaComposerEdDialog.singleton = this;\n        this._dialog = a;\n        if (f) {\n            Arbiter.subscribe(\"composer/mutate\", function(h, i) {\n                this._sendEducationRequest({\n                    sticky_num: MetaComposerEdDialog.timesStickyEduShown\n                }, \"/ajax/composer/audience/sticky_education\");\n            }.bind(this));\n        }\n    ;\n    ;\n        if (d) {\n            if (((e === 0))) {\n                Arbiter.subscribe(\"EventTagged/changed\", function(h, i) {\n                    this._sendEducationRequest({\n                        id: \"composerTourAudience\",\n                        privacy: i.privacy,\n                        event_tag_num: MetaComposerEdDialog.timesEventTagEduShown\n                    }, \"ajax/events/tagging/user_education\", null);\n                }.bind(this));\n                Arbiter.subscribe([\"composer/publish\",\"composer/reset\",], function() {\n                    var h = $(\"event_tagging_tag_expansion_NUX\");\n                    ((h && CSS.hide(h)));\n                }.bind(this));\n            }\n             else Arbiter.subscribe(\"EventTagged/changed\", function(h, i) {\n                this._sendEducationRequest({\n                    ids: i.tags,\n                    from: \"AtTagger\",\n                    eventID: i.eventTag,\n                    type: i.privacy,\n                    tag_num: MetaComposerEdDialog.timesTagEduShown,\n                    event_tag_num: MetaComposerEdDialog.timesEventTagEduShown\n                }, \"ajax/composer/audience/tag_education\", this._handler.bind(this));\n            }.bind(this));\n        ;\n        }\n    ;\n    ;\n        if (b) {\n            Arbiter.subscribe(\"SelectedPrivacyOption/changed\", function(h, i) {\n                this._sendEducationRequest({\n                    ids: i.tags,\n                    from: \"WithTagger\",\n                    eventID: i.eventTag,\n                    type: i.privacy,\n                    tag_num: MetaComposerEdDialog.timesTagEduShown,\n                    event_tag_num: MetaComposerEdDialog.timesEventTagEduShown\n                }, \"/ajax/composer/audience/tag_education\", this._handler.bind(this));\n            }.bind(this));\n        }\n    ;\n    ;\n        Selector.subscribe(\"open\", this._killAnim.bind(this));\n    },\n    _sendEducationRequest: function(a, b, c) {\n        if (!this._updateDialogContext()) {\n            return;\n        }\n    ;\n    ;\n        ((this._async && this._async.abort()));\n        this._async = new AsyncRequest(b);\n        this._async.setData(a).setHandler(c).send();\n    },\n    _updateDialogContext: function() {\n        var a = DOM.scry(JSBNG__document.body, \"div.composerAudienceWrapper\")[0], b = Vector2.getElementPosition(a);\n        if (((((a && ((b.x > 0)))) && ((b.y > 0))))) {\n            this._dialog.setContext(a);\n            return true;\n        }\n    ;\n    ;\n        return false;\n    },\n    _handler: function(a) {\n        var b = a.payload;\n        if (((!b || !this._updateDialogContext()))) {\n            return;\n        }\n    ;\n    ;\n        var c = this._dialog.getContent();\n        DOM.setContent(c, b);\n        ARIA.announce(DOM.getText(c));\n        this._dialog.disableBehavior(LayerDestroyOnHide).show();\n        var d = Parent.byClass(c, \"metaComposerUserEd\");\n        if (this._anim) {\n            this._anim.JSBNG__stop();\n            this._anim = animation(d);\n        }\n         else this._anim = animation(d).from(\"opacity\", 0);\n    ;\n    ;\n        this._anim.by(\"opacity\", 1).checkpoint().duration(3500).checkpoint().to(\"opacity\", 0).checkpoint().JSBNG__ondone(this._killAnim.bind(this)).go();\n    },\n    _killAnim: function(a, b) {\n        if (this._anim) {\n            this._anim.JSBNG__stop();\n            this._dialog.hide(false);\n            this._anim = null;\n        }\n    ;\n    ;\n    }\n});\n__d(\"StreamViewportTracking\", [\"event-extensions\",\"Arbiter\",\"Class\",\"DOM\",\"NavigationMessage\",\"Run\",\"Style\",\"UIIntentionalStreamMessage\",\"Vector\",\"ViewportTracking\",\"$\",\"collectSubtreeData\",\"copyProperties\",\"debounce\",\"userAction\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"Class\"), i = b(\"DOM\"), j = b(\"NavigationMessage\"), k = b(\"Run\"), l = b(\"Style\"), m = b(\"UIIntentionalStreamMessage\"), n = b(\"Vector\"), o = b(\"ViewportTracking\"), p = b(\"$\"), q = b(\"collectSubtreeData\"), r = b(\"copyProperties\"), s = b(\"debounce\"), t = b(\"userAction\"), u = 51;\n    function v() {\n        this.parent.construct(this);\n    };\n;\n    h.extend(v, o);\n    r(v.prototype, {\n        getDataFromConfig: function(w) {\n            this.recordTNTree = w.record_tn_tree;\n            this.timeout = w.record_delay;\n        },\n        getTimeout: function() {\n            return this.timeout;\n        },\n        getAllStories: function() {\n            return i.scry(p(\"home_stream\"), \".uiStreamStory\");\n        },\n        getStoryID: function(w) {\n            var x = JSON.parse(w.getAttribute(\"data-ft\"));\n            return x.mf_story_key;\n        },\n        getDataToLog: function(w) {\n            var x = {\n                evt: u\n            };\n            if (this.recordTNTree) {\n                var y = q(w, [\"ft\",]);\n                for (var z in y.ft) {\n                    x[((z + \"_tree\"))] = y.ft[z];\n                    if (((z === \"tn-debug\"))) {\n                        w.setAttribute(\"tn-debug_subtree\", y.ft[z]);\n                    }\n                ;\n                ;\n                };\n            ;\n                x.evt_value = w.offsetHeight;\n            }\n        ;\n        ;\n            return {\n                ft: x\n            };\n        }\n    });\n    e.exports.init = function(w) {\n        (new v()).init(w);\n    };\n});");
// 2854
JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_84[0](o23,false,o24);
// undefined
o23 = null;
// undefined
o24 = null;
// 2876
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"1zqwA\",]);\n}\n;\n__d(\"AjaxRequest\", [\"ErrorUtils\",\"Keys\",\"URI\",\"UserAgent\",\"XHR\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"ErrorUtils\"), h = b(\"Keys\"), i = b(\"URI\"), j = b(\"UserAgent\"), k = b(\"XHR\"), l = b(\"copyProperties\");\n    function m(q, r, s) {\n        this.xhr = k.create();\n        if (!((r instanceof i))) {\n            r = new i(r);\n        };\n        if ((s && (q == \"GET\"))) {\n            r.setQueryData(s);\n        }\n         else this._params = s;\n    ;\n        this.method = q;\n        this.uri = r;\n        this.xhr.open(q, r);\n    };\n    var n = (window.XMLHttpRequest && ((\"withCredentials\" in new XMLHttpRequest())));\n    m.supportsCORS = function() {\n        return n;\n    };\n    m.ERROR = \"ar:error\";\n    m.TIMEOUT = \"ar:timeout\";\n    m.PROXY_ERROR = \"ar:proxy error\";\n    m.TRANSPORT_ERROR = \"ar:transport error\";\n    m.SERVER_ERROR = \"ar:http error\";\n    m.PARSE_ERROR = \"ar:parse error\";\n    m._inflight = [];\n    function o() {\n        var q = m._inflight;\n        m._inflight = [];\n        q.forEach(function(r) {\n            r.abort();\n        });\n    };\n    function p(q) {\n        q.onJSON = q.onError = q.onSuccess = null;\n        clearTimeout(q._timer);\n        if ((q.xhr && (q.xhr.readyState < 4))) {\n            q.xhr.abort();\n            q.xhr = null;\n        }\n    ;\n        m._inflight = m._inflight.filter(function(r) {\n            return (((r && (r != q)) && r.xhr) && (r.xhr.readyState < 4));\n        });\n    };\n    l(m.prototype, {\n        timeout: 60000,\n        prelude: /^for \\(;;\\);/,\n        status: null,\n        _eol: -1,\n        _call: function(q) {\n            if (this[q]) {\n                this[q](this);\n            };\n        },\n        _parseStatus: function() {\n            var q;\n            try {\n                this.status = this.xhr.status;\n                q = this.xhr.statusText;\n            } catch (r) {\n                if ((this.xhr.readyState >= 4)) {\n                    this.errorType = m.TRANSPORT_ERROR;\n                    this.errorText = r.message;\n                }\n            ;\n                return;\n            };\n            if (((this.status === 0) && !(/^(file|ftp)/.test(this.uri)))) {\n                this.errorType = m.TRANSPORT_ERROR;\n            }\n             else if (((this.status >= 100) && (this.status < 200))) {\n                this.errorType = m.PROXY_ERROR;\n            }\n             else if (((this.status >= 200) && (this.status < 300))) {\n                return;\n            }\n             else if (((this.status >= 300) && (this.status < 400))) {\n                this.errorType = m.PROXY_ERROR;\n            }\n             else if (((this.status >= 400) && (this.status < 500))) {\n                this.errorType = m.SERVER_ERROR;\n            }\n             else if (((this.status >= 500) && (this.status < 600))) {\n                this.errorType = m.PROXY_ERROR;\n            }\n             else if ((this.status == 1223)) {\n                return;\n            }\n             else if (((this.status >= 12001) && (this.status <= 12156))) {\n                this.errorType = m.TRANSPORT_ERROR;\n            }\n             else {\n                q = (\"unrecognized status code: \" + this.status);\n                this.errorType = m.ERROR;\n            }\n            \n            \n            \n            \n            \n            \n            \n        ;\n            if (!this.errorText) {\n                this.errorText = q;\n            };\n        },\n        _parseResponse: function() {\n            var q, r = this.xhr.readyState;\n            try {\n                q = (this.xhr.responseText || \"\");\n            } catch (s) {\n                if ((r >= 4)) {\n                    this.errorType = m.ERROR;\n                    this.errorText = (\"responseText not available - \" + s.message);\n                }\n            ;\n                return;\n            };\n            while (this.xhr) {\n                var t = (this._eol + 1), u = q.indexOf(\"\\u000a\", t);\n                if (((u < 0) && (r == 4))) {\n                    u = q.length;\n                };\n                if ((u <= this._eol)) {\n                    break;\n                };\n                var v = q.substr(t, (u - t)).replace(/^\\s*|\\s*$/g, \"\");\n                if (((t === 0) && this.prelude)) {\n                    if (this.prelude.test(v)) {\n                        v = v.replace(this.prelude, \"\");\n                    }\n                };\n                this._eol = u;\n                if (v) {\n                    try {\n                        this.json = JSON.parse(v);\n                    } catch (s) {\n                        var w = ((/(<body[\\S\\s]+?<\\/body>)/i).test(q) && RegExp.$1), x = {\n                            message: s.message,\n                            char: t,\n                            excerpt: (((((t === 0) && w)) || v)).substr(512)\n                        };\n                        this.errorType = m.PARSE_ERROR;\n                        this.errorText = (\"parse error - \" + JSON.stringify(x));\n                        return;\n                    };\n                    g.applyWithGuard(this._call, this, [\"onJSON\",]);\n                }\n            ;\n            };\n        },\n        _onReadyState: function() {\n            var q = ((this.xhr && this.xhr.readyState) || 0);\n            if (((this.status == null) && (q >= 2))) {\n                this._parseStatus();\n            };\n            if ((((this.status != null) && (q >= 3)) && !this.errorType)) {\n                this._parseResponse();\n            };\n            if ((this.errorType || (q == 4))) {\n                this._time = (Date.now() - this._sentAt);\n                this._call((!this.errorType ? \"onSuccess\" : \"onError\"));\n                p(this);\n            }\n        ;\n        },\n        send: function(q) {\n            this.xhr.onreadystatechange = function() {\n                g.applyWithGuard(this._onReadyState, this, arguments);\n            }.bind(this);\n            var r = this.timeout;\n            if (r) {\n                this._timer = setTimeout((function() {\n                    this.errorType = m.TIMEOUT;\n                    this.errorText = \"timeout\";\n                    this._time = (Date.now() - this._sentAt);\n                    this._call(\"onError\");\n                    p(this);\n                }).bind(this), r, false);\n            };\n            m._inflight.push(this);\n            if ((this.method == \"POST\")) {\n                this.xhr.setRequestHeader(\"Content-Type\", \"application/x-www-form-urlencoded\");\n            };\n            this._sentAt = Date.now();\n            this.xhr.send((q ? i.implodeQuery(q) : \"\"));\n        },\n        abort: function() {\n            p(this);\n        },\n        toString: function() {\n            var q = (\"[AjaxRequest readyState=\" + this.xhr.readyState);\n            if (this.errorType) {\n                q += ((((\" errorType=\" + this.errorType) + \" (\") + this.errorText) + \")\");\n            };\n            return (q + \"]\");\n        },\n        toJSON: function() {\n            var q = {\n                json: this.json,\n                status: this.status,\n                errorType: this.errorType,\n                errorText: this.errorText,\n                time: this._time\n            };\n            for (var r in q) {\n                if ((q[r] == null)) {\n                    delete q[r];\n                };\n            };\n            return q;\n        }\n    });\n    if ((window.addEventListener && j.firefox())) {\n        window.addEventListener(\"keydown\", function(event) {\n            if ((event.keyCode === h.ESC)) {\n                event.prevent();\n            };\n        }, false);\n    };\n    if (window.attachEvent) {\n        window.attachEvent(\"onunload\", o);\n    };\n    e.exports = m;\n});\n__d(\"ChatConfig\", [\"copyProperties\",\"ChatConfigInitialData\",], function(a, b, c, d, e, f) {\n    var g = c(\"ChatConfigInitialData\"), h = b(\"copyProperties\"), i = {\n    }, j = {\n        get: function(k, l) {\n            return ((k in i) ? i[k] : l);\n        },\n        set: function(k) {\n            if ((arguments.length > 1)) {\n                var l = {\n                };\n                l[k] = arguments[1];\n                k = l;\n            }\n        ;\n            h(i, k);\n        },\n        getDebugInfo: function() {\n            return i;\n        }\n    };\n    j.set(g);\n    e.exports = j;\n});\n__d(\"ChannelConstants\", [], function(a, b, c, d, e, f) {\n    var g = \"channel/\", h = {\n        ON_SHUTDOWN: (g + \"shutdown\"),\n        ON_INVALID_HISTORY: (g + \"invalid_history\"),\n        ON_CONFIG: (g + \"config\"),\n        ON_ENTER_STATE: (g + \"enter_state\"),\n        ON_EXIT_STATE: (g + \"exit_state\"),\n        OK: \"ok\",\n        ERROR: \"error\",\n        ERROR_MAX: \"error_max\",\n        ERROR_MISSING: \"error_missing\",\n        ERROR_MSG_TYPE: \"error_msg_type\",\n        ERROR_SHUTDOWN: \"error_shutdown\",\n        ERROR_STALE: \"error_stale\",\n        SYS_OWNER: \"sys_owner\",\n        SYS_NONOWNER: \"sys_nonowner\",\n        SYS_ONLINE: \"sys_online\",\n        SYS_OFFLINE: \"sys_offline\",\n        SYS_TIMETRAVEL: \"sys_timetravel\",\n        HINT_AUTH: \"shutdown auth\",\n        HINT_CONN: \"shutdown conn\",\n        HINT_DISABLED: \"shutdown disabled\",\n        HINT_INVALID_STATE: \"shutdown invalid state\",\n        HINT_MAINT: \"shutdown maint\",\n        HINT_UNSUPPORTED: \"shutdown unsupported\",\n        reason_Unknown: 0,\n        reason_AsyncError: 1,\n        reason_TooLong: 2,\n        reason_Refresh: 3,\n        reason_RefreshDelay: 4,\n        reason_UIRestart: 5,\n        reason_NeedSeq: 6,\n        reason_PrevFailed: 7,\n        reason_IFrameLoadGiveUp: 8,\n        reason_IFrameLoadRetry: 9,\n        reason_IFrameLoadRetryWorked: 10,\n        reason_PageTransitionRetry: 11,\n        reason_IFrameLoadMaxSubdomain: 12,\n        reason_NoChannelInfo: 13,\n        reason_NoChannelHost: 14,\n        getArbiterType: function(i) {\n            return ((g + \"message:\") + i);\n        }\n    };\n    e.exports = h;\n});\n__d(\"ChannelSubdomain\", [\"Cookie\",\"JSLogger\",\"UserAgent\",], function(a, b, c, d, e, f) {\n    var g = b(\"Cookie\"), h = b(\"JSLogger\"), i = b(\"UserAgent\"), j = h.create(\"channel\"), k = 7, l = null;\n    function m(p) {\n        var q = null, r = n(), s, t = (i.firefox() ? Math.floor((Math.random() * 32)) : 0);\n        for (var u = 0; (u < 32); u++) {\n            s = (((u + t)) \u0025 32);\n            if (!((r & ((1 << s))))) {\n                break;\n            };\n        };\n        p--;\n        if ((s < Math.min(32, (k * p)))) {\n            l = s;\n            q = (l \u0025 k);\n            g.set(\"sub\", (r | ((1 << l))));\n        }\n         else {\n            l = -1;\n            q = null;\n            j.error(\"subdomain_overflow\", {\n                slot: l,\n                max: p\n            });\n        }\n    ;\n        return q;\n    };\n    function n() {\n        var p = (g.get(\"sub\") || 0);\n        p = parseInt(p, 10);\n        return (isNaN(p) ? 0 : p);\n    };\n    function o() {\n        if (((l !== null) && (l >= 0))) {\n            var p = (n() & ~((1 << l)));\n            if (p) {\n                g.set(\"sub\", p);\n            }\n             else g.clear(\"sub\");\n        ;\n        }\n    ;\n    };\n    e.exports = {\n        allocate: m,\n        clear: o\n    };\n});\n__d(\"ChannelTransport\", [\"copyProperties\",\"bind\",\"AjaxRequest\",\"URI\",\"JSLogger\",\"DocRPC\",\"ChannelConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\"), h = b(\"bind\"), i = b(\"AjaxRequest\"), j = b(\"URI\"), k = b(\"JSLogger\"), l = b(\"DocRPC\"), m = b(\"ChannelConstants\"), n = k.create(\"channel\");\n    function o() {\n        return (((1048576 * Math.random()) | 0)).toString(36);\n    };\n    function p(x, y) {\n        var z = x.subdomain;\n        z = ((z === null) ? \"\" : ((z + \"-\")));\n        var aa = new j(y).setDomain(((z + x.host) + \".facebook.com\")).setPort(x.port).setSecure(j().isSecure());\n        return aa;\n    };\n    function q(x) {\n        var y = {\n            partition: x.partition,\n            cb: o()\n        }, z = p(x, \"/p\").setQueryData(y);\n        n.log(\"start_p\", {\n            uri: z.toString()\n        });\n        var aa = new i(\"GET\", z);\n        if (i.supportsCORS()) {\n            aa.xhr.withCredentials = true;\n        };\n        var ba = function(ca) {\n            n.log(\"finish_p\", {\n                xhr: (ca.toJSON ? ca.toJSON() : ca)\n            });\n        };\n        aa.timeout = x.P_TIMEOUT;\n        aa.onError = aa.onSuccess = ba;\n        aa.send();\n    };\n    function r(x, y, z) {\n        var aa = new Image(), ba = 0, ca = function(fa) {\n            aa.abort();\n            return (fa ? y() : z());\n        };\n        aa.onload = function() {\n            n.log(\"ping_ok\", {\n                duration: (Date.now() - ba)\n            });\n            ca(true);\n        };\n        aa.onerror = function() {\n            q(x);\n            ca(false);\n        };\n        var da = setTimeout(aa.onerror, 10000, false);\n        aa.abort = function() {\n            if (da) {\n                clearTimeout(da);\n                da = null;\n            }\n        ;\n            aa.onload = aa.onerror = null;\n        };\n        var ea = {\n            partition: x.partition,\n            cb: o()\n        };\n        ba = Date.now();\n        aa.src = p(x, \"/ping\").setQueryData(ea);\n        return aa;\n    };\n    function s(x, y, z, aa) {\n        var ba = new Date(), ca = ((((ba - x.userActive)) / 1000) | 0);\n        if ((ca < 0)) {\n            n.warn(\"idle_regression\", {\n                idleTime: ca,\n                now: ba.getTime(),\n                userActive: x.userActive\n            });\n        };\n        var da = {\n            channel: x.user_channel,\n            seq: x.seq,\n            partition: x.partition,\n            clientid: x.sessionID,\n            cb: o(),\n            idle: ca\n        };\n        if ((ca < 60)) {\n            da.state = \"active\";\n        };\n        if (x.streamingCapable) {\n            da.mode = \"stream\";\n            da.format = \"json\";\n        }\n    ;\n        var ea = p(x, \"/pull\").setQueryData(da), fa = new i(\"GET\", ea);\n        if (i.supportsCORS()) {\n            fa.xhr.withCredentials = true;\n        };\n        fa.timeout = (x.streamingCapable ? x.STREAMING_TIMEOUT : x.LONGPOLL_TIMEOUT);\n        fa.onJSON = y;\n        fa.onSuccess = z;\n        fa.onError = function() {\n            var ga = ((((this.status == 12002) && (this._time >= x.MIN_12002_TIMEOUT))) || (((this.status == 504) && (this._time >= x.MIN_504_TIMEOUT)))), ha = (ga ? z : aa);\n            return (ha && ha.apply(this, arguments));\n        };\n        fa.send();\n        x.inStreaming = x.streamingCapable;\n        return fa;\n    };\n    function t(x) {\n        this.manager = x;\n        ((this.init && this.init()));\n    };\n    function u(x) {\n        t.apply(this, arguments);\n    };\n    g(u.prototype, {\n        logName: \"CORS\",\n        enterState: function(x, y) {\n            if (this._request) {\n                this._request.abort();\n                this._request = null;\n            }\n        ;\n            if ((x == \"init\")) {\n                setTimeout(h(this.manager, \"exitState\", {\n                    status: m.OK,\n                    stateId: y.stateId\n                }), 3000, false);\n            };\n            if (!/pull|ping/.test(x)) {\n                return\n            };\n            var z = this.manager;\n            if ((x == \"ping\")) {\n                this._request = r(y, h(z, \"exitState\", {\n                    status: m.OK,\n                    stateId: y.stateId\n                }), h(z, \"exitState\", {\n                    status: m.ERROR,\n                    stateId: y.stateId\n                }));\n            }\n             else if ((x == \"pull\")) {\n                this._request = s(y, h(z, \"_processTransportData\", y.stateId), h(z, \"exitState\", {\n                    status: m.OK,\n                    stateId: y.stateId\n                }), h(z, \"exitState\", {\n                    status: m.ERROR,\n                    stateId: y.stateId\n                }));\n            }\n        ;\n        }\n    });\n    function v(x) {\n        n.log(\"iframe_init_constructor\");\n        t.apply(this, arguments);\n        this._iframe = document.createElement(\"iframe\");\n        this._iframe.style.display = \"none\";\n        document.body.appendChild(this._iframe);\n        l.publish(this, \"outerTransport\");\n    };\n    g(v.prototype, {\n        logName: \"iframe\",\n        _initIframe: function(x) {\n            n.log(\"iframe_init_start\");\n            window.onchanneliframeready = function() {\n                n.log(\"iframe_resources\");\n                return x.resources;\n            };\n            window.onchanneliframeloaded = function() {\n                n.log(\"iframe_loaded\");\n            };\n            if (x) {\n                this._iframeURI = p(x, x.path);\n                if (x.bustIframe) {\n                    var y = {\n                        partition: x.partition,\n                        cb: o()\n                    };\n                    this._iframeURI.setQueryData(y);\n                }\n            ;\n            }\n             else this._iframeURI = \"about:blank\";\n        ;\n            this._iframeProxy = null;\n            try {\n                this._iframe.contentWindow.location.replace(this._iframeURI);\n                n.log(\"iframe_uri_set\");\n            } catch (z) {\n                n.error(\"iframe_uri_set_error\", z);\n                this.exitState({\n                    status: m.ERROR,\n                    stateId: x.stateId\n                }, (z + \"\"));\n            };\n        },\n        enterState: function(x, y) {\n            if ((x == \"init\")) {\n                this._initIframe(y);\n            }\n             else if (/idle|ping|pull/.test(x)) {\n                if (this._iframeProxy) {\n                    this._iframeProxy.enterState.apply(this._iframeProxy, arguments);\n                }\n                 else if ((x != \"idle\")) {\n                    this.exitState({\n                        status: m.ERROR,\n                        stateId: y.stateId\n                    }, \"iframe not yet loaded\");\n                }\n            ;\n            }\n             else if ((x == \"shutdown\")) {\n                this._initIframe();\n            }\n            \n        ;\n        },\n        _processTransportData: function() {\n            this.manager._processTransportData.apply(this.manager, arguments);\n        },\n        exitState: function(x) {\n            if (((this.manager.state == \"init\") && (x.status == m.OK))) {\n                this._iframeProxy = l.proxy(this._iframe.contentWindow, \"innerTransport\", [\"enterState\",], ((this._iframeURI + \"\")).replace(/iframe.*/, \"\"));\n            };\n            if ((/ping|pull/.test(this.manager.state) && !this._iframeProxy)) {\n                return\n            };\n            this.manager.exitState.apply(this.manager, arguments);\n        }\n    });\n    function w() {\n        this.init = this.init.bind(this);\n        t.apply(this, arguments);\n    };\n    g(w.prototype, {\n        logName: \"iframe(inner)\",\n        init: function() {\n            l.publish(this, \"innerTransport\");\n            try {\n                var y = l.proxy(window.parent, \"outerTransport\", [\"_processTransportData\",\"exitState\",], top.DocRPC.origin);\n                g(this, y);\n                this.exitState({\n                    status: m.OK,\n                    stateId: 1000000\n                });\n            } catch (x) {\n                n.error(\"iframe_inner_init_error\", x);\n            };\n        },\n        enterState: function(x, y) {\n            if (this._request) {\n                this._request.abort();\n                this._request = null;\n            }\n        ;\n            if ((x == \"ping\")) {\n                this._request = r(y, h(this, \"exitState\", {\n                    status: m.OK,\n                    stateId: y.stateId\n                }), h(this, \"exitState\", {\n                    status: m.ERROR,\n                    stateId: y.stateId\n                }));\n            }\n             else if ((x == \"pull\")) {\n                this._request = s(y, h(this, \"_processTransportData\", y.stateId), h(this, \"exitState\", {\n                    status: m.OK,\n                    stateId: y.stateId\n                }), h(this, \"exitState\", {\n                    status: m.ERROR,\n                    stateId: y.stateId\n                }));\n            }\n        ;\n        }\n    });\n    e.exports = {\n        getURI: p,\n        Transport: t,\n        CORSTransport: u,\n        IframeTransport: v,\n        IframeInnerTransport: w\n    };\n});\n__d(\"FBAjaxRequest\", [\"$\",\"AjaxRequest\",\"copyProperties\",\"XHR\",], function(a, b, c, d, e, f) {\n    var g = b(\"$\"), h = b(\"AjaxRequest\"), i = b(\"copyProperties\"), j = b(\"XHR\");\n    function k(l, m, n) {\n        n = i(j.getAsyncParams(l), n);\n        var o = new h(l, m, n), p = o._call;\n        o._call = function(q) {\n            if (((q == \"onJSON\") && this.json)) {\n                if (this.json.error) {\n                    this.errorType = h.SERVER_ERROR;\n                    this.errorText = (\"AsyncResponse error: \" + this.json.error);\n                }\n            ;\n                this.json = this.json.payload;\n            }\n        ;\n            p.apply(this, arguments);\n        };\n        return o;\n    };\n    e.exports = k;\n});\n__d(\"MovingStat\", [], function(a, b, c, d, e, f) {\n    function g(h) {\n        h = (h || 60000);\n        var i = {\n            t: new Date(),\n            count: 0,\n            v: 0\n        }, j = i, k = 0, l = 0;\n        function m() {\n            var n = (new Date() - h);\n            while (((j && j.next) && (j.t < n))) {\n                k -= j.v;\n                l -= j.count;\n                j = j.next;\n            };\n        };\n        this.add = function(n) {\n            k += n;\n            l++;\n            var o = new Date();\n            if (((o - i.t) < 1000)) {\n                i.v += n;\n                i.count++;\n            }\n             else {\n                i.next = {\n                    t: o,\n                    v: n,\n                    count: 1\n                };\n                i = i.next;\n                m();\n            }\n        ;\n        };\n        this.tally = function(n) {\n            n = (n || 1000);\n            m();\n            return {\n                sum: k,\n                count: l,\n                timeAverage: ((k * n) / h)\n            };\n        };\n    };\n    e.exports = g;\n});\n__d(\"PresenceUtil\", [\"Cookie\",\"Env\",\"randomInt\",\"tx\",], function(a, b, c, d, e, f) {\n    var g = b(\"Cookie\"), h = b(\"Env\"), i = b(\"randomInt\"), j = b(\"tx\"), k = (i(0, 4294967295) + 1);\n    a.PresenceUtil = e.exports = {\n        checkMaintenanceError: function(l) {\n            if ((l.getError() == 1356007)) {\n                return true\n            };\n            return false;\n        },\n        getErrorDescription: function(l) {\n            var m = l.getError(), n = l.getErrorDescription();\n            if (!n) {\n                n = \"An error occurred.\";\n            };\n            if ((m == 1357001)) {\n                n = \"Your session has timed out. Please log in.\";\n            };\n            return n;\n        },\n        getSessionID: function() {\n            return k;\n        },\n        hasUserCookie: function() {\n            return (h.user === g.get(\"c_user\"));\n        }\n    };\n}, 3);\n__d(\"PresenceCookieManager\", [\"Cookie\",\"Dcode\",\"ErrorUtils\",\"Env\",\"JSLogger\",\"PresenceUtil\",\"URI\",\"PresenceInitialData\",], function(a, b, c, d, e, f) {\n    var g = b(\"Cookie\"), h = b(\"Dcode\"), i = b(\"ErrorUtils\"), j = b(\"Env\"), k = b(\"JSLogger\"), l = b(\"PresenceUtil\"), m = b(\"URI\"), n = c(\"PresenceInitialData\"), o = n.cookieVersion, p = n.dictEncode, q = \"presence\", r = {\n    }, s = null, t = null, u = k.create(\"presence_cookie\");\n    function v() {\n        try {\n            var z = g.get(q);\n            if ((s !== z)) {\n                s = z;\n                t = null;\n                if ((z && (z.charAt(0) == \"E\"))) {\n                    z = h.decode(z.substring(1));\n                };\n                if (z) {\n                    t = JSON.parse(z);\n                };\n            }\n        ;\n            if ((t && ((!t.user || (t.user === j.user))))) {\n                return t\n            };\n        } catch (y) {\n            u.warn(\"getcookie_error\");\n        };\n        return null;\n    };\n    function w() {\n        return parseInt((new Date().getTime() / 1000), 10);\n    };\n    var x = {\n        register: function(y, z) {\n            r[y] = z;\n        },\n        store: function() {\n            var y = v();\n            if (((y && y.v) && (o < y.v))) {\n                return\n            };\n            var z = {\n                v: o,\n                time: w(),\n                user: j.user\n            };\n            for (var aa in r) {\n                z[aa] = i.applyWithGuard(r[aa], r, [(y && y[aa]),], function(ea) {\n                    ea.presence_subcookie = aa;\n                });;\n            };\n            var ba = JSON.stringify(z);\n            if (p) {\n                ba = (\"E\" + h.encode(ba));\n            };\n            if (l.hasUserCookie()) {\n                var ca = ba.length;\n                if ((ca > 1024)) {\n                    u.warn(\"big_cookie\", ca);\n                };\n                var da = (m.getRequestURI(false).isSecure() && !!g.get(\"csm\"));\n                g.set(q, ba, null, null, da);\n            }\n        ;\n        },\n        clear: function() {\n            g.clear(q);\n        },\n        getSubCookie: function(y) {\n            var z = v();\n            if (!z) {\n                return null\n            };\n            return z[y];\n        }\n    };\n    e.exports = x;\n});\n__d(\"PresenceState\", [\"Arbiter\",\"ErrorUtils\",\"JSLogger\",\"PresenceCookieManager\",\"copyProperties\",\"debounceAcrossTransitions\",\"setIntervalAcrossTransitions\",\"PresenceInitialData\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ErrorUtils\"), i = b(\"JSLogger\"), j = b(\"PresenceCookieManager\"), k = b(\"copyProperties\"), l = b(\"debounceAcrossTransitions\"), m = b(\"setIntervalAcrossTransitions\"), n = c(\"PresenceInitialData\"), o = (n.cookiePollInterval || 2000), p = [], q = [], r = null, s = null, t = 0, u = null, v = 0, w = [\"sb2\",\"t2\",\"lm2\",\"uct2\",\"tr\",\"tw\",\"at\",\"snd\",\"not\",], x = i.create(\"presence_state\");\n    function y() {\n        return j.getSubCookie(\"state\");\n    };\n    function z() {\n        t = Date.now();\n        j.store();\n        da(s);\n    };\n    var aa = l(z, 0);\n    function ba(ha) {\n        if (((((typeof ha == \"undefined\") || isNaN(ha)) || (ha == Number.POSITIVE_INFINITY)) || (ha == Number.NEGATIVE_INFINITY))) {\n            ha = 0;\n        };\n        return ha;\n    };\n    function ca(ha) {\n        var ia = {\n        };\n        if (ha) {\n            w.forEach(function(la) {\n                ia[la] = ha[la];\n            });\n            if ((t < ha.ut)) {\n                x.error(\"new_cookie\", {\n                    cookie_time: ha.ut,\n                    local_time: t\n                });\n            };\n        }\n    ;\n        ia.ut = t;\n        for (var ja = 0, ka = p.length; (ja < ka); ja++) {\n            h.applyWithGuard(p[ja], null, [ia,]);;\n        };\n        s = ia;\n        return s;\n    };\n    function da(ha) {\n        v++;\n        t = ba(ha.ut);\n        if (!r) {\n            r = m(ga, o);\n        };\n        s = ha;\n        if ((u === null)) {\n            u = ha;\n        };\n        for (var ia = 0, ja = q.length; (ia < ja); ia++) {\n            h.applyWithGuard(q[ia], null, [ha,]);;\n        };\n        v--;\n    };\n    function ea(ha) {\n        if ((ha && ha.ut)) {\n            if ((t < ha.ut)) {\n                return true;\n            }\n             else if ((ha.ut < t)) {\n                x.error(\"old_cookie\", {\n                    cookie_time: ha.ut,\n                    local_time: t\n                });\n            }\n        \n        };\n        return false;\n    };\n    function fa() {\n        var ha = y();\n        if (ea(ha)) {\n            s = ha;\n        };\n        return s;\n    };\n    function ga() {\n        var ha = y();\n        if (ea(ha)) {\n            da(ha);\n        };\n    };\n    j.register(\"state\", ca);\n    g.subscribe(i.DUMP_EVENT, function(ha, ia) {\n        ia.presence_state = {\n            initial: k({\n            }, u),\n            state: k({\n            }, s),\n            update_time: t,\n            sync_paused: v,\n            poll_time: o\n        };\n    });\n    (function() {\n        var ha = fa();\n        if (ha) {\n            da(ha);\n        }\n         else {\n            x.debug(\"no_cookie_initial\");\n            da(ca());\n            return;\n        }\n    ;\n    })();\n    a.PresenceState = e.exports = {\n        doSync: function(ha) {\n            if (v) {\n                return\n            };\n            if (ha) {\n                z();\n            }\n             else aa();\n        ;\n        },\n        registerStateStorer: function(ha) {\n            p.push(ha);\n        },\n        registerStateLoader: function(ha) {\n            q.push(ha);\n        },\n        get: function() {\n            return fa();\n        },\n        getInitial: function() {\n            return u;\n        },\n        verifyNumber: ba\n    };\n}, 3);\n__d(\"ChannelManager\", [\"event-extensions\",\"function-extensions\",\"AjaxRequest\",\"Arbiter\",\"AsyncRequest\",\"ChannelConstants\",\"ChannelSubdomain\",\"ChannelTransport\",\"Cookie\",\"Env\",\"FBAjaxRequest\",\"JSLogger\",\"MovingStat\",\"PresenceCookieManager\",\"PresenceState\",\"PresenceUtil\",\"Run\",\"SystemEvents\",\"URI\",\"UserActivity\",\"UserAgent\",\"copyProperties\",\"createArrayFrom\",\"hasArrayNature\",\"ChannelInitialData\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"AjaxRequest\"), h = b(\"Arbiter\"), i = b(\"AsyncRequest\"), j = b(\"ChannelConstants\"), k = b(\"ChannelSubdomain\"), l = b(\"ChannelTransport\"), m = b(\"Cookie\"), n = b(\"Env\"), o = b(\"FBAjaxRequest\"), p = b(\"JSLogger\"), q = b(\"MovingStat\"), r = b(\"PresenceCookieManager\"), s = b(\"PresenceState\"), t = b(\"PresenceUtil\"), u = b(\"Run\"), v = b(\"SystemEvents\"), w = b(\"URI\"), x = b(\"UserActivity\"), y = b(\"UserAgent\"), z = b(\"copyProperties\"), aa = b(\"createArrayFrom\"), ba = b(\"hasArrayNature\"), ca = c(\"ChannelInitialData\"), da, ea = p.create(\"channel\"), fa = null;\n    function ga(sa) {\n        fa = sa;\n    };\n    var ha = {\n        idle: {\n            ok: \"init!\"\n        },\n        init: {\n            ok: \"pull!\",\n            error: \"reconnect\",\n            sys_online: \"init\",\n            sys_timetravel: \"init\"\n        },\n        pull: {\n            ok: \"pull!\",\n            error: \"ping\",\n            error_missing: \"pull\",\n            error_msg_type: \"pull\",\n            refresh_0: \"reconnect\",\n            refresh_110: \"reconnect\",\n            refresh_111: \"pull\",\n            refresh_112: \"pull\",\n            refresh_113: \"pull\",\n            refresh_117: \"reconnect\"\n        },\n        ping: {\n            ok: \"pull!\",\n            error: \"ping\",\n            error_stale: \"reconnect!\"\n        },\n        reconnect: {\n            ok: \"init!\",\n            error: \"reconnect\",\n            sys_online: \"reconnect\",\n            sys_timetravel: \"reconnect\"\n        },\n        shutdown: {\n        },\n        _all: {\n            error_max: \"shutdown!\",\n            error_shutdown: \"shutdown!\",\n            sys_owner: \"reconnect\",\n            sys_nonowner: \"idle!\",\n            sys_online: \"ping\",\n            sys_offline: \"idle!\",\n            sys_timetravel: \"ping\"\n        }\n    }, ia = {\n        userActive: Date.now(),\n        sessionID: (((Math.random() * 2147483648) | 0)).toString(16),\n        streamingCapable: false,\n        inStreaming: false,\n        LONGPOLL_TIMEOUT: 60000,\n        STREAMING_TIMEOUT: 60000,\n        P_TIMEOUT: 30000,\n        IFRAME_LOAD_TIMEOUT: 30000,\n        MIN_RETRY_INTERVAL: 5000,\n        MAX_RETRY_INTERVAL: 30000,\n        MIN_12002_TIMEOUT: 9000,\n        MIN_504_TIMEOUT: 20000,\n        STALL_THRESHOLD: 180000,\n        JUMPSTART_THRESHOLD: 90000,\n        MIN_INIT_PROBE_DELAY: 3000,\n        INIT_PROBE_DELAY_RANDOMIZE_RANGE: 12000,\n        PROBE_DELAY: 60000,\n        PROBE_HEARTBEATS_INTERVAL_LOW: 1500,\n        PROBE_HEARTBEATS_INTERVAL_HIGH: 2500,\n        STREAMING_EXIT_STATE_ON_CONTINUE: false\n    }, ja = 1, ka = {\n    }, la = 0;\n    function ma(sa) {\n        return sa.toLowerCase().replace(/[^0-9a-z]+/g, \"_\");\n    };\n    function na() {\n        return (i.lastSuccessTime ? Math.round((((Date.now() - i.lastSuccessTime)) / 1000)) : -1);\n    };\n    function oa() {\n        var sa = {\n        };\n        if (da.getConfig(\"host\")) {\n            sa[da.getConfig(\"user_channel\")] = da.getConfig(\"seq\", 0);\n        };\n        return sa;\n    };\n    function pa() {\n        var sa = Date.now(), ta = Date.now(), ua = {\n            total: 0\n        }, va = \"idle\", wa = false;\n        v.subscribe([v.USER,v.ONLINE,v.TIME_TRAVEL,], function(za, ab) {\n            ra(true);\n            ta = null;\n            da.lastPullTime = Date.now();\n            var bb;\n            switch (za) {\n              case v.USER:\n                bb = (v.isPageOwner() ? j.SYS_OWNER : j.SYS_NONOWNER);\n                break;\n              case v.ONLINE:\n                bb = (ab ? j.SYS_ONLINE : j.SYS_OFFLINE);\n                break;\n              case v.TIME_TRAVEL:\n                bb = j.SYS_TIMETRAVEL;\n                break;\n            };\n            da.exitState({\n                status: bb,\n                stateId: ja\n            });\n        });\n        var xa = function(za, ab) {\n            var bb = Date.now(), cb;\n            if (ab) {\n                sa = bb;\n                cb = (ab.nextState || ab.state);\n            }\n             else cb = va;\n        ;\n            v.checkTimeTravel();\n            if (ta) {\n                var db = Math.round((((bb - ta)) / 1000));\n                if ((db > 0)) {\n                    ua[va] = (((ua[va] || 0)) + db);\n                    ua.total += db;\n                }\n            ;\n            }\n        ;\n            va = cb;\n            ta = bb;\n            if (!za) {\n                ua.lastSuccessTime = na();\n                ua.online = v.isOnline();\n                ea.log(\"rollup\", ua);\n            }\n        ;\n        };\n        h.subscribe(j.ON_ENTER_STATE, xa);\n        setInterval(xa, 60000, false);\n        h.subscribe(p.DUMP_EVENT, function(za, ab) {\n            ab.channelRollup = ua;\n        });\n        var ya = function() {\n            if ((da.isShutdown() || da.shouldIdle())) {\n                return\n            };\n            v.checkTimeTravel();\n            var za = (Date.now() - ((da.lastPullTime || n.start)));\n            if ((!wa && (za > ia.STALL_THRESHOLD))) {\n                var ab = na();\n                ea.error(\"stall\", {\n                    lastSuccessTime: ab,\n                    rollupState: va\n                });\n                wa = true;\n            }\n        ;\n            var bb = (Date.now() - sa);\n            if (((da.state == \"pull\") && (bb > ia.JUMPSTART_THRESHOLD))) {\n                sa = null;\n                ea.warn(\"jumpstart\", {\n                    state: da.state,\n                    dormant: bb\n                });\n                da.enterState(\"init\");\n            }\n        ;\n        };\n        setInterval(ya, 10000, false);\n    };\n    function qa() {\n        var sa = Date.now(), ta = 1;\n        function ua() {\n            setTimeout(ua, (ta * 1000), false);\n            var za = da.state;\n            if (((za == \"idle\") && da.shouldIdle())) {\n                return\n            };\n            ea.bump(\"conn_t\", ta);\n            if ((za == \"pull\")) {\n                ea.bump(\"conn_t_pull\", ta);\n            };\n        };\n        ua();\n        var va = [15,30,60,120,240,], wa = false, xa = false;\n        function ya(za) {\n            setTimeout(function() {\n                ea.rate((\"pullenter_\" + za), wa);\n                ea.rate((\"pullexit_\" + za), xa);\n            }, (za * 1000), false);\n        };\n        while (va.length) {\n            ya(va.shift());;\n        };\n        h.subscribe(j.ON_ENTER_STATE, function(za, ab) {\n            if ((ab.state == \"pull\")) {\n                wa = true;\n            };\n            sa = Date.now();\n        });\n        h.subscribe(j.ON_EXIT_STATE, function(za, ab) {\n            if (((ab.state != \"pull\") || !sa)) {\n                return\n            };\n            var bb = \"other\";\n            if ((ab.status == j.OK)) {\n                xa = true;\n                bb = \"ok\";\n            }\n             else if ((ab.xhr && ab.xhr.errorType)) {\n                bb = (/ar:(\\w+)/.test(ab.xhr.errorType) && RegExp.$1);\n            }\n             else if (/^sys_/.test(ab.status)) {\n                return\n            }\n            \n        ;\n            var cb = (((Date.now() - sa)) / 1000);\n            if ((cb < 0)) {\n                return;\n            }\n             else if ((cb > 3600)) {\n                cb = 3600;\n            }\n        ;\n            ea.bump(\"conn_num\");\n            ea.bump(\"conn_exit\", cb);\n            ea.bump((\"conn_num_\" + bb));\n            ea.bump((\"conn_exit_\" + bb), cb);\n        });\n    };\n    function ra(sa) {\n        if (sa) {\n            la = 0;\n            ka = {\n            };\n        }\n         else la++;\n    ;\n    };\n    da = {\n        state: \"idle\",\n        nextState: null,\n        lastPullTime: Date.now(),\n        heartbeats: [],\n        setTestCallback: ga,\n        init: function(sa) {\n            this.init = function() {\n            \n            };\n            if ((typeof (x) != \"undefined\")) {\n                x.subscribe(function() {\n                    ia.userActive = Date.now();\n                }.bind(this));\n            }\n             else ea.error(\"user_activity_undefined\");\n        ;\n            r.register(\"ch\", oa);\n            var ta = this.getConfig(\"max_conn\", 2);\n            ia.subdomain = k.allocate(ta);\n            if ((typeof window.onpageshow != \"undefined\")) {\n                Event.listen(window, \"pagehide\", k.clear);\n            }\n             else u.onUnload(k.clear);\n        ;\n            this._transportRate = new q(30000);\n            var ua = (((g.supportsCORS() && !ia.forceIframe)) ? \"CORSTransport\" : \"IframeTransport\");\n            this.transport = new l[ua](this);\n            if (sa) {\n                this.enterState.apply(this, arguments);\n            };\n            h.subscribe(p.DUMP_EVENT, function(event, wa) {\n                wa.transportRate = this._transportRate.tally();\n                wa.transportType = ua;\n                wa.transportVersion = 2;\n            }.bind(this));\n            pa();\n            qa();\n            if ((((da.getConfig(\"tryStreaming\") && da.getConfig(\"host\")) && g.supportsCORS()) && !ia.forceIframe)) {\n                var va = (ia.MIN_INIT_PROBE_DELAY + (Math.random() * ia.INIT_PROBE_DELAY_RANDOMIZE_RANGE));\n                setTimeout(this._probeTest, va, false);\n            }\n        ;\n        },\n        configure: function() {\n            var sa = aa(arguments);\n            ea.log(\"configure\", sa);\n            sa.forEach(z.bind(null, ia));\n            h.inform(j.ON_CONFIG, this);\n        },\n        getConfig: function(sa, ta) {\n            return ((sa in ia) ? ia[sa] : ta);\n        },\n        isShutdown: function() {\n            return (this.state == \"shutdown\");\n        },\n        shouldIdle: function() {\n            return !((v.isPageOwner() && v.isOnline()));\n        },\n        _sendIframeError: function(sa) {\n            var ta = new i().setURI(\"/ajax/presence/reconnect.php\").setData({\n                reason: sa,\n                fb_dtsg: n.fb_dtsg\n            }).setOption(\"suppressErrorHandlerWarning\", true).setOption(\"retries\", 1).setMethod(\"GET\").setReadOnly(true).setAllowCrossPageTransition(true);\n            (ta.specifiesWriteRequiredParams() && ta.send());\n        },\n        _getDelay: function() {\n            var sa = Math.min((ia.MIN_RETRY_INTERVAL * Math.pow(2, Math.max(0, (la - 1)))), ia.MAX_RETRY_INTERVAL);\n            return ((sa * ((22198 + (Math.random() / 2)))) | 0);\n        },\n        enterState: function() {\n            if (this._inEnterState) {\n                ea.warn(\"enterstate_recursion\");\n            };\n            this._inEnterState = true;\n            try {\n                this._enterState.apply(this, arguments);\n                this._inEnterState = false;\n            } catch (sa) {\n                this._inEnterState = false;\n                throw sa;\n            };\n        },\n        _enterState: function(sa) {\n            var ta = 0, ua = null, va = aa(arguments);\n            if (this.isShutdown()) {\n                return\n            };\n            if (((sa != \"idle!\") && this.shouldIdle())) {\n                return\n            };\n            ja++;\n            ia.stateId = ja;\n            clearTimeout(this._deferredTransition);\n            this._deferredTransition = null;\n            this.transport.enterState(\"idle\");\n            this.state = \"idle\";\n            this.nextState = null;\n            if (/!$/.test(sa)) {\n                var wa = this._transportRate.tally().timeAverage, xa = da.getConfig(\"MAX_CHANNEL_STATES_PER_SEC\", 1);\n                if ((wa >= xa)) {\n                    if (!this._throttled) {\n                        this._throttled = true;\n                        ea.warn(\"throttled\");\n                    }\n                ;\n                    ea.bump(\"throttle\");\n                    ta = (1000 / xa);\n                }\n            ;\n            }\n             else if (!(/#$/.test(sa))) {\n                ta = this._getDelay();\n            }\n        ;\n            sa = sa.replace(/\\W*$/, \"\");\n            if (!ha[sa]) {\n                throw new Error((\"invalid state:\" + sa))\n            };\n            var ya;\n            if ((ta <= 0)) {\n                ya = {\n                    state: sa\n                };\n                this._transportRate.add(1);\n                this.state = sa;\n                var za = this[(\"_enter_\" + this.state)];\n                if (za) {\n                    va.shift();\n                    za.apply(this, va);\n                }\n            ;\n                if (/init|idle|pull|ping/.test(this.state)) {\n                    if ((ia.streamingCapable && /pull/.test(this.state))) {\n                        this.heartbeats = [];\n                    };\n                    this.transport.enterState(this.state, ia);\n                    if ((this.state == \"ping\")) {\n                        ya.url = l.getURI(ia).toString();\n                        ya.port = (ia.port || \"undefined\");\n                    }\n                ;\n                }\n            ;\n            }\n             else {\n                this.state = \"idle\";\n                this.nextState = sa;\n                ya = {\n                    state: this.state,\n                    delay: ta,\n                    nextState: sa\n                };\n                va[0] = (sa + \"#\");\n                this._deferredTransition = (function() {\n                    this._deferredTransition = null;\n                    this.enterState.apply(this, va);\n                }).bind(this).defer(ta, false);\n            }\n        ;\n            if (/pull/.test(sa)) {\n                ya.client_id = ia.sessionID;\n                ya.streaming = ia.inStreaming;\n            }\n        ;\n            ea.log((\"enter_\" + this.state), ya);\n            h.inform(j.ON_ENTER_STATE, ya);\n        },\n        exitState: function(sa, ta) {\n            var ua = sa.stateId, va = sa.status;\n            if ((this.isShutdown() || (ua < ja))) {\n                return\n            };\n            var wa = aa(arguments), xa = this.state;\n            wa[0] = sa.status;\n            var ya = {\n                state: xa,\n                status: va\n            };\n            if (/pull/.test(xa)) {\n                ya.client_id = ia.sessionID;\n                ya.streaming = ia.inStreaming;\n            }\n        ;\n            if (this.nextState) {\n                ya.nextState = this.nextState;\n            };\n            if ((ta && ta.errorType)) {\n                ya.xhr = (ta.toJSON ? ta.toJSON() : ta);\n                delete ya.xhr.json;\n            }\n        ;\n            if ((ta && ta.json)) {\n                if (ta.json.t) {\n                    ya.t = ta.json.t;\n                };\n                if (ta.json.reason) {\n                    ya.reason = ta.json.reason;\n                };\n                if (ta.json.seq) {\n                    ya.seq = ta.json.seq;\n                };\n            }\n        ;\n            ea.log((\"exit_\" + xa), ya);\n            h.inform(j.ON_EXIT_STATE, ya);\n            var za = this[(\"_exit_\" + xa)];\n            if (za) {\n                va = (za.apply(this, wa) || va);\n            };\n            if ((va != j.OK)) {\n                ra();\n                ka[xa] = (((ka[xa] || 0)) + 1);\n            }\n        ;\n            var ab = (ha[(this.nextState || xa)][va] || ha._all[va]), bb = (ab && ab.replace(/!*$/, \"\"));\n            if (!bb) {\n                ea.error(\"terminal_transition\", ya);\n                this._shutdownHint = j.HINT_INVALID_STATE;\n                ab = \"shutdown!\";\n            }\n        ;\n            this._lastState = xa;\n            this._lastStatus = va;\n            this.enterState(ab);\n        },\n        _processTransportData: function(sa, ta) {\n            var ua = ta.json, va = ua.t;\n            if ((\"s\" in ua)) {\n                ua.seq = ua.s;\n                delete ua.s;\n            }\n        ;\n            var wa = ia.seq;\n            if ((\"seq\" in ua)) {\n                ia.seq = ua.seq;\n                s.doSync();\n            }\n        ;\n            switch (va) {\n              case \"continue\":\n                if ((ia.inStreaming && (this.heartbeats.length < 1))) {\n                    ia.streamingCapable = false;\n                    ea.log(\"switch_to_longpoll\");\n                    setTimeout(this._probeTest, ia.PROBE_DELAY, false);\n                }\n            ;\n                ra(true);\n                if ((!ia.inStreaming || ia.STREAMING_EXIT_STATE_ON_CONTINUE)) {\n                    this.exitState({\n                        status: j.OK,\n                        stateId: sa\n                    });\n                };\n                break;\n              case \"refresh\":\n            \n              case \"refreshDelay\":\n                this.exitState({\n                    status: (\"refresh_\" + ((ua.reason || 0))),\n                    stateId: sa\n                }, ta);\n                break;\n              case \"fullReload\":\n                r.clear();\n                ea.log(\"invalid_history\");\n                h.inform(j.ON_INVALID_HISTORY);\n                this.exitState({\n                    status: j.ERROR_MISSING,\n                    stateId: sa\n                }, ta);\n                break;\n              case \"msg\":\n                var xa, ya, za, ab;\n                ra(true);\n                ya = ua.ms;\n                za = (ia.seq - ya.length);\n                for (xa = 0; (xa < ya.length); xa++, za++) {\n                    if ((za >= wa)) {\n                        ab = ya[xa];\n                        if (ab.type) {\n                            ea.debug(\"message\", {\n                                type: ab.type\n                            });\n                            h.inform(j.getArbiterType(ab.type), {\n                                obj: ab\n                            });\n                        }\n                    ;\n                    }\n                     else ea.warn(\"seq_regression\", {\n                        seq: za,\n                        last_seq: wa,\n                        messages: ya.length\n                    });\n                ;\n                };\n                break;\n              case \"heartbeat\":\n                if (ia.inStreaming) {\n                    var bb = Date.now();\n                    if ((this.heartbeats.length > 0)) {\n                        var cb = (bb - this.heartbeats[(this.heartbeats.length - 1)]);\n                        ea.log(\"heartbeat_interval\", {\n                            client_id: ia.sessionID,\n                            interval: cb\n                        });\n                    }\n                ;\n                    this.heartbeats.push(bb);\n                }\n            ;\n                break;\n              default:\n                ea.error(\"unknown_msg_type\", {\n                    type: va\n                });\n                break;\n            };\n        },\n        _enter_init: function() {\n            if ((ka.init >= da.getConfig(\"MAX_INIT_FAILS\", 2))) {\n                return this.exitState.bind(this, {\n                    status: j.ERROR_MAX,\n                    stateId: ja\n                }).defer()\n            };\n            this._initTimer = this.exitState.bind(this, {\n                status: j.ERROR,\n                stateId: ja\n            }, \"timeout\").defer(ia.IFRAME_LOAD_TIMEOUT, false);\n        },\n        _enter_reconnect: function(sa) {\n            var ta = ja;\n            if (!t.hasUserCookie()) {\n                ea.warn(\"no_user_cookie\");\n                (function() {\n                    da._shutdownHint = j.HINT_AUTH;\n                    da.exitState({\n                        status: j.ERROR_SHUTDOWN,\n                        stateId: ta\n                    });\n                }).defer();\n                return;\n            }\n        ;\n            var ua = {\n                reason: sa,\n                fb_dtsg: n.fb_dtsg\n            };\n            if (n.fb_isb) {\n                ua.fb_isb = n.fb_isb;\n            };\n            if (fa) {\n                fa(ua);\n            };\n            var va = new o(\"GET\", \"/ajax/presence/reconnect.php\", ua);\n            va.onSuccess = (function() {\n                da.configure(va.json);\n                r.store();\n                this.exitState({\n                    status: j.OK,\n                    stateId: ta\n                });\n            }).bind(this);\n            va.onError = (function() {\n                var wa = (va.json && va.json.error);\n                if (((va.errorType == g.TRANSPORT_ERROR) || (va.errorType == g.PROXY_ERROR))) {\n                    this._shutdownHint = j.HINT_CONN;\n                };\n                if ((wa && (wa == 1356007))) {\n                    this._shutdownHint = j.HINT_MAINT;\n                }\n                 else if ((((wa == 1357001) || (wa == 1357004)) || (wa == 1348009))) {\n                    this._shutdownHint = j.HINT_AUTH;\n                }\n                 else this._shutdownHint = null;\n                \n            ;\n                this.exitState({\n                    status: (this._shutdownHint ? j.ERROR_SHUTDOWN : j.ERROR),\n                    stateId: ta\n                }, va);\n            }).bind(this);\n            va.send();\n        },\n        _enter_shutdown: function() {\n            h.inform(j.ON_SHUTDOWN, {\n                reason: this._shutdownHint\n            });\n        },\n        _exit_init: function(sa) {\n            if (this._initTimer) {\n                this._initTimer = clearTimeout(this._initTimer);\n            };\n            if ((sa == j.ERROR_MAX)) {\n                this._sendIframeError(j.reason_IFrameLoadGiveUp);\n            };\n        },\n        _exit_pull: function(sa) {\n            if ((sa == j.OK)) {\n                this.lastPullTime = Date.now();\n            };\n        },\n        _exit_ping: function(sa) {\n            if ((sa == j.OK)) {\n                var ta = (Date.now() - ((this.lastPullTime || n.start)));\n                if ((ta > ia.STALL_THRESHOLD)) {\n                    return j.ERROR_STALE\n                };\n            }\n        ;\n        },\n        _probeTest: function() {\n            ia.streamingCapable = false;\n            var sa = [], ta = {\n                mode: \"stream\",\n                format: \"json\"\n            }, ua = new w(\"/probe\").setDomain((ia.host + \".facebook.com\")).setPort(ia.port).setSecure(w().isSecure()).setQueryData(ta), va = new g(\"GET\", ua);\n            va.onJSON = function(wa, xa) {\n                if (((wa && wa.json) && (wa.json.t === \"heartbeat\"))) {\n                    sa.push(Date.now());\n                    if ((sa.length >= 2)) {\n                        var ya = (sa[1] - sa[0]);\n                        if (((ya >= ia.PROBE_HEARTBEATS_INTERVAL_LOW) && (ya <= ia.PROBE_HEARTBEATS_INTERVAL_HIGH))) {\n                            ia.streamingCapable = true;\n                            ea.log(\"switch_to_streaming\");\n                        }\n                    ;\n                        ea.log(\"probe_ok\", {\n                            time: ya\n                        });\n                    }\n                ;\n                }\n            ;\n            };\n            va.onSuccess = function(wa) {\n                if ((sa.length != 2)) {\n                    ia.streamingCapable = false;\n                    ea.error(\"probe_error\", {\n                        error: (\"beats.length = \" + sa.length)\n                    });\n                }\n            ;\n            };\n            va.onError = function(wa) {\n                ia.streamingCapable = false;\n                ea.error(\"probe_error\", wa);\n            };\n            ea.log(\"probe_request\");\n            va.send();\n        }\n    };\n    e.exports = da;\n    if ((ca.serverInitialized == null)) {\n        da.configure(ca.channelConfig);\n        if (/shutdown/.test(ca.state)) {\n            da._shutdownHint = j[ca.reason];\n        }\n         else ca.reconnectReason;\n    ;\n        da.init(ca.state, ca.reason);\n    }\n;\n});\n__d(\"ChannelConnection\", [\"Arbiter\",\"copyProperties\",\"ChatConfig\",\"Run\",\"SystemEvents\",\"ChannelConstants\",\"ChannelManager\",\"JSLogger\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"copyProperties\"), i = b(\"ChatConfig\"), j = b(\"Run\"), k = b(\"SystemEvents\"), l = b(\"ChannelConstants\"), m = b(\"ChannelManager\"), n = b(\"JSLogger\"), o = n.create(\"channel_connection\"), p = null, q = null, r = null, s = null, t = 0, u = h(new g(), {\n        CONNECTED: \"chat-connection/connected\",\n        RECONNECTING: \"chat-connection/reconnecting\",\n        SHUTDOWN: \"chat-connection/shutdown\",\n        MUTE_WARNING: \"chat-connection/mute\",\n        UNMUTE_WARNING: \"chat-connection/unmute\"\n    });\n    function v() {\n        if (q) {\n            clearTimeout(q);\n            q = null;\n        }\n    ;\n    };\n    function w() {\n        v();\n        o.log(\"unmute_warning\");\n        u.inform(u.UNMUTE_WARNING);\n    };\n    function x(ba) {\n        v();\n        q = w.defer(ba, false);\n        o.log(\"mute_warning\", {\n            time: ba\n        });\n        u.inform(u.MUTE_WARNING);\n    };\n    function y() {\n        if (r) {\n            clearTimeout(r);\n            r = null;\n        }\n    ;\n    };\n    function z(ba, ca) {\n        y();\n        if (((ba === l.ON_ENTER_STATE) && (((ca.nextState || ca.state)) === \"pull\"))) {\n            if ((s !== u.CONNECTED)) {\n                o.log(\"connected\");\n                var da = !s;\n                s = u.CONNECTED;\n                t = 0;\n                u.inform(u.CONNECTED, {\n                    init: da\n                });\n            }\n        ;\n        }\n         else if (((ba === l.ON_ENTER_STATE) && (((((ca.nextState || ca.state)) === \"ping\") || ((!ca.nextState && (ca.state === \"idle\"))))))) {\n            r = (function() {\n                var ea = null;\n                if (!(((ca.state === \"idle\") && !ca.nextState))) {\n                    ea = ((ca.delay || 0));\n                };\n                o.log(\"reconnecting\", {\n                    delay: ea\n                });\n                if (u.disconnected()) {\n                    o.log(\"reconnecting_ui\", {\n                        delay: ea\n                    });\n                };\n                s = u.RECONNECTING;\n                (((ca.state === \"idle\")) && t++);\n                if ((t > 1)) {\n                    u.inform(u.RECONNECTING, ea);\n                }\n                 else if ((!ca.nextState && (ca.state === \"idle\"))) {\n                    z(ba, ca);\n                }\n            ;\n            }).defer(500, false);\n        }\n         else if ((ba === l.ON_SHUTDOWN)) {\n            o.log(\"shutdown\", {\n                reason: ca.reason\n            });\n            s = u.SHUTDOWN;\n            t = 0;\n            u.inform(u.SHUTDOWN, ca.reason);\n        }\n        \n        \n    ;\n    };\n    function aa(ba) {\n        if (((m.state === \"ping\") || m.isShutdown())) {\n            return\n        };\n        o.log(\"reconnect\", {\n            now: ba\n        });\n        u.inform(u.RECONNECTING, 0);\n        if (!!ba) {\n            if ((p !== null)) {\n                clearTimeout(p);\n                p = null;\n            }\n        ;\n            m.enterState(\"ping!\");\n        }\n         else if (!p) {\n            p = setTimeout(function() {\n                m.enterState(\"ping!\");\n                p = null;\n            }, i.get(\"channel_manual_reconnect_defer_msec\"), false);\n        }\n    ;\n    };\n    if (m.isShutdown()) {\n        z(l.ON_SHUTDOWN, m._shutdownHint);\n    }\n     else z(l.ON_ENTER_STATE, {\n        state: m.state,\n        nextState: m.nextState,\n        delay: 0\n    });\n;\n    g.subscribe([l.ON_ENTER_STATE,l.ON_SHUTDOWN,], z);\n    k.subscribe(k.TIME_TRAVEL, function() {\n        aa();\n        x(i.get(\"mute_warning_time_msec\"));\n    });\n    j.onBeforeUnload(y, false);\n    h(u, {\n        disconnected: function() {\n            return ((s === u.SHUTDOWN) || ((((s === u.RECONNECTING) && !q) && (t > 1))));\n        },\n        isShutdown: function() {\n            return (s === u.SHUTDOWN);\n        },\n        reconnect: aa,\n        unmuteWarning: w\n    });\n    e.exports = u;\n});\n__d(\"legacy:ChannelConstants\", [\"ChannelConstants\",], function(a, b, c, d) {\n    a.ChannelConstants = b(\"ChannelConstants\");\n}, 3);\n__d(\"AvailableListConstants\", [], function(a, b, c, d, e, f) {\n    var g = {\n        ON_AVAILABILITY_CHANGED: \"buddylist/availability-changed\",\n        ON_UPDATE_ERROR: \"buddylist/update-error\",\n        ON_UPDATED: \"buddylist/updated\",\n        ON_CHAT_NOTIFICATION_CHANGED: \"chat-notification-changed\",\n        OFFLINE: 0,\n        IDLE: 1,\n        ACTIVE: 2,\n        MOBILE: 3,\n        LEGACY_OVERLAY_OFFLINE: -1,\n        LEGACY_OVERLAY_ONLINE: 0,\n        LEGACY_OVERLAY_IDLE: 1,\n        legacyStatusMap: {\n            0: 2,\n            1: 1,\n            \"-1\": 0,\n            2: 3\n        },\n        reverseLegacyStatusMap: {\n            0: -1,\n            1: 1,\n            2: 0,\n            3: 2\n        }\n    };\n    window.AvailableListConstants = e.exports = g;\n}, 3);\n__d(\"PresencePrivacy\", [\"hasArrayNature\",\"Arbiter\",\"AsyncRequest\",\"ChannelConstants\",\"copyProperties\",\"Env\",\"JSLogger\",\"PresenceUtil\",\"PresencePrivacyInitialData\",], function(a, b, c, d, e, f) {\n    var g = b(\"hasArrayNature\"), h = b(\"Arbiter\"), i = b(\"AsyncRequest\"), j = b(\"ChannelConstants\"), k = b(\"copyProperties\"), l = b(\"Env\"), m = b(\"JSLogger\"), n = b(\"PresenceUtil\"), o = c(\"PresencePrivacyInitialData\"), p = \"/ajax/chat/privacy/settings.php\", q = \"/ajax/chat/privacy/online_policy.php\", r = \"/ajax/chat/privacy/visibility.php\", s = \"friend_visibility\", t = \"visibility\", u = \"online_policy\", v = k({\n    }, o.privacyData), w = o.visibility, x = k({\n    }, o.privacyData), y = w, z = o.onlinePolicy, aa = z, ba = [], ca = false;\n    function da() {\n        return m.create(\"blackbird\");\n    };\n    var ea = k(new h(), {\n        WHITELISTED: 1,\n        BLACKLISTED: -1,\n        UNLISTED: 0,\n        ONLINE: 1,\n        OFFLINE: 0,\n        ONLINE_TO_WHITELIST: 0,\n        ONLINE_TO_BLACKLIST: 1\n    });\n    function fa(ra) {\n        var sa;\n        for (sa in ra) {\n            var ta = ra[sa];\n            if ((sa == l.user)) {\n                da().error(\"set_viewer_visibility\");\n                throw new Error(\"Invalid to set current user's visibility\");\n            }\n        ;\n            switch (ta) {\n              case ea.WHITELISTED:\n            \n              case ea.BLACKLISTED:\n            \n              case ea.UNLISTED:\n                break;\n              default:\n                da().error(\"set_invalid_friend_visibility\", {\n                    id: sa,\n                    value: ta\n                });\n                throw new Error((\"Invalid state: \" + ta));\n            };\n        };\n        for (sa in ra) {\n            v[sa] = ra[sa];;\n        };\n        ea.inform(\"privacy-changed\");\n    };\n    function ga(ra, sa) {\n        var ta = {\n        };\n        ta[ra] = sa;\n        fa(ta);\n    };\n    function ha(ra) {\n        switch (ra) {\n          case ea.ONLINE:\n        \n          case ea.OFFLINE:\n            break;\n          default:\n            da().error(\"set_invalid_visibility\", {\n                value: ra\n            });\n            throw new Error((\"Invalid visibility: \" + ra));\n        };\n        w = ra;\n        ea.inform(\"privacy-changed\");\n        ea.inform(\"privacy-user-presence-changed\");\n        h.inform(\"chat/visibility-changed\", {\n            sender: this\n        });\n    };\n    function ia(ra) {\n        switch (ra) {\n          case ea.ONLINE_TO_WHITELIST:\n        \n          case ea.ONLINE_TO_BLACKLIST:\n            break;\n          default:\n            throw new Error((\"Invalid default online policy: \" + ra));\n        };\n        z = ra;\n        ea.inform(\"privacy-user-presence-changed\");\n        ea.inform(\"privacy-changed\");\n    };\n    function ja(ra, sa) {\n        ca = true;\n        ra.send();\n    };\n    function ka(ra, sa) {\n        ba.push({\n            request: ra,\n            data: sa\n        });\n        if (!ca) {\n            var ta = ba.shift();\n            ja(ta.request, ta.data);\n        }\n    ;\n    };\n    function la(ra, sa) {\n        var ta = ra.type;\n        if ((ta === s)) {\n            var ua = sa.payload.user_availabilities;\n            if (!g(ua)) {\n                ea.inform(\"privacy-availability-changed\", {\n                    user_availabilities: ua\n                });\n                for (var va in ra.settings) {\n                    x[va] = ra.settings[va];;\n                };\n            }\n        ;\n        }\n         else {\n            if ((ta === t)) {\n                y = ra.visibility;\n            }\n             else if ((ta === u)) {\n                aa = ra.online_policy;\n            }\n        ;\n            ea.inform(\"privacy-user-presence-response\");\n        }\n    ;\n        da().log(\"set_update_response\", {\n            data: ra,\n            response: sa\n        });\n    };\n    function ma(ra, sa) {\n        if ((w !== y)) {\n            ha(y);\n        };\n        if ((z !== aa)) {\n            ia(aa);\n        };\n        k(v, x);\n        ea.inform(\"privacy-changed\");\n        ba = [];\n        da().log(\"set_error_response\", {\n            data: ra,\n            response: sa\n        });\n    };\n    function na(ra) {\n        ca = false;\n        if ((ba.length > 0)) {\n            var sa = ba.shift();\n            ja(sa.request, sa.data);\n        }\n    ;\n    };\n    function oa(ra, sa) {\n        if ((n != null)) {\n            var ta = ra.getData();\n            ta.window_id = n.getSessionID();\n            ra.setData(ta);\n        }\n    ;\n        ra.setHandler(la.bind(this, sa)).setErrorHandler(ma.bind(this, sa)).setTransportErrorHandler(ma.bind(this, sa)).setFinallyHandler(na.bind(this)).setAllowCrossPageTransition(true);\n        return ra;\n    };\n    function pa(ra, sa, ta) {\n        return oa(new i(ra).setData(sa), ta);\n    };\n    function qa(ra, sa) {\n        var ta = sa.obj;\n        if ((ta.viewer_id != l.user)) {\n            da().error(\"invalid_viewer_for_channel_message\", {\n                type: ra,\n                data: sa\n            });\n            throw new Error(\"Viewer got from the channel is not the real viewer\");\n        }\n    ;\n        if ((ta.window_id === n.getSessionID())) {\n            return\n        };\n        var ua = ta.data;\n        if ((ta.event == \"access_control_entry\")) {\n            ua.target_ids.forEach(function(wa) {\n                ga(wa, ua.setting);\n                x[wa] = ua.setting;\n            });\n        }\n         else {\n            if ((ta.event == \"visibility_update\")) {\n                var va = (!!ua.visibility ? ea.ONLINE : ea.OFFLINE);\n                ha(va);\n                y = va;\n            }\n             else if ((ta.event == \"online_policy_update\")) {\n                ia(ua.online_policy);\n                aa = ua.online_policy;\n            }\n            \n        ;\n            ea.inform(\"privacy-user-presence-response\");\n        }\n    ;\n        da().log(\"channel_message_received\", {\n            data: sa.obj\n        });\n    };\n    k(ea, {\n        WHITELISTED: 1,\n        BLACKLISTED: -1,\n        UNLISTED: 0,\n        ONLINE: 1,\n        OFFLINE: 0,\n        ONLINE_TO_WHITELIST: 0,\n        ONLINE_TO_BLACKLIST: 1,\n        init: function(ra, sa, ta) {\n        \n        },\n        setVisibility: function(ra) {\n            y = w;\n            ha(ra);\n            var sa = {\n                visibility: ra\n            }, ta = {\n                type: t,\n                visibility: ra\n            }, ua = pa(r, sa, ta);\n            ka(ua, ta);\n            da().log(\"set_visibility\", {\n                data: sa\n            });\n            return ra;\n        },\n        getVisibility: function() {\n            return w;\n        },\n        setOnlinePolicy: function(ra) {\n            aa = z;\n            ia(ra);\n            var sa = {\n                online_policy: ra\n            }, ta = {\n                type: u,\n                online_policy: ra\n            }, ua = pa(q, sa, ta);\n            ka(ua, ta);\n            da().log(\"set_online_policy\", {\n                data: sa\n            });\n            return ra;\n        },\n        getOnlinePolicy: function() {\n            return z;\n        },\n        getFriendVisibility: function(ra) {\n            return (v[ra] || ea.UNLISTED);\n        },\n        allows: function(ra) {\n            if ((this.getVisibility() === ea.OFFLINE)) {\n                return false\n            };\n            var sa = this.getOnlinePolicy();\n            return ((sa === ea.ONLINE_TO_WHITELIST) ? (v[ra] == ea.WHITELISTED) : (v[ra] != ea.BLACKLISTED));\n        },\n        setFriendsVisibility: function(ra, sa) {\n            if ((ra.length > 0)) {\n                var ta = {\n                };\n                for (var ua = 0; (ua < ra.length); ua++) {\n                    var va = ra[ua];\n                    x[va] = v[va];\n                    ta[va] = sa;\n                };\n                fa(ta);\n                var wa = sa;\n                if ((wa == ea.UNLISTED)) {\n                    wa = x[ra[0]];\n                };\n                var xa = {\n                    users: ra,\n                    setting: sa,\n                    setting_type: wa\n                }, ya = {\n                    type: s,\n                    settings: ta\n                }, za = pa(p, xa, ya);\n                ka(za, ya);\n                da().log(\"set_friend_visibility\", {\n                    data: xa\n                });\n            }\n        ;\n            return sa;\n        },\n        setFriendVisibilityMap: function(ra, sa) {\n            for (var ta in ra) {\n                x[ta] = v[ta];;\n            };\n            fa(ra);\n            var ua = {\n                type: s,\n                settings: ra\n            };\n            ka(oa(sa, ua), ua);\n            da().log(\"set_friend_visibility_from_map\", {\n                data: ra\n            });\n        },\n        allow: function(ra) {\n            if (this.allows(ra)) {\n                da().error(\"allow_already_allowed\");\n                throw new Error((\"allow() should only be called for users that \" + \"are not already allowed\"));\n            }\n        ;\n            if ((this.getVisibility() === ea.OFFLINE)) {\n                da().error(\"allow_called_while_offline\");\n                throw new Error(\"allow() should only be called when the user is already online\");\n            }\n        ;\n            var sa = ((this.getOnlinePolicy() === ea.ONLINE_TO_WHITELIST) ? ea.WHITELISTED : ea.UNLISTED);\n            return this.setFriendsVisibility([ra,], sa);\n        },\n        disallow: function(ra) {\n            if (!this.allows(ra)) {\n                da().error(\"disallow_already_disallowed\");\n                throw new Error((\"disallow() should only be called for users that \" + \"are not already disallowed\"));\n            }\n        ;\n            if ((this.getVisibility() === ea.OFFLINE)) {\n                da().error(\"disallow_called_while_offline\");\n                throw new Error(\"disallow() should only be called when the user is already online\");\n            }\n        ;\n            var sa = ((this.getOnlinePolicy() === ea.ONLINE_TO_BLACKLIST) ? ea.BLACKLISTED : ea.UNLISTED);\n            return this.setFriendsVisibility([ra,], sa);\n        },\n        getBlacklist: function() {\n            var ra = [];\n            for (var sa in v) {\n                if ((v[sa] === ea.BLACKLISTED)) {\n                    ra.push(sa);\n                };\n            };\n            return ra;\n        },\n        getWhitelist: function() {\n            var ra = [];\n            for (var sa in v) {\n                if ((v[sa] === ea.WHITELISTED)) {\n                    ra.push(sa);\n                };\n            };\n            return ra;\n        },\n        getMapForTest: function() {\n            return v;\n        },\n        setMapForTest: function(ra) {\n            v = ra;\n        }\n    });\n    ea.inform(\"privacy-changed\");\n    ea.inform(\"privacy-user-presence-changed\");\n    da().log(\"initialized\", {\n        visibility: w,\n        policy: z\n    });\n    h.subscribe(j.getArbiterType(\"privacy_changed\"), qa.bind(this));\n    h.subscribe(j.ON_CONFIG, function(ra, sa) {\n        var ta = sa.getConfig(\"visibility\", null);\n        if (((ta !== null) && (typeof (ta) !== \"undefined\"))) {\n            var ua = (ta ? ea.ONLINE : ea.OFFLINE);\n            ha(ua);\n            da().log(\"config_visibility\", {\n                vis: ua\n            });\n        }\n    ;\n    }.bind(this));\n    a.PresencePrivacy = e.exports = ea;\n}, 3);\n__d(\"Chat\", [\"Arbiter\",\"AsyncSignal\",\"JSLogger\",\"PresencePrivacy\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AsyncSignal\"), i = b(\"JSLogger\"), j = b(\"PresencePrivacy\");\n    function k(o, p, q) {\n        if (((((p && (p == \"ordered_list\")) || (p == \"more_online_friends\")) || (p == \"online_friends\")) || (p == \"typeahead\"))) {\n            var r = {\n                target: o,\n                source: p,\n                sorted_list: q\n            };\n            new h(\"/ajax/chat/ct.php\", r).send();\n        }\n    ;\n    };\n    var l = {\n        buddyListNub: \"buddylist-nub/initialized\",\n        sidebar: \"sidebar/initialized\"\n    };\n    function m(o, p) {\n        g.subscribe(l[o], function(event, q) {\n            p(q);\n        });\n    };\n    var n = {\n        openTab: function(o, p, q, r, s) {\n            if (((window.External && window.External.Chat) && window.External.Chat.openWindow)) {\n                window.External.Chat.openWindow(o);\n            };\n            k(o, r, s);\n            d([\"MercuryThreads\",], function(t) {\n                if ((!q || (q == \"friend\"))) {\n                    var u = t.getCanonicalThreadToUser(o);\n                    g.inform(\"chat/open-tab\", {\n                        thread_id: u.thread_id\n                    });\n                }\n            ;\n            });\n        },\n        openBuddyList: function() {\n            m(\"buddyListNub\", function(o) {\n                o.show();\n                m(\"sidebar\", function(p) {\n                    p.enable();\n                });\n            });\n        },\n        closeBuddyList: function() {\n            m(\"buddyListNub\", function(o) {\n                o.hide();\n            });\n        },\n        toggleSidebar: function() {\n            m(\"sidebar\", function(o) {\n                o.toggle();\n            });\n        },\n        goOnline: function(o) {\n            d([\"ChatVisibility\",], function(p) {\n                p.goOnline(o);\n            });\n        },\n        isOnline: function() {\n            var o = null;\n            d([\"ChatVisibility\",], function(p) {\n                o = p;\n            });\n            return (o && o.isOnline());\n        }\n    };\n    a.Chat = e.exports = n;\n}, 3);\n__d(\"ChatVisibility\", [\"ChatConfig\",\"JSLogger\",\"PresencePrivacy\",], function(a, b, c, d, e, f) {\n    var g = b(\"ChatConfig\"), h = b(\"JSLogger\"), i = b(\"PresencePrivacy\"), j = {\n        isOnline: function() {\n            return (i.getVisibility() === i.ONLINE);\n        },\n        goOnline: function(k) {\n            if ((i.getVisibility() === i.OFFLINE)) {\n                h.create(\"blackbird\").log(\"chat_go_online\");\n                i.setVisibility(i.ONLINE);\n            }\n        ;\n            (k && k());\n        },\n        goOffline: function(k) {\n            if ((i.getVisibility() === i.ONLINE)) {\n                h.create(\"blackbird\").log(\"chat_go_offline\");\n                i.setVisibility(i.OFFLINE);\n            }\n        ;\n            (k && k());\n        },\n        toggleVisibility: function() {\n            if (j.isOnline()) {\n                j.goOffline();\n            }\n             else j.goOnline();\n        ;\n        }\n    };\n    a.ChatVisibility = e.exports = j;\n}, 3);\n__d(\"ServerTime\", [\"PresenceInitialData\",], function(a, b, c, d, e, f) {\n    var g = c(\"PresenceInitialData\"), h;\n    function i(k) {\n        h = (Date.now() - k);\n    };\n    i(g.serverTime);\n    var j = {\n        get: function() {\n            return (Date.now() - h);\n        },\n        getSkew: function() {\n            return h;\n        },\n        update: function(k) {\n            i(k);\n        }\n    };\n    e.exports = j;\n});\n__d(\"CallbackManagerController\", [\"ErrorUtils\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"ErrorUtils\"), h = b(\"copyProperties\"), i = function(j) {\n        this._pendingIDs = [];\n        this._allRequests = [undefined,];\n        this._callbackArgHandler = j;\n    };\n    h(i.prototype, {\n        executeOrEnqueue: function(j, k, l) {\n            l = (l || {\n            });\n            var m = this._attemptCallback(k, j, l);\n            if (m) {\n                return 0\n            };\n            this._allRequests.push({\n                fn: k,\n                request: j,\n                options: l\n            });\n            var n = (this._allRequests.length - 1);\n            this._pendingIDs.push(n);\n            return n;\n        },\n        unsubscribe: function(j) {\n            delete this._allRequests[j];\n        },\n        getRequest: function(j) {\n            return this._allRequests[j];\n        },\n        runPossibleCallbacks: function() {\n            var j = this._pendingIDs;\n            this._pendingIDs = [];\n            var k = [];\n            j.forEach(function(l) {\n                var m = this._allRequests[l];\n                if (!m) {\n                    return\n                };\n                if (this._callbackArgHandler(m.request, m.options)) {\n                    k.push(l);\n                }\n                 else this._pendingIDs.push(l);\n            ;\n            }.bind(this));\n            k.forEach(function(l) {\n                var m = this._allRequests[l];\n                delete this._allRequests[l];\n                this._attemptCallback(m.fn, m.request, m.options);\n            }.bind(this));\n        },\n        _attemptCallback: function(j, k, l) {\n            var m = this._callbackArgHandler(k, l);\n            if (m) {\n                var n = {\n                    ids: k\n                };\n                g.applyWithGuard(j, n, [m,]);\n            }\n        ;\n            return !!m;\n        }\n    });\n    e.exports = i;\n});\n__d(\"KeyedCallbackManager\", [\"CallbackManagerController\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"CallbackManagerController\"), h = b(\"copyProperties\"), i = function() {\n        this._resources = {\n        };\n        this._controller = new g(this._constructCallbackArg.bind(this));\n    };\n    h(i.prototype, {\n        executeOrEnqueue: function(j, k) {\n            if (!((j instanceof Array))) {\n                var l = j, m = k;\n                j = [j,];\n                k = function(n) {\n                    m(n[l]);\n                };\n            }\n        ;\n            return this._controller.executeOrEnqueue(j, k);\n        },\n        unsubscribe: function(j) {\n            this._controller.unsubscribe(j);\n        },\n        getUnavailableResources: function(j) {\n            var k = this._controller.getRequest(j), l = [];\n            if (k) {\n                l = k.request.filter(function(m) {\n                    return !this._resources[m];\n                }.bind(this));\n            };\n            return l;\n        },\n        addResourcesAndExecute: function(j) {\n            h(this._resources, j);\n            this._controller.runPossibleCallbacks();\n        },\n        setResource: function(j, k) {\n            this._resources[j] = k;\n            this._controller.runPossibleCallbacks();\n        },\n        getResource: function(j) {\n            return this._resources[j];\n        },\n        getAllResources: function() {\n            return this._resources;\n        },\n        dumpResources: function() {\n            var j = {\n            };\n            for (var k in this._resources) {\n                var l = this._resources[k];\n                if ((typeof l === \"object\")) {\n                    l = h({\n                    }, l);\n                };\n                j[k] = l;\n            };\n            return j;\n        },\n        _constructCallbackArg: function(j) {\n            var k = {\n            };\n            for (var l = 0; (l < j.length); l++) {\n                var m = j[l], n = this._resources[m];\n                if ((typeof n == \"undefined\")) {\n                    return false\n                };\n                k[m] = n;\n            };\n            return k;\n        }\n    });\n    e.exports = i;\n});\n__d(\"AsyncLoader\", [\"AsyncRequest\",\"KeyedCallbackManager\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncRequest\"), h = b(\"KeyedCallbackManager\"), i = b(\"copyProperties\"), j = {\n    };\n    function k(m, n) {\n        var o = new h(), p = false, q = [];\n        function r() {\n            if ((!q.length || p)) {\n                return\n            };\n            p = true;\n            t.defer();\n        };\n        function s(w) {\n            p = false;\n            w.forEach(o.unsubscribe.bind(o));\n            r();\n        };\n        function t() {\n            var w = {\n            }, x = [];\n            q = q.filter(function(z) {\n                var aa = o.getUnavailableResources(z);\n                if (aa.length) {\n                    aa.forEach(function(ba) {\n                        w[ba] = true;\n                    });\n                    x.push(z);\n                    return true;\n                }\n            ;\n                return false;\n            });\n            var y = Object.keys(w);\n            if (y.length) {\n                new g(m).setData({\n                    ids: y\n                }).setHandler(u.curry(x)).setErrorHandler(v.curry(x)).setAllowCrossPageTransition(true).setMethod(\"GET\").setReadOnly(true).send();\n            }\n             else p = false;\n        ;\n        };\n        function u(w, x) {\n            var y = (x.payload[n] || x.payload);\n            o.addResourcesAndExecute(y);\n            s(w);\n        };\n        function v(w) {\n            s(w);\n        };\n        return {\n            get: function(w, x) {\n                var y = o.executeOrEnqueue(w, x), z = o.getUnavailableResources(y);\n                if (z.length) {\n                    q.push(y);\n                    r();\n                }\n            ;\n            },\n            getCachedKeys: function() {\n                return Object.keys(o.getAllResources());\n            },\n            getNow: function(w) {\n                return (o.getResource(w) || null);\n            },\n            set: function(w) {\n                o.addResourcesAndExecute(w);\n            }\n        };\n    };\n    function l(m, n) {\n        this._endpoint = m;\n        this._type = n;\n    };\n    i(l.prototype, {\n        _getLoader: function() {\n            if (!j[this._endpoint]) {\n                j[this._endpoint] = k(this._endpoint, this._type);\n            };\n            return j[this._endpoint];\n        },\n        get: function(m, n) {\n            return this._getLoader().get(m, n);\n        },\n        getCachedKeys: function() {\n            return this._getLoader().getCachedKeys();\n        },\n        getNow: function(m) {\n            return this._getLoader().getNow(m);\n        },\n        reset: function() {\n            j[this._endpoint] = null;\n        },\n        set: function(m) {\n            this._getLoader().set(m);\n        }\n    });\n    e.exports = l;\n});\n__d(\"ShortProfiles\", [\"ArbiterMixin\",\"AsyncLoader\",\"AsyncRequest\",\"Env\",\"JSLogger\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"ArbiterMixin\"), h = b(\"AsyncLoader\"), i = b(\"AsyncRequest\"), j = b(\"Env\"), k = b(\"JSLogger\"), l = b(\"copyProperties\"), m = \"/ajax/chat/user_info.php\", n = \"/ajax/chat/user_info_all.php\", o = new h(m, \"profiles\"), p = false, q = k.create(\"short_profiles\");\n    function r() {\n        if (!p) {\n            q.log(\"fetch_all\");\n            p = true;\n            new i(n).setData({\n                viewer: j.user\n            }).setHandler(function(u) {\n                o.set(u.payload);\n                t.inform(\"updated\");\n            }).setAllowCrossPageTransition(true).setMethod(\"GET\").setReadOnly(true).send();\n        }\n    ;\n    };\n    function s(u) {\n        return JSON.parse(JSON.stringify(u));\n    };\n    var t = {\n    };\n    l(t, g, {\n        get: function(u, v) {\n            this.getMulti([u,], function(w) {\n                v(w[u], u);\n            });\n        },\n        getMulti: function(u, v) {\n            function w(x) {\n                v(s(x));\n            };\n            o.get(u, w);\n        },\n        getNow: function(u) {\n            return s((o.getNow(u) || null));\n        },\n        getCachedProfileIDs: function() {\n            return o.getCachedKeys();\n        },\n        hasAll: function() {\n            return p;\n        },\n        fetchAll: function() {\n            r();\n        },\n        set: function(u, v) {\n            var w = {\n            };\n            w[u] = v;\n            this.setMulti(w);\n        },\n        setMulti: function(u) {\n            o.set(s(u));\n        }\n    });\n    e.exports = t;\n});\n__d(\"AvailableList\", [\"function-extensions\",\"Arbiter\",\"ArbiterMixin\",\"AsyncRequest\",\"AvailableListConstants\",\"ChannelConstants\",\"Chat\",\"ChatConfig\",\"ChatVisibility\",\"Class\",\"Env\",\"JSLogger\",\"Poller\",\"PresencePrivacy\",\"PresenceUtil\",\"ServerTime\",\"ShortProfiles\",\"UserActivity\",\"copyProperties\",\"createObjectFrom\",\"debounceAcrossTransitions\",\"ChannelImplementation\",\"AvailableListInitialData\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"AsyncRequest\"), j = b(\"AvailableListConstants\"), k = b(\"ChannelConstants\"), l = b(\"Chat\"), m = b(\"ChatConfig\"), n = b(\"ChatVisibility\"), o = b(\"Class\"), p = b(\"Env\"), q = b(\"JSLogger\"), r = b(\"Poller\"), s = b(\"PresencePrivacy\"), t = b(\"PresenceUtil\"), u = b(\"ServerTime\"), v = b(\"ShortProfiles\"), w = b(\"UserActivity\"), x = b(\"copyProperties\"), y = b(\"createObjectFrom\"), z = b(\"debounceAcrossTransitions\"), aa = c(\"ChannelImplementation\").instance, ba = c(\"AvailableListInitialData\"), ca = 5, da = 60000, ea = \"/ajax/chat/buddy_list.php\", fa = 5000, ga = 1800000, ha = 45821, ia = 0, ja = 0, ka = false, la = ba.pollInterval, ma = ba.lazyPollInterval, na = ba.lazyThreshold, oa = 0, pa = Date.now(), qa = 0, ra = false, sa = {\n    }, ta = false, ua = {\n    }, va = null, wa = {\n    }, xa = {\n    }, ya = q.create(\"available_list\"), za = x({\n    }, j, h);\n    za.subscribe([j.ON_AVAILABILITY_CHANGED,j.ON_UPDATE_ERROR,j.ON_UPDATED,], function(sb, tb) {\n        g.inform(sb, tb);\n    });\n    function ab(sb) {\n        var tb = (sb || w.isActive(na));\n        return (n.isOnline() ? ((tb ? la : ma)) : null);\n    };\n    function bb() {\n        za.inform(j.ON_AVAILABILITY_CHANGED);\n    };\n    var cb = z(bb, 0);\n    function db(sb, tb, ub, vb) {\n        if ((sb == p.user)) {\n            return\n        };\n        switch (tb) {\n          case j.OFFLINE:\n        \n          case j.IDLE:\n        \n          case j.ACTIVE:\n        \n          case j.MOBILE:\n            break;\n          default:\n            return;\n        };\n        var wb = (za.get(sb) != tb);\n        if (ub) {\n            wa[sb] = u.get();\n            xa[sb] = vb;\n        }\n    ;\n        sa[sb] = tb;\n        if (wb) {\n            ia++;\n            cb();\n        }\n    ;\n    };\n    function eb(sb) {\n        qa = Date.now();\n        ua = y(sb);\n        ia++;\n        cb();\n    };\n    function fb() {\n        if (ra) {\n            za.inform(j.ON_UPDATED, za);\n        };\n    };\n    function gb(sb) {\n        if (t.checkMaintenanceError(sb)) {\n            return\n        };\n        ja++;\n        ka = false;\n        if ((ja >= ca)) {\n            za.inform(j.ON_UPDATE_ERROR);\n        };\n    };\n    function hb(sb) {\n        var tb = sb.getPayload(), ub = tb.buddy_list;\n        if (!ub) {\n            gb(sb);\n            return;\n        }\n    ;\n        u.update(tb.time);\n        oa = u.get();\n        ja = 0;\n        ka = false;\n        if ((ub.mobile_friends != null)) {\n            eb(ub.mobile_friends);\n        };\n        var vb = ub.userInfos;\n        if (vb) {\n            v.setMulti(vb);\n        };\n        nb();\n        ta = ub.userIsIdle;\n        var wb = ub.nowAvailableList;\n        (wb && lb(wb));\n        if ((ub.chatNotif !== undefined)) {\n            va = ub.chatNotif;\n            za.inform(j.ON_CHAT_NOTIFICATION_CHANGED, va);\n        }\n    ;\n        mb();\n        fb();\n        cb();\n    };\n    function ib(sb) {\n        if ((aa.isShutdown() || !n.isOnline())) {\n            za._poller.stop();\n            return;\n        }\n    ;\n        pa = Date.now();\n        var tb = false;\n        if (((Date.now() - qa) > ga)) {\n            tb = true;\n        };\n        ka = true;\n        var ub = v.getCachedProfileIDs();\n        sb.setHandler(hb).setErrorHandler(gb).setOption(\"suppressErrorAlerts\", true).setOption(\"retries\", 1).setData({\n            user: p.user,\n            available_user_info_ids: ub,\n            fetch_mobile: tb\n        }).setURI(ea).setAllowCrossPageTransition(true);\n    };\n    function jb(sb) {\n        var tb = (sb.payload.availability || {\n        });\n        for (var ub in tb) {\n            db(ub, tb[ub], true, \"mercury_tabs\");;\n        };\n    };\n    function kb(sb) {\n        var tb = za.getDebugInfo(sb), ub = ((tb.presence == j.ACTIVE)), vb = new i(\"/ajax/mercury/tabs_presence.php\").setData({\n            target_id: sb,\n            to_online: ub,\n            presence_source: tb.overlaySource,\n            presence_time: tb.overlayTime\n        }).setHandler(jb).setErrorHandler(bagofholding).setAllowCrossPageTransition(true).send();\n    };\n    function lb(sb) {\n        for (var tb in sb) {\n            db(tb, sb[tb].a, false, null);;\n        };\n        ra = true;\n    };\n    function mb(sb) {\n        var tb = ab(sb);\n        ya.debug(\"update_poller\", tb);\n        (za._poller && za._poller.setTimePeriod(tb));\n    };\n    function nb() {\n        ra = false;\n        sa = {\n        };\n        xa = {\n        };\n        wa = {\n        };\n        ia++;\n    };\n    function ob() {\n        nb();\n        pa = 0;\n        qa = 0;\n        ta = false;\n        va = null;\n        ua = {\n        };\n        bb();\n    };\n    function pb() {\n        mb();\n        if (n.isOnline()) {\n            za.update();\n        }\n         else ob();\n    ;\n    };\n    function qb() {\n        mb();\n        if (aa.disconnected()) {\n            ob();\n        }\n         else if (!ra) {\n            za.update();\n        }\n    ;\n    };\n    function rb(sb, tb) {\n        tb.chat_config = m.getDebugInfo();\n        tb.available_list_debug_info = {\n        };\n        za.getAvailableIDs().forEach(function(ub) {\n            tb.available_list_debug_info[ub] = za.getDebugInfo(ub);\n        });\n        tb.available_list_poll_interval = (za._poller && za._poller.getTimePeriod());\n    };\n    x(za, {\n        get: function(sb) {\n            if ((sb == p.user)) {\n                return (n.isOnline() ? j.ACTIVE : j.OFFLINE)\n            };\n            var tb = j.OFFLINE;\n            if ((sb in sa)) {\n                tb = sa[sb];\n            };\n            if (!s.allows(sb)) {\n                tb = j.OFFLINE;\n            };\n            if ((tb == j.OFFLINE)) {\n                if (ua[sb]) {\n                    tb = j.MOBILE;\n                }\n            };\n            return tb;\n        },\n        updateForID: function(sb) {\n            kb(sb);\n        },\n        getWebChatNotification: function() {\n            return va;\n        },\n        isUserIdle: function() {\n            return ta;\n        },\n        isReady: function() {\n            return ra;\n        },\n        set: function(sb, tb, ub) {\n            db(sb, tb, true, null, ub);\n        },\n        update: function() {\n            if (((Date.now() - pa) < fa)) {\n                (!ka && fb.defer());\n                return;\n            }\n        ;\n            (za._poller && za._poller.requestNow());\n        },\n        getRev: function() {\n            return ia;\n        },\n        isIdle: function(sb) {\n            return (za.get(sb) == j.IDLE);\n        },\n        getOnlineIDs: function() {\n            var sb, tb = [];\n            for (sb in sa) {\n                if ((za.get(sb) === j.ACTIVE)) {\n                    tb.push(sb);\n                };\n            };\n            return tb;\n        },\n        getAvailableIDs: function() {\n            var sb = za.getOnlineIDs(), tb;\n            for (tb in ua) {\n                if (sa[tb]) {\n                    continue;\n                };\n                sb.push(tb);\n            };\n            return sb;\n        },\n        getOnlineCount: function() {\n            return za.getOnlineIDs().length;\n        },\n        getDebugInfo: function(sb) {\n            var tb;\n            if (window.ShortProfiles) {\n                var ub = v.getNow(sb);\n                if (ub) {\n                    tb = ub.name;\n                };\n            }\n        ;\n            return {\n                id: sb,\n                presence: sa[sb],\n                overlaySource: xa[sb],\n                overlayTime: wa[sb],\n                overlaySource: xa[sb],\n                mobile: ua[sb],\n                name: tb\n            };\n        }\n    });\n    oa = ba.updateTime;\n    lb(ba.availableList);\n    if (ba.mobileFriends) {\n        eb(ba.mobileFriends);\n    };\n    va = ba.chatNotif;\n    za._poller = new r(ab(), ib, true);\n    mb(true);\n    g.subscribe(q.DUMP_EVENT, rb);\n    w.subscribe(function(sb, tb) {\n        if ((tb.idleness > la)) {\n            ya.debug(\"update_activity\");\n            za.update();\n        }\n    ;\n    });\n    s.subscribe(\"privacy-changed\", bb);\n    s.subscribe(\"privacy-availability-changed\", function(sb, tb) {\n        for (var ub in tb.user_availabilities) {\n            this.set(ub, tb.user_availabilities[ub]);;\n        };\n    }.bind(za));\n    s.subscribe(\"privacy-user-presence-response\", za.update);\n    aa.subscribe([aa.CONNECTED,aa.RECONNECTING,aa.SHUTDOWN,aa.MUTE_WARNING,aa.UNMUTE_WARNING,], qb);\n    g.subscribe(k.getArbiterType(\"buddylist_overlay\"), function(sb, tb) {\n        var ub = tb.obj.overlay;\n        for (var vb in ub) {\n            za.set(vb, ub[vb].a, (ub[vb].s || \"channel\"));;\n        };\n    });\n    a.AvailableList = e.exports = za;\n});\n__d(\"ChatHovercard\", [\"Arbiter\",\"AsyncLoader\",\"Hovercard\",\"JSLogger\",\"debounce\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AsyncLoader\"), i = b(\"Hovercard\"), j = b(\"JSLogger\"), k = b(\"debounce\"), l = 5, m = new h(\"/ajax/chat/hovercard/sidebar.php\", \"hover\"), n = j.create(\"chat_hovercard\");\n    g.subscribe(\"Hovercard/dirty\", m.reset.bind(m));\n    function o(s, t) {\n        m.get(s, function(u) {\n            (function() {\n                if (!u) {\n                    n.error(\"fetch_failure\", {\n                        id: s\n                    });\n                    return;\n                }\n            ;\n                var v = i.getDialog(u);\n                if (!v) {\n                    n.error(\"no_hovercard\", {\n                        id: s,\n                        endpoint: u\n                    });\n                    return;\n                }\n            ;\n                if ((s == t.getActiveID())) {\n                    t.showHovercard(s, v);\n                };\n            }).defer();\n        });\n    };\n    function p(s, t) {\n        var u = [];\n        function v(y) {\n            if (((y >= 0) && (y < s.length))) {\n                u.push(s[y]);\n            };\n        };\n        var w = s.indexOf(t);\n        if ((w > -1)) {\n            v(w);\n            for (var x = 1; (x < l); x++) {\n                v((w + x));\n                v((w - x));\n            };\n        }\n    ;\n        return u;\n    };\n    function q(s, t) {\n        var u = t.getActiveID();\n        if (u) {\n            var v = s.getShowingUsers(), w = p(v, u);\n            m.get(w, function() {\n            \n            });\n        }\n    ;\n    };\n    function r(s) {\n        var t = s.getHoverController();\n        t.registerDefault(o);\n        t.subscribe(\"hover\", k(q.curry(s, t), 100));\n    };\n    e.exports = r;\n});\n__d(\"ChatOptions\", [\"Arbiter\",\"ChannelConstants\",\"JSLogger\",\"PresenceUtil\",\"copyProperties\",\"ChatOptionsInitialData\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ChannelConstants\"), i = b(\"JSLogger\"), j = b(\"PresenceUtil\"), k = b(\"copyProperties\"), l = i.create(\"chat_options\"), m = {\n    };\n    (function() {\n        var o = c(\"ChatOptionsInitialData\");\n        for (var p in o) {\n            var q = o[p];\n            m[p] = !!q;\n        };\n    })();\n    var n = k(new g(), {\n        getSetting: function(o) {\n            return m[o];\n        },\n        setSetting: function(o, p, q) {\n            if ((this.getSetting(o) == p)) {\n                return\n            };\n            if (q) {\n                q = (\"from_\" + q);\n                l.log(q, {\n                    name: o,\n                    new_value: p,\n                    old_value: this.getSetting(o)\n                });\n            }\n        ;\n            m[o] = !!p;\n            g.inform(\"chat/option-changed\", {\n                name: o,\n                value: p\n            });\n        }\n    });\n    g.subscribe(h.getArbiterType(\"setting\"), function(o, p) {\n        var q = p.obj;\n        if ((q.window_id === j.getSessionID())) {\n            return\n        };\n        n.setSetting(q.setting, !!q.value, \"channel\");\n    });\n    g.subscribe(i.DUMP_EVENT, function(o, p) {\n        p.chat_options = m;\n    });\n    e.exports = n;\n});\n__d(\"ChatOrderedListHover\", [\"event-extensions\",\"function-extensions\",\"ArbiterMixin\",\"Class\",\"CSS\",\"DOM\",\"ErrorUtils\",\"LayerFadeOnHide\",\"Parent\",\"copyProperties\",\"setTimeoutAcrossTransitions\",\"tx\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"Class\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"ErrorUtils\"), l = b(\"LayerFadeOnHide\"), m = b(\"Parent\"), n = b(\"copyProperties\"), o = b(\"setTimeoutAcrossTransitions\"), p = b(\"tx\");\n    function q(t) {\n        i.addClass(t, \"fetching\");\n    };\n    function r(t) {\n        i.removeClass(t, \"fetching\");\n    };\n    function s(t) {\n        this._orderedList = t;\n        this._root = t.getRoot();\n        Event.listen(this._root, \"mouseover\", this._mouseOver.bind(this));\n        Event.listen(this._root, \"mouseleave\", this._mouseLeave.bind(this));\n        t.subscribe(\"click\", this._hide.shield(this));\n    };\n    n(s.prototype, g, {\n        _root: null,\n        _activeItem: null,\n        _hideTimeout: null,\n        _showTimeout: null,\n        _showingDialog: null,\n        _showingID: null,\n        _alreadyShowing: false,\n        _handlers: {\n        },\n        _defaultHandler: null,\n        _mouseOver: function(t) {\n            var u = t.getTarget(), v = m.byClass(u, \"item\");\n            (v && this._setActiveItem(v));\n        },\n        _mouseLeave: function(t) {\n            this._setActiveItem(null);\n        },\n        _clearTimeouts: function() {\n            (this._showTimeout && clearTimeout(this._showTimeout));\n            this._showTimeout = null;\n            (this._hideTimeout && clearTimeout(this._hideTimeout));\n            this._hideTimeout = null;\n        },\n        _checkAlreadyShowing: function() {\n            var t = this.getActiveID();\n            if ((!t && !this._showingID)) {\n                this._alreadyShowing = false;\n            };\n        },\n        _hide: function() {\n            if (this._showingDialog) {\n                this._showingDialog.enableBehavior(l);\n                this._showingDialog.hide();\n                this._showingDialog = null;\n                this._showingID = null;\n            }\n        ;\n            this._checkAlreadyShowing();\n        },\n        _show: function() {\n            this._alreadyShowing = true;\n            var t = this.getActiveID(), u = false;\n            if (this._handlers[t]) {\n                u = true;\n                k.applyWithGuard(this._handlers[t], {\n                }, [t,this,]);\n            }\n             else if (this._defaultHandler) {\n                u = true;\n                k.applyWithGuard(this._defaultHandler, {\n                }, [t,this,]);\n            }\n            \n        ;\n            if ((u && (this._showingID != this.getActiveID()))) {\n                q(this._activeItem);\n            };\n        },\n        _setActiveItem: function(t) {\n            if ((t != this._activeItem)) {\n                this._clearTimeouts();\n                (this._activeItem && r(this._activeItem));\n                this._activeItem = null;\n                var u = (t ? 0 : 100);\n                this._hideTimeout = o(function() {\n                    if ((this.getActiveID() != this._showingID)) {\n                        this._hide();\n                    };\n                }.bind(this), u);\n                if (t) {\n                    var v = this._orderedList.getUserForNode(t);\n                    this._activeItem = t;\n                    var w = (u + ((this._alreadyShowing ? 75 : 500)));\n                    this._showTimeout = o(function() {\n                        this._show();\n                    }.bind(this), w);\n                    this.inform(\"hover\", v);\n                }\n                 else this.inform(\"leave\");\n            ;\n                this._checkAlreadyShowing();\n            }\n        ;\n        },\n        register: function(t, u) {\n            if (!this._handlers[t]) {\n                this._handlers[t] = u;\n                return {\n                    unregister: function() {\n                        if ((t == this._showingID)) {\n                            this._hide();\n                        };\n                        delete this._handlers[t];\n                        var v = this._orderedList.getAllNodes(), w = v[t];\n                        (w && r(w));\n                    }.bind(this)\n                };\n            }\n        ;\n        },\n        registerDefault: function(t) {\n            this._defaultHandler = t;\n        },\n        getActiveID: function() {\n            var t = (this._activeItem && this._orderedList.getUserForNode(this._activeItem));\n            return (t || null);\n        },\n        showHovercard: function(t, u) {\n            if (((t == this.getActiveID()) && (t != this._showingID))) {\n                this._clearTimeouts();\n                r(this._activeItem);\n                this._hide();\n                this._showingDialog = u;\n                this._showingID = t;\n                var v = u.subscribe(\"mouseenter\", this._setActiveItem.bind(this, this._activeItem)), w = u.subscribe(\"mouseleave\", function() {\n                    v.unsubscribe();\n                    this._setActiveItem(null);\n                }.bind(this)), x = u.subscribe(\"hide\", function() {\n                    v.unsubscribe();\n                    w.unsubscribe();\n                    x.unsubscribe();\n                });\n                u.setContext(this._activeItem);\n                u.setFixed(true);\n                u.setPosition(\"left\");\n                u.show();\n                u.updatePosition();\n            }\n        ;\n        }\n    });\n    e.exports = s;\n});\n__d(\"ChatQuietLinks\", [\"event-extensions\",\"DOM\",\"DOMQuery\",\"UserAgent\",\"DataStore\",\"Parent\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"DOM\"), h = b(\"DOMQuery\"), i = b(\"UserAgent\"), j = b(\"DataStore\"), k = b(\"Parent\"), l = {\n    }, m = {\n        silenceLinks: function(q) {\n            n(q, this.removeEmptyHrefs.bind(this));\n        },\n        nukeLinks: function(q) {\n            n(q, this.removeAllHrefs.bind(this));\n        },\n        removeEmptyHrefs: function(q) {\n            o(q, function(r) {\n                return (!r || (r === \"#\"));\n            });\n        },\n        removeAllHrefs: function(q) {\n            o(q);\n        }\n    };\n    function n(q, r) {\n        var s = !!i.chrome(), t = ((!!i.chrome() || (i.ie() >= 9)) || (i.firefox() >= 4));\n        if (l[g.getID(q)]) {\n            return\n        };\n        l[g.getID(q)] = true;\n        if (!t) {\n            return\n        };\n        if (!s) {\n            (r && r(q));\n            return;\n        }\n    ;\n        Event.listen(q, \"mouseover\", function u(v) {\n            var w = k.byTag(v.getTarget(), \"a\");\n            if (w) {\n                var x = w.getAttribute(\"href\");\n                if (p(x)) {\n                    j.set(w, \"stashedHref\", w.getAttribute(\"href\"));\n                    w.removeAttribute(\"href\");\n                }\n            ;\n            }\n        ;\n        });\n        Event.listen(q, \"mouseout\", function u(v) {\n            var w = k.byTag(v.getTarget(), \"a\"), x = (w && j.remove(w, \"stashedHref\"));\n            if (p(x)) {\n                w.setAttribute(\"href\", x);\n            };\n        });\n        Event.listen(q, \"mousedown\", function(u) {\n            if (!u.isDefaultRequested()) {\n                return true\n            };\n            var v = k.byTag(u.getTarget(), \"a\"), w = (v && j.get(v, \"stashedHref\"));\n            if (p(w)) {\n                v.setAttribute(\"href\", w);\n            };\n        });\n    };\n    function o(q, r) {\n        var s = g.scry(q, \"a\");\n        if (r) {\n            s = s.filter(function(t) {\n                return r(t.getAttribute(\"href\"));\n            });\n        };\n        s.forEach(function(t) {\n            t.removeAttribute(\"href\");\n            t.setAttribute(\"tabindex\", 0);\n        });\n    };\n    function p(q) {\n        return (q && (q !== \"#\"));\n    };\n    e.exports = m;\n});\n__d(\"OrderedFriendsList\", [\"array-extensions\",\"Arbiter\",\"createArrayFrom\",\"ShortProfiles\",\"copyProperties\",\"OrderedFriendsListInitialData\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"createArrayFrom\"), i = b(\"ShortProfiles\"), j = b(\"copyProperties\"), k = [], l = {\n    }, m = j(new g(), {\n        contains: function(n) {\n            return (n in l);\n        },\n        compare: function(n, o) {\n            var p = m.getRank(n), q = m.getRank(o);\n            if ((p !== q)) {\n                return (p - q)\n            };\n            var r = i.getNow(n), s = i.getNow(o), t = ((((r || {\n            })).name || \"~\")).toLowerCase(), u = ((((s || {\n            })).name || \"~\")).toLowerCase();\n            if ((t !== u)) {\n                return ((t < u) ? -1 : 1)\n            };\n            return 0;\n        },\n        getList: function() {\n            var n = h(k);\n            n = n.filter(function(o) {\n                var p = (window.ShortProfiles && i.getNow(o));\n                return (!p || (p.type == \"friend\"));\n            });\n            return n;\n        },\n        getRank: function(n) {\n            return ((n in l) ? l[n] : k.length);\n        },\n        isReady: function() {\n            return true;\n        }\n    });\n    (function() {\n        var n = c(\"OrderedFriendsListInitialData\");\n        k = (n.list.length ? n.list : []);\n        k.forEach(function(o, p) {\n            l[o] = p;\n        });\n        m.inform(\"initialized\", {\n        }, g.BEHAVIOR_PERSISTENT);\n    })();\n    e.exports = (a.OrderedFriendsList || m);\n});\n__d(\"ChatOrderedList\", [\"event-extensions\",\"Animation\",\"Arbiter\",\"ArbiterMixin\",\"AvailableList\",\"AvailableListConstants\",\"Chat\",\"ChatConfig\",\"ChatOrderedListHover\",\"ChatQuietLinks\",\"ChatVisibility\",\"Class\",\"CSS\",\"DataStore\",\"Dialog\",\"DOM\",\"HTML\",\"JSLogger\",\"OrderedFriendsList\",\"Parent\",\"PresencePrivacy\",\"ShortProfiles\",\"Tooltip\",\"URI\",\"Vector\",\"XHPTemplate\",\"copyProperties\",\"createObjectFrom\",\"debounceAcrossTransitions\",\"goURI\",\"tx\",\"MercuryConfig\",\"ChannelImplementation\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Animation\"), h = b(\"Arbiter\"), i = b(\"ArbiterMixin\"), j = b(\"AvailableList\"), k = b(\"AvailableListConstants\"), l = b(\"Chat\"), m = b(\"ChatConfig\"), n = b(\"ChatOrderedListHover\"), o = b(\"ChatQuietLinks\"), p = b(\"ChatVisibility\"), q = b(\"Class\"), r = b(\"CSS\"), s = b(\"DataStore\"), t = b(\"Dialog\"), u = b(\"DOM\"), v = b(\"HTML\"), w = b(\"JSLogger\"), x = b(\"OrderedFriendsList\"), y = b(\"Parent\"), z = b(\"PresencePrivacy\"), aa = b(\"ShortProfiles\"), ba = b(\"Tooltip\"), ca = b(\"URI\"), da = b(\"Vector\"), ea = b(\"XHPTemplate\"), fa = b(\"copyProperties\"), ga = b(\"createObjectFrom\"), ha = b(\"debounceAcrossTransitions\"), ia = b(\"goURI\"), ja = b(\"tx\"), ka = c(\"MercuryConfig\"), la = c(\"ChannelImplementation\").instance;\n    function ma(ra, sa, ta, ua) {\n        this._root = ra;\n        this._items = {\n        };\n        this._isVisible = false;\n        this._excludedIds = {\n        };\n        this._numTopFriends = 5;\n        this._hasRendered = false;\n        this._preventRendering = false;\n        this._hoverController = null;\n        this._template = sa;\n        this._messageTemplate = ta;\n        this._contextualDialog = ua;\n        Event.listen(this._root, \"click\", this._onClick.bind(this));\n        Event.listen(this._root, \"mouseenter\", this._mouseEnter.bind(this));\n        Event.listen(this._root, \"mouseleave\", this._mouseLeave.bind(this));\n        j.subscribe(k.ON_AVAILABILITY_CHANGED, this.update.shield(this));\n        z.subscribe(\"privacy-changed\", this.update.shield(this));\n        la.subscribe([la.CONNECTED,la.RECONNECTING,la.SHUTDOWN,la.MUTE_WARNING,la.UNMUTE_WARNING,], this.update.shield(this));\n        this.inform(\"initialized\", this, h.BEHAVIOR_PERSISTENT);\n        this.render();\n        h.subscribe(w.DUMP_EVENT, function(va, wa) {\n            wa.chat_lists = (wa.chat_lists || {\n                sorted_list: this.getSortedList(),\n                ordered_list: x.getList(),\n                available_list: ma.getAvailableList(this._excludedIds),\n                excluded_list: this._excludedIds\n            });\n        }.bind(this));\n    };\n    function na(ra, sa) {\n        var ta = oa(ra, sa);\n        if ((ta !== 0)) {\n            return ta\n        };\n        var ua = pa(ra, sa);\n        if ((ua !== 0)) {\n            return ua\n        };\n        return x.compare(ra, sa);\n    };\n    function oa(ra, sa) {\n        var ta = z.allows(ra), ua = z.allows(sa);\n        if ((ta !== ua)) {\n            return (ta ? -1 : 1)\n        };\n        return 0;\n    };\n    function pa(ra, sa) {\n        var ta = aa.getNow(ra), ua = aa.getNow(sa), va = ((((ta || {\n        })).name || \"~\")).toLowerCase(), wa = ((((ua || {\n        })).name || \"~\")).toLowerCase();\n        if ((va !== wa)) {\n            return ((va < wa) ? -1 : 1)\n        };\n        return 0;\n    };\n    function qa(ra, sa) {\n        var ta = (j.get(ra) === k.MOBILE), ua = (j.get(sa) === k.MOBILE);\n        if ((ta !== ua)) {\n            return (ua ? -1 : 1)\n        };\n        return pa(ra, sa);\n    };\n    fa(ma, {\n        getSortedList: function(ra, sa) {\n            var ta = x.getList().filter(function(jb) {\n                return !((jb in ra));\n            });\n            ta = ta.filter(function(jb) {\n                return (z.getFriendVisibility(jb) !== z.BLACKLISTED);\n            });\n            var ua = [], va = p.isOnline();\n            if (va) {\n                if ((z.getOnlinePolicy() === z.ONLINE_TO_WHITELIST)) {\n                    var wa = ta, xa = {\n                    }, ya, za;\n                    ta = [];\n                    for (ya = 0; (ya < wa.length); ++ya) {\n                        za = wa[ya];\n                        if (z.allows(za)) {\n                            xa[za] = true;\n                            ta.push(za);\n                        }\n                    ;\n                    };\n                    var ab = z.getWhitelist();\n                    for (ya = 0; (ya < ab.length); ++ya) {\n                        za = ab[ya];\n                        if (!((za in xa))) {\n                            ta.push(za);\n                        };\n                    };\n                    for (ya = 0; (ya < wa.length); ++ya) {\n                        za = wa[ya];\n                        if (!z.allows(za)) {\n                            ta.push(za);\n                        };\n                    };\n                }\n            ;\n                var bb = m.get(\"ordered_list.top_friends\", 0), cb = m.get(\"ordered_list.available_target\", 0), db = Math.floor((sa * cb)), eb = [];\n                for (var ya = 0, fb = ta.length; ((ya < fb) && (db > 0)); ya++) {\n                    var za = ta[ya], gb = j.get(za), hb = (gb === k.ACTIVE);\n                    if (m.get(\"chat_sidebar_mobile_available\")) {\n                        hb = (hb || ((gb === k.MOBILE)));\n                    };\n                    if ((hb || (ya < bb))) {\n                        ua.push(za);\n                        (hb && db--);\n                    }\n                     else eb.push(za);\n                ;\n                };\n                if ((ya < fb)) {\n                    Array.prototype.push.apply(eb, ta.slice(ya));\n                };\n                if ((ua.length < sa)) {\n                    Array.prototype.push.apply(ua, eb);\n                };\n            }\n             else Array.prototype.push.apply(ua, ta);\n        ;\n            ua = ua.slice(0, sa);\n            if ((ua.length === sa)) {\n                var ib = ma.getAvailableList(ua.concat(ra)).length;\n                (ib && ua.splice(-1));\n            }\n        ;\n            ua.sort(na);\n            return ua;\n        },\n        getAvailableList: function(ra) {\n            return j.getOnlineIDs().filter(function(sa) {\n                return !((sa in ra));\n            });\n        }\n    });\n    fa(ma.prototype, i, {\n        getAllNodes: function() {\n            var ra = {\n            }, sa = u.scry(this._root, \"li.item\");\n            for (var ta = 0; (ta < sa.length); ta++) {\n                var ua = s.get(sa[ta], \"id\");\n                if (ua) {\n                    ra[ua] = sa[ta];\n                };\n            };\n            return ra;\n        },\n        getShowingUsers: function() {\n            return u.scry(this._root, \"li.item\").map(function(ra) {\n                return s.get(ra, \"id\");\n            });\n        },\n        getUserForNode: function(ra) {\n            return s.get(ra, \"id\");\n        },\n        getHoverController: function() {\n            if (!this._hoverController) {\n                this._hoverController = new n(this, this._contextualDialog);\n            };\n            return this._hoverController;\n        },\n        _getListItem: function(ra) {\n            var sa = this._items[ra];\n            if (sa) {\n                var ta = j.get(ra), ua = (z.allows(ra) && !la.disconnected()), va = {\n                    active: false,\n                    mobile: false,\n                    greenphone: false\n                };\n                va.active = (ta === k.ACTIVE);\n                if (m.get(\"sidebar_mobile_icon_green\")) {\n                    va.greenphone = (ta === k.MOBILE);\n                }\n                 else va.mobile = (ta === k.MOBILE);\n            ;\n                for (var wa in va) {\n                    r.conditionClass(sa, wa, (va[wa] && ua));;\n                };\n                r.conditionClass(sa, \"invis\", !ua);\n            }\n        ;\n            return sa;\n        },\n        getRoot: function() {\n            return this._root;\n        },\n        getSortedList: function() {\n            return ma.getSortedList(this._excludedIds, this._numTopFriends);\n        },\n        hide: function() {\n            if (!this._isVisible) {\n                return\n            };\n            this._isVisible = false;\n            r.hide(this._root);\n            this.inform(\"hide\");\n        },\n        _onClick: function(event) {\n            var ra = event.getTarget(), sa = y.byTag(ra, \"li\");\n            if (sa) {\n                if (r.hasClass(sa, \"blackbirdWhitelist\")) {\n                    var ta = new ca(\"/ajax/chat/privacy/settings_dialog.php\").addQueryData({\n                        ref: \"whitelist_separator\"\n                    });\n                    new t().setAsyncURL(ta.toString()).show();\n                    event.prevent();\n                    return false;\n                }\n            ;\n                var ua = s.get(sa, \"id\");\n                if (ua) {\n                    var va = \"ordered_list\", wa = sa;\n                    while (sa.previousSibling) {\n                        sa = sa.previousSibling;\n                        if (r.hasClass(sa, \"separator\")) {\n                            if (r.hasClass(sa, \"moreOnlineFriends\")) {\n                                va = \"more_online_friends\";\n                                break;\n                            }\n                        ;\n                            if (r.hasClass(sa, \"blackbirdWhitelist\")) {\n                                va = \"blackbird_offline_section\";\n                                break;\n                            }\n                        ;\n                        }\n                    ;\n                    };\n                    var xa = [];\n                    if (m.get(\"chat_realtime_coefficient_impressions\")) {\n                        xa = this.getSortedList();\n                    };\n                    aa.get(ua, function(ya) {\n                        l.openTab(ua, ya.name, \"friend\", va, xa);\n                    });\n                    this.inform(\"click\", {\n                        id: ua\n                    });\n                }\n                 else if ((r.hasClass(sa, \"separator\") && y.byClass(ra, \"inner\"))) {\n                    this.scrollTo(sa);\n                }\n            ;\n                return false;\n            }\n        ;\n        },\n        _mouseEnter: function() {\n            this._preventRendering = true;\n        },\n        _mouseLeave: function() {\n            this._preventRendering = false;\n        },\n        setExcludedIds: function(ra) {\n            this._excludedIds = ga((ra || []));\n        },\n        setNumTopFriends: function(ra) {\n            if ((ra !== this._numTopFriends)) {\n                this._numTopFriends = ra;\n                this.render();\n            }\n        ;\n        },\n        _getOfflineToSectionItems: function() {\n            var ra = u.create(\"a\", {\n                href: \"#\"\n            }, u.tx._(\"Edit\")), sa = [];\n            sa.push(v((((((((((\"\\u003Cli class=\\\"separator\\\"\\u003E\" + \"\\u003Cdiv class=\\\"outer\\\"\\u003E\") + \"\\u003Cdiv class=\\\"inner\\\"\\u003E\") + \"\\u003Cspan class=\\\"text\\\"\\u003E\") + u.tx._(\"OFFLINE FRIENDS\")) + \"\\u003C/span\\u003E\") + \"\\u003Cdiv class=\\\"dive\\\"\\u003E\\u003Cspan class=\\\"bar\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\") + \"\\u003C/div\\u003E\") + \"\\u003C/div\\u003E\") + \"\\u003C/li\\u003E\")));\n            sa.push(v((((((((((\"\\u003Cli class=\\\"separator blackbirdWhitelist\\\"\\u003E\" + \"\\u003Cdiv class=\\\"outer\\\"\\u003E\") + \"\\u003Cdiv class=\\\"inner\\\"\\u003E\") + \"\\u003Cdiv class=\\\"subheader\\\"\\u003E\") + \"\\u003Cspan class=\\\"subheaderText\\\"\\u003E\") + u.tx._(\"These friends can't see you on chat. {=link}\", {\n                \"=link\": ra\n            })) + \"\\u003C/span\\u003E\") + \"\\u003C/div\\u003E\") + \"\\u003C/div\\u003E\") + \"\\u003C/li\\u003E\")));\n            return sa;\n        },\n        render: function() {\n            this.render = ha(function() {\n                if ((!this._isVisible || ((this._preventRendering && this._hasRendered)))) {\n                    return\n                };\n                this._hasRendered = true;\n                var ra = this.getSortedList(), sa = [], ta, ua, va = (z.getVisibility() && (z.getOnlinePolicy() == z.ONLINE_TO_WHITELIST));\n                for (var wa = 0, xa = ra.length; (wa < xa); wa++) {\n                    ta = ra[wa];\n                    if (va) {\n                        if (!z.allows(ta)) {\n                            if (((wa + 2) >= ra.length)) {\n                                break;\n                            };\n                            va = false;\n                            var ya = this._getOfflineToSectionItems();\n                            sa.push(ya[0]);\n                            sa.push(ya[1]);\n                            xa -= 2;\n                        }\n                    \n                    };\n                    ua = this._getListItem(ta);\n                    if (ua) {\n                        sa.push(ua);\n                    }\n                     else this._renderListItem(ta, this.render.bind(this));\n                ;\n                };\n                var za = ma.getAvailableList(this._excludedIds), ab = ga(ra);\n                za = za.filter(function(gb) {\n                    return !((gb in ab));\n                });\n                za.sort(qa);\n                var bb = (ka.ChatControlLanguageChangeGK ? \"MORE FRIENDS\" : \"MORE ONLINE FRIENDS\");\n                if ((za.length && sa.length)) {\n                    sa.push(v((((((((((\"\\u003Cli class=\\\"separator moreOnlineFriends\\\"\\u003E\" + \"\\u003Cdiv class=\\\"outer\\\"\\u003E\") + \"\\u003Cdiv class=\\\"inner\\\"\\u003E\") + \"\\u003Cspan class=\\\"text\\\"\\u003E\") + ja._(\"{MORE ONLINE FRIENDS} ({=count})\", {\n                        \"MORE ONLINE FRIENDS\": bb,\n                        \"=count\": za.length\n                    })) + \"\\u003C/span\\u003E\") + \"\\u003Cdiv class=\\\"dive\\\"\\u003E\\u003Cspan class=\\\"bar\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\") + \"\\u003C/div\\u003E\") + \"\\u003C/div\\u003E\") + \"\\u003C/li\\u003E\")));\n                };\n                for (var cb = 0, db = za.length; (cb < db); cb++) {\n                    ta = za[cb];\n                    ua = this._getListItem(ta);\n                    if (ua) {\n                        sa.push(ua);\n                    }\n                     else this._renderListItem(ta, this.render.bind(this));\n                ;\n                };\n                if ((!ra.length && !za.length)) {\n                    var eb = this._messageTemplate.render(), fb = ea.getNode(eb, \"message\");\n                    u.setContent(fb, \"No one is available to chat.\");\n                    sa.push(eb);\n                }\n            ;\n                if (sa.length) {\n                    u.setContent(this._root, sa);\n                    o.nukeLinks(this.getRoot());\n                    this.inform(\"render\");\n                }\n            ;\n            }, 300, this);\n            this.render();\n        },\n        _renderListItem: function(ra, sa) {\n            aa.get(ra, function(ta) {\n                if ((ta.type === \"friend\")) {\n                    var ua = this._template.render(), va = ea.getNode(ua, \"profile-photo\");\n                    va.setAttribute(\"src\", ta.thumbSrc);\n                    var wa = ea.getNode(ua, \"name\");\n                    u.setContent(wa, ta.name);\n                    var xa = ea.getNode(ua, \"anchor\");\n                    xa.setAttribute(\"href\", (\"/messages/\" + ra));\n                    var ya = ea.getNode(ua, \"timeline_icon\");\n                    if (ya) {\n                        var za = ja._(\"Go to {name}'s timeline\", {\n                            name: ta.firstName\n                        });\n                        ba.set(ya, za, \"above\", \"center\");\n                        Event.listen(ya, \"click\", function(event) {\n                            event.kill();\n                            ia(ta.uri);\n                        });\n                    }\n                ;\n                    s.set(ua, \"id\", ra);\n                    this._items[ra] = ua;\n                    (sa && sa(ua));\n                }\n            ;\n            }.bind(this));\n        },\n        show: function() {\n            if (this._isVisible) {\n                return\n            };\n            this._isVisible = true;\n            r.show(this._root);\n            this.render();\n            this.inform(\"show\");\n        },\n        isVisible: function() {\n            return this._isVisible;\n        },\n        update: function() {\n            this._hasRendered = false;\n            this.render();\n        },\n        setScrollContainer: function(ra) {\n            if (u.contains(ra, this._root)) {\n                this._scrollContainer = ra;\n            };\n        },\n        scrollTo: function(ra) {\n            if (!this._scrollContainer) {\n                return\n            };\n            var sa = this._scrollContainer.scrollHeight, ta = this._scrollContainer.clientHeight, ua = this._scrollContainer.scrollTop, va = Math.min(ra.offsetTop, (sa - ta));\n            if ((ua !== va)) {\n                var wa = ((Math.abs((va - ua)) / this._scrollContainer.clientHeight) * 500);\n                g(this._scrollContainer).to(\"scrollTop\", va).ease(g.ease.end).duration(wa).go();\n            }\n        ;\n        }\n    });\n    e.exports = ma;\n});\n__d(\"TypingIndicator\", [\"Arbiter\",\"AsyncRequest\",\"AvailableList\",\"AvailableListConstants\",\"ChannelManager\",\"ChannelConnection\",\"ChatConfig\",\"ChatVisibility\",\"copyProperties\",\"Keys\",\"ShortProfiles\",\"TypingDetector\",\"PresencePrivacy\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"AvailableList\"), j = b(\"AvailableListConstants\"), k = b(\"ChannelManager\"), l = b(\"ChannelConnection\"), m = b(\"ChatConfig\"), n = b(\"ChatVisibility\"), o = b(\"copyProperties\"), p = b(\"Keys\"), q = b(\"ShortProfiles\"), r = b(\"TypingDetector\"), s = b(\"PresencePrivacy\");\n    function t(v) {\n        if (!n.isOnline()) {\n            return false\n        };\n        if (v) {\n            var w = q.getNow(v);\n            return ((w && (w.type == \"friend\")) && s.allows(v));\n        }\n    ;\n        return true;\n    };\n    function u(v, w, x, y, z) {\n        this.userID = v;\n        this.input = w;\n        this.source = x;\n        this.threadID = z;\n        this.remoteState = r.INACTIVE;\n        this.notifyTimer = null;\n        y = (y || {\n        });\n        this.notifyDelay = (y.notifyDelay || this.notifyDelay);\n        this._typingDetector = new r(w);\n        this._typingDetector.init(y);\n        this._typingDetector.subscribe(\"change\", this._stateChange.bind(this));\n    };\n    o(u.prototype, {\n        notifyDelay: 1000,\n        setIgnoreEnter: function(v) {\n            var w = (v ? [p.RETURN,] : []);\n            this._typingDetector.setIgnoreKeys(w);\n        },\n        resetState: function() {\n            this.remoteState = u.INACTIVE;\n            this._typingDetector.reset();\n            clearTimeout(this.notifyTimer);\n            this.notifyTimer = null;\n        },\n        _stateChange: function(v, w) {\n            if ((w != r.QUITTING)) {\n                clearTimeout(this.notifyTimer);\n                this.notifyTimer = this._notifyState.shield(this, w).defer(this.notifyDelay, false);\n            }\n             else this._notifyState(w, true);\n        ;\n        },\n        _notifyState: function(v, w) {\n            var x = this.userID, y = t(x);\n            if ((y && (v != this.remoteState))) {\n                this.remoteState = v;\n                if (l.disconnected()) {\n                    return\n                };\n                var z = {\n                    typ: v,\n                    to: x,\n                    source: this.source,\n                    thread: this.threadID\n                };\n                new h().setHandler(this._onTypResponse.bind(this, x)).setErrorHandler(bagofholding).setData(z).setURI(\"/ajax/messaging/typ.php\").setAllowCrossPageTransition(true).setOption(\"asynchronous\", !w).send();\n            }\n        ;\n        },\n        _onTypResponse: function(v, w) {\n            var x = (w.getPayload() || {\n            });\n            if (x.offline) {\n                i.set(v, j.OFFLINE, \"typing_response\");\n            };\n        }\n    });\n    e.exports = u;\n});\n__d(\"ChatBehavior\", [\"Arbiter\",\"AvailableList\",\"AvailableListConstants\",\"copyProperties\",\"MercuryConstants\",\"ChatSidebarCalloutData\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AvailableList\"), i = b(\"AvailableListConstants\"), j = b(\"copyProperties\"), k = c(\"MercuryConstants\").ChatNotificationConstants, l = c(\"ChatSidebarCalloutData\").isShown, m = h.getWebChatNotification(), n = l, o = j(new g(), {\n        ON_CHANGED: \"changed\",\n        notifiesUserMessages: function() {\n            return (m !== k.NO_USER_MESSAGE_NOTIFICATION);\n        },\n        ignoresRemoteTabRaise: function() {\n            return n;\n        }\n    });\n    function p() {\n        o.inform(o.ON_CHANGED);\n    };\n    h.subscribe(i.ON_CHAT_NOTIFICATION_CHANGED, function() {\n        var q = m, r = h.getWebChatNotification();\n        m = r;\n        if ((q != r)) {\n            p();\n        };\n    });\n    g.subscribe(\"chat/set_does_page_occlude_tabs\", function(q, r) {\n        n = !!r;\n        p();\n    });\n    e.exports = o;\n});\n__d(\"ChatSidebarSheet\", [\"event-extensions\",\"function-extensions\",\"ArbiterMixin\",\"ChannelConnection\",\"ChannelConstants\",\"ChatBehavior\",\"ChatConfig\",\"ChatVisibility\",\"Class\",\"CSS\",\"DOM\",\"JSLogger\",\"PresencePrivacy\",\"copyProperties\",\"tx\",\"MercuryConfig\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"ChannelConnection\"), i = b(\"ChannelConstants\"), j = b(\"ChatBehavior\"), k = b(\"ChatConfig\"), l = b(\"ChatVisibility\"), m = b(\"Class\"), n = b(\"CSS\"), o = b(\"DOM\"), p = b(\"JSLogger\"), q = b(\"PresencePrivacy\"), r = b(\"copyProperties\"), s = b(\"tx\"), t = c(\"MercuryConfig\"), u = p.create(\"sidebar_sheet\");\n    function v(y) {\n        switch (y) {\n          case i.HINT_AUTH:\n            return \"Your session has timed out. Please log in.\";\n          case i.HINT_CONN:\n            return s._(\"Facebook {Chat} is currently unavailable.\", {\n                Chat: \"Chat\"\n            });\n          case i.HINT_MAINT:\n            return s._(\"Facebook {Chat} is currently down for maintenance.\", {\n                Chat: \"Chat\"\n            });\n          default:\n            return s._(\"Facebook {Chat} is currently unavailable.\", {\n                Chat: \"Chat\"\n            });\n        };\n    };\n    function w(y) {\n        var z;\n        if ((y === null)) {\n            z = \"Unable to connect to chat. Check your Internet connection.\";\n        }\n         else if ((y > k.get(\"warning_countdown_threshold_msec\"))) {\n            var aa = o.create(\"a\", {\n                href: \"#\",\n                className: \"fbChatReconnectLink\"\n            }, \"Try again\");\n            z = o.tx._(\"Unable to connect to chat. {try-again-link}\", {\n                \"try-again-link\": aa\n            });\n        }\n         else if ((y > 1000)) {\n            z = s._(\"Unable to connect to chat. Reconnecting in {seconds}...\", {\n                seconds: Math.floor((y / 1000))\n            });\n        }\n         else z = \"Unable to connect to chat. Reconnecting...\";\n        \n        \n    ;\n        return z;\n    };\n    function x(y) {\n        this._root = y;\n        this._message = o.find(y, \"div.fbChatSidebarMessage div.message\");\n        h.subscribe([h.CONNECTED,h.SHUTDOWN,h.RECONNECTING,], this._handleConnectionChange.bind(this));\n        h.subscribe([h.MUTE_WARNING,h.UNMUTE_WARNING,], this._render.bind(this));\n        q.subscribe(\"privacy-user-presence-changed\", this._render.bind(this));\n        j.subscribe(j.ON_CHANGED, this._render.bind(this));\n        this._render();\n    };\n    r(x.prototype, g, {\n        _channelStatus: null,\n        _channelData: null,\n        _handleConnectionChange: function(y, z) {\n            this._channelStatus = y;\n            this._channelData = z;\n            this._render();\n        },\n        _showWarningTimeout: null,\n        _warningMsgEventListener: null,\n        _renderChannelDisconnect: function() {\n            if ((this._channelStatus === h.SHUTDOWN)) {\n                return o.setContent(this._message, v(this._channelData));\n            }\n             else if ((this._channelStatus === h.RECONNECTING)) {\n                var y = this._channelData;\n                o.setContent(this._message, w(y));\n                if ((y > 1000)) {\n                    if ((y > k.get(\"warning_countdown_threshold_msec\"))) {\n                        this._warningMsgEventListener = Event.listen(this._message, \"click\", function(event) {\n                            if (n.hasClass(event.getTarget(), \"fbChatReconnectLink\")) {\n                                h.reconnect();\n                                return false;\n                            }\n                        ;\n                        });\n                    };\n                    this._showWarningTimeout = setTimeout(this._handleConnectionChange.bind(this, h.RECONNECTING, (y - 1000)), 1000, false);\n                }\n            ;\n            }\n            \n        ;\n        },\n        _goOnlineEventListener: null,\n        _renderOffline: function() {\n            var y = \"fbChatGoOnlineLink\", z = (t.ChatControlLanguageChangeGK ? \"Turn on chat\" : \"Go online\"), aa = o.create(\"a\", {\n                href: \"#\",\n                className: y\n            }, z), ba;\n            if (t.ChatControlLanguageChangeGK) {\n                ba = o.tx._(\"{=Go online} to see who's available.\", {\n                    \"=Go online\": aa\n                });\n            }\n             else ba = o.tx._(\"{=Go online} to see who's online to chat.\", {\n                \"=Go online\": aa\n            });\n        ;\n            o.setContent(this._message, ba);\n            this._goOnlineEventListener = Event.listen(this._message, \"click\", function(event) {\n                if (n.hasClass(event.getTarget(), y)) {\n                    u.log(\"sidebar_go_online\");\n                    l.goOnline();\n                    return false;\n                }\n            ;\n            });\n        },\n        _clear: function() {\n            if (this._showWarningTimeout) {\n                clearTimeout(this._showWarningTimeout);\n                this._showWarningTimeout = null;\n            }\n        ;\n            if (this._warningMsgEventListener) {\n                this._warningMsgEventListener.remove();\n                this._warningMsgEventListener = null;\n            }\n        ;\n            if (this._goOnlineEventListener) {\n                this._goOnlineEventListener.remove();\n                this._goOnlineEventListener = null;\n            }\n        ;\n            n.removeClass(this._root, \"offline\");\n            n.removeClass(this._root, \"error\");\n            n.removeClass(this._root, \"notice\");\n            o.empty(this._message);\n        },\n        _render: function() {\n            this._clear();\n            if (!l.isOnline()) {\n                n.addClass(this._root, \"offline\");\n                this._renderOffline();\n            }\n             else if (h.disconnected()) {\n                n.addClass(this._root, \"error\");\n                this._renderChannelDisconnect();\n            }\n             else if (!j.notifiesUserMessages()) {\n                n.addClass(this._root, \"notice\");\n                o.setContent(this._message, \"Alerts are off while you use another client to chat.\");\n            }\n            \n            \n        ;\n            this.inform(\"updated\");\n        }\n    });\n    e.exports = x;\n});\n__d(\"ChatTypeaheadBehavior\", [\"Chat\",\"CSS\",\"DOM\",\"Rect\",\"copyProperties\",\"tx\",], function(a, b, c, d, e, f) {\n    var g = b(\"Chat\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"Rect\"), k = b(\"copyProperties\"), l = b(\"tx\");\n    function m(n) {\n        this._typeahead = n;\n    };\n    k(m.prototype, {\n        _subscriptions: null,\n        enable: function() {\n            var n = this._typeahead;\n            this._subscriptions = [n.subscribe(\"focus\", function() {\n                n.getData().refreshData();\n            }),n.subscribe(\"blur\", function(o) {\n                n.getCore().reset();\n            }),n.subscribe(\"respond\", function(o, p) {\n                if ((p.value && (p.value === n.getCore().getValue()))) {\n                    if (!p.results.length) {\n                        var q = i.create(\"div\", {\n                            className: \"noResults\"\n                        }, \"Friend not found.\");\n                        i.setContent(n.getView().getElement(), q);\n                    }\n                ;\n                    h.addClass(n.getElement(), \"hasValue\");\n                }\n            ;\n            }),n.subscribe(\"reset\", function() {\n                h.removeClass(n.getElement(), \"hasValue\");\n            }),n.subscribe(\"select\", function(o, p) {\n                g.openTab(p.selected.uid, p.selected.text, p.selected.type, \"typeahead\");\n            }),n.subscribe(\"highlight\", function(o, p) {\n                if ((p.index >= 0)) {\n                    var q = n.getView().getItems()[p.index];\n                    if (q) {\n                        var r = new j(q), s = q.offsetParent, t = r.boundWithin(new j(s)).getPositionVector();\n                        r.getPositionVector().sub(t).scrollElementBy(s);\n                    }\n                ;\n                }\n            ;\n            }),];\n        },\n        disable: function() {\n            this._subscriptions.forEach(function(n) {\n                this._typeahead.unsubscribe(n);\n            }.bind(this));\n            this._subscriptions = null;\n        }\n    });\n    e.exports = m;\n});\n__d(\"ChatTypeaheadCore\", [\"event-extensions\",\"function-extensions\",\"Class\",\"Keys\",\"TypeaheadCore\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Class\"), h = b(\"Keys\"), i = b(\"TypeaheadCore\"), j = b(\"copyProperties\");\n    function k(l) {\n        this.parent.construct(this, l);\n    };\n    g.extend(k, i);\n    j(k.prototype, {\n        handleTab: bagofholding,\n        keydown: function(event) {\n            var l = Event.getKeyCode(event);\n            if ((l === h.ESC)) {\n                this.reset.shield(this).defer();\n                return event.kill();\n            }\n        ;\n            return this.parent.keydown(event);\n        }\n    });\n    e.exports = k;\n});\n__d(\"ChatTypeaheadDataSource\", [\"Arbiter\",\"AvailableListConstants\",\"Class\",\"DataSource\",\"Env\",\"JSLogger\",\"OrderedFriendsList\",\"Run\",\"ShortProfiles\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AvailableListConstants\"), i = b(\"Class\"), j = b(\"DataSource\"), k = b(\"Env\"), l = b(\"JSLogger\"), m = b(\"OrderedFriendsList\"), n = b(\"Run\"), o = b(\"ShortProfiles\"), p = b(\"copyProperties\");\n    function q(r) {\n        this.parent.construct(this, r);\n        this.persistOnRefresh = (r.persistOnRefresh !== false);\n        this.showOfflineUsers = !!r.showOfflineUsers;\n        this._jslog = l.create(\"chat_typeahead\");\n        this._jslog.log(\"created\");\n    };\n    i.extend(q, j);\n    p(q.prototype, {\n        init: function() {\n            this._jslog.log(\"init\");\n            this.parent.init();\n            var r = g.subscribe(h.ON_AVAILABILITY_CHANGED, this._update.shield(this));\n            this._update();\n            if (!this.persistOnRefresh) {\n                n.onLeave(function() {\n                    r.unsubscribe();\n                });\n            };\n        },\n        bootstrap: function() {\n            this._jslog.log(\"bootstrap\");\n            this.parent.bootstrap();\n            if (this.showOfflineUsers) {\n                this._jslog.log(\"show_offline_users\");\n                this._jslog.log(\"ensured_short_profiles\");\n                if (o.hasAll()) {\n                    this._update();\n                }\n                 else {\n                    this._jslog.log(\"fetch_all_short_profiles\");\n                    o.fetchAll();\n                    this.inform(\"activity\", {\n                        activity: true\n                    });\n                    var r = o.subscribe(\"updated\", function() {\n                        this.inform(\"activity\", {\n                            activity: false\n                        });\n                        this._update();\n                    }.bind(this));\n                    if (!this.persistOnRefresh) {\n                        n.onLeave(function() {\n                            o.unsubscribe(r);\n                        });\n                    };\n                }\n            ;\n            }\n        ;\n        },\n        _update: function() {\n            d([\"AvailableList\",], function(r) {\n                var s = this.value;\n                this.dirty();\n                var t = o.getCachedProfileIDs(), u = t.filter(function(w) {\n                    var x = o.getNow(w);\n                    return (x.type === \"friend\");\n                });\n                u.sort(m.compare);\n                var v = [];\n                u.forEach(function(w) {\n                    if ((w == k.user)) {\n                        return\n                    };\n                    var x = r.get(w);\n                    if ((!this.showOfflineUsers && (x !== r.ACTIVE))) {\n                        return\n                    };\n                    var y = o.getNow(w);\n                    v.push({\n                        uid: w,\n                        text: y.name,\n                        tokens: y.additionalName,\n                        localized_text: y.name,\n                        additional_text: y.additionalName,\n                        photo: y.thumbSrc,\n                        availability: x,\n                        type: y.type\n                    });\n                }.bind(this));\n                if (v.length) {\n                    this.addEntries(v);\n                };\n                this.value = s;\n                if (s) {\n                    this.respond(s, this.buildUids(s, [], this._exclusions), true);\n                };\n            }.bind(this));\n        },\n        refreshData: function() {\n            d([\"AvailableList\",], function(r) {\n                r.update();\n            }.bind(this));\n        }\n    });\n    e.exports = q;\n});\n__d(\"ChatTypeaheadRenderer\", [\"AvailableListConstants\",\"DOM\",\"PresencePrivacy\",], function(a, b, c, d, e, f) {\n    var g = b(\"AvailableListConstants\"), h = b(\"DOM\"), i = b(\"PresencePrivacy\");\n    function j(k, l) {\n        var m = \"offline\";\n        switch (k.availability) {\n          case g.ACTIVE:\n            m = \"active\";\n            break;\n          case g.IDLE:\n            m = \"idle\";\n            break;\n          case g.MOBILE:\n            m = \"mobile\";\n            break;\n        };\n        if (!i.allows(k.uid)) {\n            m = \"invis\";\n        };\n        var n = [];\n        if (k.photo) {\n            n.push(h.create(\"img\", {\n                alt: \"\",\n                src: k.photo\n            }));\n        };\n        if (k.text) {\n            n.push(h.create(\"span\", {\n                className: \"text\"\n            }, [k.text,]));\n        };\n        n.push(h.create(\"i\", {\n            className: m\n        }));\n        return h.create(\"li\", {\n            className: (\"clearfix \" + m)\n        }, n);\n    };\n    e.exports = j;\n});\n__d(\"ChatSidebar\", [\"JSXDOM\",\"event-extensions\",\"Arbiter\",\"ArbiterMixin\",\"AsyncRequest\",\"ChatConfig\",\"ChatHovercard\",\"ChatOptions\",\"ChatQuietLinks\",\"ChatSidebarSheet\",\"CSS\",\"DOM\",\"FBDesktopPlugin\",\"JSLogger\",\"OrderedFriendsList\",\"PresencePrivacy\",\"ScrollableArea\",\"Style\",\"Vector\",\"ViewportBounds\",\"copyProperties\",\"createArrayFrom\",\"debounce\",\"ChatOrderedList\",\"ChatTypeaheadBehavior\",\"ChatTypeaheadCore\",\"ChatTypeaheadDataSource\",\"ChatTypeaheadRenderer\",\"Typeahead\",], function(a, b, c, d, e, f) {\n    var g = b(\"JSXDOM\"), g = b(\"JSXDOM\");\n    b(\"event-extensions\");\n    var h = b(\"Arbiter\"), i = b(\"ArbiterMixin\"), j = b(\"AsyncRequest\"), k = b(\"ChatConfig\"), l = b(\"ChatHovercard\"), m = b(\"ChatOptions\"), n = b(\"ChatQuietLinks\"), o = b(\"ChatSidebarSheet\"), p = b(\"CSS\"), q = b(\"DOM\"), r = b(\"FBDesktopPlugin\"), s = b(\"JSLogger\"), t = b(\"OrderedFriendsList\"), u = b(\"PresencePrivacy\"), v = b(\"ScrollableArea\"), w = b(\"Style\"), x = b(\"Vector\"), y = b(\"ViewportBounds\"), z = b(\"copyProperties\"), aa = b(\"createArrayFrom\"), ba = b(\"debounce\");\n    b(\"ChatOrderedList\");\n    b(\"ChatTypeaheadBehavior\");\n    b(\"ChatTypeaheadCore\");\n    b(\"ChatTypeaheadDataSource\");\n    b(\"ChatTypeaheadRenderer\");\n    b(\"Typeahead\");\n    var ca, da = false, ea = false, fa = false, ga = false, ha = false, ia = false, ja, ka, la, ma, na = null, oa = s.create(\"chat_sidebar\"), pa = 32;\n    function qa() {\n        p.removeClass(document.documentElement, \"sidebarMode\");\n        if ((!ha || !wa.isVisible())) {\n            return\n        };\n        ga = false;\n        na = null;\n        p.hide(ka);\n        ja.hide();\n        la.getCore().reset();\n        oa.rate(\"sidebar_hide\", ha);\n        wa.inform(\"sidebar/hide\", wa);\n        h.inform(\"sidebar/hide\", wa);\n        h.inform(\"reflow\");\n    };\n    function ra() {\n        var xa = wa.shouldShowSidebar();\n        p.conditionClass(document.documentElement, \"sidebarCapable\", xa);\n        if ((wa.isEnabled() && xa)) {\n            sa();\n            var ya = ma.y;\n            aa(ka.childNodes).forEach(function(za) {\n                if ((za !== ca)) {\n                    ya -= x.getElementDimensions(za).y;\n                };\n            });\n            ya = Math.max(0, ya);\n            w.set(ca, \"height\", (ya + \"px\"));\n            this._maxItems = Math.floor((((ya - 8)) / pa));\n            ja.setNumTopFriends(this._maxItems);\n            la.getData().setMaxResults(this._maxItems);\n            wa.inform(\"sidebar/resized\", wa);\n            h.inform(\"sidebar/resized\", wa);\n            h.inform(\"reflow\");\n        }\n         else qa();\n    ;\n        if (!ha) {\n            va();\n            ha = true;\n        }\n    ;\n        na = null;\n    };\n    function sa() {\n        if (wa.isVisible()) {\n            return\n        };\n        ga = true;\n        na = null;\n        p.show(ka);\n        p.addClass(document.documentElement, \"sidebarMode\");\n        ja.show();\n        oa.rate(\"sidebar_show\", ha);\n        wa.inform(\"sidebar/show\", wa);\n        h.inform(\"sidebar/show\", wa);\n    };\n    function ta() {\n        m.setSetting(\"sidebar_mode\", wa.isEnabled(), \"sidebar\");\n        new j(\"/ajax/chat/settings.php\").setHandler(bagofholding).setErrorHandler(bagofholding).setData({\n            sidebar_mode: wa.isEnabled()\n        }).setAllowCrossPageTransition(true).send();\n    };\n    function ua() {\n        return (t.getList().length <= k.get(\"sidebar.min_friends\"));\n    };\n    function va() {\n        var xa = true;\n        if (!wa.isEnabled()) {\n            oa.log(\"state_not_enabled\");\n            xa = false;\n        }\n    ;\n        if (!wa.isViewportCapable()) {\n            oa.log(\"state_not_shown_viewport\");\n            xa = false;\n        }\n    ;\n        if (fa) {\n            oa.log(\"state_not_shown_hidden\");\n            xa = false;\n        }\n    ;\n        if (ua()) {\n            oa.log(\"state_not_shown_num_friends\");\n            xa = false;\n        }\n    ;\n        if (r.shouldSuppressSidebar()) {\n            oa.log(\"state_not_shown_fbdesktop\");\n            xa = false;\n        }\n    ;\n        oa.log((xa ? \"state_shown\" : \"state_not_shown\"));\n    };\n    var wa = {\n        init: function(xa, ya, za) {\n            wa.init = bagofholding;\n            ia = true;\n            ka = xa;\n            ja = ya;\n            la = za;\n            ca = q.find(xa, \"div.fbChatSidebarBody\");\n            if (k.get(\"chat_sidebar_hovercards\")) {\n                new l(ya);\n            };\n            var ab = new o(xa);\n            ab.subscribe(\"updated\", ra);\n            h.subscribe(\"sidebar/invalidate\", ra);\n            ya.setScrollContainer(q.find(ca, \"div.uiScrollableAreaWrap\"));\n            ya.subscribe([\"render\",\"show\",\"hide\",], ba(function() {\n                var bb = ya.getRoot(), cb = v.getInstance(bb);\n                (cb && cb.adjustGripper());\n            }));\n            Event.listen(window, \"resize\", ra);\n            h.subscribe(\"chat/option-changed\", function(bb, cb) {\n                if ((cb.name == \"sidebar_mode\")) {\n                    ea = !!m.getSetting(\"sidebar_mode\");\n                    ra();\n                }\n            ;\n            });\n            za.subscribe([\"respond\",\"reset\",], function(bb, cb) {\n                if (ga) {\n                    if ((((cb && cb.value) && (cb.value === za.getCore().getValue())) && za.getView().isVisible())) {\n                        ja.hide();\n                    }\n                     else ja.show();\n                \n                };\n            });\n            za.getData().subscribe(\"beforeQuery\", ra);\n            h.subscribe(\"buddylist-nub/initialized\", function(bb, cb) {\n                Event.listen(cb.getButton(), \"click\", function(event) {\n                    wa.enable();\n                    return !wa.shouldShowSidebar();\n                });\n            });\n            ea = !!m.getSetting(\"sidebar_mode\");\n            u.subscribe(\"privacy-user-presence-changed\", ra);\n            ra();\n            y.addRight(wa.getVisibleWidth);\n            wa.inform(\"sidebar/initialized\", wa, h.BEHAVIOR_PERSISTENT);\n            h.inform(\"sidebar/initialized\", wa, h.BEHAVIOR_PERSISTENT);\n        },\n        isInitialized: function() {\n            return ha;\n        },\n        disable: function() {\n            if (!wa.isEnabled()) {\n                return\n            };\n            ea = false;\n            ta();\n            qa();\n        },\n        enable: function() {\n            if (wa.isEnabled()) {\n                return\n            };\n            ea = true;\n            ta();\n            ra();\n            !function() {\n                if (wa.isVisible()) {\n                    la.getCore().getElement().focus();\n                };\n            }.defer();\n        },\n        ensureLoaded: function() {\n            if (ia) {\n                return\n            };\n            d([\"UIPagelet\",], function(xa) {\n                var ya = g.div({\n                    id: \"pagelet_sidebar\"\n                });\n                q.appendContent(document.body, ya);\n                xa.loadFromEndpoint(\"SidebarPagelet\", \"pagelet_sidebar\");\n            });\n            ia = true;\n        },\n        hide: function() {\n            if (fa) {\n                return\n            };\n            fa = true;\n            qa();\n        },\n        unhide: function() {\n            if (!fa) {\n                return\n            };\n            fa = false;\n            ra();\n        },\n        getBody: function() {\n            return ca;\n        },\n        getRoot: function() {\n            return ka;\n        },\n        getVisibleWidth: function() {\n            if ((!ga || !ka)) {\n                return 0\n            };\n            if ((na === null)) {\n                na = ka.offsetWidth;\n            };\n            return na;\n        },\n        isEnabled: function() {\n            return ea;\n        },\n        isViewportCapable: function() {\n            ma = x.getViewportDimensions();\n            var xa = k.get(\"sidebar.minimum_width\");\n            if (da) {\n                xa = k.get(\"sidebar.minimum_width_wide_content\");\n            };\n            return (ma.x > xa);\n        },\n        shouldShowSidebar: function() {\n            return (((wa.isViewportCapable() && !fa) && !ua()) && !r.shouldSuppressSidebar());\n        },\n        isVisible: function() {\n            return ga;\n        },\n        resize: ra,\n        toggle: function() {\n            (wa.isEnabled() ? wa.disable() : wa.enable());\n        },\n        setHasWideContent: function(xa) {\n            if ((da != xa)) {\n                da = xa;\n                ra();\n            }\n        ;\n        }\n    };\n    z(wa, i);\n    e.exports = wa;\n});\n__d(\"VideoCallingTour\", [\"event-extensions\",\"Arbiter\",\"ArbiterMixin\",\"Chat\",\"ChatSidebar\",\"ChatVisibility\",\"CSS\",\"DOM\",\"PresencePrivacy\",\"Run\",\"Toggler\",\"Vector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"Chat\"), j = b(\"ChatSidebar\"), k = b(\"ChatVisibility\"), l = b(\"CSS\"), m = b(\"DOM\"), n = b(\"PresencePrivacy\"), o = b(\"Run\"), p = b(\"Toggler\"), q = b(\"Vector\"), r = b(\"copyProperties\"), s, t, u, v, w = [], x = function() {\n    \n    };\n    function y() {\n        if (j.isVisible()) {\n            z();\n        }\n         else if (u) {\n            aa();\n        }\n    ;\n    };\n    function z() {\n        s.setContext(t.getBody());\n        ba();\n        s.show();\n        ca();\n    };\n    function aa() {\n        if (!v) {\n            v = p.createInstance(u.getRoot());\n        };\n        var fa = m.scry(u.getRoot(), \"div.fbNubFlyout\")[0];\n        if (fa) {\n            s.setContext(fa);\n            ba();\n            s.show();\n            ca();\n        }\n    ;\n    };\n    function ba() {\n        var fa = q.getElementDimensions(s.getContext()).y;\n        s.setOffsetY((fa * 84185));\n        s.updatePosition();\n    };\n    function ca() {\n        if (u) {\n            w.push(u.subscribe(\"hide\", function() {\n                da();\n                if (!j.isVisible()) {\n                    s.hide();\n                };\n            }), u.subscribe(\"show\", function() {\n                s.show();\n            }), u.subscribe(\"resize\", function() {\n                ba();\n                s.updatePosition();\n            }));\n        };\n        w.push(g.subscribe(\"sidebar/show\", z), g.subscribe(\"sidebar/hide\", aa), g.subscribe(\"sidebar/resized\", ba));\n    };\n    function da() {\n        if (v) {\n            v.setSticky(false);\n            v = null;\n        }\n    ;\n    };\n    function ea() {\n        while (w.length) {\n            w.pop().unsubscribe();;\n        };\n        if (u) {\n            da();\n        };\n        s.hide();\n        l.show(\"fbVideoCallingGetStarted\");\n    };\n    r(x, h, {\n        start: function(fa) {\n            s = fa;\n            l.hide(\"fbVideoCallingGetStarted\");\n            k.goOnline(function() {\n                w.push(n.subscribe(\"privacy-user-presence-changed\", ea));\n                o.onLeave(ea);\n                i.openBuddyList();\n                var ga = null;\n                w.push(j.subscribe(\"sidebar/initialized\", function(ha, ia) {\n                    t = ia;\n                    clearTimeout(ga);\n                    ga = y.defer();\n                }), x.subscribe(\"videocallingtour/end\", ea));\n                w.push(g.subscribe(\"buddylist-nub/initialized\", function(ha, ia) {\n                    u = ia;\n                    clearTimeout(ga);\n                    ga = y.defer();\n                }));\n            });\n            x.inform(\"videocallingtour/start\");\n        }\n    });\n    e.exports = x;\n});\n__d(\"ModuleDependencies\", [\"getObjectValues\",], function(a, b, c, d, e, f) {\n    var g = b(\"getObjectValues\");\n    function h(l, m, n) {\n        var o = a.require.__debug.modules[n], p = a.require.__debug.deps;\n        if (m[n]) {\n            return\n        };\n        m[n] = true;\n        if (!o) {\n            (p[n] && (l[n] = true));\n            return;\n        }\n    ;\n        if ((!o.dependencies || !o.dependencies.length)) {\n            if (o.waiting) {\n                l[n] = true;\n            };\n            return;\n        }\n    ;\n        o.dependencies.forEach(function(q) {\n            h(l, m, q);\n        });\n    };\n    function i(l) {\n        if (a.require.__debug) {\n            var m = {\n            };\n            h(m, {\n            }, l);\n            var n = Object.keys(m);\n            n.sort();\n            return n;\n        }\n    ;\n        return null;\n    };\n    function j() {\n        var l = {\n            loading: {\n            },\n            missing: []\n        };\n        if (!a.require.__debug) {\n            return l\n        };\n        var m = {\n        }, n = a.require.__debug.modules, o = a.require.__debug.deps;\n        for (var p in n) {\n            var q = n[p];\n            if (q.waiting) {\n                var r = {\n                };\n                h(r, {\n                }, q.id);\n                delete r[q.id];\n                l.loading[q.id] = Object.keys(r);\n                l.loading[q.id].sort();\n                l.loading[q.id].forEach(function(s) {\n                    if ((!((s in n)) && o[s])) {\n                        m[s] = 1;\n                    };\n                });\n            }\n        ;\n        };\n        l.missing = Object.keys(m);\n        l.missing.sort();\n        return l;\n    };\n    var k = {\n        getMissing: i,\n        getNotLoadedModules: j\n    };\n    e.exports = k;\n});\n__d(\"legacy:ChatSidebar\", [\"ModuleDependencies\",\"JSLogger\",], function(a, b, c, d) {\n    d([\"ChatSidebar\",], function(i) {\n        a.ChatSidebar = i;\n    });\n    var e = b(\"ModuleDependencies\"), f = b(\"JSLogger\"), g = f.create(\"chat_sidebar_load\");\n    function h(i) {\n        setTimeout(function() {\n            if (!a.ChatSidebar) {\n                var j = e.getMissing(\"ChatSidebar\");\n                g.warn((\"require_\" + i), {\n                    missing: j\n                });\n            }\n        ;\n            if ((!a.ChatSidebar || !a.ChatSidebar.isInitialized())) {\n                g.warn((\"init_\" + i), {\n                    missing: j\n                });\n            };\n        }, i);\n    };\n    h(5000);\n    h(10000);\n    h(15000);\n    h(30000);\n    h(60000);\n}, 3);\n__d(\"legacy:ChatTypeaheadBehavior\", [\"ChatTypeaheadBehavior\",], function(a, b, c, d) {\n    var e = b(\"ChatTypeaheadBehavior\");\n    if (!a.TypeaheadBehaviors) {\n        a.TypeaheadBehaviors = {\n        };\n    };\n    a.TypeaheadBehaviors.chatTypeahead = function(f) {\n        f.enableBehavior(e);\n    };\n}, 3);\n__d(\"RangedCallbackManager\", [\"CallbackManagerController\",\"copyProperties\",\"createObjectFrom\",], function(a, b, c, d, e, f) {\n    var g = b(\"CallbackManagerController\"), h = b(\"copyProperties\"), i = b(\"createObjectFrom\"), j = function(k, l, m) {\n        this._resources = [];\n        this._reachedEndOfArray = false;\n        this._existingIDs = {\n        };\n        this._controller = new g(this._constructCallbackArg.bind(this));\n        this._getValueHandler = k;\n        this._compareValuesHandler = l;\n        this._skipOnStrictHandler = m;\n    };\n    h(j.prototype, {\n        executeOrEnqueue: function(k, l, m, n) {\n            return this._controller.executeOrEnqueue({\n                start: k,\n                limit: l\n            }, m, {\n                strict: !!n\n            });\n        },\n        unsubscribe: function(k) {\n            this._controller.unsubscribe(k);\n        },\n        getUnavailableResources: function(k) {\n            var l = this._controller.getRequest(k), m = [];\n            if ((l && !this._reachedEndOfArray)) {\n                var n = l.request, o = this._filterForStrictResults(l.options), p = (n.start + n.limit);\n                for (var q = o.length; (q < p); q++) {\n                    m.push(q);;\n                };\n            }\n        ;\n            return m;\n        },\n        addResources: function(k) {\n            k.forEach(function(l) {\n                if (!this._existingIDs[l]) {\n                    this._existingIDs[l] = true;\n                    this._resources.push(l);\n                }\n            ;\n            }.bind(this));\n            this.resortResources();\n            this._controller.runPossibleCallbacks();\n        },\n        addResourcesWithoutSorting: function(k, l) {\n            var m = this._resources.slice(0, l);\n            m = m.concat(k);\n            m = m.concat(this._resources.slice(l));\n            this._resources = m;\n            h(this._existingIDs, i(k, true));\n            this._controller.runPossibleCallbacks();\n        },\n        removeResources: function(k) {\n            k.forEach(function(l) {\n                if (this._existingIDs[l]) {\n                    this._existingIDs[l] = false;\n                    this._resources.remove(l);\n                }\n            ;\n            }.bind(this));\n        },\n        removeAllResources: function() {\n            this._resources = [];\n            this._existingIDs = {\n            };\n        },\n        resortResources: function() {\n            this._resources = this._resources.sort(function(k, l) {\n                return this._compareValuesHandler(this._getValueHandler(k), this._getValueHandler(l));\n            }.bind(this));\n        },\n        setReachedEndOfArray: function() {\n            if (!this._reachedEndOfArray) {\n                this._reachedEndOfArray = true;\n                this._controller.runPossibleCallbacks();\n            }\n        ;\n        },\n        hasReachedEndOfArray: function() {\n            return this._reachedEndOfArray;\n        },\n        hasResource: function(k) {\n            return this._existingIDs[k];\n        },\n        getResourceAtIndex: function(k) {\n            return this._resources[k];\n        },\n        getAllResources: function() {\n            return this._resources.concat();\n        },\n        getCurrentArraySize: function() {\n            return this._resources.length;\n        },\n        _filterForStrictResults: function(k) {\n            var l = this._resources;\n            if (((k && k.strict) && this._skipOnStrictHandler)) {\n                l = l.filter(this._skipOnStrictHandler);\n            };\n            return l;\n        },\n        _constructCallbackArg: function(k, l) {\n            var m = this._filterForStrictResults(l);\n            if ((!this._reachedEndOfArray && ((k.start + k.limit) > m.length))) {\n                return false;\n            }\n             else return m.slice(k.start, (k.start + k.limit))\n        ;\n        },\n        getElementsUntil: function(k) {\n            var l = [];\n            for (var m = 0; (m < this._resources.length); m++) {\n                var n = this._getValueHandler(this._resources[m]);\n                if ((this._compareValuesHandler(n, k) > 0)) {\n                    break;\n                };\n                l.push(this._resources[m]);\n            };\n            return l;\n        }\n    });\n    e.exports = j;\n});\n__d(\"TimestampConverter\", [\"JSLogger\",], function(a, b, c, d, e, f) {\n    var g = b(\"JSLogger\"), h = g.create(\"timestamp_converter\");\n    function i(k) {\n        return (((typeof (k) == \"string\")) && (k.length > 6));\n    };\n    var j = {\n        convertActionIDToTimestamp: function(k) {\n            if (i(k)) {\n                var l = k.slice(0, -6);\n                return parseInt(l, 10);\n            }\n        ;\n        },\n        maxValidActionID: function(k, l) {\n            if (!i(k)) {\n                return l\n            };\n            if (!i(l)) {\n                return k\n            };\n            return (this.isGreaterThan(k, l) ? k : l);\n        },\n        isGreaterThan: function(k, l) {\n            if ((!i(k) || !i(l))) {\n                return false\n            };\n            return (this.convertActionIDToTimestamp(k) > this.convertActionIDToTimestamp(l));\n        }\n    };\n    e.exports = j;\n});\n__d(\"MercuryFolders\", [\"array-extensions\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    var g = c(\"MercuryConstants\"), h = [g.MessagingTag.INBOX,g.MessagingTag.OTHER,g.MessagingTag.ACTION_ARCHIVED,g.MessagingTag.SPAM,], i = {\n        getSupportedFolders: function() {\n            return h.concat();\n        },\n        isSupportedFolder: function(j) {\n            return h.contains(j);\n        },\n        getFromMeta: function(j) {\n            var k = j.folder;\n            if (j.is_archived) {\n                k = g.MessagingTag.ACTION_ARCHIVED;\n            };\n            return k;\n        }\n    };\n    e.exports = i;\n});\n__d(\"MercuryIDs\", [], function(a, b, c, d, e, f) {\n    function g(h) {\n        return ((typeof h === \"string\") && (h.indexOf(\":\") !== -1));\n    };\n    e.exports = {\n        isValid: function(h) {\n            if (!h) {\n                return false\n            };\n            return g(h);\n        },\n        tokenize: function(h) {\n            if (!this.isValid(h)) {\n                throw \"bad_id_format\"\n            };\n            var i = h.indexOf(\":\");\n            return {\n                type: h.substr(0, i),\n                value: h.substr((i + 1))\n            };\n        }\n    };\n});\n__d(\"MercuryAssert\", [\"MercuryIDs\",], function(a, b, c, d, e, f) {\n    var g = b(\"MercuryIDs\");\n    e.exports = {\n        isParticipantID: function(h) {\n            if (!g.isValid(h)) {\n                throw \"bad_participant_id\"\n            };\n        },\n        allParticipantIDs: function(h) {\n            h.forEach(this.isParticipantID);\n        },\n        isUserParticipantID: function(h) {\n            var i = g.tokenize(h);\n            if ((i.type != \"fbid\")) {\n                throw \"bad_user_id\"\n            };\n        },\n        isEmailParticipantID: function(h) {\n            var i = g.tokenize(h);\n            if ((i.type != \"email\")) {\n                throw \"bad_email_id\"\n            };\n        },\n        allThreadID: function(h) {\n            h.forEach(this.isThreadID);\n        },\n        isThreadID: function(h) {\n            if (!g.isValid(h)) {\n                throw \"bad_thread_id\"\n            };\n        }\n    };\n});\n__d(\"MercuryAttachment\", [\"startsWith\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"startsWith\"), h = c(\"MercuryConstants\"), i = {\n        getAttachIconClass: function(j) {\n            switch (j) {\n              case h.MercuryAttachmentContentType.PHOTO:\n                return \"MercuryPhotoIcon\";\n              case h.MercuryAttachmentContentType.VIDEO:\n                return \"MercuryVideoIcon\";\n              case h.MercuryAttachmentContentType.MUSIC:\n                return \"MercuryMusicIcon\";\n              case h.MercuryAttachmentContentType.TEXT:\n                return \"MercuryTextIcon\";\n              case h.MercuryAttachmentContentType.MSWORD:\n                return \"MercuryMSWordIcon\";\n              case h.MercuryAttachmentContentType.MSXLS:\n                return \"MercuryMSXLSIcon\";\n              case h.MercuryAttachmentContentType.MSPPT:\n                return \"MercuryMSPPTIcon\";\n            };\n            return \"MercuryDefaultIcon\";\n        },\n        getAttachIconClassByMime: function(j) {\n            if (g(j, \"image\")) {\n                return \"MercuryPhotoIcon\";\n            }\n             else if (g(j, \"video\")) {\n                return \"MercuryVideoIcon\";\n            }\n             else if (g(j, \"audio\")) {\n                return \"MercuryMusicIcon\";\n            }\n             else if (g(j, \"text/plain\")) {\n                return \"MercuryTextIcon\";\n            }\n             else return \"MercuryDefaultIcon\"\n            \n            \n            \n        ;\n        },\n        getAttachTypeByMime: function(j) {\n            if (g(j, \"image\")) {\n                return h.MercuryAttachmentContentType.PHOTO;\n            }\n             else if (g(j, \"video\")) {\n                return h.MercuryAttachmentContentType.VIDEO;\n            }\n             else if (g(j, \"audio\")) {\n                return h.MercuryAttachmentContentType.MUSIC;\n            }\n             else if (g(j, \"text/plain\")) {\n                return h.MercuryAttachmentContentType.TEXT;\n            }\n             else return h.MercuryAttachmentContentType.UNKNOWN\n            \n            \n            \n        ;\n        },\n        convertRaw: function(j) {\n            var k = [];\n            for (var l = 0; (l < j.length); l++) {\n                var m = j[l];\n                if (m.filename) {\n                    var n = {\n                    };\n                    n.attach_type = h.MercuryAttachmentType.FILE;\n                    n.name = m.filename;\n                    n.icon_type = i.getAttachTypeByMime(m.filetype);\n                    n.url = \"#\";\n                    k.push(n);\n                }\n            ;\n            };\n            return k;\n        }\n    };\n    e.exports = i;\n});\n__d(\"MercuryMessageIDs\", [\"KeyedCallbackManager\",], function(a, b, c, d, e, f) {\n    var g = b(\"KeyedCallbackManager\"), h = new g(), i = {\n        getServerIDs: function(j, k) {\n            var l = j.filter(function(n) {\n                return (n.indexOf(\"mail.projektitan.com\") !== -1);\n            }), m = function(n) {\n                var o = j.map(function(p) {\n                    return (n[p] ? n[p] : p);\n                });\n                k(o);\n            };\n            return h.executeOrEnqueue(l, m);\n        },\n        addServerID: function(j, k) {\n            h.setResource(j, k);\n        }\n    };\n    e.exports = i;\n});\n__d(\"MercuryServerDispatcher\", [\"AsyncRequest\",\"JSLogger\",\"URI\",\"areObjectsEqual\",\"copyProperties\",\"debounceAcrossTransitions\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncRequest\"), h = b(\"JSLogger\"), i = b(\"URI\"), j = b(\"areObjectsEqual\"), k = b(\"copyProperties\"), l = b(\"debounceAcrossTransitions\"), m = {\n    }, n = h.create(\"mercury_dispatcher\"), o = false, p = {\n        IMMEDIATE: \"immediate\",\n        IDEMPOTENT: \"idempotent\",\n        BATCH_SUCCESSIVE: \"batch-successive\",\n        BATCH_SUCCESSIVE_UNIQUE: \"batch-successive-unique\",\n        BATCH_SUCCESSIVE_PIGGYBACK_ON_ERROR: \"batch-successive-piggyback-retry\",\n        BATCH_DEFERRED_MULTI: \"batch-deferred-multi\",\n        BATCH_CONDITIONAL: \"batch-conditional\",\n        registerEndpoints: function(r) {\n            for (var s in r) {\n                var t = r[s];\n                m[s] = new q(s, t);\n            };\n        },\n        trySend: function(r, s, t) {\n            m[r].trySend(s, t);\n        }\n    };\n    function q(r, s) {\n        var t = (s.mode || p.IMMEDIATE);\n        switch (t) {\n          case p.IMMEDIATE:\n        \n          case p.IDEMPOTENT:\n        \n          case p.BATCH_SUCCESSIVE:\n        \n          case p.BATCH_SUCCESSIVE_UNIQUE:\n        \n          case p.BATCH_SUCCESSIVE_PIGGYBACK_ON_ERROR:\n        \n          case p.BATCH_DEFERRED_MULTI:\n        \n          case p.BATCH_CONDITIONAL:\n            break;\n          default:\n            throw new Error((\"Invalid MercuryServerDispatcher mode \" + t));\n        };\n        this._endpoint = r;\n        this._mode = t;\n        this._combineData = s.batch_function;\n        this._combineDataIf = s.batch_if;\n        this._handler = s.handler;\n        this._errorHandler = s.error_handler;\n        this._transportErrorHandler = (s.transport_error_handler || s.error_handler);\n        this._serverDialogCancelHandler = (s.server_dialog_cancel_handler || s.error_handler);\n        this._deferredSend = l(this._batchSend, 0, this);\n    };\n    k(q.prototype, {\n        _inFlight: 0,\n        _handler: null,\n        _errorHandler: null,\n        _transportErrorHandler: null,\n        _serverDialogCancelHandler: null,\n        _combineData: null,\n        _pendingRequestData: null,\n        trySend: function(r, s) {\n            if (o) {\n                return\n            };\n            if ((typeof r == \"undefined\")) {\n                r = null;\n            };\n            var t = (s || this._mode);\n            if ((t == p.IMMEDIATE)) {\n                this._send(r);\n            }\n             else if ((t == p.IDEMPOTENT)) {\n                if (!this._inFlight) {\n                    this._send(r);\n                };\n            }\n             else if (((t == p.BATCH_SUCCESSIVE) || (t == p.BATCH_SUCCESSIVE_UNIQUE))) {\n                if (!this._inFlight) {\n                    this._send(r);\n                }\n                 else this._batchData(r);\n            ;\n            }\n             else if ((t == p.BATCH_CONDITIONAL)) {\n                if ((this._inFlight && ((this._combineDataIf(this._pendingRequestData, r) || this._combineDataIf(this._batchedData, r))))) {\n                    this._batchData(r);\n                }\n                 else this._send(r);\n            ;\n            }\n             else if ((t == p.BATCH_DEFERRED_MULTI)) {\n                this._batchData(r);\n                this._deferredSend();\n            }\n             else if ((t == p.BATCH_SUCCESSIVE_PIGGYBACK_ON_ERROR)) {\n                this._batchData(r);\n                if (!this._inFlight) {\n                    this._batchSend();\n                };\n            }\n            \n            \n            \n            \n            \n        ;\n        },\n        _send: function(r) {\n            this._inFlight++;\n            this._pendingRequestData = k({\n            }, r);\n            n.log(\"send\", {\n                endpoint: this._endpoint,\n                data: r,\n                inflight_count: this._inFlight\n            });\n            new g(this._endpoint).setData(r).setHandler(this._handleResponse.bind(this)).setErrorHandler(this._handleError.bind(this)).setTransportErrorHandler(this._handleTransportError.bind(this)).setServerDialogCancelHandler(this._handleServerDialogCancel.bind(this)).setAllowCrossPageTransition(true).send();\n        },\n        _batchData: function(r) {\n            if ((((this._mode == p.BATCH_SUCCESSIVE_UNIQUE) && this._pendingRequestData) && j(r, this._pendingRequestData))) {\n                return;\n            }\n             else if ((typeof this._batchedData == \"undefined\")) {\n                this._batchedData = r;\n            }\n             else this._batchedData = this._combineData(this._batchedData, r);\n            \n        ;\n        },\n        _batchSend: function() {\n            if ((typeof this._batchedData != \"undefined\")) {\n                this._send(this._batchedData);\n                delete this._batchedData;\n            }\n        ;\n        },\n        _handleResponse: function(r) {\n            this._inFlight--;\n            n.log(\"response\", {\n                endpoint: this._endpoint,\n                inflight_count: this._inFlight\n            });\n            var s = r.getPayload();\n            o = (s && s.kill_chat);\n            if (o) {\n                n.log(\"killswitch_enabled\", {\n                    endpoint: this._endpoint,\n                    inflight_count: this._inFlight\n                });\n            };\n            if ((s && s.error_payload)) {\n                if (this._errorHandler) {\n                    this._errorHandler(r);\n                };\n            }\n             else (this._handler && this._handler(s));\n        ;\n            if (((((this._mode == p.BATCH_SUCCESSIVE) || (this._mode == p.BATCH_SUCCESSIVE_UNIQUE)) || (this._mode == p.BATCH_SUCCESSIVE_PIGGYBACK_ON_ERROR)) || (this._mode == p.BATCH_CONDITIONAL))) {\n                this._batchSend();\n            };\n            this._pendingRequestData = null;\n        },\n        _handleErrorCommon: function(r, s) {\n            n.error(\"error\", {\n                endpoint: this._endpoint,\n                inflight_count: (this._inFlight - 1)\n            });\n            (s && s(r));\n            this._inFlight--;\n            var t = this._mode;\n            if ((((t == p.BATCH_SUCCESSIVE) || (t == p.BATCH_SUCCESSIVE_UNIQUE)) || (t == p.BATCH_CONDITIONAL))) {\n                this._batchSend();\n            }\n             else if ((t == p.BATCH_SUCCESSIVE_PIGGYBACK_ON_ERROR)) {\n                if ((typeof this._batchedData == \"undefined\")) {\n                    this._batchedData = this._pendingRequestData;\n                }\n                 else {\n                    this._batchedData = this._combineData(this._pendingRequestData, this._batchedData);\n                    this._batchSend();\n                }\n            \n            }\n        ;\n            this._pendingRequestData = null;\n        },\n        _handleError: function(r) {\n            this._handleErrorCommon(r, this._errorHandler);\n        },\n        _handleTransportError: function(r) {\n            this._handleErrorCommon(r, this._transportErrorHandler);\n        },\n        _handleServerDialogCancel: function(r) {\n            this._handleErrorCommon(r, this._serverDialogCancelHandler);\n        }\n    });\n    e.exports = p;\n});\n__d(\"MercuryThreadInformer\", [\"Arbiter\",\"copyProperties\",\"MercuryAssert\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"copyProperties\"), i = b(\"MercuryAssert\"), j = {\n    }, k = {\n    }, l = {\n    }, m = false, n = false, o = false, p = {\n    }, q = {\n    }, r = {\n    }, s = 0;\n    function t() {\n        if (!s) {\n            var v = j, w = k, x = l, y = m, z = n, aa = o, ba = p, ca = q, da = r;\n            j = {\n            };\n            k = {\n            };\n            l = {\n            };\n            m = false;\n            n = false;\n            o = false;\n            p = {\n            };\n            q = {\n            };\n            r = {\n            };\n            var ea = Object.keys(w);\n            if ((ea.length || y)) {\n                u.inform(\"threadlist-updated\", ea);\n            };\n            if (ea.length) {\n                u.inform(\"threads-updated\", w);\n            };\n            for (var fa in x) {\n                u.inform(\"thread-read-changed\", x);\n                break;\n            };\n            for (var fa in v) {\n                u.inform(\"threads-deleted\", v);\n                break;\n            };\n            if (z) {\n                u.inform(\"unseen-updated\", null);\n            };\n            if (aa) {\n                u.inform(\"unread-updated\", null);\n            };\n            for (fa in ba) {\n                u.inform(\"messages-received\", ba);\n                break;\n            };\n            for (fa in ca) {\n                u.inform(\"messages-reordered\", ca);\n                break;\n            };\n            for (fa in da) {\n                u.inform(\"messages-updated\", da);\n                break;\n            };\n        }\n    ;\n    };\n    var u = h(new g(), {\n        updatedThread: function(v) {\n            k[v] = true;\n            t();\n        },\n        deletedThread: function(v) {\n            j[v] = true;\n            t();\n        },\n        updatedThreadlist: function() {\n            m = true;\n            t();\n        },\n        updatedUnseenState: function() {\n            n = true;\n            t();\n        },\n        updatedUnreadState: function() {\n            o = true;\n            t();\n        },\n        changedThreadReadState: function(v, w, x) {\n            if ((!l[v] || (l[v].timestamp < x))) {\n                l[v] = {\n                    mark_as_read: w,\n                    timestamp: x\n                };\n            };\n            t();\n        },\n        receivedMessage: function(v) {\n            i.isThreadID(v.thread_id);\n            var w = v.thread_id;\n            if (!p[w]) {\n                p[w] = [];\n            };\n            p[w].push(v);\n            u.updatedThread(w);\n        },\n        reorderedMessages: function(v, w) {\n            q[v] = {\n                source: w\n            };\n            t();\n        },\n        updatedMessage: function(v, w, x) {\n            if (!r[v]) {\n                r[v] = {\n                };\n            };\n            r[v][w] = {\n                source: x\n            };\n            t();\n        },\n        synchronizeInforms: function(v) {\n            s++;\n            try {\n                v();\n            } catch (w) {\n                throw w;\n            } finally {\n                s--;\n                t();\n            };\n        },\n        listen: function(v, w) {\n            return u.subscribe(\"threads-updated\", function(x, y) {\n                if (y[v]) {\n                    w(v);\n                };\n            });\n        }\n    });\n    e.exports = u;\n});\n__d(\"MessagingReliabilityLogger\", [\"function-extensions\",\"AsyncRequest\",\"copyProperties\",\"isEmpty\",\"PresenceUtil\",\"Run\",\"MercuryServerDispatcher\",\"setTimeoutAcrossTransitions\",\"MessagingReliabilityLoggerInitialData\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"AsyncRequest\"), h = b(\"copyProperties\"), i = b(\"isEmpty\"), j = b(\"PresenceUtil\"), k = b(\"Run\"), l = b(\"MercuryServerDispatcher\"), m = b(\"setTimeoutAcrossTransitions\"), n = c(\"MessagingReliabilityLoggerInitialData\"), o = \"/ajax/mercury/client_reliability.php\", p = 60000;\n    function q(w, x) {\n        var y = {\n            app: n.app,\n            categories: JSON.stringify(w)\n        };\n        if (!i(x)) {\n            y.extra = JSON.stringify(x);\n        };\n        return y;\n    };\n    function r(w, x, y, z) {\n        if ((w[x] === undefined)) {\n            w[x] = {\n            };\n        };\n        if ((w[x][y] === undefined)) {\n            w[x][y] = 0;\n        };\n        w[x][y] += z;\n    };\n    function s(w, x, y, z) {\n        if ((w[x] === undefined)) {\n            w[x] = {\n            };\n        };\n        if ((w[x][y] === undefined)) {\n            w[x][y] = [];\n        };\n        for (var aa = 0; (aa < z.length); ++aa) {\n            w[x][y].push(z[aa]);;\n        };\n    };\n    function t(w, x) {\n        if ((!w.categories || !x.categories)) {\n            return\n        };\n        var y = JSON.parse(w.categories), z = (w.extra ? JSON.parse(w.extra) : {\n        }), aa = JSON.parse(x.categories), ba = (x.extra ? JSON.parse(x.extra) : {\n        });\n        for (var ca in aa) {\n            var da = aa[ca], ea = ba[ca];\n            for (var fa in da) {\n                r(y, ca, fa, da[fa]);\n                if ((ea !== undefined)) {\n                    var ga = ea[fa];\n                    if ((ga !== undefined)) {\n                        s(z, ca, fa, ga);\n                    };\n                }\n            ;\n            };\n        };\n        return q(y, z);\n    };\n    var u = {\n    };\n    u[o] = {\n        mode: l.BATCH_SUCCESSIVE_PIGGYBACK_ON_ERROR,\n        batch_function: t\n    };\n    l.registerEndpoints(u);\n    var v = {\n        addEntry: function(w, x, y) {\n            if (!n.enabled) {\n                return\n            };\n            var z = {\n            };\n            r(z, w, x, 1);\n            var aa = {\n            };\n            if ((y !== undefined)) {\n                s(aa, w, x, [y,]);\n            };\n            l.trySend(o, q(z, aa));\n        }\n    };\n    (function w() {\n        v.addEntry(\"page_event\", \"active\", j.getSessionID());\n        m(w, p);\n    })();\n    e.exports = v;\n});\n__d(\"MercuryServerRequests\", [\"Arbiter\",\"AsyncResponse\",\"KeyedCallbackManager\",\"TimestampConverter\",\"copyProperties\",\"Env\",\"JSLogger\",\"MercuryAssert\",\"MercuryMessageIDs\",\"MercuryServerDispatcher\",\"MercuryThreadInformer\",\"MercuryIDs\",\"MessagingReliabilityLogger\",\"createObjectFrom\",\"hasArrayNature\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AsyncResponse\"), i = b(\"KeyedCallbackManager\"), j = b(\"TimestampConverter\"), k = b(\"copyProperties\"), l = b(\"Env\"), m = b(\"JSLogger\"), n = b(\"MercuryAssert\"), o = b(\"MercuryMessageIDs\"), p = b(\"MercuryServerDispatcher\"), q = b(\"MercuryThreadInformer\"), r = b(\"MercuryIDs\"), s = b(\"MessagingReliabilityLogger\"), t = b(\"createObjectFrom\"), u = b(\"hasArrayNature\"), v = c(\"MercuryConstants\"), w = v.MercuryGenericConstants, x = 0, y = m.create(\"mercury_server\"), z = new i(), aa = new i(), ba = [], ca = {\n    }, da = {\n    };\n    function ea(ab) {\n        if (ab) {\n            x = j.maxValidActionID(x, ab);\n        };\n    };\n    function fa(ab) {\n        var bb = ab.thread_id, cb = z.getResource(bb);\n        if (!cb) {\n            if (ab.is_canonical) {\n                if ((ab.canonical_fbid === undefined)) {\n                    var db = ab.participants.filter(function(fb) {\n                        return (fb != (\"fbid:\" + l.user));\n                    });\n                    if (db.length) {\n                        var eb = r.tokenize(db[0]);\n                        if ((eb.type == \"email\")) {\n                            ab.canonical_email = eb.value;\n                        }\n                         else ab.canonical_fbid = eb.value;\n                    ;\n                    }\n                     else ab.canonical_fbid = l.user;\n                ;\n                }\n            ;\n                cb = (ab.canonical_fbid ? (\"user:\" + ab.canonical_fbid) : (\"email:\" + ab.canonical_email));\n            }\n             else if (ab.is_canonical_group) {\n                cb = (\"group:\" + ab.group_id);\n            }\n             else if (ab.root_message_threading_id) {\n                cb = (\"root:\" + ab.root_message_threading_id);\n            }\n            \n        ;\n            cb = (cb || (\"thread:\" + bb));\n            ga(bb, cb);\n        }\n    ;\n        ab.thread_id = cb;\n    };\n    function ga(ab, bb) {\n        z.setResource(ab, bb);\n        aa.setResource(bb, ab);\n        da[ab] = bb;\n    };\n    function ha(ab, bb) {\n        var cb = aa.executeOrEnqueue(ab, bb), db = aa.getUnavailableResources(cb), eb = xa.tokenizeThreadID(ab);\n        if ((db.length && (eb.type != \"root\"))) {\n            xa.fetchThreadData(db);\n        };\n    };\n    function ia(ab) {\n        return aa.getResource(ab);\n    };\n    function ja(ab) {\n        return !!z.getResource(ab);\n    };\n    function ka(ab) {\n        var bb = z.getResource(ab);\n        if ((typeof bb == \"undefined\")) {\n            y.warn(\"no_client_thread_id\", {\n                server_id: ab\n            });\n        };\n        return bb;\n    };\n    function la(ab, bb) {\n        z.executeOrEnqueue(ab, bb);\n        xa.ensureThreadIsFetched(ab);\n    };\n    function ma(ab, bb) {\n        if ((ab.action_type != v.MercuryActionType.SEND_MESSAGE)) {\n            return\n        };\n        var cb = ab.client_thread_id;\n        if (!cb) {\n            cb = ka(ab.thread_id);\n        };\n        var db = null;\n        if (cb) {\n            db = r.tokenize(cb).type;\n        };\n        s.addEntry((\"send_\" + db), bb, ((ab.thread_id + \",\") + ab.message_id));\n    };\n    function na(ab) {\n        var bb = null;\n        switch (ab.status) {\n          case v.MercuryActionStatus.SUCCESS:\n            bb = \"success\";\n            break;\n          case v.MercuryActionStatus.FAILED_UNKNOWN_REASON:\n            bb = \"confirmed_error\";\n            break;\n          case v.MercuryActionStatus.UNABLE_TO_CONFIRM:\n            bb = \"confirm_error\";\n            break;\n          default:\n            return;\n        };\n        ma(ab, bb);\n    };\n    function oa(ab) {\n        ((ab.message_counts || [])).forEach(function(jb) {\n            ea(jb.last_action_id);\n        });\n        ((ab.threads || [])).forEach(function(jb) {\n            fa(jb);\n            delete ca[jb.thread_id];\n            delete ca[ia(jb.thread_id)];\n            ea(jb.last_action_id);\n        });\n        ((ab.ordered_threadlists || [])).forEach(function(jb) {\n            jb.thread_ids = jb.thread_ids.map(ka);\n        });\n        ab.actions = (ab.actions || []);\n        ab.actions.forEach(function(jb) {\n            na(jb);\n            if (((jb.status && (jb.status != v.MercuryActionStatus.SUCCESS)) && !jb.thread_id)) {\n                jb.thread_id = jb.client_thread_id;\n                return;\n            }\n        ;\n            if ((((jb.action_type == v.MercuryActionType.SEND_MESSAGE) && jb.client_thread_id) && (jb.client_thread_id != w.PENDING_THREAD_ID))) {\n                ga(jb.thread_id, jb.client_thread_id);\n            };\n            jb.server_thread_id = jb.thread_id;\n            jb.thread_id = (ja(jb.thread_id) ? ka(jb.thread_id) : null);\n            ea(jb.action_id);\n        });\n        if (ab.end_of_history) {\n            var bb = [];\n            for (var cb = 0; (cb < ab.end_of_history.length); cb++) {\n                var db = ab.end_of_history[cb];\n                if ((db.type == \"user\")) {\n                    bb.push((\"user:\" + db.id));\n                }\n                 else if (((db.type == \"thread\") && ja(db.id))) {\n                    bb.push(ka(db.id));\n                }\n            ;\n            };\n            ab.end_of_history = bb;\n        }\n    ;\n        if (ab.roger) {\n            var eb = {\n            };\n            for (var fb in ab.roger) {\n                var gb = z.getResource(fb);\n                if (gb) {\n                    var hb = ab.roger[fb];\n                    eb[gb] = {\n                    };\n                    for (var ib in hb) {\n                        eb[gb][(\"fbid:\" + ib)] = hb[ib];;\n                    };\n                }\n            ;\n            };\n            ab.roger = eb;\n        }\n    ;\n    };\n    function pa() {\n        if ((ba && ba.length)) {\n            var ab = ba[0];\n            ba = ba.slice(1);\n            xa.handleUpdate(ab);\n        }\n    ;\n    };\n    function qa(ab, bb) {\n        var cb = k({\n        }, ab), db;\n        if (bb.threads) {\n            if (!cb.threads) {\n                cb.threads = {\n                };\n            };\n            for (db in bb.threads) {\n                cb.threads[db] = Object.keys(t(((cb.threads[db] || [])).concat(bb.threads[db])));;\n            };\n        }\n    ;\n        if (bb.messages) {\n            if (!cb.messages) {\n                cb.messages = {\n                };\n            };\n            for (db in bb.messages) {\n                if (!cb.messages[db]) {\n                    cb.messages[db] = {\n                    };\n                };\n                for (var eb in bb.messages[db]) {\n                    if (cb.messages[db][eb]) {\n                        cb.messages[db][eb] = ta(cb.messages[db][eb], bb.messages[db][eb]);\n                    }\n                     else cb.messages[db][eb] = bb.messages[db][eb];\n                ;\n                };\n            };\n        }\n    ;\n        return cb;\n    };\n    function ra(ab, bb) {\n        var cb = k(t(ab.folders, true), t(bb.folders, true));\n        return {\n            folders: Object.keys(cb)\n        };\n    };\n    function sa(ab, bb) {\n        for (var cb in bb) {\n            if (ab[cb]) {\n                ab[cb] = ta(ab[cb], bb[cb]);\n            }\n             else {\n                var db = {\n                };\n                k(db, bb[cb]);\n                ab[cb] = db;\n            }\n        ;\n        };\n        return ab;\n    };\n    function ta(ab, bb) {\n        var cb = ((ab.offset < bb.offset) ? ab.offset : bb.offset), db = (ab.offset + ab.limit), eb = (bb.offset + bb.limit), fb = (((db > eb)) ? db : eb), gb = (fb - cb);\n        return {\n            offset: cb,\n            limit: gb\n        };\n    };\n    function ua(ab, bb) {\n        var cb = {\n            ids: {\n            }\n        };\n        k(cb.ids, ab.ids);\n        k(cb.ids, bb.ids);\n        return cb;\n    };\n    function va(ab, bb) {\n        var cb = {\n        }, db;\n        for (db in ab) {\n            k(cb, t(ab[db], db));;\n        };\n        for (db in bb) {\n            k(cb, t(bb[db], db));;\n        };\n        var eb = {\n        };\n        for (var fb in cb) {\n            db = cb[fb];\n            if (!eb[db]) {\n                eb[db] = [];\n            };\n            eb[db].push(fb);\n        };\n        return eb;\n    };\n    function wa(ab, bb) {\n        var cb = t(ab.ids, true), db = t(bb.ids, true), eb = k(cb, db);\n        return {\n            ids: Object.keys(eb)\n        };\n    };\n    var xa = k(new g(), {\n        tokenizeThreadID: function(ab) {\n            n.isThreadID(ab);\n            return r.tokenize(ab);\n        },\n        getServerThreadID: function(ab, bb) {\n            n.isThreadID(ab);\n            ha(ab, bb);\n        },\n        getClientThreadID: function(ab, bb) {\n            la(ab, bb);\n        },\n        getClientThreadIDNow: function(ab) {\n            return ka(ab);\n        },\n        getServerThreadIDNow: function(ab) {\n            return ia(ab);\n        },\n        convertThreadIDIfAvailable: function(ab) {\n            var bb = z.getResource(ab);\n            if ((bb === undefined)) {\n                return ab;\n            }\n             else return bb\n        ;\n        },\n        canLinkExternally: function(ab) {\n            n.isThreadID(ab);\n            var bb = xa.tokenizeThreadID(ab);\n            return (((bb.type == \"user\")) || !!ia(ab));\n        },\n        fetchThreadlistInfo: function(ab, bb, cb, db) {\n            cb = (cb || v.MessagingTag.INBOX);\n            var eb = (db ? p.IMMEDIATE : null), fb = {\n            };\n            fb[cb] = {\n                offset: ab,\n                limit: bb,\n                filter: db\n            };\n            p.trySend(\"/ajax/mercury/threadlist_info.php\", fb, eb);\n        },\n        fetchUnseenThreadIDs: function(ab) {\n            xa.fetchThreadlistInfo(v.MercuryThreadlistConstants.RECENT_THREAD_OFFSET, v.MercuryThreadlistConstants.JEWEL_THREAD_COUNT, ab);\n        },\n        fetchUnreadThreadIDs: function(ab) {\n            p.trySend(\"/ajax/mercury/unread_threads.php\", {\n                folders: [ab,]\n            });\n        },\n        fetchMissedMessages: function(ab) {\n            p.trySend(\"/ajax/mercury/thread_sync.php\", {\n                last_action_id: x,\n                folders: ab\n            });\n        },\n        fetchThreadData: function(ab) {\n            n.allThreadID(ab);\n            var bb = {\n                threads: {\n                }\n            }, cb = [], db = [], eb = [], fb = [];\n            ab.forEach(function(hb) {\n                if (ca[hb]) {\n                    return\n                };\n                ca[hb] = true;\n                var ib = ia(hb);\n                if (ib) {\n                    db.push(ib);\n                    bb.threads.thread_ids = db;\n                }\n                 else {\n                    var jb = xa.tokenizeThreadID(hb);\n                    if ((jb.type == \"user\")) {\n                        cb.push(jb.value);\n                        bb.threads.user_ids = cb;\n                    }\n                     else if ((jb.type == \"group\")) {\n                        eb.push(jb.value);\n                        bb.threads.group_ids = eb;\n                    }\n                     else if ((jb.type == \"thread\")) {\n                        db.push(jb.value);\n                        bb.threads.thread_ids = db;\n                    }\n                     else if ((((jb.type != \"root\") && (jb.type != \"email\")) && (jb.type != \"pending\"))) {\n                        throw new Error(\"Unknown thread type\", jb)\n                    }\n                    \n                    \n                ;\n                }\n            ;\n            });\n            xa.inform(\"fetch-thread-data\", bb);\n            for (var gb in bb.threads) {\n                p.trySend(\"/ajax/mercury/thread_info.php\", bb);\n                break;\n            };\n        },\n        ensureThreadIsFetched: function(ab) {\n            if ((!z.getResource(ab) && !ca[ab])) {\n                ca[ab] = true;\n                p.trySend(\"/ajax/mercury/thread_info.php\", {\n                    threads: {\n                        thread_ids: [ab,]\n                    }\n                });\n            }\n        ;\n        },\n        fetchThreadMessages: function(ab, bb, cb, db) {\n            n.isThreadID(ab);\n            var eb, fb, gb = xa.tokenizeThreadID(ab), hb = ia(ab), ib = false;\n            if ((hb && (gb.type != \"group\"))) {\n                fb = \"thread_ids\";\n                eb = hb;\n            }\n             else {\n                eb = gb.value;\n                switch (gb.type) {\n                  case \"user\":\n                    fb = \"user_ids\";\n                    ib = true;\n                    break;\n                  case \"group\":\n                    fb = \"group_ids\";\n                    break;\n                  case \"thread\":\n                    fb = \"thread_ids\";\n                    break;\n                };\n            }\n        ;\n            var jb = {\n                messages: {\n                },\n                threads: {\n                }\n            };\n            if (fb) {\n                jb.messages[fb] = {\n                };\n                jb.messages[fb][eb] = {\n                    offset: bb,\n                    limit: cb\n                };\n                if (ib) {\n                    jb.threads[fb] = [eb,];\n                };\n                p.trySend(\"/ajax/mercury/thread_info.php\", jb, db);\n            }\n             else ha(ab, function(kb) {\n                jb.messages.thread_ids = {\n                };\n                jb.messages.thread_ids[kb] = {\n                    offset: bb,\n                    limit: cb\n                };\n                p.trySend(\"/ajax/mercury/thread_info.php\", jb, db);\n            });\n        ;\n        },\n        handleThreadInfoError: function(ab) {\n            var bb = ab.getRequest().getData(), cb = [];\n            if (bb.messages) {\n                for (var db in bb.messages.thread_ids) {\n                    cb.push(ya(ka(db)));;\n                };\n                for (var eb in bb.messages.user_ids) {\n                    cb.push(ya((\"user:\" + eb)));;\n                };\n                for (var fb in bb.messages.group_ids) {\n                    cb.push(ya((\"group:\" + fb)));;\n                };\n            }\n        ;\n            if (cb.length) {\n                xa.handleUpdate({\n                    actions: cb,\n                    from_client: true,\n                    payload_source: v.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE\n                });\n            };\n            if (((bb.threads && (((bb.threads.user_ids || bb.threads.group_ids) || bb.threads.thread_ids))) && !bb.is_retry)) {\n                if (bb.messages) {\n                    delete bb.messages;\n                };\n                y.log(\"retry_thread\", bb);\n                bb.is_retry = true;\n                p.trySend(\"/ajax/mercury/thread_info.php\", bb);\n            }\n        ;\n        },\n        markFolderAsRead: function(ab) {\n            p.trySend(\"/ajax/mercury/mark_folder_as_read.php\", {\n                folder: ab\n            });\n            var bb = [{\n                action_type: v.MercuryGlobalActionType.MARK_ALL_READ,\n                action_id: null,\n                folder: ab\n            },];\n            xa.handleUpdate({\n                global_actions: bb,\n                from_client: true,\n                payload_source: v.MercuryPayloadSource.CLIENT_CHANGE_READ_STATUS\n            });\n        },\n        changeThreadReadStatus: function(ab, bb, cb) {\n            n.isThreadID(ab);\n            ha(ab, function(eb) {\n                var fb = {\n                    ids: {\n                    }\n                };\n                fb.ids[eb] = bb;\n                p.trySend(\"/ajax/mercury/change_read_status.php\", fb);\n            });\n            var db = [{\n                action_type: v.MercuryActionType.CHANGE_READ_STATUS,\n                action_id: null,\n                thread_id: ab,\n                mark_as_read: bb,\n                folder: cb\n            },];\n            xa.handleUpdate({\n                actions: db,\n                from_client: true,\n                payload_source: v.MercuryPayloadSource.CLIENT_CHANGE_READ_STATUS\n            });\n        },\n        changeThreadArchivedStatus: function(ab, bb) {\n            n.isThreadID(ab);\n            ha(ab, function(eb) {\n                var fb = {\n                    ids: {\n                    }\n                };\n                fb.ids[eb] = bb;\n                p.trySend(\"/ajax/mercury/change_archived_status.php\", fb);\n            });\n            var cb = {\n                action_type: v.MercuryActionType.CHANGE_ARCHIVED_STATUS,\n                action_id: null,\n                thread_id: ab,\n                archived: bb\n            }, db = {\n                actions: [cb,],\n                from_client: true,\n                payload_source: v.MercuryPayloadSource.CLIENT_CHANGE_ARCHIVED_STATUS\n            };\n            xa.handleUpdate(db);\n        },\n        changeThreadFolder: function(ab, bb) {\n            n.isThreadID(ab);\n            ha(ab, function(eb) {\n                var fb = {\n                };\n                fb[bb] = [eb,];\n                p.trySend(\"/ajax/mercury/move_thread.php\", fb);\n            });\n            var cb = {\n                action_type: v.MercuryActionType.CHANGE_FOLDER,\n                action_id: null,\n                thread_id: ab,\n                new_folder: bb\n            }, db = {\n                actions: [cb,],\n                from_client: true,\n                payload_source: v.MercuryPayloadSource.CLIENT_CHANGE_FOLDER\n            };\n            xa.handleUpdate(db);\n        },\n        markThreadSpam: function(ab) {\n            n.isThreadID(ab);\n            ha(ab, function(db) {\n                p.trySend(\"/ajax/mercury/mark_spam.php\", {\n                    id: db\n                });\n            });\n            var bb = {\n                action_type: v.MercuryActionType.CHANGE_FOLDER,\n                action_id: null,\n                thread_id: ab,\n                new_folder: v.MessagingTag.SPAM\n            }, cb = {\n                actions: [bb,],\n                from_client: true,\n                payload_source: v.MercuryPayloadSource.CLIENT_CHANGE_FOLDER\n            };\n            xa.handleUpdate(cb);\n        },\n        unmarkThreadSpam: function(ab) {\n            n.isThreadID(ab);\n            ha(ab, function(db) {\n                p.trySend(\"/ajax/mercury/unmark_spam.php\", {\n                    id: db\n                });\n            });\n            var bb = {\n                action_type: v.MercuryActionType.CHANGE_FOLDER,\n                action_id: null,\n                thread_id: ab,\n                new_folder: v.MessagingTag.INBOX\n            }, cb = {\n                actions: [bb,],\n                from_client: true,\n                payload_source: v.MercuryPayloadSource.CLIENT_CHANGE_FOLDER\n            };\n            xa.handleUpdate(cb);\n        },\n        deleteThread: function(ab) {\n            n.isThreadID(ab);\n            ha(ab, function(db) {\n                var eb = {\n                    ids: [db,]\n                };\n                p.trySend(\"/ajax/mercury/delete_thread.php\", eb);\n            });\n            var bb = {\n                action_type: v.MercuryActionType.DELETE_THREAD,\n                action_id: null,\n                thread_id: ab\n            }, cb = {\n                actions: [bb,],\n                from_client: true,\n                payload_source: v.MercuryPayloadSource.CLIENT_DELETE_THREAD\n            };\n            xa.handleUpdate(cb);\n        },\n        deleteMessages: function(ab, bb, cb) {\n            o.getServerIDs((bb || []), function(eb) {\n                p.trySend(\"/ajax/mercury/delete_messages.php\", {\n                    message_ids: eb\n                });\n            });\n            var db;\n            if (cb) {\n                db = {\n                    action_type: v.MercuryActionType.DELETE_THREAD,\n                    action_id: null,\n                    thread_id: ab\n                };\n            }\n             else db = {\n                action_type: v.MercuryActionType.DELETE_MESSAGES,\n                action_id: null,\n                thread_id: ab,\n                message_ids: bb\n            };\n        ;\n            xa.handleUpdate({\n                actions: [db,],\n                from_client: true,\n                payload_source: v.MercuryPayloadSource.CLIENT_DELETE_MESSAGES\n            });\n        },\n        clearChat: function(ab, bb, cb) {\n            n.isThreadID(ab);\n            p.trySend(\"/ajax/chat/settings.php\", {\n                clear_history_id: bb\n            });\n            var db = [{\n                action_type: v.MercuryActionType.CLEAR_CHAT,\n                action_id: null,\n                thread_id: ab,\n                clear_time: cb\n            },];\n            xa.handleUpdate({\n                actions: db,\n                from_client: true,\n                payload_source: v.MercuryPayloadSource.CLIENT_CLEAR_CHAT\n            });\n        },\n        _batchThreadRead: function(ab, bb) {\n            var cb = {\n            };\n            k(cb, ab.ids);\n            k(cb, bb.ids);\n            return {\n                ids: cb\n            };\n        },\n        sendNewMessage: function(ab) {\n            o.getServerIDs((ab.forward_message_ids || []), function(cb) {\n                var db = xa.tokenizeThreadID(ab.thread_id), eb = db.type, fb = k({\n                }, ab);\n                fb.forward_message_ids = cb;\n                var gb = ia(ab.thread_id);\n                if ((((((eb == \"root\") && (db.value == fb.message_id))) || ((eb == \"user\"))) || ((ab.thread_id == w.PENDING_THREAD_ID)))) {\n                    fb.client_thread_id = fb.thread_id;\n                    fb.thread_id = null;\n                    xa._sendNewMessageToServer(fb);\n                }\n                 else ha(fb.thread_id, function(hb) {\n                    fb.thread_id = hb;\n                    xa._sendNewMessageToServer(fb);\n                });\n            ;\n            });\n            if ((ab.thread_id != w.PENDING_THREAD_ID)) {\n                var bb = {\n                    actions: [k({\n                    }, ab),],\n                    from_client: true,\n                    payload_source: v.MercuryPayloadSource.CLIENT_SEND_MESSAGE\n                };\n                xa.handleUpdate(bb);\n            }\n        ;\n        },\n        _sendNewMessageToServer: function(ab) {\n            p.trySend(\"/ajax/mercury/send_messages.php\", {\n                message_batch: [ab,]\n            });\n        },\n        _batchMessageSend: function(ab, bb) {\n            return {\n                message_batch: ab.message_batch.concat(bb.message_batch)\n            };\n        },\n        requestMessageConfirmation: function(ab) {\n            var bb = {\n            }, cb = {\n            };\n            for (var db in ab) {\n                var eb = ia(db);\n                if (eb) {\n                    bb[eb] = ab[db];\n                }\n                 else {\n                    var fb = ab[db];\n                    for (var gb = 0; (gb < fb.length); gb++) {\n                        cb[fb[gb]] = db;;\n                    };\n                }\n            ;\n            };\n            var hb = Object.keys(bb), ib = Object.keys(cb);\n            if ((hb.length || ib.length)) {\n                p.trySend(\"/ajax/mercury/confirm_messages.php\", {\n                    thread_message_map: bb,\n                    local_messages: cb\n                });\n            };\n        },\n        handleMessageConfirmError: function(ab) {\n            var bb = ab.getRequest().getData().thread_message_map, cb = ab.getRequest().getData().local_messages;\n            if ((!bb && !cb)) {\n                return\n            };\n            var db = [];\n            for (var eb in bb) {\n                var fb = bb[eb];\n                fb.forEach(function(ib) {\n                    db.push({\n                        action_type: v.MercuryActionType.SEND_MESSAGE,\n                        client_message_id: ib,\n                        message_id: ib,\n                        client_thread_id: null,\n                        thread_id: eb,\n                        status: v.MercuryActionStatus.UNABLE_TO_CONFIRM\n                    });\n                });\n            };\n            for (var gb in cb) {\n                var hb = cb[gb];\n                db.push({\n                    action_type: v.MercuryActionType.SEND_MESSAGE,\n                    client_message_id: gb,\n                    message_id: gb,\n                    client_thread_id: hb,\n                    thread_id: null,\n                    status: v.MercuryActionStatus.UNABLE_TO_CONFIRM\n                });\n            };\n            if (db.length) {\n                xa.handleUpdate({\n                    actions: db,\n                    payload_source: v.MercuryPayloadSource.CLIENT_HANDLE_ERROR\n                });\n            };\n        },\n        markSeen: function() {\n            var ab = j.convertActionIDToTimestamp(x);\n            p.trySend(\"/ajax/mercury/mark_seen.php\", {\n                seen_timestamp: ab\n            });\n        },\n        _batchMarkSeen: function(ab, bb) {\n            return bb;\n        },\n        handleRoger: function(ab) {\n            var bb = (ab.tid ? z.getResource(ab.tid) : ((\"user:\" + ab.reader)));\n            if (bb) {\n                var cb = {\n                };\n                cb[bb] = {\n                };\n                cb[bb][(\"fbid:\" + ab.reader)] = ab.time;\n                xa.inform(\"update-roger\", cb);\n            }\n        ;\n        },\n        handleUpdateWaitForThread: function(ab, bb) {\n            var cb = z.getResource(bb);\n            if (cb) {\n                xa.handleUpdate(ab);\n                return;\n            }\n        ;\n            z.executeOrEnqueue(bb, function() {\n                ba.push(ab);\n            });\n            if (!ca[bb]) {\n                ca[bb] = true;\n                p.trySend(\"/ajax/mercury/thread_info.php\", {\n                    threads: {\n                        thread_ids: [bb,]\n                    }\n                });\n            }\n        ;\n        },\n        handleUpdate: function(ab) {\n            y.debug(\"handle_update\", {\n                payload: ab,\n                from_client: ab.from_client\n            });\n            for (var bb in ab) {\n                q.synchronizeInforms(function() {\n                    if (!ab.from_client) {\n                        oa(ab);\n                        xa.inform(\"payload-preprocessed\", ab);\n                    }\n                ;\n                    xa.inform(\"update-thread-ids\", da);\n                    da = {\n                    };\n                    xa.inform(\"update-participants\", ab);\n                    xa.inform(\"update-threads\", ab);\n                    xa.inform(\"update-unread\", ab);\n                    xa.inform(\"update-threadlist\", ab);\n                    xa.inform(\"update-messages\", ab);\n                    xa.inform(\"update-unseen\", ab);\n                    xa.inform(\"update-typing-state\", ab);\n                    xa.inform(\"update-roger\", ab.roger);\n                    xa.inform(\"model-update-completed\", null);\n                    pa();\n                });\n                break;\n            };\n        },\n        _handleSendMessageErrorCommon: function(ab, bb) {\n            y.debug(\"handle_send_message_error_common\", {\n                response: ab,\n                request_error_status: bb\n            });\n            var cb = ab.getPayload(), db = ab.getRequest().getData(), eb = db.message_batch;\n            if (!eb) {\n                ma({\n                    action_type: v.MercuryActionType.SEND_MESSAGE,\n                    status: v.MercuryActionStatus.REQUEST_EMPTY_MESSAGE_LIST\n                });\n                return;\n            }\n        ;\n            var fb, gb = null;\n            if ((cb && cb.error_payload)) {\n                fb = v.MercuryActionStatus.UNCONFIRMED;\n                gb = \"send_error\";\n            }\n             else {\n                gb = ((bb == v.MercuryActionStatus.REQUEST_ERROR) ? \"request_error\" : \"transport_error\");\n                if (ab.getError()) {\n                    gb += (\"_\" + ab.getError());\n                };\n                fb = bb;\n            }\n        ;\n            var hb = eb.map(function(jb) {\n                return {\n                    action_type: v.MercuryActionType.SEND_MESSAGE,\n                    client_message_id: jb.message_id,\n                    message_id: jb.message_id,\n                    client_thread_id: jb.client_thread_id,\n                    thread_id: jb.thread_id,\n                    status: fb\n                };\n            });\n            hb.forEach(function(jb) {\n                ma(jb, gb);\n            });\n            var ib = {\n                actions: hb,\n                payload_source: v.MercuryPayloadSource.CLIENT_HANDLE_ERROR\n            };\n            xa.handleUpdate(ib);\n        },\n        handleSendMessageError: function(ab) {\n            if ((ab.error === 1404074)) {\n                h.verboseErrorHandler(ab);\n            };\n            xa._handleSendMessageErrorCommon(ab, v.MercuryActionStatus.REQUEST_ERROR);\n        },\n        handleSendMessageTransportError: function(ab) {\n            xa._handleSendMessageErrorCommon(ab, v.MercuryActionStatus.TRANSPORT_ERROR);\n        },\n        getLastActionID: function() {\n            return x;\n        }\n    });\n    function ya(ab) {\n        return {\n            action_type: v.MercuryActionType.LOG_MESSAGE,\n            thread_id: ab,\n            message_id: ab,\n            timestamp: (new Date()).getTime(),\n            timestamp_absolute: \"\",\n            timestamp_relative: \"\",\n            is_unread: false,\n            source: v.MercurySourceType.UNKNOWN,\n            log_message_type: v.MercuryLogMessageType.SERVER_ERROR,\n            log_message_data: {\n            }\n        };\n    };\n    var za = xa.handleUpdate;\n    p.registerEndpoints({\n        \"/ajax/mercury/thread_sync.php\": {\n            mode: p.IDEMPOTENT,\n            handler: za\n        },\n        \"/ajax/mercury/thread_info.php\": {\n            mode: p.BATCH_DEFERRED_MULTI,\n            batch_function: qa,\n            handler: za,\n            error_handler: xa.handleThreadInfoError\n        },\n        \"/ajax/mercury/mark_folder_as_read.php\": {\n            mode: p.IMMEDIATE,\n            handler: za\n        },\n        \"/ajax/mercury/change_read_status.php\": {\n            mode: p.BATCH_SUCCESSIVE,\n            batch_function: xa._batchThreadRead,\n            handler: za\n        },\n        \"/ajax/mercury/send_messages.php\": {\n            mode: p.BATCH_SUCCESSIVE,\n            batch_function: xa._batchMessageSend,\n            handler: za,\n            error_handler: xa.handleSendMessageError,\n            transport_error_handler: xa.handleSendMessageTransportError\n        },\n        \"/ajax/mercury/mark_seen.php\": {\n            mode: p.BATCH_SUCCESSIVE,\n            batch_function: xa._batchMarkSeen,\n            handler: za\n        },\n        \"/ajax/mercury/confirm_messages.php\": {\n            mode: p.IMMEDIATE,\n            handler: za,\n            error_handler: xa.handleMessageConfirmError\n        },\n        \"/ajax/mercury/threadlist_info.php\": {\n            mode: p.BATCH_SUCCESSIVE_UNIQUE,\n            batch_function: sa,\n            handler: za\n        },\n        \"/ajax/mercury/mark_spam.php\": {\n            mode: p.IMMEDIATE,\n            handler: za\n        },\n        \"/ajax/mercury/unmark_spam.php\": {\n            mode: p.IMMEDIATE,\n            handler: za\n        },\n        \"/ajax/mercury/unread_threads.php\": {\n            mode: p.BATCH_SUCCESSIVE_UNIQUE,\n            batch_function: ra,\n            handler: za\n        },\n        \"/ajax/chat/settings.php\": {\n            mode: p.IMMEDIATE\n        },\n        \"/ajax/mercury/change_archived_status.php\": {\n            mode: p.BATCH_SUCCESSIVE,\n            batch_function: ua,\n            handler: za\n        },\n        \"/ajax/mercury/delete_thread.php\": {\n            mode: p.BATCH_SUCCESSIVE,\n            batch_function: wa,\n            handler: za\n        },\n        \"/ajax/mercury/delete_messages.php\": {\n            mode: p.IMMEDIATE,\n            handler: za\n        },\n        \"/ajax/mercury/move_thread.php\": {\n            mode: p.BATCH_SUCCESSIVE,\n            batch_function: va,\n            handler: za\n        }\n    });\n    e.exports = xa;\n});\n__d(\"MercuryTimestampTracker\", [\"MercuryServerRequests\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"MercuryServerRequests\"), h = c(\"MercuryConstants\"), i = 0;\n    e.exports = {\n        getLastUserMessageTimestamp: function() {\n            return i;\n        }\n    };\n    g.subscribe(\"update-messages\", function(j, k) {\n        if ((!k.actions || !k.actions.length)) {\n            return\n        };\n        var l = h.MercuryPayloadSource;\n        if (((k.payload_source == l.CLIENT_SEND_MESSAGE) || (k.payload_source == l.UNKNOWN))) {\n            return\n        };\n        for (var m = 0; (m < k.actions.length); m++) {\n            var n = k.actions[m], o = n.action_type;\n            if ((((o == h.MercuryActionType.USER_GENERATED_MESSAGE) && n.thread_id) && (n.timestamp > i))) {\n                i = n.timestamp;\n            };\n        };\n    });\n});\n__d(\"MercuryParticipants\", [\"Env\",\"JSLogger\",\"MercuryAssert\",\"MercuryIDs\",\"ShortProfiles\",\"MercuryServerRequests\",\"copyProperties\",\"getObjectValues\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"Env\"), h = b(\"JSLogger\"), i = b(\"MercuryAssert\"), j = b(\"MercuryIDs\"), k = b(\"ShortProfiles\"), l = b(\"MercuryServerRequests\"), m = b(\"copyProperties\"), n = b(\"getObjectValues\"), o = c(\"MercuryConstants\"), p = (\"fbid:\" + g.user), q = {\n    }, r = h.create(\"mercury_participants\"), s = function(v) {\n        if (!q[v.id]) {\n            q[v.id] = m({\n            }, v);\n        };\n    };\n    function t(v) {\n        i.isEmailParticipantID(v);\n        var w = j.tokenize(v), x = w.value;\n        return {\n            gender: o.MercuryParticipantsConstants.UNKNOWN_GENDER,\n            href: null,\n            id: v,\n            image_src: o.MercuryParticipantsConstants.EMAIL_IMAGE,\n            name: x,\n            short_name: x,\n            employee: false,\n            call_promo: false\n        };\n    };\n    var u = {\n        user: p,\n        getNow: function(v) {\n            return q[v];\n        },\n        get: function(v, w) {\n            i.isParticipantID(v);\n            u.getMulti([v,], function(x) {\n                w(x[v]);\n            });\n        },\n        getMulti: function(v, w) {\n            i.allParticipantIDs(v);\n            var x = {\n            }, y = {\n            };\n            v.forEach(function(aa) {\n                if (q[aa]) {\n                    x[aa] = m({\n                    }, q[aa]);\n                }\n                 else {\n                    var ba = j.tokenize(aa);\n                    if ((ba.type == \"fbid\")) {\n                        var ca = ba.value;\n                        y[aa] = ca;\n                    }\n                     else if ((ba.type == \"email\")) {\n                        x[aa] = t(aa);\n                    }\n                ;\n                }\n            ;\n            });\n            var z = n(y);\n            if (z.length) {\n                k.getMulti(z, function(aa) {\n                    for (var ba in y) {\n                        var ca = y[ba], da = aa[ca];\n                        x[ba] = {\n                            gender: da.gender,\n                            href: da.uri,\n                            id: ba,\n                            image_src: da.thumbSrc,\n                            name: da.name,\n                            short_name: da.firstName,\n                            employee: da.employee,\n                            call_promo: da.showVideoPromo\n                        };\n                    };\n                    w(x);\n                });\n            }\n             else w(x);\n        ;\n        },\n        getUserID: function(v) {\n            if (!j.isValid(v)) {\n                return null\n            };\n            var w = j.tokenize(v);\n            if ((w.type != \"fbid\")) {\n                return null\n            };\n            return w.value;\n        },\n        getIDForUser: function(v) {\n            return (\"fbid:\" + v);\n        },\n        addParticipants: function(v) {\n            v.forEach(s);\n        }\n    };\n    l.subscribe(\"update-participants\", function(v, w) {\n        u.addParticipants((w.participants || []));\n    });\n    e.exports = u;\n});\n__d(\"MercuryThreads\", [\"Arbiter\",\"copyProperties\",\"JSLogger\",\"createObjectFrom\",\"KeyedCallbackManager\",\"TimestampConverter\",\"MercuryFolders\",\"MercuryAssert\",\"MercuryAttachment\",\"MercuryIDs\",\"MercuryServerRequests\",\"MercuryThreadInformer\",\"MercuryTimestampTracker\",\"MercuryParticipants\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"copyProperties\"), i = b(\"JSLogger\"), j = b(\"createObjectFrom\"), k = b(\"KeyedCallbackManager\"), l = b(\"TimestampConverter\"), m = b(\"MercuryFolders\"), n = b(\"MercuryAssert\"), o = b(\"MercuryAttachment\"), p = b(\"MercuryIDs\"), q = b(\"MercuryServerRequests\"), r = b(\"MercuryThreadInformer\"), s = b(\"MercuryTimestampTracker\"), t = b(\"MercuryParticipants\"), u = c(\"MercuryConstants\"), v = i.create(\"mercury_threads\"), w = new k();\n    function x(ha, ia) {\n        var ja = j(ha.participants, true), ka = t.user;\n        ia.forEach(function(la) {\n            if ((ja[la] !== true)) {\n                ha.participants.push(la);\n                if ((la === ka)) {\n                    ha.is_subscribed = true;\n                };\n            }\n        ;\n        });\n    };\n    function y(ha, ia) {\n        ha.participants.remove(ia);\n        if ((ia === t.user)) {\n            ha.is_subscribed = false;\n        };\n    };\n    function z(ha, ia) {\n        if ((ha.participants[0] != ia)) {\n            ha.participants.remove(ia);\n            ha.participants.unshift(ia);\n        }\n    ;\n    };\n    function aa(ha, ia) {\n        var ja = ia.body, ka = ia.subject, la = \"\";\n        if (ka) {\n            ka = ka.toLowerCase();\n            if ((ja.slice(0, ka.length).toLowerCase() == ka)) {\n                la = ja;\n            }\n             else if (ja) {\n                la = ((ka + \" \\u00b7 \") + ja);\n            }\n             else la = ka;\n            \n        ;\n        }\n         else la = ja;\n    ;\n        ha.snippet = la;\n        ha.snippet_has_attachment = ia.has_attachment;\n        if ((ia.raw_attachments && (ia.raw_attachments.length > 0))) {\n            var ma = o.convertRaw(ia.raw_attachments);\n            ha.snippet_attachments = ma;\n        }\n         else ha.snippet_attachments = ia.attachments;\n    ;\n        ha.is_forwarded_snippet = !!ia.forward_count;\n    };\n    function ba(ha, ia) {\n        if (!ha) {\n            return false\n        };\n        var ja = !ha.unread_count;\n        if ((ia == ja)) {\n            return false\n        };\n        ha.unread_count = (ia ? 0 : 1);\n        w.setResource(ha.thread_id, ha);\n        r.updatedThread(ha.thread_id);\n        return true;\n    };\n    function ca(ha) {\n        var ia = w.getAllResources();\n        for (var ja in ia) {\n            var ka = ia[ja];\n            if ((ka.folder == ha)) {\n                ka.unread_count = 0;\n                w.setResource(ja, ka);\n                r.updatedThread(ja);\n            }\n        ;\n        };\n    };\n    function da(ha, ia) {\n        if ((!ha || (ha.chat_clear_time === ia))) {\n            return false\n        };\n        ha.chat_clear_time = ia;\n        w.setResource(ha.thread_id, ha);\n        r.reorderedMessages(ha.thread_id);\n        return true;\n    };\n    function ea(ha, ia, ja) {\n        var ka = ia.action_type;\n        if (((ka == u.MercuryActionType.USER_GENERATED_MESSAGE) || (ka == u.MercuryActionType.LOG_MESSAGE))) {\n            (ia.is_unread && ha.unread_count++);\n            ha.is_archived = false;\n        }\n    ;\n        switch (ka) {\n          case u.MercuryActionType.USER_GENERATED_MESSAGE:\n            z(ha, ia.author);\n            break;\n          case u.MercuryActionType.LOG_MESSAGE:\n            var la = ia.log_message_type;\n            if ((la == u.MercuryLogMessageType.SUBSCRIBE)) {\n                x(ha, ia.log_message_data.added_participants);\n            }\n             else if ((la == u.MercuryLogMessageType.UNSUBSCRIBE)) {\n                y(ha, ia.author);\n            }\n             else if ((la == u.MercuryLogMessageType.THREAD_IMAGE)) {\n                ha.image_src = (ia.log_message_data.image ? ia.log_message_data.image.preview_url : null);\n            }\n             else if ((la == u.MercuryLogMessageType.THREAD_NAME)) {\n                ha.name = ia.log_message_data.name;\n            }\n            \n            \n        ;\n            break;\n          case u.MercuryActionType.CHANGE_READ_STATUS:\n            if (ia.timestamp) {\n                r.changedThreadReadState(ha.thread_id, ia.mark_as_read, ia.timestamp);\n            };\n            ba(ha, ia.mark_as_read);\n            break;\n          case u.MercuryActionType.CLEAR_CHAT:\n            da(ha, ia.clear_time);\n            break;\n          case u.MercuryActionType.CHANGE_ARCHIVED_STATUS:\n            ha.is_archived = ia.archived;\n            break;\n          case u.MercuryActionType.CHANGE_FOLDER:\n            ha.folder = ia.new_folder;\n            break;\n          case u.MercuryActionType.DELETE_MESSAGES:\n            if (ja) {\n                ha.snippet = \"...\";\n                ha.snippet_has_attachment = false;\n                ha.snippet_attachments = null;\n                ha.is_forwarded_snippet = false;\n                r.updatedThread(ia.thread_id);\n            }\n        ;\n            break;\n        };\n        if (ia.action_id) {\n            ha.last_action_id = l.maxValidActionID(ia.action_id, ha.last_action_id);\n        };\n    };\n    function fa(ha) {\n        var ia = q.tokenizeThreadID(ha.thread_id);\n        if ((ia.type == \"group\")) {\n            v.error(\"invalid_new_thread_message\", ha);\n            return undefined;\n        }\n    ;\n        var ja = {\n            thread_id: ha.thread_id,\n            last_action_id: ha.action_id,\n            participants: ha.specific_to_list,\n            name: null,\n            snippet: ha.body,\n            snippet_has_attachment: false,\n            snippet_attachments: [],\n            unread_count: 0,\n            image_src: null,\n            timestamp_absolute: ha.timestamp_absolute,\n            timestamp_relative: ha.timestamp_relative,\n            timestamp: ha.timestamp,\n            is_canonical_user: (ia.type == \"user\"),\n            is_canonical: ((ia.type == \"user\") || (ia.type == \"email\")),\n            is_subscribed: true,\n            is_canonical_group: false,\n            is_chatlogger_thread: false,\n            group_id: null,\n            root_message_threading_id: ha.message_id,\n            folder: u.MessagingTag.INBOX,\n            is_archived: false,\n            mode: u.MercuryThreadMode.TITAN_ORIGINATED\n        };\n        w.setResource(ja.thread_id, ja);\n        return ja;\n    };\n    g.subscribe(i.DUMP_EVENT, function(ha, ia) {\n        ia.messaging = (ia.messaging || {\n        });\n        ia.messaging.threads = w.dumpResources();\n    });\n    var ga = {\n        getThreadMetaNow: function(ha) {\n            n.isThreadID(ha);\n            return w.getResource(ha);\n        },\n        getThreadMeta: function(ha, ia) {\n            n.isThreadID(ha);\n            var ja = w.executeOrEnqueue(ha, ia), ka = w.getUnavailableResources(ja);\n            if (ka.length) {\n                var la = q.tokenizeThreadID(ha);\n                if ((la.type == \"user\")) {\n                    ga.getCanonicalThreadToUser(la.value);\n                }\n                 else q.fetchThreadData(ka);\n            ;\n            }\n        ;\n            return ja;\n        },\n        unsubscribe: function(ha) {\n            w.unsubscribe(ha);\n        },\n        changeThreadReadStatus: function(ha, ia) {\n            n.isThreadID(ha);\n            var ja = w.getResource(ha);\n            if (ba(ja, ia)) {\n                q.changeThreadReadStatus(ha, ia, m.getFromMeta(ja));\n            };\n        },\n        changeThreadArchivedStatus: function(ha, ia) {\n            n.isThreadID(ha);\n            var ja = w.getResource(ha);\n            if ((ja.is_archived != ia)) {\n                ja.is_archived = ia;\n                r.updatedThread(ja.thread_id);\n                q.changeThreadArchivedStatus(ha, ia);\n            }\n        ;\n        },\n        markThreadSpam: function(ha) {\n            q.markThreadSpam(ha);\n        },\n        unmarkThreadSpam: function(ha) {\n            q.unmarkThreadSpam(ha);\n        },\n        changeFolder: function(ha, ia) {\n            n.isThreadID(ha);\n            var ja = w.getResource(ha);\n            if ((ja && (ja.folder != ia))) {\n                ja.folder = ia;\n                r.updatedThread(ja.thread_id);\n                q.changeThreadFolder(ha, ia);\n            }\n        ;\n        },\n        deleteThread: function(ha) {\n            n.isThreadID(ha);\n            q.deleteThread(ha);\n        },\n        updateThreads: function(ha) {\n            if ((!ha || !ha.length)) {\n                return\n            };\n            var ia = {\n            };\n            ha.forEach(function(ja) {\n                ia[ja.thread_id] = ja;\n            });\n            w.addResourcesAndExecute(ia);\n        },\n        updateMetadataByActions: function(ha, ia) {\n            if ((!ha || !ha.length)) {\n                return\n            };\n            var ja = {\n            }, ka = {\n            }, la = {\n            };\n            for (var ma = 0; (ma < ha.length); ma++) {\n                var na = ha[ma];\n                if (na.is_forward) {\n                    continue;\n                };\n                var oa = na.action_type, pa = na.thread_id;\n                n.isThreadID(pa);\n                var qa = ga.getThreadMetaNow(pa);\n                if (((oa == u.MercuryActionType.LOG_MESSAGE) && (na.log_message_type == u.MercuryLogMessageType.SERVER_ERROR))) {\n                    continue;\n                };\n                if (((!qa && !na.action_id) && (oa == u.MercuryActionType.USER_GENERATED_MESSAGE))) {\n                    qa = fa(na);\n                };\n                if (qa) {\n                    if ((oa == u.MercuryActionType.DELETE_THREAD)) {\n                        r.deletedThread(pa);\n                        continue;\n                    }\n                ;\n                    var ra = !!na.action_id;\n                    if (((oa == u.MercuryActionType.LOG_MESSAGE) || (oa == u.MercuryActionType.USER_GENERATED_MESSAGE))) {\n                        ra = !ia;\n                    };\n                    if (((na.timestamp <= qa.timestamp) && ra)) {\n                        v.log(\"ignore_old_timestamp\", {\n                            action: na,\n                            from_client: ia,\n                            thread_timestamp: qa.timestamp\n                        });\n                        continue;\n                    }\n                ;\n                    if (!la[pa]) {\n                        la[pa] = h({\n                        }, qa);\n                    };\n                    ea(la[pa], na, ia);\n                    if ((oa == u.MercuryActionType.USER_GENERATED_MESSAGE)) {\n                        ja[pa] = na;\n                    };\n                    if ((((oa == u.MercuryActionType.USER_GENERATED_MESSAGE) || (oa == u.MercuryActionType.LOG_MESSAGE)) || (oa == u.MercuryActionType.SEND_MESSAGE))) {\n                        if (((na && na.timestamp) && ((!ka[pa] || (na.timestamp > ka[pa].timestamp))))) {\n                            ka[pa] = na;\n                        }\n                    };\n                }\n            ;\n            };\n            for (var sa in la) {\n                var ta = la[sa], ua = ja[sa];\n                if (ua) {\n                    aa(ta, ua);\n                };\n                var va = ka[sa], wa = ta.timestamp;\n                if ((va && (va.timestamp > wa))) {\n                    ta = h(ta, {\n                        timestamp_absolute: va.timestamp_absolute,\n                        timestamp_relative: va.timestamp_relative,\n                        timestamp: va.timestamp\n                    });\n                };\n                w.setResource(sa, ta);\n            };\n        },\n        getCanonicalThreadToGroup: function(ha, ia) {\n            var ja = (\"group:\" + ha);\n            ga.getThreadMeta(ja, ia);\n        },\n        getCanonicalThreadToUser: function(ha, ia) {\n            return ga.getCanonicalThreadToParticipant((\"fbid:\" + ha), ia);\n        },\n        getCanonicalThreadToParticipant: function(ha, ia) {\n            var ja = ga.getThreadIDForParticipant(ha), ka = w.getResource(ja);\n            if ((typeof ka == \"undefined\")) {\n                ka = ga.createNewLocalThread(ja, [t.user,ha,], ia);\n                q.fetchThreadData([ja,]);\n            }\n        ;\n            return ka;\n        },\n        getThreadIdForUser: function(ha) {\n            return (\"user:\" + ha);\n        },\n        getThreadIdForEmail: function(ha) {\n            return (\"email:\" + ha);\n        },\n        getThreadIDForParticipant: function(ha) {\n            var ia = p.tokenize(ha);\n            return ((ia.type == \"fbid\") ? ga.getThreadIdForUser(ia.value) : ga.getThreadIdForEmail(ia.value));\n        },\n        createNewLocalThread: function(ha, ia, ja) {\n            var ka = w.getResource(ha);\n            if (!ka) {\n                var la = q.tokenizeThreadID(ha);\n                ka = {\n                    thread_id: ha,\n                    last_action_id: null,\n                    participants: ia,\n                    name: null,\n                    snippet: \"\",\n                    snippet_has_attachment: false,\n                    unread_count: (ja ? ja : 0),\n                    image_src: null,\n                    timestamp_absolute: null,\n                    timestamp_relative: null,\n                    timestamp: null,\n                    is_canonical_user: (la.type == \"user\"),\n                    is_canonical: ((la.type == \"user\") || (la.type == \"email\")),\n                    is_subscribed: true,\n                    is_canonical_group: (la.type == \"group\"),\n                    group_id: (((la.type == \"group\") ? la.value : null)),\n                    root_message_threading_id: null,\n                    folder: u.MessagingTag.INBOX,\n                    is_archived: false,\n                    mode: u.MercuryThreadMode.TITAN_ORIGINATED\n                };\n                ka.is_chatlogger_thread = ka.is_canonical_group;\n                w.setResource(ha, ka);\n            }\n        ;\n            return ka;\n        },\n        addParticipantsToThreadLocally: function(ha, ia) {\n            var ja = w.getResource(ha);\n            if (ja) {\n                x(ja, ia);\n                r.updatedThread(ja.thread_id);\n            }\n        ;\n        },\n        getCanonicalUserInThread: function(ha) {\n            var ia = q.tokenizeThreadID(ha);\n            return ((ia.type == \"user\") ? ia.value : null);\n        },\n        getCanonicalGroupInThread: function(ha) {\n            var ia = q.tokenizeThreadID(ha);\n            return ((ia.type == \"group\") ? ia.value : null);\n        },\n        isEmptyLocalThread: function(ha) {\n            var ia = w.getResource(ha);\n            if (!ia) {\n                return false\n            };\n            var ja = q.tokenizeThreadID(ha);\n            return ((ja.type == \"root\") && !ia.timestamp);\n        },\n        isMultichatThread: function(ha) {\n            var ia = q.tokenizeThreadID(ha).type;\n            return (((ia != \"user\") && (ia != \"group\")) && (ia != \"email\"));\n        }\n    };\n    q.subscribe(\"update-threads\", function(ha, ia) {\n        var ja = ((ia.actions || [])).filter(function(na) {\n            return na.thread_id;\n        });\n        ga.updateThreads(ia.threads);\n        ga.updateMetadataByActions(ja, ia.from_client);\n        ((ia.threads || [])).forEach(function(na) {\n            r.updatedThread(na.thread_id);\n        });\n        var ka = (ia.global_actions || []);\n        for (var la = 0; (la < ka.length); la++) {\n            var ma = ka[la];\n            if ((ma.action_type == u.MercuryGlobalActionType.MARK_ALL_READ)) {\n                ca(ma.folder);\n            };\n        };\n    });\n    e.exports = ga;\n});\n__d(\"ChatActivity\", [\"Arbiter\",\"AvailableList\",\"AvailableListConstants\",\"copyProperties\",\"event-extensions\",\"JSLogger\",\"MercuryThreads\",\"PresenceState\",\"UserActivity\",\"MercuryConfig\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AvailableList\"), i = b(\"AvailableListConstants\"), j = b(\"copyProperties\");\n    b(\"event-extensions\");\n    var k = b(\"JSLogger\"), l = b(\"MercuryThreads\"), m = b(\"PresenceState\"), n = b(\"UserActivity\"), o = c(\"MercuryConfig\"), p = (o.activity_limit || 60000), q = (o.idle_limit || 1800000), r = (o.idle_poll_interval || 300000), s = k.create(\"chat_activity\"), t = Date.now(), u = t, v = true;\n    function w() {\n        var aa = Date.now();\n        return !!((v && (((aa - t) < p))));\n    };\n    var x = j(new g(), {\n        isActive: w\n    });\n    function y() {\n        var aa = t;\n        t = Date.now();\n        if (((t - aa) > q)) {\n            s.debug(\"idle_to_active\", aa);\n            m.doSync();\n        }\n    ;\n        x.inform(\"activity\");\n    };\n    h.subscribe(i.ON_AVAILABILITY_CHANGED, function() {\n        if (!h.isUserIdle()) {\n            u = Date.now();\n        };\n    });\n    Event.listen(window, \"focus\", function() {\n        v = true;\n        y();\n    });\n    Event.listen(window, \"blur\", function() {\n        v = false;\n    });\n    n.subscribe(function() {\n        y();\n    });\n    function z(aa) {\n        var ba = ((aa && aa.at) && m.verifyNumber(aa.at));\n        if ((typeof ba !== \"number\")) {\n            ba = null;\n        };\n        return (ba || 0);\n    };\n    setInterval(function() {\n        var aa = Date.now(), ba = z(m.get()), ca = Math.max(t, ba, u);\n        if (((aa - ca) > q)) {\n            s.debug(\"idle\", {\n                cookie: ba,\n                local: t,\n                presence: u\n            });\n            x.inform(\"idle\", (aa - ca));\n        }\n    ;\n    }, r);\n    m.registerStateStorer(function(aa) {\n        var ba = z(aa);\n        if ((ba < t)) {\n            aa.at = t;\n        };\n        return aa;\n    });\n    g.subscribe(k.DUMP_EVENT, function(aa, ba) {\n        ba.chat_activity = {\n            activity_limit: p,\n            idle_limit: q,\n            idle_poll_interval: r,\n            last_active_time: t,\n            last_global_active_time: u\n        };\n    });\n    e.exports = x;\n});\n__d(\"MercuryMessages\", [\"Arbiter\",\"copyProperties\",\"Env\",\"JSLogger\",\"randomInt\",\"tx\",\"KeyedCallbackManager\",\"MercuryAssert\",\"MercuryIDs\",\"MercuryMessageIDs\",\"MercuryParticipants\",\"PresenceUtil\",\"RangedCallbackManager\",\"MercuryServerRequests\",\"MercuryServerDispatcher\",\"MercuryThreadInformer\",\"MercuryThreads\",\"MercuryConstants\",\"MercuryConfig\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"copyProperties\"), i = b(\"Env\"), j = b(\"JSLogger\"), k = b(\"randomInt\"), l = b(\"tx\"), m = b(\"KeyedCallbackManager\"), n = b(\"MercuryAssert\"), o = b(\"MercuryIDs\"), p = b(\"MercuryMessageIDs\"), q = b(\"MercuryParticipants\"), r = b(\"PresenceUtil\"), s = b(\"RangedCallbackManager\"), t = b(\"MercuryServerRequests\"), u = b(\"MercuryServerDispatcher\"), v = b(\"MercuryThreadInformer\"), w = b(\"MercuryThreads\"), x = c(\"MercuryConstants\"), y = c(\"MercuryConfig\"), z = x.MercuryGenericConstants, aa = {\n    }, ba = {\n    }, ca = {\n    }, da = function(sa) {\n        var ta = sa;\n        if (ba[sa]) {\n            ta = ba[sa];\n        };\n        return aa[ta];\n    }, ea = {\n    }, fa = {\n    }, ga = new m();\n    function ha(sa) {\n        if ((sa.status === undefined)) {\n            sa.status = x.MercuryActionStatus.UNSENT;\n        };\n        sa.message_id = (sa.message_id || na.generateNewClientMessageID(sa.timestamp));\n        var ta = q.user;\n        sa.specific_to_list = (sa.specific_to_list || []);\n        if ((sa.specific_to_list.length && (sa.specific_to_list.indexOf(ta) === -1))) {\n            sa.specific_to_list.push(ta);\n        };\n        if (!sa.thread_id) {\n            if ((sa.specific_to_list.length == 1)) {\n                sa.thread_id = (\"user:\" + i.user);\n            }\n             else if ((sa.specific_to_list.length == 2)) {\n                var ua = ((sa.specific_to_list[0] == ta) ? sa.specific_to_list[1] : sa.specific_to_list[0]);\n                if ((o.tokenize(ua).type == \"email\")) {\n                    sa.thread_id = z.PENDING_THREAD_ID;\n                }\n                 else sa.thread_id = w.getThreadIDForParticipant(ua);\n            ;\n            }\n            \n        ;\n            sa.thread_id = (sa.thread_id || (\"root:\" + sa.message_id));\n        }\n    ;\n        if (!sa.specific_to_list.length) {\n            var va = t.tokenizeThreadID(sa.thread_id);\n            if ((va.type == \"user\")) {\n                sa.specific_to_list = [(\"fbid:\" + va.value),ta,];\n            };\n        }\n    ;\n    };\n    function ia(sa, ta, ua) {\n        var va = (ra(ta) ? [x.MercuryMessageSourceTags.CHAT,] : []), wa = Date.now(), xa = Date.format((y[\"24h_times\"] ? \"H:i\" : \"g:ia\"), Math.floor((wa / 1000))), ya = {\n            action_type: sa,\n            thread_id: ua,\n            author: q.user,\n            author_email: null,\n            coordinates: null,\n            timestamp: wa,\n            timestamp_absolute: (new Date(wa)).toLocaleDateString(),\n            timestamp_relative: xa,\n            is_unread: false,\n            is_cleared: false,\n            is_forward: false,\n            spoof_warning: false,\n            source: ta,\n            source_tags: va\n        };\n        return ya;\n    };\n    function ja(sa) {\n        switch (sa) {\n          case x.MercuryPayloadSource.UNKNOWN:\n        \n          case x.MercuryPayloadSource.SERVER_INITIAL_DATA:\n        \n          case x.MercuryPayloadSource.SERVER_FETCH_THREAD_INFO:\n        \n          case x.MercuryPayloadSource.SERVER_THREAD_SYNC:\n            return true;\n        };\n        return false;\n    };\n    function ka(sa) {\n        return (sa && (sa.substr(0, 6) === \"server\"));\n    };\n    function la(sa) {\n        if (!ea[sa]) {\n            ea[sa] = new s(function(ta) {\n                return da(ta).timestamp;\n            }, function(ta, ua) {\n                return (ua - ta);\n            });\n        };\n        return ea[sa];\n    };\n    g.subscribe(j.DUMP_EVENT, function(sa, ta) {\n        var ua = {\n        };\n        for (var va in aa) {\n            var wa = aa[va], xa = wa.thread_id;\n            ua[xa] = (ua[xa] || {\n            });\n            ua[xa][wa.message_id] = h({\n            }, wa);\n        };\n        ta.messaging = (ta.messaging || {\n        });\n        ta.messaging.local_message_ids = h({\n        }, ba);\n        ta.messaging.messages = ua;\n    });\n    function ma(sa, ta) {\n        sa.forEach(function(ua) {\n            var va = la(ua);\n            va.setReachedEndOfArray();\n            v.reorderedMessages(ua, ta);\n        });\n    };\n    var na = {\n        getMessagesFromIDs: function(sa) {\n            return ((sa || [])).map(da).filter(function(ta) {\n                return ta;\n            });\n        },\n        hasLoadedNMessages: function(sa, ta) {\n            var ua = la(sa);\n            return (ua.hasReachedEndOfArray() || (ua.getCurrentArraySize() >= ta));\n        },\n        getThreadMessagesRangeImmediately: function(sa, ta, ua, va) {\n            return na.getThreadMessagesRange(sa, ta, ua, va, u.IMMEDIATE);\n        },\n        getThreadMessagesRange: function(sa, ta, ua, va, wa) {\n            var xa = la(sa), ya = function(db) {\n                va(oa(db));\n            }, za = xa.executeOrEnqueue(ta, ua, ya), ab = xa.getUnavailableResources(za), bb = ca[sa];\n            if ((ab.length && !bb)) {\n                var cb = (fa[sa] || 0);\n                t.fetchThreadMessages(sa, cb, ab.length, wa);\n            }\n             else ca[sa] = false;\n        ;\n            return za;\n        },\n        getThreadMessagesSinceTimestamp: function(sa, ta) {\n            var ua = la(sa), va = ua.getElementsUntil(ta);\n            return oa(va);\n        },\n        hasLoadedAllMessages: function(sa) {\n            return la(sa).hasReachedEndOfArray();\n        },\n        unsubscribe: function(sa, ta) {\n            n.isThreadID(ta);\n            var ua = la(ta);\n            ua.unsubscribe(sa);\n        },\n        handleUpdates: function(sa, ta, ua) {\n            var va = {\n            }, wa = {\n            }, xa = x.MercuryActionStatus;\n            for (var ya = 0; (ya < sa.length); ya++) {\n                var za = sa[ya];\n                if ((za.is_forward || (ua == x.MercuryPayloadSource.SERVER_SEARCH))) {\n                    if (!aa[za.message_id]) {\n                        aa[za.message_id] = za;\n                    };\n                    continue;\n                }\n            ;\n                var ab = za.action_type;\n                if ((ab == x.MercuryActionType.SEND_MESSAGE)) {\n                    var bb = za.client_message_id;\n                    if (((bb && ba[bb]) && za.status)) {\n                        if ((za.status == xa.UNCONFIRMED)) {\n                            if (!wa[za.thread_id]) {\n                                wa[za.thread_id] = [];\n                            };\n                            wa[za.thread_id].push(za.client_message_id);\n                        }\n                         else if (!va[za.thread_id]) {\n                            va[za.thread_id] = [];\n                        }\n                    ;\n                        var cb = da(za.client_message_id), db = cb.status;\n                        cb.status = za.status;\n                        if ((za.status == xa.SUCCESS)) {\n                            na.updateLocalMessage(za, ua);\n                            if ((za.client_thread_id == z.PENDING_THREAD_ID)) {\n                                cb.thread_id = za.thread_id;\n                                va[za.thread_id].push(cb.message_id);\n                                ga.setResource(cb.message_id, cb.thread_id);\n                            }\n                        ;\n                        }\n                    ;\n                        if (((((((typeof db != \"undefined\") || (za.status == xa.REQUEST_ERROR)) || (za.status == xa.TRANSPORT_ERROR)) || (za.status == xa.FAILED_UNKNOWN_REASON)) || (za.status == xa.UNABLE_TO_CONFIRM)) || (za.status == xa.SUCCESS))) {\n                            v.updatedMessage(za.thread_id, da(za.client_message_id).message_id, ua);\n                        };\n                    }\n                ;\n                    continue;\n                }\n                 else if ((ab == x.MercuryActionType.DELETE_THREAD)) {\n                    la(za.thread_id).removeAllResources();\n                    continue;\n                }\n                 else if ((ab == x.MercuryActionType.DELETE_MESSAGES)) {\n                    var eb = za.message_ids.map(function(mb) {\n                        return da(mb).message_id;\n                    }), fb = la(za.thread_id);\n                    fb.removeResources(eb);\n                    v.reorderedMessages(za.thread_id, ua);\n                    continue;\n                }\n                 else if ((ab == x.MercuryActionType.LOG_MESSAGE)) {\n                    if ((za.log_message_type == x.MercuryLogMessageType.SERVER_ERROR)) {\n                        ca[za.thread_id] = true;\n                    };\n                }\n                 else if ((ab == x.MercuryActionType.CLEAR_CHAT)) {\n                    var gb = la(za.thread_id).getAllResources();\n                    gb.map(da).forEach(function(mb) {\n                        mb.is_cleared = true;\n                    });\n                    continue;\n                }\n                \n                \n                \n                \n            ;\n                var hb = da(za.message_id);\n                if ((((za.threading_id && ba[za.threading_id])) || ((hb && !hb.is_forward)))) {\n                    continue;\n                };\n                if (!va[za.thread_id]) {\n                    va[za.thread_id] = [];\n                };\n                va[za.thread_id].push(za.message_id);\n                aa[za.message_id] = za;\n                if ((za.threading_id && (za.threading_id != za.message_id))) {\n                    p.addServerID(za.threading_id, za.message_id);\n                };\n                if (!ta) {\n                    v.receivedMessage(za);\n                };\n            };\n            for (var ib in va) {\n                var fb = la(ib), jb = fb.getAllResources(), kb = jb.filter(function(mb) {\n                    var nb = aa[mb];\n                    return ((nb.action_type == x.MercuryActionType.LOG_MESSAGE) && (nb.log_message_type == x.MercuryLogMessageType.SERVER_ERROR));\n                });\n                fb.removeResources(kb);\n                pa(ib, va[ib]);\n                if (ta) {\n                    fb.addResources(va[ib]);\n                    v.reorderedMessages(ib, ua);\n                }\n                 else fb.addResourcesWithoutSorting(va[ib].reverse(), 0);\n            ;\n                v.updatedThread(ib);\n            };\n            var lb = Object.keys(wa);\n            if (lb.length) {\n                t.requestMessageConfirmation(wa);\n            };\n        },\n        sendMessage: function(sa, ta) {\n            ta = (ta || Function.prototype);\n            ha(sa);\n            ba[sa.message_id] = sa.message_id;\n            if ((sa.thread_id == (\"root:\" + sa.message_id))) {\n                la(sa.thread_id).setReachedEndOfArray();\n            };\n            t.sendNewMessage(sa);\n            if ((sa.thread_id == z.PENDING_THREAD_ID)) {\n                aa[sa.message_id] = sa;\n                return ga.executeOrEnqueue(sa.message_id, ta);\n            }\n             else ta(sa.thread_id);\n        ;\n        },\n        unsubscribeSend: function(sa) {\n            ga.unsubscribe(sa);\n        },\n        resendMessage: function(sa) {\n            var ta = h({\n            }, sa);\n            ta.status = x.MercuryActionStatus.RESENDING;\n            ta.timestamp = (new Date()).getTime();\n            ta.message_id = na.generateNewClientMessageID(ta.timestamp);\n            var ua = la(sa.thread_id);\n            ua.removeResources([sa.message_id,]);\n            na.sendMessage(ta);\n            v.reorderedMessages(sa.thread_id, x.MercuryPayloadSource.CLIENT_SEND_MESSAGE);\n        },\n        deleteMessages: function(sa, ta) {\n            if (ta.length) {\n                var ua = la(sa), va = ((ua.getCurrentArraySize() == ta.length) && ua.hasReachedEndOfArray());\n                t.deleteMessages(sa, ta, va);\n            }\n        ;\n        },\n        updateLocalMessage: function(sa, ta) {\n            var ua = sa.message_id, va = sa.client_message_id;\n            ba[va] = ua;\n            aa[ua] = aa[va];\n            p.addServerID(va, ua);\n            aa[va] = {\n            };\n            if (sa.timestamp) {\n                da(va).timestamp = sa.timestamp;\n            };\n            if ((sa.attachments && sa.attachments.length)) {\n                da(va).raw_attachments = null;\n                da(va).attachments = sa.attachments;\n            }\n        ;\n        },\n        constructUserGeneratedMessageObject: function(sa, ta, ua, va) {\n            var wa = ia(x.MercuryActionType.USER_GENERATED_MESSAGE, ta, ua);\n            wa.body = sa;\n            wa.has_attachment = false;\n            wa.html_body = false;\n            wa.attachments = [];\n            wa.specific_to_list = (va || []);\n            return wa;\n        },\n        constructLogMessageObject: function(sa, ta, ua, va) {\n            var wa = ia(x.MercuryActionType.LOG_MESSAGE, sa, ta);\n            wa.log_message_type = ua;\n            wa.log_message_data = va;\n            return wa;\n        },\n        generateNewClientMessageID: function(sa) {\n            var ta = ((((sa + \":\") + ((k(0, 4294967295) + 1))) + \"-\") + r.getSessionID());\n            return ((\"\\u003C\" + ta) + \"@mail.projektitan.com\\u003E\");\n        }\n    };\n    t.subscribe(\"update-messages\", function(sa, ta) {\n        var ua = ((ta.actions || [])).filter(function(wa) {\n            var xa = wa.action_type;\n            return (((wa.is_forward || wa.thread_id)) && (((((((xa == x.MercuryActionType.LOG_MESSAGE) || (xa == x.MercuryActionType.USER_GENERATED_MESSAGE)) || (xa == x.MercuryActionType.SEND_MESSAGE)) || (xa == x.MercuryActionType.CLEAR_CHAT)) || (xa == x.MercuryActionType.DELETE_THREAD)) || (xa == x.MercuryActionType.DELETE_MESSAGES))));\n        }), va = ja(ta.payload_source);\n        if (ka(ta.payload_source)) {\n            ua.forEach(function(wa) {\n                if (!wa.is_forward) {\n                    var xa = w.getThreadMetaNow(wa.thread_id);\n                    if (xa) {\n                        wa.is_cleared = (wa.timestamp < xa.chat_clear_time);\n                    };\n                }\n            ;\n            });\n        };\n        na.handleUpdates(ua, va, ta.payload_source);\n        if (ta.end_of_history) {\n            ma(ta.end_of_history, ta.payload_source);\n        };\n    });\n    function oa(sa) {\n        var ta = sa.map(da);\n        return ta.reverse();\n    };\n    function pa(sa, ta) {\n        var ua = ta.filter(function(va) {\n            return qa(da(va));\n        });\n        if (!fa[sa]) {\n            fa[sa] = 0;\n        };\n        fa[sa] += ua.length;\n    };\n    function qa(sa) {\n        var ta = sa.action_type;\n        if ((ta == x.MercuryActionType.USER_GENERATED_MESSAGE)) {\n            return true\n        };\n        switch (sa.log_message_type) {\n          case x.MercuryLogMessageType.SUBSCRIBE:\n        \n          case x.MercuryLogMessageType.UNSUBSCRIBE:\n        \n          case x.MercuryLogMessageType.SERVER_ERROR:\n        \n          case x.MercuryLogMessageType.LIVE_LISTEN:\n            return false;\n          default:\n            return true;\n        };\n    };\n    function ra(sa) {\n        switch (sa) {\n          case x.MercurySourceType.CHAT_WEB:\n        \n          case x.MercurySourceType.CHAT_JABBER:\n        \n          case x.MercurySourceType.CHAT_IPHONE:\n        \n          case x.MercurySourceType.CHAT_MEEBO:\n        \n          case x.MercurySourceType.CHAT_ORCA:\n        \n          case x.MercurySourceType.CHAT_TEST:\n        \n          case x.MercurySourceType.CHAT:\n        \n          case x.MercurySourceType.DESKTOP:\n            return true;\n          default:\n            return false;\n        };\n    };\n    e.exports = na;\n});\n__d(\"MercuryNotificationRenderer\", [\"MercuryAssert\",\"MercuryMessages\",\"MercuryParticipants\",\"MercuryThreads\",\"tx\",], function(a, b, c, d, e, f) {\n    var g = b(\"MercuryAssert\"), h = b(\"MercuryMessages\"), i = b(\"MercuryParticipants\"), j = b(\"MercuryThreads\"), k = b(\"tx\");\n    function l(m, n) {\n        g.isThreadID(m);\n        j.getThreadMeta(m, function(o) {\n            h.getThreadMessagesRange(m, 0, 1, function(p) {\n                var q = (p.length && p[(p.length - 1)]);\n                if ((q && (q.author != i.user))) {\n                    i.get(q.author, function(r) {\n                        if (o.name) {\n                            n(k._(\"{senderName} messaged {groupName}\", {\n                                senderName: r.short_name,\n                                groupName: o.name\n                            }));\n                        }\n                         else n(k._(\"{name} messaged you\", {\n                            name: r.short_name\n                        }));\n                    ;\n                    });\n                }\n                 else n(\"New message!\");\n            ;\n            });\n        });\n    };\n    e.exports = {\n        renderDocumentTitle: l\n    };\n});\n__d(\"MercuryUnseenState\", [\"Arbiter\",\"copyProperties\",\"TimestampConverter\",\"KeyedCallbackManager\",\"JSLogger\",\"createObjectFrom\",\"MercuryServerRequests\",\"MercuryThreadInformer\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"copyProperties\"), i = b(\"TimestampConverter\"), j = b(\"KeyedCallbackManager\"), k = b(\"JSLogger\"), l = b(\"createObjectFrom\"), m = b(\"MercuryServerRequests\"), n = b(\"MercuryThreadInformer\"), o = c(\"MercuryConstants\"), p = o.MercuryThreadlistConstants.MAX_UNSEEN_COUNT, q = 0, r = 0, s = false, t = new j(), u = \"unseen_thread_hash\", v = \"unseen_thread_list\", w = k.create(\"mercury_unseen_state\"), x = {\n        getUnseenCount: function() {\n            if (x.exceedsMaxCount()) {\n                w.error(\"unguarded_unseen_count_fetch\", {\n                });\n                return 0;\n            }\n        ;\n            return ba();\n        },\n        exceedsMaxCount: function() {\n            return (s || ((ba() > p)));\n        },\n        markAsSeen: function() {\n            if (((ba() > 0) || s)) {\n                m.markSeen();\n                da(i.convertActionIDToTimestamp(m.getLastActionID()), []);\n            }\n        ;\n        },\n        markThreadSeen: function(ka, la) {\n            var ma = {\n            };\n            ma[ka] = null;\n            fa(ma, la);\n        }\n    };\n    function y(ka) {\n        t.setResource(u, ka);\n        t.setResource(v, Object.keys(ka));\n    };\n    function z(ka) {\n        var la = t.executeOrEnqueue(u, ka), ma = t.getUnavailableResources(la);\n        if (ma.length) {\n            m.fetchUnseenThreadIDs();\n        };\n    };\n    function aa() {\n        return t.getResource(u);\n    };\n    function ba() {\n        var ka = t.getResource(v);\n        if (ka) {\n            return ka.length;\n        }\n         else return q\n    ;\n    };\n    function ca(ka) {\n        var la = ja(ka);\n        if (ka.unseen_thread_ids) {\n            ka.unseen_thread_ids.forEach(function(wa) {\n                if ((wa.folder != o.MessagingTag.INBOX)) {\n                    return\n                };\n                var xa = ha(wa.thread_ids), ya = r;\n                if ((la && la.seen_timestamp)) {\n                    ya = la.seen_timestamp;\n                };\n                da(ya, xa);\n                if ((la && (la.unseen_count > p))) {\n                    s = true;\n                };\n            });\n        }\n         else if ((la && la.seen_timestamp)) {\n            r = la.seen_timestamp;\n            if ((la.unseen_count > p)) {\n                s = true;\n                y({\n                });\n            }\n             else {\n                q = la.unseen_count;\n                if ((q === 0)) {\n                    y({\n                    });\n                };\n            }\n        ;\n        }\n         else {\n            if (s) {\n                return\n            };\n            var ma = ka.actions;\n            if ((!ma || !(ma.length))) {\n                return\n            };\n            var na = {\n            }, oa = {\n            };\n            for (var pa = 0; (pa < ma.length); pa++) {\n                var qa = ma[pa];\n                if (qa.is_forward) {\n                    continue;\n                };\n                var ra = qa.action_type, sa = qa.action_id, ta = (qa.thread_id ? qa.thread_id : qa.server_thread_id), ua = ((qa.folder === undefined) || (qa.folder == o.MessagingTag.INBOX));\n                if (!ua) {\n                    continue;\n                };\n                if (((ra == o.MercuryActionType.USER_GENERATED_MESSAGE) || (ra == o.MercuryActionType.LOG_MESSAGE))) {\n                    var va = i.isGreaterThan(sa, na[ta]);\n                    if ((qa.is_unread && ((!na[ta] || va)))) {\n                        na[ta] = sa;\n                    };\n                }\n                 else if (((ra == o.MercuryActionType.CHANGE_READ_STATUS) && qa.mark_as_read)) {\n                    oa[ta] = sa;\n                }\n            ;\n            };\n            ea(na);\n            fa(oa);\n        }\n        \n    ;\n    };\n    function da(ka, la) {\n        var ma = aa();\n        if ((((ma === undefined) || (ka > r)) || s)) {\n            r = ka;\n            la = (la || []);\n            if ((la.length <= p)) {\n                s = false;\n            };\n            var na = {\n            }, oa = (aa() || {\n            });\n            for (var pa in oa) {\n                if ((oa[pa] !== true)) {\n                    var qa = oa[pa];\n                    if (ga(qa)) {\n                        na[pa] = qa;\n                    };\n                }\n            ;\n            };\n            var ra = h(l(la, true), na);\n            y(ra);\n            n.updatedUnseenState();\n        }\n    ;\n    };\n    function ea(ka) {\n        if (s) {\n            return\n        };\n        var la = {\n        }, ma = false;\n        for (var na in ka) {\n            var oa = ka[na];\n            if (ga(oa)) {\n                la[na] = oa;\n                ma = true;\n            }\n        ;\n        };\n        if (!ma) {\n            return\n        };\n        z(function(pa) {\n            for (var qa in la) {\n                var ra = la[qa];\n                if ((!pa[qa] && ga(ra))) {\n                    pa[qa] = la[qa];\n                };\n            };\n            y(pa);\n            n.updatedUnseenState();\n        });\n    };\n    function fa(ka, la) {\n        var ma = false;\n        for (var na in ka) {\n            ma = true;\n            break;\n        };\n        if (ma) {\n            z(function(oa) {\n                var pa = false;\n                for (var qa in ka) {\n                    var ra = ka[qa], sa = i.isGreaterThan(ra, oa[qa]);\n                    if ((oa[qa] && ((!ra || sa)))) {\n                        delete oa[qa];\n                        pa = true;\n                    }\n                ;\n                };\n                if (pa) {\n                    y(oa);\n                    n.updatedUnseenState();\n                    if ((la && (ba() === 0))) {\n                        m.markSeen();\n                    };\n                }\n            ;\n            });\n        };\n    };\n    function ga(ka) {\n        return (i.convertActionIDToTimestamp(ka) > r);\n    };\n    function ha(ka) {\n        return ka.map(m.convertThreadIDIfAvailable);\n    };\n    function ia(ka) {\n        var la = aa();\n        if (!la) {\n            return\n        };\n        for (var ma in ka) {\n            var na = ka[ma];\n            if (la[ma]) {\n                la[na] = la[ma];\n                delete la[ma];\n            }\n        ;\n        };\n        y(la);\n    };\n    function ja(ka) {\n        var la = ((ka.message_counts || []));\n        for (var ma = 0; (ma < la.length); ma++) {\n            if ((la[ma].folder == o.MessagingTag.INBOX)) {\n                return la[ma]\n            };\n        };\n        return null;\n    };\n    m.subscribe(\"update-unseen\", function(ka, la) {\n        ca(la);\n    });\n    m.subscribe(\"update-thread-ids\", function(ka, la) {\n        ia(la);\n    });\n    g.subscribe(k.DUMP_EVENT, function(ka, la) {\n        la.messaging = (la.messaging || {\n        });\n        la.messaging.unseen = h({\n        }, aa());\n        la.messaging.unseen_max_count = s;\n        la.messaging.unseen_time = r;\n    });\n    e.exports = x;\n});\n__d(\"ChatTitleBarBlinker\", [\"ChatActivity\",\"DocumentTitle\",\"JSLogger\",\"MercuryThreadInformer\",\"MercuryNotificationRenderer\",\"PresenceState\",\"MercuryTimestampTracker\",\"MercuryUnseenState\",], function(a, b, c, d, e, f) {\n    var g = b(\"ChatActivity\"), h = b(\"DocumentTitle\"), i = b(\"JSLogger\"), j = b(\"MercuryThreadInformer\"), k = b(\"MercuryNotificationRenderer\"), l = b(\"PresenceState\"), m = b(\"MercuryTimestampTracker\"), n = b(\"MercuryUnseenState\"), o = i.create(\"chat_title\"), p = null, q = 0, r = false;\n    function s() {\n        if (p) {\n            p.stop();\n            p = null;\n            return true;\n        }\n    ;\n        return false;\n    };\n    function t(y) {\n        var z = (y || m.getLastUserMessageTimestamp());\n        if ((q <= z)) {\n            q = z;\n            if ((s() || r)) {\n                l.doSync();\n            };\n        }\n    ;\n    };\n    var u = {\n        blink: function(y, z) {\n            if ((!p && (q < z))) {\n                k.renderDocumentTitle(y, function(aa) {\n                    if (!p) {\n                        p = h.blink(aa);\n                    };\n                });\n            };\n        },\n        stopBlinking: function() {\n            t();\n        },\n        blinkingElsewhere: function() {\n            r = true;\n        }\n    };\n    function v(y) {\n        var z = l.verifyNumber(y.sb2);\n        if ((!z || (z <= q))) {\n            return null\n        };\n        return z;\n    };\n    function w(y) {\n        var z = (y && v(y));\n        if (z) {\n            q = z;\n            o.debug(\"load\", q);\n            s();\n            r = false;\n        }\n    ;\n    };\n    function x(y) {\n        var z = v(y);\n        if (!z) {\n            o.debug(\"store\", q);\n            y.sb2 = q;\n            r = false;\n        }\n    ;\n        return y;\n    };\n    l.registerStateStorer(x);\n    l.registerStateLoader(w);\n    j.subscribe(\"thread-read-changed\", function(y, z) {\n        var aa = m.getLastUserMessageTimestamp(), ba = 0;\n        for (var ca in z) {\n            if (((z[ca].mark_as_read && (z[ca].timestamp >= aa)) && (z[ca].timestamp > ba))) {\n                ba = z[ca].timestamp;\n            };\n        };\n        (ba && t(ba));\n    });\n    g.subscribe(\"activity\", function() {\n        t();\n    });\n    (function() {\n        var y = l.getInitial();\n        if (y) {\n            q = (v(y) || 0);\n        };\n    })();\n    e.exports = u;\n});\n__d(\"MercuryBrowserAlerts\", [\"ArbiterMixin\",\"ChatActivity\",\"ChatConfig\",\"ChatOptions\",\"ChatTitleBarBlinker\",\"copyProperties\",\"MercuryParticipants\",\"Sound\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"ArbiterMixin\"), h = b(\"ChatActivity\"), i = b(\"ChatConfig\"), j = b(\"ChatOptions\"), k = b(\"ChatTitleBarBlinker\"), l = b(\"copyProperties\"), m = b(\"MercuryParticipants\"), n = b(\"Sound\"), o = c(\"MercuryConstants\");\n    n.init([\"audio/ogg\",\"audio/mpeg\",]);\n    function p(r) {\n        if (j.getSetting(\"sound\")) {\n            n.play([i.get(\"sound.notif_ogg_url\"),i.get(\"sound.notif_mp3_url\"),], r, false);\n        };\n    };\n    var q = {\n        messageReceived: function(r) {\n            var s = o.MessagingTag;\n            if ((((r.author == m.user) || !r.is_unread) || (((r.folder != s.INBOX) && (r.folder != s.ARCHIVED))))) {\n                return\n            };\n            var t = h.isActive(), u = r.thread_id, v = r.timestamp;\n            if (t) {\n                var w = false;\n                q.inform(\"before-alert\", {\n                    threadID: u,\n                    cancelAlert: function() {\n                        w = true;\n                    }\n                });\n                (!w && p(v));\n            }\n             else {\n                k.blink(u, v);\n                p(v);\n            }\n        ;\n            k.blinkingElsewhere();\n        }\n    };\n    e.exports = l(q, g);\n});\n__d(\"VideoCallRecordMessageDialog\", [\"Dialog\",\"URI\",], function(a, b, c, d, e, f) {\n    var g = b(\"Dialog\"), h = b(\"URI\"), i = {\n        get: function(j, k) {\n            return new g().setTitle(tx._(\"{firstname} is Unavailable\", {\n                firstname: k\n            })).setBody(\"Would you like to leave a video message?\").setButtons([{\n                name: \"record-message\",\n                label: \"Record Message\"\n            },g.CANCEL,]).setHandler(function() {\n                var l = h(\"/ajax/messaging/composer.php\").setQueryData({\n                    ids: [j,],\n                    autoloadvideo: true\n                }).toString();\n                g.bootstrap(l);\n            });\n        }\n    };\n    e.exports = i;\n});\n__d(\"VideoCallCore\", [\"event-extensions\",\"Arbiter\",\"AsyncRequest\",\"AvailableList\",\"AvailableListConstants\",\"Bootloader\",\"ChannelConstants\",\"Cookie\",\"Dialog\",\"UserAgent\",\"ge\",\"ShortProfiles\",\"VideoCallRecordMessageDialog\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"AvailableList\"), j = b(\"AvailableListConstants\"), k = b(\"Bootloader\"), l = b(\"ChannelConstants\"), m = b(\"Cookie\"), n = b(\"Dialog\"), o = b(\"UserAgent\"), p = b(\"ge\"), q = [], r = {\n        isSupported: function() {\n            if (o.windows()) {\n                return ((((((o.ie() >= 7) && !o.ie64())) || (o.firefox() >= 3.6)) || (o.chrome() >= 5)) || (o.opera() >= 12));\n            }\n             else if ((o.osx() > 10.4)) {\n                return (((((o.firefox() >= 3.6) || (o.chrome() >= 5)) || (o.safari() >= 500)) || (o.opera() >= 12)))\n            }\n        ;\n            return false;\n        },\n        isInstalled: function() {\n            var v = false;\n            if (this.isSupported()) {\n                if (s()) {\n                    var w = null;\n                    try {\n                        w = new ActiveXObject(\"SkypeLimited.SkypeWebPlugin\");\n                        v = !!w;\n                    } catch (x) {\n                    \n                    };\n                    w = null;\n                }\n                 else v = t();\n            \n            };\n            return v;\n        },\n        mightReloadPostInstall: function() {\n            return o.windows();\n        },\n        onVideoMessage: function(v) {\n            q.push(v);\n            k.loadModules([\"VideoCallController\",], bagofholding);\n        },\n        setMessageHandler: function(v) {\n            this.onVideoMessage = v;\n            if (v) {\n                while (q.length) {\n                    v(q.shift());;\n                }\n            };\n        },\n        availableForCall: function(v) {\n            var w = i.get(v);\n            return ((w == j.ACTIVE) || (w == j.IDLE));\n        },\n        onProfileButtonClick: function(v) {\n            r.startCallOrLeaveMessage(v, \"profile_button_click\");\n        },\n        attachListenerToProfileButton: function(v) {\n            var w = p(\"videoCallProfileButton\");\n            if (w) {\n                Event.listen(w, \"click\", function(event) {\n                    r.startCallOrLeaveMessage(v, \"profile_button_click_timeline\");\n                });\n            };\n        },\n        startCallOrLeaveMessage: function(v, w) {\n            if (this.availableForCall(v)) {\n                r.showOutgoingCallDialog(v, w);\n            }\n             else b(\"ShortProfiles\").get(v, function(x) {\n                b(\"VideoCallRecordMessageDialog\").get(v, x.firstName).show();\n            });\n        ;\n        },\n        showOutgoingCallDialog: function(v, w) {\n            var x = (w || \"unknown\");\n            r.logClick(v, x);\n            var y = (r.isInstalled() ? \"outgoing_dialog.php\" : \"intro.php\"), z = (((\"/ajax/chat/video/\" + y) + \"?idTarget=\") + v);\n            new n().setAllowCrossPageTransition(true).setAsync(new h(z)).show();\n        },\n        logClick: function(v, w) {\n            new h().setURI(\"/ajax/chat/video/log_click.php\").setData({\n                targetUserID: v,\n                clickSource: w\n            }).setAllowCrossPageTransition(true).setErrorHandler(bagofholding).send();\n        }\n    };\n    function s() {\n        return ((o.ie() && o.windows()) && !o.opera());\n    };\n    function t() {\n        if (!navigator) {\n            return null\n        };\n        navigator.plugins.refresh(false);\n        var v = navigator.mimeTypes[\"application/skypesdk-plugin\"];\n        return (v && v.enabledPlugin);\n    };\n    function u() {\n        if (!r.mightReloadPostInstall()) {\n            return\n        };\n        var v = m.get(\"vcpwn\");\n        if (v) {\n            m.clear(\"vcpwn\");\n            var w = m.get(\"vctid\");\n            if (w) {\n                m.clear(\"vctid\");\n                if (m.get(\"vctid\")) {\n                    return\n                };\n                if ((w && r.isInstalled())) {\n                    var x = (\"/ajax/chat/video/outgoing_dialog.php?idTarget=\" + w);\n                    new n().setAllowCrossPageTransition(true).setAsync(new h(x)).show();\n                }\n            ;\n            }\n        ;\n        }\n    ;\n    };\n    g.subscribe(l.getArbiterType(\"video\"), function(v, w) {\n        r.onVideoMessage(w.obj);\n    });\n    g.subscribe(l.getArbiterType(\"chat_event\"), function(v, w) {\n        if ((w.obj.event_name == \"missed-call\")) {\n            k.loadModules([\"VideoCallController\",], function(x) {\n                x.onMissedCallEvent(w.obj);\n            });\n        };\n    });\n    u();\n    e.exports = r;\n});\n__d(\"ChatApp\", [\"CSS\",\"$\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"$\"), i = b(\"copyProperties\"), j = false, k = false, l = false;\n    function m(n, o) {\n        m.init(h(\"fbDockChat\"), n, o);\n    };\n    i(m, {\n        init: function(n, o, p) {\n            this.root = n;\n            d([\"TabsViewport\",\"ChatTabController\",\"ChatTabViewCoordinator\",\"MercuryServerRequests\",\"MercuryChannelHandler\",\"MercuryStateCheck\",], function(q, r, s, t, u, v) {\n                t.handleUpdate(p);\n                this.tabsViewport = new q(o);\n                this.tabController = new r(this.tabsViewport);\n                this.tabViewCoordinator = new s(o, this.tabsViewport);\n                j = k = true;\n            }.bind(this));\n        },\n        hide: function() {\n            if ((!j || l)) {\n                return\n            };\n            g.hide(this.root);\n            l = true;\n        },\n        unhide: function() {\n            if (j) {\n                if (l) {\n                    g.show(this.root);\n                    this.tabsViewport.checkWidth();\n                    d([\"Dock\",], function(n) {\n                        n.resizeAllFlyouts();\n                    });\n                    l = false;\n                }\n            ;\n            }\n             else if (!k) {\n                d([\"UIPagelet\",], function(n) {\n                    n.loadFromEndpoint(\"DockChatPagelet\", \"pagelet_chat\");\n                });\n                k = true;\n            }\n            \n        ;\n        }\n    });\n    e.exports = m;\n});\n__d(\"ChatTabModel\", [\"function-extensions\",\"Arbiter\",\"ArbiterMixin\",\"ChatBehavior\",\"ChatConfig\",\"copyProperties\",\"JSLogger\",\"MercuryAssert\",\"MercuryServerRequests\",\"MercuryThreads\",\"MercuryTimestampTracker\",\"PresenceState\",\"PresenceUtil\",\"areObjectsEqual\",\"PresenceInitialData\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"ChatBehavior\"), j = b(\"ChatConfig\"), k = b(\"copyProperties\"), l = b(\"JSLogger\"), m = b(\"MercuryAssert\"), n = b(\"MercuryServerRequests\"), o = b(\"MercuryThreads\"), p = b(\"MercuryTimestampTracker\"), q = c(\"PresenceInitialData\"), r = b(\"PresenceState\"), s = b(\"PresenceUtil\"), t = b(\"areObjectsEqual\"), u = [], v = null, w = null, x = null, y = null;\n    function z() {\n        return parseInt(q.serverTime, 10);\n    };\n    var aa = (j.get(\"tab_max_load_age\") || 3600000), ba = (z() - aa), ca = 0, da = 20, ea = l.create(\"chat_tab_model\"), fa = false;\n    function ga(xa) {\n        var ya = r.verifyNumber(xa.uct2);\n        if ((!ya || (typeof ya !== \"number\"))) {\n            ea.warn(\"bad_cookie_version\", xa.uct2);\n            return null;\n        }\n    ;\n        if (((ya <= ca) || (ya < ba))) {\n            return null\n        };\n        return ya;\n    };\n    function ha(xa) {\n        var ya = ga(xa);\n        if (!ya) {\n            var za = {\n            };\n            za.old_tabs = ((xa && xa.t2) && JSON.stringify(xa.t2));\n            za.old_promoted = (xa && xa.lm2);\n            za.old_time = (xa && xa.uct2);\n            za.old_reason = (xa && xa.tr);\n            za.old_window = (xa && xa.tw);\n            var ab;\n            if ((w && xa.t2)) {\n                for (var bb = 0; (bb < xa.t2.length); bb++) {\n                    var cb = xa.t2[bb];\n                    if ((cb.i === w)) {\n                        ab = cb.r;\n                    };\n                }\n            };\n            var db = [];\n            u.forEach(function(eb) {\n                if (!eb.fragile) {\n                    var fb = {\n                        i: eb.id,\n                        si: eb.server_id\n                    };\n                    if ((eb.raised || (((eb.id === w) && ab)))) {\n                        fb.r = 1;\n                    };\n                    db.push(fb);\n                }\n            ;\n            });\n            xa.t2 = db;\n            xa.uct2 = ca;\n            xa.lm2 = v;\n            xa.tr = y;\n            xa.tw = s.getSessionID();\n            za.new_tabs = JSON.stringify(xa.t2);\n            za.new_promoted = xa.lm2;\n            za.new_time = xa.uct2;\n            za.new_reason = xa.tr;\n            za.new_window = xa.tw;\n            ea.debug(\"store\", za);\n        }\n    ;\n        return xa;\n    };\n    function ia(xa) {\n        if (xa) {\n            var ya = ga(xa);\n            if (ya) {\n                var za = {\n                };\n                za.old_tabs = JSON.stringify(u);\n                za.old_promoted = v;\n                za.old_time = ca;\n                za.old_reason = y;\n                za.window_id = s.getSessionID();\n                za.cookie_tabs = ((xa && xa.t2) && JSON.stringify(xa.t2));\n                za.cookie_promoted = (xa && xa.lm2);\n                za.cookie_time = (xa && xa.uct2);\n                za.cookie_reason = (xa && xa.tr);\n                za.cookie_window = (xa && xa.tw);\n                ca = ya;\n                y = \"load\";\n                var ab = ja(xa.t2, (xa.lm2 || null));\n                za.load_result = ab;\n                za.new_tabs = JSON.stringify(u);\n                za.new_promoted = v;\n                za.new_time = ca;\n                za.new_reason = y;\n                var event = \"load\";\n                if (!fa) {\n                    event += \"_init\";\n                };\n                ea.log(event, za);\n                return ab;\n            }\n        ;\n        }\n    ;\n        return false;\n    };\n    function ja(xa, ya) {\n        if (ka(xa, ya)) {\n            var za = u.filter(function(cb) {\n                return cb.fragile;\n            }), ab = {\n            };\n            v = null;\n            u = xa.map(function(cb) {\n                var db = {\n                    id: cb.i,\n                    server_id: cb.si\n                };\n                if ((db.id == ya)) {\n                    v = db.id;\n                };\n                if ((w == cb.i)) {\n                    var eb = pa(w);\n                    if ((eb != -1)) {\n                        db.raised = u[eb].raised;\n                        return db;\n                    }\n                     else return null\n                ;\n                }\n            ;\n                if (cb.r) {\n                    db.raised = true;\n                };\n                ab[db.id] = db;\n                return db;\n            });\n            u = u.filter(function(cb) {\n                return (cb != null);\n            });\n            if (x) {\n                for (var bb in x) {\n                    if ((!ab[bb] || !ab[bb].raised)) {\n                        delete x[bb];\n                    };\n                }\n            };\n            za = za.filter(function(cb) {\n                return !ab[cb.id];\n            });\n            u = u.concat(za);\n            oa();\n            return true;\n        }\n    ;\n        return false;\n    };\n    function ka(xa, ya) {\n        if ((ya != v)) {\n            return true\n        };\n        var za = u.filter(function(cb) {\n            return !cb.fragile;\n        });\n        if ((xa.length != za.length)) {\n            return true\n        };\n        for (var ab = 0, bb = xa.length; (ab < bb); ab++) {\n            if ((xa[ab].id === w)) {\n                continue;\n            };\n            if (!t(xa[ab], za[ab])) {\n                return true\n            };\n        };\n        return false;\n    };\n    function la(xa, ya, za) {\n        var ab = ia(r.get());\n        if (((ya === undefined) || (ya > ca))) {\n            if (xa()) {\n                ab = true;\n                y = (za || null);\n                na(ya);\n            }\n        ;\n        }\n         else ea.error(\"rejected\", {\n            change_time: ya,\n            state_time: ca\n        });\n    ;\n        (ab && ma());\n    };\n    function ma() {\n        if (fa) {\n            va.inform(\"chat/tabs-changed\", va.get());\n        };\n    };\n    function na(xa) {\n        if ((xa === undefined)) {\n            xa = Math.max((p.getLastUserMessageTimestamp() || 1), (ca + 1));\n        };\n        ca = xa;\n        r.doSync();\n    };\n    function oa() {\n        var xa = (u.length - da);\n        if ((xa > 0)) {\n            u = u.filter(function(ya) {\n                return (ya.raised || (xa-- <= 0));\n            });\n        };\n    };\n    function pa(xa) {\n        for (var ya = 0; (ya < u.length); ya++) {\n            if ((u[ya].id == xa)) {\n                return ya\n            };\n        };\n        return -1;\n    };\n    function qa(xa) {\n        var ya = o.getThreadMetaNow(xa);\n        if (!ya) {\n            return false\n        };\n        if ((ya.is_canonical_user || ya.is_canonical_group)) {\n            return sa(xa);\n        }\n         else {\n            var za = ra(xa);\n            if (za) {\n                n.getServerThreadID(xa, function(ab) {\n                    if (ta(xa, ab)) {\n                        na();\n                        ma();\n                    }\n                ;\n                });\n            };\n            return za;\n        }\n    ;\n    };\n    function ra(xa) {\n        if ((pa(xa) === -1)) {\n            u.push({\n                id: xa,\n                fragile: true\n            });\n            ea.log(\"open_fragile_tab\", {\n                tabs: JSON.stringify(u),\n                opened: xa,\n                window_id: s.getSessionID()\n            });\n            return true;\n        }\n    ;\n        return false;\n    };\n    function sa(xa) {\n        var ya = pa(xa);\n        if ((ya != -1)) {\n            if (u[ya].fragile) {\n                u.splice(ya, 1);\n            }\n             else return false\n        \n        };\n        for (var za = 0; (za <= u.length); za++) {\n            if (((za == u.length) || u[za].fragile)) {\n                u.splice(za, 0, {\n                    id: xa\n                });\n                oa();\n                ea.log(\"open_tab\", {\n                    tabs: JSON.stringify(u),\n                    opened: xa,\n                    window_id: s.getSessionID()\n                });\n                return true;\n            }\n        ;\n        };\n    };\n    function ta(xa, ya) {\n        var za = pa(xa);\n        if (((za != -1) && u[za].fragile)) {\n            var ab = u[za];\n            ab.fragile = false;\n            ab.server_id = ya;\n            var bb = [];\n            u.forEach(function(cb) {\n                if ((cb.id != xa)) {\n                    if ((ab && cb.fragile)) {\n                        bb.push(ab);\n                        ab = null;\n                    }\n                ;\n                    bb.push(cb);\n                }\n            ;\n            });\n            if (ab) {\n                bb.push(ab);\n            };\n            u = bb;\n            ea.log(\"make_permanent\", {\n                tabs: JSON.stringify(u),\n                tab_id: xa,\n                window_id: s.getSessionID()\n            });\n            return true;\n        }\n    ;\n        return false;\n    };\n    function ua(xa) {\n        var ya = pa(xa);\n        if ((xa == v)) {\n            v = null;\n        };\n        if ((ya != -1)) {\n            u.splice(ya, 1);\n            ea.log(\"close_tab\", {\n                tabs: JSON.stringify(u),\n                closed: xa,\n                window_id: s.getSessionID()\n            });\n            return true;\n        }\n    ;\n        return false;\n    };\n    r.registerStateStorer(ha);\n    r.registerStateLoader(function(xa) {\n        if (ia(xa)) {\n            ma();\n        };\n    });\n    function va() {\n    \n    };\n    k(va, h, {\n        indexOf: function(xa) {\n            return pa(xa);\n        },\n        getTab: function(xa) {\n            m.isThreadID(xa);\n            var ya = this.indexOf(xa);\n            if ((ya > -1)) {\n                var za = u[ya];\n                return k({\n                }, za);\n            }\n        ;\n            return null;\n        },\n        closeAllTabs: function() {\n            if (u.length) {\n                ea.log(\"close_all_tabs\", {\n                    closed_tabs: JSON.stringify(u),\n                    window_id: s.getSessionID()\n                });\n                u = [];\n                v = null;\n                if (x) {\n                    x = {\n                    };\n                };\n                na();\n                ma();\n            }\n        ;\n        },\n        closeFragileTabs: function() {\n            var xa = [];\n            for (var ya = 0; (ya < u.length); ya++) {\n                if (u[ya].fragile) {\n                    xa.push(u[ya]);\n                    u.splice(ya);\n                    ma();\n                    break;\n                }\n            ;\n            };\n            ea.log(\"close_fragile_tabs\", {\n                tabs: JSON.stringify(u),\n                fragile_closed: xa,\n                window_id: s.getSessionID()\n            });\n        },\n        closeTab: function(xa, ya) {\n            m.isThreadID(xa);\n            var za = false;\n            if (x) {\n                delete x[xa];\n                za = true;\n            }\n        ;\n            la(function() {\n                if (ua(xa)) {\n                    za = true;\n                };\n                return za;\n            }, undefined, ya);\n        },\n        closeTabAndDemote: function(xa, ya, za) {\n            m.isThreadID(xa);\n            var ab = false;\n            if (x) {\n                delete x[xa];\n                ab = true;\n            }\n        ;\n            la(function() {\n                if (ua(xa)) {\n                    if (v) {\n                        var bb = pa(v);\n                        if ((bb > ya)) {\n                            var cb = u.splice(bb, 1)[0];\n                            u.splice(ya, 0, cb);\n                            v = null;\n                        }\n                    ;\n                    }\n                ;\n                    ab = true;\n                }\n            ;\n                return ab;\n            }, undefined, za);\n        },\n        raiseTab: function(xa, ya) {\n            m.isThreadID(xa);\n            var za = false;\n            if ((x && ya)) {\n                x[xa] = true;\n                za = true;\n            }\n        ;\n            if ((!ya && (xa === w))) {\n                (za && ma());\n                return;\n            }\n        ;\n            la(function() {\n                if (qa(xa)) {\n                    za = true;\n                };\n                var ab = pa(xa);\n                if (((ab != -1) && !u[ab].raised)) {\n                    u[ab].raised = true;\n                    za = true;\n                    ea.log(\"raise_tab\", {\n                        tabs: JSON.stringify(u),\n                        raised: xa,\n                        window_id: s.getSessionID()\n                    });\n                }\n            ;\n                return za;\n            });\n        },\n        get: function() {\n            var xa = u.map(function(ya) {\n                var za = k({\n                }, ya);\n                delete za.fragile;\n                if (x) {\n                    za.raised = x[za.id];\n                };\n                return za;\n            });\n            return {\n                tabs: xa,\n                promoted: v\n            };\n        },\n        openFragileTab: function(xa) {\n            m.isThreadID(xa);\n            if (ra(xa)) {\n                ma();\n            };\n        },\n        openTab: function(xa) {\n            m.isThreadID(xa);\n            la(qa.curry(xa));\n        },\n        lowerTab: function(xa) {\n            m.isThreadID(xa);\n            var ya = false;\n            if (x) {\n                delete x[xa];\n                ya = true;\n            }\n        ;\n            la(function() {\n                var za = pa(xa);\n                if (((za != -1) && u[za].raised)) {\n                    delete u[za].raised;\n                    ea.log(\"lower_tab\", {\n                        tabs: JSON.stringify(u),\n                        lowered: xa,\n                        window_id: s.getSessionID()\n                    });\n                    ya = true;\n                }\n            ;\n                return ya;\n            });\n        },\n        raiseAndPromoteTab: function(xa, ya, za, ab) {\n            m.isThreadID(xa);\n            var bb = false;\n            if ((x && ya)) {\n                x[xa] = true;\n                bb = true;\n            }\n        ;\n            if ((!ya && (xa === w))) {\n                (bb && ma());\n                return;\n            }\n        ;\n            la(function() {\n                if (qa(xa)) {\n                    bb = true;\n                };\n                var cb = pa(xa);\n                if (((cb != -1) && ((!u[cb].raised || (v != xa))))) {\n                    u[cb].raised = true;\n                    v = xa;\n                    bb = true;\n                    ea.log(\"raise_and_promote_tab\", {\n                        tabs: JSON.stringify(u),\n                        promoted: xa,\n                        window_id: s.getSessionID()\n                    });\n                }\n            ;\n                return bb;\n            }, za, ab);\n        },\n        squelchTab: function(xa) {\n            m.isThreadID(xa);\n            w = xa;\n            this.lowerTab(xa);\n            ea.log(\"squelch_tab\", {\n                squelched: xa,\n                tabs: JSON.stringify(u),\n                window_id: s.getSessionID()\n            });\n        },\n        clearSquelchedTab: function() {\n            if (w) {\n                ea.log(\"unsquelch_tab\", {\n                    squelched: w,\n                    tabs: JSON.stringify(u),\n                    window_id: s.getSessionID()\n                });\n            };\n            w = null;\n        }\n    });\n    g.subscribe(l.DUMP_EVENT, function(xa, ya) {\n        ya.chat_tabs = {\n            promoted: v,\n            tabs: u.map(function(za) {\n                return k({\n                }, za);\n            }),\n            time: ca,\n            max_load_age: aa\n        };\n    });\n    function wa() {\n        var xa = i.ignoresRemoteTabRaise();\n        if ((xa && !x)) {\n            ea.log(\"start_ignore_remote_raise\");\n            x = {\n            };\n            ma();\n        }\n         else if ((!xa && x)) {\n            ea.log(\"stop_ignore_remote_raise\");\n            x = null;\n            ma();\n        }\n        \n    ;\n    };\n    i.subscribe(i.ON_CHANGED, wa);\n    wa();\n    ia(r.getInitial(), true);\n    if ((ca === 0)) {\n        ca = (z() - 600000);\n    };\n    fa = true;\n    e.exports = va;\n});\n__d(\"VideoCallPromo\", [\"ArbiterMixin\",\"AsyncRequest\",\"AvailableList\",\"AvailableListConstants\",\"ChatConfig\",\"ChatVisibility\",\"ContextualDialogX\",\"copyProperties\",\"CSS\",\"MercuryThreads\",\"MercuryParticipants\",\"VideoCallCore\",\"ChatTabTemplates\",], function(a, b, c, d, e, f) {\n    var g = b(\"ArbiterMixin\"), h = b(\"AsyncRequest\"), i = b(\"AvailableList\"), j = b(\"AvailableListConstants\"), k = b(\"ChatConfig\"), l = b(\"ChatVisibility\"), m = b(\"ContextualDialogX\"), n = b(\"copyProperties\"), o = b(\"CSS\"), p = b(\"MercuryThreads\"), q = b(\"MercuryParticipants\"), r = c(\"ChatTabTemplates\"), s = b(\"VideoCallCore\");\n    function t() {\n        this._dialog = null;\n    };\n    function u(w) {\n        if (!((s.isSupported() && k.get(\"video.show_promo\")))) {\n            return false\n        };\n        var x = p.getCanonicalUserInThread(w);\n        if (!x) {\n            return false\n        };\n        return (l.isOnline() && s.availableForCall(x));\n    };\n    function v(w) {\n        new h().setURI(\"/ajax/chat/video/log_promo.php\").setData({\n            viewedUserID: w\n        }).setAllowCrossPageTransition(true).setErrorHandler(bagofholding).send();\n    };\n    n(t.prototype, g);\n    n(t.prototype, {\n        render: function(w, x) {\n            var y = u(x);\n            if (!y) {\n                return\n            };\n            var z = p.getCanonicalUserInThread(x);\n            q.get((\"fbid:\" + z), function(aa) {\n                if (!aa.call_promo) {\n                    return\n                };\n                var ba = r[\":fb:mercury:call:promo\"].build();\n                this._dialog = new m();\n                this._dialog.init(ba.getRoot()).setWidth(250).setAlignH(\"center\").setContext(w).show();\n                o.addClass(this._dialog.getRoot(), \"uiContextualDialogWithFooterArrowBottom\");\n                o.addClass(w, \"video_call_promo\");\n                v(p.getCanonicalUserInThread(x));\n                this.inform(\"chat/dialog-rendered\", {\n                    dialog: this,\n                    thread_id: x\n                });\n            }.bind(this));\n        },\n        updatePosition: function() {\n            if ((this._dialog && this._dialog.isShown())) {\n                this._dialog.updatePosition();\n            };\n        },\n        hide: function() {\n            if ((this._dialog && this._dialog.isShown())) {\n                this._dialog.hide();\n                this._dialog = null;\n            }\n        ;\n        }\n    });\n    e.exports = t;\n});\n__d(\"VideoCallTourDialog\", [\"ArbiterMixin\",\"ContextualDialogX\",\"copyProperties\",\"CSS\",\"MercuryThreads\",\"VideoCallCore\",\"VideoCallingTour\",\"ChatTabTemplates\",], function(a, b, c, d, e, f) {\n    var g = b(\"ArbiterMixin\"), h = b(\"ContextualDialogX\"), i = b(\"copyProperties\"), j = b(\"CSS\"), k = b(\"MercuryThreads\"), l = c(\"ChatTabTemplates\"), m = b(\"VideoCallCore\"), n = b(\"VideoCallingTour\");\n    function o() {\n        this._dialog = null;\n    };\n    i(o.prototype, g);\n    i(o.prototype, {\n        render: function(p, q) {\n            var r = k.getCanonicalUserInThread(q);\n            if ((!r || !m.availableForCall(r))) {\n                return\n            };\n            var s = l[\":fb:mercury:call:tour\"].build();\n            this._dialog = new h();\n            this._dialog.init(s.getRoot()).setWidth(250).setAlignH(\"center\").setContext(p).show();\n            j.addClass(this._dialog.getRoot(), \"uiContextualDialogWithFooterArrowBottom\");\n            j.addClass(p, \"video_call_tour\");\n            this.inform(\"chat/dialog-rendered\", {\n                dialog: this,\n                thread_id: q\n            });\n            n.inform(\"videocallingtour/end\");\n        },\n        updatePosition: function() {\n            if ((this._dialog && this._dialog.isShown())) {\n                this._dialog.updatePosition();\n            };\n        },\n        hide: function() {\n            if ((this._dialog && this._dialog.isShown())) {\n                this._dialog.hide();\n                this._dialog = null;\n            }\n        ;\n        }\n    });\n    e.exports = o;\n});\n__d(\"ChatContextualDialogController\", [\"event-extensions\",\"ArbiterMixin\",\"ChatTabModel\",\"VideoCallingTour\",\"VideoCallPromo\",\"VideoCallTourDialog\",\"copyProperties\",\"setTimeoutAcrossTransitions\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"ChatTabModel\"), i = b(\"VideoCallingTour\"), j = b(\"VideoCallPromo\"), k = b(\"VideoCallTourDialog\"), l = b(\"copyProperties\"), m = b(\"setTimeoutAcrossTransitions\"), n = 60000, o = false, p = false, q = function(x, y) {\n        this._videoCallPromo = new j();\n        this._videoCallTour = new k();\n        this._threadID = x;\n        this._tabMainElement = y;\n        this._openDialog = null;\n        this._subscriptionTokens = [];\n        this._scrollListener = null;\n        this._timeout = null;\n    };\n    function r(x, event, y) {\n        if (x._openDialog) {\n            x._openDialog.updatePosition();\n        };\n    };\n    function s(x) {\n        if (x._openDialog) {\n            x._openDialog.updatePosition();\n        };\n    };\n    function t(x) {\n        if (x._openDialog) {\n            x._openDialog.hide();\n            x._openDialog = null;\n        }\n    ;\n        if (x._timeout) {\n            clearTimeout(x._timeout);\n            x._timeout = null;\n        }\n    ;\n        while (x._subscriptionTokens.length) {\n            x._subscriptionTokens.pop().unsubscribe();;\n        };\n        if (x._scrollListener) {\n            x._scrollListener.remove();\n            x._scrollListener = null;\n        }\n    ;\n    };\n    function u(x, event, y) {\n        if ((y.thread_id === x._threadID)) {\n            x._openDialog = y.dialog;\n            o = true;\n            w(x);\n            x._timeout = m(x.destroy.bind(x, x._threadID), n);\n            x._scrollListener = Event.listen(window, \"scroll\", s.curry(x));\n        }\n    ;\n    };\n    function v(x, y) {\n        if (!x._openDialog) {\n            x._subscriptionTokens.push(y.subscribe(\"chat/dialog-rendered\", u.curry(x)));\n            y.render(x._tabMainElement, x._threadID);\n        }\n    ;\n    };\n    function w(x) {\n        x._subscriptionTokens.push(h.subscribe(\"chat/tabs-changed\", r.curry(x)), q.subscribe(\"dialog/close-all\", t.curry(x)));\n    };\n    l(q, g);\n    l(q.prototype, {\n        destroy: function() {\n            t(this);\n        },\n        tabFocused: function() {\n            if (p) {\n                v(this, this._videoCallTour);\n                return;\n            }\n        ;\n            if (!o) {\n                v(this, this._videoCallPromo);\n            };\n        },\n        tabNotActive: function() {\n            t(this);\n        },\n        hideVideoCallouts: function() {\n            t(this);\n        }\n    });\n    i.subscribe(\"videocallingtour/start\", function() {\n        p = true;\n        q.inform(\"dialog/close-all\");\n    });\n    i.subscribe(\"videocallingtour/end\", function() {\n        p = false;\n    });\n    e.exports = q;\n});\n__d(\"ChatPrivacyActionController\", [\"Arbiter\",\"ChatVisibility\",\"JSLogger\",\"PresencePrivacy\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ChatVisibility\"), i = b(\"JSLogger\"), j = b(\"PresencePrivacy\"), k = b(\"copyProperties\"), l = function(m, n) {\n        this._userID = m;\n        this._logger = i.create(\"blackbird\");\n        this._getState = function() {\n            if (h.isOnline()) {\n                return (j.allows(this._userID) ? l.NORMAL : l.BLOCKED)\n            };\n            return l.OFFLINE;\n        };\n        this._togglePrivacy = function() {\n            var o = this._getState();\n            switch (this._getState()) {\n              case l.OFFLINE:\n                if (h.isOnline()) {\n                    this._logger.error(\"tabs_already_online\");\n                    break;\n                }\n            ;\n                this._logger.log(\"tabs_go_online\", {\n                    tab_id: this._userID\n                });\n                h.goOnline(function() {\n                    if (!j.allows(this._userID)) {\n                        if ((this._getState() !== l.BLOCKED)) {\n                            this._logger.error(\"privacy_action_controller_blocked_inconsistency\");\n                        };\n                        this._togglePrivacy();\n                    }\n                ;\n                }.bind(this));\n                break;\n              case l.BLOCKED:\n                j.allow(this._userID);\n                this._logger.log(\"tabs_unblock\", {\n                    tab_id: this._userID\n                });\n                break;\n              case l.NORMAL:\n                j.disallow(this._userID);\n                this._logger.log(\"tabs_block\", {\n                    tab_id: this._userID\n                });\n                break;\n            };\n        };\n        (function() {\n            var o = function() {\n                (n && n(this._getState()));\n            }.bind(this);\n            o();\n            this._subscribeToken = j.subscribe(\"privacy-changed\", o);\n        }.bind(this)).defer();\n    };\n    l.OFFLINE = \"offline\";\n    l.BLOCKED = \"blocked\";\n    l.NORMAL = \"normal\";\n    k(l.prototype, {\n        togglePrivacy: function() {\n            this._logger.log(\"gear_menu_toggle_privacy\", {\n                tab_id: this._userID\n            });\n            this._togglePrivacy();\n        },\n        destroy: function() {\n            j.unsubscribe(this._subscribeToken);\n        }\n    });\n    e.exports = l;\n});\n__d(\"MessagesEmoticonView\", [\"event-extensions\",\"function-extensions\",\"DOM\",\"InputSelection\",\"Parent\",\"TextAreaControl\",\"Toggler\",\"copyProperties\",\"endsWith\",\"startsWith\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"DOM\"), h = b(\"InputSelection\"), i = b(\"Parent\"), j = b(\"TextAreaControl\"), k = b(\"Toggler\"), l = b(\"copyProperties\"), m = b(\"endsWith\"), n = b(\"startsWith\"), o = {\n        smile: \":)\",\n        frown: \":(\",\n        tongue: \":P\",\n        grin: \"=D\",\n        gasp: \":o\",\n        wink: \";)\",\n        glasses: \"8)\",\n        sunglasses: \"B|\",\n        grumpy: \"\\u003E:(\",\n        unsure: \":/\",\n        cry: \":'(\",\n        devil: \"3:)\",\n        angel: \"O:)\",\n        kiss: \":*\",\n        heart: \"\\u003C3\",\n        kiki: \"^_^\",\n        squint: \"-_-\",\n        confused: \"o.O\",\n        upset: \"\\u003E:o\",\n        pacman: \":v\",\n        robot: \":|]\",\n        colonthree: \":3\",\n        penguin: \"\\u003C(\\\")\",\n        putnam: \":putnam:\",\n        shark: \"(^^^)\",\n        42: \":42:\",\n        like: \"(y)\"\n    };\n    function p(r, s, t) {\n        var u = i.byClass(r, \"emoteIcon\");\n        if (!u) {\n            return\n        };\n        var v = \"name_\", w = null;\n        u.className.split(\" \").forEach(function(da) {\n            if (n(da, v)) {\n                w = da.substring(v.length);\n            };\n        });\n        if (!o[w]) {\n            return\n        };\n        var x = j.getInstance(s), y = x.getValue(), z = o[w], aa = y.substring(0, t.start), ba = y.substring(t.end);\n        if (((t.start > 0) && !m(aa, \" \"))) {\n            z = (\" \" + z);\n        };\n        if (!n(ba, \" \")) {\n            z += \" \";\n        };\n        var ca = ((aa + z) + ba);\n        t.start += z.length;\n        t.end = t.start;\n        x.setValue(ca);\n        h.set(s, t.start, t.end);\n    };\n    function q(r, s) {\n        var t = {\n            start: 0,\n            end: 0\n        };\n        function u() {\n            t = h.get(s);\n        };\n        var v = g.find(r, \".uiToggleFlyout\");\n        this._subscription = k.subscribe(\"show\", function(w, x) {\n            if ((x.active && g.contains(r, x.active))) {\n                h.set(s, t.start, t.end);\n            };\n        });\n        this._eventListeners = [Event.listen(v, \"click\", function(event) {\n            k.hide(r);\n            p(event.getTarget(), s, t);\n        }),Event.listen(s, \"keyup\", u),Event.listen(s, \"click\", u),];\n    };\n    l(q.prototype, {\n        destroy: function() {\n            this._subscription.unsubscribe();\n            while (this._eventListeners.length) {\n                this._eventListeners.pop().remove();;\n            };\n        }\n    });\n    e.exports = q;\n});\n__d(\"MercuryAttachmentRenderer\", [\"CSS\",\"DOM\",\"MercuryAttachment\",\"Style\",\"tx\",\"URI\",\"MercuryAttachmentTemplates\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"MercuryAttachment\"), j = b(\"Style\"), k = b(\"tx\"), l = b(\"URI\"), m = c(\"MercuryAttachmentTemplates\"), n = c(\"MercuryConstants\");\n    function o(q, r) {\n        var s = m[r].build().setNodeContent(\"filename\", q.name), t = s.getNode(\"link\");\n        t.setAttribute(\"href\", q.url);\n        (q.rel && t.setAttribute(\"rel\", q.rel));\n        g.addClass(s.getRoot(), i.getAttachIconClass(q.icon_type));\n        return s;\n    };\n    var p = {\n        renderError: function(q) {\n            var r = m[\":fb:mercury:attachment:error\"].build();\n            h.appendContent(r.getNode(\"error\"), q.error_msg);\n            return r.getRoot();\n        },\n        renderExternalLink: function(q) {\n            var r = m[\":fb:mercury:attachment:external-link\"].build().setNodeContent(\"name\", q.name).setNodeContent(\"shortLink\", q.base_url), s = r.getNode(\"preview\");\n            s.setAttribute(\"href\", q.url);\n            (q.rel && s.setAttribute(\"rel\", q.rel));\n            if (q.preview_url) {\n                var t = r.getNode(\"preview-image\");\n                t.setAttribute(\"src\", q.preview_url);\n                g.addClass(s, q.preview_class);\n                g.show(t);\n            }\n             else {\n                g.addClass(r.getRoot(), \"noMedia\");\n                g.hide(s);\n            }\n        ;\n            r.getNode(\"name\").setAttribute(\"href\", q.url);\n            return r.getRoot();\n        },\n        renderFileLink: function(q) {\n            var r = \":fb:mercury:attachment:file-link\", s = o(q, r);\n            return s.getRoot();\n        },\n        renderExtendedFileLink: function(q) {\n            var r = \":fb:mercury:attachment:extended-file-link\", s = o(q, r);\n            if (q.open_url) {\n                var t = s.getNode(\"openLinkContainer\");\n                g.show(t);\n                var u = s.getNode(\"openFile\");\n                u.setAttribute(\"href\", q.open_url);\n            }\n        ;\n            var v = s.getNode(\"downloadFile\");\n            v.setAttribute(\"href\", q.url);\n            (q.rel && v.setAttribute(\"rel\", q.rel));\n            return s.getRoot();\n        },\n        renderMusic: function(q) {\n            var r = m[\":fb:mercury:attachment:music\"].build().setNodeContent(\"filename\", q.name), s = r.getNode(\"link\");\n            s.setAttribute(\"href\", q.url);\n            s.setAttribute(\"target\", \"_blank\");\n            (q.rel && s.setAttribute(\"rel\", q.rel));\n            var t = r.getNode(\"preview\");\n            t.setAttribute(\"href\", q.url);\n            (q.rel && t.setAttribute(\"rel\", q.rel));\n            var u = r.getNode(\"preview-image\");\n            u.setAttribute(\"src\", q.preview_url);\n            g.show(u);\n            g.addClass(r.getNode(\"icon_link\"), \"MercuryMusicIcon\");\n            return r.getRoot();\n        },\n        renderPreview: function(q, r, s, t, u, v) {\n            var w = m[\":fb:mercury:attachment:preview\"].build(), x = w.getNode(\"image-link\"), y = \"\";\n            if (q) {\n                x.setAttribute(\"href\", q.url);\n                (q.rel && x.setAttribute(\"rel\", q.rel));\n                y = q.preview_url;\n                if ((s && (l(y).getPath() == \"/ajax/messaging/attachment.php\"))) {\n                    y += s;\n                };\n                if ((((q.is_social_report_attachment && t) && v) && u)) {\n                    var z = h.create(\"a\", {\n                        rel: \"dialog-post\",\n                        className: \"SocialReportLink\",\n                        id: \"respond-link\",\n                        ajaxify: l(\"/ajax/report/social_resolution/photo/\").setQueryData({\n                            attachment_fbid: q.attach_id,\n                            photo_fbid: q.shared_object_id,\n                            sender_id: v\n                        }).toString()\n                    });\n                    h.setContent(z, k._(\"Respond to {name}'s request\", {\n                        name: u.name\n                    }));\n                    h.appendContent(w.getRoot(), z);\n                }\n            ;\n                g.addClass(x, q.preview_class);\n            }\n             else {\n                y = \"/images/blank.gif\";\n                g.addClass(x, \"imagePreview\");\n                g.addClass(x, \"thumbnail\");\n            }\n        ;\n            var aa = w.getNode(\"preview-image\");\n            if (!r) {\n                g.show(aa);\n                if (!q) {\n                    j.set(aa, \"height\", \"194px\");\n                    j.set(aa, \"width\", \"194px\");\n                }\n            ;\n            }\n             else aa.onload = function() {\n                var ba = aa.width, ca = aa.height, da, ea;\n                if ((ba > ca)) {\n                    j.set(aa, \"maxHeight\", (r + \"px\"));\n                    ea = Math.min(ca, r);\n                    da = Math.ceil(((ba * ea) / ca));\n                }\n                 else {\n                    j.set(aa, \"maxWidth\", (r + \"px\"));\n                    da = Math.min(ba, r);\n                    ea = Math.ceil(((ca * da) / ba));\n                }\n            ;\n                j.set(aa, \"marginTop\", ((\"-\" + ((ea >>> 1))) + \"px\"));\n                j.set(aa, \"marginLeft\", ((\"-\" + ((da >>> 1))) + \"px\"));\n                g.show(aa);\n            };\n        ;\n            aa.setAttribute(\"src\", y);\n            return w.getRoot();\n        },\n        renderMultiplePreviews: function(q) {\n            return this._renderMultiplePreviews(q, q.length);\n        },\n        renderMultipleThumbnails: function(q) {\n            return this._renderMultiplePreviews(null, q);\n        },\n        renderShareLink: function(q) {\n            var r = m[\":fb:mercury:attachment:share-link\"].build().setNodeContent(\"name\", q.name), s = r.getNode(\"link\");\n            s.setAttribute(\"href\", q.url);\n            (q.rel && s.setAttribute(\"rel\", q.rel));\n            return r.getRoot();\n        },\n        renderVideoThumb: function(q) {\n            var r = m[\":fb:mercury:attachment:video-thumb\"].build(), s = r.getNode(\"thumb\");\n            s.setAttribute(\"href\", q.url);\n            s.setAttribute(\"rel\", q.rel);\n            var t = h.find(r.getRoot(), \"img\");\n            t.src = q.preview_url;\n            return r.getRoot();\n        },\n        _renderMultiplePreviews: function(q, r) {\n            var s = \"singleImagePreview\", t = 0;\n            if (((r == 2) || (r == 4))) {\n                s = \"doubleImagePreview\";\n                t = 194;\n            }\n             else if ((r > 1)) {\n                s = \"multipleImagePreview\";\n                t = 129;\n            }\n            \n        ;\n            var u = h.create(\"div\", {\n                className: \"imagePreviews\"\n            });\n            g.addClass(u, s);\n            if (q) {\n                var v = (\"&numPreviews=\" + r);\n                for (var w = 0; (w < r); ++w) {\n                    var x = this.renderPreview(q[w], t, v);\n                    h.appendContent(u, x);\n                };\n            }\n             else for (w = 0; (w < r); ++w) {\n                x = this.renderPreview(null, t);\n                h.appendContent(u, x);\n            }\n        ;\n            return u;\n        }\n    };\n    e.exports = p;\n});\n__d(\"MercuryRoger\", [\"ArbiterMixin\",\"MercuryServerRequests\",\"LiveTimer\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"ArbiterMixin\"), h = b(\"MercuryServerRequests\"), i = b(\"LiveTimer\"), j = b(\"copyProperties\"), k = {\n    }, l = {\n        getSeenBy: function(m) {\n            if (!m) {\n                return []\n            };\n            var n = [], o = k[m.thread_id];\n            for (var p in o) {\n                if (((o[p] > m.timestamp) && (p != m.author))) {\n                    n.push(p);\n                };\n            };\n            return n;\n        },\n        getSeenTimestamp: function(m, n) {\n            var o = k[m];\n            return (o ? o[n] : null);\n        }\n    };\n    j(l, g);\n    h.subscribe(\"update-roger\", function(m, n) {\n        for (var o in n) {\n            if (!k[o]) {\n                k[o] = {\n                };\n            };\n            for (var p in n[o]) {\n                var q = k[o][p], r = n[o][p];\n                if ((!q || (r > q))) {\n                    k[o][p] = r;\n                };\n            };\n        };\n        if (n) {\n            l.inform(\"state-changed\", n);\n        };\n    });\n    e.exports = l;\n});\n__d(\"MercuryTypingReceiver\", [\"Arbiter\",\"ChannelConstants\",\"MercuryParticipants\",\"MercuryServerRequests\",\"MercuryThreads\",\"TypingDetector\",\"setTimeoutAcrossTransitions\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ChannelConstants\"), i = b(\"MercuryParticipants\"), j = b(\"MercuryServerRequests\"), k = b(\"MercuryThreads\"), l = b(\"TypingDetector\"), m = b(\"setTimeoutAcrossTransitions\"), n = c(\"MercuryConstants\"), o, p = {\n    }, q = 30000, r = new g();\n    function s(x) {\n        var y = (p[x] || {\n        }), z = Object.keys(y);\n        z.sort(function(aa, ba) {\n            return (y[aa] - y[ba]);\n        });\n        return z;\n    };\n    function t() {\n        o = null;\n        var x = Date.now(), y = {\n        }, z = false;\n        for (var aa in p) {\n            var ba = false;\n            for (var ca in (p[aa] || {\n            })) {\n                if ((p[aa][ca] < (x - q))) {\n                    delete p[aa][ca];\n                    ba = true;\n                }\n                 else z = true;\n            ;\n            };\n            if (ba) {\n                y[aa] = s(aa);\n            };\n        };\n        for (var da in y) {\n            r.inform(\"state-changed\", y);\n            break;\n        };\n        if (z) {\n            o = m(t, 3000);\n        };\n    };\n    function u(x, y) {\n        if ((x in p)) {\n            if ((y in p[x])) {\n                delete p[x][y];\n                v(x);\n            }\n        \n        };\n    };\n    function v(x) {\n        var y = {\n        };\n        y[x] = s(x);\n        r.inform(\"state-changed\", y);\n    };\n    function w(x) {\n        if (x.thread) {\n            return j.getClientThreadIDNow(x.thread)\n        };\n        if ((x.type === \"typ\")) {\n            return k.getThreadIdForUser(x.from)\n        };\n        return null;\n    };\n    g.subscribe([h.getArbiterType(\"typ\"),h.getArbiterType(\"ttyp\"),], function(x, y) {\n        var z = y.obj, aa = w(z);\n        if (aa) {\n            var ba = i.getIDForUser(z.from);\n            if ((z.st == l.TYPING)) {\n                p[aa] = (p[aa] || {\n                });\n                var ca = p[aa][ba];\n                p[aa][ba] = Date.now();\n                if (!o) {\n                    o = m(t, 3000);\n                };\n                (!ca && v(aa));\n            }\n             else if ((z.st == l.INACTIVE)) {\n                u(aa, ba);\n            }\n        ;\n        }\n    ;\n    });\n    j.subscribe(\"update-typing-state\", function(x, y) {\n        var z = y.payload_source;\n        if ((z != n.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE)) {\n            return\n        };\n        var aa = y.actions;\n        if ((!aa || !aa.length)) {\n            return\n        };\n        var ba = n.MercuryActionType.USER_GENERATED_MESSAGE;\n        aa.forEach(function(ca) {\n            if (((ca.action_type == ba) && (ca.author != i.user))) {\n                u(ca.thread_id, ca.author);\n            };\n        });\n    });\n    e.exports = r;\n});\n__d(\"ChatTabIndicatorController\", [\"ArbiterMixin\",\"ChatConfig\",\"DOM\",\"LiveTimer\",\"MercuryParticipants\",\"MercuryRoger\",\"MercuryThreads\",\"MercuryTypingReceiver\",\"copyProperties\",\"setTimeoutAcrossTransitions\",\"tx\",\"date-extensions\",\"MercuryConfig\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"ArbiterMixin\"), h = b(\"ChatConfig\"), i = b(\"DOM\"), j = b(\"LiveTimer\"), k = b(\"MercuryParticipants\"), l = b(\"MercuryRoger\"), m = b(\"MercuryThreads\"), n = b(\"MercuryTypingReceiver\"), o = b(\"copyProperties\"), p = b(\"setTimeoutAcrossTransitions\"), q = b(\"tx\");\n    b(\"date-extensions\");\n    var r = c(\"MercuryConfig\"), s = c(\"MercuryConstants\"), t = r[\"roger.seen_delay\"], u = [];\n    function v(w) {\n        this._threadID = w;\n        this._canonicalUser = m.getCanonicalUserInThread(w);\n        u.push(this);\n    };\n    o(v.prototype, g, {\n        destroy: function() {\n            u.remove(this);\n        },\n        setLastMessage: function(w) {\n            this._lastMsg = w;\n            if (this._stateChangeTimeout) {\n                clearTimeout(this._stateChangeTimeout);\n                this._stateChangeTimeout = null;\n            }\n        ;\n            if (w) {\n                var x = t, y = s.MercuryActionStatus.SUCCESS;\n                if ((w.action_id || (w.status == y))) {\n                    var z = j.getApproximateServerTime();\n                    x = ((w.timestamp + t) - z);\n                }\n            ;\n                if ((x > 0)) {\n                    this._stateChangeTimeout = p(function() {\n                        this._stateChangeTimeout = null;\n                        this._handleStateChange();\n                    }.bind(this), x);\n                };\n            }\n        ;\n            this._handleStateChange();\n        },\n        _informStateChanged: function(w) {\n            if (((w.activity == \"none\") && (this._currentActivity == \"none\"))) {\n                return\n            };\n            this._currentActivity = w.activity;\n            this.inform(\"state-changed\", w);\n        },\n        _notifySentFrom: function() {\n            var w = s.MercurySourceType, x, y, z = this._lastMsg.location_text;\n            if (z) {\n                x = q._(\"Sent from {location}\", {\n                    location: z\n                });\n                y = \"sentFromMobile\";\n            }\n             else switch (this._lastMsg.source) {\n              case w.CHAT_ORCA:\n            \n              case w.TITAN_ORCA:\n                x = i.create(\"a\", {\n                    href: \"/mobile/messenger\",\n                    class: \"fcg\",\n                    target: \"_blank\"\n                }, \"Sent from Messenger\");\n                y = \"sentFromMobile\";\n                break;\n              case w.MOBILE:\n            \n              case w.CHAT_IPHONE:\n            \n              case w.TITAN_API_MOBILE:\n            \n              case w.TITAN_WAP:\n                x = i.create(\"a\", {\n                    href: \"/mobile\",\n                    class: \"fcg\",\n                    target: \"_blank\"\n                }, \"Sent from Mobile\");\n                y = \"sentFromMobile\";\n                break;\n              case w.EMAIL:\n            \n              case w.TITAN_EMAIL_REPLY:\n                x = \"Sent from Email\";\n                y = \"sentFromEmail\";\n                break;\n              default:\n                this._informStateChanged({\n                    activity: \"none\"\n                });\n                return;\n            }\n        ;\n            this._informStateChanged({\n                activity: y,\n                text: x\n            });\n        },\n        _notifySeenTimestamp: function(w) {\n            var x = (l.getSeenTimestamp(this._threadID, w[0]) * 175256), y = (Date.now() * 175274), z = (r[\"24h_times\"] ? \"H:i\" : \"g:i A\");\n            if ((x < (y - 518400))) {\n                z = \"M j\";\n            }\n             else if ((x < (y - 86400))) {\n                z = (\"D \" + z);\n            }\n        ;\n            var aa = Date.format(z, x);\n            this._informStateChanged({\n                activity: \"seen-timestamp\",\n                text: q._(\"Seen {timestamp}\", {\n                    timestamp: aa\n                })\n            });\n        },\n        _notifySeenBy: function(w) {\n            var x = this._lastMsg, y = true;\n            k.getMulti(w, function(z) {\n                y = false;\n                if ((this._lastMsg != x)) {\n                    return\n                };\n                var aa = m.getThreadMetaNow(this._threadID), ba = (aa ? aa.participants.length : 0), ca = (w.length + ((x.author != k.user))), da, ea = false;\n                if (((ba > 2) && (ca >= (ba - 1)))) {\n                    da = \"Seen by Everyone\";\n                }\n                 else if ((w.length == 1)) {\n                    da = q._(\"Seen by {user}\", {\n                        user: z[w[0]].short_name\n                    });\n                }\n                 else if ((w.length == 2)) {\n                    da = q._(\"Seen by {user1}, {user2}\", {\n                        user1: z[w[0]].short_name,\n                        user2: z[w[1]].short_name\n                    });\n                }\n                 else if ((w.length == 3)) {\n                    da = q._(\"Seen by {user1}, {user2}, {user3}\", {\n                        user1: z[w[0]].short_name,\n                        user2: z[w[1]].short_name,\n                        user3: z[w[2]].short_name\n                    });\n                }\n                 else if ((w.length > 3)) {\n                    var fa = (Object.keys(z).length - 2), ga = q._(\"{num} more\", {\n                        num: fa\n                    }), ha = i.create(\"span\", {\n                        className: \"more\"\n                    }, ga);\n                    da = i.tx._(\"Seen by {user1}, {user2}, {=num more link}\", {\n                        user1: z[w[0]].short_name,\n                        user2: z[w[1]].short_name,\n                        \"=num more link\": ha\n                    });\n                    ea = true;\n                }\n                \n                \n                \n                \n            ;\n                this._informStateChanged({\n                    activity: \"seen-by\",\n                    text: da,\n                    seenBy: w,\n                    tooltip: ea\n                });\n            }.bind(this));\n            (y && this._informStateChanged({\n                activity: \"none\"\n            }));\n        },\n        _notifyTyping: function(w) {\n            var x = this._lastMsg, y = true;\n            k.getMulti(w, function(z) {\n                y = false;\n                if ((this._lastMsg != x)) {\n                    return\n                };\n                if ((this._canonicalUser || h.get(\"chat_multi_typ\"))) {\n                    var aa = m.getThreadMetaNow(this._threadID), ba = (aa ? aa.participants.length : 0), ca, da = false;\n                    if (((ba > 2) && (w.length >= (ba - 1)))) {\n                        ca = \"Everyone is typing...\";\n                    }\n                     else if ((w.length == 1)) {\n                        ca = q._(\"{name} is typing...\", {\n                            name: z[w[0]].short_name\n                        });\n                    }\n                     else if ((w.length == 2)) {\n                        ca = q._(\"{user1} and {user2} are typing...\", {\n                            user1: z[w[0]].short_name,\n                            user2: z[w[1]].short_name\n                        });\n                    }\n                     else if ((w.length == 3)) {\n                        ca = q._(\"{user1}, {user2}, and {user3} are typing...\", {\n                            user1: z[w[0]].short_name,\n                            user2: z[w[1]].short_name,\n                            user3: z[w[2]].short_name\n                        });\n                    }\n                     else if ((w.length > 3)) {\n                        var ea = (Object.keys(z).length - 2), fa = q._(\"{num} more\", {\n                            num: ea\n                        }), ga = i.create(\"a\", {\n                            href: \"#\"\n                        }, fa);\n                        ca = i.tx._(\"{user1}, {user2}, and {=num more link} are typing...\", {\n                            user1: z[w[0]].short_name,\n                            user2: z[w[1]].short_name,\n                            \"=num more link\": ga\n                        });\n                        da = true;\n                    }\n                    \n                    \n                    \n                    \n                ;\n                    this._informStateChanged({\n                        activity: \"typing\",\n                        text: ca,\n                        typing: w,\n                        tooltip: da\n                    });\n                }\n            ;\n            }.bind(this));\n            (y && this._informStateChanged({\n                activity: \"none\"\n            }));\n        },\n        _handleStateChange: function() {\n            var w = s.MercuryActionType.LOG_MESSAGE;\n            if ((!this._lastMsg || (this._lastMsg.action_type == w))) {\n                this._informStateChanged({\n                    activity: \"none\"\n                });\n                return;\n            }\n        ;\n            if ((this._typing && this._typing.length)) {\n                this._notifyTyping(this._typing);\n                return;\n            }\n        ;\n            if ((this._canonicalUser && (this._lastMsg.author != k.user))) {\n                this._notifySentFrom();\n                return;\n            }\n        ;\n            if (!this._stateChangeTimeout) {\n                var x = l.getSeenBy(this._lastMsg);\n                if (x.length) {\n                    if (this._canonicalUser) {\n                        this._notifySeenTimestamp(x);\n                        return;\n                    }\n                     else {\n                        this._notifySeenBy(x);\n                        return;\n                    }\n                \n                };\n            }\n        ;\n            this._informStateChanged({\n                activity: \"none\"\n            });\n        }\n    });\n    n.subscribe(\"state-changed\", function(w, x) {\n        u.forEach(function(y) {\n            var z = x[y._threadID];\n            if ((z !== undefined)) {\n                y._typing = z;\n                y._handleStateChange();\n            }\n        ;\n        });\n    });\n    l.subscribe(\"state-changed\", function(w, x) {\n        u.forEach(function(y) {\n            if ((x[y._threadID] && !y._stateChangeTimeout)) {\n                y._handleStateChange();\n            };\n        });\n    });\n    e.exports = v;\n});\n__d(\"ChatTabIndicatorLine\", [\"ChatTabIndicatorController\",\"CSS\",\"DOM\",\"DOMQuery\",\"MercuryParticipants\",\"Tooltip\",\"copyProperties\",\"csx\",], function(a, b, c, d, e, f) {\n    var g = b(\"ChatTabIndicatorController\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"DOMQuery\"), k = b(\"MercuryParticipants\"), l = b(\"Tooltip\"), m = b(\"copyProperties\"), n = b(\"csx\");\n    function o(p, q, r) {\n        this._typingIndicator = q;\n        this._messagesView = r;\n        this._controller = new g(p);\n        this._subscription = this._controller.subscribe(\"state-changed\", this._handleStateChanged.bind(this));\n    };\n    m(o.prototype, {\n        destroy: function() {\n            this._setClass(null);\n            this._subscription.unsubscribe();\n            this._controller.destroy();\n        },\n        setLastMessage: function(p) {\n            this._controller.setLastMessage(p);\n        },\n        _handleStateChanged: function(p, q) {\n            var r = this._messagesView.isScrolledToBottom();\n            this._rerender(q);\n            (r && this._messagesView.scrollToBottom());\n        },\n        _rerender: function(p) {\n            if ((p.activity == \"none\")) {\n                this._setClass(null);\n                return;\n            }\n        ;\n            var q = i.find(this._typingIndicator, \".-cx-PRIVATE-mercuryTypingIndicator__text\");\n            if (p.text) {\n                i.setContent(q, p.text);\n            }\n             else i.empty(q);\n        ;\n            if ((p.activity.substring(0, 4) == \"seen\")) {\n                this._setClass(\"seen\");\n                if (((p.activity == \"seen-by\") && p.tooltip)) {\n                    k.getMulti(p.seenBy, function(r) {\n                        var s = i.create(\"div\"), t = 0;\n                        for (var u in r) {\n                            if ((t++ >= 2)) {\n                                var v = i.create(\"div\");\n                                i.setContent(v, r[u].name);\n                                i.appendContent(s, v);\n                            }\n                        ;\n                        };\n                        var w = j.find(this._typingIndicator, \"span.more\");\n                        l.set(w, s, \"above\", \"center\");\n                    }.bind(this));\n                };\n            }\n             else this._setClass(p.activity);\n        ;\n        },\n        _setClass: function(p) {\n            if ((this._lastClass === p)) {\n                return\n            };\n            (this._lastClass && h.removeClass(this._typingIndicator, this._lastClass));\n            (p && h.addClass(this._typingIndicator, p));\n            this._lastClass = p;\n        }\n    });\n    e.exports = o;\n});\n__d(\"MercuryEmoji\", [\"Emoji\",\"Emote\",\"MercuryConfig\",], function(a, b, c, d, e, f) {\n    var g = b(\"Emoji\"), h = b(\"Emote\"), i = c(\"MercuryConfig\"), j = {\n        htmlEmojiAndEmote: function(k, l) {\n            if (i.MessagingDisplayEmojiGK) {\n                return g.htmlEmojiAndEmote(k, l);\n            }\n             else return h.htmlEmote(k, l)\n        ;\n        }\n    };\n    e.exports = j;\n});\n__d(\"MercurySeenByAll\", [\"CSS\",\"DataStore\",\"DOM\",\"MercuryMessages\",\"MercuryParticipants\",\"MercuryRoger\",\"MercuryThreads\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"DataStore\"), i = b(\"DOM\"), j = b(\"MercuryMessages\"), k = b(\"MercuryParticipants\"), l = b(\"MercuryRoger\"), m = b(\"MercuryThreads\"), n = {\n    }, o = {\n        updateOnSeenChange: function(r, s) {\n            n[r.tagName] = true;\n            h.set(r, \"thread-id\", s.thread_id);\n            g.addClass(r, \"seenByListener\");\n            p(r, s);\n        }\n    };\n    function p(r, s) {\n        var t = s.participants.filter(function(w) {\n            return (w !== k.user);\n        }), u = q(s), v = ((s.participants.length > 0) && (s.participants[0] === k.user));\n        g.conditionClass(r, \"repliedLast\", v);\n        g.conditionClass(r, \"seenByAll\", (v && (l.getSeenBy(u).length === t.length)));\n    };\n    function q(r) {\n        return {\n            author: k.user,\n            thread_id: r.thread_id,\n            timestamp: r.timestamp\n        };\n    };\n    l.subscribe(\"state-changed\", function(r, s) {\n        for (var t in n) {\n            var u = i.scry(document.body, (t + \".seenByListener\"));\n            for (var v = 0; (v < u.length); v++) {\n                var w = u[v], x = h.get(w, \"thread-id\");\n                if (s[x]) {\n                    m.getThreadMeta(x, function(y) {\n                        p(w, y);\n                    });\n                };\n            };\n        };\n    });\n    e.exports = o;\n});\n__d(\"WebMessengerPermalinkConstants\", [\"URI\",], function(a, b, c, d, e, f) {\n    var g = b(\"URI\"), h = {\n        ARCHIVED_PATH: \"/messages/archived\",\n        BASE_PATH: \"/messages\",\n        OTHER_PATH: \"/messages/other\",\n        SPAM_PATH: \"/messages/spam\",\n        COMPOSE_POSTFIX_PATH: \"/new\",\n        SEARCH_POSTFIX_PATH: \"/search\",\n        TID_POSTFIX_PARTIAL_PATH: \"/conversation-\",\n        getURIPathForThreadID: function(i, j) {\n            return ((((j || h.BASE_PATH)) + h.TID_POSTFIX_PARTIAL_PATH) + g.encodeComponent(g.encodeComponent(i)));\n        },\n        getThreadIDFromURI: function(i) {\n            var j = i.getPath().match((((h.BASE_PATH + \"(/[^/]+)*\") + h.TID_POSTFIX_PARTIAL_PATH) + \"([^/]+)\"));\n            if (j) {\n                var k = g.decodeComponent(g.decodeComponent(j[2]));\n                return k;\n            }\n        ;\n        },\n        getCanonicalUserID: function(i) {\n            var j = i.match(\"(.*/)+(\\\\d+)$\");\n            return (j && parseInt(j[2], 10));\n        }\n    };\n    e.exports = h;\n});\n__d(\"MercuryThreadMetadataRenderer\", [\"event-extensions\",\"CSS\",\"DOM\",\"HTML\",\"JSLogger\",\"MercuryAttachment\",\"MercuryEmoji\",\"MercuryParticipants\",\"MercurySeenByAll\",\"MercuryServerRequests\",\"MercuryThreads\",\"Tooltip\",\"URI\",\"WebMessengerPermalinkConstants\",\"cx\",\"createArrayFrom\",\"tx\",\"MercuryImageTemplates\",\"MercuryThreadlistIconTemplates\",\"MercuryStatusTemplates\",\"MercuryConstants\",\"MercuryConfig\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"HTML\"), j = b(\"JSLogger\"), k = b(\"MercuryAttachment\"), l = b(\"MercuryEmoji\"), m = b(\"MercuryParticipants\"), n = b(\"MercurySeenByAll\"), o = b(\"MercuryServerRequests\"), p = b(\"MercuryThreads\"), q = b(\"Tooltip\"), r = b(\"URI\"), s = b(\"WebMessengerPermalinkConstants\"), t = b(\"cx\"), u = c(\"MercuryImageTemplates\"), v = c(\"MercuryThreadlistIconTemplates\"), w = c(\"MercuryStatusTemplates\"), x = c(\"MercuryConstants\"), y = c(\"MercuryConfig\"), z = b(\"createArrayFrom\"), aa = b(\"tx\"), ba = j.create(\"wm_timestamp\");\n    e.exports = {\n        renderTimestamp: function(fa, ga, ha, ia) {\n            if (ia) {\n                if (!ga) {\n                    ba.warn(\"no_title\");\n                    ga = (new Date(ia)).toLocaleDateString();\n                }\n            ;\n                fa.setAttribute(\"title\", ga);\n                if (!ha) {\n                    ba.warn(\"no_display\");\n                    ha = Date.format((y[\"24h_times\"] ? \"H:i\" : \"g:ia\"), Math.floor((ia / 1000)));\n                }\n            ;\n                h.setContent(fa, ha);\n                g.show(fa);\n            }\n        ;\n        },\n        renderMessageSourceTags: function(fa, ga, ha, ia) {\n            var ja = x.MercuryMessageSourceTags, ka = \"\", la = \"\", ma = \"\";\n            if (ha.contains(ja.MESSENGER)) {\n                ka = \"Sent from Messenger\";\n                la = new r(\"/mobile/messenger\");\n                ma = \"-cx-PRIVATE-webMessengerMessageGroup__sourceMessenger\";\n            }\n             else if (ha.contains(ja.CHAT)) {\n                ka = \"Sent from Chat\";\n                ma = \"-cx-PRIVATE-webMessengerMessageGroup__sourceChat\";\n            }\n             else if (ha.contains(ja.EMAIL)) {\n                if (ia) {\n                    ka = aa._(\"Sent from {email}\", {\n                        email: ia\n                    });\n                }\n                 else ka = \"Sent from Email\";\n            ;\n                ma = \"-cx-PRIVATE-webMessengerMessageGroup__sourceEmail\";\n            }\n             else if (ha.contains(ja.MOBILE)) {\n                ka = \"Sent from Mobile\";\n                la = new r(\"/mobile/\");\n                ma = \"-cx-PRIVATE-webMessengerMessageGroup__sourceMobile\";\n            }\n            \n            \n            \n        ;\n            if (ma) {\n                q.set(fa, ka);\n                g.addClass(ga, ma);\n                if (la) {\n                    fa.setAttribute(\"href\", la);\n                }\n                 else fa.removeAttribute(\"href\");\n            ;\n            }\n             else g.hide(fa);\n        ;\n        },\n        renderMessageLocation: function(fa, ga, ha) {\n            var ia = r(\"/ajax/messaging/hovercard/map.php\").setQueryData(ha);\n            fa.setAttribute(\"data-hovercard\", ia);\n            g.removeClass(fa, \"-cx-PRIVATE-webMessengerMessageGroup__noLocation\");\n            g.show(ga);\n        },\n        renderSpoofWarning: function(fa, ga, ha) {\n            if (ga) {\n                g.addClass(fa, \"-cx-PRIVATE-webMessengerMessageGroup__spoofWarning\");\n                q.set(fa, aa._(\"Unable to confirm {name_or_email} as the sender.\", {\n                    name_or_email: ha.name\n                }));\n            }\n        ;\n        },\n        renderCoreThreadlist: function(fa, ga, ha, ia, ja) {\n            ia = (ia || {\n            });\n            this.renderThreadImage(fa, ga.getNode(\"image\"));\n            ea(fa, ga.getNode(\"name\"), ia);\n            if ((fa.folder && ja)) {\n                da(ga.getNode(\"folderBadge\"), fa.folder);\n            };\n            var ka = ga.getNode(\"timestamp\");\n            this.renderTimestamp(ka, fa.timestamp_absolute, fa.timestamp_relative, fa.timestamp);\n            this.renderSnippet(fa, ga.getNode(\"snippet\"));\n            ha(ga, fa);\n        },\n        renderAndSeparatedParticipantList: function(fa, ga, ha) {\n            ha = (ha || {\n            });\n            ha.last_separator_uses_and = true;\n            p.getThreadMeta(fa, function(ia) {\n                ea(ia, ga, ha);\n            }.bind(this));\n        },\n        renderSnippet: function(fa, ga) {\n            var ha = h.create(\"span\");\n            g.addClass(ha, \"MercuryRepliedIndicator\");\n            h.appendContent(ga, ha);\n            n.updateOnSeenChange(ha, fa);\n            if (fa.snippet_has_attachment) {\n                if ((!fa.snippet && fa.snippet_attachments)) {\n                    fa.snippet_attachments.forEach(function(ka) {\n                        if ((ka.attach_type != x.MercuryAttachmentType.FILE)) {\n                            return\n                        };\n                        var la = k.getAttachIconClass(ka.icon_type), ma = v[\":fb:mercury:attachment-icon-text\"].build().getRoot();\n                        h.appendContent(ma, ka.name);\n                        g.addClass(ma, la);\n                        h.appendContent(ga, ma);\n                    }.bind(this));\n                }\n                 else h.appendContent(ga, h.create(\"span\", {\n                    className: \"MercuryAttachmentIndicator\"\n                }));\n            \n            };\n            if (fa.is_forwarded_snippet) {\n                var ia;\n                if (fa.snippet) {\n                    ia = \"Forwarded Message:\";\n                }\n                 else ia = \"Forwarded Message\";\n            ;\n                h.appendContent(ga, h.create(\"strong\", {\n                    className: \"mercuryForwardedIndicator\"\n                }, ia));\n            }\n        ;\n            var ja = fa.snippet;\n            if (ja) {\n                if ((ja.substr(0, 4) == \"?OTR\")) {\n                    ja = \"[encrypted message]\";\n                }\n                 else ja = ja.replace(/\\r\\n|[\\r\\n]/g, \" \");\n            \n            };\n            h.appendContent(ga, i(l.htmlEmojiAndEmote(ja)));\n        },\n        renderTitanLink: function(fa, ga, ha) {\n            var ia = fa.indexOf(\":\"), ja = new r().setSubdomain(\"www\");\n            if ((fa.substr(0, ia) == \"user\")) {\n                ja.setPath((\"/messages/\" + fa.substr((ia + 1))));\n                ga.setAttribute(\"href\", ja.toString());\n                (ha && ha());\n            }\n             else o.getServerThreadID(fa, function(ka) {\n                if (y.MessagesMercuryIntegrationGK) {\n                    ja.setPath(s.getURIPathForThreadID(ka));\n                }\n                 else {\n                    ja.setPath(\"/messages/\");\n                    ja.setQueryData({\n                        action: \"read\",\n                        tid: ka\n                    });\n                }\n            ;\n                ga.setAttribute(\"href\", ja.toString());\n                (ha && ha());\n            });\n        ;\n        },\n        renderThreadImage: function(fa, ga) {\n            if (fa.image_src) {\n                this._renderThreadImageSingle(fa.image_src, ga);\n                return;\n            }\n        ;\n            var ha = [], ia = fa.participants.filter(function(ja) {\n                return (ja != m.user);\n            });\n            if (!ia.length) {\n                ha = [m.user,];\n            }\n             else if ((ia.length == 1)) {\n                ha = [ia[0],];\n            }\n             else {\n                ha = ia.slice(0, 3);\n                if ((ha.length == 2)) {\n                    ha.push(m.user);\n                };\n            }\n            \n        ;\n            m.getMulti(ha, function(ja) {\n                var ka = ha.map(function(la) {\n                    return ja[la];\n                });\n                this.renderParticipantImages(ka, ga);\n            }.bind(this));\n        },\n        renderParticipantImages: function(fa, ga) {\n            if ((fa.length > 2)) {\n                this._renderThreadImageSplit(fa, ga);\n            }\n             else this._renderThreadImageSingle(fa[0].image_src, ga);\n        ;\n        },\n        renderErrorIndicator: function(fa, ga) {\n            var ha = w[\":fb:mercury:error-indicator\"].render(), ia;\n            switch (fa) {\n              case x.MercuryActionStatus.REQUEST_ERROR:\n            \n              case x.MercuryActionStatus.TRANSPORT_ERROR:\n            \n              case x.MercuryActionStatus.FAILED_UNKNOWN_REASON:\n            \n              case x.MercuryActionStatus.UNABLE_TO_CONFIRM:\n                ia = \"This message failed to send. Click to send again.\";\n                break;\n              default:\n                throw new Error((\"Invalid error code \" + fa));\n            };\n            q.set(ha, ia, \"above\", \"center\");\n            if (ga) {\n                Event.listen(ha, \"click\", ga);\n                g.addClass(ha, \"mercuryClickableErrorIndicator\");\n            }\n        ;\n            return ha;\n        },\n        renderResendIndicator: function() {\n            return w[\":fb:mercury:resend-indicator\"].render();\n        },\n        renderStatusIndicator: function(fa, ga) {\n            var ha = x.MercuryActionStatus, ia;\n            if ((fa == ha.RESENDING)) {\n                ia = this.renderResendIndicator();\n            }\n             else if (((((fa !== undefined) && (fa != ha.UNSENT)) && (fa != ha.UNCONFIRMED)) && (fa != ha.SUCCESS))) {\n                ia = this.renderErrorIndicator(fa, ga);\n            }\n        ;\n            return ia;\n        },\n        renderParticipantList: function(fa, ga, ha, ia) {\n            var ja = {\n                abbr_mode: true,\n                last_separator_uses_and: true,\n                link_mode: true,\n                names_renderer: true\n            };\n            ia = (ia || {\n            });\n            var ka = null;\n            if (ia.names_renderer) {\n                ka = ia.names_renderer(ga);\n            }\n             else ka = ga.map(function(na) {\n                return na.name;\n            });\n        ;\n            var la = null;\n            if ((ka.length == 1)) {\n                la = ka[0];\n            }\n             else if ((ka.length == 2)) {\n                var ma = {\n                    participant1: ka[0],\n                    participant2: ka[1]\n                };\n                if (ia.last_separator_uses_and) {\n                    la = aa._(\"{participant1} and {participant2}\", ma);\n                }\n                 else la = aa._(\"{participant1}, {participant2}\", ma);\n            ;\n            }\n             else if (ia.last_separator_uses_and) {\n                if (ia.abbr_mode) {\n                    la = aa._(\"{participant1} and {others_link}\", {\n                        participant1: ka[0],\n                        others_link: this.renderParticipantCount(fa, {\n                            render_subset: true,\n                            count: (ha - 1),\n                            as_link: ia.link_mode\n                        })\n                    });\n                }\n                 else if ((ka.length == 3)) {\n                    la = aa._(\"{participant1}, {participant2} and {participant3}\", {\n                        participant1: ka[0],\n                        participant2: ka[1],\n                        participant3: ka[2]\n                    });\n                }\n                 else la = aa._(\"{participant1}, {participant2} and {others_link}\", {\n                    participant1: ka[0],\n                    participant2: ka[1],\n                    others_link: this.renderParticipantCount(fa, {\n                        render_subset: true,\n                        count: (ha - 2),\n                        as_link: ia.link_mode\n                    })\n                });\n                \n            ;\n            }\n             else if ((ka.length == 3)) {\n                la = aa._(\"{participant1}, {participant2}, {participant3}\", {\n                    participant1: ka[0],\n                    participant2: ka[1],\n                    participant3: ka[2]\n                });\n            }\n             else la = aa._(\"{participant1}, {participant2}, {participant3}, {others_link}\", {\n                participant1: ka[0],\n                participant2: ka[1],\n                participant3: ka[2],\n                others_link: this.renderParticipantCount(fa, {\n                    render_subset: true,\n                    count: (ha - 3),\n                    as_link: ia.link_mode\n                })\n            });\n            \n            \n            \n        ;\n            if (Array.isArray(la)) {\n                la = h.create(\"span\", {\n                }, la);\n            };\n            return la;\n        },\n        renderParticipantCount: function(fa, ga) {\n            function ha(la, ma) {\n                return h.create(\"a\", {\n                    className: \"hoverlistLink\",\n                    href: r(\"/ajax/messaging/profile_browser/profile_browser.php\").setQueryData(la),\n                    rel: \"dialog\"\n                }, ma);\n            };\n            var ia = ga.render_subset, ja = o.getServerThreadIDNow(fa), ka;\n            if (!ia) {\n                ka = ((ga.count > 1) ? aa._(\"{num} people\", {\n                    num: ga.count\n                }) : \"1 person\");\n            }\n             else ka = ((ga.count > 1) ? aa._(\"{others_count} others\", {\n                others_count: ga.count\n            }) : \"1 other\");\n        ;\n            if ((ga.as_link && ja)) {\n                return ha({\n                    tid: ja\n                }, ka);\n            }\n             else return ka\n        ;\n        },\n        renderShortNames: function(fa) {\n            if ((fa.length == 1)) {\n                return [fa[0].name,]\n            };\n            return fa.map(function(ga) {\n                return ga.short_name;\n            });\n        },\n        _renderThreadImageSingle: function(fa, ga) {\n            var ha = u[\":fb:mercury:thread-image:single\"].build().getRoot();\n            ha.src = fa;\n            h.setContent(ga, ha);\n        },\n        _renderThreadImageSplit: function(fa, ga) {\n            var ha = u[\":fb:mercury:thread-image:split\"].build().setNodeProperty(\"left\", \"src\", fa[0].image_src).setNodeProperty(\"topRight\", \"src\", fa[1].image_src).setNodeProperty(\"bottomRight\", \"src\", fa[2].image_src);\n            h.setContent(ga, ha.getRoot());\n        },\n        _cloneIfDOMElement: function(fa) {\n            if (fa.cloneNode) {\n                return fa.cloneNode();\n            }\n             else return fa\n        ;\n        }\n    };\n    function ca(fa, ga) {\n        var ha = fa;\n        if ((ga && (ga > 1))) {\n            ha = h.create(\"span\", {\n            }, aa._(\"{conversation_title} ({unread_count})\", {\n                conversation_title: fa,\n                unread_count: ga\n            }));\n        };\n        return ha;\n    };\n    function da(fa, ga) {\n        z(fa).forEach(function(ha) {\n            h.setContent(ha, ga);\n        });\n    };\n    function ea(fa, ga, ha) {\n        ga = z(ga);\n        var ia = {\n            callback: true,\n            check_length: true,\n            show_unread_count: true\n        };\n        ha = (ha || {\n        });\n        var ja = {\n        };\n        for (var ka in ha) {\n            if (ia[ka]) {\n                ja[ka] = ha[ka];\n                delete ha[ka];\n            }\n        ;\n        };\n        if (fa.name) {\n            var la = ca(fa.name, (ja.show_unread_count ? fa.unread_count : 0));\n            ga.forEach(function(na) {\n                h.setContent(na, la);\n            });\n            (ja.callback && ja.callback(la));\n            return;\n        }\n    ;\n        var ma = fa.participants;\n        if ((fa.participants.length > 1)) {\n            ma = fa.participants.filter(function(na) {\n                return (na != m.user);\n            });\n        };\n        m.getMulti(ma, function(na) {\n            var oa = ma.map(function(ta) {\n                return na[ta];\n            }), pa = e.exports.renderParticipantList(fa.thread_id, oa, ma.length, ha);\n            pa = ca(pa, (ja.show_unread_count ? fa.unread_count : 0));\n            var qa = ha.abbr_mode, ra = {\n            };\n            for (var sa in ha) {\n                ra[sa] = ha[sa];;\n            };\n            ra.abbr_mode = true;\n            ga.forEach(function(ta) {\n                var ua = ((ga.length > 1) ? e.exports._cloneIfDOMElement(pa) : pa);\n                h.setContent(ta, ua);\n                if (((ja.check_length && !qa) && (ta.scrollWidth > ta.clientWidth))) {\n                    var va = e.exports.renderParticipantList(fa.thread_id, oa, ma.length, ra);\n                    va = ca(va, (ja.show_unread_count ? fa.unread_count : 0));\n                    h.setContent(ta, va);\n                }\n            ;\n            }.bind(this));\n            (ja.callback && ja.callback(pa));\n        }.bind(this));\n    };\n});\n__d(\"MercuryMessageRenderer\", [\"MercuryAttachmentRenderer\",\"CSS\",\"DOM\",\"DOMQuery\",\"HTML\",\"htmlHyperlink\",\"MercuryEmoji\",\"MercuryParticipants\",\"Tooltip\",\"tx\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"MercuryAttachmentRenderer\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"DOMQuery\"), k = b(\"HTML\"), l = b(\"htmlHyperlink\"), m = b(\"MercuryEmoji\"), n = b(\"MercuryParticipants\"), o = b(\"Tooltip\"), p = c(\"MercuryConstants\"), q = b(\"tx\"), r = {\n        renderTooltipFlyout: function(ha, ia) {\n            ia.forEach(function(ja) {\n                var ka = i.create(\"div\");\n                i.setContent(ka, ja.name);\n                i.appendContent(ha, ka);\n            });\n        },\n        renderLogMessage: function(ha, ia, ja, ka) {\n            t(ha, ka);\n            u(ia, ka);\n            v(ja, ka);\n        },\n        formatMessageBody: function(ha, ia) {\n            ia = (ia || {\n            });\n            var ja = ((ha || \"\")).replace(/\\n+$/, \"\"), ka = Object.keys(ia).map(function(na) {\n                return window.parseInt(na);\n            }).sort(function(na, oa) {\n                return (na - oa);\n            }), la = 0, ma = i.create(\"span\");\n            ka.forEach(function(na) {\n                var oa = ja.slice(la, na);\n                s(ma, oa, false);\n                var pa = ia[na.toString()], qa = ja.slice(na, (na + pa.length));\n                s(ma, qa, true);\n                la = (na + pa.length);\n            });\n            s(ma, ja.slice(la), false);\n            return ma;\n        }\n    };\n    function s(ha, ia, ja) {\n        if (((ia.length === 0) && !ja)) {\n            return\n        };\n        var ka = k(l(ia, m.htmlEmojiAndEmote, null, true)), la = (ja ? {\n            class: \"highlight\"\n        } : {\n        }), ma = i.create(\"span\", la, ka);\n        i.appendContent(ha, ma);\n    };\n    function t(ha, ia) {\n        var ja = \"\";\n        switch (ia.log_message_type) {\n          case p.MercuryLogMessageType.SUBSCRIBE:\n            ja = \"mercurySubscribeIcon\";\n            break;\n          case p.MercuryLogMessageType.UNSUBSCRIBE:\n            ja = \"mercuryUnsubscribeIcon\";\n            break;\n          case p.MercuryLogMessageType.THREAD_NAME:\n            ja = \"mercuryThreadNameIcon\";\n            break;\n          case p.MercuryLogMessageType.THREAD_IMAGE:\n            ja = \"mercuryThreadImageIcon\";\n            break;\n          case p.MercuryLogMessageType.VIDEO_CALL:\n            var ka = ia.log_message_data.answered;\n            if ((ka || ga(ia))) {\n                ja = \"mercuryVideoCallIcon\";\n            }\n             else ja = \"mercuryMissedVideoCallIcon\";\n        ;\n            break;\n          case p.MercuryLogMessageType.SERVER_ERROR:\n            ja = \"mercuryErrorIcon\";\n            break;\n        };\n        h.addClass(ha, ja);\n    };\n    function u(ha, ia) {\n        switch (ia.log_message_type) {\n          case p.MercuryLogMessageType.SUBSCRIBE:\n            da(ha, ia);\n            break;\n          case p.MercuryLogMessageType.UNSUBSCRIBE:\n            ea(ha, ia);\n            break;\n          case p.MercuryLogMessageType.VIDEO_CALL:\n            if (ga(ia)) {\n                w(ha, ia);\n            }\n             else x(ha, ia);\n        ;\n            break;\n          case p.MercuryLogMessageType.THREAD_NAME:\n            y(ha, ia);\n            break;\n          case p.MercuryLogMessageType.THREAD_IMAGE:\n            z(ha, ia);\n            break;\n          case p.MercuryLogMessageType.SERVER_ERROR:\n            fa(ha, ia);\n            break;\n        };\n    };\n    function v(ha, ia) {\n        var ja = ia.log_message_type;\n        if ((ja == p.MercuryLogMessageType.THREAD_IMAGE)) {\n            var ka = ia.log_message_data.image;\n            (ka && i.setContent(ha, g.renderPreview(ka)));\n            h.show(ha);\n        }\n    ;\n    };\n    var w = function(ha, ia) {\n        n.get(ia.author, function(ja) {\n            var ka = ja.short_name, la;\n            switch (ia.log_message_data.event_name) {\n              case \"installing\":\n                la = i.tx._(\"{firstname} is setting up video calling...\", {\n                    firstname: ka\n                });\n                break;\n              case \"installed\":\n                la = i.tx._(\"{firstname} finished setting up video calling.\", {\n                    firstname: ka\n                });\n                break;\n              case \"install_canceled\":\n                la = i.tx._(\"You canceled the video calling installation. \", {\n                    firstname: ka\n                });\n                break;\n            };\n            if (la) {\n                i.setContent(ha, la);\n            };\n        });\n    }, x = function(ha, ia) {\n        var ja = ia.log_message_data.caller, ka = ia.log_message_data.callee, la = [ja,ka,];\n        n.getMulti(la, function(ma) {\n            if ((ja == n.user)) {\n                var na = ma[ka].short_name, oa;\n                if (ia.log_message_data.answered) {\n                    oa = i.tx._(\"You called {firstname}.\", {\n                        firstname: na\n                    });\n                }\n                 else oa = i.tx._(\"{firstname} missed a call from you. \", {\n                    firstname: na\n                });\n            ;\n            }\n             else {\n                var pa = ma[ja].short_name;\n                if (ia.log_message_data.answered) {\n                    oa = i.tx._(\"{firstname} called you.\", {\n                        firstname: pa\n                    });\n                }\n                 else oa = i.tx._(\"You missed a call from {firstname}. \", {\n                    firstname: pa\n                });\n            ;\n            }\n        ;\n            i.setContent(ha, oa);\n        });\n    }, y = function(ha, ia) {\n        var ja = ia.log_message_data.name, ka = i.create(\"b\", {\n        }, ja);\n        if ((ia.author == n.user)) {\n            if (ja) {\n                i.setContent(ha, i.tx._(\"You named the conversation: {name}.\", {\n                    name: ka\n                }));\n            }\n             else i.setContent(ha, i.tx._(\"You removed the conversation name.\"));\n        ;\n        }\n         else n.get(ia.author, function(la) {\n            var ma, na = aa(la);\n            if (ja) {\n                ma = i.tx._(\"{actor} named the conversation: {name}.\", {\n                    actor: na,\n                    name: ka\n                });\n            }\n             else ma = i.tx._(\"{actor} removed the conversation name.\", {\n                actor: na\n            });\n        ;\n            i.setContent(ha, ma);\n        });\n    ;\n    }, z = function(ha, ia) {\n        if ((ia.author == n.user)) {\n            if (ia.log_message_data.image) {\n                i.setContent(ha, i.tx._(\"You changed the conversation picture.\"));\n            }\n             else i.setContent(ha, i.tx._(\"You removed the conversation picture.\"));\n        ;\n        }\n         else n.get(ia.author, function(ja) {\n            var ka = aa(ja), la;\n            if (ia.log_message_data.image) {\n                la = i.tx._(\"{actor} changed the conversation picture.\", {\n                    actor: ka\n                });\n            }\n             else la = i.tx._(\"{actor} removed the conversation picture.\", {\n                actor: ka\n            });\n        ;\n            i.setContent(ha, la);\n        });\n    ;\n    }, aa = function(ha) {\n        if (ha.href) {\n            return i.create(\"a\", {\n                href: ha.href\n            }, ha.name)\n        };\n        return ha.name;\n    }, ba = function(ha) {\n        if (ha.href) {\n            return i.create(\"a\", {\n                href: ha.href\n            }, ha.short_name)\n        };\n        return ha.short_name;\n    }, ca = function(ha) {\n        var ia = ha.indexOf(n.user);\n        if ((ia > 0)) {\n            return ha.splice(ia, 1).concat(ha)\n        };\n        return ha;\n    }, da = function(ha, ia) {\n        var ja = ca(ia.log_message_data.added_participants), ka = null, la;\n        if ((ja.length == 1)) {\n            ka = [ia.author,ja[0],];\n            n.getMulti(ka, function(ma) {\n                if ((ia.author == n.user)) {\n                    la = i.tx._(\"You added {subscriber1}.\", {\n                        subscriber1: aa(ma[ja[0]])\n                    });\n                }\n                 else if ((ja[0] == n.user)) {\n                    la = i.tx._(\"{actor} added you.\", {\n                        actor: aa(ma[ia.author])\n                    });\n                }\n                 else la = i.tx._(\"{actor} added {subscriber1}.\", {\n                    actor: aa(ma[ia.author]),\n                    subscriber1: aa(ma[ja[0]])\n                });\n                \n            ;\n                i.setContent(ha, la);\n            });\n        }\n         else if ((ja.length == 2)) {\n            ka = [ia.author,].concat(ja);\n            n.getMulti(ka, function(ma) {\n                if ((ia.author == n.user)) {\n                    la = i.tx._(\"You added {subscriber1} and {subscriber2}.\", {\n                        subscriber1: aa(ma[ja[0]]),\n                        subscriber2: aa(ma[ja[1]])\n                    });\n                }\n                 else if ((ja[0] == n.user)) {\n                    la = i.tx._(\"{actor} added you and {subscriber2}.\", {\n                        actor: aa(ma[ia.author]),\n                        subscriber2: aa(ma[ja[1]])\n                    });\n                }\n                 else la = i.tx._(\"{actor} added {subscriber1} and {subscriber2}.\", {\n                    actor: aa(ma[ia.author]),\n                    subscriber1: aa(ma[ja[0]]),\n                    subscriber2: aa(ma[ja[1]])\n                });\n                \n            ;\n                i.setContent(ha, la);\n            });\n        }\n         else if ((ja.length == 3)) {\n            ka = [ia.author,].concat(ja);\n            n.getMulti(ka, function(ma) {\n                if ((ia.author == n.user)) {\n                    la = i.tx._(\"You added {subscriber1}, {subscriber2} and {subscriber3}.\", {\n                        subscriber1: aa(ma[ja[0]]),\n                        subscriber2: aa(ma[ja[1]]),\n                        subscriber3: aa(ma[ja[2]])\n                    });\n                }\n                 else if ((ja[0] == n.user)) {\n                    la = i.tx._(\"{actor} added you, {subscriber2} and {subscriber3}.\", {\n                        actor: aa(ma[ia.author]),\n                        subscriber2: aa(ma[ja[1]]),\n                        subscriber3: aa(ma[ja[2]])\n                    });\n                }\n                 else la = i.tx._(\"{actor} added {subscriber1}, {subscriber2} and {subscriber3}.\", {\n                    actor: aa(ma[ia.author]),\n                    subscriber1: aa(ma[ja[0]]),\n                    subscriber2: aa(ma[ja[1]]),\n                    subscriber3: aa(ma[ja[2]])\n                });\n                \n            ;\n                i.setContent(ha, la);\n            });\n        }\n         else {\n            ka = [ia.author,].concat(ja);\n            n.getMulti(ka, function(ma) {\n                var na = i.tx._(\"{num} more\", {\n                    num: (ja.length - 2)\n                }), oa = i.create(\"span\", {\n                    className: \"more\"\n                }, na), pa = i.create(\"div\");\n                r.renderTooltipFlyout(pa, ja.slice(2).map(function(ra) {\n                    return ma[ra];\n                }));\n                if ((ia.author == n.user)) {\n                    la = i.tx._(\"You added {subscriber1}, {subscriber2} and {more_people}.\", {\n                        subscriber1: aa(ma[ja[0]]),\n                        subscriber2: aa(ma[ja[1]]),\n                        more_people: oa\n                    });\n                }\n                 else if ((ja[0] == n.user)) {\n                    la = i.tx._(\"{actor} added you, {subscriber2} and {more_people}.\", {\n                        actor: aa(ma[ia.author]),\n                        subscriber2: aa(ma[ja[1]]),\n                        more_people: oa\n                    });\n                }\n                 else la = i.tx._(\"{actor} added {subscriber1}, {subscriber2} and {more_people}.\", {\n                    actor: aa(ma[ia.author]),\n                    subscriber1: aa(ma[ja[0]]),\n                    subscriber2: aa(ma[ja[1]]),\n                    more_people: oa\n                });\n                \n            ;\n                i.setContent(ha, la);\n                var qa = j.find(ha, \"span.more\");\n                o.set(qa, pa, \"above\", \"center\");\n            });\n        }\n        \n        \n    ;\n    }, ea = function(ha, ia) {\n        n.get(ia.author, function(ja) {\n            var ka;\n            if ((ia.author == n.user)) {\n                ka = i.tx._(\"You left the conversation.\");\n            }\n             else ka = i.tx._(\"{actor} left the conversation.\", {\n                actor: aa(ja)\n            });\n        ;\n            i.setContent(ha, ka);\n        });\n    }, fa = function(ha, ia) {\n        var ja = \"We were unable to fetch previous messages in this conversation.\";\n        i.setContent(ha, ja);\n    }, ga = function(ha) {\n        return ((ha.log_message_data.event_name === \"installing\") || (ha.log_message_data.event_name === \"install_canceled\"));\n    };\n    e.exports = r;\n});\n__d(\"ChatTabMessagesView\", [\"event-extensions\",\"Arbiter\",\"ArbiterMixin\",\"MercuryAttachmentRenderer\",\"ChannelConstants\",\"ChatConfig\",\"ChatTabIndicatorLine\",\"ChatVisibility\",\"CSS\",\"DOM\",\"Emote\",\"Env\",\"MercuryMessages\",\"MercuryThreadMetadataRenderer\",\"MercuryThreads\",\"MercuryMessageRenderer\",\"MercuryParticipants\",\"MercuryThreadInformer\",\"Tooltip\",\"VideoCallCore\",\"copyProperties\",\"isRTL\",\"tx\",\"date-extensions\",\"ChatTabTemplates\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"MercuryAttachmentRenderer\"), j = b(\"ChannelConstants\"), k = b(\"ChatConfig\"), l = b(\"ChatTabIndicatorLine\"), m = b(\"ChatVisibility\"), n = b(\"CSS\"), o = b(\"DOM\"), p = b(\"Emote\"), q = b(\"Env\"), r = b(\"MercuryMessages\"), s = b(\"MercuryThreadMetadataRenderer\"), t = b(\"MercuryThreads\"), u = b(\"MercuryMessageRenderer\"), v = b(\"MercuryParticipants\"), w = b(\"MercuryThreadInformer\"), x = b(\"Tooltip\"), y = b(\"VideoCallCore\"), z = c(\"ChatTabTemplates\"), aa = c(\"MercuryConstants\"), ba = b(\"copyProperties\"), ca = b(\"isRTL\"), da = b(\"tx\");\n    b(\"date-extensions\");\n    function ea(pa) {\n        return Date.format((k.get(\"24h_times\") ? \"H:i\" : \"g:ia\"), (pa / 1000));\n    };\n    function fa(pa) {\n        var qa = z[\":fb:chat:conversation:message-group\"].build();\n        qa.setNodeContent(\"timestamp\", ea(pa.timestamp));\n        v.get(pa.author, function(ra) {\n            var sa = qa.getNode(\"profileLink\");\n            sa.href = ra.href;\n            var ta = ((ra.fbid == q.user) ? \"You\" : ra.name);\n            x.set(sa, ta, \"left\");\n            qa.setNodeProperty(\"profilePhoto\", \"src\", ra.image_src);\n        });\n        return qa;\n    };\n    function ga(pa) {\n        var qa = z[\":fb:chat:conversation:message:event\"].build();\n        qa.setNodeContent(\"timestamp\", ea(pa.timestamp));\n        u.renderLogMessage(qa.getNode(\"icon\"), qa.getNode(\"message\"), qa.getNode(\"attachment\"), pa);\n        var ra = ha(pa);\n        if (ra) {\n            o.appendContent(qa.getNode(\"message\"), ra);\n        };\n        return qa.getRoot();\n    };\n    function ha(pa) {\n        var qa, ra;\n        if ((pa.log_message_type == aa.MercuryLogMessageType.VIDEO_CALL)) {\n            if ((pa.log_message_data.event_name == \"install_canceled\")) {\n                qa = o.tx._(\"Retry setup and call back.\");\n                ra = \"callback_cancelinstall_link\";\n                return ia(qa, pa.thread_id, pa.log_message_data.to, ra);\n            }\n             else if (((!pa.log_message_data.event_name && (pa.log_message_data.callee == v.user)) && !pa.log_message_data.answered)) {\n                qa = o.tx._(\"Call Back\");\n                ra = \"callback_link\";\n                return ia(qa, pa.thread_id, pa.log_message_data.caller.split(\":\")[1], ra);\n            }\n            \n        \n        };\n        return null;\n    };\n    function ia(pa, qa, ra, sa) {\n        if (y.isSupported()) {\n            var ta = (!m.isOnline() || !y.availableForCall(ra)), ua = o.create(\"a\", {\n                href: \"#\",\n                className: \"callBackLink\"\n            }, pa);\n            if (ta) {\n                n.hide(ua);\n            };\n            ua.setAttribute(\"data-gt\", JSON.stringify({\n                videochat: \"clicked_callback_link\"\n            }));\n            Event.listen(ua, \"click\", function() {\n                na.inform(\"video-call-clicked\", {\n                    userID: ra,\n                    threadID: qa,\n                    clickSource: sa\n                });\n            });\n            return ua;\n        }\n    ;\n        return null;\n    };\n    function ja(pa) {\n        var qa = z[\":fb:mercury:chat:message:forward\"].build(), ra = qa.getNode(\"forwardText\");\n        if (ra) {\n            n.hide(qa.getRoot());\n            s.renderTitanLink(pa.thread_id, qa.getNode(\"forwardLink\"), n.show.bind(n, qa.getRoot()));\n            if ((pa.forward_count > 1)) {\n                o.appendContent(ra, da._(\"{count} forwarded messages\", {\n                    count: pa.forward_count\n                }));\n            }\n             else o.appendContent(ra, \"1 forwarded message\");\n        ;\n        }\n    ;\n        return qa.getRoot();\n    };\n    var ka = [\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\",];\n    function la(pa) {\n        var qa = new Date();\n        qa.setHours(0);\n        qa.setMinutes(0);\n        qa.setSeconds(0);\n        qa.setMilliseconds(0);\n        var ra = (((24 * 60) * 60) * 1000), sa = (qa.getTime() - pa.getTime());\n        if ((sa <= 0)) {\n            return \"Today\";\n        }\n         else if ((sa < ra)) {\n            return \"Yesterday\"\n        }\n    ;\n        return da._(\"{month} {date}\", {\n            month: ka[pa.getMonth()],\n            date: pa.getDate()\n        });\n    };\n    var ma = [];\n    function na(pa, qa, ra, sa) {\n        this.threadID = pa;\n        this.scrollContainer = qa;\n        this.conversationElem = ra;\n        this.messageElements = {\n        };\n        this.messageGroup = null;\n        this.prevMessage = null;\n        var ta = aa.MercuryThreadlistConstants.MESSAGE_TIMESTAMP_THRESHOLD;\n        this._olderTimestamp = ((new Date()).getTime() - ta);\n        ma.push(this);\n        this._subscription = g.subscribe(\"overflow-applied-to-body\", this.scrollToBottom.bind(this));\n        if (sa) {\n            this.indicatorLine = new l(this.threadID, sa, this);\n        };\n        r.getThreadMessagesRange(this.threadID, 0, aa.MercuryThreadlistConstants.RECENT_MESSAGES_LIMIT, Function.prototype);\n        this.rerender();\n    };\n    ba(na, h);\n    ba(na.prototype, {\n        destroy: function() {\n            o.empty(this.conversationElem);\n            this._subscription.unsubscribe();\n            ma.remove(this);\n            (this.indicatorLine && this.indicatorLine.destroy());\n            this.destroyed = true;\n        },\n        _appendMessage: function(pa) {\n            if ((pa == this.prevMessage)) {\n                return\n            };\n            var qa = aa.MercuryThreadlistConstants, ra = qa.GROUPING_THRESHOLD, sa = ((pa.action_type == aa.MercuryActionType.LOG_MESSAGE) && (pa.log_message_type == aa.MercuryLogMessageType.SERVER_ERROR));\n            if (pa.is_cleared) {\n                return\n            };\n            var ta = null;\n            if (this.prevMessage) {\n                ta = new Date(this.prevMessage.timestamp);\n            };\n            var ua = new Date(pa.timestamp);\n            if ((!sa && ((((!ta || (ta.getDate() != ua.getDate())) || (ta.getMonth() != ua.getMonth())) || (ta.getFullYear() != ua.getFullYear()))))) {\n                var va = z[\":fb:chat:conversation:date-break\"].build();\n                o.setContent(va.getRoot(), la(ua));\n                o.appendContent(this.conversationElem, va.getRoot());\n                this.messageGroup = null;\n            }\n        ;\n            if ((pa.action_type == aa.MercuryActionType.LOG_MESSAGE)) {\n                o.appendContent(this.conversationElem, ga(pa));\n                this.messageGroup = null;\n                this.prevMessage = pa;\n                return;\n            }\n        ;\n            if (((!this.messageGroup || (this.prevMessage.author != pa.author)) || (this.prevMessage.timestamp < (pa.timestamp - ra)))) {\n                this.messageGroup = fa(pa);\n                o.appendContent(this.conversationElem, this.messageGroup.getRoot());\n            }\n        ;\n            var wa = this._renderSingleMessage(pa);\n            this.messageElements[pa.message_id] = wa;\n            o.appendContent(this.messageGroup.getNode(\"messages\"), wa);\n            this.prevMessage = pa;\n        },\n        rerender: function() {\n            o.empty(this.conversationElem);\n            this.messageElements = {\n            };\n            this.messageGroup = null;\n            this.prevMessage = null;\n            var pa = r.getThreadMessagesSinceTimestamp(this.threadID, this._olderTimestamp);\n            this._appendMessages(pa);\n        },\n        update: function(pa) {\n            for (var qa in pa) {\n                var ra = this.messageElements[qa];\n                if (ra) {\n                    var sa = this._renderSingleMessage(r.getMessagesFromIDs([qa,])[0]);\n                    this.messageElements[qa] = sa;\n                    o.replace(ra, sa);\n                }\n            ;\n            };\n        },\n        _appendMessages: function(pa) {\n            pa.forEach(this._appendMessage.bind(this));\n            (this.indicatorLine && this.indicatorLine.setLastMessage(this.prevMessage));\n            this.scrollToBottom();\n        },\n        isScrolledToBottom: function() {\n            var pa = this.scrollContainer;\n            return ((pa.scrollTop + pa.clientHeight) >= pa.scrollHeight);\n        },\n        scrollToBottom: function() {\n            this.scrollContainer.scrollTop = this.scrollContainer.scrollHeight;\n        },\n        _renderSingleMessage: function(pa) {\n            var qa = z[\":fb:chat:conversation:message\"].render();\n            if (pa.subject) {\n                var ra = z[\":fb:chat:conversation:message:subject\"].render();\n                o.setContent(ra, pa.subject);\n                o.appendContent(qa, ra);\n            }\n        ;\n            if ((pa.body.substr(0, 4) == \"?OTR\")) {\n                o.setContent(qa, \"[encrypted message]\");\n                n.addClass(qa, \"cyphertext\");\n            }\n             else {\n                n.addClass(qa, (ca(pa.body) ? \"direction_rtl\" : \"direction_ltr\"));\n                o.appendContent(qa, u.formatMessageBody(pa.body));\n            }\n        ;\n            if (pa.has_attachment) {\n                this._appendMessageAttachments(qa, pa);\n            };\n            if (pa.forward_count) {\n                o.appendContent(qa, ja(pa));\n            };\n            var sa = s.renderStatusIndicator(pa.status, r.resendMessage.bind(r, pa));\n            if (sa) {\n                n.addClass(qa, \"errorStatus\");\n                var ta = z[\":fb:chat:conversation:message:status\"].build();\n                o.appendContent(ta.getNode(\"message\"), qa);\n                o.appendContent(ta.getNode(\"status\"), sa);\n                return ta.getRoot();\n            }\n        ;\n            return qa;\n        },\n        _appendMessageAttachments: function(pa, qa) {\n            var ra = aa.MercuryAttachmentType, sa = qa.attachments;\n            for (var ta = 0, ua = sa.length; (ta < ua); ++ta) {\n                var va = sa[ta], wa = va.attach_type, xa = va.share_data_type;\n                if ((wa == ra.ERROR)) {\n                    o.appendContent(pa, i.renderError(va));\n                };\n                if ((wa == ra.FILE)) {\n                    o.appendContent(pa, i.renderFileLink(va));\n                };\n                var ya = null, za;\n                if (((wa == ra.SHARE) && (xa == aa.MercurySupportedShareType.FB_VIDEO))) {\n                    ya = i.renderVideoThumb(va);\n                    za = o.find(ya, \"img\");\n                    Event.listen(za, \"load\", this._thumbLoaded.shield(this, za));\n                }\n                 else if (((wa == ra.SHARE) && (((xa == aa.MercurySupportedShareType.FB_MUSIC_ALBUM) || (xa == aa.MercurySupportedShareType.FB_SONG))))) {\n                    ya = i.renderMusic(va);\n                    za = o.find(ya, \"img\");\n                    Event.listen(za, \"load\", this._thumbLoaded.shield(this, za));\n                }\n                 else if (((wa == ra.SHARE) && (((xa == aa.MercurySupportedShareType.EXTERNAL) || (xa == aa.MercurySupportedShareType.FB_TEMPLATE))))) {\n                    ya = i.renderExternalLink(va);\n                    za = o.find(ya, \"img\");\n                    Event.listen(za, \"load\", this._thumbLoaded.shield(this, za));\n                }\n                 else if (va.preview_url) {\n                    v.get(qa.author, function(ab) {\n                        var bb = v.getUserID(ab.id);\n                        ya = i.renderPreview(va, 0, null, qa, ab, bb);\n                        za = o.find(ya, \"img\");\n                        Event.listen(za, \"load\", this._thumbLoaded.shield(this, za));\n                    }.bind(this));\n                }\n                 else if ((wa == ra.SHARE)) {\n                    ya = i.renderShareLink(va);\n                }\n                \n                \n                \n            ;\n                if (ya) {\n                    o.appendContent(pa, ya);\n                };\n            };\n        },\n        _thumbLoaded: function(pa) {\n            var qa = (this.scrollContainer.scrollTop + this.scrollContainer.clientHeight);\n            if (((qa + pa.offsetHeight) >= this.scrollContainer.scrollHeight)) {\n                this.scrollToBottom();\n            };\n        }\n    });\n    w.subscribe(\"messages-reordered\", function(pa, qa) {\n        ma.forEach(function(ra) {\n            (qa[ra.threadID] && ra.rerender());\n        });\n    });\n    w.subscribe(\"messages-updated\", function(pa, qa) {\n        ma.forEach(function(ra) {\n            (qa[ra.threadID] && ra.update(qa[ra.threadID]));\n        });\n    });\n    w.subscribe(\"messages-received\", function(pa, qa) {\n        ma.forEach(function(ra) {\n            var sa = qa[ra.threadID];\n            (sa && ra._appendMessages(sa));\n        });\n    });\n    g.subscribe(j.getArbiterType(\"chat_event\"), function(pa, qa) {\n        if (oa(qa.obj)) {\n            var ra = (((q.user == qa.obj.from)) ? qa.obj.to : qa.obj.from), sa = t.getThreadIdForUser(ra), ta = ma.filter(function(wa) {\n                return (wa.threadID === sa);\n            });\n            if ((ta.length > 0)) {\n                var ua = ta[0], va = r.constructLogMessageObject(aa.MercurySourceType.CHAT_WEB, sa, aa.MercuryLogMessageType.VIDEO_CALL, qa.obj);\n                va.author = (\"fbid:\" + qa.obj.from);\n                ua._appendMessages([va,]);\n            }\n        ;\n        }\n    ;\n    });\n    function oa(pa) {\n        return (((pa.event_name === \"installing\") || (pa.event_name === \"install_canceled\")));\n    };\n    e.exports = na;\n});\n__d(\"ChatTabSheetPolicy\", [], function(a, b, c, d, e, f) {\n    var g = {\n        canReplaceOpenSheet: function(h, i) {\n            if ((h.getType() == i.getType())) {\n                return false\n            };\n            if ((h.isPermanent() && !i.isPermanent())) {\n                return false\n            };\n            return true;\n        }\n    };\n    e.exports = g;\n});\n__d(\"ChatTabSheetView\", [\"event-extensions\",\"Animation\",\"ChatTabSheetPolicy\",\"CSS\",\"DOM\",\"Style\",\"Vector\",\"copyProperties\",\"ChatTabTemplates\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Animation\"), h = b(\"ChatTabSheetPolicy\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"Style\"), l = b(\"Vector\"), m = b(\"copyProperties\"), n = c(\"ChatTabTemplates\"), o = 5000, p = function(q, r, s) {\n        this._threadID = q;\n        this._rootElement = r;\n        this._tabMainElement = s;\n        this._openSheet = null;\n    };\n    m(p.prototype, {\n        destroy: function() {\n            j.empty(this._rootElement);\n        },\n        _openCommon: function(q, r) {\n            if ((this._openSheet && !h.canReplaceOpenSheet(this._openSheet, q))) {\n                return\n            };\n            this.clear(function() {\n                this._openSheet = q;\n                var s = n[\":fb:mercury:chat:tab-sheet:loading\"].build().getRoot();\n                j.setContent(this._rootElement, s);\n                i.show(s);\n                i.show(this._rootElement);\n                q.render();\n                if (r) {\n                    i.addClass(this._tabMainElement, \"sheetSlide\");\n                    var t = l.getElementDimensions(this._rootElement).y;\n                    k.set(this._rootElement, \"bottom\", (t + \"px\"));\n                    this._animation = new g(this._rootElement).to(\"bottom\", 0).duration(150).ease(g.ease.both).ondone(function() {\n                        i.removeClass(this._tabMainElement, \"sheetSlide\");\n                    }.bind(this)).go();\n                }\n            ;\n                if (!q.isPermanent()) {\n                    var u = o;\n                    if (q.getCloseTimeout) {\n                        u = q.getCloseTimeout();\n                    };\n                    this._sheetCloseHandler = this.close.bind(this, q).defer(u, false);\n                }\n            ;\n            }.bind(this));\n        },\n        set: function(q) {\n            return this._openCommon(q, false);\n        },\n        open: function(q) {\n            return this._openCommon(q, true);\n        },\n        close: function(q, r) {\n            if ((this._openSheet != q)) {\n                return\n            };\n            if (!this._openSheet) {\n                (r && r());\n                return;\n            }\n        ;\n            if (this._animation) {\n                this._animation.stop();\n            };\n            if (this._sheetCloseHandler) {\n                clearTimeout(this._sheetCloseHandler);\n                this._sheetCloseHandler = null;\n            }\n        ;\n            i.addClass(this._tabMainElement, \"sheetSlide\");\n            var s = l.getElementDimensions(this._rootElement).y;\n            this._animation = new g(this._rootElement).to(\"bottom\", (s + \"px\")).duration(100).ease(g.ease.begin).ondone(function() {\n                j.empty(this._rootElement);\n                i.hide(this._rootElement);\n                i.removeClass(this._tabMainElement, \"sheetSlide\");\n                this._openSheet = null;\n                (r && r());\n            }.bind(this)).go();\n        },\n        clear: function(q) {\n            this.close(this._openSheet, q);\n        }\n    });\n    e.exports = p;\n});\n__d(\"MercuryTypeahead\", [\"event-extensions\",\"ArbiterMixin\",\"DOM\",\"Env\",\"Input\",\"Tokenizer\",\"Typeahead\",\"TypeaheadCore\",\"copyProperties\",\"MercuryTypeaheadTemplates\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"DOM\"), i = b(\"Env\"), j = b(\"Input\"), k = b(\"Tokenizer\"), l = b(\"Typeahead\"), m = b(\"TypeaheadCore\"), n = b(\"copyProperties\"), o = c(\"MercuryTypeaheadTemplates\"), p = function(q, r) {\n        this._domElement = null;\n        this._typeahead = null;\n        this._tokenizer = null;\n        this._placeholder = \"\";\n        this._exclusions = [];\n        this._viewNodeID = null;\n        this._viewOptions = {\n            renderer: \"compact\",\n            autoSelect: true\n        };\n        this._tokenizerBehaviors = [];\n        this._dataSource = q;\n        this._view = r;\n    };\n    n(p.prototype, g);\n    n(p.prototype, {\n        setPlaceholder: function(q) {\n            this._placeholder = q;\n            return this;\n        },\n        setExcludedParticipants: function(q) {\n            this._exclusions = [];\n            q.forEach(function(r) {\n                var s = r.indexOf(\":\");\n                if ((r.substr(0, s) == \"fbid\")) {\n                    this._exclusions.push(r.substr((s + 1)));\n                };\n            }.bind(this));\n            return this;\n        },\n        setViewNodeID: function(q) {\n            this._viewNodeID = q;\n        },\n        setViewOption: function(q, r) {\n            this._viewOptions[q] = r;\n        },\n        addTokenizerBehavior: function(q) {\n            this._tokenizerBehaviors.push(q);\n        },\n        build: function(q) {\n            if (this._domElement) {\n                return\n            };\n            var r = o[\":fb:mercury:tokenizer\"].build(), s = o[\":fb:mercury:typeahead\"].build();\n            this._domElement = r.getRoot();\n            h.appendContent(this._domElement, s.getRoot());\n            var t = s.getNode(\"textfield\");\n            j.setPlaceholder(t, this._placeholder);\n            t.setAttribute(\"data-placeholder\", this._placeholder);\n            var u = {\n                node_id: this._viewNodeID,\n                ctor: this._view,\n                options: this._viewOptions\n            }, v = {\n                ctor: m,\n                options: {\n                    setValueOnSelect: true\n                }\n            };\n            this._typeahead = new l(this._dataSource, u, v, s.getRoot());\n            this._typeahead.init();\n            var w = {\n                inline: true,\n                behaviors: this._tokenizerBehaviors\n            };\n            this._tokenizer = new k(this._domElement, this._typeahead);\n            this._tokenizer.init(r.getNode(\"tokenarea\"), \"participants\", [], w);\n            this._tokenizer.subscribe([\"addToken\",\"removeToken\",\"removeAllTokens\",], function() {\n                this.inform(\"tokens-changed\");\n            }.bind(this));\n            Event.listen(t, \"focus\", function() {\n                this._resetDataSource();\n                this._typeahead.init();\n            }.bind(this));\n            Event.listen(this._domElement, \"click\", this.focus.bind(this));\n        },\n        getElement: function() {\n            return this._domElement;\n        },\n        getSelectedParticipantIDs: function() {\n            var q = [];\n            if (this._tokenizer) {\n                ((this._tokenizer.getTokenValues() || [])).forEach(function(r) {\n                    q.push((\"fbid:\" + r));\n                });\n            };\n            return q;\n        },\n        getTokens: function() {\n            var q = [];\n            if (this._tokenizer) {\n                q = this._tokenizer.getTokens();\n            };\n            return q;\n        },\n        getTokenizer: function() {\n            return this._tokenizer;\n        },\n        reset: function() {\n            (this._tokenizer && this._tokenizer.removeAllTokens());\n            (this._typeahead && this._typeahead.getCore().reset());\n        },\n        focus: function() {\n            (this._tokenizer && this._tokenizer.focusInput());\n        },\n        getTypeahead: function() {\n            return this._typeahead;\n        },\n        _resetDataSource: function() {\n            this._dataSource.setExclusions(this._exclusions);\n        }\n    });\n    e.exports = p;\n});\n__d(\"MultiChatController\", [\"Arbiter\",\"AsyncSignal\",\"copyProperties\",\"Form\",\"MercuryMessages\",\"MercuryServerRequests\",\"MercuryThreads\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AsyncSignal\"), i = b(\"copyProperties\"), j = b(\"Form\"), k = b(\"MercuryMessages\"), l = b(\"MercuryServerRequests\"), m = b(\"MercuryThreads\");\n    function n() {\n    \n    };\n    i(n, {\n        subscribe: function(o, p) {\n            o.subscribe(\"confirm\", function() {\n                this.createGroupThreadFromChooserDialog(o, p);\n            }.bind(this));\n        },\n        createGroupThreadFromChooserDialog: function(o, p) {\n            var q = j.serialize(o.getRoot()), r = JSON.parse(q.profileChooserItems), s = [];\n            for (var t in r) {\n                if (r[t]) {\n                    s.push(t);\n                };\n            };\n            var u = n.createThreadForFBIDs(s);\n            l.subscribe(\"update-thread-ids\", function(v, w) {\n                for (var x in w) {\n                    if ((w[x] == u)) {\n                        new h(\"/ajax/groups/chat/log\", {\n                            group_id: p,\n                            message_id: x\n                        }).send();\n                    };\n                };\n            });\n            o.hide();\n        },\n        createThreadForTokens: function(o) {\n            if (!o.length) {\n                return\n            };\n            var p;\n            if ((o.length == 1)) {\n                p = (\"user:\" + o[0].split(\":\")[1]);\n            }\n             else p = (\"root:\" + k.generateNewClientMessageID((new Date()).getTime()));\n        ;\n            m.createNewLocalThread(p, o);\n            g.inform(\"chat/open-tab\", {\n                thread_id: p\n            });\n            return p;\n        },\n        createThreadForFBIDs: function(o) {\n            var p = [];\n            for (var q = 0; (q < o.length); q++) {\n                p.push((\"fbid:\" + o[q]));;\n            };\n            return n.createThreadForTokens(p);\n        }\n    });\n    e.exports = n;\n});\n__d(\"ChatAddFriendsTabSheet\", [\"event-extensions\",\"Arbiter\",\"ChatTabSheetView\",\"ContextualTypeaheadView\",\"DOM\",\"MercuryTypeahead\",\"MercuryMessages\",\"MultiChatController\",\"MercuryServerRequests\",\"MercuryThreads\",\"copyProperties\",\"tx\",\"MercuryConstants\",\"MercuryDataSource\",\"ChatTabTemplates\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ChatTabSheetView\"), i = b(\"ContextualTypeaheadView\"), j = b(\"DOM\"), k = b(\"MercuryTypeahead\"), l = b(\"MercuryMessages\"), m = b(\"MultiChatController\"), n = b(\"MercuryServerRequests\"), o = b(\"MercuryThreads\"), p = b(\"copyProperties\"), q = c(\"MercuryConstants\"), r = c(\"MercuryDataSource\"), s = c(\"ChatTabTemplates\"), t = b(\"tx\");\n    function u(x, y, z) {\n        this._threadID = x;\n        this._rootElement = y;\n        this._sheetView = z;\n    };\n    p(u.prototype, {\n        render: function() {\n            var x = s[\":fb:mercury:chat:tab-sheet:add-friends\"].build();\n            o.getThreadMeta(this._threadID, function(y) {\n                var z = new k(r, i);\n                z.setExcludedParticipants(y.participants);\n                z.setPlaceholder(\"Enter a friend's name\");\n                z.build();\n                j.replace(x.getNode(\"participantsTypeahead\"), z.getElement());\n                j.setContent(this._rootElement, x.getRoot());\n                z.focus();\n                var aa = y.participants, ba = (y.is_canonical_user ? v.bind(null, this, this._sheetView, aa, z) : w.bind(null, this, this._sheetView, this._threadID, z));\n                Event.listen(x.getNode(\"doneButton\"), \"click\", ba);\n            }.bind(this));\n        },\n        isPermanent: function() {\n            return true;\n        },\n        getType: function() {\n            return \"add_friends_type\";\n        },\n        open: function() {\n            this._sheetView.open(this);\n        }\n    });\n    function v(x, y, z, aa) {\n        var ba = aa.getSelectedParticipantIDs();\n        if (ba.length) {\n            m.createThreadForTokens(z.concat(ba));\n        };\n        y.close(x);\n    };\n    function w(x, y, z, aa) {\n        var ba = aa.getSelectedParticipantIDs();\n        if (ba.length) {\n            if (o.isEmptyLocalThread(z)) {\n                o.addParticipantsToThreadLocally(z, ba);\n            }\n             else l.sendMessage(l.constructLogMessageObject(q.MercurySourceType.CHAT_WEB, z, q.MercuryLogMessageType.SUBSCRIBE, {\n                added_participants: ba\n            }));\n        \n        };\n        y.close(x);\n    };\n    e.exports = u;\n});\n__d(\"ChatAvailabilityTabSheet\", [\"Arbiter\",\"AvailableList\",\"AvailableListConstants\",\"ChatConfig\",\"CSS\",\"DOM\",\"GenderConst\",\"MercuryThreads\",\"ShortProfiles\",\"copyProperties\",\"ChatTabTemplates\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AvailableList\"), i = b(\"AvailableListConstants\"), j = b(\"ChatConfig\"), k = b(\"CSS\"), l = b(\"DOM\"), m = b(\"GenderConst\"), n = b(\"MercuryThreads\"), o = b(\"ShortProfiles\"), p = b(\"copyProperties\"), q = c(\"ChatTabTemplates\");\n    function r(v, w, x, y) {\n        this._handledAvailability = w;\n        this._sheetView = y;\n        this._rootElement = x;\n        this._canonicalUser = n.getCanonicalUserInThread(v);\n        if (this._canonicalUser) {\n            this._currentAvailability = i.ACTIVE;\n            this._handleAvailabilityChange();\n            g.subscribe(i.ON_AVAILABILITY_CHANGED, this._handleAvailabilityChange.bind(this));\n        }\n    ;\n    };\n    r.createSheets = function(v, w, x) {\n        var y = {\n        };\n        if (j.get(\"roger.ui\")) {\n            y[i.OFFLINE] = new r(v, i.OFFLINE, w, x);\n            return y;\n        }\n    ;\n        [i.ACTIVE,i.OFFLINE,i.MOBILE,].forEach(function(z) {\n            y[z] = new r(v, z, w, x);\n        });\n        return y;\n    };\n    p(r.prototype, {\n        render: function() {\n            !this._canonicalUser;\n            var v = q[\":fb:mercury:chat:tab-sheet:message-icon-sheet\"].build();\n            o.get(this._canonicalUser, function(w) {\n                var x = null;\n                switch (this._currentAvailability) {\n                  case i.ACTIVE:\n                    k.addClass(v.getRoot(), \"active\");\n                    x = s(w);\n                    break;\n                  case i.MOBILE:\n                    k.addClass(v.getRoot(), \"mobile\");\n                    x = t(w);\n                    break;\n                  case i.OFFLINE:\n                    x = u(w);\n                    break;\n                };\n                l.setContent(v.getNode(\"text\"), x);\n                l.setContent(this._rootElement, v.getRoot());\n            }.bind(this));\n        },\n        isPermanent: function() {\n            return false;\n        },\n        getType: function() {\n            switch (this._handledAvailability) {\n              case i.ACTIVE:\n                return \"availability_active_type\";\n              case i.MOBILE:\n                return \"availability_mobile_type\";\n              case i.OFFLINE:\n                return \"availability_offline_type\";\n              default:\n                throw new Error(\"Invalid handled availability\");\n            };\n        },\n        getCloseTimeout: function() {\n            return 5000;\n        },\n        _handleAvailabilityChange: function() {\n            var v = h.get(this._canonicalUser);\n            if ((v == this._currentAvailability)) {\n                return\n            };\n            this._currentAvailability = v;\n            if ((v == this._handledAvailability)) {\n                this._sheetView.open(this);\n            };\n        }\n    });\n    function s(v) {\n        return l.tx._(\"{name} is now available.\", {\n            name: v.firstName\n        });\n    };\n    function t(v) {\n        return l.tx._(\"Your messages will be sent to {name}'s phone.\", {\n            name: v.firstName\n        });\n    };\n    function u(v) {\n        switch (v.gender) {\n          case m.FEMALE_SINGULAR:\n        \n          case m.FEMALE_SINGULAR_GUESS:\n            return l.tx._(\"{name} is offline, but you can still send her a message.\", {\n                name: v.firstName\n            });\n          case m.MALE_SINGULAR:\n        \n          case m.MALE_SINGULAR_GUESS:\n            return l.tx._(\"{name} is offline, but you can still send him a message.\", {\n                name: v.firstName\n            });\n          default:\n            return l.tx._(\"{name} is offline, but you can still send them a message.\", {\n                name: v.firstName\n            });\n        };\n    };\n    e.exports = r;\n});\n__d(\"ChatNoRecipientsTabSheet\", [\"DOM\",\"MercuryParticipants\",\"MercuryThreadInformer\",\"MercuryThreads\",\"copyProperties\",\"ChatTabTemplates\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"MercuryParticipants\"), i = b(\"MercuryThreadInformer\"), j = b(\"MercuryThreads\"), k = b(\"copyProperties\"), l = c(\"ChatTabTemplates\");\n    function m(n, o, p) {\n        this._threadID = n;\n        this._rootElement = o;\n        this._sheetView = p;\n        i.subscribe(\"threads-updated\", this._handleThreadsUpdated.bind(this));\n    };\n    k(m.prototype, {\n        render: function() {\n            var n = l[\":fb:mercury:chat:tab-sheet:message-icon-sheet\"].build();\n            g.setContent(n.getNode(\"text\"), g.tx._(\"All recipients have left this conversation. Please close the stale tab.\"));\n            g.setContent(this._rootElement, n.getRoot());\n        },\n        isPermanent: function() {\n            return true;\n        },\n        getType: function() {\n            return \"no_recipients_type\";\n        },\n        _handleThreadsUpdated: function() {\n            j.getThreadMeta(this._threadID, function(n) {\n                var o = h.user, p = n.participants.filter(function(q) {\n                    return (q != o);\n                });\n                if ((p.length < 1)) {\n                    this._sheetView.open(this);\n                }\n                 else this._sheetView.close(this);\n            ;\n            }.bind(this));\n        }\n    });\n    e.exports = m;\n});\n__d(\"ChatOfflineTabSheet\", [\"event-extensions\",\"ChatPrivacyActionController\",\"ChatTabSheetView\",\"ChatVisibility\",\"CSS\",\"DOM\",\"JSLogger\",\"MercuryParticipants\",\"MercuryThreads\",\"copyProperties\",\"MercuryConfig\",\"ChatTabTemplates\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ChatPrivacyActionController\"), h = b(\"ChatTabSheetView\"), i = b(\"ChatVisibility\"), j = b(\"CSS\"), k = b(\"DOM\"), l = b(\"JSLogger\"), m = b(\"MercuryParticipants\"), n = b(\"MercuryThreads\"), o = b(\"copyProperties\"), o = b(\"copyProperties\"), p = c(\"MercuryConfig\"), q = c(\"ChatTabTemplates\");\n    function r(s, t, u) {\n        this._rootElement = t;\n        this._sheetView = u;\n        this._logger = l.create(\"blackbird\");\n        this._canonicalUser = n.getCanonicalUserInThread(s);\n        if (this._canonicalUser) {\n            this._privacyActionController = new g(this._canonicalUser, this._handlePrivacyChange.bind(this));\n        };\n    };\n    o(r.prototype, {\n        render: function() {\n            if (!this._canonicalUser) {\n                this._logger.error(\"offline_sheet_open_with_non_friend\");\n                return;\n            }\n        ;\n            var s = q[\":fb:mercury:chat:tab-sheet:message-icon-sheet\"].build(), t = (\"fbid:\" + this._canonicalUser);\n            m.get(t, function(u) {\n                var v = \"fbChatGoOnlineLink\", w = (p.ChatControlLanguageChangeGK ? k.tx._(\"turn on chat\") : k.tx._(\"go online\")), x = k.create(\"a\", {\n                    href: \"#\",\n                    className: v\n                }, w), y;\n                if (p.ChatControlLanguageChangeGK) {\n                    y = k.tx._(\"To chat with {name} and other friends, {link}.\", {\n                        name: u.short_name,\n                        link: x\n                    });\n                }\n                 else y = k.tx._(\"You are now offline. To chat with {name} and other friends, {link}.\", {\n                    name: u.short_name,\n                    link: x\n                });\n            ;\n                k.setContent(s.getNode(\"text\"), y);\n                j.addClass(s.getRoot(), \"chatOffline\");\n                k.setContent(this._rootElement, s.getRoot());\n                Event.listen(this._rootElement, \"click\", function(event) {\n                    if (j.hasClass(event.getTarget(), v)) {\n                        if (i.isOnline()) {\n                            this._logger.error(\"tab_sheet_already_online\");\n                        };\n                        this._privacyActionController.togglePrivacy();\n                        this._logger.log(\"tab_sheet_go_online\", {\n                            tab_id: this._canonicalUser\n                        });\n                        return false;\n                    }\n                ;\n                }.bind(this));\n            }.bind(this));\n        },\n        _handlePrivacyChange: function(s) {\n            if (!this._canonicalUser) {\n                this._logger.error(\"user_blocked_sheet_privacy_changed_non_friend\");\n            };\n            switch (s) {\n              case g.OFFLINE:\n                this._sheetView.open(this);\n                break;\n              case g.NORMAL:\n            \n              case g.BLOCKED:\n                this._sheetView.close(this);\n                break;\n            };\n        },\n        isPermanent: function() {\n            return true;\n        },\n        getType: function() {\n            return \"offline_type\";\n        },\n        destroy: function() {\n            (this._privacyActionController && this._privacyActionController.destroy());\n        }\n    });\n    e.exports = r;\n});\n__d(\"ChatUserBlockedTabSheet\", [\"event-extensions\",\"ChatPrivacyActionController\",\"ChatTabSheetView\",\"CSS\",\"DOM\",\"GenderConst\",\"JSLogger\",\"MercuryParticipants\",\"MercuryThreads\",\"copyProperties\",\"tx\",\"MercuryConfig\",\"ChatTabTemplates\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ChatPrivacyActionController\"), h = b(\"ChatTabSheetView\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"GenderConst\"), l = b(\"JSLogger\"), m = b(\"MercuryParticipants\"), n = b(\"MercuryThreads\"), o = b(\"copyProperties\"), p = c(\"MercuryConfig\"), q = c(\"ChatTabTemplates\"), r = b(\"tx\");\n    function s(t, u, v) {\n        this._rootElement = u;\n        this._sheetView = v;\n        this._logger = l.create(\"blackbird\");\n        this._canonicalUser = n.getCanonicalUserInThread(t);\n        if (this._canonicalUser) {\n            this._privacyActionController = new g(this._canonicalUser, this._handlePrivacyChange.bind(this));\n        };\n    };\n    o(s.prototype, {\n        render: function() {\n            if (!this._canonicalUser) {\n                this._logger.error(\"user_blocked_sheet_open_with_non_friend\");\n                return;\n            }\n        ;\n            var t = q[\":fb:mercury:chat:tab-sheet:user-blocked\"].build(), u = (\"fbid:\" + this._canonicalUser);\n            m.get(u, function(v) {\n                var w = null;\n                switch (v.gender) {\n                  case k.FEMALE_SINGULAR:\n                \n                  case k.FEMALE_SINGULAR_GUESS:\n                    w = (p.ChatControlLanguageChangeGK ? r._(\"You turned off chat for {name} but you can still send her a message. \", {\n                        name: v.short_name\n                    }) : r._(\"{name} sees you as offline on chat, but you can still send her a message. \", {\n                        name: v.short_name\n                    }));\n                    break;\n                  case k.MALE_SINGULAR:\n                \n                  case k.MALE_SINGULAR_GUESS:\n                    w = (p.ChatControlLanguageChangeGK ? r._(\"You turned off chat for {name} but you can still send him a message. \", {\n                        name: v.short_name\n                    }) : r._(\"{name} sees you as offline on chat, but you can still send him a message. \", {\n                        name: v.short_name\n                    }));\n                    break;\n                  default:\n                    w = (p.ChatControlLanguageChangeGK ? r._(\"You turned off chat for {name} but you can still send them a message. \", {\n                        name: v.short_name\n                    }) : r._(\"{name} sees you as offline on chat, but you can still send them a message. \", {\n                        name: v.short_name\n                    }));\n                };\n                j.setContent(t.getNode(\"text\"), w);\n                var x = (p.ChatControlLanguageChangeGK ? r._(\"Turn on chat for {name}?\", {\n                    name: v.short_name\n                }) : r._(\"Go Online to {name}\", {\n                    name: v.short_name\n                }));\n                j.setContent(t.getNode(\"actionLink\"), x);\n                i.addClass(t.getRoot(), \"blocked\");\n                j.setContent(this._rootElement, t.getRoot());\n                Event.listen(t.getNode(\"actionLink\"), \"click\", this._privacyActionController.togglePrivacy.bind(this._privacyActionController));\n            }.bind(this));\n        },\n        _handlePrivacyChange: function(t) {\n            if (!this._canonicalUser) {\n                this._logger.error(\"user_blocked_sheet_privacy_changed_non_friend\");\n            };\n            switch (t) {\n              case g.BLOCKED:\n                this._sheetView.open(this);\n                break;\n              case g.NORMAL:\n            \n              case g.OFFLINE:\n                this._sheetView.close(this);\n                break;\n            };\n        },\n        isPermanent: function() {\n            return true;\n        },\n        getType: function() {\n            return \"user_blocked_type\";\n        },\n        destroy: function() {\n            (this._privacyActionController && this._privacyActionController.destroy());\n        }\n    });\n    e.exports = s;\n});\n__d(\"ChatTabSheetController\", [\"ChatAddFriendsTabSheet\",\"ChatAvailabilityTabSheet\",\"ChatNoRecipientsTabSheet\",\"ChatOfflineTabSheet\",\"ChatTabSheetView\",\"ChatUserBlockedTabSheet\",\"copyProperties\",\"MercuryServerRequests\",\"MercuryThreads\",], function(a, b, c, d, e, f) {\n    var g = b(\"ChatAddFriendsTabSheet\"), h = b(\"ChatAvailabilityTabSheet\"), i = b(\"ChatNoRecipientsTabSheet\"), j = b(\"ChatOfflineTabSheet\"), k = b(\"ChatTabSheetView\"), l = b(\"ChatUserBlockedTabSheet\"), m = b(\"copyProperties\"), n = b(\"MercuryServerRequests\"), o = b(\"MercuryThreads\"), p = function(q, r, s) {\n        this._sheetView = new k(q, r, s);\n        this._addFriendsTabSheet = new g(q, r, this._sheetView);\n        this._userBlockedTabSheet = new l(q, r, this._sheetView);\n        this._offlineTabSheet = new j(q, r, this._sheetView);\n        this._availabilityTabSheets = h.createSheets(q, r, this._sheetView);\n        if (o.isMultichatThread(q)) {\n            this._noRecipientsTabSheet = new i(q, r, this._sheetView);\n        };\n    };\n    m(p.prototype, {\n        openAddFriendsSheet: function() {\n            this._addFriendsTabSheet.open();\n        },\n        destroy: function() {\n            this._sheetView.destroy();\n            this._offlineTabSheet.destroy();\n            this._userBlockedTabSheet.destroy();\n        }\n    });\n    e.exports = p;\n});\n__d(\"ChatTabView\", [\"event-extensions\",\"function-extensions\",\"Arbiter\",\"ArbiterMixin\",\"AsyncDialog\",\"AsyncRequest\",\"AvailableList\",\"AvailableListConstants\",\"ChatConfig\",\"ChatContextualDialogController\",\"ChatQuietLinks\",\"ChatPrivacyActionController\",\"MessagesEmoticonView\",\"ChatTabMessagesView\",\"ChatTabSheetController\",\"ChatVisibility\",\"CSS\",\"Dialog\",\"Dock\",\"DOM\",\"JSLogger\",\"Keys\",\"MercuryMessages\",\"MercuryParticipants\",\"MercuryServerRequests\",\"MercuryThreadInformer\",\"MercuryThreadMetadataRenderer\",\"MercuryThreads\",\"MercuryTypingReceiver\",\"NubController\",\"Parent\",\"PresencePrivacy\",\"Style\",\"TextAreaControl\",\"Tooltip\",\"TypingIndicator\",\"URI\",\"UserAgent\",\"VideoCallCore\",\"copyProperties\",\"setIntervalAcrossTransitions\",\"tx\",\"MercuryConfig\",\"MercuryConstants\",\"ChatTabTemplates\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"AsyncDialog\"), j = b(\"AsyncRequest\"), k = b(\"AvailableList\"), l = b(\"AvailableListConstants\"), m = b(\"ChatConfig\"), n = b(\"ChatContextualDialogController\"), o = b(\"ChatQuietLinks\"), p = b(\"ChatPrivacyActionController\"), q = b(\"MessagesEmoticonView\"), r = b(\"ChatTabMessagesView\"), s = b(\"ChatTabSheetController\"), t = b(\"ChatVisibility\"), u = b(\"CSS\"), v = b(\"Dialog\"), w = b(\"Dock\"), x = b(\"DOM\"), y = b(\"JSLogger\"), z = b(\"Keys\"), aa = b(\"MercuryMessages\"), ba = b(\"MercuryParticipants\"), ca = b(\"MercuryServerRequests\"), da = b(\"MercuryThreadInformer\"), ea = b(\"MercuryThreadMetadataRenderer\"), fa = b(\"MercuryThreads\"), ga = b(\"MercuryTypingReceiver\"), ha = b(\"NubController\"), ia = b(\"Parent\"), ja = b(\"PresencePrivacy\"), ka = b(\"Style\"), la = b(\"TextAreaControl\"), ma = b(\"Tooltip\"), na = b(\"TypingIndicator\"), oa = b(\"URI\"), pa = b(\"UserAgent\"), qa = b(\"VideoCallCore\"), ra = c(\"MercuryConfig\"), sa = c(\"MercuryConstants\"), ta = c(\"ChatTabTemplates\"), ua = b(\"copyProperties\"), va = b(\"setIntervalAcrossTransitions\"), wa = b(\"tx\"), xa = y.create(\"tab_view\"), ya = {\n    };\n    function za(ib, jb) {\n        var kb = x.create(\"div\");\n        jb = jb.filter(function(lb) {\n            return (lb != ba.user);\n        });\n        ba.getMulti(jb, function(lb) {\n            for (var mb in lb) {\n                var nb = lb[mb], ob = ta[\":fb:mercury:chat:multichat-tooltip-item\"].build();\n                x.setContent(ob.getNode(\"name\"), nb.name);\n                var pb = ba.getUserID(mb), qb = (pb && (k.get(pb) == l.ACTIVE));\n                u.conditionShow(ob.getNode(\"icon\"), qb);\n                u.conditionClass(ob.getNode(\"name\"), \"tooltipItemWithIcon\", qb);\n                x.appendContent(kb, ob.getRoot());\n            };\n            ma.set(ib, kb, \"above\", \"center\");\n        });\n    };\n    var ab = {\n    }, bb = null, cb = false;\n    function db(ib, jb, kb) {\n        if (kb) {\n            ab[ib] = jb;\n            if (!bb) {\n                bb = va(eb, 600);\n            };\n        }\n         else {\n            u.removeClass(jb, \"highlightTitle\");\n            delete ab[ib];\n        }\n    ;\n    };\n    function eb() {\n        for (var ib in ab) {\n            var jb = ab[ib];\n            if (jb.parentNode) {\n                u.conditionClass(jb, \"highlightTitle\", cb);\n            }\n             else delete ab[ib];\n        ;\n        };\n        cb = !cb;\n        if (!Object.keys(ab).length) {\n            clearInterval(bb);\n            bb = null;\n        }\n    ;\n    };\n    function fb(ib) {\n        var jb = ca.tokenizeThreadID(ib);\n        switch (jb.type) {\n          case \"user\":\n            return ta[\":fb:mercury:chat:user-tab\"].build();\n          case \"group\":\n            return ta[\":fb:mercury:chat:group-tab\"].build();\n        };\n        return ta[\":fb:mercury:chat:multichat-tab\"].build();\n    };\n    function gb(ib, jb) {\n        if (jb) {\n            ca.ensureThreadIsFetched(jb);\n        };\n        this._threadID = ib;\n        this._eventListeners = [];\n        this._tabTemplate = fb(ib);\n        this._tabElem = this._tabTemplate.getRoot();\n        if (!((this._getNode instanceof Function))) {\n            xa.log(\"getnode_undefined\", {\n                is_getnode_set: !!this._getNode,\n                is_prototype_set: !!gb.prototype,\n                is_window: (window == this),\n                is_chat_tab_view: (this instanceof gb),\n                ctor_name: (this.constructor && this.constructor.name)\n            });\n        };\n        this._sheetController = new s(this._threadID, this._getNode(\"sheet\"), this._tabElem);\n        this._contextualDialogController = new n(this._threadID, this._getNode(\"videoCallLink\"));\n        this._messagesView = null;\n        var kb = this._getNode(\"conversationLink\");\n        if (kb) {\n            u.hide(kb);\n            ea.renderTitanLink(ib, kb, u.show.bind(u, kb));\n        }\n    ;\n        if (fa.isMultichatThread(this._threadID)) {\n            this._titlebarTooltipAnchor = this._getNode(\"titlebarText\");\n        };\n        var lb = this._getCanonicalUserID();\n        if (this._isTitleTextLinked()) {\n            ba.get((\"fbid:\" + lb), function(pb) {\n                var qb = this._getNode(\"titlebarText\");\n                qb.setAttribute(\"href\", pb.href);\n                qb.removeAttribute(\"rel\");\n                u.removeClass(qb, \"noLink\");\n            }.bind(this));\n        };\n        this._nubController = new ha().init(this._tabElem);\n        la.getInstance(this._getNode(\"input\")).subscribe(\"resize\", function() {\n            this._nubController.flyoutContentChanged();\n        }.bind(this));\n        this._nubController.subscribe(\"resize\", function() {\n            this._emoticonsNode.style.left = (((this._getNode(\"input\").clientWidth + 3)) + \"px\");\n            la.getInstance(this._getNode(\"input\")).update();\n        }.bind(this));\n        this._listen(\"closeButton\", \"click\", this._closeClicked);\n        this._listen(\"titlebarCloseButton\", \"click\", this._closeClicked);\n        this._listen(\"dockButton\", \"click\", this._nubClicked);\n        this._listen(\"dockButton\", \"keydown\", this._dockKeyDown);\n        this._listen(\"nubFlyoutTitlebar\", \"click\", this._titleClicked);\n        this._listen(\"chatConv\", \"click\", this._chatConvClicked);\n        this._listen(\"addFriendLink\", \"click\", this._addFriendLinkClicked, true);\n        this._listen(\"addToThreadLink\", \"click\", this._addFriendLinkClicked, true);\n        this._listen(\"clearWindowLink\", \"click\", this._clearHistory, true);\n        this._listen(\"unsubscribeLink\", \"click\", this._unsubscribeLinkClicked, true);\n        this._listen(\"videoCallLink\", \"click\", this._callClicked, true);\n        this._listen(\"reportSpamLink\", \"click\", this._reportSpamClicked, true);\n        this._listen(\"input\", \"focus\", this._focusTab);\n        this._listen(\"input\", \"blur\", this._blurTab);\n        this._emoticonsNode = this._getNode(\"emoticons\");\n        this._emoticonView = new q(this._emoticonsNode, this._getNode(\"input\"));\n        if (pa.firefox()) {\n            this._listen(\"input\", \"keypress\", this._inputKeyDown);\n        }\n         else this._listen(\"input\", \"keydown\", this._inputKeyDown);\n    ;\n        this._privacyLink = this._getNode(\"privacyLink\");\n        if (this._privacyLink) {\n            this._privacyActionController = new p(lb, this._updatePrivacyLink.bind(this));\n            this._eventListeners.push(Event.listen(this._privacyLink, \"click\", this._privacyActionController.togglePrivacy.bind(this._privacyActionController)));\n        }\n    ;\n        var mb = (lb || ((m.get(\"chat_multi_typ_send\") && fa.isMultichatThread(this._threadID))));\n        if (mb) {\n            ca.getServerThreadID(this._threadID, function(pb) {\n                this._typingIndicator = new na(lb, this._getNode(\"input\"), \"mercury-chat\", null, pb);\n            }.bind(this));\n        };\n        var nb = this._getNode(\"muteGroupLink\");\n        if (nb) {\n            var ob = fa.getCanonicalGroupInThread(this._threadID);\n            if (ob) {\n                nb.setAttribute(\"ajaxify\", oa(nb.getAttribute(\"ajaxify\")).addQueryData({\n                    id: ob\n                }));\n            };\n        }\n    ;\n        o.removeEmptyHrefs(this._tabElem);\n        ya[ib] = this;\n        this.updateAvailableStatus();\n        this.updateTab();\n    };\n    function hb() {\n        for (var ib in ya) {\n            ya[ib].updateAvailableStatus();\n            ya[ib].updateMultichatTooltip();\n        };\n    };\n    g.subscribe([\"buddylist/availability-changed\",], hb);\n    ja.subscribe([\"privacy-changed\",\"privacy-availability-changed\",], hb);\n    ga.subscribe(\"state-changed\", function(ib, jb) {\n        for (var kb in jb) {\n            var lb = (jb[kb] && jb[kb].length), mb = ya[kb];\n            (mb && mb.showTypingIndicator(lb));\n        };\n    });\n    da.subscribe(\"threads-updated\", function(ib, jb) {\n        for (var kb in ya) {\n            (jb[kb] && ya[kb].updateTab());;\n        };\n    });\n    da.subscribe(\"threads-deleted\", function(ib, jb) {\n        for (var kb in ya) {\n            gb.inform(\"thread-deleted\", kb);;\n        };\n    });\n    ua(gb, h, {\n        get: function(ib) {\n            return ya[ib];\n        }\n    });\n    ua(gb.prototype, {\n        getThreadID: function() {\n            return this._threadID;\n        },\n        isVisible: function() {\n            return u.shown(this._tabElem);\n        },\n        setVisibleState: function(ib, jb) {\n            var kb = u.shown(this._tabElem), lb = u.hasClass(this._tabElem, \"opened\");\n            u.conditionShow(this._tabElem, ib);\n            u.conditionClass(this._tabElem, \"opened\", jb);\n            if (((!((kb && lb)) && ib) && jb)) {\n                if (!this._messagesView) {\n                    this._messagesView = new r(this._threadID, this._getNode(\"chatConv\"), this._getNode(\"conversation\"), this._getNode(\"typingIndicator\"));\n                };\n                this._nubController.flyoutContentChanged();\n                this._messagesView.scrollToBottom();\n            }\n        ;\n            if (((kb && lb) && !((ib && jb)))) {\n                this._contextualDialogController.tabNotActive();\n            };\n        },\n        focus: function() {\n            var ib = (u.hasClass(this._tabElem, \"opened\") ? \"input\" : \"dockButton\");\n            this._getNode(ib).focus();\n        },\n        isFocused: function() {\n            var ib = document.activeElement;\n            return (ia.byClass(ib, \"fbMercuryChatTab\") === this._tabElem);\n        },\n        setInput: function(ib) {\n            this._getNode(\"input\").value = ib;\n        },\n        insertBefore: function(ib) {\n            x.insertBefore(ib._tabElem, this._tabElem);\n        },\n        appendTo: function(ib) {\n            x.appendContent(ib, this._tabElem);\n        },\n        nextTabIs: function(ib) {\n            var jb = (ib && ib._tabElem);\n            return (this._tabElem.nextSibling == jb);\n        },\n        destroy: function() {\n            x.remove(this._tabElem);\n            (this._emoticonView && this._emoticonView.destroy());\n            while (this._eventListeners.length) {\n                this._eventListeners.pop().remove();;\n            };\n            (this._messagesView && this._messagesView.destroy());\n            this._sheetController.destroy();\n            this._contextualDialogController.destroy();\n            (this._privacyActionController && this._privacyActionController.destroy());\n            delete ya[this._threadID];\n            w.unregisterNubController(this._nubController);\n        },\n        updateAvailableStatus: function() {\n            var ib = {\n                active: false,\n                mobile: false,\n                greenphone: false\n            }, jb = this._getCanonicalUserID(), kb = true, lb = false;\n            if (jb) {\n                var mb = k.get(jb);\n                kb = !t.isOnline();\n                lb = !ja.allows(jb);\n                ib.active = ((mb === l.ACTIVE));\n                if (m.get(\"sidebar_mobile_icon_green\")) {\n                    ib.greenphone = (mb === l.MOBILE);\n                }\n                 else ib.mobile = (mb === l.MOBILE);\n            ;\n                this._updateCallLink(mb);\n            }\n        ;\n            u.conditionClass(this._tabElem, \"chatOffline\", kb);\n            u.conditionClass(this._tabElem, \"blocked\", (!kb && lb));\n            for (var nb in ib) {\n                u.conditionClass(this._tabElem, nb, ((!kb && !lb) && ib[nb]));;\n            };\n        },\n        updateTab: function() {\n            fa.getThreadMeta(this._threadID, function(ib) {\n                if (!ib.is_subscribed) {\n                    gb.inform(\"unsubscribed\", this._threadID);\n                    return;\n                }\n            ;\n                ea.renderAndSeparatedParticipantList(this._threadID, [this._getNode(\"name\"),this._getNode(\"titlebarText\"),], {\n                    names_renderer: ea.renderShortNames,\n                    check_length: true\n                });\n                this._updateUnreadCount(ib);\n                this.updateMultichatTooltip();\n                this._updateArchiveWarning(ib);\n            }.bind(this));\n        },\n        _updateArchiveWarning: function(ib) {\n            var jb = false;\n            ba.get(ba.user, function(kb) {\n                jb = kb.employee;\n                if (jb) {\n                    ba.getMulti(ib.participants, this._showArchiveWarningIfAllParticipantsAreEmployees.bind(this));\n                };\n            }.bind(this));\n        },\n        _showArchiveWarningIfAllParticipantsAreEmployees: function(ib) {\n            var jb = true;\n            for (var kb in ib) {\n                jb = (jb && ib[kb].employee);;\n            };\n            var lb = this._getNode(\"titanArchiveWarning\");\n            if (lb) {\n                if (this._titlebarTooltipAnchor) {\n                    u.conditionClass(this._titlebarTooltipAnchor, \"narrowTitleBar\", jb);\n                };\n                u.conditionShow(lb, jb);\n            }\n        ;\n        },\n        updateMultichatTooltip: function() {\n            if (fa.isMultichatThread(this._threadID)) {\n                fa.getThreadMeta(this._threadID, function(ib) {\n                    za(this._titlebarTooltipAnchor, ib.participants);\n                }.bind(this));\n            };\n        },\n        _getNode: function(ib) {\n            return this._tabTemplate.getNode(ib);\n        },\n        _getCanonicalUserID: function() {\n            return fa.getCanonicalUserInThread(this._threadID);\n        },\n        _listen: function(ib, event, jb, kb) {\n            var lb = this._getNode(ib);\n            if (lb) {\n                this._eventListeners.push(Event.listen(lb, event, jb.bind(this)));\n            }\n             else if (!kb) {\n                throw new Error(((\"Could not find node \\\"\" + ib) + \"\\\"\"))\n            }\n        ;\n        },\n        _closeClicked: function(ib) {\n            gb.inform(\"closed-tab\", this._threadID);\n            ib.prevent();\n        },\n        _nubClicked: function() {\n            return gb.inform(\"nub-activated\", this._threadID);\n        },\n        _dockKeyDown: function(event) {\n            if (((event.keyCode === z.RETURN) || (event.keyCode === z.SPACE))) {\n                gb.inform(\"nub-activated\", this._threadID);\n                event.kill();\n            }\n             else this._handleHotkeyPressed(event);\n        ;\n        },\n        _handleHotkeyPressed: function(event) {\n            if ((event.keyCode === z.ESC)) {\n                gb.inform(\"esc-pressed\", this._threadID);\n                event.kill();\n            }\n             else if ((event.keyCode === z.TAB)) {\n                var ib = gb.inform(\"tab-pressed\", {\n                    id: this._threadID,\n                    shiftPressed: event.shiftKey\n                });\n                (!ib && event.kill());\n            }\n            \n        ;\n        },\n        _isTitleTextLinked: function() {\n            var ib = this._getCanonicalUserID();\n            return (ib && m.get(\"chat_tab_title_link_timeline\"));\n        },\n        _titleClicked: function(event) {\n            var ib = event.getTarget(), jb = ia.byClass(ib, \"titlebarText\"), kb = (jb && this._isTitleTextLinked());\n            if (((!kb && !ia.byClass(ib, \"uiSelector\")) && !ia.byClass(ib, \"addToThread\"))) {\n                gb.inform(\"lower-activated\", this._threadID);\n            };\n        },\n        _callClicked: function(ib) {\n            var jb = this._getCanonicalUserID();\n            if (qa.availableForCall(jb)) {\n                var kb = \"chat_tab_icon\";\n                if ((ib.target && u.hasClass(ib.target, \"video_call_promo\"))) {\n                    kb = \"chat_tab_icon_promo\";\n                }\n                 else if ((ib.target && u.hasClass(ib.target, \"video_call_tour\"))) {\n                    kb = \"chat_tab_icon_tour\";\n                }\n            ;\n                gb.inform(\"video-call-clicked\", {\n                    threadID: this._threadID,\n                    userID: jb,\n                    clickSource: kb\n                });\n            }\n        ;\n            return false;\n        },\n        _addFriendLinkClicked: function() {\n            this._sheetController.openAddFriendsSheet();\n        },\n        _clearHistory: function() {\n            var ib = fa.getThreadMetaNow(this._threadID);\n            if (ib) {\n                var jb = this._getCanonicalUserID();\n                ca.clearChat(this._threadID, jb, ib.timestamp);\n            }\n        ;\n        },\n        _unsubscribeLinkClicked: function() {\n            var ib = [];\n            ib.push({\n                name: \"unsubscribe\",\n                label: \"Leave Conversation\",\n                handler: this._unsubscribeToThread.bind(this)\n            });\n            ib.push(v.CANCEL);\n            new v().setTitle(\"Leave Conversation?\").setBody(\"You will stop receiving messages from this conversation and people will see that you left.\").setButtons(ib).show();\n        },\n        _reportSpamClicked: function() {\n            var ib = this._getCanonicalUserID(), jb = oa(\"/ajax/chat/report.php\").addQueryData({\n                id: ib\n            }).addQueryData({\n                src: \"top_report_link\"\n            });\n            i.send(new j(jb));\n        },\n        _focusTab: function() {\n            u.addClass(this._tabElem, \"focusedTab\");\n            gb.inform(\"focused\", this._threadID);\n            this._contextualDialogController.tabFocused();\n        },\n        _blurTab: function() {\n            u.removeClass(this._tabElem, \"focusedTab\");\n        },\n        _inputKeyDown: function(event) {\n            if (((event.keyCode === z.RETURN) && !event.shiftKey)) {\n                var ib = this._getNode(\"input\"), jb = (ib.value || \"\");\n                if (!/^\\s*$/.test(jb)) {\n                    fa.getThreadMeta(this._threadID, function(kb) {\n                        var lb = aa.constructUserGeneratedMessageObject(jb, sa.MercurySourceType.CHAT_WEB, this._threadID);\n                        if (fa.isEmptyLocalThread(this._threadID)) {\n                            var mb = ca.tokenizeThreadID(this._threadID);\n                            lb.message_id = mb.value;\n                            lb.specific_to_list = kb.participants;\n                        }\n                    ;\n                        aa.sendMessage(lb);\n                        this._getNode(\"input\").value = \"\";\n                        (this._typingIndicator && this._typingIndicator.resetState());\n                    }.bind(this));\n                };\n                event.kill();\n            }\n        ;\n            if ((((event.keyCode === z.DOWN) && event.shiftKey) && (this._getNode(\"input\").value === \"\"))) {\n                gb.inform(\"lower-activated\", this._threadID);\n                event.kill();\n                return;\n            }\n        ;\n            this._handleHotkeyPressed(event);\n        },\n        _chatConvClicked: function() {\n            (!x.getSelection() && this.focus());\n        },\n        showTypingIndicator: function(ib) {\n            var jb = (this._getCanonicalUserID() || ((m.get(\"chat_multi_typ\") && fa.isMultichatThread(this._threadID))));\n            if (jb) {\n                u.conditionClass(this._tabElem, \"typing\", ib);\n            };\n        },\n        _updateUnreadCount: function(ib) {\n            var jb = ib.unread_count;\n            if ((typeof jb != \"undefined\")) {\n                var kb = this._getNode(\"numMessages\");\n                u.conditionShow(kb, jb);\n                u.conditionClass(this._tabElem, \"highlightTab\", jb);\n                db(this._threadID, this._tabElem, !!jb);\n                x.setContent(kb, jb);\n            }\n        ;\n        },\n        _updateCallLink: function(ib) {\n            var jb = this._getNode(\"videoCallLink\");\n            if (t.isOnline()) {\n                var kb = this._getCanonicalUserID(), lb = (\"fbid:\" + kb);\n                ba.get(lb, function(mb) {\n                    if (qa.availableForCall(kb)) {\n                        ma.set(jb, wa._(\"Start a video call with {firstname}\", {\n                            firstname: mb.short_name\n                        }));\n                        this._updateCallBackLinks(this._tabElem, true);\n                    }\n                     else {\n                        ma.set(jb, wa._(\"{firstname} is currently unavailable for video calling\", {\n                            firstname: mb.short_name\n                        }));\n                        this._hideVideoCallouts();\n                        this._updateCallBackLinks(this._tabElem, false);\n                    }\n                ;\n                }.bind(this));\n            }\n             else {\n                ma.set(jb, \"You must be online to make a call.\");\n                this._hideVideoCallouts();\n                this._updateCallBackLinks(document.body, false);\n            }\n        ;\n        },\n        _updateCallBackLinks: function(ib, jb) {\n            var kb = x.scry(ib, \"a.callBackLink\");\n            if (jb) {\n                kb.forEach(u.show);\n            }\n             else kb.forEach(u.hide);\n        ;\n        },\n        _hideVideoCallouts: function() {\n            this._contextualDialogController.hideVideoCallouts();\n        },\n        _updatePrivacyLink: function(ib) {\n            if ((ib == p.OFFLINE)) {\n                x.setContent(this._privacyLink, \"Go online\");\n            }\n             else {\n                var jb = this._getCanonicalUserID(), kb = (\"fbid:\" + jb);\n                ba.get(kb, function(lb) {\n                    var mb = null;\n                    if ((ib == p.BLOCKED)) {\n                        if (ra.ChatControlLanguageChangeGK) {\n                            mb = wa._(\"Turn On Chat for {name}\", {\n                                name: lb.short_name\n                            });\n                        }\n                         else mb = wa._(\"Go Online to {name}\", {\n                            name: lb.short_name\n                        });\n                    ;\n                    }\n                     else if (ra.ChatControlLanguageChangeGK) {\n                        mb = wa._(\"Turn Off Chat for {name}\", {\n                            name: lb.short_name\n                        });\n                    }\n                     else mb = wa._(\"Go Offline to {name}\", {\n                        name: lb.short_name\n                    });\n                    \n                ;\n                    x.setContent(this._privacyLink, mb);\n                }.bind(this));\n            }\n        ;\n        },\n        _unsubscribeToThread: function() {\n            if (fa.isEmptyLocalThread(this._threadID)) {\n                gb.inform(\"unsubscribed\", this._threadID);\n            }\n             else {\n                var ib = aa.constructLogMessageObject(sa.MercurySourceType.CHAT_WEB, this._threadID, sa.MercuryLogMessageType.UNSUBSCRIBE, {\n                });\n                aa.sendMessage(ib);\n            }\n        ;\n            return true;\n        },\n        _emoticonView: null\n    });\n    e.exports = gb;\n});\n__d(\"ChatNewMessageHandler\", [\"ChatActivity\",\"ChatTabModel\",\"ChatTabView\",\"JSLogger\",\"MercuryAssert\",\"MercuryBrowserAlerts\",\"MercuryThreads\",\"MercuryUnseenState\",], function(a, b, c, d, e, f) {\n    var g = b(\"ChatActivity\"), h = b(\"ChatTabModel\"), i = b(\"ChatTabView\"), j = b(\"JSLogger\"), k = b(\"MercuryAssert\"), l = b(\"MercuryBrowserAlerts\"), m = b(\"MercuryThreads\"), n = b(\"MercuryUnseenState\"), o = j.create(\"chat_new_message\"), p = {\n        _raiseTab: function(q, r) {\n            var s = h.getTab(q), t = false;\n            if (s) {\n                t = s.raised;\n            }\n             else {\n                h.raiseTab(q, false);\n                t = true;\n            }\n        ;\n            r.to_new_tab = !s;\n            r.to_raised_tab = !!t;\n        },\n        _notify: function(q, r, s) {\n            var t = i.get(q);\n            s.view_is_visible = (t && t.isVisible());\n            s.view_is_focused = (t && t.isFocused());\n            if (!s.view_is_visible) {\n                o.log(\"message_to_hidden\");\n            };\n            s.is_active = g.isActive();\n            l.messageReceived(r);\n        },\n        newMessage: function(q, r) {\n            k.isThreadID(q);\n            var s = {\n                thread_id: q,\n                message_id: r.message_id\n            };\n            this._raiseTab(q, s);\n            this._notify(q, r, s);\n            o.log(\"message\", s);\n        }\n    };\n    l.subscribe(\"before-alert\", function(q, event) {\n        var r = event.threadID, s = i.get(r), t = h.getTab(r);\n        if (((((t && t.raised) && s) && s.isVisible()) && s.isFocused())) {\n            m.changeThreadReadStatus(r, true);\n            n.markThreadSeen(r);\n            event.cancelAlert();\n        }\n    ;\n    });\n    e.exports = p;\n});\n__d(\"ChatTabPresence\", [\"Arbiter\",\"AvailableList\",\"ChatTabModel\",\"MercuryThreads\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AvailableList\"), i = b(\"ChatTabModel\"), j = b(\"MercuryThreads\"), k = {\n    };\n    function l(m) {\n        var n = j.getCanonicalUserInThread(m);\n        if (n) {\n            h.updateForID(n);\n        };\n    };\n    i.subscribe(\"chat/tabs-changed\", function(event, m) {\n        m.tabs.forEach(function(n) {\n            if ((n.raised && !k[n.id])) {\n                l(n.id);\n            };\n        });\n        k = {\n        };\n        m.tabs.forEach(function(n) {\n            if (n.raised) {\n                k[n.id] = true;\n            };\n        });\n    });\n    e.exports = {\n    };\n});\n__d(\"ChatTabPolicy\", [\"ChatBehavior\",\"ChatConfig\",\"FBDesktopPlugin\",\"JSLogger\",\"MercuryAssert\",\"MercuryParticipants\",\"MercuryThreads\",\"MercuryUnseenState\",\"PresencePrivacy\",\"ShortProfiles\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"ChatBehavior\"), h = b(\"ChatConfig\"), i = b(\"FBDesktopPlugin\"), j = b(\"JSLogger\"), k = b(\"MercuryAssert\"), l = b(\"MercuryParticipants\"), m = b(\"MercuryThreads\"), n = b(\"MercuryUnseenState\"), o = b(\"PresencePrivacy\"), p = b(\"ShortProfiles\"), q = c(\"MercuryConstants\"), r = j.create(\"tab_policy\");\n    function s(t, u) {\n        n.markThreadSeen(t, u);\n    };\n    e.exports = {\n        messageIsAllowed: function(t, u, v) {\n            var w = t.thread_id, x = u.message_id;\n            k.isThreadID(w);\n            k.isParticipantID(u.author);\n            var y;\n            if ((t.mode == q.MercuryThreadMode.OBJECT_ORIGINATED)) {\n                y = {\n                    thread_id: w,\n                    message_id: x,\n                    mode: t.mode\n                };\n                r.log(\"message_object_originated\", y);\n                return;\n            }\n        ;\n            var z = q.MercurySourceType;\n            if (((u.source == z.EMAIL) || (u.source == z.TITAN_EMAIL_REPLY))) {\n                y = {\n                    thread_id: w,\n                    message_id: x,\n                    source: u.source\n                };\n                r.log(\"message_source_not_allowed\", y);\n                return;\n            }\n        ;\n            var aa = l.getUserID(u.author);\n            if (!aa) {\n                r.log(\"message_bad_author\", {\n                    thread_id: w,\n                    message_id: x,\n                    user: aa\n                });\n                return;\n            }\n        ;\n            if ((u.action_type != q.MercuryActionType.USER_GENERATED_MESSAGE)) {\n                y = {\n                    thread_id: w,\n                    message_id: x,\n                    type: u.action_type\n                };\n                r.log(\"message_non_user_generated\", y);\n                return;\n            }\n        ;\n            if ((t.is_canonical_user && !g.notifiesUserMessages())) {\n                r.log(\"message_jabber\", {\n                    thread_id: w,\n                    message_id: x\n                });\n                s(w, true);\n                return;\n            }\n        ;\n            if (i.shouldSuppressMessages()) {\n                r.log(\"message_desktop\", {\n                    thread_id: w,\n                    message_id: x\n                });\n                return;\n            }\n        ;\n            if ((!t.is_canonical_group && (t.folder != q.MessagingTag.INBOX))) {\n                r.log(\"message_folder\", {\n                    thread_id: w,\n                    message_id: x,\n                    folder: t.folder\n                });\n                return;\n            }\n        ;\n            p.get(aa, function(ba) {\n                if (!o.allows(aa)) {\n                    r.log(\"message_privacy\", {\n                        thread_id: w,\n                        message_id: x,\n                        user: aa\n                    });\n                    return;\n                }\n            ;\n                if (!t.is_canonical_group) {\n                    if ((ba.type != \"friend\")) {\n                        r.log(\"message_non_friend\", {\n                            thread_id: w,\n                            message_id: x,\n                            user: aa\n                        });\n                        return;\n                    }\n                \n                };\n                v();\n            });\n        }\n    };\n});\n__d(\"ChatTabViewSelector\", [\"Arbiter\",\"copyProperties\",\"CSS\",\"DataStore\",\"DOM\",\"Menu\",\"MercuryThreadInformer\",\"MercuryThreads\",\"NubController\",\"MercuryThreadMetadataRenderer\",\"Toggler\",\"ChatTabTemplates\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"copyProperties\"), i = b(\"CSS\"), j = b(\"DataStore\"), k = b(\"DOM\"), l = b(\"Menu\"), m = b(\"MercuryThreadInformer\"), n = b(\"MercuryThreads\"), o = b(\"NubController\"), p = b(\"MercuryThreadMetadataRenderer\"), q = b(\"Toggler\"), r = c(\"ChatTabTemplates\");\n    function s(t) {\n        var u = r[\":fb:chat:tab:selector\"].build(), v = u.getRoot(), w = u.getNode(\"menu\"), x = k.find(w, \".uiMenuInner\"), y = {\n        }, z = new o().init(v);\n        i.hide(v);\n        k.insertBefore(t, v);\n        function aa(da) {\n            var ea = 0;\n            for (var fa in y) {\n                var ga = y[fa], ha = n.getThreadMetaNow(fa), ia = ga.getNode(\"unreadCount\"), ja = (((ha && ha.unread_count)) || 0);\n                ea += ja;\n                if ((ja > 9)) {\n                    ja = \"+\";\n                };\n                i.conditionClass(ia, \"invisible_elem\", !ja);\n                k.setContent(ia, ja);\n            };\n            var ka = u.getNode(\"numMessages\");\n            i.conditionShow(ka, ea);\n            k.setContent(ka, ea);\n        };\n        this.setTabData = function(da) {\n            y = {\n            };\n            if ((da.length < 1)) {\n                i.hide(v);\n                return;\n            }\n        ;\n            i.show(v);\n            k.empty(x);\n            da.forEach(function(ea) {\n                var fa = r[\":fb:chat:tab:selector:item\"].build();\n                y[ea.id] = fa;\n                var ga = fa.getNode(\"content\");\n                p.renderAndSeparatedParticipantList(ea.id, ga);\n                k.prependContent(x, fa.getRoot());\n                j.set(fa.getRoot(), \"threadID\", ea.id);\n            });\n            z.flyoutContentChanged();\n            k.setContent(u.getNode(\"numTabs\"), da.length);\n            aa();\n        };\n        function ba(event, da) {\n            if ((da.menu != w)) {\n                return\n            };\n            var ea = j.get(da.item, \"threadID\");\n            s.inform(\"selected\", ea);\n            q.hide(v);\n        };\n        function ca(event, da) {\n            l.register(w);\n        };\n        l.subscribe(\"select\", ba.bind(this));\n        q.listen(\"show\", v, function() {\n            g.inform(\"layer_shown\", {\n                type: \"ChatTabSelector\"\n            });\n            ca();\n        });\n        q.listen(\"hide\", v, function() {\n            g.inform(\"layer_hidden\", {\n                type: \"ChatTabSelector\"\n            });\n        });\n        m.subscribe(\"threads-updated\", aa);\n    };\n    h(s, new g());\n    e.exports = s;\n});\n__d(\"ChatTabController\", [\"ChatTabPresence\",\"Arbiter\",\"AsyncRequest\",\"ChatActivity\",\"ChatConfig\",\"ChatNewMessageHandler\",\"ChatTabMessagesView\",\"ChatTabModel\",\"ChatTabPolicy\",\"ChatTabView\",\"ChatTabViewSelector\",\"ChatTitleBarBlinker\",\"Dialog\",\"JSLogger\",\"MercuryMessages\",\"MercuryParticipants\",\"MercuryServerRequests\",\"MercuryThreadInformer\",\"MercuryThreads\",\"MercuryUnseenState\",\"Style\",\"UserAgent\",\"VideoCallCore\",], function(a, b, c, d, e, f) {\n    b(\"ChatTabPresence\");\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"ChatActivity\"), j = b(\"ChatConfig\"), k = b(\"ChatNewMessageHandler\"), l = b(\"ChatTabMessagesView\"), m = b(\"ChatTabModel\"), n = b(\"ChatTabPolicy\"), o = b(\"ChatTabView\"), p = b(\"ChatTabViewSelector\"), q = b(\"ChatTitleBarBlinker\"), r = b(\"Dialog\"), s = b(\"JSLogger\"), t = b(\"MercuryMessages\"), u = b(\"MercuryParticipants\"), v = b(\"MercuryServerRequests\"), w = b(\"MercuryThreadInformer\"), x = b(\"MercuryThreads\"), y = b(\"MercuryUnseenState\"), z = b(\"Style\"), aa = b(\"UserAgent\"), ba = b(\"VideoCallCore\"), ca = (j.get(\"tab_auto_close_timeout\") || 7200000), da = s.create(\"tab_controller\");\n    function ea(pa) {\n        x.changeThreadReadStatus(pa, true);\n        fa(pa);\n    };\n    function fa(pa) {\n        y.markThreadSeen(pa);\n    };\n    function ga() {\n        var pa = m.get();\n        pa.tabs.forEach(function(qa) {\n            var ra = o.get(qa.id);\n            if (((qa.raised && ra) && ra.isVisible())) {\n                ea(qa.id);\n            };\n        });\n    };\n    function ha() {\n        var pa = m.get();\n        pa.tabs.forEach(function(qa) {\n            fa(qa.id);\n        });\n    };\n    function ia(pa, qa, ra) {\n        var sa = m.get().tabs;\n        pa += (qa ? 1 : -1);\n        while (((pa >= 0) && (pa < sa.length))) {\n            var ta = sa[pa], ua = o.get(ta.id);\n            if (((ua && ua.isVisible()) && ((!ra || ta.raised)))) {\n                ua.focus();\n                return true;\n            }\n        ;\n            pa += (qa ? 1 : -1);\n        };\n        return false;\n    };\n    function ja(pa) {\n        function qa(ta) {\n            var ua = pa.shouldPromoteOnRaise(ta);\n            g.inform(\"chat/promote-tab\", ta);\n            if (ua) {\n                m.raiseAndPromoteTab(ta, true);\n            }\n             else m.raiseTab(ta, true);\n        ;\n            var va = o.get(ta);\n            (va && va.focus());\n        };\n        function ra(ta, ua) {\n            var va = m.get(), wa = pa.getMaxTabsToShow(), xa = m.indexOf(ta);\n            m.closeTabAndDemote(ta, (wa - 2), ua);\n            return xa;\n        };\n        p.subscribe(\"selected\", function(ta, ua) {\n            qa(ua);\n        });\n        g.subscribe(\"chat/open-tab\", function(ta, ua) {\n            qa(ua.thread_id);\n        });\n        g.subscribe(\"page_transition\", function(ta, ua) {\n            m.closeFragileTabs();\n        });\n        v.subscribe(\"model-update-completed\", ha);\n        o.subscribe(\"focused\", function(event, ta) {\n            ea(ta);\n        });\n        i.subscribe(\"idle\", function(ta, ua) {\n            if ((ua > ca)) {\n                var va = m.get().tabs;\n                va.forEach(function(wa) {\n                    var xa = wa.id;\n                    x.getThreadMeta(xa, function(ya) {\n                        if (!ya.unread_count) {\n                            da.log(\"autoclose_idle_seen\", {\n                                thread_id: xa,\n                                idleness: ua\n                            });\n                            m.closeTab(xa, \"autoclose_idle_seen\");\n                        }\n                    ;\n                    });\n                });\n            }\n        ;\n        });\n        o.subscribe(\"nub-activated\", function(ta, ua) {\n            qa(ua);\n        });\n        o.subscribe(\"lower-activated\", function(ta, ua) {\n            m.lowerTab(ua);\n            var va = o.get(ua);\n            (va && va.focus());\n            ea(ua);\n        });\n        function sa(ta, ua) {\n            ba.showOutgoingCallDialog(ua.userID, ua.clickSource);\n            m.lowerTab(ua.threadID);\n        };\n        o.subscribe(\"video-call-clicked\", sa);\n        l.subscribe(\"video-call-clicked\", sa);\n        o.subscribe(\"closed-tab\", function(ta, ua) {\n            da.log(\"close_view\", {\n                thread_id: ua\n            });\n            ra(ua, \"close_view\");\n            ea(ua);\n            return false;\n        });\n        o.subscribe(\"thread-deleted\", function(ta, ua) {\n            da.log(\"close_thread_deleted\", {\n                thread_id: ua\n            });\n            ra(ua, \"close_thread_deleted\");\n            return false;\n        });\n        o.subscribe(\"unsubscribed\", function(ta, ua) {\n            da.log(\"close_view_unsubscribed\", {\n                thread_id: ua\n            });\n            ra(ua, \"close_view_unsubscribed\");\n            return false;\n        });\n        o.subscribe(\"esc-pressed\", function(ta, ua) {\n            da.log(\"close_esc\", {\n                thread_id: ua\n            });\n            var va = ra(ua, \"close_esc\");\n            (ia((va - 1), true, true) || ia(va, false, true));\n        });\n        w.subscribe(\"messages-received\", function(ta, ua) {\n            for (var va in ua) {\n                var wa = ua[va];\n                for (var xa = 0; (xa < wa.length); xa++) {\n                    var ya = wa[xa];\n                    if ((ya.author != u.user)) {\n                        if (!ya.is_unread) {\n                            da.log(\"message_already_read\", {\n                                action_id: ya.action_id,\n                                thread_id: ya.thread_id\n                            });\n                            continue;\n                        }\n                    ;\n                        x.getThreadMeta(va, function(za) {\n                            n.messageIsAllowed(za, ya, function() {\n                                k.newMessage(va, ya);\n                            });\n                        });\n                    }\n                ;\n                };\n            };\n        });\n        w.subscribe(\"thread-read-changed\", function(ta, ua) {\n            for (var va in ua) {\n                if (!ua[va].mark_as_read) {\n                    da.log(\"autoclose_marked_unread\", {\n                        thread_id: va\n                    });\n                    m.closeTab(va, \"autoclose_marked_unread\");\n                }\n            ;\n            };\n        });\n        o.subscribe(\"tab-pressed\", function(ta, ua) {\n            return !ia(m.indexOf(ua.id), ua.shiftPressed);\n        });\n        g.subscribe(s.DUMP_EVENT, function(ta, ua) {\n            ua.chat_controller = {\n                auto_close_timeout: ca\n            };\n        });\n    };\n    if (aa.firefox()) {\n        var ka = function() {\n            return ((z.get(document.body, \"overflowX\") + \" \") + z.get(document.body, \"overflowY\"));\n        }, la = ka(), ma = function() {\n            var pa = ka();\n            if ((pa !== la)) {\n                la = pa;\n                g.inform(\"overflow-applied-to-body\");\n            }\n        ;\n        };\n        if ((\"MutationObserver\" in window)) {\n            var na = new MutationObserver(ma), oa = {\n                attributes: true,\n                attributeFilter: [\"class\",\"style\",]\n            };\n            na.observe(document.documentElement, oa);\n        }\n         else document.documentElement.addEventListener(\"DOMAttrModified\", function(event) {\n            if (((event.getTarget() === document.documentElement) && (((event.attrName === \"class\") || (event.attrName === \"style\"))))) {\n                ma();\n            };\n        }, false);\n    ;\n    }\n;\n    e.exports = ja;\n});\n__d(\"ChatTabViewCoordinator\", [\"Arbiter\",\"ChatConfig\",\"ChatTabModel\",\"ChatTabView\",\"ChatTabViewSelector\",\"CSS\",\"VideoCallCore\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ChatConfig\"), i = b(\"ChatTabModel\"), j = b(\"ChatTabView\"), k = b(\"ChatTabViewSelector\"), l = b(\"CSS\"), m = b(\"VideoCallCore\");\n    function n(o, p) {\n        var q = new k(o), r = {\n        }, s = false;\n        function t() {\n            var y = i.get(), z = {\n            };\n            y.tabs.forEach(function(ba) {\n                z[ba.id] = 1;\n            });\n            for (var aa in r) {\n                if (!z[aa]) {\n                    r[aa].destroy();\n                    delete (r[aa]);\n                }\n            ;\n            };\n            u(y);\n            v(y);\n        };\n        function u(y) {\n            var z = null;\n            y.tabs.forEach(function(aa) {\n                var ba = aa.id, ca = false;\n                if (!r[ba]) {\n                    r[ba] = new j(ba, aa.server_id);\n                    ca = true;\n                }\n            ;\n                if ((ca || !r[ba].nextTabIs(z))) {\n                    if (z) {\n                        r[ba].insertBefore(z);\n                    }\n                     else r[ba].appendTo(o);\n                \n                };\n                z = r[ba];\n            });\n        };\n        function v(y) {\n            var z = p.getTabsToShow(y), aa = [], ba = false;\n            y.tabs.forEach(function(ca) {\n                if (!z[ca.id]) {\n                    r[ca.id].setVisibleState(false, ca.raised);\n                    aa.push(ca);\n                }\n            ;\n            });\n            y.tabs.forEach(function(ca) {\n                if (z[ca.id]) {\n                    r[ca.id].setVisibleState(true, ca.raised);\n                    ba |= ca.raised;\n                }\n            ;\n            });\n            q.setTabData(aa);\n            x(ba);\n        };\n        function w(y) {\n            for (var z = 0, aa = y.tabs.length; (z < aa); z++) {\n                var ba = y.tabs[z];\n                if (ba.raised) {\n                    if (((ba.id === y.promoted) || (z < (p.getMaxTabsToShow() - 1)))) {\n                        return true\n                    }\n                };\n            };\n            return false;\n        };\n        function x(y) {\n            if ((!y && s)) {\n                g.inform(\"layer_hidden\", {\n                    type: \"ChatTab\"\n                });\n                s = false;\n            }\n             else if ((y && !s)) {\n                g.inform(\"layer_shown\", {\n                    type: \"ChatTab\"\n                });\n                s = true;\n            }\n            \n        ;\n        };\n        if (m.isSupported()) {\n            l.addClass(o, \"videoCallEnabled\");\n        };\n        p.subscribe(\"tabs-changed\", t);\n        t();\n    };\n    e.exports = n;\n});\n__d(\"TabsViewport\", [\"event-extensions\",\"ArbiterMixin\",\"ChatConfig\",\"ChatTabModel\",\"Class\",\"CSS\",\"Dock\",\"DOM\",\"Parent\",\"Vector\",\"areObjectsEqual\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"ChatConfig\"), i = b(\"ChatTabModel\"), j = b(\"Class\"), k = b(\"CSS\"), l = b(\"Dock\"), m = b(\"DOM\"), n = b(\"Parent\"), o = b(\"Vector\"), p = b(\"areObjectsEqual\"), q = b(\"copyProperties\");\n    function r(s) {\n        this._root = s;\n        Event.listen(window, \"resize\", this._recalculateWidth.bind(this));\n        l.subscribe(\"resize\", this._recalculateWidth.bind(this));\n        i.subscribe(\"chat/tabs-changed\", this._recalculateTabs.shield(this, true));\n        this._recalculateWidth();\n        this._initialized = true;\n    };\n    q(r.prototype, g, {\n        _root: null,\n        _initialized: false,\n        _availableWidth: 0,\n        _maxShown: 1,\n        _viewState: null,\n        _recalculateWidth: function() {\n            var s = r._getAvailableDockWidth(this._root), t = Math.max(1, Math.floor((s / 264))), u = (t != this._maxShown);\n            if ((((!this._viewState || u) || (s <= this._viewState.usedWidth)) || (s > this._viewState.widthToShowNext))) {\n                this._availableWidth = s;\n                this._maxShown = t;\n                this._viewState = null;\n                this._recalculateTabs(u);\n            }\n        ;\n        },\n        _onTabsChanged: function() {\n            if (this._initialized) {\n                this.inform(\"tabs-changed\");\n                this.inform(\"max-to-show-changed\", this._maxShown);\n                this.inform(\"max-to-show-change-completed\");\n            }\n        ;\n        },\n        _recalculateTabs: function(s) {\n            var t = r._getTabsToShow(i.get(), this._availableWidth);\n            if ((s || !p(this._viewState, t))) {\n                this._viewState = t;\n                this._onTabsChanged();\n            }\n        ;\n        },\n        getMaxTabsToShow: function() {\n            return this._maxShown;\n        },\n        checkWidth: function() {\n            this._recalculateWidth();\n        },\n        getTabsToShow: function() {\n            return JSON.parse(JSON.stringify(this._viewState.tabsToShow));\n        },\n        shouldPromoteOnRaise: function(s) {\n            if (!this._viewState.tabsToShow[s]) {\n                return true\n            };\n            if ((this._viewState.nextToHide != s)) {\n                return false\n            };\n            var t = i.getTab(s), u = (t && t.raised);\n            return (!u && (((this._availableWidth - this._viewState.usedWidth) < 100)));\n        }\n    });\n    q(r, {\n        _getAvailableDockWidth: function(s) {\n            var t = o.getViewportDimensions().x;\n            t -= 230;\n            t -= 50;\n            var u = n.byClass(s, \"fbDock\"), v = o.getElementDimensions(u), w = n.byClass(s, \"fbDockChat\"), x = o.getElementDimensions(w), y = (v.x - x.x);\n            t -= y;\n            t -= 20;\n            return Math.max(t, 0);\n        },\n        _getTabsToShow: function(s, t) {\n            var u = 164, v = 264;\n            t = Math.max(t, (v + 1));\n            function w(la) {\n                return (la.raised ? v : u);\n            };\n            var x = JSON.parse(JSON.stringify(s.tabs)), y = -1, z = null;\n            if (s.promoted) {\n                x.forEach(function(la, ma) {\n                    if ((la.id === s.promoted)) {\n                        y = ma;\n                        z = la;\n                    }\n                ;\n                });\n            };\n            var aa = 0, ba = 0, ca = !z;\n            x.forEach(function(la, ma) {\n                var na = w(la);\n                la.leftmostOffset = (aa + v);\n                aa += na;\n                if ((la.leftmostOffset < t)) {\n                    ba++;\n                };\n                ca |= (ma == y);\n                la.alreadyPlacedPromoted = ca;\n            });\n            function da(la, ma, na) {\n                var oa = {\n                };\n                for (var pa = 0; (pa < ma); pa++) {\n                    var qa = la[pa];\n                    if ((!qa.alreadyPlacedPromoted && (pa == (ma - 1)))) {\n                        oa[na] = true;\n                    }\n                     else oa[qa.id] = true;\n                ;\n                };\n                return oa;\n            };\n            var ea = da(x, ba, s.promoted), fa = da(x, (ba - 1), s.promoted), ga = null;\n            for (var ha in ea) {\n                if (!fa[ha]) {\n                    ga = ha;\n                };\n            };\n            var ia = x[(ba - 1)], ja = (ia ? ia.leftmostOffset : 0), ka = Infinity;\n            if ((ba < x.length)) {\n                ka = x[ba].leftmostOffset;\n            };\n            return {\n                nextToHide: ga,\n                tabsToShow: ea,\n                usedWidth: ja,\n                widthToShowNext: ka\n            };\n        }\n    });\n    e.exports = r;\n});\n__d(\"MercuryChannelHandler\", [\"Arbiter\",\"ChannelConstants\",\"copyProperties\",\"Env\",\"MessagingReliabilityLogger\",\"MercuryParticipants\",\"PresenceUtil\",\"MercuryServerRequests\",\"MercuryThreadInformer\",\"MercuryThreads\",\"MercuryConstants\",\"MercuryConfig\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ChannelConstants\"), i = b(\"copyProperties\"), j = b(\"Env\"), k = b(\"MessagingReliabilityLogger\"), l = b(\"MercuryParticipants\"), m = b(\"PresenceUtil\"), n = b(\"MercuryServerRequests\"), o = b(\"MercuryThreadInformer\"), p = b(\"MercuryThreads\"), q = c(\"MercuryConstants\"), r = c(\"MercuryConfig\");\n    function s(ia, ja) {\n        var ka = ja.obj.to;\n        p.getCanonicalThreadToGroup(ka, function(la) {\n            var ma = la.thread_id;\n            n.getServerThreadID(ma, function(na) {\n                var oa = ba(ka, ja.obj.from, ja.obj.msg.time), pa = (ja.obj.from != j.user), qa = Date.format((r[\"24h_times\"] ? \"H:i\" : \"g:ia\"), Math.floor((ja.obj.msg.time / 1000))), ra = new Date(ja.obj.msg.time).toLocaleDateString(), sa = {\n                    obj: {\n                        message: {\n                            action_id: null,\n                            body: ja.obj.msg.text,\n                            is_unread: pa,\n                            mid: oa,\n                            mercury_author_id: (\"fbid:\" + ja.obj.from),\n                            mercury_author_email: null,\n                            mercury_coordinates: null,\n                            mercury_spoof_warning: false,\n                            mercury_source: q.MercurySourceType.CHAT_WEB,\n                            mercury_source_tags: [q.MercuryMessageSourceTags.CHAT,],\n                            sender_fbid: ja.obj.from,\n                            tid: na,\n                            timestamp: ja.obj.msg.time,\n                            timestamp_absolute: ra,\n                            timestamp_relative: qa,\n                            threading_id: ja.obj.sync_id\n                        },\n                        folder: \"group_chat\"\n                    }\n                };\n                t(h.getArbiterType(\"messaging\"), sa);\n            });\n        });\n    };\n    function t(ia, ja) {\n        if ((((ia != h.getArbiterType(\"messaging\")) || !ja.obj) || !ja.obj.message)) {\n            k.addEntry(\"channel_receive\", \"invalid_data\");\n            return;\n        }\n    ;\n        var ka = ja.obj.message, la = {\n            author: ka.mercury_author_id,\n            author_email: ka.mercury_author_email,\n            body: ka.body,\n            subject: ka.subject,\n            has_attachment: ka.has_attachment,\n            attachments: ka.attachments,\n            html_body: ka.html_body,\n            thread_id: ka.tid,\n            message_id: ka.mid,\n            coordinates: ka.mercury_coordinates,\n            spoof_warning: ka.mercury_spoof_warning,\n            source: ka.mercury_source,\n            source_tags: ka.mercury_source_tags,\n            threading_id: ka.threading_id,\n            timestamp: ka.timestamp,\n            timestamp_absolute: ka.timestamp_absolute,\n            timestamp_relative: ka.timestamp_relative,\n            action_type: q.MercuryActionType.USER_GENERATED_MESSAGE,\n            is_unread: ka.is_unread,\n            action_id: ka.action_id,\n            is_forward: false,\n            forward_count: (ka.forward_count || ka.forward),\n            forward_message_ids: ka.forward_msg_ids,\n            location_text: ka.location_text,\n            folder: ja.obj.folder\n        }, ma = [i({\n        }, la),];\n        ma = ma.concat((ka.forward_actions || []));\n        var na = q.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE;\n        n.handleUpdateWaitForThread({\n            actions: ma,\n            payload_source: na\n        }, ka.tid);\n        if ((!ka.is_unread && (ka.mercury_author_id === l.user))) {\n            var oa = {\n            };\n            oa[ka.tid] = ja.obj.folder;\n            u(h.getArbiterType(\"messaging\"), {\n                obj: {\n                    event: q.MessagingEventTypes.READ,\n                    tids: [ka.tid,],\n                    folder_info: oa\n                }\n            });\n        }\n    ;\n        k.addEntry(\"channel_receive\", \"success\", [la.thread_id,la.message_id,m.getSessionID(),]);\n    };\n    function u(ia, ja) {\n        if ((((ia != h.getArbiterType(\"messaging\")) || !ja.obj) || !ja.obj.tids)) {\n            return\n        };\n        var ka = [], la = (ja.obj.event == q.MessagingEventTypes.READ);\n        ja.obj.tids.forEach(function(ma) {\n            ka.push({\n                action_type: q.MercuryActionType.CHANGE_READ_STATUS,\n                action_id: null,\n                thread_id: ma,\n                mark_as_read: la,\n                timestamp: (ja.obj.timestamp || 0),\n                folder: ja.obj.folder_info[ma]\n            });\n        });\n        n.handleUpdate({\n            actions: ka,\n            payload_source: q.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE\n        });\n    };\n    function v(ia, ja) {\n        if ((((ia != h.getArbiterType(\"messaging\")) || !ja.obj) || !ja.obj.tids)) {\n            return\n        };\n        var ka = [];\n        ja.obj.tids.forEach(function(la) {\n            ka.push({\n                action_type: q.MercuryActionType.DELETE_THREAD,\n                action_id: null,\n                thread_id: la\n            });\n        });\n        n.handleUpdate({\n            actions: ka,\n            payload_source: q.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE\n        });\n    };\n    function w(ia, ja) {\n        if (((((ia != h.getArbiterType(\"messaging\")) || !ja.obj) || !ja.obj.tids) || !ja.obj.mids)) {\n            return\n        };\n        var ka = ja.obj.tids[0], la = {\n            action_type: q.MercuryActionType.DELETE_MESSAGES,\n            action_id: null,\n            thread_id: ka,\n            message_ids: ja.obj.mids\n        };\n        n.handleUpdate({\n            actions: [la,],\n            threads: [ja.obj.updated_thread,],\n            payload_source: q.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE\n        });\n    };\n    function x(ia, ja) {\n        if ((((ia != h.getArbiterType(\"messaging\")) || !ja.obj) || !ja.obj.folder)) {\n            return\n        };\n        var ka = {\n            action_type: q.MercuryGlobalActionType.MARK_ALL_READ,\n            action_id: ja.obj.action_id,\n            folder: ja.obj.folder\n        };\n        n.handleUpdate({\n            global_actions: [ka,]\n        });\n    };\n    function y(ia, ja) {\n        if (((ia != h.getArbiterType(\"messaging\")) || !ja.obj.tids)) {\n            return\n        };\n        var ka = q.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE;\n        ja.obj.tids.forEach(function(la) {\n            var ma = {\n                action_type: q.MercuryActionType.CHANGE_ARCHIVED_STATUS,\n                action_id: null,\n                thread_id: la,\n                archived: ja.obj.state\n            };\n            n.handleUpdateWaitForThread({\n                actions: [i({\n                }, ma),],\n                payload_source: ka\n            }, la);\n        });\n    };\n    function z(ia, ja) {\n        if (((ia != h.getArbiterType(\"messaging\")) || !ja.obj.tids)) {\n            return\n        };\n        var ka = q.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE, la;\n        ja.obj.tids.forEach(function(ma) {\n            if ((ja.obj.event == q.MessagingEventTypes.TAG)) {\n                la = ja.obj.tag;\n            }\n             else la = (ja.obj.marked_as_spam ? q.MessagingTag.SPAM : q.MessagingTag.INBOX);\n        ;\n            var na = {\n                action_type: q.MercuryActionType.CHANGE_FOLDER,\n                action_id: null,\n                thread_id: ma,\n                new_folder: la\n            };\n            n.handleUpdateWaitForThread({\n                actions: [i({\n                }, na),],\n                payload_source: ka\n            }, ma);\n        });\n    };\n    function aa(ia, ja) {\n        if (((ia != h.getArbiterType(\"messaging\")) || !ja.obj.tag)) {\n            return\n        };\n        switch (ja.obj.tag) {\n          case q.MessagingTag.ACTION_ARCHIVED:\n            y(ia, ja);\n            break;\n          case q.MessagingTag.INBOX:\n        \n          case q.MessagingTag.OTHER:\n            z(ia, ja);\n            break;\n        };\n    };\n    function ba(ia, ja, ka) {\n        return ((((ia + \":\") + ja) + \":\") + ka);\n    };\n    function ca(ia, ja) {\n        if ((((ia != h.getArbiterType(\"inbox\")) || !ja.obj) || !ja.obj.seen_timestamp)) {\n            return\n        };\n        n.handleUpdate({\n            message_counts: [{\n                seen_timestamp: ja.obj.seen_timestamp,\n                folder: q.MessagingTag.INBOX\n            },],\n            unseen_thread_ids: [{\n                thread_ids: [],\n                folder: q.MessagingTag.INBOX\n            },],\n            payload_source: q.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE\n        });\n    };\n    function da(ia, ja) {\n        if (((ia != h.getArbiterType(\"mercury\")) || !ja.obj)) {\n            return\n        };\n        o.synchronizeInforms(function() {\n            var ka = ja.obj, la = [];\n            ((ka.actions || [])).forEach(function(ma) {\n                var na = q.MercuryActionType.USER_GENERATED_MESSAGE;\n                if ((ma.action_type == q.MercuryActionType.LOG_MESSAGE)) {\n                    var oa = q.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE;\n                    n.handleUpdateWaitForThread({\n                        actions: [i({\n                        }, ma),],\n                        payload_source: oa\n                    }, ma.thread_id);\n                }\n                 else if ((ma.action_type != na)) {\n                    la.push(ma);\n                }\n            ;\n            });\n            ka.actions = la;\n            ka.payload_source = q.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE;\n            n.handleUpdate(ka);\n        });\n    };\n    function ea(ia, ja) {\n        n.handleRoger(ja.obj);\n    };\n    function fa(ia, ja) {\n        switch (ja.obj.event) {\n          case q.MessagingEventTypes.DELIVER:\n            t(ia, ja);\n            break;\n          case q.MessagingEventTypes.READ:\n        \n          case q.MessagingEventTypes.UNREAD:\n            u(ia, ja);\n            break;\n          case q.MessagingEventTypes.READ_ALL:\n            x(ia, ja);\n            break;\n          case q.MessagingEventTypes.DELETE:\n            v(ia, ja);\n            break;\n          case q.MessagingEventTypes.DELETE_MESSAGES:\n            w(ia, ja);\n            break;\n          case q.MessagingEventTypes.TAG:\n            aa(ia, ja);\n            break;\n          case q.MessagingEventTypes.REPORT_SPAM:\n            z(ia, ja);\n            break;\n          case q.MessagingEventTypes.READ_RECEIPT:\n            ea(ia, ja);\n            break;\n        };\n    };\n    var ga = [], ha = {\n        turnOn: function() {\n            if (!ga.length) {\n                var ia = {\n                    mercury: da,\n                    messaging: fa,\n                    group_msg: s,\n                    inbox: ca\n                };\n                for (var ja in ia) {\n                    ga.push(g.subscribe(h.getArbiterType(ja), ia[ja]));;\n                };\n            }\n        ;\n        },\n        turnOff: function() {\n            if (ga.length) {\n                ga.forEach(g.unsubscribe);\n                ga = [];\n            }\n        ;\n        }\n    };\n    ha.turnOn();\n    e.exports = ha;\n});\n__d(\"MercuryJewelCountControl\", [\"Arbiter\",\"DOM\",\"JewelX\",\"MercuryUnseenState\",\"MercuryServerRequests\",\"MercuryThreadInformer\",\"copyProperties\",\"tx\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = c(\"MercuryConstants\"), i = b(\"DOM\"), j = b(\"JewelX\"), k = b(\"MercuryUnseenState\"), l = b(\"MercuryServerRequests\"), m = b(\"MercuryThreadInformer\"), n = b(\"copyProperties\"), o = b(\"tx\"), p, q, r, s = function(u) {\n        if ((u || r.isOpen())) {\n            k.markAsSeen();\n        };\n    }, t = function(u, v) {\n        p = u;\n        q = i.find(p, \"#mercurymessagesCountValue\");\n        r = v;\n        this.render();\n        l.subscribe(\"model-update-completed\", function(w, x) {\n            s(false);\n        });\n        m.subscribe(\"unseen-updated\", this.render.bind(this));\n        r.subscribe(\"marked-seen\", s.shield(this, true));\n    };\n    n(t.prototype, {\n        render: function() {\n            var u = \"\";\n            if (k.exceedsMaxCount()) {\n                u = o._(\"{count}+\", {\n                    count: h.MercuryThreadlistConstants.MAX_UNSEEN_COUNT\n                });\n            }\n             else u = k.getUnseenCount().toString();\n        ;\n            g.inform(\"jewel/count-updated\", {\n                jewel: \"mercurymessages\",\n                count: u\n            }, g.BEHAVIOR_STATE);\n        }\n    });\n    e.exports = t;\n});\n__d(\"MercuryFilters\", [\"array-extensions\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    var g = c(\"MercuryConstants\"), h = [g.MessagingTag.UNREAD,], i = {\n        ALL: \"all\",\n        getSupportedFilters: function() {\n            return h.concat();\n        },\n        isSupportedFilter: function(j) {\n            return h.contains(j);\n        }\n    };\n    e.exports = i;\n});\n__d(\"MercuryOrderedThreadlist\", [\"JSLogger\",\"MercuryFolders\",\"MercuryFilters\",\"MercuryServerRequests\",\"RangedCallbackManager\",\"MercuryThreadInformer\",\"MercuryThreads\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"JSLogger\"), h = b(\"MercuryFolders\"), i = b(\"MercuryFilters\"), j = b(\"MercuryServerRequests\"), k = b(\"RangedCallbackManager\"), l = b(\"MercuryThreadInformer\"), m = b(\"MercuryThreads\"), n = c(\"MercuryConstants\"), o = g.create(\"ordered_threadlist_model\"), p = i.getSupportedFilters().concat([i.ALL,]), q = h.getSupportedFolders(), r = {\n    };\n    q.forEach(function(ca) {\n        r[ca] = {\n        };\n        p.forEach(function(da) {\n            r[ca][da] = new k(function(ea) {\n                return m.getThreadMetaNow(ea).timestamp;\n            }, function(ea, fa) {\n                return (fa - ea);\n            }, j.canLinkExternally.bind(j));\n        });\n    });\n    function s(ca, da, ea) {\n        var fa = [], ga = false, ha = ((ca || [])).filter(function(oa) {\n            var pa = (oa.filter || i.ALL);\n            return ((((oa.folder == da) || ((!oa.folder && (da == n.MessagingTag.INBOX))))) && (pa == ea));\n        }), ia = r[da][ea].getAllResources(), ja;\n        ha.forEach(function(oa) {\n            fa = fa.concat(oa.thread_ids);\n            var pa = (oa.end - oa.start);\n            if ((oa.thread_ids.length < pa)) {\n                ga = true;\n            };\n            if ((!ja || (oa.end > ja))) {\n                ja = oa.end;\n            };\n        });\n        w(fa, da, ea);\n        if (ga) {\n            r[da][ea].setReachedEndOfArray();\n        }\n         else {\n            var ka = r[da][ea].getCurrentArraySize();\n            if ((ja && (ka < ja))) {\n                var la = {\n                }, ma = ia.concat(fa), na = ma.filter(function(oa) {\n                    var pa = la[oa];\n                    la[oa] = true;\n                    return pa;\n                });\n                if (na.length) {\n                    o.warn(\"duplicate_threads\", {\n                        folder: da,\n                        expected_final_size: ja,\n                        actual_final_size: ka,\n                        duplicate_thread_ids: na\n                    });\n                    j.fetchThreadlistInfo(ja, na.length, da, ((ea == i.ALL) ? null : ea));\n                }\n            ;\n            }\n        ;\n        }\n    ;\n    };\n    function t(ca) {\n        q.forEach(function(da) {\n            p.forEach(function(ea) {\n                s(ca, da, ea);\n            });\n        });\n    };\n    function u(ca) {\n        var da = {\n        };\n        q.forEach(function(ea) {\n            da[ea] = {\n            };\n            p.forEach(function(fa) {\n                da[ea][fa] = {\n                    to_add: [],\n                    to_remove: [],\n                    to_remove_if_last_after_add: {\n                    }\n                };\n            });\n        });\n        ca.forEach(function(ea) {\n            if (ea.is_forward) {\n                return\n            };\n            var fa = ea.thread_id, ga = x(fa), ha = y(fa);\n            function ia() {\n                ha.forEach(function(ka) {\n                    da[ga][ka].to_add.push(fa);\n                    if ((!r[ga][ka].hasReachedEndOfArray() && !r[ga][ka].hasResource(fa))) {\n                        da[ga][ka].to_remove_if_last_after_add[fa] = true;\n                    };\n                });\n            };\n            function ja(ka) {\n                if (p.contains(ka)) {\n                    if (ha.contains(ka)) {\n                        da[ga][ka].to_add.push(fa);\n                    }\n                     else da[ga][ka].to_remove.push(fa);\n                \n                };\n            };\n            if (!ga) {\n                if (((ea.action_type === n.MercuryActionType.CHANGE_FOLDER) || (ea.action_type === n.MercuryActionType.CHANGE_ARCHIVED_STATUS))) {\n                    q.forEach(function(ka) {\n                        if ((ka !== ga)) {\n                            p.forEach(function(la) {\n                                r[ka][la].removeResources([fa,]);\n                            });\n                        };\n                    });\n                };\n                return;\n            }\n        ;\n            switch (ea.action_type) {\n              case n.MercuryActionType.DELETE_THREAD:\n                ha.forEach(function(ka) {\n                    da[ga][ka].to_remove.push(fa);\n                });\n                break;\n              case n.MercuryActionType.CHANGE_ARCHIVED_STATUS:\n            \n              case n.MercuryActionType.CHANGE_FOLDER:\n                ia();\n                break;\n              case n.MercuryActionType.CHANGE_READ_STATUS:\n                ja(n.MessagingTag.UNREAD);\n                break;\n              case n.MercuryActionType.USER_GENERATED_MESSAGE:\n            \n              case n.MercuryActionType.LOG_MESSAGE:\n                ha.forEach(function(ka) {\n                    if (z(fa, ga, ka)) {\n                        da[ga][ka].to_add.push(fa);\n                    };\n                });\n                break;\n            };\n        });\n        q.forEach(function(ea) {\n            p.forEach(function(fa) {\n                var ga = r[ea][fa];\n                w(da[ea][fa].to_add, ea, fa);\n                for (var ha = (ga.getCurrentArraySize() - 1); (ha >= 0); ha--) {\n                    var ia = ga.getResourceAtIndex(ha);\n                    if (!da[ea][fa].to_remove_if_last_after_add[ia]) {\n                        break;\n                    };\n                    da[ea][fa].to_remove.push(ia);\n                };\n                ga.removeResources(da[ea][fa].to_remove);\n            });\n        });\n    };\n    function v(ca) {\n        var da = {\n        };\n        q.forEach(function(ea) {\n            da[ea] = {\n            };\n            p.forEach(function(fa) {\n                da[ea][fa] = [];\n            });\n        });\n        ca.forEach(function(ea) {\n            var fa = x(ea.thread_id), ga = y(ea.thread_id);\n            ga.forEach(function(ha) {\n                if ((fa && z(ea.thread_id, fa, ha))) {\n                    da[fa][ha].push(ea.thread_id);\n                };\n            });\n        });\n        q.forEach(function(ea) {\n            p.forEach(function(fa) {\n                if ((da[ea][fa].length > 0)) {\n                    w(da[ea][fa], ea, fa);\n                };\n            });\n        });\n    };\n    function w(ca, da, ea) {\n        ea = (ea || i.ALL);\n        r[da][ea].addResources(ca);\n        q.forEach(function(fa) {\n            if ((fa != da)) {\n                r[fa][ea].removeResources(ca);\n            };\n        });\n    };\n    function x(ca) {\n        var da = m.getThreadMetaNow(ca), ea = null;\n        if (!da) {\n            ea = \"No thread metadata\";\n        }\n         else if (!da.folder) {\n            ea = \"No thread folder\";\n        }\n    ;\n        if (ea) {\n            var fa = {\n                error: ea,\n                tid: ca\n            };\n            o.warn(\"no_thread_folder\", fa);\n            return null;\n        }\n    ;\n        var ga = da.folder;\n        if (da.is_archived) {\n            ga = n.MessagingTag.ACTION_ARCHIVED;\n        };\n        if (r[ga]) {\n            return ga;\n        }\n         else return null\n    ;\n    };\n    function y(ca) {\n        var da = m.getThreadMetaNow(ca), ea = [i.ALL,];\n        if (!da) {\n            var fa = {\n                error: \"no_thread_metadata\",\n                tid: ca\n            };\n            o.warn(\"no_thread_metadata\", fa);\n            return [];\n        }\n    ;\n        if (da.unread_count) {\n            ea.push(n.MessagingTag.UNREAD);\n        };\n        return ea;\n    };\n    function z(ca, da, ea) {\n        var fa = m.getThreadMetaNow(ca);\n        return (((fa && fa.timestamp) && (x(ca) == da)) && y(ca).contains(ea));\n    };\n    var aa = {\n        getThreadlist: function(ca, da, ea, fa, ga) {\n            return aa.getFilteredThreadlist(ca, da, ea, i.ALL, fa, ga);\n        },\n        getFilteredThreadlist: function(ca, da, ea, fa, ga, ha) {\n            var ia = r[ea][fa], ja = ia.executeOrEnqueue(ca, da, ga, ha), ka = ia.getUnavailableResources(ja);\n            if (ka.length) {\n                if ((ia.getCurrentArraySize() < ca)) {\n                    var la = {\n                        start: ca,\n                        limit: da,\n                        filter: fa,\n                        resources_size: ia.getCurrentArraySize()\n                    };\n                    o.warn(\"range_with_gap\", la);\n                }\n            ;\n                j.fetchThreadlistInfo(ia.getCurrentArraySize(), ka.length, ea, ((fa == i.ALL) ? null : fa));\n            }\n        ;\n            return ja;\n        },\n        getThreadlistUntilTimestamp: function(ca, da, ea) {\n            ea = (ea || i.ALL);\n            return r[da][ea].getElementsUntil(ca);\n        },\n        unsubscribe: function(ca, da, ea) {\n            ea = (ea || i.ALL);\n            r[da][ea].unsubscribe(ca);\n        }\n    };\n    function ba(ca) {\n        switch (ca.payload_source) {\n          case n.MercuryPayloadSource.CLIENT_CHANGE_ARCHIVED_STATUS:\n        \n          case n.MercuryPayloadSource.CLIENT_CHANGE_READ_STATUS:\n        \n          case n.MercuryPayloadSource.CLIENT_CHANGE_FOLDER:\n        \n          case n.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE:\n        \n          case n.MercuryPayloadSource.CLIENT_DELETE_MESSAGES:\n        \n          case n.MercuryPayloadSource.CLIENT_DELETE_THREAD:\n        \n          case n.MercuryPayloadSource.CLIENT_SEND_MESSAGE:\n        \n          case n.MercuryPayloadSource.SERVER_SEND_MESSAGE:\n        \n          case n.MercuryPayloadSource.SERVER_CONFIRM_MESSAGES:\n        \n          case n.MercuryPayloadSource.SERVER_FETCH_THREADLIST_INFO:\n        \n          case n.MercuryPayloadSource.SERVER_THREAD_SYNC:\n            return true;\n          case n.MercuryPayloadSource.SERVER_INITIAL_DATA:\n            return ca.ordered_threadlists;\n          default:\n            return false;\n        };\n    };\n    j.subscribe(\"update-threadlist\", function(ca, da) {\n        if (!ba(da)) {\n            return\n        };\n        var ea = da.ordered_threadlists;\n        if ((ea && ea.length)) {\n            t(ea);\n        }\n         else {\n            var fa = ((da.actions || [])).filter(function(ga) {\n                return ga.thread_id;\n            });\n            v((da.threads || []));\n            u(fa);\n        }\n    ;\n        l.updatedThreadlist();\n    });\n    e.exports = aa;\n});\n__d(\"WebMessengerStateConstants\", [], function(a, b, c, d, e, f) {\n    var g = {\n        SELECTION: \"selection\",\n        COMPOSE: \"compose\",\n        SEARCH_THREAD: \"search-thread\",\n        SEARCH_THREAD_SELECTION: \"search-thread-selection\",\n        SEARCH_SNIPPET: \"search-snippet\",\n        SEARCH_SNIPPET_SELECTION: \"search-snippet-selection\",\n        STATE_CHANGE_EVENT: \"state-changed\",\n        COMPOSE_SHOWING_CONTEXT: \"showing_context\",\n        COMPOSE_SHOWING_TYPEAHEAD_RESULTS: \"showing_typeahead_results\",\n        COMPOSE_SHOWING_ALL_PEOPLE: \"showing_all_people\",\n        MESSAGE_ACTION: {\n            DELETE: \"delete\",\n            FORWARD: \"forward\"\n        }\n    };\n    e.exports = g;\n});\n__d(\"WebMessengerOldToNewPermalink\", [\"WebMessengerPermalinkConstants\",\"WebMessengerStateConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"WebMessengerPermalinkConstants\"), h = b(\"WebMessengerStateConstants\");\n    function i(n) {\n        if (!j(n)) {\n            return n\n        };\n        k(n);\n        m(n);\n        l(n);\n        return n;\n    };\n    function j(n) {\n        var o = n.getQueryData();\n        if (o.sk) {\n            switch (o.sk) {\n              case \"inbox\":\n                n.setPath(g.BASE_PATH);\n                n.removeQueryData(\"sk\");\n                break;\n              case \"other\":\n                n.setPath(g.OTHER_PATH);\n                n.removeQueryData(\"sk\");\n                break;\n              default:\n                return false;\n            }\n        };\n        return true;\n    };\n    function k(n) {\n        var o = n.getQueryData();\n        switch (o.action) {\n          case \"read\":\n            if (!o.tid) {\n                n.addQueryData({\n                    action: h.SELECTION\n                });\n            }\n             else n.removeQueryData(\"action\");\n        ;\n            break;\n        };\n    };\n    function l(n) {\n        var o = n.getQueryData();\n        if (o.tid) {\n            n.setPath(g.getURIPathForThreadID(o.tid, n.getPath()));\n            n.removeQueryData(\"tid\");\n        }\n    ;\n    };\n    function m(n) {\n        var o = n.getQueryData();\n        if (!n.getPath().match(g.SEARCH_POSTFIX_PATH)) {\n            var p = o.query;\n            if (o.query) {\n                var q = /\\bis:(archived|spam)\\b(.*)/, r = q.exec(o.query);\n                if (r) {\n                    switch (r[1]) {\n                      case \"archived\":\n                        n.setPath(g.ARCHIVED_PATH);\n                        break;\n                      case \"spam\":\n                        n.setPath(g.SPAM_PATH);\n                        break;\n                    };\n                    var s = o.query.substr(0, (o.query.length - r[0].length)), t = r[2];\n                    p = (((s.trim() + \" \") + t.trim())).trim();\n                }\n            ;\n            }\n        ;\n            if (o.thread_query) {\n                n.setPath((n.getPath() + g.SEARCH_POSTFIX_PATH));\n                n.setQueryData({\n                    query: o.thread_query\n                });\n            }\n             else if (p) {\n                n.setPath((n.getPath() + g.SEARCH_POSTFIX_PATH));\n                n.addQueryData({\n                    query: p\n                });\n            }\n             else n.removeQueryData(\"query\");\n            \n        ;\n        }\n    ;\n    };\n    e.exports = i;\n});\n__d(\"WebMessengerPermalinks\", [\"goURI\",\"MercuryIDs\",\"MercuryParticipants\",\"MercuryFilters\",\"WebMessengerOldToNewPermalink\",\"WebMessengerPermalinkConstants\",\"MercuryServerRequests\",\"WebMessengerStateConstants\",\"MercuryThreads\",\"Token\",\"URI\",\"MercuryConstants\",\"WebMessengerConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"goURI\"), h = b(\"MercuryIDs\"), i = b(\"MercuryParticipants\"), j = b(\"MercuryFilters\"), k = b(\"WebMessengerOldToNewPermalink\"), l = b(\"WebMessengerPermalinkConstants\"), m = b(\"MercuryServerRequests\"), n = b(\"WebMessengerStateConstants\"), o = b(\"MercuryThreads\"), p = b(\"Token\"), q = b(\"URI\"), r = c(\"MercuryConstants\"), s = c(\"WebMessengerConstants\"), t = {\n        getDefaultURI: function() {\n            var da = new q().setSubdomain(\"www\");\n            da.setPath(l.BASE_PATH);\n            return da;\n        },\n        goNextURI: function(da, ea) {\n            if (aa(da, ea)) {\n                var fa = t.getURI(da, ea);\n                g(fa);\n                return true;\n            }\n        ;\n            return false;\n        },\n        getURI: function(da, ea) {\n            var fa = t.getDefaultURI();\n            if ((!da || !ea)) {\n                return fa\n            };\n            switch (ea.folder) {\n              case r.MessagingTag.OTHER:\n                fa.setPath(l.OTHER_PATH);\n                break;\n              case r.MessagingTag.ACTION_ARCHIVED:\n                fa.setPath(l.ARCHIVED_PATH);\n                break;\n              case r.MessagingTag.SPAM:\n                fa.setPath(l.SPAM_PATH);\n                break;\n            };\n            if ((ea.filter && ((ea.filter != j.ALL)))) {\n                fa.addQueryData({\n                    filter: ea.filter\n                });\n            };\n            var ga;\n            switch (da) {\n              case n.COMPOSE:\n                fa.setPath((fa.getPath() + l.COMPOSE_POSTFIX_PATH));\n                ga = false;\n                break;\n              case n.SEARCH_SNIPPET:\n            \n              case n.SEARCH_THREAD_SELECTION:\n            \n              case n.SEARCH_SNIPPET_SELECTION:\n                ga = false;\n                fa.setPath((fa.getPath() + l.SEARCH_POSTFIX_PATH));\n                break;\n              case n.SEARCH_THREAD:\n                ga = true;\n                fa.setPath((fa.getPath() + l.SEARCH_POSTFIX_PATH));\n                break;\n              case n.SELECTION:\n                ga = !ea.thread_id;\n                break;\n              default:\n                ga = true;\n                break;\n            };\n            if (da) {\n                if (ga) {\n                    fa.addQueryData({\n                        action: da\n                    });\n                };\n                if (ea.thread_id) {\n                    var ha = m.getServerThreadIDNow(ea.thread_id), ia = (ha ? ha : ea.thread_id);\n                    fa.setPath(l.getURIPathForThreadID(ia, fa.getPath()));\n                }\n            ;\n                if (ea.query) {\n                    fa.addQueryData({\n                        query: ea.query\n                    });\n                };\n                if (ea.message_id) {\n                    fa.addQueryData({\n                        mid: ea.message_id\n                    });\n                };\n                if (ea.reuse_composer) {\n                    fa.addQueryData({\n                        rc: true\n                    });\n                };\n            }\n        ;\n            return fa;\n        },\n        processURI: function(da) {\n            da = k(da);\n            if (!t.isWebMessengerURI(da)) {\n                return false\n            };\n            var ea = ba(da);\n            if (!ea) {\n                return ca(da)\n            };\n            var fa = {\n                data: {\n                    folder: y(da),\n                    filter: z(da)\n                },\n                redirect: false,\n                state: ea\n            };\n            if (da.getQueryData().rc) {\n                fa.data.reuse_composer = true;\n            };\n            switch (ea) {\n              case n.SELECTION:\n                return x(da, fa);\n              case n.COMPOSE:\n                return u(da, fa);\n              case n.SEARCH_SNIPPET:\n                return w(da, fa);\n              case n.SEARCH_THREAD:\n            \n              case n.SEARCH_THREAD_SELECTION:\n                fa = w(da, fa);\n                return x(da, fa);\n              case n.SEARCH_SNIPPET_SELECTION:\n                fa = w(da, fa);\n                fa = x(da, fa);\n                return v(da, fa);\n            };\n            fa.redirect = true;\n            return fa;\n        },\n        isWebMessengerURI: function(da) {\n            return (/^(\\/messages|\\/webmessenger)/).test(da.getPath());\n        }\n    };\n    function u(da, ea) {\n        var fa = da.getQueryData().to;\n        if (fa) {\n            var ga = i.getNow((\"fbid:\" + fa));\n            if (ga) {\n                var ha = {\n                    uid: fa,\n                    text: ga.name,\n                    type: s.USER_TYPE\n                };\n                ea.data.new_tokens = [new p(ha),];\n            }\n        ;\n        }\n    ;\n        ea.data.start = true;\n        ea.data.contents_state = n.COMPOSE_SHOWING_CONTEXT;\n        return ea;\n    };\n    function v(da, ea) {\n        var fa = da.getQueryData().mid;\n        if (fa) {\n            ea.data.message_id = fa;\n        }\n         else ea.redirect = true;\n    ;\n        return ea;\n    };\n    function w(da, ea) {\n        var fa = da.getQueryData().query;\n        ea.data.query = fa;\n        return ea;\n    };\n    function x(da, ea) {\n        var fa = l.getThreadIDFromURI(da);\n        if (fa) {\n            var ga = (h.isValid(fa) ? fa : m.getClientThreadIDNow(fa));\n            if (ga) {\n                ea.data.thread_id = ga;\n            }\n             else ea.redirect = true;\n        ;\n        }\n         else {\n            var ha = l.getCanonicalUserID(da.getPath());\n            if (ha) {\n                var ia = o.getCanonicalThreadToUser(ha);\n                if (ia) {\n                    ea.data.thread_id = ia.thread_id;\n                }\n                 else ea.redirect = true;\n            ;\n            }\n        ;\n        }\n    ;\n        return ea;\n    };\n    function y(da) {\n        var ea = da.getPath();\n        if (ea.match((\"^\" + l.ARCHIVED_PATH))) {\n            return r.MessagingTag.ACTION_ARCHIVED\n        };\n        if (ea.match((\"^\" + l.OTHER_PATH))) {\n            return r.MessagingTag.OTHER\n        };\n        if (ea.match((\"^\" + l.SPAM_PATH))) {\n            return r.MessagingTag.SPAM\n        };\n        return r.MessagingTag.INBOX;\n    };\n    function z(da) {\n        return (da.getQueryData().filter || j.ALL);\n    };\n    function aa(da, ea) {\n        if (((da == n.COMPOSE) && !ea.start)) {\n            return false\n        };\n        if ((da == n.SEARCH_THREAD)) {\n            return false\n        };\n        if ((!da || !ea)) {\n            return true\n        };\n        if (ea.bug_reporting_enabled) {\n            return false\n        };\n        return !ea.message_action;\n    };\n    function ba(da) {\n        var ea = da.getQueryData();\n        if (ea.action) {\n            return ea.action\n        };\n        var fa = da.getPath();\n        if (fa.match(((l.BASE_PATH + \"(/[^/]+)?\") + l.COMPOSE_POSTFIX_PATH))) {\n            return n.COMPOSE\n        };\n        var ga = fa.match((((l.BASE_PATH + \"(/[^/]+)?\") + l.SEARCH_POSTFIX_PATH) + \"(/[^/]+)?\"));\n        if (ga) {\n            var ha = ga[2];\n            if ((ha && ha.match(l.TID_POSTFIX_PARTIAL_PATH))) {\n                if (ea.mid) {\n                    return n.SEARCH_SNIPPET_SELECTION;\n                }\n                 else return n.SEARCH_THREAD_SELECTION\n            ;\n            }\n             else return n.SEARCH_SNIPPET\n        ;\n        }\n    ;\n        if ((fa.match(l.TID_POSTFIX_PARTIAL_PATH) || l.getCanonicalUserID(fa))) {\n            return n.SELECTION\n        };\n    };\n    function ca(da) {\n        var ea = {\n            redirect: false,\n            state: n.COMPOSE,\n            data: {\n                contents_state: n.COMPOSE_SHOWING_CONTEXT,\n                folder: y(da),\n                filter: z(da),\n                start: true\n            }\n        };\n        return ea;\n    };\n    e.exports = t;\n});\n__d(\"MercuryJewelThreadlistControl\", [\"event-extensions\",\"ArbiterMixin\",\"CSS\",\"DOM\",\"MercuryOrderedThreadlist\",\"Parent\",\"MercuryThreadInformer\",\"MercuryThreadMetadataRenderer\",\"MercuryThreads\",\"WebMessengerPermalinks\",\"WebMessengerStateConstants\",\"copyProperties\",\"tx\",\"MercuryConfig\",\"MercuryConstants\",\"MercuryJewelTemplates\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"MercuryOrderedThreadlist\"), k = b(\"Parent\"), l = b(\"MercuryThreadInformer\"), m = b(\"MercuryThreadMetadataRenderer\"), n = b(\"MercuryThreads\"), o = b(\"WebMessengerPermalinks\"), p = b(\"WebMessengerStateConstants\"), q = b(\"copyProperties\"), r = b(\"tx\"), s = c(\"MercuryConfig\"), t = c(\"MercuryConstants\"), u = c(\"MercuryJewelTemplates\");\n    function v(w) {\n        this._rootElement = w;\n        this._contentElement = i.find(this._rootElement, \".jewelContent\");\n        this._loadingElement = i.find(this._rootElement, \".jewelLoading\");\n        l.subscribe(\"threadlist-updated\", this.render.bind(this));\n        this.render();\n    };\n    q(v, {\n        EVENT_THREADS_LOADED: \"threads-loaded\",\n        EVENT_THREADS_RENDERED: \"threads-rendered\"\n    });\n    q(v.prototype, g);\n    q(v.prototype, {\n        render: function() {\n            i.empty(this._contentElement);\n            h.show(this._loadingElement);\n            var w = i.create(\"div\");\n            i.appendContent(this._contentElement, w);\n            j.getThreadlist(t.MercuryThreadlistConstants.RECENT_THREAD_OFFSET, t.MercuryThreadlistConstants.JEWEL_THREAD_COUNT, t.MessagingTag.INBOX, this.renderThreads.bind(this, w), true);\n        },\n        renderThreads: function(w, x) {\n            this.inform(v.EVENT_THREADS_LOADED);\n            if (x.length) {\n                x.forEach(function(y) {\n                    var z = u[\":fb:mercury:jewel:threadlist-row\"].build();\n                    n.getThreadMeta(y, function(aa) {\n                        m.renderCoreThreadlist(aa, z, this.renderSingleThread.bind(this), {\n                            show_unread_count: true\n                        });\n                    }.bind(this));\n                    i.appendContent(w, z.getRoot());\n                }.bind(this));\n            }\n             else i.setContent(this._rootElement, this.renderEmptyThreadlist());\n        ;\n            h.hide(this._loadingElement);\n            this.inform(v.EVENT_THREADS_RENDERED);\n        },\n        renderSingleThread: function(w, x) {\n            if ((x.unread_count > 0)) {\n                h.addClass(w.getRoot(), \"jewelItemNew\");\n            };\n            if (s.MessagesMercuryIntegrationGK) {\n                w.getNode(\"link\").setAttribute(\"href\", o.getURI(p.SELECTION, {\n                    thread_id: x.thread_id\n                }).toString());\n            }\n             else m.renderTitanLink(x.thread_id, w.getNode(\"link\"));\n        ;\n            Event.listen(w.getRoot(), \"mouseover\", function(event) {\n                var y = w.getRoot();\n                if (!k.byClass(y, \"notifNegativeBase\")) {\n                    h.addClass(y, \"selected\");\n                };\n            });\n            Event.listen(w.getRoot(), \"mouseout\", function(event) {\n                h.removeClass(w.getRoot(), \"selected\");\n            });\n        },\n        renderEmptyThreadlist: function() {\n            return i.create(\"li\", {\n                className: \"empty\"\n            }, \"No messages\");\n        }\n    });\n    e.exports = v;\n});\n__d(\"MercuryJewel\", [\"MercuryChannelHandler\",\"MercuryJewelCountControl\",\"DOM\",\"MercuryJewelThreadlistControl\",\"MercuryServerRequests\",\"userAction\",], function(a, b, c, d, e, f) {\n    b(\"MercuryChannelHandler\");\n    var g = b(\"MercuryJewelCountControl\"), h = b(\"DOM\"), i = b(\"MercuryJewelThreadlistControl\"), j = b(\"MercuryServerRequests\"), k = b(\"userAction\"), l = false;\n    function m(q, r, s, t) {\n        j.handleUpdate(t);\n        var u = new g(r, s), v = h.find(q, \"#MercuryJewelThreadList\");\n        if ((s.getRoot() && s.isOpen())) {\n            n.call(this, v);\n        }\n         else s.subscribe(\"opened\", n.bind(this, v));\n    ;\n    };\n    e.exports = m;\n    function n(q) {\n        this._ua = k(\"click\").set_namespace(\"messages\").set_ua_id(\"jewel\");\n        this._listenForLoad = this._listenForRender = true;\n        if (!l) {\n            var r = new i(q);\n            r.subscribe(i.EVENT_THREADS_LOADED, o.bind(this));\n            r.subscribe(i.EVENT_THREADS_RENDERED, p.bind(this));\n            l = true;\n        }\n    ;\n    };\n    function o() {\n        if (this._listenForLoad) {\n            this._ua.add_event(\"loaded\");\n            this._listenForLoad = false;\n        }\n    ;\n    };\n    function p() {\n        if (this._listenForRender) {\n            this._ua.add_event(\"rendered\");\n            this._listenForRender = false;\n        }\n    ;\n    };\n});\n__d(\"TitanLeftNav\", [\"CounterDisplay\",\"MessagingEvents\",], function(a, b, c, d, e, f) {\n    var g = b(\"CounterDisplay\"), h = b(\"MessagingEvents\"), i = {\n        initialize: function() {\n            h.subscribe(\"count/other_unseen\", function(j, k) {\n                g.setCount(\"other_unseen\", k);\n            });\n        }\n    };\n    e.exports = i;\n});\n__d(\"MercuryStateCheck\", [\"Arbiter\",\"copyProperties\",\"ChannelConnection\",\"ChannelConstants\",\"MercuryFolders\",\"MercuryServerRequests\",\"URI\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"copyProperties\"), i = b(\"ChannelConnection\"), j = b(\"ChannelConstants\"), k = b(\"MercuryFolders\"), l = b(\"MercuryServerRequests\"), m = b(\"URI\"), n = c(\"MercuryConstants\"), o = h(new g(), {\n        initialize: function() {\n            g.subscribe(j.ON_INVALID_HISTORY, p);\n            i.subscribe(i.CONNECTED, function(q, r) {\n                if (!r.init) {\n                    p();\n                };\n            });\n        }\n    });\n    function p() {\n        var q;\n        if ((m.getRequestURI().getPath().search(/webmessenger/) !== -1)) {\n            q = k.getSupportedFolders();\n        }\n         else q = [n.MessagingTag.INBOX,];\n    ;\n        l.fetchMissedMessages(q);\n    };\n    o.initialize();\n    e.exports = o;\n});\n__d(\"LiveMessageReceiver\", [\"Arbiter\",\"AsyncRequest\",\"ChannelConstants\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"ChannelConstants\"), j = b(\"copyProperties\");\n    function k(l) {\n        this.eventName = l;\n        this.subs = null;\n        this.handler = bagofholding;\n        this.shutdownHandler = null;\n        this.registered = false;\n        this.appId = 1;\n    };\n    j(k, {\n        getAppMessageType: function(l, m) {\n            return (((\"live_message/\" + l) + \":\") + m);\n        },\n        route: function(l) {\n            var m = function(n) {\n                var o = k.getAppMessageType(l.app_id, l.event_name);\n                g.inform(o, n, g.BEHAVIOR_PERSISTENT);\n            };\n            if (l.hasCapture) {\n                new h().setHandler(function(n) {\n                    m(n.getPayload());\n                }).setAllowCrossPageTransition(true).handleResponse(l.response);\n            }\n             else m(l.response);\n        ;\n        }\n    });\n    j(k.prototype, {\n        setAppId: function(l) {\n            this.appId = l;\n            return this;\n        },\n        setHandler: function(l) {\n            this.handler = l;\n            this._dirty();\n            return this;\n        },\n        setRestartHandler: bagofholding,\n        setShutdownHandler: function(l) {\n            this.shutdownHandler = l.shield();\n            this._dirty();\n            return this;\n        },\n        _dirty: function() {\n            if (this.registered) {\n                this.unregister();\n                this.register();\n            }\n        ;\n        },\n        register: function() {\n            var l = function(n, o) {\n                return this.handler(o);\n            }.bind(this), m = k.getAppMessageType(this.appId, this.eventName);\n            this.subs = {\n            };\n            this.subs.main = g.subscribe(m, l);\n            if (this.shutdownHandler) {\n                this.subs.shut = g.subscribe(i.ON_SHUTDOWN, this.shutdownHandler);\n            };\n            this.registered = true;\n            return this;\n        },\n        unregister: function() {\n            if (!this.subs) {\n                return this\n            };\n            for (var l in this.subs) {\n                if (this.subs[l]) {\n                    this.subs[l].unsubscribe();\n                };\n            };\n            this.subs = null;\n            this.registered = false;\n            return this;\n        }\n    });\n    e.exports = k;\n});\nfunction PresenceIndicator() {\n\n};\ncopyProperties(PresenceIndicator.prototype, {\n    init: function(a, b, c) {\n        this._id = a;\n        this._firstname = b;\n        this._tooltip = c;\n        this._image = DOM.scry(this._tooltip, \"i\")[0];\n        this._previousAvail = null;\n        this._jslog = JSLogger.create(\"presence_indicator\");\n        requireLazy([\"ChatVisibility\",], function(e) {\n            this._jslog.log(\"vis_init\", e.isOnline());\n            this._chatVisibility = e;\n            this._updateVisibility();\n        }.bind(this));\n        this._subscriptions = [Arbiter.subscribe([AvailableListConstants.ON_AVAILABILITY_CHANGED,], this._updateAvailability.bind(this)),Arbiter.subscribe([\"chat/visibility-changed\",], this._updateVisibility.bind(this)),];\n        this._updateAvailability.bind(this).defer();\n        var d = Event.listen(this._tooltip, \"click\", function() {\n            requireLazy([\"AvailableList\",], function(e) {\n                if ((this._previousAvail != AvailableListConstants.OFFLINE)) {\n                    Chat.openTab(this._id);\n                };\n            }.bind(this));\n        }.bind(this));\n        onleaveRegister(function() {\n            d.remove();\n            while (this._subscriptions.length) {\n                Arbiter.unsubscribe(this._subscriptions.pop());;\n            };\n        }.bind(this));\n    },\n    _updateAvailability: function() {\n        requireLazy([\"AvailableList\",\"ChatConfig\",], function(a, b) {\n            if (!a.isReady()) {\n                return\n            };\n            var c, d, e = a.get(this._id);\n            if ((e === this._previousAvail)) {\n                return\n            };\n            this._previousAvail = e;\n            switch (e) {\n              case AvailableListConstants.OFFLINE:\n                c = tx._(\"{name} is offline\", {\n                    name: this._firstname\n                });\n                d = \"offline\";\n                break;\n              case AvailableListConstants.IDLE:\n                c = tx._(\"{name} is idle\", {\n                    name: this._firstname\n                });\n                d = \"idle\";\n                break;\n              case AvailableListConstants.ACTIVE:\n                c = tx._(\"{name} is online\", {\n                    name: this._firstname\n                });\n                d = \"online\";\n                break;\n              case AvailableListConstants.MOBILE:\n                c = tx._(\"{name} is available on mobile\", {\n                    name: this._firstname\n                });\n                d = \"mobile\";\n                break;\n              default:\n                throw new Error(\"Invalid availability\");\n            };\n            TooltipLink.setTooltipText(this._tooltip, c);\n            CSS.setClass(this._image, d);\n        }.bind(this));\n    },\n    _updateVisibility: function() {\n        if (this._chatVisibility.isOnline()) {\n            CSS.show(this._tooltip);\n        }\n         else CSS.hide(this._tooltip);\n    ;\n    }\n});\n__d(\"legacy:livemessage\", [\"LiveMessageReceiver\",], function(a, b, c, d) {\n    a.LiveMessageReceiver = b(\"LiveMessageReceiver\");\n}, 3);");
// 2877
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s9a2fdc1f321111aabbda3fe27580db2752c0f4b5");
// 2878
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"1zqwA\",]);\n}\n;\n;\n__d(\"AjaxRequest\", [\"ErrorUtils\",\"Keys\",\"URI\",\"UserAgent\",\"XHR\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"ErrorUtils\"), h = b(\"Keys\"), i = b(\"URI\"), j = b(\"UserAgent\"), k = b(\"XHR\"), l = b(\"copyProperties\");\n    function m(q, r, s) {\n        this.xhr = k.create();\n        if (!((r instanceof i))) {\n            r = new i(r);\n        }\n    ;\n    ;\n        if (((s && ((q == \"GET\"))))) {\n            r.setQueryData(s);\n        }\n         else this._params = s;\n    ;\n    ;\n        this.method = q;\n        this.uri = r;\n        this.xhr.open(q, r);\n    };\n;\n    var n = ((window.JSBNG__XMLHttpRequest && ((\"withCredentials\" in new JSBNG__XMLHttpRequest()))));\n    m.supportsCORS = function() {\n        return n;\n    };\n    m.ERROR = \"ar:error\";\n    m.TIMEOUT = \"ar:timeout\";\n    m.PROXY_ERROR = \"ar:proxy error\";\n    m.TRANSPORT_ERROR = \"ar:transport error\";\n    m.SERVER_ERROR = \"ar:http error\";\n    m.PARSE_ERROR = \"ar:parse error\";\n    m._inflight = [];\n    function o() {\n        var q = m._inflight;\n        m._inflight = [];\n        q.forEach(function(r) {\n            r.abort();\n        });\n    };\n;\n    function p(q) {\n        q.JSBNG__onJSON = q.JSBNG__onError = q.JSBNG__onSuccess = null;\n        JSBNG__clearTimeout(q._timer);\n        if (((q.xhr && ((q.xhr.readyState < 4))))) {\n            q.xhr.abort();\n            q.xhr = null;\n        }\n    ;\n    ;\n        m._inflight = m._inflight.filter(function(r) {\n            return ((((((r && ((r != q)))) && r.xhr)) && ((r.xhr.readyState < 4))));\n        });\n    };\n;\n    l(m.prototype, {\n        timeout: 60000,\n        prelude: /^for \\(;;\\);/,\n        JSBNG__status: null,\n        _eol: -1,\n        _call: function(q) {\n            if (this[q]) {\n                this[q](this);\n            }\n        ;\n        ;\n        },\n        _parseStatus: function() {\n            var q;\n            try {\n                this.JSBNG__status = this.xhr.JSBNG__status;\n                q = this.xhr.statusText;\n            } catch (r) {\n                if (((this.xhr.readyState >= 4))) {\n                    this.errorType = m.TRANSPORT_ERROR;\n                    this.errorText = r.message;\n                }\n            ;\n            ;\n                return;\n            };\n        ;\n            if (((((this.JSBNG__status === 0)) && !(/^(file|ftp)/.test(this.uri))))) {\n                this.errorType = m.TRANSPORT_ERROR;\n            }\n             else if (((((this.JSBNG__status >= 100)) && ((this.JSBNG__status < 200))))) {\n                this.errorType = m.PROXY_ERROR;\n            }\n             else if (((((this.JSBNG__status >= 200)) && ((this.JSBNG__status < 300))))) {\n                return;\n            }\n             else if (((((this.JSBNG__status >= 300)) && ((this.JSBNG__status < 400))))) {\n                this.errorType = m.PROXY_ERROR;\n            }\n             else if (((((this.JSBNG__status >= 400)) && ((this.JSBNG__status < 500))))) {\n                this.errorType = m.SERVER_ERROR;\n            }\n             else if (((((this.JSBNG__status >= 500)) && ((this.JSBNG__status < 600))))) {\n                this.errorType = m.PROXY_ERROR;\n            }\n             else if (((this.JSBNG__status == 1223))) {\n                return;\n            }\n             else if (((((this.JSBNG__status >= 12001)) && ((this.JSBNG__status <= 12156))))) {\n                this.errorType = m.TRANSPORT_ERROR;\n            }\n             else {\n                q = ((\"unrecognized status code: \" + this.JSBNG__status));\n                this.errorType = m.ERROR;\n            }\n            \n            \n            \n            \n            \n            \n            \n        ;\n        ;\n            if (!this.errorText) {\n                this.errorText = q;\n            }\n        ;\n        ;\n        },\n        _parseResponse: function() {\n            var q, r = this.xhr.readyState;\n            try {\n                q = ((this.xhr.responseText || \"\"));\n            } catch (s) {\n                if (((r >= 4))) {\n                    this.errorType = m.ERROR;\n                    this.errorText = ((\"responseText not available - \" + s.message));\n                }\n            ;\n            ;\n                return;\n            };\n        ;\n            while (this.xhr) {\n                var t = ((this._eol + 1)), u = q.indexOf(\"\\u000a\", t);\n                if (((((u < 0)) && ((r == 4))))) {\n                    u = q.length;\n                }\n            ;\n            ;\n                if (((u <= this._eol))) {\n                    break;\n                }\n            ;\n            ;\n                var v = q.substr(t, ((u - t))).replace(/^\\s*|\\s*$/g, \"\");\n                if (((((t === 0)) && this.prelude))) {\n                    if (this.prelude.test(v)) {\n                        v = v.replace(this.prelude, \"\");\n                    }\n                ;\n                }\n            ;\n            ;\n                this._eol = u;\n                if (v) {\n                    try {\n                        this.json = JSON.parse(v);\n                    } catch (s) {\n                        var w = (((/(<body[\\S\\s]+?<\\/body>)/i).test(q) && RegExp.$1)), x = {\n                            message: s.message,\n                            char: t,\n                            excerpt: ((((((t === 0)) && w)) || v)).substr(512)\n                        };\n                        this.errorType = m.PARSE_ERROR;\n                        this.errorText = ((\"parse error - \" + JSON.stringify(x)));\n                        return;\n                    };\n                ;\n                    g.applyWithGuard(this._call, this, [\"JSBNG__onJSON\",]);\n                }\n            ;\n            ;\n            };\n        ;\n        },\n        _onReadyState: function() {\n            var q = ((((this.xhr && this.xhr.readyState)) || 0));\n            if (((((this.JSBNG__status == null)) && ((q >= 2))))) {\n                this._parseStatus();\n            }\n        ;\n        ;\n            if (((((((this.JSBNG__status != null)) && ((q >= 3)))) && !this.errorType))) {\n                this._parseResponse();\n            }\n        ;\n        ;\n            if (((this.errorType || ((q == 4))))) {\n                this._time = ((JSBNG__Date.now() - this._sentAt));\n                this._call(((!this.errorType ? \"JSBNG__onSuccess\" : \"JSBNG__onError\")));\n                p(this);\n            }\n        ;\n        ;\n        },\n        send: function(q) {\n            this.xhr.JSBNG__onreadystatechange = function() {\n                g.applyWithGuard(this._onReadyState, this, arguments);\n            }.bind(this);\n            var r = this.timeout;\n            if (r) {\n                this._timer = JSBNG__setTimeout((function() {\n                    this.errorType = m.TIMEOUT;\n                    this.errorText = \"timeout\";\n                    this._time = ((JSBNG__Date.now() - this._sentAt));\n                    this._call(\"JSBNG__onError\");\n                    p(this);\n                }).bind(this), r, false);\n            }\n        ;\n        ;\n            m._inflight.push(this);\n            if (((this.method == \"POST\"))) {\n                this.xhr.setRequestHeader(\"Content-Type\", \"application/x-www-form-urlencoded\");\n            }\n        ;\n        ;\n            this._sentAt = JSBNG__Date.now();\n            this.xhr.send(((q ? i.implodeQuery(q) : \"\")));\n        },\n        abort: function() {\n            p(this);\n        },\n        toString: function() {\n            var q = ((\"[AjaxRequest readyState=\" + this.xhr.readyState));\n            if (this.errorType) {\n                q += ((((((((\" errorType=\" + this.errorType)) + \" (\")) + this.errorText)) + \")\"));\n            }\n        ;\n        ;\n            return ((q + \"]\"));\n        },\n        toJSON: function() {\n            var q = {\n                json: this.json,\n                JSBNG__status: this.JSBNG__status,\n                errorType: this.errorType,\n                errorText: this.errorText,\n                time: this._time\n            };\n            for (var r in q) {\n                if (((q[r] == null))) {\n                    delete q[r];\n                }\n            ;\n            ;\n            };\n        ;\n            return q;\n        }\n    });\n    if (((window.JSBNG__addEventListener && j.firefox()))) {\n        window.JSBNG__addEventListener(\"keydown\", function(JSBNG__event) {\n            if (((JSBNG__event.keyCode === h.ESC))) {\n                JSBNG__event.prevent();\n            }\n        ;\n        ;\n        }, false);\n    }\n;\n;\n    if (window.JSBNG__attachEvent) {\n        window.JSBNG__attachEvent(\"JSBNG__onunload\", o);\n    }\n;\n;\n    e.exports = m;\n});\n__d(\"ChatConfig\", [\"copyProperties\",\"ChatConfigInitialData\",], function(a, b, c, d, e, f) {\n    var g = c(\"ChatConfigInitialData\"), h = b(\"copyProperties\"), i = {\n    }, j = {\n        get: function(k, l) {\n            return ((((k in i)) ? i[k] : l));\n        },\n        set: function(k) {\n            if (((arguments.length > 1))) {\n                var l = {\n                };\n                l[k] = arguments[1];\n                k = l;\n            }\n        ;\n        ;\n            h(i, k);\n        },\n        getDebugInfo: function() {\n            return i;\n        }\n    };\n    j.set(g);\n    e.exports = j;\n});\n__d(\"ChannelConstants\", [], function(a, b, c, d, e, f) {\n    var g = \"channel/\", h = {\n        ON_SHUTDOWN: ((g + \"shutdown\")),\n        ON_INVALID_HISTORY: ((g + \"invalid_history\")),\n        ON_CONFIG: ((g + \"config\")),\n        ON_ENTER_STATE: ((g + \"enter_state\")),\n        ON_EXIT_STATE: ((g + \"exit_state\")),\n        OK: \"ok\",\n        ERROR: \"error\",\n        ERROR_MAX: \"error_max\",\n        ERROR_MISSING: \"error_missing\",\n        ERROR_MSG_TYPE: \"error_msg_type\",\n        ERROR_SHUTDOWN: \"error_shutdown\",\n        ERROR_STALE: \"error_stale\",\n        SYS_OWNER: \"sys_owner\",\n        SYS_NONOWNER: \"sys_nonowner\",\n        SYS_ONLINE: \"sys_online\",\n        SYS_OFFLINE: \"sys_offline\",\n        SYS_TIMETRAVEL: \"sys_timetravel\",\n        HINT_AUTH: \"shutdown auth\",\n        HINT_CONN: \"shutdown conn\",\n        HINT_DISABLED: \"shutdown disabled\",\n        HINT_INVALID_STATE: \"shutdown invalid state\",\n        HINT_MAINT: \"shutdown maint\",\n        HINT_UNSUPPORTED: \"shutdown unsupported\",\n        reason_Unknown: 0,\n        reason_AsyncError: 1,\n        reason_TooLong: 2,\n        reason_Refresh: 3,\n        reason_RefreshDelay: 4,\n        reason_UIRestart: 5,\n        reason_NeedSeq: 6,\n        reason_PrevFailed: 7,\n        reason_IFrameLoadGiveUp: 8,\n        reason_IFrameLoadRetry: 9,\n        reason_IFrameLoadRetryWorked: 10,\n        reason_PageTransitionRetry: 11,\n        reason_IFrameLoadMaxSubdomain: 12,\n        reason_NoChannelInfo: 13,\n        reason_NoChannelHost: 14,\n        getArbiterType: function(i) {\n            return ((((g + \"message:\")) + i));\n        }\n    };\n    e.exports = h;\n});\n__d(\"ChannelSubdomain\", [\"Cookie\",\"JSLogger\",\"UserAgent\",], function(a, b, c, d, e, f) {\n    var g = b(\"Cookie\"), h = b(\"JSLogger\"), i = b(\"UserAgent\"), j = h.create(\"channel\"), k = 7, l = null;\n    function m(p) {\n        var q = null, r = n(), s, t = ((i.firefox() ? Math.floor(((Math.JSBNG__random() * 32))) : 0));\n        for (var u = 0; ((u < 32)); u++) {\n            s = ((((u + t)) % 32));\n            if (!((r & ((1 << s))))) {\n                break;\n            }\n        ;\n        ;\n        };\n    ;\n        p--;\n        if (((s < Math.min(32, ((k * p)))))) {\n            l = s;\n            q = ((l % k));\n            g.set(\"sub\", ((r | ((1 << l)))));\n        }\n         else {\n            l = -1;\n            q = null;\n            j.error(\"subdomain_overflow\", {\n                slot: l,\n                max: p\n            });\n        }\n    ;\n    ;\n        return q;\n    };\n;\n    function n() {\n        var p = ((g.get(\"sub\") || 0));\n        p = parseInt(p, 10);\n        return ((isNaN(p) ? 0 : p));\n    };\n;\n    function o() {\n        if (((((l !== null)) && ((l >= 0))))) {\n            var p = ((n() & ~((1 << l))));\n            if (p) {\n                g.set(\"sub\", p);\n            }\n             else g.clear(\"sub\");\n        ;\n        ;\n        }\n    ;\n    ;\n    };\n;\n    e.exports = {\n        allocate: m,\n        clear: o\n    };\n});\n__d(\"ChannelTransport\", [\"copyProperties\",\"bind\",\"AjaxRequest\",\"URI\",\"JSLogger\",\"DocRPC\",\"ChannelConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\"), h = b(\"bind\"), i = b(\"AjaxRequest\"), j = b(\"URI\"), k = b(\"JSLogger\"), l = b(\"DocRPC\"), m = b(\"ChannelConstants\"), n = k.create(\"channel\");\n    function o() {\n        return ((((1048576 * Math.JSBNG__random())) | 0)).toString(36);\n    };\n;\n    function p(x, y) {\n        var z = x.subdomain;\n        z = ((((z === null)) ? \"\" : ((z + \"-\"))));\n        var aa = new j(y).setDomain(((((z + x.host)) + \".facebook.com\"))).setPort(x.port).setSecure(j().isSecure());\n        return aa;\n    };\n;\n    function q(x) {\n        var y = {\n            partition: x.partition,\n            cb: o()\n        }, z = p(x, \"/p\").setQueryData(y);\n        n.log(\"start_p\", {\n            uri: z.toString()\n        });\n        var aa = new i(\"GET\", z);\n        if (i.supportsCORS()) {\n            aa.xhr.withCredentials = true;\n        }\n    ;\n    ;\n        var ba = function(ca) {\n            n.log(\"finish_p\", {\n                xhr: ((ca.toJSON ? ca.toJSON() : ca))\n            });\n        };\n        aa.timeout = x.P_TIMEOUT;\n        aa.JSBNG__onError = aa.JSBNG__onSuccess = ba;\n        aa.send();\n    };\n;\n    function r(x, y, z) {\n        var aa = new JSBNG__Image(), ba = 0, ca = function(fa) {\n            aa.abort();\n            return ((fa ? y() : z()));\n        };\n        aa.JSBNG__onload = function() {\n            n.log(\"ping_ok\", {\n                duration: ((JSBNG__Date.now() - ba))\n            });\n            ca(true);\n        };\n        aa.JSBNG__onerror = function() {\n            q(x);\n            ca(false);\n        };\n        var da = JSBNG__setTimeout(aa.JSBNG__onerror, 10000, false);\n        aa.abort = function() {\n            if (da) {\n                JSBNG__clearTimeout(da);\n                da = null;\n            }\n        ;\n        ;\n            aa.JSBNG__onload = aa.JSBNG__onerror = null;\n        };\n        var ea = {\n            partition: x.partition,\n            cb: o()\n        };\n        ba = JSBNG__Date.now();\n        aa.src = p(x, \"/ping\").setQueryData(ea);\n        return aa;\n    };\n;\n    function s(x, y, z, aa) {\n        var ba = new JSBNG__Date(), ca = ((((((ba - x.userActive)) / 1000)) | 0));\n        if (((ca < 0))) {\n            n.warn(\"idle_regression\", {\n                idleTime: ca,\n                now: ba.getTime(),\n                userActive: x.userActive\n            });\n        }\n    ;\n    ;\n        var da = {\n            channel: x.user_channel,\n            seq: x.seq,\n            partition: x.partition,\n            clientid: x.sessionID,\n            cb: o(),\n            idle: ca\n        };\n        if (((ca < 60))) {\n            da.state = \"active\";\n        }\n    ;\n    ;\n        if (x.streamingCapable) {\n            da.mode = \"stream\";\n            da.format = \"json\";\n        }\n    ;\n    ;\n        var ea = p(x, \"/pull\").setQueryData(da), fa = new i(\"GET\", ea);\n        if (i.supportsCORS()) {\n            fa.xhr.withCredentials = true;\n        }\n    ;\n    ;\n        fa.timeout = ((x.streamingCapable ? x.STREAMING_TIMEOUT : x.LONGPOLL_TIMEOUT));\n        fa.JSBNG__onJSON = y;\n        fa.JSBNG__onSuccess = z;\n        fa.JSBNG__onError = function() {\n            var ga = ((((((this.JSBNG__status == 12002)) && ((this._time >= x.MIN_12002_TIMEOUT)))) || ((((this.JSBNG__status == 504)) && ((this._time >= x.MIN_504_TIMEOUT)))))), ha = ((ga ? z : aa));\n            return ((ha && ha.apply(this, arguments)));\n        };\n        fa.send();\n        x.inStreaming = x.streamingCapable;\n        return fa;\n    };\n;\n    function t(x) {\n        this.manager = x;\n        ((this.init && this.init()));\n    };\n;\n    function u(x) {\n        t.apply(this, arguments);\n    };\n;\n    g(u.prototype, {\n        logName: \"CORS\",\n        enterState: function(x, y) {\n            if (this._request) {\n                this._request.abort();\n                this._request = null;\n            }\n        ;\n        ;\n            if (((x == \"init\"))) {\n                JSBNG__setTimeout(h(this.manager, \"exitState\", {\n                    JSBNG__status: m.OK,\n                    stateId: y.stateId\n                }), 3000, false);\n            }\n        ;\n        ;\n            if (!/pull|ping/.test(x)) {\n                return;\n            }\n        ;\n        ;\n            var z = this.manager;\n            if (((x == \"ping\"))) {\n                this._request = r(y, h(z, \"exitState\", {\n                    JSBNG__status: m.OK,\n                    stateId: y.stateId\n                }), h(z, \"exitState\", {\n                    JSBNG__status: m.ERROR,\n                    stateId: y.stateId\n                }));\n            }\n             else if (((x == \"pull\"))) {\n                this._request = s(y, h(z, \"_processTransportData\", y.stateId), h(z, \"exitState\", {\n                    JSBNG__status: m.OK,\n                    stateId: y.stateId\n                }), h(z, \"exitState\", {\n                    JSBNG__status: m.ERROR,\n                    stateId: y.stateId\n                }));\n            }\n            \n        ;\n        ;\n        }\n    });\n    function v(x) {\n        n.log(\"iframe_init_constructor\");\n        t.apply(this, arguments);\n        this._iframe = JSBNG__document.createElement(\"div\");\n        this._iframe.style.display = \"none\";\n        JSBNG__document.body.appendChild(this._iframe);\n        l.publish(this, \"outerTransport\");\n    };\n;\n    g(v.prototype, {\n        logName: \"div\",\n        _initIframe: function(x) {\n            n.log(\"iframe_init_start\");\n            window.JSBNG__onchanneliframeready = function() {\n                n.log(\"iframe_resources\");\n                return x.resources;\n            };\n            window.JSBNG__onchanneliframeloaded = function() {\n                n.log(\"iframe_loaded\");\n            };\n            if (x) {\n                this._iframeURI = p(x, x.path);\n                if (x.bustIframe) {\n                    var y = {\n                        partition: x.partition,\n                        cb: o()\n                    };\n                    this._iframeURI.setQueryData(y);\n                }\n            ;\n            ;\n            }\n             else this._iframeURI = \"about:blank\";\n        ;\n        ;\n            this._iframeProxy = null;\n            try {\n                this._iframe.contentWindow.JSBNG__location.replace(this._iframeURI);\n                n.log(\"iframe_uri_set\");\n            } catch (z) {\n                n.error(\"iframe_uri_set_error\", z);\n                this.exitState({\n                    JSBNG__status: m.ERROR,\n                    stateId: x.stateId\n                }, ((z + \"\")));\n            };\n        ;\n        },\n        enterState: function(x, y) {\n            if (((x == \"init\"))) {\n                this._initIframe(y);\n            }\n             else if (/idle|ping|pull/.test(x)) {\n                if (this._iframeProxy) {\n                    this._iframeProxy.enterState.apply(this._iframeProxy, arguments);\n                }\n                 else if (((x != \"idle\"))) {\n                    this.exitState({\n                        JSBNG__status: m.ERROR,\n                        stateId: y.stateId\n                    }, \"iframe not yet loaded\");\n                }\n                \n            ;\n            ;\n            }\n             else if (((x == \"shutdown\"))) {\n                this._initIframe();\n            }\n            \n            \n        ;\n        ;\n        },\n        _processTransportData: function() {\n            this.manager._processTransportData.apply(this.manager, arguments);\n        },\n        exitState: function(x) {\n            if (((((this.manager.state == \"init\")) && ((x.JSBNG__status == m.OK))))) {\n                this._iframeProxy = l.proxy(this._iframe.contentWindow, \"innerTransport\", [\"enterState\",], ((this._iframeURI + \"\")).replace(/iframe.*/, \"\"));\n            }\n        ;\n        ;\n            if (((/ping|pull/.test(this.manager.state) && !this._iframeProxy))) {\n                return;\n            }\n        ;\n        ;\n            this.manager.exitState.apply(this.manager, arguments);\n        }\n    });\n    function w() {\n        this.init = this.init.bind(this);\n        t.apply(this, arguments);\n    };\n;\n    g(w.prototype, {\n        logName: \"iframe(inner)\",\n        init: function() {\n            l.publish(this, \"innerTransport\");\n            try {\n                var y = l.proxy(window.parent, \"outerTransport\", [\"_processTransportData\",\"exitState\",], JSBNG__top.DocRPC.origin);\n                g(this, y);\n                this.exitState({\n                    JSBNG__status: m.OK,\n                    stateId: 1000000\n                });\n            } catch (x) {\n                n.error(\"iframe_inner_init_error\", x);\n            };\n        ;\n        },\n        enterState: function(x, y) {\n            if (this._request) {\n                this._request.abort();\n                this._request = null;\n            }\n        ;\n        ;\n            if (((x == \"ping\"))) {\n                this._request = r(y, h(this, \"exitState\", {\n                    JSBNG__status: m.OK,\n                    stateId: y.stateId\n                }), h(this, \"exitState\", {\n                    JSBNG__status: m.ERROR,\n                    stateId: y.stateId\n                }));\n            }\n             else if (((x == \"pull\"))) {\n                this._request = s(y, h(this, \"_processTransportData\", y.stateId), h(this, \"exitState\", {\n                    JSBNG__status: m.OK,\n                    stateId: y.stateId\n                }), h(this, \"exitState\", {\n                    JSBNG__status: m.ERROR,\n                    stateId: y.stateId\n                }));\n            }\n            \n        ;\n        ;\n        }\n    });\n    e.exports = {\n        getURI: p,\n        Transport: t,\n        CORSTransport: u,\n        IframeTransport: v,\n        IframeInnerTransport: w\n    };\n});\n__d(\"FBAjaxRequest\", [\"$\",\"AjaxRequest\",\"copyProperties\",\"XHR\",], function(a, b, c, d, e, f) {\n    var g = b(\"$\"), h = b(\"AjaxRequest\"), i = b(\"copyProperties\"), j = b(\"XHR\");\n    function k(l, m, n) {\n        n = i(j.getAsyncParams(l), n);\n        var o = new h(l, m, n), p = o._call;\n        o._call = function(q) {\n            if (((((q == \"JSBNG__onJSON\")) && this.json))) {\n                if (this.json.error) {\n                    this.errorType = h.SERVER_ERROR;\n                    this.errorText = ((\"AsyncResponse error: \" + this.json.error));\n                }\n            ;\n            ;\n                this.json = this.json.payload;\n            }\n        ;\n        ;\n            p.apply(this, arguments);\n        };\n        return o;\n    };\n;\n    e.exports = k;\n});\n__d(\"MovingStat\", [], function(a, b, c, d, e, f) {\n    function g(h) {\n        h = ((h || 60000));\n        var i = {\n            t: new JSBNG__Date(),\n            count: 0,\n            v: 0\n        }, j = i, k = 0, l = 0;\n        function m() {\n            var n = ((new JSBNG__Date() - h));\n            while (((((j && j.next)) && ((j.t < n))))) {\n                k -= j.v;\n                l -= j.count;\n                j = j.next;\n            };\n        ;\n        };\n    ;\n        this.add = function(n) {\n            k += n;\n            l++;\n            var o = new JSBNG__Date();\n            if (((((o - i.t)) < 1000))) {\n                i.v += n;\n                i.count++;\n            }\n             else {\n                i.next = {\n                    t: o,\n                    v: n,\n                    count: 1\n                };\n                i = i.next;\n                m();\n            }\n        ;\n        ;\n        };\n        this.tally = function(n) {\n            n = ((n || 1000));\n            m();\n            return {\n                sum: k,\n                count: l,\n                timeAverage: ((((k * n)) / h))\n            };\n        };\n    };\n;\n    e.exports = g;\n});\n__d(\"PresenceUtil\", [\"Cookie\",\"Env\",\"randomInt\",\"tx\",], function(a, b, c, d, e, f) {\n    var g = b(\"Cookie\"), h = b(\"Env\"), i = b(\"randomInt\"), j = b(\"tx\"), k = ((i(0, 4294967295) + 1));\n    a.PresenceUtil = e.exports = {\n        checkMaintenanceError: function(l) {\n            if (((l.getError() == 1356007))) {\n                return true;\n            }\n        ;\n        ;\n            return false;\n        },\n        getErrorDescription: function(l) {\n            var m = l.getError(), n = l.getErrorDescription();\n            if (!n) {\n                n = \"An error occurred.\";\n            }\n        ;\n        ;\n            if (((m == 1357001))) {\n                n = \"Your session has timed out. Please log in.\";\n            }\n        ;\n        ;\n            return n;\n        },\n        getSessionID: function() {\n            return k;\n        },\n        hasUserCookie: function() {\n            return ((h.user === g.get(\"c_user\")));\n        }\n    };\n}, 3);\n__d(\"PresenceCookieManager\", [\"Cookie\",\"Dcode\",\"ErrorUtils\",\"Env\",\"JSLogger\",\"PresenceUtil\",\"URI\",\"PresenceInitialData\",], function(a, b, c, d, e, f) {\n    var g = b(\"Cookie\"), h = b(\"Dcode\"), i = b(\"ErrorUtils\"), j = b(\"Env\"), k = b(\"JSLogger\"), l = b(\"PresenceUtil\"), m = b(\"URI\"), n = c(\"PresenceInitialData\"), o = n.cookieVersion, p = n.dictEncode, q = \"presence\", r = {\n    }, s = null, t = null, u = k.create(\"presence_cookie\");\n    function v() {\n        try {\n            var z = g.get(q);\n            if (((s !== z))) {\n                s = z;\n                t = null;\n                if (((z && ((z.charAt(0) == \"E\"))))) {\n                    z = h.decode(z.substring(1));\n                }\n            ;\n            ;\n                if (z) {\n                    t = JSON.parse(z);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            if (((t && ((!t.user || ((t.user === j.user))))))) {\n                return t;\n            }\n        ;\n        ;\n        } catch (y) {\n            u.warn(\"getcookie_error\");\n        };\n    ;\n        return null;\n    };\n;\n    function w() {\n        return parseInt(((new JSBNG__Date().getTime() / 1000)), 10);\n    };\n;\n    var x = {\n        register: function(y, z) {\n            r[y] = z;\n        },\n        store: function() {\n            var y = v();\n            if (((((y && y.v)) && ((o < y.v))))) {\n                return;\n            }\n        ;\n        ;\n            var z = {\n                v: o,\n                time: w(),\n                user: j.user\n            };\n            for (var aa in r) {\n                z[aa] = i.applyWithGuard(r[aa], r, [((y && y[aa])),], function(ea) {\n                    ea.presence_subcookie = aa;\n                });\n            ;\n            };\n        ;\n            var ba = JSON.stringify(z);\n            if (p) {\n                ba = ((\"E\" + h.encode(ba)));\n            }\n        ;\n        ;\n            if (l.hasUserCookie()) {\n                var ca = ba.length;\n                if (((ca > 1024))) {\n                    u.warn(\"big_cookie\", ca);\n                }\n            ;\n            ;\n                var da = ((m.getRequestURI(false).isSecure() && !!g.get(\"csm\")));\n                g.set(q, ba, null, null, da);\n            }\n        ;\n        ;\n        },\n        clear: function() {\n            g.clear(q);\n        },\n        getSubCookie: function(y) {\n            var z = v();\n            if (!z) {\n                return null;\n            }\n        ;\n        ;\n            return z[y];\n        }\n    };\n    e.exports = x;\n});\n__d(\"PresenceState\", [\"Arbiter\",\"ErrorUtils\",\"JSLogger\",\"PresenceCookieManager\",\"copyProperties\",\"debounceAcrossTransitions\",\"setIntervalAcrossTransitions\",\"PresenceInitialData\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ErrorUtils\"), i = b(\"JSLogger\"), j = b(\"PresenceCookieManager\"), k = b(\"copyProperties\"), l = b(\"debounceAcrossTransitions\"), m = b(\"setIntervalAcrossTransitions\"), n = c(\"PresenceInitialData\"), o = ((n.cookiePollInterval || 2000)), p = [], q = [], r = null, s = null, t = 0, u = null, v = 0, w = [\"sb2\",\"t2\",\"lm2\",\"uct2\",\"tr\",\"tw\",\"at\",\"snd\",\"not\",], x = i.create(\"presence_state\");\n    function y() {\n        return j.getSubCookie(\"state\");\n    };\n;\n    function z() {\n        t = JSBNG__Date.now();\n        j.store();\n        da(s);\n    };\n;\n    var aa = l(z, 0);\n    function ba(ha) {\n        if (((((((((typeof ha == \"undefined\")) || isNaN(ha))) || ((ha == Number.POSITIVE_INFINITY)))) || ((ha == Number.NEGATIVE_INFINITY))))) {\n            ha = 0;\n        }\n    ;\n    ;\n        return ha;\n    };\n;\n    function ca(ha) {\n        var ia = {\n        };\n        if (ha) {\n            w.forEach(function(la) {\n                ia[la] = ha[la];\n            });\n            if (((t < ha.ut))) {\n                x.error(\"new_cookie\", {\n                    cookie_time: ha.ut,\n                    local_time: t\n                });\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        ia.ut = t;\n        for (var ja = 0, ka = p.length; ((ja < ka)); ja++) {\n            h.applyWithGuard(p[ja], null, [ia,]);\n        ;\n        };\n    ;\n        s = ia;\n        return s;\n    };\n;\n    function da(ha) {\n        v++;\n        t = ba(ha.ut);\n        if (!r) {\n            r = m(ga, o);\n        }\n    ;\n    ;\n        s = ha;\n        if (((u === null))) {\n            u = ha;\n        }\n    ;\n    ;\n        for (var ia = 0, ja = q.length; ((ia < ja)); ia++) {\n            h.applyWithGuard(q[ia], null, [ha,]);\n        ;\n        };\n    ;\n        v--;\n    };\n;\n    function ea(ha) {\n        if (((ha && ha.ut))) {\n            if (((t < ha.ut))) {\n                return true;\n            }\n             else if (((ha.ut < t))) {\n                x.error(\"old_cookie\", {\n                    cookie_time: ha.ut,\n                    local_time: t\n                });\n            }\n            \n        ;\n        }\n    ;\n    ;\n        return false;\n    };\n;\n    function fa() {\n        var ha = y();\n        if (ea(ha)) {\n            s = ha;\n        }\n    ;\n    ;\n        return s;\n    };\n;\n    function ga() {\n        var ha = y();\n        if (ea(ha)) {\n            da(ha);\n        }\n    ;\n    ;\n    };\n;\n    j.register(\"state\", ca);\n    g.subscribe(i.DUMP_EVENT, function(ha, ia) {\n        ia.presence_state = {\n            initial: k({\n            }, u),\n            state: k({\n            }, s),\n            update_time: t,\n            sync_paused: v,\n            poll_time: o\n        };\n    });\n    (function() {\n        var ha = fa();\n        if (ha) {\n            da(ha);\n        }\n         else {\n            x.debug(\"no_cookie_initial\");\n            da(ca());\n            return;\n        }\n    ;\n    ;\n    })();\n    a.PresenceState = e.exports = {\n        doSync: function(ha) {\n            if (v) {\n                return;\n            }\n        ;\n        ;\n            if (ha) {\n                z();\n            }\n             else aa();\n        ;\n        ;\n        },\n        registerStateStorer: function(ha) {\n            p.push(ha);\n        },\n        registerStateLoader: function(ha) {\n            q.push(ha);\n        },\n        get: function() {\n            return fa();\n        },\n        getInitial: function() {\n            return u;\n        },\n        verifyNumber: ba\n    };\n}, 3);\n__d(\"ChannelConnection\", [\"Arbiter\",\"copyProperties\",\"ChatConfig\",\"Run\",\"SystemEvents\",\"ChannelConstants\",\"ChannelManager\",\"JSLogger\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"copyProperties\"), i = b(\"ChatConfig\"), j = b(\"Run\"), k = b(\"SystemEvents\"), l = b(\"ChannelConstants\"), m = b(\"ChannelManager\"), n = b(\"JSLogger\"), o = n.create(\"channel_connection\"), p = null, q = null, r = null, s = null, t = 0, u = h(new g(), {\n        CONNECTED: \"chat-connection/connected\",\n        RECONNECTING: \"chat-connection/reconnecting\",\n        SHUTDOWN: \"chat-connection/shutdown\",\n        MUTE_WARNING: \"chat-connection/mute\",\n        UNMUTE_WARNING: \"chat-connection/unmute\"\n    });\n    function v() {\n        if (q) {\n            JSBNG__clearTimeout(q);\n            q = null;\n        }\n    ;\n    ;\n    };\n;\n    function w() {\n        v();\n        o.log(\"unmute_warning\");\n        u.inform(u.UNMUTE_WARNING);\n    };\n;\n    function x(ba) {\n        v();\n        q = w.defer(ba, false);\n        o.log(\"mute_warning\", {\n            time: ba\n        });\n        u.inform(u.MUTE_WARNING);\n    };\n;\n    function y() {\n        if (r) {\n            JSBNG__clearTimeout(r);\n            r = null;\n        }\n    ;\n    ;\n    };\n;\n    function z(ba, ca) {\n        y();\n        if (((((ba === l.ON_ENTER_STATE)) && ((((ca.nextState || ca.state)) === \"pull\"))))) {\n            if (((s !== u.CONNECTED))) {\n                o.log(\"connected\");\n                var da = !s;\n                s = u.CONNECTED;\n                t = 0;\n                u.inform(u.CONNECTED, {\n                    init: da\n                });\n            }\n        ;\n        ;\n        }\n         else if (((((ba === l.ON_ENTER_STATE)) && ((((((ca.nextState || ca.state)) === \"ping\")) || ((!ca.nextState && ((ca.state === \"idle\"))))))))) {\n            r = (function() {\n                var ea = null;\n                if (!((((ca.state === \"idle\")) && !ca.nextState))) {\n                    ea = ((ca.delay || 0));\n                }\n            ;\n            ;\n                o.log(\"reconnecting\", {\n                    delay: ea\n                });\n                if (u.disconnected()) {\n                    o.log(\"reconnecting_ui\", {\n                        delay: ea\n                    });\n                }\n            ;\n            ;\n                s = u.RECONNECTING;\n                ((((ca.state === \"idle\")) && t++));\n                if (((t > 1))) {\n                    u.inform(u.RECONNECTING, ea);\n                }\n                 else if (((!ca.nextState && ((ca.state === \"idle\"))))) {\n                    z(ba, ca);\n                }\n                \n            ;\n            ;\n            }).defer(500, false);\n        }\n         else if (((ba === l.ON_SHUTDOWN))) {\n            o.log(\"shutdown\", {\n                reason: ca.reason\n            });\n            s = u.SHUTDOWN;\n            t = 0;\n            u.inform(u.SHUTDOWN, ca.reason);\n        }\n        \n        \n    ;\n    ;\n    };\n;\n    function aa(ba) {\n        if (((((m.state === \"ping\")) || m.isShutdown()))) {\n            return;\n        }\n    ;\n    ;\n        o.log(\"reconnect\", {\n            now: ba\n        });\n        u.inform(u.RECONNECTING, 0);\n        if (!!ba) {\n            if (((p !== null))) {\n                JSBNG__clearTimeout(p);\n                p = null;\n            }\n        ;\n        ;\n            m.enterState(\"ping!\");\n        }\n         else if (!p) {\n            p = JSBNG__setTimeout(function() {\n                m.enterState(\"ping!\");\n                p = null;\n            }, i.get(\"channel_manual_reconnect_defer_msec\"), false);\n        }\n        \n    ;\n    ;\n    };\n;\n    if (m.isShutdown()) {\n        z(l.ON_SHUTDOWN, m._shutdownHint);\n    }\n     else z(l.ON_ENTER_STATE, {\n        state: m.state,\n        nextState: m.nextState,\n        delay: 0\n    });\n;\n;\n    g.subscribe([l.ON_ENTER_STATE,l.ON_SHUTDOWN,], z);\n    k.subscribe(k.TIME_TRAVEL, function() {\n        aa();\n        x(i.get(\"mute_warning_time_msec\"));\n    });\n    j.JSBNG__onBeforeUnload(y, false);\n    h(u, {\n        disconnected: function() {\n            return ((((s === u.SHUTDOWN)) || ((((((s === u.RECONNECTING)) && !q)) && ((t > 1))))));\n        },\n        isShutdown: function() {\n            return ((s === u.SHUTDOWN));\n        },\n        reconnect: aa,\n        unmuteWarning: w\n    });\n    e.exports = u;\n});\n__d(\"legacy:ChannelConstants\", [\"ChannelConstants\",], function(a, b, c, d) {\n    a.ChannelConstants = b(\"ChannelConstants\");\n}, 3);\n__d(\"AvailableListConstants\", [], function(a, b, c, d, e, f) {\n    var g = {\n        ON_AVAILABILITY_CHANGED: \"buddylist/availability-changed\",\n        ON_UPDATE_ERROR: \"buddylist/update-error\",\n        ON_UPDATED: \"buddylist/updated\",\n        ON_CHAT_NOTIFICATION_CHANGED: \"chat-notification-changed\",\n        OFFLINE: 0,\n        IDLE: 1,\n        ACTIVE: 2,\n        MOBILE: 3,\n        LEGACY_OVERLAY_OFFLINE: -1,\n        LEGACY_OVERLAY_ONLINE: 0,\n        LEGACY_OVERLAY_IDLE: 1,\n        legacyStatusMap: {\n            0: 2,\n            1: 1,\n            \"-1\": 0,\n            2: 3\n        },\n        reverseLegacyStatusMap: {\n            0: -1,\n            1: 1,\n            2: 0,\n            3: 2\n        }\n    };\n    window.AvailableListConstants = e.exports = g;\n}, 3);\n__d(\"PresencePrivacy\", [\"hasArrayNature\",\"Arbiter\",\"AsyncRequest\",\"ChannelConstants\",\"copyProperties\",\"Env\",\"JSLogger\",\"PresenceUtil\",\"PresencePrivacyInitialData\",], function(a, b, c, d, e, f) {\n    var g = b(\"hasArrayNature\"), h = b(\"Arbiter\"), i = b(\"AsyncRequest\"), j = b(\"ChannelConstants\"), k = b(\"copyProperties\"), l = b(\"Env\"), m = b(\"JSLogger\"), n = b(\"PresenceUtil\"), o = c(\"PresencePrivacyInitialData\"), p = \"/ajax/chat/privacy/settings.php\", q = \"/ajax/chat/privacy/online_policy.php\", r = \"/ajax/chat/privacy/visibility.php\", s = \"friend_visibility\", t = \"visibility\", u = \"JSBNG__online_policy\", v = k({\n    }, o.privacyData), w = o.visibility, x = k({\n    }, o.privacyData), y = w, z = o.JSBNG__onlinePolicy, aa = z, ba = [], ca = false;\n    function da() {\n        return m.create(\"blackbird\");\n    };\n;\n    var ea = k(new h(), {\n        WHITELISTED: 1,\n        BLACKLISTED: -1,\n        UNLISTED: 0,\n        ONLINE: 1,\n        OFFLINE: 0,\n        ONLINE_TO_WHITELIST: 0,\n        ONLINE_TO_BLACKLIST: 1\n    });\n    function fa(ra) {\n        var sa;\n        for (sa in ra) {\n            var ta = ra[sa];\n            if (((sa == l.user))) {\n                da().error(\"set_viewer_visibility\");\n                throw new Error(\"Invalid to set current user's visibility\");\n            }\n        ;\n        ;\n            switch (ta) {\n              case ea.WHITELISTED:\n            \n              case ea.BLACKLISTED:\n            \n              case ea.UNLISTED:\n                break;\n              default:\n                da().error(\"set_invalid_friend_visibility\", {\n                    id: sa,\n                    value: ta\n                });\n                throw new Error(((\"Invalid state: \" + ta)));\n            };\n        ;\n        };\n    ;\n        for (sa in ra) {\n            v[sa] = ra[sa];\n        ;\n        };\n    ;\n        ea.inform(\"privacy-changed\");\n    };\n;\n    function ga(ra, sa) {\n        var ta = {\n        };\n        ta[ra] = sa;\n        fa(ta);\n    };\n;\n    function ha(ra) {\n        switch (ra) {\n          case ea.ONLINE:\n        \n          case ea.OFFLINE:\n            break;\n          default:\n            da().error(\"set_invalid_visibility\", {\n                value: ra\n            });\n            throw new Error(((\"Invalid visibility: \" + ra)));\n        };\n    ;\n        w = ra;\n        ea.inform(\"privacy-changed\");\n        ea.inform(\"privacy-user-presence-changed\");\n        h.inform(\"chat/visibility-changed\", {\n            sender: this\n        });\n    };\n;\n    function ia(ra) {\n        switch (ra) {\n          case ea.ONLINE_TO_WHITELIST:\n        \n          case ea.ONLINE_TO_BLACKLIST:\n            break;\n          default:\n            throw new Error(((\"Invalid default online policy: \" + ra)));\n        };\n    ;\n        z = ra;\n        ea.inform(\"privacy-user-presence-changed\");\n        ea.inform(\"privacy-changed\");\n    };\n;\n    function ja(ra, sa) {\n        ca = true;\n        ra.send();\n    };\n;\n    function ka(ra, sa) {\n        ba.push({\n            request: ra,\n            data: sa\n        });\n        if (!ca) {\n            var ta = ba.shift();\n            ja(ta.request, ta.data);\n        }\n    ;\n    ;\n    };\n;\n    function la(ra, sa) {\n        var ta = ra.type;\n        if (((ta === s))) {\n            var ua = sa.payload.user_availabilities;\n            if (!g(ua)) {\n                ea.inform(\"privacy-availability-changed\", {\n                    user_availabilities: ua\n                });\n                for (var va in ra.settings) {\n                    x[va] = ra.settings[va];\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n        }\n         else {\n            if (((ta === t))) {\n                y = ra.visibility;\n            }\n             else if (((ta === u))) {\n                aa = ra.JSBNG__online_policy;\n            }\n            \n        ;\n        ;\n            ea.inform(\"privacy-user-presence-response\");\n        }\n    ;\n    ;\n        da().log(\"set_update_response\", {\n            data: ra,\n            response: sa\n        });\n    };\n;\n    function ma(ra, sa) {\n        if (((w !== y))) {\n            ha(y);\n        }\n    ;\n    ;\n        if (((z !== aa))) {\n            ia(aa);\n        }\n    ;\n    ;\n        k(v, x);\n        ea.inform(\"privacy-changed\");\n        ba = [];\n        da().log(\"set_error_response\", {\n            data: ra,\n            response: sa\n        });\n    };\n;\n    function na(ra) {\n        ca = false;\n        if (((ba.length > 0))) {\n            var sa = ba.shift();\n            ja(sa.request, sa.data);\n        }\n    ;\n    ;\n    };\n;\n    function oa(ra, sa) {\n        if (((n != null))) {\n            var ta = ra.getData();\n            ta.window_id = n.getSessionID();\n            ra.setData(ta);\n        }\n    ;\n    ;\n        ra.setHandler(la.bind(this, sa)).setErrorHandler(ma.bind(this, sa)).setTransportErrorHandler(ma.bind(this, sa)).setFinallyHandler(na.bind(this)).setAllowCrossPageTransition(true);\n        return ra;\n    };\n;\n    function pa(ra, sa, ta) {\n        return oa(new i(ra).setData(sa), ta);\n    };\n;\n    function qa(ra, sa) {\n        var ta = sa.obj;\n        if (((ta.viewer_id != l.user))) {\n            da().error(\"invalid_viewer_for_channel_message\", {\n                type: ra,\n                data: sa\n            });\n            throw new Error(\"Viewer got from the channel is not the real viewer\");\n        }\n    ;\n    ;\n        if (((ta.window_id === n.getSessionID()))) {\n            return;\n        }\n    ;\n    ;\n        var ua = ta.data;\n        if (((ta.JSBNG__event == \"access_control_entry\"))) {\n            ua.target_ids.forEach(function(wa) {\n                ga(wa, ua.setting);\n                x[wa] = ua.setting;\n            });\n        }\n         else {\n            if (((ta.JSBNG__event == \"visibility_update\"))) {\n                var va = ((!!ua.visibility ? ea.ONLINE : ea.OFFLINE));\n                ha(va);\n                y = va;\n            }\n             else if (((ta.JSBNG__event == \"JSBNG__online_policy_update\"))) {\n                ia(ua.JSBNG__online_policy);\n                aa = ua.JSBNG__online_policy;\n            }\n            \n        ;\n        ;\n            ea.inform(\"privacy-user-presence-response\");\n        }\n    ;\n    ;\n        da().log(\"channel_message_received\", {\n            data: sa.obj\n        });\n    };\n;\n    k(ea, {\n        WHITELISTED: 1,\n        BLACKLISTED: -1,\n        UNLISTED: 0,\n        ONLINE: 1,\n        OFFLINE: 0,\n        ONLINE_TO_WHITELIST: 0,\n        ONLINE_TO_BLACKLIST: 1,\n        init: function(ra, sa, ta) {\n        \n        },\n        setVisibility: function(ra) {\n            y = w;\n            ha(ra);\n            var sa = {\n                visibility: ra\n            }, ta = {\n                type: t,\n                visibility: ra\n            }, ua = pa(r, sa, ta);\n            ka(ua, ta);\n            da().log(\"set_visibility\", {\n                data: sa\n            });\n            return ra;\n        },\n        getVisibility: function() {\n            return w;\n        },\n        setOnlinePolicy: function(ra) {\n            aa = z;\n            ia(ra);\n            var sa = {\n                JSBNG__online_policy: ra\n            }, ta = {\n                type: u,\n                JSBNG__online_policy: ra\n            }, ua = pa(q, sa, ta);\n            ka(ua, ta);\n            da().log(\"set_online_policy\", {\n                data: sa\n            });\n            return ra;\n        },\n        getOnlinePolicy: function() {\n            return z;\n        },\n        getFriendVisibility: function(ra) {\n            return ((v[ra] || ea.UNLISTED));\n        },\n        allows: function(ra) {\n            if (((this.getVisibility() === ea.OFFLINE))) {\n                return false;\n            }\n        ;\n        ;\n            var sa = this.getOnlinePolicy();\n            return ((((sa === ea.ONLINE_TO_WHITELIST)) ? ((v[ra] == ea.WHITELISTED)) : ((v[ra] != ea.BLACKLISTED))));\n        },\n        setFriendsVisibility: function(ra, sa) {\n            if (((ra.length > 0))) {\n                var ta = {\n                };\n                for (var ua = 0; ((ua < ra.length)); ua++) {\n                    var va = ra[ua];\n                    x[va] = v[va];\n                    ta[va] = sa;\n                };\n            ;\n                fa(ta);\n                var wa = sa;\n                if (((wa == ea.UNLISTED))) {\n                    wa = x[ra[0]];\n                }\n            ;\n            ;\n                var xa = {\n                    users: ra,\n                    setting: sa,\n                    setting_type: wa\n                }, ya = {\n                    type: s,\n                    settings: ta\n                }, za = pa(p, xa, ya);\n                ka(za, ya);\n                da().log(\"set_friend_visibility\", {\n                    data: xa\n                });\n            }\n        ;\n        ;\n            return sa;\n        },\n        setFriendVisibilityMap: function(ra, sa) {\n            for (var ta in ra) {\n                x[ta] = v[ta];\n            ;\n            };\n        ;\n            fa(ra);\n            var ua = {\n                type: s,\n                settings: ra\n            };\n            ka(oa(sa, ua), ua);\n            da().log(\"set_friend_visibility_from_map\", {\n                data: ra\n            });\n        },\n        allow: function(ra) {\n            if (this.allows(ra)) {\n                da().error(\"allow_already_allowed\");\n                throw new Error(((\"allow() should only be called for users that \" + \"are not already allowed\")));\n            }\n        ;\n        ;\n            if (((this.getVisibility() === ea.OFFLINE))) {\n                da().error(\"allow_called_while_offline\");\n                throw new Error(\"allow() should only be called when the user is already online\");\n            }\n        ;\n        ;\n            var sa = ((((this.getOnlinePolicy() === ea.ONLINE_TO_WHITELIST)) ? ea.WHITELISTED : ea.UNLISTED));\n            return this.setFriendsVisibility([ra,], sa);\n        },\n        disallow: function(ra) {\n            if (!this.allows(ra)) {\n                da().error(\"disallow_already_disallowed\");\n                throw new Error(((\"disallow() should only be called for users that \" + \"are not already disallowed\")));\n            }\n        ;\n        ;\n            if (((this.getVisibility() === ea.OFFLINE))) {\n                da().error(\"disallow_called_while_offline\");\n                throw new Error(\"disallow() should only be called when the user is already online\");\n            }\n        ;\n        ;\n            var sa = ((((this.getOnlinePolicy() === ea.ONLINE_TO_BLACKLIST)) ? ea.BLACKLISTED : ea.UNLISTED));\n            return this.setFriendsVisibility([ra,], sa);\n        },\n        getBlacklist: function() {\n            var ra = [];\n            for (var sa in v) {\n                if (((v[sa] === ea.BLACKLISTED))) {\n                    ra.push(sa);\n                }\n            ;\n            ;\n            };\n        ;\n            return ra;\n        },\n        getWhitelist: function() {\n            var ra = [];\n            for (var sa in v) {\n                if (((v[sa] === ea.WHITELISTED))) {\n                    ra.push(sa);\n                }\n            ;\n            ;\n            };\n        ;\n            return ra;\n        },\n        getMapForTest: function() {\n            return v;\n        },\n        setMapForTest: function(ra) {\n            v = ra;\n        }\n    });\n    ea.inform(\"privacy-changed\");\n    ea.inform(\"privacy-user-presence-changed\");\n    da().log(\"initialized\", {\n        visibility: w,\n        policy: z\n    });\n    h.subscribe(j.getArbiterType(\"privacy_changed\"), qa.bind(this));\n    h.subscribe(j.ON_CONFIG, function(ra, sa) {\n        var ta = sa.getConfig(\"visibility\", null);\n        if (((((ta !== null)) && ((typeof (ta) !== \"undefined\"))))) {\n            var ua = ((ta ? ea.ONLINE : ea.OFFLINE));\n            ha(ua);\n            da().log(\"config_visibility\", {\n                vis: ua\n            });\n        }\n    ;\n    ;\n    }.bind(this));\n    a.PresencePrivacy = e.exports = ea;\n}, 3);\n__d(\"Chat\", [\"Arbiter\",\"AsyncSignal\",\"JSLogger\",\"PresencePrivacy\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AsyncSignal\"), i = b(\"JSLogger\"), j = b(\"PresencePrivacy\");\n    function k(o, p, q) {\n        if (((((((((p && ((p == \"ordered_list\")))) || ((p == \"more_online_friends\")))) || ((p == \"JSBNG__online_friends\")))) || ((p == \"typeahead\"))))) {\n            var r = {\n                target: o,\n                source: p,\n                sorted_list: q\n            };\n            new h(\"/ajax/chat/ct.php\", r).send();\n        }\n    ;\n    ;\n    };\n;\n    var l = {\n        buddyListNub: \"buddylist-nub/initialized\",\n        sidebar: \"sidebar/initialized\"\n    };\n    function m(o, p) {\n        g.subscribe(l[o], function(JSBNG__event, q) {\n            p(q);\n        });\n    };\n;\n    var n = {\n        openTab: function(o, p, q, r, s) {\n            if (((((window.External && window.External.Chat)) && window.External.Chat.openWindow))) {\n                window.External.Chat.openWindow(o);\n            }\n        ;\n        ;\n            k(o, r, s);\n            d([\"MercuryThreads\",], function(t) {\n                if (((!q || ((q == \"friend\"))))) {\n                    var u = t.getCanonicalThreadToUser(o);\n                    g.inform(\"chat/open-tab\", {\n                        thread_id: u.thread_id\n                    });\n                }\n            ;\n            ;\n            });\n        },\n        openBuddyList: function() {\n            m(\"buddyListNub\", function(o) {\n                o.show();\n                m(\"sidebar\", function(p) {\n                    p.enable();\n                });\n            });\n        },\n        closeBuddyList: function() {\n            m(\"buddyListNub\", function(o) {\n                o.hide();\n            });\n        },\n        toggleSidebar: function() {\n            m(\"sidebar\", function(o) {\n                o.toggle();\n            });\n        },\n        goOnline: function(o) {\n            d([\"ChatVisibility\",], function(p) {\n                p.goOnline(o);\n            });\n        },\n        isOnline: function() {\n            var o = null;\n            d([\"ChatVisibility\",], function(p) {\n                o = p;\n            });\n            return ((o && o.isOnline()));\n        }\n    };\n    a.Chat = e.exports = n;\n}, 3);\n__d(\"ChatVisibility\", [\"ChatConfig\",\"JSLogger\",\"PresencePrivacy\",], function(a, b, c, d, e, f) {\n    var g = b(\"ChatConfig\"), h = b(\"JSLogger\"), i = b(\"PresencePrivacy\"), j = {\n        isOnline: function() {\n            return ((i.getVisibility() === i.ONLINE));\n        },\n        goOnline: function(k) {\n            if (((i.getVisibility() === i.OFFLINE))) {\n                h.create(\"blackbird\").log(\"chat_go_online\");\n                i.setVisibility(i.ONLINE);\n            }\n        ;\n        ;\n            ((k && k()));\n        },\n        goOffline: function(k) {\n            if (((i.getVisibility() === i.ONLINE))) {\n                h.create(\"blackbird\").log(\"chat_go_offline\");\n                i.setVisibility(i.OFFLINE);\n            }\n        ;\n        ;\n            ((k && k()));\n        },\n        toggleVisibility: function() {\n            if (j.isOnline()) {\n                j.goOffline();\n            }\n             else j.goOnline();\n        ;\n        ;\n        }\n    };\n    a.ChatVisibility = e.exports = j;\n}, 3);\n__d(\"ServerTime\", [\"PresenceInitialData\",], function(a, b, c, d, e, f) {\n    var g = c(\"PresenceInitialData\"), h;\n    function i(k) {\n        h = ((JSBNG__Date.now() - k));\n    };\n;\n    i(g.serverTime);\n    var j = {\n        get: function() {\n            return ((JSBNG__Date.now() - h));\n        },\n        getSkew: function() {\n            return h;\n        },\n        update: function(k) {\n            i(k);\n        }\n    };\n    e.exports = j;\n});\n__d(\"CallbackManagerController\", [\"ErrorUtils\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"ErrorUtils\"), h = b(\"copyProperties\"), i = function(j) {\n        this._pendingIDs = [];\n        this._allRequests = [undefined,];\n        this._callbackArgHandler = j;\n    };\n    h(i.prototype, {\n        executeOrEnqueue: function(j, k, l) {\n            l = ((l || {\n            }));\n            var m = this._attemptCallback(k, j, l);\n            if (m) {\n                return 0;\n            }\n        ;\n        ;\n            this._allRequests.push({\n                fn: k,\n                request: j,\n                options: l\n            });\n            var n = ((this._allRequests.length - 1));\n            this._pendingIDs.push(n);\n            return n;\n        },\n        unsubscribe: function(j) {\n            delete this._allRequests[j];\n        },\n        getRequest: function(j) {\n            return this._allRequests[j];\n        },\n        runPossibleCallbacks: function() {\n            var j = this._pendingIDs;\n            this._pendingIDs = [];\n            var k = [];\n            j.forEach(function(l) {\n                var m = this._allRequests[l];\n                if (!m) {\n                    return;\n                }\n            ;\n            ;\n                if (this._callbackArgHandler(m.request, m.options)) {\n                    k.push(l);\n                }\n                 else this._pendingIDs.push(l);\n            ;\n            ;\n            }.bind(this));\n            k.forEach(function(l) {\n                var m = this._allRequests[l];\n                delete this._allRequests[l];\n                this._attemptCallback(m.fn, m.request, m.options);\n            }.bind(this));\n        },\n        _attemptCallback: function(j, k, l) {\n            var m = this._callbackArgHandler(k, l);\n            if (m) {\n                var n = {\n                    ids: k\n                };\n                g.applyWithGuard(j, n, [m,]);\n            }\n        ;\n        ;\n            return !!m;\n        }\n    });\n    e.exports = i;\n});\n__d(\"KeyedCallbackManager\", [\"CallbackManagerController\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"CallbackManagerController\"), h = b(\"copyProperties\"), i = function() {\n        this._resources = {\n        };\n        this._controller = new g(this._constructCallbackArg.bind(this));\n    };\n    h(i.prototype, {\n        executeOrEnqueue: function(j, k) {\n            if (!((j instanceof Array))) {\n                var l = j, m = k;\n                j = [j,];\n                k = function(n) {\n                    m(n[l]);\n                };\n            }\n        ;\n        ;\n            return this._controller.executeOrEnqueue(j, k);\n        },\n        unsubscribe: function(j) {\n            this._controller.unsubscribe(j);\n        },\n        getUnavailableResources: function(j) {\n            var k = this._controller.getRequest(j), l = [];\n            if (k) {\n                l = k.request.filter(function(m) {\n                    return !this._resources[m];\n                }.bind(this));\n            }\n        ;\n        ;\n            return l;\n        },\n        addResourcesAndExecute: function(j) {\n            h(this._resources, j);\n            this._controller.runPossibleCallbacks();\n        },\n        setResource: function(j, k) {\n            this._resources[j] = k;\n            this._controller.runPossibleCallbacks();\n        },\n        getResource: function(j) {\n            return this._resources[j];\n        },\n        getAllResources: function() {\n            return this._resources;\n        },\n        dumpResources: function() {\n            var j = {\n            };\n            for (var k in this._resources) {\n                var l = this._resources[k];\n                if (((typeof l === \"object\"))) {\n                    l = h({\n                    }, l);\n                }\n            ;\n            ;\n                j[k] = l;\n            };\n        ;\n            return j;\n        },\n        _constructCallbackArg: function(j) {\n            var k = {\n            };\n            for (var l = 0; ((l < j.length)); l++) {\n                var m = j[l], n = this._resources[m];\n                if (((typeof n == \"undefined\"))) {\n                    return false;\n                }\n            ;\n            ;\n                k[m] = n;\n            };\n        ;\n            return k;\n        }\n    });\n    e.exports = i;\n});\n__d(\"AsyncLoader\", [\"AsyncRequest\",\"KeyedCallbackManager\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncRequest\"), h = b(\"KeyedCallbackManager\"), i = b(\"copyProperties\"), j = {\n    };\n    function k(m, n) {\n        var o = new h(), p = false, q = [];\n        function r() {\n            if (((!q.length || p))) {\n                return;\n            }\n        ;\n        ;\n            p = true;\n            t.defer();\n        };\n    ;\n        function s(w) {\n            p = false;\n            w.forEach(o.unsubscribe.bind(o));\n            r();\n        };\n    ;\n        function t() {\n            var w = {\n            }, x = [];\n            q = q.filter(function(z) {\n                var aa = o.getUnavailableResources(z);\n                if (aa.length) {\n                    aa.forEach(function(ba) {\n                        w[ba] = true;\n                    });\n                    x.push(z);\n                    return true;\n                }\n            ;\n            ;\n                return false;\n            });\n            var y = Object.keys(w);\n            if (y.length) {\n                new g(m).setData({\n                    ids: y\n                }).setHandler(u.curry(x)).setErrorHandler(v.curry(x)).setAllowCrossPageTransition(true).setMethod(\"GET\").setReadOnly(true).send();\n            }\n             else p = false;\n        ;\n        ;\n        };\n    ;\n        function u(w, x) {\n            var y = ((x.payload[n] || x.payload));\n            o.addResourcesAndExecute(y);\n            s(w);\n        };\n    ;\n        function v(w) {\n            s(w);\n        };\n    ;\n        return {\n            get: function(w, x) {\n                var y = o.executeOrEnqueue(w, x), z = o.getUnavailableResources(y);\n                if (z.length) {\n                    q.push(y);\n                    r();\n                }\n            ;\n            ;\n            },\n            getCachedKeys: function() {\n                return Object.keys(o.getAllResources());\n            },\n            getNow: function(w) {\n                return ((o.getResource(w) || null));\n            },\n            set: function(w) {\n                o.addResourcesAndExecute(w);\n            }\n        };\n    };\n;\n    function l(m, n) {\n        this._endpoint = m;\n        this._type = n;\n    };\n;\n    i(l.prototype, {\n        _getLoader: function() {\n            if (!j[this._endpoint]) {\n                j[this._endpoint] = k(this._endpoint, this._type);\n            }\n        ;\n        ;\n            return j[this._endpoint];\n        },\n        get: function(m, n) {\n            return this._getLoader().get(m, n);\n        },\n        getCachedKeys: function() {\n            return this._getLoader().getCachedKeys();\n        },\n        getNow: function(m) {\n            return this._getLoader().getNow(m);\n        },\n        reset: function() {\n            j[this._endpoint] = null;\n        },\n        set: function(m) {\n            this._getLoader().set(m);\n        }\n    });\n    e.exports = l;\n});\n__d(\"ShortProfiles\", [\"ArbiterMixin\",\"AsyncLoader\",\"AsyncRequest\",\"Env\",\"JSLogger\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"ArbiterMixin\"), h = b(\"AsyncLoader\"), i = b(\"AsyncRequest\"), j = b(\"Env\"), k = b(\"JSLogger\"), l = b(\"copyProperties\"), m = \"/ajax/chat/user_info.php\", n = \"/ajax/chat/user_info_all.php\", o = new h(m, \"profiles\"), p = false, q = k.create(\"short_profiles\");\n    function r() {\n        if (!p) {\n            q.log(\"fetch_all\");\n            p = true;\n            new i(n).setData({\n                viewer: j.user\n            }).setHandler(function(u) {\n                o.set(u.payload);\n                t.inform(\"updated\");\n            }).setAllowCrossPageTransition(true).setMethod(\"GET\").setReadOnly(true).send();\n        }\n    ;\n    ;\n    };\n;\n    function s(u) {\n        return JSON.parse(JSON.stringify(u));\n    };\n;\n    var t = {\n    };\n    l(t, g, {\n        get: function(u, v) {\n            this.getMulti([u,], function(w) {\n                v(w[u], u);\n            });\n        },\n        getMulti: function(u, v) {\n            function w(x) {\n                v(s(x));\n            };\n        ;\n            o.get(u, w);\n        },\n        getNow: function(u) {\n            return s(((o.getNow(u) || null)));\n        },\n        getCachedProfileIDs: function() {\n            return o.getCachedKeys();\n        },\n        hasAll: function() {\n            return p;\n        },\n        fetchAll: function() {\n            r();\n        },\n        set: function(u, v) {\n            var w = {\n            };\n            w[u] = v;\n            this.setMulti(w);\n        },\n        setMulti: function(u) {\n            o.set(s(u));\n        }\n    });\n    e.exports = t;\n});\n__d(\"AvailableList\", [\"function-extensions\",\"Arbiter\",\"ArbiterMixin\",\"AsyncRequest\",\"AvailableListConstants\",\"ChannelConstants\",\"Chat\",\"ChatConfig\",\"ChatVisibility\",\"Class\",\"Env\",\"JSLogger\",\"Poller\",\"PresencePrivacy\",\"PresenceUtil\",\"ServerTime\",\"ShortProfiles\",\"UserActivity\",\"copyProperties\",\"createObjectFrom\",\"debounceAcrossTransitions\",\"ChannelImplementation\",\"AvailableListInitialData\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"AsyncRequest\"), j = b(\"AvailableListConstants\"), k = b(\"ChannelConstants\"), l = b(\"Chat\"), m = b(\"ChatConfig\"), n = b(\"ChatVisibility\"), o = b(\"Class\"), p = b(\"Env\"), q = b(\"JSLogger\"), r = b(\"Poller\"), s = b(\"PresencePrivacy\"), t = b(\"PresenceUtil\"), u = b(\"ServerTime\"), v = b(\"ShortProfiles\"), w = b(\"UserActivity\"), x = b(\"copyProperties\"), y = b(\"createObjectFrom\"), z = b(\"debounceAcrossTransitions\"), aa = c(\"ChannelImplementation\").instance, ba = c(\"AvailableListInitialData\"), ca = 5, da = 60000, ea = \"/ajax/chat/buddy_list.php\", fa = 5000, ga = 1800000, ha = 45821, ia = 0, ja = 0, ka = false, la = ba.pollInterval, ma = ba.lazyPollInterval, na = ba.lazyThreshold, oa = 0, pa = JSBNG__Date.now(), qa = 0, ra = false, sa = {\n    }, ta = false, ua = {\n    }, va = null, wa = {\n    }, xa = {\n    }, ya = q.create(\"available_list\"), za = x({\n    }, j, h);\n    za.subscribe([j.ON_AVAILABILITY_CHANGED,j.ON_UPDATE_ERROR,j.ON_UPDATED,], function(sb, tb) {\n        g.inform(sb, tb);\n    });\n    function ab(sb) {\n        var tb = ((sb || w.isActive(na)));\n        return ((n.isOnline() ? ((tb ? la : ma)) : null));\n    };\n;\n    function bb() {\n        za.inform(j.ON_AVAILABILITY_CHANGED);\n    };\n;\n    var cb = z(bb, 0);\n    function db(sb, tb, ub, vb) {\n        if (((sb == p.user))) {\n            return;\n        }\n    ;\n    ;\n        switch (tb) {\n          case j.OFFLINE:\n        \n          case j.IDLE:\n        \n          case j.ACTIVE:\n        \n          case j.MOBILE:\n            break;\n          default:\n            return;\n        };\n    ;\n        var wb = ((za.get(sb) != tb));\n        if (ub) {\n            wa[sb] = u.get();\n            xa[sb] = vb;\n        }\n    ;\n    ;\n        sa[sb] = tb;\n        if (wb) {\n            ia++;\n            cb();\n        }\n    ;\n    ;\n    };\n;\n    function eb(sb) {\n        qa = JSBNG__Date.now();\n        ua = y(sb);\n        ia++;\n        cb();\n    };\n;\n    function fb() {\n        if (ra) {\n            za.inform(j.ON_UPDATED, za);\n        }\n    ;\n    ;\n    };\n;\n    function gb(sb) {\n        if (t.checkMaintenanceError(sb)) {\n            return;\n        }\n    ;\n    ;\n        ja++;\n        ka = false;\n        if (((ja >= ca))) {\n            za.inform(j.ON_UPDATE_ERROR);\n        }\n    ;\n    ;\n    };\n;\n    function hb(sb) {\n        var tb = sb.getPayload(), ub = tb.buddy_list;\n        if (!ub) {\n            gb(sb);\n            return;\n        }\n    ;\n    ;\n        u.update(tb.time);\n        oa = u.get();\n        ja = 0;\n        ka = false;\n        if (((ub.mobile_friends != null))) {\n            eb(ub.mobile_friends);\n        }\n    ;\n    ;\n        var vb = ub.userInfos;\n        if (vb) {\n            v.setMulti(vb);\n        }\n    ;\n    ;\n        nb();\n        ta = ub.userIsIdle;\n        var wb = ub.nowAvailableList;\n        ((wb && lb(wb)));\n        if (((ub.chatNotif !== undefined))) {\n            va = ub.chatNotif;\n            za.inform(j.ON_CHAT_NOTIFICATION_CHANGED, va);\n        }\n    ;\n    ;\n        mb();\n        fb();\n        cb();\n    };\n;\n    function ib(sb) {\n        if (((aa.isShutdown() || !n.isOnline()))) {\n            za._poller.JSBNG__stop();\n            return;\n        }\n    ;\n    ;\n        pa = JSBNG__Date.now();\n        var tb = false;\n        if (((((JSBNG__Date.now() - qa)) > ga))) {\n            tb = true;\n        }\n    ;\n    ;\n        ka = true;\n        var ub = v.getCachedProfileIDs();\n        sb.setHandler(hb).setErrorHandler(gb).setOption(\"suppressErrorAlerts\", true).setOption(\"retries\", 1).setData({\n            user: p.user,\n            available_user_info_ids: ub,\n            fetch_mobile: tb\n        }).setURI(ea).setAllowCrossPageTransition(true);\n    };\n;\n    function jb(sb) {\n        var tb = ((sb.payload.availability || {\n        }));\n        for (var ub in tb) {\n            db(ub, tb[ub], true, \"mercury_tabs\");\n        ;\n        };\n    ;\n    };\n;\n    function kb(sb) {\n        var tb = za.getDebugInfo(sb), ub = ((tb.presence == j.ACTIVE)), vb = new i(\"/ajax/mercury/tabs_presence.php\").setData({\n            target_id: sb,\n            to_online: ub,\n            presence_source: tb.overlaySource,\n            presence_time: tb.overlayTime\n        }).setHandler(jb).setErrorHandler(bagofholding).setAllowCrossPageTransition(true).send();\n    };\n;\n    function lb(sb) {\n        for (var tb in sb) {\n            db(tb, sb[tb].a, false, null);\n        ;\n        };\n    ;\n        ra = true;\n    };\n;\n    function mb(sb) {\n        var tb = ab(sb);\n        ya.debug(\"update_poller\", tb);\n        ((za._poller && za._poller.setTimePeriod(tb)));\n    };\n;\n    function nb() {\n        ra = false;\n        sa = {\n        };\n        xa = {\n        };\n        wa = {\n        };\n        ia++;\n    };\n;\n    function ob() {\n        nb();\n        pa = 0;\n        qa = 0;\n        ta = false;\n        va = null;\n        ua = {\n        };\n        bb();\n    };\n;\n    function pb() {\n        mb();\n        if (n.isOnline()) {\n            za.update();\n        }\n         else ob();\n    ;\n    ;\n    };\n;\n    function qb() {\n        mb();\n        if (aa.disconnected()) {\n            ob();\n        }\n         else if (!ra) {\n            za.update();\n        }\n        \n    ;\n    ;\n    };\n;\n    function rb(sb, tb) {\n        tb.chat_config = m.getDebugInfo();\n        tb.available_list_debug_info = {\n        };\n        za.getAvailableIDs().forEach(function(ub) {\n            tb.available_list_debug_info[ub] = za.getDebugInfo(ub);\n        });\n        tb.available_list_poll_interval = ((za._poller && za._poller.getTimePeriod()));\n    };\n;\n    x(za, {\n        get: function(sb) {\n            if (((sb == p.user))) {\n                return ((n.isOnline() ? j.ACTIVE : j.OFFLINE));\n            }\n        ;\n        ;\n            var tb = j.OFFLINE;\n            if (((sb in sa))) {\n                tb = sa[sb];\n            }\n        ;\n        ;\n            if (!s.allows(sb)) {\n                tb = j.OFFLINE;\n            }\n        ;\n        ;\n            if (((tb == j.OFFLINE))) {\n                if (ua[sb]) {\n                    tb = j.MOBILE;\n                }\n            ;\n            }\n        ;\n        ;\n            return tb;\n        },\n        updateForID: function(sb) {\n            kb(sb);\n        },\n        getWebChatNotification: function() {\n            return va;\n        },\n        isUserIdle: function() {\n            return ta;\n        },\n        isReady: function() {\n            return ra;\n        },\n        set: function(sb, tb, ub) {\n            db(sb, tb, true, null, ub);\n        },\n        update: function() {\n            if (((((JSBNG__Date.now() - pa)) < fa))) {\n                ((!ka && fb.defer()));\n                return;\n            }\n        ;\n        ;\n            ((za._poller && za._poller.requestNow()));\n        },\n        getRev: function() {\n            return ia;\n        },\n        isIdle: function(sb) {\n            return ((za.get(sb) == j.IDLE));\n        },\n        getOnlineIDs: function() {\n            var sb, tb = [];\n            for (sb in sa) {\n                if (((za.get(sb) === j.ACTIVE))) {\n                    tb.push(sb);\n                }\n            ;\n            ;\n            };\n        ;\n            return tb;\n        },\n        getAvailableIDs: function() {\n            var sb = za.getOnlineIDs(), tb;\n            for (tb in ua) {\n                if (sa[tb]) {\n                    continue;\n                }\n            ;\n            ;\n                sb.push(tb);\n            };\n        ;\n            return sb;\n        },\n        getOnlineCount: function() {\n            return za.getOnlineIDs().length;\n        },\n        getDebugInfo: function(sb) {\n            var tb;\n            if (window.ShortProfiles) {\n                var ub = v.getNow(sb);\n                if (ub) {\n                    tb = ub.JSBNG__name;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            return {\n                id: sb,\n                presence: sa[sb],\n                overlaySource: xa[sb],\n                overlayTime: wa[sb],\n                overlaySource: xa[sb],\n                mobile: ua[sb],\n                JSBNG__name: tb\n            };\n        }\n    });\n    oa = ba.updateTime;\n    lb(ba.availableList);\n    if (ba.mobileFriends) {\n        eb(ba.mobileFriends);\n    }\n;\n;\n    va = ba.chatNotif;\n    za._poller = new r(ab(), ib, true);\n    mb(true);\n    g.subscribe(q.DUMP_EVENT, rb);\n    w.subscribe(function(sb, tb) {\n        if (((tb.idleness > la))) {\n            ya.debug(\"update_activity\");\n            za.update();\n        }\n    ;\n    ;\n    });\n    s.subscribe(\"privacy-changed\", bb);\n    s.subscribe(\"privacy-availability-changed\", function(sb, tb) {\n        for (var ub in tb.user_availabilities) {\n            this.set(ub, tb.user_availabilities[ub]);\n        ;\n        };\n    ;\n    }.bind(za));\n    s.subscribe(\"privacy-user-presence-response\", za.update);\n    aa.subscribe([aa.CONNECTED,aa.RECONNECTING,aa.SHUTDOWN,aa.MUTE_WARNING,aa.UNMUTE_WARNING,], qb);\n    g.subscribe(k.getArbiterType(\"buddylist_overlay\"), function(sb, tb) {\n        var ub = tb.obj.overlay;\n        for (var vb in ub) {\n            za.set(vb, ub[vb].a, ((ub[vb].s || \"channel\")));\n        ;\n        };\n    ;\n    });\n    a.AvailableList = e.exports = za;\n});\n__d(\"ChatHovercard\", [\"Arbiter\",\"AsyncLoader\",\"Hovercard\",\"JSLogger\",\"debounce\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AsyncLoader\"), i = b(\"Hovercard\"), j = b(\"JSLogger\"), k = b(\"debounce\"), l = 5, m = new h(\"/ajax/chat/hovercard/sidebar.php\", \"hover\"), n = j.create(\"chat_hovercard\");\n    g.subscribe(\"Hovercard/dirty\", m.reset.bind(m));\n    function o(s, t) {\n        m.get(s, function(u) {\n            (function() {\n                if (!u) {\n                    n.error(\"fetch_failure\", {\n                        id: s\n                    });\n                    return;\n                }\n            ;\n            ;\n                var v = i.getDialog(u);\n                if (!v) {\n                    n.error(\"no_hovercard\", {\n                        id: s,\n                        endpoint: u\n                    });\n                    return;\n                }\n            ;\n            ;\n                if (((s == t.getActiveID()))) {\n                    t.showHovercard(s, v);\n                }\n            ;\n            ;\n            }).defer();\n        });\n    };\n;\n    function p(s, t) {\n        var u = [];\n        function v(y) {\n            if (((((y >= 0)) && ((y < s.length))))) {\n                u.push(s[y]);\n            }\n        ;\n        ;\n        };\n    ;\n        var w = s.indexOf(t);\n        if (((w > -1))) {\n            v(w);\n            for (var x = 1; ((x < l)); x++) {\n                v(((w + x)));\n                v(((w - x)));\n            };\n        ;\n        }\n    ;\n    ;\n        return u;\n    };\n;\n    function q(s, t) {\n        var u = t.getActiveID();\n        if (u) {\n            var v = s.getShowingUsers(), w = p(v, u);\n            m.get(w, function() {\n            \n            });\n        }\n    ;\n    ;\n    };\n;\n    function r(s) {\n        var t = s.getHoverController();\n        t.registerDefault(o);\n        t.subscribe(\"hover\", k(q.curry(s, t), 100));\n    };\n;\n    e.exports = r;\n});\n__d(\"ChatOptions\", [\"Arbiter\",\"ChannelConstants\",\"JSLogger\",\"PresenceUtil\",\"copyProperties\",\"ChatOptionsInitialData\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ChannelConstants\"), i = b(\"JSLogger\"), j = b(\"PresenceUtil\"), k = b(\"copyProperties\"), l = i.create(\"chat_options\"), m = {\n    };\n    (function() {\n        var o = c(\"ChatOptionsInitialData\");\n        for (var p in o) {\n            var q = o[p];\n            m[p] = !!q;\n        };\n    ;\n    })();\n    var n = k(new g(), {\n        getSetting: function(o) {\n            return m[o];\n        },\n        setSetting: function(o, p, q) {\n            if (((this.getSetting(o) == p))) {\n                return;\n            }\n        ;\n        ;\n            if (q) {\n                q = ((\"from_\" + q));\n                l.log(q, {\n                    JSBNG__name: o,\n                    new_value: p,\n                    old_value: this.getSetting(o)\n                });\n            }\n        ;\n        ;\n            m[o] = !!p;\n            g.inform(\"chat/option-changed\", {\n                JSBNG__name: o,\n                value: p\n            });\n        }\n    });\n    g.subscribe(h.getArbiterType(\"setting\"), function(o, p) {\n        var q = p.obj;\n        if (((q.window_id === j.getSessionID()))) {\n            return;\n        }\n    ;\n    ;\n        n.setSetting(q.setting, !!q.value, \"channel\");\n    });\n    g.subscribe(i.DUMP_EVENT, function(o, p) {\n        p.chat_options = m;\n    });\n    e.exports = n;\n});\n__d(\"ChatOrderedListHover\", [\"event-extensions\",\"function-extensions\",\"ArbiterMixin\",\"Class\",\"CSS\",\"DOM\",\"ErrorUtils\",\"LayerFadeOnHide\",\"Parent\",\"copyProperties\",\"setTimeoutAcrossTransitions\",\"tx\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"Class\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"ErrorUtils\"), l = b(\"LayerFadeOnHide\"), m = b(\"Parent\"), n = b(\"copyProperties\"), o = b(\"setTimeoutAcrossTransitions\"), p = b(\"tx\");\n    function q(t) {\n        i.addClass(t, \"fetching\");\n    };\n;\n    function r(t) {\n        i.removeClass(t, \"fetching\");\n    };\n;\n    function s(t) {\n        this._orderedList = t;\n        this._root = t.getRoot();\n        JSBNG__Event.listen(this._root, \"mouseover\", this._mouseOver.bind(this));\n        JSBNG__Event.listen(this._root, \"mouseleave\", this._mouseLeave.bind(this));\n        t.subscribe(\"click\", this._hide.shield(this));\n    };\n;\n    n(s.prototype, g, {\n        _root: null,\n        _activeItem: null,\n        _hideTimeout: null,\n        _showTimeout: null,\n        _showingDialog: null,\n        _showingID: null,\n        _alreadyShowing: false,\n        _handlers: {\n        },\n        _defaultHandler: null,\n        _mouseOver: function(t) {\n            var u = t.getTarget(), v = m.byClass(u, \"item\");\n            ((v && this._setActiveItem(v)));\n        },\n        _mouseLeave: function(t) {\n            this._setActiveItem(null);\n        },\n        _clearTimeouts: function() {\n            ((this._showTimeout && JSBNG__clearTimeout(this._showTimeout)));\n            this._showTimeout = null;\n            ((this._hideTimeout && JSBNG__clearTimeout(this._hideTimeout)));\n            this._hideTimeout = null;\n        },\n        _checkAlreadyShowing: function() {\n            var t = this.getActiveID();\n            if (((!t && !this._showingID))) {\n                this._alreadyShowing = false;\n            }\n        ;\n        ;\n        },\n        _hide: function() {\n            if (this._showingDialog) {\n                this._showingDialog.enableBehavior(l);\n                this._showingDialog.hide();\n                this._showingDialog = null;\n                this._showingID = null;\n            }\n        ;\n        ;\n            this._checkAlreadyShowing();\n        },\n        _show: function() {\n            this._alreadyShowing = true;\n            var t = this.getActiveID(), u = false;\n            if (this._handlers[t]) {\n                u = true;\n                k.applyWithGuard(this._handlers[t], {\n                }, [t,this,]);\n            }\n             else if (this._defaultHandler) {\n                u = true;\n                k.applyWithGuard(this._defaultHandler, {\n                }, [t,this,]);\n            }\n            \n        ;\n        ;\n            if (((u && ((this._showingID != this.getActiveID()))))) {\n                q(this._activeItem);\n            }\n        ;\n        ;\n        },\n        _setActiveItem: function(t) {\n            if (((t != this._activeItem))) {\n                this._clearTimeouts();\n                ((this._activeItem && r(this._activeItem)));\n                this._activeItem = null;\n                var u = ((t ? 0 : 100));\n                this._hideTimeout = o(function() {\n                    if (((this.getActiveID() != this._showingID))) {\n                        this._hide();\n                    }\n                ;\n                ;\n                }.bind(this), u);\n                if (t) {\n                    var v = this._orderedList.getUserForNode(t);\n                    this._activeItem = t;\n                    var w = ((u + ((this._alreadyShowing ? 75 : 500))));\n                    this._showTimeout = o(function() {\n                        this._show();\n                    }.bind(this), w);\n                    this.inform(\"hover\", v);\n                }\n                 else this.inform(\"leave\");\n            ;\n            ;\n                this._checkAlreadyShowing();\n            }\n        ;\n        ;\n        },\n        register: function(t, u) {\n            if (!this._handlers[t]) {\n                this._handlers[t] = u;\n                return {\n                    unregister: function() {\n                        if (((t == this._showingID))) {\n                            this._hide();\n                        }\n                    ;\n                    ;\n                        delete this._handlers[t];\n                        var v = this._orderedList.getAllNodes(), w = v[t];\n                        ((w && r(w)));\n                    }.bind(this)\n                };\n            }\n        ;\n        ;\n        },\n        registerDefault: function(t) {\n            this._defaultHandler = t;\n        },\n        getActiveID: function() {\n            var t = ((this._activeItem && this._orderedList.getUserForNode(this._activeItem)));\n            return ((t || null));\n        },\n        showHovercard: function(t, u) {\n            if (((((t == this.getActiveID())) && ((t != this._showingID))))) {\n                this._clearTimeouts();\n                r(this._activeItem);\n                this._hide();\n                this._showingDialog = u;\n                this._showingID = t;\n                var v = u.subscribe(\"mouseenter\", this._setActiveItem.bind(this, this._activeItem)), w = u.subscribe(\"mouseleave\", function() {\n                    v.unsubscribe();\n                    this._setActiveItem(null);\n                }.bind(this)), x = u.subscribe(\"hide\", function() {\n                    v.unsubscribe();\n                    w.unsubscribe();\n                    x.unsubscribe();\n                });\n                u.setContext(this._activeItem);\n                u.setFixed(true);\n                u.setPosition(\"left\");\n                u.show();\n                u.updatePosition();\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = s;\n});\n__d(\"ChatQuietLinks\", [\"event-extensions\",\"DOM\",\"DOMQuery\",\"UserAgent\",\"DataStore\",\"Parent\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"DOM\"), h = b(\"DOMQuery\"), i = b(\"UserAgent\"), j = b(\"DataStore\"), k = b(\"Parent\"), l = {\n    }, m = {\n        silenceLinks: function(q) {\n            n(q, this.removeEmptyHrefs.bind(this));\n        },\n        nukeLinks: function(q) {\n            n(q, this.removeAllHrefs.bind(this));\n        },\n        removeEmptyHrefs: function(q) {\n            o(q, function(r) {\n                return ((!r || ((r === \"#\"))));\n            });\n        },\n        removeAllHrefs: function(q) {\n            o(q);\n        }\n    };\n    function n(q, r) {\n        var s = !!i.JSBNG__chrome(), t = ((((!!i.JSBNG__chrome() || ((i.ie() >= 9)))) || ((i.firefox() >= 4))));\n        if (l[g.getID(q)]) {\n            return;\n        }\n    ;\n    ;\n        l[g.getID(q)] = true;\n        if (!t) {\n            return;\n        }\n    ;\n    ;\n        if (!s) {\n            ((r && r(q)));\n            return;\n        }\n    ;\n    ;\n        JSBNG__Event.listen(q, \"mouseover\", function u(v) {\n            var w = k.byTag(v.getTarget(), \"a\");\n            if (w) {\n                var x = w.getAttribute(\"href\");\n                if (p(x)) {\n                    j.set(w, \"stashedHref\", w.getAttribute(\"href\"));\n                    w.removeAttribute(\"href\");\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        });\n        JSBNG__Event.listen(q, \"mouseout\", function u(v) {\n            var w = k.byTag(v.getTarget(), \"a\"), x = ((w && j.remove(w, \"stashedHref\")));\n            if (p(x)) {\n                w.setAttribute(\"href\", x);\n            }\n        ;\n        ;\n        });\n        JSBNG__Event.listen(q, \"mousedown\", function(u) {\n            if (!u.isDefaultRequested()) {\n                return true;\n            }\n        ;\n        ;\n            var v = k.byTag(u.getTarget(), \"a\"), w = ((v && j.get(v, \"stashedHref\")));\n            if (p(w)) {\n                v.setAttribute(\"href\", w);\n            }\n        ;\n        ;\n        });\n    };\n;\n    function o(q, r) {\n        var s = g.scry(q, \"a\");\n        if (r) {\n            s = s.filter(function(t) {\n                return r(t.getAttribute(\"href\"));\n            });\n        }\n    ;\n    ;\n        s.forEach(function(t) {\n            t.removeAttribute(\"href\");\n            t.setAttribute(\"tabindex\", 0);\n        });\n    };\n;\n    function p(q) {\n        return ((q && ((q !== \"#\"))));\n    };\n;\n    e.exports = m;\n});\n__d(\"OrderedFriendsList\", [\"array-extensions\",\"Arbiter\",\"createArrayFrom\",\"ShortProfiles\",\"copyProperties\",\"OrderedFriendsListInitialData\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"createArrayFrom\"), i = b(\"ShortProfiles\"), j = b(\"copyProperties\"), k = [], l = {\n    }, m = j(new g(), {\n        contains: function(n) {\n            return ((n in l));\n        },\n        compare: function(n, o) {\n            var p = m.getRank(n), q = m.getRank(o);\n            if (((p !== q))) {\n                return ((p - q));\n            }\n        ;\n        ;\n            var r = i.getNow(n), s = i.getNow(o), t = ((((r || {\n            })).JSBNG__name || \"~\")).toLowerCase(), u = ((((s || {\n            })).JSBNG__name || \"~\")).toLowerCase();\n            if (((t !== u))) {\n                return ((((t < u)) ? -1 : 1));\n            }\n        ;\n        ;\n            return 0;\n        },\n        getList: function() {\n            var n = h(k);\n            n = n.filter(function(o) {\n                var p = ((window.ShortProfiles && i.getNow(o)));\n                return ((!p || ((p.type == \"friend\"))));\n            });\n            return n;\n        },\n        getRank: function(n) {\n            return ((((n in l)) ? l[n] : k.length));\n        },\n        isReady: function() {\n            return true;\n        }\n    });\n    (function() {\n        var n = c(\"OrderedFriendsListInitialData\");\n        k = ((n.list.length ? n.list : []));\n        k.forEach(function(o, p) {\n            l[o] = p;\n        });\n        m.inform(\"initialized\", {\n        }, g.BEHAVIOR_PERSISTENT);\n    })();\n    e.exports = ((a.OrderedFriendsList || m));\n});\n__d(\"ChatOrderedList\", [\"event-extensions\",\"Animation\",\"Arbiter\",\"ArbiterMixin\",\"AvailableList\",\"AvailableListConstants\",\"Chat\",\"ChatConfig\",\"ChatOrderedListHover\",\"ChatQuietLinks\",\"ChatVisibility\",\"Class\",\"CSS\",\"DataStore\",\"Dialog\",\"DOM\",\"HTML\",\"JSLogger\",\"OrderedFriendsList\",\"Parent\",\"PresencePrivacy\",\"ShortProfiles\",\"Tooltip\",\"URI\",\"Vector\",\"XHPTemplate\",\"copyProperties\",\"createObjectFrom\",\"debounceAcrossTransitions\",\"goURI\",\"tx\",\"MercuryConfig\",\"ChannelImplementation\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Animation\"), h = b(\"Arbiter\"), i = b(\"ArbiterMixin\"), j = b(\"AvailableList\"), k = b(\"AvailableListConstants\"), l = b(\"Chat\"), m = b(\"ChatConfig\"), n = b(\"ChatOrderedListHover\"), o = b(\"ChatQuietLinks\"), p = b(\"ChatVisibility\"), q = b(\"Class\"), r = b(\"CSS\"), s = b(\"DataStore\"), t = b(\"Dialog\"), u = b(\"DOM\"), v = b(\"HTML\"), w = b(\"JSLogger\"), x = b(\"OrderedFriendsList\"), y = b(\"Parent\"), z = b(\"PresencePrivacy\"), aa = b(\"ShortProfiles\"), ba = b(\"Tooltip\"), ca = b(\"URI\"), da = b(\"Vector\"), ea = b(\"XHPTemplate\"), fa = b(\"copyProperties\"), ga = b(\"createObjectFrom\"), ha = b(\"debounceAcrossTransitions\"), ia = b(\"goURI\"), ja = b(\"tx\"), ka = c(\"MercuryConfig\"), la = c(\"ChannelImplementation\").instance;\n    function ma(ra, sa, ta, ua) {\n        this._root = ra;\n        this._items = {\n        };\n        this._isVisible = false;\n        this._excludedIds = {\n        };\n        this._numTopFriends = 5;\n        this._hasRendered = false;\n        this._preventRendering = false;\n        this._hoverController = null;\n        this._template = sa;\n        this._messageTemplate = ta;\n        this._contextualDialog = ua;\n        JSBNG__Event.listen(this._root, \"click\", this._onClick.bind(this));\n        JSBNG__Event.listen(this._root, \"mouseenter\", this._mouseEnter.bind(this));\n        JSBNG__Event.listen(this._root, \"mouseleave\", this._mouseLeave.bind(this));\n        j.subscribe(k.ON_AVAILABILITY_CHANGED, this.update.shield(this));\n        z.subscribe(\"privacy-changed\", this.update.shield(this));\n        la.subscribe([la.CONNECTED,la.RECONNECTING,la.SHUTDOWN,la.MUTE_WARNING,la.UNMUTE_WARNING,], this.update.shield(this));\n        this.inform(\"initialized\", this, h.BEHAVIOR_PERSISTENT);\n        this.render();\n        h.subscribe(w.DUMP_EVENT, function(va, wa) {\n            wa.chat_lists = ((wa.chat_lists || {\n                sorted_list: this.getSortedList(),\n                ordered_list: x.getList(),\n                available_list: ma.getAvailableList(this._excludedIds),\n                excluded_list: this._excludedIds\n            }));\n        }.bind(this));\n    };\n;\n    function na(ra, sa) {\n        var ta = oa(ra, sa);\n        if (((ta !== 0))) {\n            return ta;\n        }\n    ;\n    ;\n        var ua = pa(ra, sa);\n        if (((ua !== 0))) {\n            return ua;\n        }\n    ;\n    ;\n        return x.compare(ra, sa);\n    };\n;\n    function oa(ra, sa) {\n        var ta = z.allows(ra), ua = z.allows(sa);\n        if (((ta !== ua))) {\n            return ((ta ? -1 : 1));\n        }\n    ;\n    ;\n        return 0;\n    };\n;\n    function pa(ra, sa) {\n        var ta = aa.getNow(ra), ua = aa.getNow(sa), va = ((((ta || {\n        })).JSBNG__name || \"~\")).toLowerCase(), wa = ((((ua || {\n        })).JSBNG__name || \"~\")).toLowerCase();\n        if (((va !== wa))) {\n            return ((((va < wa)) ? -1 : 1));\n        }\n    ;\n    ;\n        return 0;\n    };\n;\n    function qa(ra, sa) {\n        var ta = ((j.get(ra) === k.MOBILE)), ua = ((j.get(sa) === k.MOBILE));\n        if (((ta !== ua))) {\n            return ((ua ? -1 : 1));\n        }\n    ;\n    ;\n        return pa(ra, sa);\n    };\n;\n    fa(ma, {\n        getSortedList: function(ra, sa) {\n            var ta = x.getList().filter(function(jb) {\n                return !((jb in ra));\n            });\n            ta = ta.filter(function(jb) {\n                return ((z.getFriendVisibility(jb) !== z.BLACKLISTED));\n            });\n            var ua = [], va = p.isOnline();\n            if (va) {\n                if (((z.getOnlinePolicy() === z.ONLINE_TO_WHITELIST))) {\n                    var wa = ta, xa = {\n                    }, ya, za;\n                    ta = [];\n                    for (ya = 0; ((ya < wa.length)); ++ya) {\n                        za = wa[ya];\n                        if (z.allows(za)) {\n                            xa[za] = true;\n                            ta.push(za);\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    var ab = z.getWhitelist();\n                    for (ya = 0; ((ya < ab.length)); ++ya) {\n                        za = ab[ya];\n                        if (!((za in xa))) {\n                            ta.push(za);\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    for (ya = 0; ((ya < wa.length)); ++ya) {\n                        za = wa[ya];\n                        if (!z.allows(za)) {\n                            ta.push(za);\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n                var bb = m.get(\"ordered_list.top_friends\", 0), cb = m.get(\"ordered_list.available_target\", 0), db = Math.floor(((sa * cb))), eb = [];\n                for (var ya = 0, fb = ta.length; ((((ya < fb)) && ((db > 0)))); ya++) {\n                    var za = ta[ya], gb = j.get(za), hb = ((gb === k.ACTIVE));\n                    if (m.get(\"chat_sidebar_mobile_available\")) {\n                        hb = ((hb || ((gb === k.MOBILE))));\n                    }\n                ;\n                ;\n                    if (((hb || ((ya < bb))))) {\n                        ua.push(za);\n                        ((hb && db--));\n                    }\n                     else eb.push(za);\n                ;\n                ;\n                };\n            ;\n                if (((ya < fb))) {\n                    Array.prototype.push.apply(eb, ta.slice(ya));\n                }\n            ;\n            ;\n                if (((ua.length < sa))) {\n                    Array.prototype.push.apply(ua, eb);\n                }\n            ;\n            ;\n            }\n             else Array.prototype.push.apply(ua, ta);\n        ;\n        ;\n            ua = ua.slice(0, sa);\n            if (((ua.length === sa))) {\n                var ib = ma.getAvailableList(ua.concat(ra)).length;\n                ((ib && ua.splice(-1)));\n            }\n        ;\n        ;\n            ua.sort(na);\n            return ua;\n        },\n        getAvailableList: function(ra) {\n            return j.getOnlineIDs().filter(function(sa) {\n                return !((sa in ra));\n            });\n        }\n    });\n    fa(ma.prototype, i, {\n        getAllNodes: function() {\n            var ra = {\n            }, sa = u.scry(this._root, \"li.item\");\n            for (var ta = 0; ((ta < sa.length)); ta++) {\n                var ua = s.get(sa[ta], \"id\");\n                if (ua) {\n                    ra[ua] = sa[ta];\n                }\n            ;\n            ;\n            };\n        ;\n            return ra;\n        },\n        getShowingUsers: function() {\n            return u.scry(this._root, \"li.item\").map(function(ra) {\n                return s.get(ra, \"id\");\n            });\n        },\n        getUserForNode: function(ra) {\n            return s.get(ra, \"id\");\n        },\n        getHoverController: function() {\n            if (!this._hoverController) {\n                this._hoverController = new n(this, this._contextualDialog);\n            }\n        ;\n        ;\n            return this._hoverController;\n        },\n        _getListItem: function(ra) {\n            var sa = this._items[ra];\n            if (sa) {\n                var ta = j.get(ra), ua = ((z.allows(ra) && !la.disconnected())), va = {\n                    active: false,\n                    mobile: false,\n                    greenphone: false\n                };\n                va.active = ((ta === k.ACTIVE));\n                if (m.get(\"sidebar_mobile_icon_green\")) {\n                    va.greenphone = ((ta === k.MOBILE));\n                }\n                 else va.mobile = ((ta === k.MOBILE));\n            ;\n            ;\n                for (var wa in va) {\n                    r.conditionClass(sa, wa, ((va[wa] && ua)));\n                ;\n                };\n            ;\n                r.conditionClass(sa, \"invis\", !ua);\n            }\n        ;\n        ;\n            return sa;\n        },\n        getRoot: function() {\n            return this._root;\n        },\n        getSortedList: function() {\n            return ma.getSortedList(this._excludedIds, this._numTopFriends);\n        },\n        hide: function() {\n            if (!this._isVisible) {\n                return;\n            }\n        ;\n        ;\n            this._isVisible = false;\n            r.hide(this._root);\n            this.inform(\"hide\");\n        },\n        _onClick: function(JSBNG__event) {\n            var ra = JSBNG__event.getTarget(), sa = y.byTag(ra, \"li\");\n            if (sa) {\n                if (r.hasClass(sa, \"blackbirdWhitelist\")) {\n                    var ta = new ca(\"/ajax/chat/privacy/settings_dialog.php\").addQueryData({\n                        ref: \"whitelist_separator\"\n                    });\n                    new t().setAsyncURL(ta.toString()).show();\n                    JSBNG__event.prevent();\n                    return false;\n                }\n            ;\n            ;\n                var ua = s.get(sa, \"id\");\n                if (ua) {\n                    var va = \"ordered_list\", wa = sa;\n                    while (sa.previousSibling) {\n                        sa = sa.previousSibling;\n                        if (r.hasClass(sa, \"separator\")) {\n                            if (r.hasClass(sa, \"moreOnlineFriends\")) {\n                                va = \"more_online_friends\";\n                                break;\n                            }\n                        ;\n                        ;\n                            if (r.hasClass(sa, \"blackbirdWhitelist\")) {\n                                va = \"blackbird_offline_section\";\n                                break;\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    var xa = [];\n                    if (m.get(\"chat_realtime_coefficient_impressions\")) {\n                        xa = this.getSortedList();\n                    }\n                ;\n                ;\n                    aa.get(ua, function(ya) {\n                        l.openTab(ua, ya.JSBNG__name, \"friend\", va, xa);\n                    });\n                    this.inform(\"click\", {\n                        id: ua\n                    });\n                }\n                 else if (((r.hasClass(sa, \"separator\") && y.byClass(ra, \"JSBNG__inner\")))) {\n                    this.JSBNG__scrollTo(sa);\n                }\n                \n            ;\n            ;\n                return false;\n            }\n        ;\n        ;\n        },\n        _mouseEnter: function() {\n            this._preventRendering = true;\n        },\n        _mouseLeave: function() {\n            this._preventRendering = false;\n        },\n        setExcludedIds: function(ra) {\n            this._excludedIds = ga(((ra || [])));\n        },\n        setNumTopFriends: function(ra) {\n            if (((ra !== this._numTopFriends))) {\n                this._numTopFriends = ra;\n                this.render();\n            }\n        ;\n        ;\n        },\n        _getOfflineToSectionItems: function() {\n            var ra = u.create(\"a\", {\n                href: \"#\"\n            }, u.tx._(\"Edit\")), sa = [];\n            sa.push(v(((((((((((((((((((\"\\u003Cli class=\\\"separator\\\"\\u003E\" + \"\\u003Cdiv class=\\\"outer\\\"\\u003E\")) + \"\\u003Cdiv class=\\\"inner\\\"\\u003E\")) + \"\\u003Cspan class=\\\"text\\\"\\u003E\")) + u.tx._(\"OFFLINE FRIENDS\"))) + \"\\u003C/span\\u003E\")) + \"\\u003Cdiv class=\\\"dive\\\"\\u003E\\u003Cspan class=\\\"bar\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\")) + \"\\u003C/div\\u003E\")) + \"\\u003C/div\\u003E\")) + \"\\u003C/li\\u003E\"))));\n            sa.push(v(((((((((((((((((((\"\\u003Cli class=\\\"separator blackbirdWhitelist\\\"\\u003E\" + \"\\u003Cdiv class=\\\"outer\\\"\\u003E\")) + \"\\u003Cdiv class=\\\"inner\\\"\\u003E\")) + \"\\u003Cdiv class=\\\"subheader\\\"\\u003E\")) + \"\\u003Cspan class=\\\"subheaderText\\\"\\u003E\")) + u.tx._(\"These friends can't see you on chat. {=link}\", {\n                \"=link\": ra\n            }))) + \"\\u003C/span\\u003E\")) + \"\\u003C/div\\u003E\")) + \"\\u003C/div\\u003E\")) + \"\\u003C/li\\u003E\"))));\n            return sa;\n        },\n        render: function() {\n            this.render = ha(function() {\n                if (((!this._isVisible || ((this._preventRendering && this._hasRendered))))) {\n                    return;\n                }\n            ;\n            ;\n                this._hasRendered = true;\n                var ra = this.getSortedList(), sa = [], ta, ua, va = ((z.getVisibility() && ((z.getOnlinePolicy() == z.ONLINE_TO_WHITELIST))));\n                for (var wa = 0, xa = ra.length; ((wa < xa)); wa++) {\n                    ta = ra[wa];\n                    if (va) {\n                        if (!z.allows(ta)) {\n                            if (((((wa + 2)) >= ra.length))) {\n                                break;\n                            }\n                        ;\n                        ;\n                            va = false;\n                            var ya = this._getOfflineToSectionItems();\n                            sa.push(ya[0]);\n                            sa.push(ya[1]);\n                            xa -= 2;\n                        }\n                    ;\n                    }\n                ;\n                ;\n                    ua = this._getListItem(ta);\n                    if (ua) {\n                        sa.push(ua);\n                    }\n                     else this._renderListItem(ta, this.render.bind(this));\n                ;\n                ;\n                };\n            ;\n                var za = ma.getAvailableList(this._excludedIds), ab = ga(ra);\n                za = za.filter(function(gb) {\n                    return !((gb in ab));\n                });\n                za.sort(qa);\n                var bb = ((ka.ChatControlLanguageChangeGK ? \"MORE FRIENDS\" : \"MORE ONLINE FRIENDS\"));\n                if (((za.length && sa.length))) {\n                    sa.push(v(((((((((((((((((((\"\\u003Cli class=\\\"separator moreOnlineFriends\\\"\\u003E\" + \"\\u003Cdiv class=\\\"outer\\\"\\u003E\")) + \"\\u003Cdiv class=\\\"inner\\\"\\u003E\")) + \"\\u003Cspan class=\\\"text\\\"\\u003E\")) + ja._(\"{MORE ONLINE FRIENDS} ({=count})\", {\n                        \"MORE ONLINE FRIENDS\": bb,\n                        \"=count\": za.length\n                    }))) + \"\\u003C/span\\u003E\")) + \"\\u003Cdiv class=\\\"dive\\\"\\u003E\\u003Cspan class=\\\"bar\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\")) + \"\\u003C/div\\u003E\")) + \"\\u003C/div\\u003E\")) + \"\\u003C/li\\u003E\"))));\n                }\n            ;\n            ;\n                for (var cb = 0, db = za.length; ((cb < db)); cb++) {\n                    ta = za[cb];\n                    ua = this._getListItem(ta);\n                    if (ua) {\n                        sa.push(ua);\n                    }\n                     else this._renderListItem(ta, this.render.bind(this));\n                ;\n                ;\n                };\n            ;\n                if (((!ra.length && !za.length))) {\n                    var eb = this._messageTemplate.render(), fb = ea.getNode(eb, \"message\");\n                    u.setContent(fb, \"No one is available to chat.\");\n                    sa.push(eb);\n                }\n            ;\n            ;\n                if (sa.length) {\n                    u.setContent(this._root, sa);\n                    o.nukeLinks(this.getRoot());\n                    this.inform(\"render\");\n                }\n            ;\n            ;\n            }, 300, this);\n            this.render();\n        },\n        _renderListItem: function(ra, sa) {\n            aa.get(ra, function(ta) {\n                if (((ta.type === \"friend\"))) {\n                    var ua = this._template.render(), va = ea.getNode(ua, \"profile-photo\");\n                    va.setAttribute(\"src\", ta.thumbSrc);\n                    var wa = ea.getNode(ua, \"JSBNG__name\");\n                    u.setContent(wa, ta.JSBNG__name);\n                    var xa = ea.getNode(ua, \"anchor\");\n                    xa.setAttribute(\"href\", ((\"/messages/\" + ra)));\n                    var ya = ea.getNode(ua, \"timeline_icon\");\n                    if (ya) {\n                        var za = ja._(\"Go to {name}'s timeline\", {\n                            JSBNG__name: ta.firstName\n                        });\n                        ba.set(ya, za, \"above\", \"center\");\n                        JSBNG__Event.listen(ya, \"click\", function(JSBNG__event) {\n                            JSBNG__event.kill();\n                            ia(ta.uri);\n                        });\n                    }\n                ;\n                ;\n                    s.set(ua, \"id\", ra);\n                    this._items[ra] = ua;\n                    ((sa && sa(ua)));\n                }\n            ;\n            ;\n            }.bind(this));\n        },\n        show: function() {\n            if (this._isVisible) {\n                return;\n            }\n        ;\n        ;\n            this._isVisible = true;\n            r.show(this._root);\n            this.render();\n            this.inform(\"show\");\n        },\n        isVisible: function() {\n            return this._isVisible;\n        },\n        update: function() {\n            this._hasRendered = false;\n            this.render();\n        },\n        setScrollContainer: function(ra) {\n            if (u.contains(ra, this._root)) {\n                this._scrollContainer = ra;\n            }\n        ;\n        ;\n        },\n        JSBNG__scrollTo: function(ra) {\n            if (!this._scrollContainer) {\n                return;\n            }\n        ;\n        ;\n            var sa = this._scrollContainer.scrollHeight, ta = this._scrollContainer.clientHeight, ua = this._scrollContainer.scrollTop, va = Math.min(ra.offsetTop, ((sa - ta)));\n            if (((ua !== va))) {\n                var wa = ((((Math.abs(((va - ua))) / this._scrollContainer.clientHeight)) * 500));\n                g(this._scrollContainer).to(\"scrollTop\", va).ease(g.ease.end).duration(wa).go();\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = ma;\n});\n__d(\"TypingIndicator\", [\"Arbiter\",\"AsyncRequest\",\"AvailableList\",\"AvailableListConstants\",\"ChannelManager\",\"ChannelConnection\",\"ChatConfig\",\"ChatVisibility\",\"copyProperties\",\"Keys\",\"ShortProfiles\",\"TypingDetector\",\"PresencePrivacy\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"AvailableList\"), j = b(\"AvailableListConstants\"), k = b(\"ChannelManager\"), l = b(\"ChannelConnection\"), m = b(\"ChatConfig\"), n = b(\"ChatVisibility\"), o = b(\"copyProperties\"), p = b(\"Keys\"), q = b(\"ShortProfiles\"), r = b(\"TypingDetector\"), s = b(\"PresencePrivacy\");\n    function t(v) {\n        if (!n.isOnline()) {\n            return false;\n        }\n    ;\n    ;\n        if (v) {\n            var w = q.getNow(v);\n            return ((((w && ((w.type == \"friend\")))) && s.allows(v)));\n        }\n    ;\n    ;\n        return true;\n    };\n;\n    function u(v, w, x, y, z) {\n        this.userID = v;\n        this.input = w;\n        this.source = x;\n        this.threadID = z;\n        this.remoteState = r.INACTIVE;\n        this.notifyTimer = null;\n        y = ((y || {\n        }));\n        this.notifyDelay = ((y.notifyDelay || this.notifyDelay));\n        this._typingDetector = new r(w);\n        this._typingDetector.init(y);\n        this._typingDetector.subscribe(\"change\", this._stateChange.bind(this));\n    };\n;\n    o(u.prototype, {\n        notifyDelay: 1000,\n        setIgnoreEnter: function(v) {\n            var w = ((v ? [p.RETURN,] : []));\n            this._typingDetector.setIgnoreKeys(w);\n        },\n        resetState: function() {\n            this.remoteState = u.INACTIVE;\n            this._typingDetector.reset();\n            JSBNG__clearTimeout(this.notifyTimer);\n            this.notifyTimer = null;\n        },\n        _stateChange: function(v, w) {\n            if (((w != r.QUITTING))) {\n                JSBNG__clearTimeout(this.notifyTimer);\n                this.notifyTimer = this._notifyState.shield(this, w).defer(this.notifyDelay, false);\n            }\n             else this._notifyState(w, true);\n        ;\n        ;\n        },\n        _notifyState: function(v, w) {\n            var x = this.userID, y = t(x);\n            if (((y && ((v != this.remoteState))))) {\n                this.remoteState = v;\n                if (l.disconnected()) {\n                    return;\n                }\n            ;\n            ;\n                var z = {\n                    typ: v,\n                    to: x,\n                    source: this.source,\n                    thread: this.threadID\n                };\n                new h().setHandler(this._onTypResponse.bind(this, x)).setErrorHandler(bagofholding).setData(z).setURI(\"/ajax/messaging/typ.php\").setAllowCrossPageTransition(true).setOption(\"asynchronous\", !w).send();\n            }\n        ;\n        ;\n        },\n        _onTypResponse: function(v, w) {\n            var x = ((w.getPayload() || {\n            }));\n            if (x.offline) {\n                i.set(v, j.OFFLINE, \"typing_response\");\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = u;\n});\n__d(\"ChatBehavior\", [\"Arbiter\",\"AvailableList\",\"AvailableListConstants\",\"copyProperties\",\"MercuryConstants\",\"ChatSidebarCalloutData\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AvailableList\"), i = b(\"AvailableListConstants\"), j = b(\"copyProperties\"), k = c(\"MercuryConstants\").ChatNotificationConstants, l = c(\"ChatSidebarCalloutData\").isShown, m = h.getWebChatNotification(), n = l, o = j(new g(), {\n        ON_CHANGED: \"changed\",\n        notifiesUserMessages: function() {\n            return ((m !== k.NO_USER_MESSAGE_NOTIFICATION));\n        },\n        ignoresRemoteTabRaise: function() {\n            return n;\n        }\n    });\n    function p() {\n        o.inform(o.ON_CHANGED);\n    };\n;\n    h.subscribe(i.ON_CHAT_NOTIFICATION_CHANGED, function() {\n        var q = m, r = h.getWebChatNotification();\n        m = r;\n        if (((q != r))) {\n            p();\n        }\n    ;\n    ;\n    });\n    g.subscribe(\"chat/set_does_page_occlude_tabs\", function(q, r) {\n        n = !!r;\n        p();\n    });\n    e.exports = o;\n});\n__d(\"ChatSidebarSheet\", [\"event-extensions\",\"function-extensions\",\"ArbiterMixin\",\"ChannelConnection\",\"ChannelConstants\",\"ChatBehavior\",\"ChatConfig\",\"ChatVisibility\",\"Class\",\"CSS\",\"DOM\",\"JSLogger\",\"PresencePrivacy\",\"copyProperties\",\"tx\",\"MercuryConfig\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"ChannelConnection\"), i = b(\"ChannelConstants\"), j = b(\"ChatBehavior\"), k = b(\"ChatConfig\"), l = b(\"ChatVisibility\"), m = b(\"Class\"), n = b(\"CSS\"), o = b(\"DOM\"), p = b(\"JSLogger\"), q = b(\"PresencePrivacy\"), r = b(\"copyProperties\"), s = b(\"tx\"), t = c(\"MercuryConfig\"), u = p.create(\"sidebar_sheet\");\n    function v(y) {\n        switch (y) {\n          case i.HINT_AUTH:\n            return \"Your session has timed out. Please log in.\";\n          case i.HINT_CONN:\n            return s._(\"Facebook {Chat} is currently unavailable.\", {\n                Chat: \"Chat\"\n            });\n          case i.HINT_MAINT:\n            return s._(\"Facebook {Chat} is currently down for maintenance.\", {\n                Chat: \"Chat\"\n            });\n          default:\n            return s._(\"Facebook {Chat} is currently unavailable.\", {\n                Chat: \"Chat\"\n            });\n        };\n    ;\n    };\n;\n    function w(y) {\n        var z;\n        if (((y === null))) {\n            z = \"Unable to connect to chat. Check your Internet connection.\";\n        }\n         else if (((y > k.get(\"warning_countdown_threshold_msec\")))) {\n            var aa = o.create(\"a\", {\n                href: \"#\",\n                className: \"fbChatReconnectLink\"\n            }, \"Try again\");\n            z = o.tx._(\"Unable to connect to chat. {try-again-link}\", {\n                \"try-again-link\": aa\n            });\n        }\n         else if (((y > 1000))) {\n            z = s._(\"Unable to connect to chat. Reconnecting in {seconds}...\", {\n                seconds: Math.floor(((y / 1000)))\n            });\n        }\n         else z = \"Unable to connect to chat. Reconnecting...\";\n        \n        \n    ;\n    ;\n        return z;\n    };\n;\n    function x(y) {\n        this._root = y;\n        this._message = o.JSBNG__find(y, \"div.fbChatSidebarMessage div.message\");\n        h.subscribe([h.CONNECTED,h.SHUTDOWN,h.RECONNECTING,], this._handleConnectionChange.bind(this));\n        h.subscribe([h.MUTE_WARNING,h.UNMUTE_WARNING,], this._render.bind(this));\n        q.subscribe(\"privacy-user-presence-changed\", this._render.bind(this));\n        j.subscribe(j.ON_CHANGED, this._render.bind(this));\n        this._render();\n    };\n;\n    r(x.prototype, g, {\n        _channelStatus: null,\n        _channelData: null,\n        _handleConnectionChange: function(y, z) {\n            this._channelStatus = y;\n            this._channelData = z;\n            this._render();\n        },\n        _showWarningTimeout: null,\n        _warningMsgEventListener: null,\n        _renderChannelDisconnect: function() {\n            if (((this._channelStatus === h.SHUTDOWN))) {\n                return o.setContent(this._message, v(this._channelData));\n            }\n             else if (((this._channelStatus === h.RECONNECTING))) {\n                var y = this._channelData;\n                o.setContent(this._message, w(y));\n                if (((y > 1000))) {\n                    if (((y > k.get(\"warning_countdown_threshold_msec\")))) {\n                        this._warningMsgEventListener = JSBNG__Event.listen(this._message, \"click\", function(JSBNG__event) {\n                            if (n.hasClass(JSBNG__event.getTarget(), \"fbChatReconnectLink\")) {\n                                h.reconnect();\n                                return false;\n                            }\n                        ;\n                        ;\n                        });\n                    }\n                ;\n                ;\n                    this._showWarningTimeout = JSBNG__setTimeout(this._handleConnectionChange.bind(this, h.RECONNECTING, ((y - 1000))), 1000, false);\n                }\n            ;\n            ;\n            }\n            \n        ;\n        ;\n        },\n        _goOnlineEventListener: null,\n        _renderOffline: function() {\n            var y = \"fbChatGoOnlineLink\", z = ((t.ChatControlLanguageChangeGK ? \"Turn on chat\" : \"Go online\")), aa = o.create(\"a\", {\n                href: \"#\",\n                className: y\n            }, z), ba;\n            if (t.ChatControlLanguageChangeGK) {\n                ba = o.tx._(\"{=Go online} to see who's available.\", {\n                    \"=Go online\": aa\n                });\n            }\n             else ba = o.tx._(\"{=Go online} to see who's online to chat.\", {\n                \"=Go online\": aa\n            });\n        ;\n        ;\n            o.setContent(this._message, ba);\n            this._goOnlineEventListener = JSBNG__Event.listen(this._message, \"click\", function(JSBNG__event) {\n                if (n.hasClass(JSBNG__event.getTarget(), y)) {\n                    u.log(\"sidebar_go_online\");\n                    l.goOnline();\n                    return false;\n                }\n            ;\n            ;\n            });\n        },\n        _clear: function() {\n            if (this._showWarningTimeout) {\n                JSBNG__clearTimeout(this._showWarningTimeout);\n                this._showWarningTimeout = null;\n            }\n        ;\n        ;\n            if (this._warningMsgEventListener) {\n                this._warningMsgEventListener.remove();\n                this._warningMsgEventListener = null;\n            }\n        ;\n        ;\n            if (this._goOnlineEventListener) {\n                this._goOnlineEventListener.remove();\n                this._goOnlineEventListener = null;\n            }\n        ;\n        ;\n            n.removeClass(this._root, \"offline\");\n            n.removeClass(this._root, \"error\");\n            n.removeClass(this._root, \"notice\");\n            o.empty(this._message);\n        },\n        _render: function() {\n            this._clear();\n            if (!l.isOnline()) {\n                n.addClass(this._root, \"offline\");\n                this._renderOffline();\n            }\n             else if (h.disconnected()) {\n                n.addClass(this._root, \"error\");\n                this._renderChannelDisconnect();\n            }\n             else if (!j.notifiesUserMessages()) {\n                n.addClass(this._root, \"notice\");\n                o.setContent(this._message, \"Alerts are off while you use another client to chat.\");\n            }\n            \n            \n        ;\n        ;\n            this.inform(\"updated\");\n        }\n    });\n    e.exports = x;\n});\n__d(\"ChatTypeaheadBehavior\", [\"Chat\",\"CSS\",\"DOM\",\"JSBNG__Rect\",\"copyProperties\",\"tx\",], function(a, b, c, d, e, f) {\n    var g = b(\"Chat\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"JSBNG__Rect\"), k = b(\"copyProperties\"), l = b(\"tx\");\n    function m(n) {\n        this._typeahead = n;\n    };\n;\n    k(m.prototype, {\n        _subscriptions: null,\n        enable: function() {\n            var n = this._typeahead;\n            this._subscriptions = [n.subscribe(\"JSBNG__focus\", function() {\n                n.getData().refreshData();\n            }),n.subscribe(\"JSBNG__blur\", function(o) {\n                n.getCore().reset();\n            }),n.subscribe(\"respond\", function(o, p) {\n                if (((p.value && ((p.value === n.getCore().getValue()))))) {\n                    if (!p.results.length) {\n                        var q = i.create(\"div\", {\n                            className: \"noResults\"\n                        }, \"Friend not found.\");\n                        i.setContent(n.getView().getElement(), q);\n                    }\n                ;\n                ;\n                    h.addClass(n.getElement(), \"hasValue\");\n                }\n            ;\n            ;\n            }),n.subscribe(\"reset\", function() {\n                h.removeClass(n.getElement(), \"hasValue\");\n            }),n.subscribe(\"select\", function(o, p) {\n                g.openTab(p.selected.uid, p.selected.text, p.selected.type, \"typeahead\");\n            }),n.subscribe(\"highlight\", function(o, p) {\n                if (((p.index >= 0))) {\n                    var q = n.getView().getItems()[p.index];\n                    if (q) {\n                        var r = new j(q), s = q.offsetParent, t = r.boundWithin(new j(s)).getPositionVector();\n                        r.getPositionVector().sub(t).scrollElementBy(s);\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            }),];\n        },\n        disable: function() {\n            this._subscriptions.forEach(function(n) {\n                this._typeahead.unsubscribe(n);\n            }.bind(this));\n            this._subscriptions = null;\n        }\n    });\n    e.exports = m;\n});\n__d(\"ChatTypeaheadCore\", [\"event-extensions\",\"function-extensions\",\"Class\",\"Keys\",\"TypeaheadCore\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Class\"), h = b(\"Keys\"), i = b(\"TypeaheadCore\"), j = b(\"copyProperties\");\n    function k(l) {\n        this.parent.construct(this, l);\n    };\n;\n    g.extend(k, i);\n    j(k.prototype, {\n        handleTab: bagofholding,\n        keydown: function(JSBNG__event) {\n            var l = JSBNG__Event.getKeyCode(JSBNG__event);\n            if (((l === h.ESC))) {\n                this.reset.shield(this).defer();\n                return JSBNG__event.kill();\n            }\n        ;\n        ;\n            return this.parent.keydown(JSBNG__event);\n        }\n    });\n    e.exports = k;\n});\n__d(\"ChatTypeaheadDataSource\", [\"Arbiter\",\"AvailableListConstants\",\"Class\",\"DataSource\",\"Env\",\"JSLogger\",\"OrderedFriendsList\",\"Run\",\"ShortProfiles\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AvailableListConstants\"), i = b(\"Class\"), j = b(\"DataSource\"), k = b(\"Env\"), l = b(\"JSLogger\"), m = b(\"OrderedFriendsList\"), n = b(\"Run\"), o = b(\"ShortProfiles\"), p = b(\"copyProperties\");\n    function q(r) {\n        this.parent.construct(this, r);\n        this.persistOnRefresh = ((r.persistOnRefresh !== false));\n        this.showOfflineUsers = !!r.showOfflineUsers;\n        this._jslog = l.create(\"chat_typeahead\");\n        this._jslog.log(\"created\");\n    };\n;\n    i.extend(q, j);\n    p(q.prototype, {\n        init: function() {\n            this._jslog.log(\"init\");\n            this.parent.init();\n            var r = g.subscribe(h.ON_AVAILABILITY_CHANGED, this._update.shield(this));\n            this._update();\n            if (!this.persistOnRefresh) {\n                n.JSBNG__onLeave(function() {\n                    r.unsubscribe();\n                });\n            }\n        ;\n        ;\n        },\n        bootstrap: function() {\n            this._jslog.log(\"bootstrap\");\n            this.parent.bootstrap();\n            if (this.showOfflineUsers) {\n                this._jslog.log(\"show_offline_users\");\n                this._jslog.log(\"ensured_short_profiles\");\n                if (o.hasAll()) {\n                    this._update();\n                }\n                 else {\n                    this._jslog.log(\"fetch_all_short_profiles\");\n                    o.fetchAll();\n                    this.inform(\"activity\", {\n                        activity: true\n                    });\n                    var r = o.subscribe(\"updated\", function() {\n                        this.inform(\"activity\", {\n                            activity: false\n                        });\n                        this._update();\n                    }.bind(this));\n                    if (!this.persistOnRefresh) {\n                        n.JSBNG__onLeave(function() {\n                            o.unsubscribe(r);\n                        });\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        _update: function() {\n            d([\"AvailableList\",], function(r) {\n                var s = this.value;\n                this.dirty();\n                var t = o.getCachedProfileIDs(), u = t.filter(function(w) {\n                    var x = o.getNow(w);\n                    return ((x.type === \"friend\"));\n                });\n                u.sort(m.compare);\n                var v = [];\n                u.forEach(function(w) {\n                    if (((w == k.user))) {\n                        return;\n                    }\n                ;\n                ;\n                    var x = r.get(w);\n                    if (((!this.showOfflineUsers && ((x !== r.ACTIVE))))) {\n                        return;\n                    }\n                ;\n                ;\n                    var y = o.getNow(w);\n                    v.push({\n                        uid: w,\n                        text: y.JSBNG__name,\n                        tokens: y.additionalName,\n                        localized_text: y.JSBNG__name,\n                        additional_text: y.additionalName,\n                        photo: y.thumbSrc,\n                        availability: x,\n                        type: y.type\n                    });\n                }.bind(this));\n                if (v.length) {\n                    this.addEntries(v);\n                }\n            ;\n            ;\n                this.value = s;\n                if (s) {\n                    this.respond(s, this.buildUids(s, [], this._exclusions), true);\n                }\n            ;\n            ;\n            }.bind(this));\n        },\n        refreshData: function() {\n            d([\"AvailableList\",], function(r) {\n                r.update();\n            }.bind(this));\n        }\n    });\n    e.exports = q;\n});\n__d(\"ChatSidebar\", [\"JSXDOM\",\"event-extensions\",\"Arbiter\",\"ArbiterMixin\",\"AsyncRequest\",\"ChatConfig\",\"ChatHovercard\",\"ChatOptions\",\"ChatQuietLinks\",\"ChatSidebarSheet\",\"CSS\",\"DOM\",\"FBDesktopPlugin\",\"JSLogger\",\"OrderedFriendsList\",\"PresencePrivacy\",\"ScrollableArea\",\"Style\",\"Vector\",\"ViewportBounds\",\"copyProperties\",\"createArrayFrom\",\"debounce\",\"ChatOrderedList\",\"ChatTypeaheadBehavior\",\"ChatTypeaheadCore\",\"ChatTypeaheadDataSource\",\"ChatTypeaheadRenderer\",\"Typeahead\",], function(a, b, c, d, e, f) {\n    var g = b(\"JSXDOM\"), g = b(\"JSXDOM\");\n    b(\"event-extensions\");\n    var h = b(\"Arbiter\"), i = b(\"ArbiterMixin\"), j = b(\"AsyncRequest\"), k = b(\"ChatConfig\"), l = b(\"ChatHovercard\"), m = b(\"ChatOptions\"), n = b(\"ChatQuietLinks\"), o = b(\"ChatSidebarSheet\"), p = b(\"CSS\"), q = b(\"DOM\"), r = b(\"FBDesktopPlugin\"), s = b(\"JSLogger\"), t = b(\"OrderedFriendsList\"), u = b(\"PresencePrivacy\"), v = b(\"ScrollableArea\"), w = b(\"Style\"), x = b(\"Vector\"), y = b(\"ViewportBounds\"), z = b(\"copyProperties\"), aa = b(\"createArrayFrom\"), ba = b(\"debounce\");\n    b(\"ChatOrderedList\");\n    b(\"ChatTypeaheadBehavior\");\n    b(\"ChatTypeaheadCore\");\n    b(\"ChatTypeaheadDataSource\");\n    b(\"ChatTypeaheadRenderer\");\n    b(\"Typeahead\");\n    var ca, da = false, ea = false, fa = false, ga = false, ha = false, ia = false, ja, ka, la, ma, na = null, oa = s.create(\"chat_sidebar\"), pa = 32;\n    function qa() {\n        p.removeClass(JSBNG__document.documentElement, \"sidebarMode\");\n        if (((!ha || !wa.isVisible()))) {\n            return;\n        }\n    ;\n    ;\n        ga = false;\n        na = null;\n        p.hide(ka);\n        ja.hide();\n        la.getCore().reset();\n        oa.rate(\"sidebar_hide\", ha);\n        wa.inform(\"sidebar/hide\", wa);\n        h.inform(\"sidebar/hide\", wa);\n        h.inform(\"reflow\");\n    };\n;\n    function ra() {\n        var xa = wa.shouldShowSidebar();\n        p.conditionClass(JSBNG__document.documentElement, \"sidebarCapable\", xa);\n        if (((wa.isEnabled() && xa))) {\n            sa();\n            var ya = ma.y;\n            aa(ka.childNodes).forEach(function(za) {\n                if (((za !== ca))) {\n                    ya -= x.getElementDimensions(za).y;\n                }\n            ;\n            ;\n            });\n            ya = Math.max(0, ya);\n            w.set(ca, \"height\", ((ya + \"px\")));\n            this._maxItems = Math.floor(((((ya - 8)) / pa)));\n            ja.setNumTopFriends(this._maxItems);\n            la.getData().setMaxResults(this._maxItems);\n            wa.inform(\"sidebar/resized\", wa);\n            h.inform(\"sidebar/resized\", wa);\n            h.inform(\"reflow\");\n        }\n         else qa();\n    ;\n    ;\n        if (!ha) {\n            va();\n            ha = true;\n        }\n    ;\n    ;\n        na = null;\n    };\n;\n    function sa() {\n        if (wa.isVisible()) {\n            return;\n        }\n    ;\n    ;\n        ga = true;\n        na = null;\n        p.show(ka);\n        p.addClass(JSBNG__document.documentElement, \"sidebarMode\");\n        ja.show();\n        oa.rate(\"sidebar_show\", ha);\n        wa.inform(\"sidebar/show\", wa);\n        h.inform(\"sidebar/show\", wa);\n    };\n;\n    function ta() {\n        m.setSetting(\"sidebar_mode\", wa.isEnabled(), \"sidebar\");\n        new j(\"/ajax/chat/settings.php\").setHandler(bagofholding).setErrorHandler(bagofholding).setData({\n            sidebar_mode: wa.isEnabled()\n        }).setAllowCrossPageTransition(true).send();\n    };\n;\n    function ua() {\n        return ((t.getList().length <= k.get(\"sidebar.min_friends\")));\n    };\n;\n    function va() {\n        var xa = true;\n        if (!wa.isEnabled()) {\n            oa.log(\"state_not_enabled\");\n            xa = false;\n        }\n    ;\n    ;\n        if (!wa.isViewportCapable()) {\n            oa.log(\"state_not_shown_viewport\");\n            xa = false;\n        }\n    ;\n    ;\n        if (fa) {\n            oa.log(\"state_not_shown_hidden\");\n            xa = false;\n        }\n    ;\n    ;\n        if (ua()) {\n            oa.log(\"state_not_shown_num_friends\");\n            xa = false;\n        }\n    ;\n    ;\n        if (r.shouldSuppressSidebar()) {\n            oa.log(\"state_not_shown_fbdesktop\");\n            xa = false;\n        }\n    ;\n    ;\n        oa.log(((xa ? \"state_shown\" : \"state_not_shown\")));\n    };\n;\n    var wa = {\n        init: function(xa, ya, za) {\n            wa.init = bagofholding;\n            ia = true;\n            ka = xa;\n            ja = ya;\n            la = za;\n            ca = q.JSBNG__find(xa, \"div.fbChatSidebarBody\");\n            if (k.get(\"chat_sidebar_hovercards\")) {\n                new l(ya);\n            }\n        ;\n        ;\n            var ab = new o(xa);\n            ab.subscribe(\"updated\", ra);\n            h.subscribe(\"sidebar/invalidate\", ra);\n            ya.setScrollContainer(q.JSBNG__find(ca, \"div.uiScrollableAreaWrap\"));\n            ya.subscribe([\"render\",\"show\",\"hide\",], ba(function() {\n                var bb = ya.getRoot(), cb = v.getInstance(bb);\n                ((cb && cb.adjustGripper()));\n            }));\n            JSBNG__Event.listen(window, \"resize\", ra);\n            h.subscribe(\"chat/option-changed\", function(bb, cb) {\n                if (((cb.JSBNG__name == \"sidebar_mode\"))) {\n                    ea = !!m.getSetting(\"sidebar_mode\");\n                    ra();\n                }\n            ;\n            ;\n            });\n            za.subscribe([\"respond\",\"reset\",], function(bb, cb) {\n                if (ga) {\n                    if (((((((cb && cb.value)) && ((cb.value === za.getCore().getValue())))) && za.getView().isVisible()))) {\n                        ja.hide();\n                    }\n                     else ja.show();\n                ;\n                }\n            ;\n            ;\n            });\n            za.getData().subscribe(\"beforeQuery\", ra);\n            h.subscribe(\"buddylist-nub/initialized\", function(bb, cb) {\n                JSBNG__Event.listen(cb.getButton(), \"click\", function(JSBNG__event) {\n                    wa.enable();\n                    return !wa.shouldShowSidebar();\n                });\n            });\n            ea = !!m.getSetting(\"sidebar_mode\");\n            u.subscribe(\"privacy-user-presence-changed\", ra);\n            ra();\n            y.addRight(wa.getVisibleWidth);\n            wa.inform(\"sidebar/initialized\", wa, h.BEHAVIOR_PERSISTENT);\n            h.inform(\"sidebar/initialized\", wa, h.BEHAVIOR_PERSISTENT);\n        },\n        isInitialized: function() {\n            return ha;\n        },\n        disable: function() {\n            if (!wa.isEnabled()) {\n                return;\n            }\n        ;\n        ;\n            ea = false;\n            ta();\n            qa();\n        },\n        enable: function() {\n            if (wa.isEnabled()) {\n                return;\n            }\n        ;\n        ;\n            ea = true;\n            ta();\n            ra();\n            !function() {\n                if (wa.isVisible()) {\n                    la.getCore().getElement().JSBNG__focus();\n                }\n            ;\n            ;\n            }.defer();\n        },\n        ensureLoaded: function() {\n            if (ia) {\n                return;\n            }\n        ;\n        ;\n            d([\"UIPagelet\",], function(xa) {\n                var ya = g.div({\n                    id: \"pagelet_sidebar\"\n                });\n                q.appendContent(JSBNG__document.body, ya);\n                xa.loadFromEndpoint(\"SidebarPagelet\", \"pagelet_sidebar\");\n            });\n            ia = true;\n        },\n        hide: function() {\n            if (fa) {\n                return;\n            }\n        ;\n        ;\n            fa = true;\n            qa();\n        },\n        unhide: function() {\n            if (!fa) {\n                return;\n            }\n        ;\n        ;\n            fa = false;\n            ra();\n        },\n        getBody: function() {\n            return ca;\n        },\n        getRoot: function() {\n            return ka;\n        },\n        getVisibleWidth: function() {\n            if (((!ga || !ka))) {\n                return 0;\n            }\n        ;\n        ;\n            if (((na === null))) {\n                na = ka.offsetWidth;\n            }\n        ;\n        ;\n            return na;\n        },\n        isEnabled: function() {\n            return ea;\n        },\n        isViewportCapable: function() {\n            ma = x.getViewportDimensions();\n            var xa = k.get(\"sidebar.minimum_width\");\n            if (da) {\n                xa = k.get(\"sidebar.minimum_width_wide_content\");\n            }\n        ;\n        ;\n            return ((ma.x > xa));\n        },\n        shouldShowSidebar: function() {\n            return ((((((wa.isViewportCapable() && !fa)) && !ua())) && !r.shouldSuppressSidebar()));\n        },\n        isVisible: function() {\n            return ga;\n        },\n        resize: ra,\n        toggle: function() {\n            ((wa.isEnabled() ? wa.disable() : wa.enable()));\n        },\n        setHasWideContent: function(xa) {\n            if (((da != xa))) {\n                da = xa;\n                ra();\n            }\n        ;\n        ;\n        }\n    };\n    z(wa, i);\n    e.exports = wa;\n});\n__d(\"VideoCallingTour\", [\"event-extensions\",\"Arbiter\",\"ArbiterMixin\",\"Chat\",\"ChatSidebar\",\"ChatVisibility\",\"CSS\",\"DOM\",\"PresencePrivacy\",\"Run\",\"Toggler\",\"Vector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"Chat\"), j = b(\"ChatSidebar\"), k = b(\"ChatVisibility\"), l = b(\"CSS\"), m = b(\"DOM\"), n = b(\"PresencePrivacy\"), o = b(\"Run\"), p = b(\"Toggler\"), q = b(\"Vector\"), r = b(\"copyProperties\"), s, t, u, v, w = [], x = function() {\n    \n    };\n    function y() {\n        if (j.isVisible()) {\n            z();\n        }\n         else if (u) {\n            aa();\n        }\n        \n    ;\n    ;\n    };\n;\n    function z() {\n        s.setContext(t.getBody());\n        ba();\n        s.show();\n        ca();\n    };\n;\n    function aa() {\n        if (!v) {\n            v = p.createInstance(u.getRoot());\n        }\n    ;\n    ;\n        var fa = m.scry(u.getRoot(), \"div.fbNubFlyout\")[0];\n        if (fa) {\n            s.setContext(fa);\n            ba();\n            s.show();\n            ca();\n        }\n    ;\n    ;\n    };\n;\n    function ba() {\n        var fa = q.getElementDimensions(s.getContext()).y;\n        s.setOffsetY(((fa * 84185)));\n        s.updatePosition();\n    };\n;\n    function ca() {\n        if (u) {\n            w.push(u.subscribe(\"hide\", function() {\n                da();\n                if (!j.isVisible()) {\n                    s.hide();\n                }\n            ;\n            ;\n            }), u.subscribe(\"show\", function() {\n                s.show();\n            }), u.subscribe(\"resize\", function() {\n                ba();\n                s.updatePosition();\n            }));\n        }\n    ;\n    ;\n        w.push(g.subscribe(\"sidebar/show\", z), g.subscribe(\"sidebar/hide\", aa), g.subscribe(\"sidebar/resized\", ba));\n    };\n;\n    function da() {\n        if (v) {\n            v.setSticky(false);\n            v = null;\n        }\n    ;\n    ;\n    };\n;\n    function ea() {\n        while (w.length) {\n            w.pop().unsubscribe();\n        ;\n        };\n    ;\n        if (u) {\n            da();\n        }\n    ;\n    ;\n        s.hide();\n        l.show(\"fbVideoCallingGetStarted\");\n    };\n;\n    r(x, h, {\n        start: function(fa) {\n            s = fa;\n            l.hide(\"fbVideoCallingGetStarted\");\n            k.goOnline(function() {\n                w.push(n.subscribe(\"privacy-user-presence-changed\", ea));\n                o.JSBNG__onLeave(ea);\n                i.openBuddyList();\n                var ga = null;\n                w.push(j.subscribe(\"sidebar/initialized\", function(ha, ia) {\n                    t = ia;\n                    JSBNG__clearTimeout(ga);\n                    ga = y.defer();\n                }), x.subscribe(\"videocallingtour/end\", ea));\n                w.push(g.subscribe(\"buddylist-nub/initialized\", function(ha, ia) {\n                    u = ia;\n                    JSBNG__clearTimeout(ga);\n                    ga = y.defer();\n                }));\n            });\n            x.inform(\"videocallingtour/start\");\n        }\n    });\n    e.exports = x;\n});\n__d(\"ModuleDependencies\", [\"getObjectValues\",], function(a, b, c, d, e, f) {\n    var g = b(\"getObjectValues\");\n    function h(l, m, n) {\n        var o = a.require.__debug.modules[n], p = a.require.__debug.deps;\n        if (m[n]) {\n            return;\n        }\n    ;\n    ;\n        m[n] = true;\n        if (!o) {\n            ((p[n] && (l[n] = true)));\n            return;\n        }\n    ;\n    ;\n        if (((!o.dependencies || !o.dependencies.length))) {\n            if (o.waiting) {\n                l[n] = true;\n            }\n        ;\n        ;\n            return;\n        }\n    ;\n    ;\n        o.dependencies.forEach(function(q) {\n            h(l, m, q);\n        });\n    };\n;\n    function i(l) {\n        if (a.require.__debug) {\n            var m = {\n            };\n            h(m, {\n            }, l);\n            var n = Object.keys(m);\n            n.sort();\n            return n;\n        }\n    ;\n    ;\n        return null;\n    };\n;\n    function j() {\n        var l = {\n            loading: {\n            },\n            missing: []\n        };\n        if (!a.require.__debug) {\n            return l;\n        }\n    ;\n    ;\n        var m = {\n        }, n = a.require.__debug.modules, o = a.require.__debug.deps;\n        for (var p in n) {\n            var q = n[p];\n            if (q.waiting) {\n                var r = {\n                };\n                h(r, {\n                }, q.id);\n                delete r[q.id];\n                l.loading[q.id] = Object.keys(r);\n                l.loading[q.id].sort();\n                l.loading[q.id].forEach(function(s) {\n                    if (((!((s in n)) && o[s]))) {\n                        m[s] = 1;\n                    }\n                ;\n                ;\n                });\n            }\n        ;\n        ;\n        };\n    ;\n        l.missing = Object.keys(m);\n        l.missing.sort();\n        return l;\n    };\n;\n    var k = {\n        getMissing: i,\n        getNotLoadedModules: j\n    };\n    e.exports = k;\n});\n__d(\"legacy:ChatSidebar\", [\"ModuleDependencies\",\"JSLogger\",], function(a, b, c, d) {\n    d([\"ChatSidebar\",], function(i) {\n        a.ChatSidebar = i;\n    });\n    var e = b(\"ModuleDependencies\"), f = b(\"JSLogger\"), g = f.create(\"chat_sidebar_load\");\n    function h(i) {\n        JSBNG__setTimeout(function() {\n            if (!a.ChatSidebar) {\n                var j = e.getMissing(\"ChatSidebar\");\n                g.warn(((\"require_\" + i)), {\n                    missing: j\n                });\n            }\n        ;\n        ;\n            if (((!a.ChatSidebar || !a.ChatSidebar.isInitialized()))) {\n                g.warn(((\"init_\" + i)), {\n                    missing: j\n                });\n            }\n        ;\n        ;\n        }, i);\n    };\n;\n    h(5000);\n    h(10000);\n    h(15000);\n    h(30000);\n    h(60000);\n}, 3);\n__d(\"legacy:ChatTypeaheadBehavior\", [\"ChatTypeaheadBehavior\",], function(a, b, c, d) {\n    var e = b(\"ChatTypeaheadBehavior\");\n    if (!a.TypeaheadBehaviors) {\n        a.TypeaheadBehaviors = {\n        };\n    }\n;\n;\n    a.TypeaheadBehaviors.chatTypeahead = function(f) {\n        f.enableBehavior(e);\n    };\n}, 3);\n__d(\"RangedCallbackManager\", [\"CallbackManagerController\",\"copyProperties\",\"createObjectFrom\",], function(a, b, c, d, e, f) {\n    var g = b(\"CallbackManagerController\"), h = b(\"copyProperties\"), i = b(\"createObjectFrom\"), j = function(k, l, m) {\n        this._resources = [];\n        this._reachedEndOfArray = false;\n        this._existingIDs = {\n        };\n        this._controller = new g(this._constructCallbackArg.bind(this));\n        this._getValueHandler = k;\n        this._compareValuesHandler = l;\n        this._skipOnStrictHandler = m;\n    };\n    h(j.prototype, {\n        executeOrEnqueue: function(k, l, m, n) {\n            return this._controller.executeOrEnqueue({\n                start: k,\n                limit: l\n            }, m, {\n                strict: !!n\n            });\n        },\n        unsubscribe: function(k) {\n            this._controller.unsubscribe(k);\n        },\n        getUnavailableResources: function(k) {\n            var l = this._controller.getRequest(k), m = [];\n            if (((l && !this._reachedEndOfArray))) {\n                var n = l.request, o = this._filterForStrictResults(l.options), p = ((n.start + n.limit));\n                for (var q = o.length; ((q < p)); q++) {\n                    m.push(q);\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            return m;\n        },\n        addResources: function(k) {\n            k.forEach(function(l) {\n                if (!this._existingIDs[l]) {\n                    this._existingIDs[l] = true;\n                    this._resources.push(l);\n                }\n            ;\n            ;\n            }.bind(this));\n            this.resortResources();\n            this._controller.runPossibleCallbacks();\n        },\n        addResourcesWithoutSorting: function(k, l) {\n            var m = this._resources.slice(0, l);\n            m = m.concat(k);\n            m = m.concat(this._resources.slice(l));\n            this._resources = m;\n            h(this._existingIDs, i(k, true));\n            this._controller.runPossibleCallbacks();\n        },\n        removeResources: function(k) {\n            k.forEach(function(l) {\n                if (this._existingIDs[l]) {\n                    this._existingIDs[l] = false;\n                    this._resources.remove(l);\n                }\n            ;\n            ;\n            }.bind(this));\n        },\n        removeAllResources: function() {\n            this._resources = [];\n            this._existingIDs = {\n            };\n        },\n        resortResources: function() {\n            this._resources = this._resources.sort(function(k, l) {\n                return this._compareValuesHandler(this._getValueHandler(k), this._getValueHandler(l));\n            }.bind(this));\n        },\n        setReachedEndOfArray: function() {\n            if (!this._reachedEndOfArray) {\n                this._reachedEndOfArray = true;\n                this._controller.runPossibleCallbacks();\n            }\n        ;\n        ;\n        },\n        hasReachedEndOfArray: function() {\n            return this._reachedEndOfArray;\n        },\n        hasResource: function(k) {\n            return this._existingIDs[k];\n        },\n        getResourceAtIndex: function(k) {\n            return this._resources[k];\n        },\n        getAllResources: function() {\n            return this._resources.concat();\n        },\n        getCurrentArraySize: function() {\n            return this._resources.length;\n        },\n        _filterForStrictResults: function(k) {\n            var l = this._resources;\n            if (((((k && k.strict)) && this._skipOnStrictHandler))) {\n                l = l.filter(this._skipOnStrictHandler);\n            }\n        ;\n        ;\n            return l;\n        },\n        _constructCallbackArg: function(k, l) {\n            var m = this._filterForStrictResults(l);\n            if (((!this._reachedEndOfArray && ((((k.start + k.limit)) > m.length))))) {\n                return false;\n            }\n             else return m.slice(k.start, ((k.start + k.limit)))\n        ;\n        },\n        getElementsUntil: function(k) {\n            var l = [];\n            for (var m = 0; ((m < this._resources.length)); m++) {\n                var n = this._getValueHandler(this._resources[m]);\n                if (((this._compareValuesHandler(n, k) > 0))) {\n                    break;\n                }\n            ;\n            ;\n                l.push(this._resources[m]);\n            };\n        ;\n            return l;\n        }\n    });\n    e.exports = j;\n});\n__d(\"TimestampConverter\", [\"JSLogger\",], function(a, b, c, d, e, f) {\n    var g = b(\"JSLogger\"), h = g.create(\"timestamp_converter\");\n    function i(k) {\n        return ((((typeof (k) == \"string\")) && ((k.length > 6))));\n    };\n;\n    var j = {\n        convertActionIDToTimestamp: function(k) {\n            if (i(k)) {\n                var l = k.slice(0, -6);\n                return parseInt(l, 10);\n            }\n        ;\n        ;\n        },\n        maxValidActionID: function(k, l) {\n            if (!i(k)) {\n                return l;\n            }\n        ;\n        ;\n            if (!i(l)) {\n                return k;\n            }\n        ;\n        ;\n            return ((this.isGreaterThan(k, l) ? k : l));\n        },\n        isGreaterThan: function(k, l) {\n            if (((!i(k) || !i(l)))) {\n                return false;\n            }\n        ;\n        ;\n            return ((this.convertActionIDToTimestamp(k) > this.convertActionIDToTimestamp(l)));\n        }\n    };\n    e.exports = j;\n});\n__d(\"MercuryFolders\", [\"array-extensions\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    var g = c(\"MercuryConstants\"), h = [g.MessagingTag.INBOX,g.MessagingTag.OTHER,g.MessagingTag.ACTION_ARCHIVED,g.MessagingTag.SPAM,], i = {\n        getSupportedFolders: function() {\n            return h.concat();\n        },\n        isSupportedFolder: function(j) {\n            return h.contains(j);\n        },\n        getFromMeta: function(j) {\n            var k = j.folder;\n            if (j.is_archived) {\n                k = g.MessagingTag.ACTION_ARCHIVED;\n            }\n        ;\n        ;\n            return k;\n        }\n    };\n    e.exports = i;\n});\n__d(\"MercuryIDs\", [], function(a, b, c, d, e, f) {\n    function g(h) {\n        return ((((typeof h === \"string\")) && ((h.indexOf(\":\") !== -1))));\n    };\n;\n    e.exports = {\n        isValid: function(h) {\n            if (!h) {\n                return false;\n            }\n        ;\n        ;\n            return g(h);\n        },\n        tokenize: function(h) {\n            if (!this.isValid(h)) {\n                throw \"bad_id_format\";\n            }\n        ;\n        ;\n            var i = h.indexOf(\":\");\n            return {\n                type: h.substr(0, i),\n                value: h.substr(((i + 1)))\n            };\n        }\n    };\n});\n__d(\"MercuryAssert\", [\"MercuryIDs\",], function(a, b, c, d, e, f) {\n    var g = b(\"MercuryIDs\");\n    e.exports = {\n        isParticipantID: function(h) {\n            if (!g.isValid(h)) {\n                throw \"bad_participant_id\";\n            }\n        ;\n        ;\n        },\n        allParticipantIDs: function(h) {\n            h.forEach(this.isParticipantID);\n        },\n        isUserParticipantID: function(h) {\n            var i = g.tokenize(h);\n            if (((i.type != \"fbid\"))) {\n                throw \"bad_user_id\";\n            }\n        ;\n        ;\n        },\n        isEmailParticipantID: function(h) {\n            var i = g.tokenize(h);\n            if (((i.type != \"email\"))) {\n                throw \"bad_email_id\";\n            }\n        ;\n        ;\n        },\n        allThreadID: function(h) {\n            h.forEach(this.isThreadID);\n        },\n        isThreadID: function(h) {\n            if (!g.isValid(h)) {\n                throw \"bad_thread_id\";\n            }\n        ;\n        ;\n        }\n    };\n});\n__d(\"MercuryAttachment\", [\"startsWith\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"startsWith\"), h = c(\"MercuryConstants\"), i = {\n        getAttachIconClass: function(j) {\n            switch (j) {\n              case h.MercuryAttachmentContentType.PHOTO:\n                return \"MercuryPhotoIcon\";\n              case h.MercuryAttachmentContentType.VIDEO:\n                return \"MercuryVideoIcon\";\n              case h.MercuryAttachmentContentType.MUSIC:\n                return \"MercuryMusicIcon\";\n              case h.MercuryAttachmentContentType.TEXT:\n                return \"MercuryTextIcon\";\n              case h.MercuryAttachmentContentType.MSWORD:\n                return \"MercuryMSWordIcon\";\n              case h.MercuryAttachmentContentType.MSXLS:\n                return \"MercuryMSXLSIcon\";\n              case h.MercuryAttachmentContentType.MSPPT:\n                return \"MercuryMSPPTIcon\";\n            };\n        ;\n            return \"MercuryDefaultIcon\";\n        },\n        getAttachIconClassByMime: function(j) {\n            if (g(j, \"image\")) {\n                return \"MercuryPhotoIcon\";\n            }\n             else if (g(j, \"video\")) {\n                return \"MercuryVideoIcon\";\n            }\n             else if (g(j, \"audio\")) {\n                return \"MercuryMusicIcon\";\n            }\n             else if (g(j, \"text/plain\")) {\n                return \"MercuryTextIcon\";\n            }\n             else return \"MercuryDefaultIcon\"\n            \n            \n            \n        ;\n        },\n        getAttachTypeByMime: function(j) {\n            if (g(j, \"image\")) {\n                return h.MercuryAttachmentContentType.PHOTO;\n            }\n             else if (g(j, \"video\")) {\n                return h.MercuryAttachmentContentType.VIDEO;\n            }\n             else if (g(j, \"audio\")) {\n                return h.MercuryAttachmentContentType.MUSIC;\n            }\n             else if (g(j, \"text/plain\")) {\n                return h.MercuryAttachmentContentType.TEXT;\n            }\n             else return h.MercuryAttachmentContentType.UNKNOWN\n            \n            \n            \n        ;\n        },\n        convertRaw: function(j) {\n            var k = [];\n            for (var l = 0; ((l < j.length)); l++) {\n                var m = j[l];\n                if (m.filename) {\n                    var n = {\n                    };\n                    n.attach_type = h.MercuryAttachmentType.FILE;\n                    n.JSBNG__name = m.filename;\n                    n.icon_type = i.getAttachTypeByMime(m.filetype);\n                    n.url = \"#\";\n                    k.push(n);\n                }\n            ;\n            ;\n            };\n        ;\n            return k;\n        }\n    };\n    e.exports = i;\n});\n__d(\"MercuryMessageIDs\", [\"KeyedCallbackManager\",], function(a, b, c, d, e, f) {\n    var g = b(\"KeyedCallbackManager\"), h = new g(), i = {\n        getServerIDs: function(j, k) {\n            var l = j.filter(function(n) {\n                return ((n.indexOf(\"mail.projektitan.com\") !== -1));\n            }), m = function(n) {\n                var o = j.map(function(p) {\n                    return ((n[p] ? n[p] : p));\n                });\n                k(o);\n            };\n            return h.executeOrEnqueue(l, m);\n        },\n        addServerID: function(j, k) {\n            h.setResource(j, k);\n        }\n    };\n    e.exports = i;\n});\n__d(\"MercuryServerDispatcher\", [\"AsyncRequest\",\"JSLogger\",\"URI\",\"areObjectsEqual\",\"copyProperties\",\"debounceAcrossTransitions\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncRequest\"), h = b(\"JSLogger\"), i = b(\"URI\"), j = b(\"areObjectsEqual\"), k = b(\"copyProperties\"), l = b(\"debounceAcrossTransitions\"), m = {\n    }, n = h.create(\"mercury_dispatcher\"), o = false, p = {\n        IMMEDIATE: \"immediate\",\n        IDEMPOTENT: \"idempotent\",\n        BATCH_SUCCESSIVE: \"batch-successive\",\n        BATCH_SUCCESSIVE_UNIQUE: \"batch-successive-unique\",\n        BATCH_SUCCESSIVE_PIGGYBACK_ON_ERROR: \"batch-successive-piggyback-retry\",\n        BATCH_DEFERRED_MULTI: \"batch-deferred-multi\",\n        BATCH_CONDITIONAL: \"batch-conditional\",\n        registerEndpoints: function(r) {\n            for (var s in r) {\n                var t = r[s];\n                m[s] = new q(s, t);\n            };\n        ;\n        },\n        trySend: function(r, s, t) {\n            m[r].trySend(s, t);\n        }\n    };\n    function q(r, s) {\n        var t = ((s.mode || p.IMMEDIATE));\n        switch (t) {\n          case p.IMMEDIATE:\n        \n          case p.IDEMPOTENT:\n        \n          case p.BATCH_SUCCESSIVE:\n        \n          case p.BATCH_SUCCESSIVE_UNIQUE:\n        \n          case p.BATCH_SUCCESSIVE_PIGGYBACK_ON_ERROR:\n        \n          case p.BATCH_DEFERRED_MULTI:\n        \n          case p.BATCH_CONDITIONAL:\n            break;\n          default:\n            throw new Error(((\"Invalid MercuryServerDispatcher mode \" + t)));\n        };\n    ;\n        this._endpoint = r;\n        this._mode = t;\n        this._combineData = s.batch_function;\n        this._combineDataIf = s.batch_if;\n        this._handler = s.handler;\n        this._errorHandler = s.error_handler;\n        this._transportErrorHandler = ((s.transport_error_handler || s.error_handler));\n        this._serverDialogCancelHandler = ((s.server_dialog_cancel_handler || s.error_handler));\n        this._deferredSend = l(this._batchSend, 0, this);\n    };\n;\n    k(q.prototype, {\n        _inFlight: 0,\n        _handler: null,\n        _errorHandler: null,\n        _transportErrorHandler: null,\n        _serverDialogCancelHandler: null,\n        _combineData: null,\n        _pendingRequestData: null,\n        trySend: function(r, s) {\n            if (o) {\n                return;\n            }\n        ;\n        ;\n            if (((typeof r == \"undefined\"))) {\n                r = null;\n            }\n        ;\n        ;\n            var t = ((s || this._mode));\n            if (((t == p.IMMEDIATE))) {\n                this._send(r);\n            }\n             else if (((t == p.IDEMPOTENT))) {\n                if (!this._inFlight) {\n                    this._send(r);\n                }\n            ;\n            ;\n            }\n             else if (((((t == p.BATCH_SUCCESSIVE)) || ((t == p.BATCH_SUCCESSIVE_UNIQUE))))) {\n                if (!this._inFlight) {\n                    this._send(r);\n                }\n                 else this._batchData(r);\n            ;\n            ;\n            }\n             else if (((t == p.BATCH_CONDITIONAL))) {\n                if (((this._inFlight && ((this._combineDataIf(this._pendingRequestData, r) || this._combineDataIf(this._batchedData, r)))))) {\n                    this._batchData(r);\n                }\n                 else this._send(r);\n            ;\n            ;\n            }\n             else if (((t == p.BATCH_DEFERRED_MULTI))) {\n                this._batchData(r);\n                this._deferredSend();\n            }\n             else if (((t == p.BATCH_SUCCESSIVE_PIGGYBACK_ON_ERROR))) {\n                this._batchData(r);\n                if (!this._inFlight) {\n                    this._batchSend();\n                }\n            ;\n            ;\n            }\n            \n            \n            \n            \n            \n        ;\n        ;\n        },\n        _send: function(r) {\n            this._inFlight++;\n            this._pendingRequestData = k({\n            }, r);\n            n.log(\"send\", {\n                endpoint: this._endpoint,\n                data: r,\n                inflight_count: this._inFlight\n            });\n            new g(this._endpoint).setData(r).setHandler(this._handleResponse.bind(this)).setErrorHandler(this._handleError.bind(this)).setTransportErrorHandler(this._handleTransportError.bind(this)).setServerDialogCancelHandler(this._handleServerDialogCancel.bind(this)).setAllowCrossPageTransition(true).send();\n        },\n        _batchData: function(r) {\n            if (((((((this._mode == p.BATCH_SUCCESSIVE_UNIQUE)) && this._pendingRequestData)) && j(r, this._pendingRequestData)))) {\n                return;\n            }\n             else if (((typeof this._batchedData == \"undefined\"))) {\n                this._batchedData = r;\n            }\n             else this._batchedData = this._combineData(this._batchedData, r);\n            \n        ;\n        ;\n        },\n        _batchSend: function() {\n            if (((typeof this._batchedData != \"undefined\"))) {\n                this._send(this._batchedData);\n                delete this._batchedData;\n            }\n        ;\n        ;\n        },\n        _handleResponse: function(r) {\n            this._inFlight--;\n            n.log(\"response\", {\n                endpoint: this._endpoint,\n                inflight_count: this._inFlight\n            });\n            var s = r.getPayload();\n            o = ((s && s.kill_chat));\n            if (o) {\n                n.log(\"killswitch_enabled\", {\n                    endpoint: this._endpoint,\n                    inflight_count: this._inFlight\n                });\n            }\n        ;\n        ;\n            if (((s && s.error_payload))) {\n                if (this._errorHandler) {\n                    this._errorHandler(r);\n                }\n            ;\n            ;\n            }\n             else ((this._handler && this._handler(s)));\n        ;\n        ;\n            if (((((((((this._mode == p.BATCH_SUCCESSIVE)) || ((this._mode == p.BATCH_SUCCESSIVE_UNIQUE)))) || ((this._mode == p.BATCH_SUCCESSIVE_PIGGYBACK_ON_ERROR)))) || ((this._mode == p.BATCH_CONDITIONAL))))) {\n                this._batchSend();\n            }\n        ;\n        ;\n            this._pendingRequestData = null;\n        },\n        _handleErrorCommon: function(r, s) {\n            n.error(\"error\", {\n                endpoint: this._endpoint,\n                inflight_count: ((this._inFlight - 1))\n            });\n            ((s && s(r)));\n            this._inFlight--;\n            var t = this._mode;\n            if (((((((t == p.BATCH_SUCCESSIVE)) || ((t == p.BATCH_SUCCESSIVE_UNIQUE)))) || ((t == p.BATCH_CONDITIONAL))))) {\n                this._batchSend();\n            }\n             else if (((t == p.BATCH_SUCCESSIVE_PIGGYBACK_ON_ERROR))) {\n                if (((typeof this._batchedData == \"undefined\"))) {\n                    this._batchedData = this._pendingRequestData;\n                }\n                 else {\n                    this._batchedData = this._combineData(this._pendingRequestData, this._batchedData);\n                    this._batchSend();\n                }\n            ;\n            }\n            \n        ;\n        ;\n            this._pendingRequestData = null;\n        },\n        _handleError: function(r) {\n            this._handleErrorCommon(r, this._errorHandler);\n        },\n        _handleTransportError: function(r) {\n            this._handleErrorCommon(r, this._transportErrorHandler);\n        },\n        _handleServerDialogCancel: function(r) {\n            this._handleErrorCommon(r, this._serverDialogCancelHandler);\n        }\n    });\n    e.exports = p;\n});\n__d(\"MercuryThreadInformer\", [\"Arbiter\",\"copyProperties\",\"MercuryAssert\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"copyProperties\"), i = b(\"MercuryAssert\"), j = {\n    }, k = {\n    }, l = {\n    }, m = false, n = false, o = false, p = {\n    }, q = {\n    }, r = {\n    }, s = 0;\n    function t() {\n        if (!s) {\n            var v = j, w = k, x = l, y = m, z = n, aa = o, ba = p, ca = q, da = r;\n            j = {\n            };\n            k = {\n            };\n            l = {\n            };\n            m = false;\n            n = false;\n            o = false;\n            p = {\n            };\n            q = {\n            };\n            r = {\n            };\n            var ea = Object.keys(w);\n            if (((ea.length || y))) {\n                u.inform(\"threadlist-updated\", ea);\n            }\n        ;\n        ;\n            if (ea.length) {\n                u.inform(\"threads-updated\", w);\n            }\n        ;\n        ;\n            for (var fa in x) {\n                u.inform(\"thread-read-changed\", x);\n                break;\n            };\n        ;\n            for (var fa in v) {\n                u.inform(\"threads-deleted\", v);\n                break;\n            };\n        ;\n            if (z) {\n                u.inform(\"unseen-updated\", null);\n            }\n        ;\n        ;\n            if (aa) {\n                u.inform(\"unread-updated\", null);\n            }\n        ;\n        ;\n            for (fa in ba) {\n                u.inform(\"messages-received\", ba);\n                break;\n            };\n        ;\n            for (fa in ca) {\n                u.inform(\"messages-reordered\", ca);\n                break;\n            };\n        ;\n            for (fa in da) {\n                u.inform(\"messages-updated\", da);\n                break;\n            };\n        ;\n        }\n    ;\n    ;\n    };\n;\n    var u = h(new g(), {\n        updatedThread: function(v) {\n            k[v] = true;\n            t();\n        },\n        deletedThread: function(v) {\n            j[v] = true;\n            t();\n        },\n        updatedThreadlist: function() {\n            m = true;\n            t();\n        },\n        updatedUnseenState: function() {\n            n = true;\n            t();\n        },\n        updatedUnreadState: function() {\n            o = true;\n            t();\n        },\n        changedThreadReadState: function(v, w, x) {\n            if (((!l[v] || ((l[v].timestamp < x))))) {\n                l[v] = {\n                    mark_as_read: w,\n                    timestamp: x\n                };\n            }\n        ;\n        ;\n            t();\n        },\n        receivedMessage: function(v) {\n            i.isThreadID(v.thread_id);\n            var w = v.thread_id;\n            if (!p[w]) {\n                p[w] = [];\n            }\n        ;\n        ;\n            p[w].push(v);\n            u.updatedThread(w);\n        },\n        reorderedMessages: function(v, w) {\n            q[v] = {\n                source: w\n            };\n            t();\n        },\n        updatedMessage: function(v, w, x) {\n            if (!r[v]) {\n                r[v] = {\n                };\n            }\n        ;\n        ;\n            r[v][w] = {\n                source: x\n            };\n            t();\n        },\n        synchronizeInforms: function(v) {\n            s++;\n            try {\n                v();\n            } catch (w) {\n                throw w;\n            } finally {\n                s--;\n                t();\n            };\n        ;\n        },\n        listen: function(v, w) {\n            return u.subscribe(\"threads-updated\", function(x, y) {\n                if (y[v]) {\n                    w(v);\n                }\n            ;\n            ;\n            });\n        }\n    });\n    e.exports = u;\n});\n__d(\"MessagingReliabilityLogger\", [\"function-extensions\",\"AsyncRequest\",\"copyProperties\",\"isEmpty\",\"PresenceUtil\",\"Run\",\"MercuryServerDispatcher\",\"setTimeoutAcrossTransitions\",\"MessagingReliabilityLoggerInitialData\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"AsyncRequest\"), h = b(\"copyProperties\"), i = b(\"isEmpty\"), j = b(\"PresenceUtil\"), k = b(\"Run\"), l = b(\"MercuryServerDispatcher\"), m = b(\"setTimeoutAcrossTransitions\"), n = c(\"MessagingReliabilityLoggerInitialData\"), o = \"/ajax/mercury/client_reliability.php\", p = 60000;\n    function q(w, x) {\n        var y = {\n            app: n.app,\n            categories: JSON.stringify(w)\n        };\n        if (!i(x)) {\n            y.extra = JSON.stringify(x);\n        }\n    ;\n    ;\n        return y;\n    };\n;\n    function r(w, x, y, z) {\n        if (((w[x] === undefined))) {\n            w[x] = {\n            };\n        }\n    ;\n    ;\n        if (((w[x][y] === undefined))) {\n            w[x][y] = 0;\n        }\n    ;\n    ;\n        w[x][y] += z;\n    };\n;\n    function s(w, x, y, z) {\n        if (((w[x] === undefined))) {\n            w[x] = {\n            };\n        }\n    ;\n    ;\n        if (((w[x][y] === undefined))) {\n            w[x][y] = [];\n        }\n    ;\n    ;\n        for (var aa = 0; ((aa < z.length)); ++aa) {\n            w[x][y].push(z[aa]);\n        ;\n        };\n    ;\n    };\n;\n    function t(w, x) {\n        if (((!w.categories || !x.categories))) {\n            return;\n        }\n    ;\n    ;\n        var y = JSON.parse(w.categories), z = ((w.extra ? JSON.parse(w.extra) : {\n        })), aa = JSON.parse(x.categories), ba = ((x.extra ? JSON.parse(x.extra) : {\n        }));\n        for (var ca in aa) {\n            var da = aa[ca], ea = ba[ca];\n            for (var fa in da) {\n                r(y, ca, fa, da[fa]);\n                if (((ea !== undefined))) {\n                    var ga = ea[fa];\n                    if (((ga !== undefined))) {\n                        s(z, ca, fa, ga);\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n        };\n    ;\n        return q(y, z);\n    };\n;\n    var u = {\n    };\n    u[o] = {\n        mode: l.BATCH_SUCCESSIVE_PIGGYBACK_ON_ERROR,\n        batch_function: t\n    };\n    l.registerEndpoints(u);\n    var v = {\n        addEntry: function(w, x, y) {\n            if (!n.enabled) {\n                return;\n            }\n        ;\n        ;\n            var z = {\n            };\n            r(z, w, x, 1);\n            var aa = {\n            };\n            if (((y !== undefined))) {\n                s(aa, w, x, [y,]);\n            }\n        ;\n        ;\n            l.trySend(o, q(z, aa));\n        }\n    };\n    (function w() {\n        v.addEntry(\"page_event\", \"active\", j.getSessionID());\n        m(w, p);\n    })();\n    e.exports = v;\n});\n__d(\"MercuryServerRequests\", [\"Arbiter\",\"AsyncResponse\",\"KeyedCallbackManager\",\"TimestampConverter\",\"copyProperties\",\"Env\",\"JSLogger\",\"MercuryAssert\",\"MercuryMessageIDs\",\"MercuryServerDispatcher\",\"MercuryThreadInformer\",\"MercuryIDs\",\"MessagingReliabilityLogger\",\"createObjectFrom\",\"hasArrayNature\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AsyncResponse\"), i = b(\"KeyedCallbackManager\"), j = b(\"TimestampConverter\"), k = b(\"copyProperties\"), l = b(\"Env\"), m = b(\"JSLogger\"), n = b(\"MercuryAssert\"), o = b(\"MercuryMessageIDs\"), p = b(\"MercuryServerDispatcher\"), q = b(\"MercuryThreadInformer\"), r = b(\"MercuryIDs\"), s = b(\"MessagingReliabilityLogger\"), t = b(\"createObjectFrom\"), u = b(\"hasArrayNature\"), v = c(\"MercuryConstants\"), w = v.MercuryGenericConstants, x = 0, y = m.create(\"mercury_server\"), z = new i(), aa = new i(), ba = [], ca = {\n    }, da = {\n    };\n    function ea(ab) {\n        if (ab) {\n            x = j.maxValidActionID(x, ab);\n        }\n    ;\n    ;\n    };\n;\n    function fa(ab) {\n        var bb = ab.thread_id, cb = z.getResource(bb);\n        if (!cb) {\n            if (ab.is_canonical) {\n                if (((ab.canonical_fbid === undefined))) {\n                    var db = ab.participants.filter(function(fb) {\n                        return ((fb != ((\"fbid:\" + l.user))));\n                    });\n                    if (db.length) {\n                        var eb = r.tokenize(db[0]);\n                        if (((eb.type == \"email\"))) {\n                            ab.canonical_email = eb.value;\n                        }\n                         else ab.canonical_fbid = eb.value;\n                    ;\n                    ;\n                    }\n                     else ab.canonical_fbid = l.user;\n                ;\n                ;\n                }\n            ;\n            ;\n                cb = ((ab.canonical_fbid ? ((\"user:\" + ab.canonical_fbid)) : ((\"email:\" + ab.canonical_email))));\n            }\n             else if (ab.is_canonical_group) {\n                cb = ((\"group:\" + ab.group_id));\n            }\n             else if (ab.root_message_threading_id) {\n                cb = ((\"root:\" + ab.root_message_threading_id));\n            }\n            \n            \n        ;\n        ;\n            cb = ((cb || ((\"thread:\" + bb))));\n            ga(bb, cb);\n        }\n    ;\n    ;\n        ab.thread_id = cb;\n    };\n;\n    function ga(ab, bb) {\n        z.setResource(ab, bb);\n        aa.setResource(bb, ab);\n        da[ab] = bb;\n    };\n;\n    function ha(ab, bb) {\n        var cb = aa.executeOrEnqueue(ab, bb), db = aa.getUnavailableResources(cb), eb = xa.tokenizeThreadID(ab);\n        if (((db.length && ((eb.type != \"root\"))))) {\n            xa.fetchThreadData(db);\n        }\n    ;\n    ;\n    };\n;\n    function ia(ab) {\n        return aa.getResource(ab);\n    };\n;\n    function ja(ab) {\n        return !!z.getResource(ab);\n    };\n;\n    function ka(ab) {\n        var bb = z.getResource(ab);\n        if (((typeof bb == \"undefined\"))) {\n            y.warn(\"no_client_thread_id\", {\n                server_id: ab\n            });\n        }\n    ;\n    ;\n        return bb;\n    };\n;\n    function la(ab, bb) {\n        z.executeOrEnqueue(ab, bb);\n        xa.ensureThreadIsFetched(ab);\n    };\n;\n    function ma(ab, bb) {\n        if (((ab.action_type != v.MercuryActionType.SEND_MESSAGE))) {\n            return;\n        }\n    ;\n    ;\n        var cb = ab.client_thread_id;\n        if (!cb) {\n            cb = ka(ab.thread_id);\n        }\n    ;\n    ;\n        var db = null;\n        if (cb) {\n            db = r.tokenize(cb).type;\n        }\n    ;\n    ;\n        s.addEntry(((\"send_\" + db)), bb, ((((ab.thread_id + \",\")) + ab.message_id)));\n    };\n;\n    function na(ab) {\n        var bb = null;\n        switch (ab.JSBNG__status) {\n          case v.MercuryActionStatus.SUCCESS:\n            bb = \"success\";\n            break;\n          case v.MercuryActionStatus.FAILED_UNKNOWN_REASON:\n            bb = \"confirmed_error\";\n            break;\n          case v.MercuryActionStatus.UNABLE_TO_CONFIRM:\n            bb = \"confirm_error\";\n            break;\n          default:\n            return;\n        };\n    ;\n        ma(ab, bb);\n    };\n;\n    function oa(ab) {\n        ((ab.message_counts || [])).forEach(function(jb) {\n            ea(jb.last_action_id);\n        });\n        ((ab.threads || [])).forEach(function(jb) {\n            fa(jb);\n            delete ca[jb.thread_id];\n            delete ca[ia(jb.thread_id)];\n            ea(jb.last_action_id);\n        });\n        ((ab.ordered_threadlists || [])).forEach(function(jb) {\n            jb.thread_ids = jb.thread_ids.map(ka);\n        });\n        ab.actions = ((ab.actions || []));\n        ab.actions.forEach(function(jb) {\n            na(jb);\n            if (((((jb.JSBNG__status && ((jb.JSBNG__status != v.MercuryActionStatus.SUCCESS)))) && !jb.thread_id))) {\n                jb.thread_id = jb.client_thread_id;\n                return;\n            }\n        ;\n        ;\n            if (((((((jb.action_type == v.MercuryActionType.SEND_MESSAGE)) && jb.client_thread_id)) && ((jb.client_thread_id != w.PENDING_THREAD_ID))))) {\n                ga(jb.thread_id, jb.client_thread_id);\n            }\n        ;\n        ;\n            jb.server_thread_id = jb.thread_id;\n            jb.thread_id = ((ja(jb.thread_id) ? ka(jb.thread_id) : null));\n            ea(jb.action_id);\n        });\n        if (ab.end_of_history) {\n            var bb = [];\n            for (var cb = 0; ((cb < ab.end_of_history.length)); cb++) {\n                var db = ab.end_of_history[cb];\n                if (((db.type == \"user\"))) {\n                    bb.push(((\"user:\" + db.id)));\n                }\n                 else if (((((db.type == \"thread\")) && ja(db.id)))) {\n                    bb.push(ka(db.id));\n                }\n                \n            ;\n            ;\n            };\n        ;\n            ab.end_of_history = bb;\n        }\n    ;\n    ;\n        if (ab.roger) {\n            var eb = {\n            };\n            for (var fb in ab.roger) {\n                var gb = z.getResource(fb);\n                if (gb) {\n                    var hb = ab.roger[fb];\n                    eb[gb] = {\n                    };\n                    for (var ib in hb) {\n                        eb[gb][((\"fbid:\" + ib))] = hb[ib];\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            ab.roger = eb;\n        }\n    ;\n    ;\n    };\n;\n    function pa() {\n        if (((ba && ba.length))) {\n            var ab = ba[0];\n            ba = ba.slice(1);\n            xa.handleUpdate(ab);\n        }\n    ;\n    ;\n    };\n;\n    function qa(ab, bb) {\n        var cb = k({\n        }, ab), db;\n        if (bb.threads) {\n            if (!cb.threads) {\n                cb.threads = {\n                };\n            }\n        ;\n        ;\n            for (db in bb.threads) {\n                cb.threads[db] = Object.keys(t(((cb.threads[db] || [])).concat(bb.threads[db])));\n            ;\n            };\n        ;\n        }\n    ;\n    ;\n        if (bb.messages) {\n            if (!cb.messages) {\n                cb.messages = {\n                };\n            }\n        ;\n        ;\n            for (db in bb.messages) {\n                if (!cb.messages[db]) {\n                    cb.messages[db] = {\n                    };\n                }\n            ;\n            ;\n                for (var eb in bb.messages[db]) {\n                    if (cb.messages[db][eb]) {\n                        cb.messages[db][eb] = ta(cb.messages[db][eb], bb.messages[db][eb]);\n                    }\n                     else cb.messages[db][eb] = bb.messages[db][eb];\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n        }\n    ;\n    ;\n        return cb;\n    };\n;\n    function ra(ab, bb) {\n        var cb = k(t(ab.folders, true), t(bb.folders, true));\n        return {\n            folders: Object.keys(cb)\n        };\n    };\n;\n    function sa(ab, bb) {\n        for (var cb in bb) {\n            if (ab[cb]) {\n                ab[cb] = ta(ab[cb], bb[cb]);\n            }\n             else {\n                var db = {\n                };\n                k(db, bb[cb]);\n                ab[cb] = db;\n            }\n        ;\n        ;\n        };\n    ;\n        return ab;\n    };\n;\n    function ta(ab, bb) {\n        var cb = ((((ab.offset < bb.offset)) ? ab.offset : bb.offset)), db = ((ab.offset + ab.limit)), eb = ((bb.offset + bb.limit)), fb = ((((db > eb)) ? db : eb)), gb = ((fb - cb));\n        return {\n            offset: cb,\n            limit: gb\n        };\n    };\n;\n    function ua(ab, bb) {\n        var cb = {\n            ids: {\n            }\n        };\n        k(cb.ids, ab.ids);\n        k(cb.ids, bb.ids);\n        return cb;\n    };\n;\n    function va(ab, bb) {\n        var cb = {\n        }, db;\n        for (db in ab) {\n            k(cb, t(ab[db], db));\n        ;\n        };\n    ;\n        for (db in bb) {\n            k(cb, t(bb[db], db));\n        ;\n        };\n    ;\n        var eb = {\n        };\n        for (var fb in cb) {\n            db = cb[fb];\n            if (!eb[db]) {\n                eb[db] = [];\n            }\n        ;\n        ;\n            eb[db].push(fb);\n        };\n    ;\n        return eb;\n    };\n;\n    function wa(ab, bb) {\n        var cb = t(ab.ids, true), db = t(bb.ids, true), eb = k(cb, db);\n        return {\n            ids: Object.keys(eb)\n        };\n    };\n;\n    var xa = k(new g(), {\n        tokenizeThreadID: function(ab) {\n            n.isThreadID(ab);\n            return r.tokenize(ab);\n        },\n        getServerThreadID: function(ab, bb) {\n            n.isThreadID(ab);\n            ha(ab, bb);\n        },\n        getClientThreadID: function(ab, bb) {\n            la(ab, bb);\n        },\n        getClientThreadIDNow: function(ab) {\n            return ka(ab);\n        },\n        getServerThreadIDNow: function(ab) {\n            return ia(ab);\n        },\n        convertThreadIDIfAvailable: function(ab) {\n            var bb = z.getResource(ab);\n            if (((bb === undefined))) {\n                return ab;\n            }\n             else return bb\n        ;\n        },\n        canLinkExternally: function(ab) {\n            n.isThreadID(ab);\n            var bb = xa.tokenizeThreadID(ab);\n            return ((((bb.type == \"user\")) || !!ia(ab)));\n        },\n        fetchThreadlistInfo: function(ab, bb, cb, db) {\n            cb = ((cb || v.MessagingTag.INBOX));\n            var eb = ((db ? p.IMMEDIATE : null)), fb = {\n            };\n            fb[cb] = {\n                offset: ab,\n                limit: bb,\n                filter: db\n            };\n            p.trySend(\"/ajax/mercury/threadlist_info.php\", fb, eb);\n        },\n        fetchUnseenThreadIDs: function(ab) {\n            xa.fetchThreadlistInfo(v.MercuryThreadlistConstants.RECENT_THREAD_OFFSET, v.MercuryThreadlistConstants.JEWEL_THREAD_COUNT, ab);\n        },\n        fetchUnreadThreadIDs: function(ab) {\n            p.trySend(\"/ajax/mercury/unread_threads.php\", {\n                folders: [ab,]\n            });\n        },\n        fetchMissedMessages: function(ab) {\n            p.trySend(\"/ajax/mercury/thread_sync.php\", {\n                last_action_id: x,\n                folders: ab\n            });\n        },\n        fetchThreadData: function(ab) {\n            n.allThreadID(ab);\n            var bb = {\n                threads: {\n                }\n            }, cb = [], db = [], eb = [], fb = [];\n            ab.forEach(function(hb) {\n                if (ca[hb]) {\n                    return;\n                }\n            ;\n            ;\n                ca[hb] = true;\n                var ib = ia(hb);\n                if (ib) {\n                    db.push(ib);\n                    bb.threads.thread_ids = db;\n                }\n                 else {\n                    var jb = xa.tokenizeThreadID(hb);\n                    if (((jb.type == \"user\"))) {\n                        cb.push(jb.value);\n                        bb.threads.user_ids = cb;\n                    }\n                     else if (((jb.type == \"group\"))) {\n                        eb.push(jb.value);\n                        bb.threads.group_ids = eb;\n                    }\n                     else if (((jb.type == \"thread\"))) {\n                        db.push(jb.value);\n                        bb.threads.thread_ids = db;\n                    }\n                     else if (((((((jb.type != \"root\")) && ((jb.type != \"email\")))) && ((jb.type != \"pending\"))))) {\n                        throw new Error(\"Unknown thread type\", jb);\n                    }\n                    \n                    \n                    \n                ;\n                ;\n                }\n            ;\n            ;\n            });\n            xa.inform(\"fetch-thread-data\", bb);\n            for (var gb in bb.threads) {\n                p.trySend(\"/ajax/mercury/thread_info.php\", bb);\n                break;\n            };\n        ;\n        },\n        ensureThreadIsFetched: function(ab) {\n            if (((!z.getResource(ab) && !ca[ab]))) {\n                ca[ab] = true;\n                p.trySend(\"/ajax/mercury/thread_info.php\", {\n                    threads: {\n                        thread_ids: [ab,]\n                    }\n                });\n            }\n        ;\n        ;\n        },\n        fetchThreadMessages: function(ab, bb, cb, db) {\n            n.isThreadID(ab);\n            var eb, fb, gb = xa.tokenizeThreadID(ab), hb = ia(ab), ib = false;\n            if (((hb && ((gb.type != \"group\"))))) {\n                fb = \"thread_ids\";\n                eb = hb;\n            }\n             else {\n                eb = gb.value;\n                switch (gb.type) {\n                  case \"user\":\n                    fb = \"user_ids\";\n                    ib = true;\n                    break;\n                  case \"group\":\n                    fb = \"group_ids\";\n                    break;\n                  case \"thread\":\n                    fb = \"thread_ids\";\n                    break;\n                };\n            ;\n            }\n        ;\n        ;\n            var jb = {\n                messages: {\n                },\n                threads: {\n                }\n            };\n            if (fb) {\n                jb.messages[fb] = {\n                };\n                jb.messages[fb][eb] = {\n                    offset: bb,\n                    limit: cb\n                };\n                if (ib) {\n                    jb.threads[fb] = [eb,];\n                }\n            ;\n            ;\n                p.trySend(\"/ajax/mercury/thread_info.php\", jb, db);\n            }\n             else ha(ab, function(kb) {\n                jb.messages.thread_ids = {\n                };\n                jb.messages.thread_ids[kb] = {\n                    offset: bb,\n                    limit: cb\n                };\n                p.trySend(\"/ajax/mercury/thread_info.php\", jb, db);\n            });\n        ;\n        ;\n        },\n        handleThreadInfoError: function(ab) {\n            var bb = ab.getRequest().getData(), cb = [];\n            if (bb.messages) {\n                for (var db in bb.messages.thread_ids) {\n                    cb.push(ya(ka(db)));\n                ;\n                };\n            ;\n                for (var eb in bb.messages.user_ids) {\n                    cb.push(ya(((\"user:\" + eb))));\n                ;\n                };\n            ;\n                for (var fb in bb.messages.group_ids) {\n                    cb.push(ya(((\"group:\" + fb))));\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            if (cb.length) {\n                xa.handleUpdate({\n                    actions: cb,\n                    from_client: true,\n                    payload_source: v.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE\n                });\n            }\n        ;\n        ;\n            if (((((bb.threads && ((((bb.threads.user_ids || bb.threads.group_ids)) || bb.threads.thread_ids)))) && !bb.is_retry))) {\n                if (bb.messages) {\n                    delete bb.messages;\n                }\n            ;\n            ;\n                y.log(\"retry_thread\", bb);\n                bb.is_retry = true;\n                p.trySend(\"/ajax/mercury/thread_info.php\", bb);\n            }\n        ;\n        ;\n        },\n        markFolderAsRead: function(ab) {\n            p.trySend(\"/ajax/mercury/mark_folder_as_read.php\", {\n                folder: ab\n            });\n            var bb = [{\n                action_type: v.MercuryGlobalActionType.MARK_ALL_READ,\n                action_id: null,\n                folder: ab\n            },];\n            xa.handleUpdate({\n                global_actions: bb,\n                from_client: true,\n                payload_source: v.MercuryPayloadSource.CLIENT_CHANGE_READ_STATUS\n            });\n        },\n        changeThreadReadStatus: function(ab, bb, cb) {\n            n.isThreadID(ab);\n            ha(ab, function(eb) {\n                var fb = {\n                    ids: {\n                    }\n                };\n                fb.ids[eb] = bb;\n                p.trySend(\"/ajax/mercury/change_read_status.php\", fb);\n            });\n            var db = [{\n                action_type: v.MercuryActionType.CHANGE_READ_STATUS,\n                action_id: null,\n                thread_id: ab,\n                mark_as_read: bb,\n                folder: cb\n            },];\n            xa.handleUpdate({\n                actions: db,\n                from_client: true,\n                payload_source: v.MercuryPayloadSource.CLIENT_CHANGE_READ_STATUS\n            });\n        },\n        changeThreadArchivedStatus: function(ab, bb) {\n            n.isThreadID(ab);\n            ha(ab, function(eb) {\n                var fb = {\n                    ids: {\n                    }\n                };\n                fb.ids[eb] = bb;\n                p.trySend(\"/ajax/mercury/change_archived_status.php\", fb);\n            });\n            var cb = {\n                action_type: v.MercuryActionType.CHANGE_ARCHIVED_STATUS,\n                action_id: null,\n                thread_id: ab,\n                archived: bb\n            }, db = {\n                actions: [cb,],\n                from_client: true,\n                payload_source: v.MercuryPayloadSource.CLIENT_CHANGE_ARCHIVED_STATUS\n            };\n            xa.handleUpdate(db);\n        },\n        changeThreadFolder: function(ab, bb) {\n            n.isThreadID(ab);\n            ha(ab, function(eb) {\n                var fb = {\n                };\n                fb[bb] = [eb,];\n                p.trySend(\"/ajax/mercury/move_thread.php\", fb);\n            });\n            var cb = {\n                action_type: v.MercuryActionType.CHANGE_FOLDER,\n                action_id: null,\n                thread_id: ab,\n                new_folder: bb\n            }, db = {\n                actions: [cb,],\n                from_client: true,\n                payload_source: v.MercuryPayloadSource.CLIENT_CHANGE_FOLDER\n            };\n            xa.handleUpdate(db);\n        },\n        markThreadSpam: function(ab) {\n            n.isThreadID(ab);\n            ha(ab, function(db) {\n                p.trySend(\"/ajax/mercury/mark_spam.php\", {\n                    id: db\n                });\n            });\n            var bb = {\n                action_type: v.MercuryActionType.CHANGE_FOLDER,\n                action_id: null,\n                thread_id: ab,\n                new_folder: v.MessagingTag.SPAM\n            }, cb = {\n                actions: [bb,],\n                from_client: true,\n                payload_source: v.MercuryPayloadSource.CLIENT_CHANGE_FOLDER\n            };\n            xa.handleUpdate(cb);\n        },\n        unmarkThreadSpam: function(ab) {\n            n.isThreadID(ab);\n            ha(ab, function(db) {\n                p.trySend(\"/ajax/mercury/unmark_spam.php\", {\n                    id: db\n                });\n            });\n            var bb = {\n                action_type: v.MercuryActionType.CHANGE_FOLDER,\n                action_id: null,\n                thread_id: ab,\n                new_folder: v.MessagingTag.INBOX\n            }, cb = {\n                actions: [bb,],\n                from_client: true,\n                payload_source: v.MercuryPayloadSource.CLIENT_CHANGE_FOLDER\n            };\n            xa.handleUpdate(cb);\n        },\n        deleteThread: function(ab) {\n            n.isThreadID(ab);\n            ha(ab, function(db) {\n                var eb = {\n                    ids: [db,]\n                };\n                p.trySend(\"/ajax/mercury/delete_thread.php\", eb);\n            });\n            var bb = {\n                action_type: v.MercuryActionType.DELETE_THREAD,\n                action_id: null,\n                thread_id: ab\n            }, cb = {\n                actions: [bb,],\n                from_client: true,\n                payload_source: v.MercuryPayloadSource.CLIENT_DELETE_THREAD\n            };\n            xa.handleUpdate(cb);\n        },\n        deleteMessages: function(ab, bb, cb) {\n            o.getServerIDs(((bb || [])), function(eb) {\n                p.trySend(\"/ajax/mercury/delete_messages.php\", {\n                    message_ids: eb\n                });\n            });\n            var db;\n            if (cb) {\n                db = {\n                    action_type: v.MercuryActionType.DELETE_THREAD,\n                    action_id: null,\n                    thread_id: ab\n                };\n            }\n             else db = {\n                action_type: v.MercuryActionType.DELETE_MESSAGES,\n                action_id: null,\n                thread_id: ab,\n                message_ids: bb\n            };\n        ;\n        ;\n            xa.handleUpdate({\n                actions: [db,],\n                from_client: true,\n                payload_source: v.MercuryPayloadSource.CLIENT_DELETE_MESSAGES\n            });\n        },\n        clearChat: function(ab, bb, cb) {\n            n.isThreadID(ab);\n            p.trySend(\"/ajax/chat/settings.php\", {\n                clear_history_id: bb\n            });\n            var db = [{\n                action_type: v.MercuryActionType.CLEAR_CHAT,\n                action_id: null,\n                thread_id: ab,\n                clear_time: cb\n            },];\n            xa.handleUpdate({\n                actions: db,\n                from_client: true,\n                payload_source: v.MercuryPayloadSource.CLIENT_CLEAR_CHAT\n            });\n        },\n        _batchThreadRead: function(ab, bb) {\n            var cb = {\n            };\n            k(cb, ab.ids);\n            k(cb, bb.ids);\n            return {\n                ids: cb\n            };\n        },\n        sendNewMessage: function(ab) {\n            o.getServerIDs(((ab.forward_message_ids || [])), function(cb) {\n                var db = xa.tokenizeThreadID(ab.thread_id), eb = db.type, fb = k({\n                }, ab);\n                fb.forward_message_ids = cb;\n                var gb = ia(ab.thread_id);\n                if (((((((((eb == \"root\")) && ((db.value == fb.message_id)))) || ((eb == \"user\")))) || ((ab.thread_id == w.PENDING_THREAD_ID))))) {\n                    fb.client_thread_id = fb.thread_id;\n                    fb.thread_id = null;\n                    xa._sendNewMessageToServer(fb);\n                }\n                 else ha(fb.thread_id, function(hb) {\n                    fb.thread_id = hb;\n                    xa._sendNewMessageToServer(fb);\n                });\n            ;\n            ;\n            });\n            if (((ab.thread_id != w.PENDING_THREAD_ID))) {\n                var bb = {\n                    actions: [k({\n                    }, ab),],\n                    from_client: true,\n                    payload_source: v.MercuryPayloadSource.CLIENT_SEND_MESSAGE\n                };\n                xa.handleUpdate(bb);\n            }\n        ;\n        ;\n        },\n        _sendNewMessageToServer: function(ab) {\n            p.trySend(\"/ajax/mercury/send_messages.php\", {\n                message_batch: [ab,]\n            });\n        },\n        _batchMessageSend: function(ab, bb) {\n            return {\n                message_batch: ab.message_batch.concat(bb.message_batch)\n            };\n        },\n        requestMessageConfirmation: function(ab) {\n            var bb = {\n            }, cb = {\n            };\n            for (var db in ab) {\n                var eb = ia(db);\n                if (eb) {\n                    bb[eb] = ab[db];\n                }\n                 else {\n                    var fb = ab[db];\n                    for (var gb = 0; ((gb < fb.length)); gb++) {\n                        cb[fb[gb]] = db;\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            var hb = Object.keys(bb), ib = Object.keys(cb);\n            if (((hb.length || ib.length))) {\n                p.trySend(\"/ajax/mercury/confirm_messages.php\", {\n                    thread_message_map: bb,\n                    local_messages: cb\n                });\n            }\n        ;\n        ;\n        },\n        handleMessageConfirmError: function(ab) {\n            var bb = ab.getRequest().getData().thread_message_map, cb = ab.getRequest().getData().local_messages;\n            if (((!bb && !cb))) {\n                return;\n            }\n        ;\n        ;\n            var db = [];\n            for (var eb in bb) {\n                var fb = bb[eb];\n                fb.forEach(function(ib) {\n                    db.push({\n                        action_type: v.MercuryActionType.SEND_MESSAGE,\n                        client_message_id: ib,\n                        message_id: ib,\n                        client_thread_id: null,\n                        thread_id: eb,\n                        JSBNG__status: v.MercuryActionStatus.UNABLE_TO_CONFIRM\n                    });\n                });\n            };\n        ;\n            for (var gb in cb) {\n                var hb = cb[gb];\n                db.push({\n                    action_type: v.MercuryActionType.SEND_MESSAGE,\n                    client_message_id: gb,\n                    message_id: gb,\n                    client_thread_id: hb,\n                    thread_id: null,\n                    JSBNG__status: v.MercuryActionStatus.UNABLE_TO_CONFIRM\n                });\n            };\n        ;\n            if (db.length) {\n                xa.handleUpdate({\n                    actions: db,\n                    payload_source: v.MercuryPayloadSource.CLIENT_HANDLE_ERROR\n                });\n            }\n        ;\n        ;\n        },\n        markSeen: function() {\n            var ab = j.convertActionIDToTimestamp(x);\n            p.trySend(\"/ajax/mercury/mark_seen.php\", {\n                seen_timestamp: ab\n            });\n        },\n        _batchMarkSeen: function(ab, bb) {\n            return bb;\n        },\n        handleRoger: function(ab) {\n            var bb = ((ab.tid ? z.getResource(ab.tid) : ((\"user:\" + ab.reader))));\n            if (bb) {\n                var cb = {\n                };\n                cb[bb] = {\n                };\n                cb[bb][((\"fbid:\" + ab.reader))] = ab.time;\n                xa.inform(\"update-roger\", cb);\n            }\n        ;\n        ;\n        },\n        handleUpdateWaitForThread: function(ab, bb) {\n            var cb = z.getResource(bb);\n            if (cb) {\n                xa.handleUpdate(ab);\n                return;\n            }\n        ;\n        ;\n            z.executeOrEnqueue(bb, function() {\n                ba.push(ab);\n            });\n            if (!ca[bb]) {\n                ca[bb] = true;\n                p.trySend(\"/ajax/mercury/thread_info.php\", {\n                    threads: {\n                        thread_ids: [bb,]\n                    }\n                });\n            }\n        ;\n        ;\n        },\n        handleUpdate: function(ab) {\n            y.debug(\"handle_update\", {\n                payload: ab,\n                from_client: ab.from_client\n            });\n            for (var bb in ab) {\n                q.synchronizeInforms(function() {\n                    if (!ab.from_client) {\n                        oa(ab);\n                        xa.inform(\"payload-preprocessed\", ab);\n                    }\n                ;\n                ;\n                    xa.inform(\"update-thread-ids\", da);\n                    da = {\n                    };\n                    xa.inform(\"update-participants\", ab);\n                    xa.inform(\"update-threads\", ab);\n                    xa.inform(\"update-unread\", ab);\n                    xa.inform(\"update-threadlist\", ab);\n                    xa.inform(\"update-messages\", ab);\n                    xa.inform(\"update-unseen\", ab);\n                    xa.inform(\"update-typing-state\", ab);\n                    xa.inform(\"update-roger\", ab.roger);\n                    xa.inform(\"model-update-completed\", null);\n                    pa();\n                });\n                break;\n            };\n        ;\n        },\n        _handleSendMessageErrorCommon: function(ab, bb) {\n            y.debug(\"handle_send_message_error_common\", {\n                response: ab,\n                request_error_status: bb\n            });\n            var cb = ab.getPayload(), db = ab.getRequest().getData(), eb = db.message_batch;\n            if (!eb) {\n                ma({\n                    action_type: v.MercuryActionType.SEND_MESSAGE,\n                    JSBNG__status: v.MercuryActionStatus.REQUEST_EMPTY_MESSAGE_LIST\n                });\n                return;\n            }\n        ;\n        ;\n            var fb, gb = null;\n            if (((cb && cb.error_payload))) {\n                fb = v.MercuryActionStatus.UNCONFIRMED;\n                gb = \"send_error\";\n            }\n             else {\n                gb = ((((bb == v.MercuryActionStatus.REQUEST_ERROR)) ? \"request_error\" : \"transport_error\"));\n                if (ab.getError()) {\n                    gb += ((\"_\" + ab.getError()));\n                }\n            ;\n            ;\n                fb = bb;\n            }\n        ;\n        ;\n            var hb = eb.map(function(jb) {\n                return {\n                    action_type: v.MercuryActionType.SEND_MESSAGE,\n                    client_message_id: jb.message_id,\n                    message_id: jb.message_id,\n                    client_thread_id: jb.client_thread_id,\n                    thread_id: jb.thread_id,\n                    JSBNG__status: fb\n                };\n            });\n            hb.forEach(function(jb) {\n                ma(jb, gb);\n            });\n            var ib = {\n                actions: hb,\n                payload_source: v.MercuryPayloadSource.CLIENT_HANDLE_ERROR\n            };\n            xa.handleUpdate(ib);\n        },\n        handleSendMessageError: function(ab) {\n            if (((ab.error === 1404074))) {\n                h.verboseErrorHandler(ab);\n            }\n        ;\n        ;\n            xa._handleSendMessageErrorCommon(ab, v.MercuryActionStatus.REQUEST_ERROR);\n        },\n        handleSendMessageTransportError: function(ab) {\n            xa._handleSendMessageErrorCommon(ab, v.MercuryActionStatus.TRANSPORT_ERROR);\n        },\n        getLastActionID: function() {\n            return x;\n        }\n    });\n    function ya(ab) {\n        return {\n            action_type: v.MercuryActionType.LOG_MESSAGE,\n            thread_id: ab,\n            message_id: ab,\n            timestamp: (new JSBNG__Date()).getTime(),\n            timestamp_absolute: \"\",\n            timestamp_relative: \"\",\n            is_unread: false,\n            source: v.MercurySourceType.UNKNOWN,\n            log_message_type: v.MercuryLogMessageType.SERVER_ERROR,\n            log_message_data: {\n            }\n        };\n    };\n;\n    var za = xa.handleUpdate;\n    p.registerEndpoints({\n        \"/ajax/mercury/thread_sync.php\": {\n            mode: p.IDEMPOTENT,\n            handler: za\n        },\n        \"/ajax/mercury/thread_info.php\": {\n            mode: p.BATCH_DEFERRED_MULTI,\n            batch_function: qa,\n            handler: za,\n            error_handler: xa.handleThreadInfoError\n        },\n        \"/ajax/mercury/mark_folder_as_read.php\": {\n            mode: p.IMMEDIATE,\n            handler: za\n        },\n        \"/ajax/mercury/change_read_status.php\": {\n            mode: p.BATCH_SUCCESSIVE,\n            batch_function: xa._batchThreadRead,\n            handler: za\n        },\n        \"/ajax/mercury/send_messages.php\": {\n            mode: p.BATCH_SUCCESSIVE,\n            batch_function: xa._batchMessageSend,\n            handler: za,\n            error_handler: xa.handleSendMessageError,\n            transport_error_handler: xa.handleSendMessageTransportError\n        },\n        \"/ajax/mercury/mark_seen.php\": {\n            mode: p.BATCH_SUCCESSIVE,\n            batch_function: xa._batchMarkSeen,\n            handler: za\n        },\n        \"/ajax/mercury/confirm_messages.php\": {\n            mode: p.IMMEDIATE,\n            handler: za,\n            error_handler: xa.handleMessageConfirmError\n        },\n        \"/ajax/mercury/threadlist_info.php\": {\n            mode: p.BATCH_SUCCESSIVE_UNIQUE,\n            batch_function: sa,\n            handler: za\n        },\n        \"/ajax/mercury/mark_spam.php\": {\n            mode: p.IMMEDIATE,\n            handler: za\n        },\n        \"/ajax/mercury/unmark_spam.php\": {\n            mode: p.IMMEDIATE,\n            handler: za\n        },\n        \"/ajax/mercury/unread_threads.php\": {\n            mode: p.BATCH_SUCCESSIVE_UNIQUE,\n            batch_function: ra,\n            handler: za\n        },\n        \"/ajax/chat/settings.php\": {\n            mode: p.IMMEDIATE\n        },\n        \"/ajax/mercury/change_archived_status.php\": {\n            mode: p.BATCH_SUCCESSIVE,\n            batch_function: ua,\n            handler: za\n        },\n        \"/ajax/mercury/delete_thread.php\": {\n            mode: p.BATCH_SUCCESSIVE,\n            batch_function: wa,\n            handler: za\n        },\n        \"/ajax/mercury/delete_messages.php\": {\n            mode: p.IMMEDIATE,\n            handler: za\n        },\n        \"/ajax/mercury/move_thread.php\": {\n            mode: p.BATCH_SUCCESSIVE,\n            batch_function: va,\n            handler: za\n        }\n    });\n    e.exports = xa;\n});\n__d(\"MercuryTimestampTracker\", [\"MercuryServerRequests\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"MercuryServerRequests\"), h = c(\"MercuryConstants\"), i = 0;\n    e.exports = {\n        getLastUserMessageTimestamp: function() {\n            return i;\n        }\n    };\n    g.subscribe(\"update-messages\", function(j, k) {\n        if (((!k.actions || !k.actions.length))) {\n            return;\n        }\n    ;\n    ;\n        var l = h.MercuryPayloadSource;\n        if (((((k.payload_source == l.CLIENT_SEND_MESSAGE)) || ((k.payload_source == l.UNKNOWN))))) {\n            return;\n        }\n    ;\n    ;\n        for (var m = 0; ((m < k.actions.length)); m++) {\n            var n = k.actions[m], o = n.action_type;\n            if (((((((o == h.MercuryActionType.USER_GENERATED_MESSAGE)) && n.thread_id)) && ((n.timestamp > i))))) {\n                i = n.timestamp;\n            }\n        ;\n        ;\n        };\n    ;\n    });\n});\n__d(\"MercuryParticipants\", [\"Env\",\"JSLogger\",\"MercuryAssert\",\"MercuryIDs\",\"ShortProfiles\",\"MercuryServerRequests\",\"copyProperties\",\"getObjectValues\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"Env\"), h = b(\"JSLogger\"), i = b(\"MercuryAssert\"), j = b(\"MercuryIDs\"), k = b(\"ShortProfiles\"), l = b(\"MercuryServerRequests\"), m = b(\"copyProperties\"), n = b(\"getObjectValues\"), o = c(\"MercuryConstants\"), p = ((\"fbid:\" + g.user)), q = {\n    }, r = h.create(\"mercury_participants\"), s = function(v) {\n        if (!q[v.id]) {\n            q[v.id] = m({\n            }, v);\n        }\n    ;\n    ;\n    };\n    function t(v) {\n        i.isEmailParticipantID(v);\n        var w = j.tokenize(v), x = w.value;\n        return {\n            gender: o.MercuryParticipantsConstants.UNKNOWN_GENDER,\n            href: null,\n            id: v,\n            image_src: o.MercuryParticipantsConstants.EMAIL_IMAGE,\n            JSBNG__name: x,\n            short_name: x,\n            employee: false,\n            call_promo: false\n        };\n    };\n;\n    var u = {\n        user: p,\n        getNow: function(v) {\n            return q[v];\n        },\n        get: function(v, w) {\n            i.isParticipantID(v);\n            u.getMulti([v,], function(x) {\n                w(x[v]);\n            });\n        },\n        getMulti: function(v, w) {\n            i.allParticipantIDs(v);\n            var x = {\n            }, y = {\n            };\n            v.forEach(function(aa) {\n                if (q[aa]) {\n                    x[aa] = m({\n                    }, q[aa]);\n                }\n                 else {\n                    var ba = j.tokenize(aa);\n                    if (((ba.type == \"fbid\"))) {\n                        var ca = ba.value;\n                        y[aa] = ca;\n                    }\n                     else if (((ba.type == \"email\"))) {\n                        x[aa] = t(aa);\n                    }\n                    \n                ;\n                ;\n                }\n            ;\n            ;\n            });\n            var z = n(y);\n            if (z.length) {\n                k.getMulti(z, function(aa) {\n                    for (var ba in y) {\n                        var ca = y[ba], da = aa[ca];\n                        x[ba] = {\n                            gender: da.gender,\n                            href: da.uri,\n                            id: ba,\n                            image_src: da.thumbSrc,\n                            JSBNG__name: da.JSBNG__name,\n                            short_name: da.firstName,\n                            employee: da.employee,\n                            call_promo: da.showVideoPromo\n                        };\n                    };\n                ;\n                    w(x);\n                });\n            }\n             else w(x);\n        ;\n        ;\n        },\n        getUserID: function(v) {\n            if (!j.isValid(v)) {\n                return null;\n            }\n        ;\n        ;\n            var w = j.tokenize(v);\n            if (((w.type != \"fbid\"))) {\n                return null;\n            }\n        ;\n        ;\n            return w.value;\n        },\n        getIDForUser: function(v) {\n            return ((\"fbid:\" + v));\n        },\n        addParticipants: function(v) {\n            v.forEach(s);\n        }\n    };\n    l.subscribe(\"update-participants\", function(v, w) {\n        u.addParticipants(((w.participants || [])));\n    });\n    e.exports = u;\n});\n__d(\"MercuryThreads\", [\"Arbiter\",\"copyProperties\",\"JSLogger\",\"createObjectFrom\",\"KeyedCallbackManager\",\"TimestampConverter\",\"MercuryFolders\",\"MercuryAssert\",\"MercuryAttachment\",\"MercuryIDs\",\"MercuryServerRequests\",\"MercuryThreadInformer\",\"MercuryTimestampTracker\",\"MercuryParticipants\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"copyProperties\"), i = b(\"JSLogger\"), j = b(\"createObjectFrom\"), k = b(\"KeyedCallbackManager\"), l = b(\"TimestampConverter\"), m = b(\"MercuryFolders\"), n = b(\"MercuryAssert\"), o = b(\"MercuryAttachment\"), p = b(\"MercuryIDs\"), q = b(\"MercuryServerRequests\"), r = b(\"MercuryThreadInformer\"), s = b(\"MercuryTimestampTracker\"), t = b(\"MercuryParticipants\"), u = c(\"MercuryConstants\"), v = i.create(\"mercury_threads\"), w = new k();\n    function x(ha, ia) {\n        var ja = j(ha.participants, true), ka = t.user;\n        ia.forEach(function(la) {\n            if (((ja[la] !== true))) {\n                ha.participants.push(la);\n                if (((la === ka))) {\n                    ha.is_subscribed = true;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        });\n    };\n;\n    function y(ha, ia) {\n        ha.participants.remove(ia);\n        if (((ia === t.user))) {\n            ha.is_subscribed = false;\n        }\n    ;\n    ;\n    };\n;\n    function z(ha, ia) {\n        if (((ha.participants[0] != ia))) {\n            ha.participants.remove(ia);\n            ha.participants.unshift(ia);\n        }\n    ;\n    ;\n    };\n;\n    function aa(ha, ia) {\n        var ja = ia.body, ka = ia.subject, la = \"\";\n        if (ka) {\n            ka = ka.toLowerCase();\n            if (((ja.slice(0, ka.length).toLowerCase() == ka))) {\n                la = ja;\n            }\n             else if (ja) {\n                la = ((((ka + \" \\u00b7 \")) + ja));\n            }\n             else la = ka;\n            \n        ;\n        ;\n        }\n         else la = ja;\n    ;\n    ;\n        ha.snippet = la;\n        ha.snippet_has_attachment = ia.has_attachment;\n        if (((ia.raw_attachments && ((ia.raw_attachments.length > 0))))) {\n            var ma = o.convertRaw(ia.raw_attachments);\n            ha.snippet_attachments = ma;\n        }\n         else ha.snippet_attachments = ia.attachments;\n    ;\n    ;\n        ha.is_forwarded_snippet = !!ia.forward_count;\n    };\n;\n    function ba(ha, ia) {\n        if (!ha) {\n            return false;\n        }\n    ;\n    ;\n        var ja = !ha.unread_count;\n        if (((ia == ja))) {\n            return false;\n        }\n    ;\n    ;\n        ha.unread_count = ((ia ? 0 : 1));\n        w.setResource(ha.thread_id, ha);\n        r.updatedThread(ha.thread_id);\n        return true;\n    };\n;\n    function ca(ha) {\n        var ia = w.getAllResources();\n        for (var ja in ia) {\n            var ka = ia[ja];\n            if (((ka.folder == ha))) {\n                ka.unread_count = 0;\n                w.setResource(ja, ka);\n                r.updatedThread(ja);\n            }\n        ;\n        ;\n        };\n    ;\n    };\n;\n    function da(ha, ia) {\n        if (((!ha || ((ha.chat_clear_time === ia))))) {\n            return false;\n        }\n    ;\n    ;\n        ha.chat_clear_time = ia;\n        w.setResource(ha.thread_id, ha);\n        r.reorderedMessages(ha.thread_id);\n        return true;\n    };\n;\n    function ea(ha, ia, ja) {\n        var ka = ia.action_type;\n        if (((((ka == u.MercuryActionType.USER_GENERATED_MESSAGE)) || ((ka == u.MercuryActionType.LOG_MESSAGE))))) {\n            ((ia.is_unread && ha.unread_count++));\n            ha.is_archived = false;\n        }\n    ;\n    ;\n        switch (ka) {\n          case u.MercuryActionType.USER_GENERATED_MESSAGE:\n            z(ha, ia.author);\n            break;\n          case u.MercuryActionType.LOG_MESSAGE:\n            var la = ia.log_message_type;\n            if (((la == u.MercuryLogMessageType.SUBSCRIBE))) {\n                x(ha, ia.log_message_data.added_participants);\n            }\n             else if (((la == u.MercuryLogMessageType.UNSUBSCRIBE))) {\n                y(ha, ia.author);\n            }\n             else if (((la == u.MercuryLogMessageType.THREAD_IMAGE))) {\n                ha.image_src = ((ia.log_message_data.image ? ia.log_message_data.image.preview_url : null));\n            }\n             else if (((la == u.MercuryLogMessageType.THREAD_NAME))) {\n                ha.JSBNG__name = ia.log_message_data.JSBNG__name;\n            }\n            \n            \n            \n        ;\n        ;\n            break;\n          case u.MercuryActionType.CHANGE_READ_STATUS:\n            if (ia.timestamp) {\n                r.changedThreadReadState(ha.thread_id, ia.mark_as_read, ia.timestamp);\n            }\n        ;\n        ;\n            ba(ha, ia.mark_as_read);\n            break;\n          case u.MercuryActionType.CLEAR_CHAT:\n            da(ha, ia.clear_time);\n            break;\n          case u.MercuryActionType.CHANGE_ARCHIVED_STATUS:\n            ha.is_archived = ia.archived;\n            break;\n          case u.MercuryActionType.CHANGE_FOLDER:\n            ha.folder = ia.new_folder;\n            break;\n          case u.MercuryActionType.DELETE_MESSAGES:\n            if (ja) {\n                ha.snippet = \"...\";\n                ha.snippet_has_attachment = false;\n                ha.snippet_attachments = null;\n                ha.is_forwarded_snippet = false;\n                r.updatedThread(ia.thread_id);\n            }\n        ;\n        ;\n            break;\n        };\n    ;\n        if (ia.action_id) {\n            ha.last_action_id = l.maxValidActionID(ia.action_id, ha.last_action_id);\n        }\n    ;\n    ;\n    };\n;\n    function fa(ha) {\n        var ia = q.tokenizeThreadID(ha.thread_id);\n        if (((ia.type == \"group\"))) {\n            v.error(\"invalid_new_thread_message\", ha);\n            return undefined;\n        }\n    ;\n    ;\n        var ja = {\n            thread_id: ha.thread_id,\n            last_action_id: ha.action_id,\n            participants: ha.specific_to_list,\n            JSBNG__name: null,\n            snippet: ha.body,\n            snippet_has_attachment: false,\n            snippet_attachments: [],\n            unread_count: 0,\n            image_src: null,\n            timestamp_absolute: ha.timestamp_absolute,\n            timestamp_relative: ha.timestamp_relative,\n            timestamp: ha.timestamp,\n            is_canonical_user: ((ia.type == \"user\")),\n            is_canonical: ((((ia.type == \"user\")) || ((ia.type == \"email\")))),\n            is_subscribed: true,\n            is_canonical_group: false,\n            is_chatlogger_thread: false,\n            group_id: null,\n            root_message_threading_id: ha.message_id,\n            folder: u.MessagingTag.INBOX,\n            is_archived: false,\n            mode: u.MercuryThreadMode.TITAN_ORIGINATED\n        };\n        w.setResource(ja.thread_id, ja);\n        return ja;\n    };\n;\n    g.subscribe(i.DUMP_EVENT, function(ha, ia) {\n        ia.messaging = ((ia.messaging || {\n        }));\n        ia.messaging.threads = w.dumpResources();\n    });\n    var ga = {\n        getThreadMetaNow: function(ha) {\n            n.isThreadID(ha);\n            return w.getResource(ha);\n        },\n        getThreadMeta: function(ha, ia) {\n            n.isThreadID(ha);\n            var ja = w.executeOrEnqueue(ha, ia), ka = w.getUnavailableResources(ja);\n            if (ka.length) {\n                var la = q.tokenizeThreadID(ha);\n                if (((la.type == \"user\"))) {\n                    ga.getCanonicalThreadToUser(la.value);\n                }\n                 else q.fetchThreadData(ka);\n            ;\n            ;\n            }\n        ;\n        ;\n            return ja;\n        },\n        unsubscribe: function(ha) {\n            w.unsubscribe(ha);\n        },\n        changeThreadReadStatus: function(ha, ia) {\n            n.isThreadID(ha);\n            var ja = w.getResource(ha);\n            if (ba(ja, ia)) {\n                q.changeThreadReadStatus(ha, ia, m.getFromMeta(ja));\n            }\n        ;\n        ;\n        },\n        changeThreadArchivedStatus: function(ha, ia) {\n            n.isThreadID(ha);\n            var ja = w.getResource(ha);\n            if (((ja.is_archived != ia))) {\n                ja.is_archived = ia;\n                r.updatedThread(ja.thread_id);\n                q.changeThreadArchivedStatus(ha, ia);\n            }\n        ;\n        ;\n        },\n        markThreadSpam: function(ha) {\n            q.markThreadSpam(ha);\n        },\n        unmarkThreadSpam: function(ha) {\n            q.unmarkThreadSpam(ha);\n        },\n        changeFolder: function(ha, ia) {\n            n.isThreadID(ha);\n            var ja = w.getResource(ha);\n            if (((ja && ((ja.folder != ia))))) {\n                ja.folder = ia;\n                r.updatedThread(ja.thread_id);\n                q.changeThreadFolder(ha, ia);\n            }\n        ;\n        ;\n        },\n        deleteThread: function(ha) {\n            n.isThreadID(ha);\n            q.deleteThread(ha);\n        },\n        updateThreads: function(ha) {\n            if (((!ha || !ha.length))) {\n                return;\n            }\n        ;\n        ;\n            var ia = {\n            };\n            ha.forEach(function(ja) {\n                ia[ja.thread_id] = ja;\n            });\n            w.addResourcesAndExecute(ia);\n        },\n        updateMetadataByActions: function(ha, ia) {\n            if (((!ha || !ha.length))) {\n                return;\n            }\n        ;\n        ;\n            var ja = {\n            }, ka = {\n            }, la = {\n            };\n            for (var ma = 0; ((ma < ha.length)); ma++) {\n                var na = ha[ma];\n                if (na.is_forward) {\n                    continue;\n                }\n            ;\n            ;\n                var oa = na.action_type, pa = na.thread_id;\n                n.isThreadID(pa);\n                var qa = ga.getThreadMetaNow(pa);\n                if (((((oa == u.MercuryActionType.LOG_MESSAGE)) && ((na.log_message_type == u.MercuryLogMessageType.SERVER_ERROR))))) {\n                    continue;\n                }\n            ;\n            ;\n                if (((((!qa && !na.action_id)) && ((oa == u.MercuryActionType.USER_GENERATED_MESSAGE))))) {\n                    qa = fa(na);\n                }\n            ;\n            ;\n                if (qa) {\n                    if (((oa == u.MercuryActionType.DELETE_THREAD))) {\n                        r.deletedThread(pa);\n                        continue;\n                    }\n                ;\n                ;\n                    var ra = !!na.action_id;\n                    if (((((oa == u.MercuryActionType.LOG_MESSAGE)) || ((oa == u.MercuryActionType.USER_GENERATED_MESSAGE))))) {\n                        ra = !ia;\n                    }\n                ;\n                ;\n                    if (((((na.timestamp <= qa.timestamp)) && ra))) {\n                        v.log(\"ignore_old_timestamp\", {\n                            action: na,\n                            from_client: ia,\n                            thread_timestamp: qa.timestamp\n                        });\n                        continue;\n                    }\n                ;\n                ;\n                    if (!la[pa]) {\n                        la[pa] = h({\n                        }, qa);\n                    }\n                ;\n                ;\n                    ea(la[pa], na, ia);\n                    if (((oa == u.MercuryActionType.USER_GENERATED_MESSAGE))) {\n                        ja[pa] = na;\n                    }\n                ;\n                ;\n                    if (((((((oa == u.MercuryActionType.USER_GENERATED_MESSAGE)) || ((oa == u.MercuryActionType.LOG_MESSAGE)))) || ((oa == u.MercuryActionType.SEND_MESSAGE))))) {\n                        if (((((na && na.timestamp)) && ((!ka[pa] || ((na.timestamp > ka[pa].timestamp))))))) {\n                            ka[pa] = na;\n                        }\n                    ;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            for (var sa in la) {\n                var ta = la[sa], ua = ja[sa];\n                if (ua) {\n                    aa(ta, ua);\n                }\n            ;\n            ;\n                var va = ka[sa], wa = ta.timestamp;\n                if (((va && ((va.timestamp > wa))))) {\n                    ta = h(ta, {\n                        timestamp_absolute: va.timestamp_absolute,\n                        timestamp_relative: va.timestamp_relative,\n                        timestamp: va.timestamp\n                    });\n                }\n            ;\n            ;\n                w.setResource(sa, ta);\n            };\n        ;\n        },\n        getCanonicalThreadToGroup: function(ha, ia) {\n            var ja = ((\"group:\" + ha));\n            ga.getThreadMeta(ja, ia);\n        },\n        getCanonicalThreadToUser: function(ha, ia) {\n            return ga.getCanonicalThreadToParticipant(((\"fbid:\" + ha)), ia);\n        },\n        getCanonicalThreadToParticipant: function(ha, ia) {\n            var ja = ga.getThreadIDForParticipant(ha), ka = w.getResource(ja);\n            if (((typeof ka == \"undefined\"))) {\n                ka = ga.createNewLocalThread(ja, [t.user,ha,], ia);\n                q.fetchThreadData([ja,]);\n            }\n        ;\n        ;\n            return ka;\n        },\n        getThreadIdForUser: function(ha) {\n            return ((\"user:\" + ha));\n        },\n        getThreadIdForEmail: function(ha) {\n            return ((\"email:\" + ha));\n        },\n        getThreadIDForParticipant: function(ha) {\n            var ia = p.tokenize(ha);\n            return ((((ia.type == \"fbid\")) ? ga.getThreadIdForUser(ia.value) : ga.getThreadIdForEmail(ia.value)));\n        },\n        createNewLocalThread: function(ha, ia, ja) {\n            var ka = w.getResource(ha);\n            if (!ka) {\n                var la = q.tokenizeThreadID(ha);\n                ka = {\n                    thread_id: ha,\n                    last_action_id: null,\n                    participants: ia,\n                    JSBNG__name: null,\n                    snippet: \"\",\n                    snippet_has_attachment: false,\n                    unread_count: ((ja ? ja : 0)),\n                    image_src: null,\n                    timestamp_absolute: null,\n                    timestamp_relative: null,\n                    timestamp: null,\n                    is_canonical_user: ((la.type == \"user\")),\n                    is_canonical: ((((la.type == \"user\")) || ((la.type == \"email\")))),\n                    is_subscribed: true,\n                    is_canonical_group: ((la.type == \"group\")),\n                    group_id: ((((la.type == \"group\")) ? la.value : null)),\n                    root_message_threading_id: null,\n                    folder: u.MessagingTag.INBOX,\n                    is_archived: false,\n                    mode: u.MercuryThreadMode.TITAN_ORIGINATED\n                };\n                ka.is_chatlogger_thread = ka.is_canonical_group;\n                w.setResource(ha, ka);\n            }\n        ;\n        ;\n            return ka;\n        },\n        addParticipantsToThreadLocally: function(ha, ia) {\n            var ja = w.getResource(ha);\n            if (ja) {\n                x(ja, ia);\n                r.updatedThread(ja.thread_id);\n            }\n        ;\n        ;\n        },\n        getCanonicalUserInThread: function(ha) {\n            var ia = q.tokenizeThreadID(ha);\n            return ((((ia.type == \"user\")) ? ia.value : null));\n        },\n        getCanonicalGroupInThread: function(ha) {\n            var ia = q.tokenizeThreadID(ha);\n            return ((((ia.type == \"group\")) ? ia.value : null));\n        },\n        isEmptyLocalThread: function(ha) {\n            var ia = w.getResource(ha);\n            if (!ia) {\n                return false;\n            }\n        ;\n        ;\n            var ja = q.tokenizeThreadID(ha);\n            return ((((ja.type == \"root\")) && !ia.timestamp));\n        },\n        isMultichatThread: function(ha) {\n            var ia = q.tokenizeThreadID(ha).type;\n            return ((((((ia != \"user\")) && ((ia != \"group\")))) && ((ia != \"email\"))));\n        }\n    };\n    q.subscribe(\"update-threads\", function(ha, ia) {\n        var ja = ((ia.actions || [])).filter(function(na) {\n            return na.thread_id;\n        });\n        ga.updateThreads(ia.threads);\n        ga.updateMetadataByActions(ja, ia.from_client);\n        ((ia.threads || [])).forEach(function(na) {\n            r.updatedThread(na.thread_id);\n        });\n        var ka = ((ia.global_actions || []));\n        for (var la = 0; ((la < ka.length)); la++) {\n            var ma = ka[la];\n            if (((ma.action_type == u.MercuryGlobalActionType.MARK_ALL_READ))) {\n                ca(ma.folder);\n            }\n        ;\n        ;\n        };\n    ;\n    });\n    e.exports = ga;\n});\n__d(\"ChatActivity\", [\"Arbiter\",\"AvailableList\",\"AvailableListConstants\",\"copyProperties\",\"event-extensions\",\"JSLogger\",\"MercuryThreads\",\"PresenceState\",\"UserActivity\",\"MercuryConfig\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AvailableList\"), i = b(\"AvailableListConstants\"), j = b(\"copyProperties\");\n    b(\"event-extensions\");\n    var k = b(\"JSLogger\"), l = b(\"MercuryThreads\"), m = b(\"PresenceState\"), n = b(\"UserActivity\"), o = c(\"MercuryConfig\"), p = ((o.activity_limit || 60000)), q = ((o.idle_limit || 1800000)), r = ((o.idle_poll_interval || 300000)), s = k.create(\"chat_activity\"), t = JSBNG__Date.now(), u = t, v = true;\n    function w() {\n        var aa = JSBNG__Date.now();\n        return !!((v && ((((aa - t)) < p))));\n    };\n;\n    var x = j(new g(), {\n        isActive: w\n    });\n    function y() {\n        var aa = t;\n        t = JSBNG__Date.now();\n        if (((((t - aa)) > q))) {\n            s.debug(\"idle_to_active\", aa);\n            m.doSync();\n        }\n    ;\n    ;\n        x.inform(\"activity\");\n    };\n;\n    h.subscribe(i.ON_AVAILABILITY_CHANGED, function() {\n        if (!h.isUserIdle()) {\n            u = JSBNG__Date.now();\n        }\n    ;\n    ;\n    });\n    JSBNG__Event.listen(window, \"JSBNG__focus\", function() {\n        v = true;\n        y();\n    });\n    JSBNG__Event.listen(window, \"JSBNG__blur\", function() {\n        v = false;\n    });\n    n.subscribe(function() {\n        y();\n    });\n    function z(aa) {\n        var ba = ((((aa && aa.at)) && m.verifyNumber(aa.at)));\n        if (((typeof ba !== \"number\"))) {\n            ba = null;\n        }\n    ;\n    ;\n        return ((ba || 0));\n    };\n;\n    JSBNG__setInterval(function() {\n        var aa = JSBNG__Date.now(), ba = z(m.get()), ca = Math.max(t, ba, u);\n        if (((((aa - ca)) > q))) {\n            s.debug(\"idle\", {\n                cookie: ba,\n                local: t,\n                presence: u\n            });\n            x.inform(\"idle\", ((aa - ca)));\n        }\n    ;\n    ;\n    }, r);\n    m.registerStateStorer(function(aa) {\n        var ba = z(aa);\n        if (((ba < t))) {\n            aa.at = t;\n        }\n    ;\n    ;\n        return aa;\n    });\n    g.subscribe(k.DUMP_EVENT, function(aa, ba) {\n        ba.chat_activity = {\n            activity_limit: p,\n            idle_limit: q,\n            idle_poll_interval: r,\n            last_active_time: t,\n            last_global_active_time: u\n        };\n    });\n    e.exports = x;\n});\n__d(\"MercuryMessages\", [\"Arbiter\",\"copyProperties\",\"Env\",\"JSLogger\",\"randomInt\",\"tx\",\"KeyedCallbackManager\",\"MercuryAssert\",\"MercuryIDs\",\"MercuryMessageIDs\",\"MercuryParticipants\",\"PresenceUtil\",\"RangedCallbackManager\",\"MercuryServerRequests\",\"MercuryServerDispatcher\",\"MercuryThreadInformer\",\"MercuryThreads\",\"MercuryConstants\",\"MercuryConfig\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"copyProperties\"), i = b(\"Env\"), j = b(\"JSLogger\"), k = b(\"randomInt\"), l = b(\"tx\"), m = b(\"KeyedCallbackManager\"), n = b(\"MercuryAssert\"), o = b(\"MercuryIDs\"), p = b(\"MercuryMessageIDs\"), q = b(\"MercuryParticipants\"), r = b(\"PresenceUtil\"), s = b(\"RangedCallbackManager\"), t = b(\"MercuryServerRequests\"), u = b(\"MercuryServerDispatcher\"), v = b(\"MercuryThreadInformer\"), w = b(\"MercuryThreads\"), x = c(\"MercuryConstants\"), y = c(\"MercuryConfig\"), z = x.MercuryGenericConstants, aa = {\n    }, ba = {\n    }, ca = {\n    }, da = function(sa) {\n        var ta = sa;\n        if (ba[sa]) {\n            ta = ba[sa];\n        }\n    ;\n    ;\n        return aa[ta];\n    }, ea = {\n    }, fa = {\n    }, ga = new m();\n    function ha(sa) {\n        if (((sa.JSBNG__status === undefined))) {\n            sa.JSBNG__status = x.MercuryActionStatus.UNSENT;\n        }\n    ;\n    ;\n        sa.message_id = ((sa.message_id || na.generateNewClientMessageID(sa.timestamp)));\n        var ta = q.user;\n        sa.specific_to_list = ((sa.specific_to_list || []));\n        if (((sa.specific_to_list.length && ((sa.specific_to_list.indexOf(ta) === -1))))) {\n            sa.specific_to_list.push(ta);\n        }\n    ;\n    ;\n        if (!sa.thread_id) {\n            if (((sa.specific_to_list.length == 1))) {\n                sa.thread_id = ((\"user:\" + i.user));\n            }\n             else if (((sa.specific_to_list.length == 2))) {\n                var ua = ((((sa.specific_to_list[0] == ta)) ? sa.specific_to_list[1] : sa.specific_to_list[0]));\n                if (((o.tokenize(ua).type == \"email\"))) {\n                    sa.thread_id = z.PENDING_THREAD_ID;\n                }\n                 else sa.thread_id = w.getThreadIDForParticipant(ua);\n            ;\n            ;\n            }\n            \n        ;\n        ;\n            sa.thread_id = ((sa.thread_id || ((\"root:\" + sa.message_id))));\n        }\n    ;\n    ;\n        if (!sa.specific_to_list.length) {\n            var va = t.tokenizeThreadID(sa.thread_id);\n            if (((va.type == \"user\"))) {\n                sa.specific_to_list = [((\"fbid:\" + va.value)),ta,];\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    };\n;\n    function ia(sa, ta, ua) {\n        var va = ((ra(ta) ? [x.MercuryMessageSourceTags.CHAT,] : [])), wa = JSBNG__Date.now(), xa = JSBNG__Date.format(((y[\"24h_times\"] ? \"H:i\" : \"g:ia\")), Math.floor(((wa / 1000)))), ya = {\n            action_type: sa,\n            thread_id: ua,\n            author: q.user,\n            author_email: null,\n            coordinates: null,\n            timestamp: wa,\n            timestamp_absolute: (new JSBNG__Date(wa)).toLocaleDateString(),\n            timestamp_relative: xa,\n            is_unread: false,\n            is_cleared: false,\n            is_forward: false,\n            spoof_warning: false,\n            source: ta,\n            source_tags: va\n        };\n        return ya;\n    };\n;\n    function ja(sa) {\n        switch (sa) {\n          case x.MercuryPayloadSource.UNKNOWN:\n        \n          case x.MercuryPayloadSource.SERVER_INITIAL_DATA:\n        \n          case x.MercuryPayloadSource.SERVER_FETCH_THREAD_INFO:\n        \n          case x.MercuryPayloadSource.SERVER_THREAD_SYNC:\n            return true;\n        };\n    ;\n        return false;\n    };\n;\n    function ka(sa) {\n        return ((sa && ((sa.substr(0, 6) === \"server\"))));\n    };\n;\n    function la(sa) {\n        if (!ea[sa]) {\n            ea[sa] = new s(function(ta) {\n                return da(ta).timestamp;\n            }, function(ta, ua) {\n                return ((ua - ta));\n            });\n        }\n    ;\n    ;\n        return ea[sa];\n    };\n;\n    g.subscribe(j.DUMP_EVENT, function(sa, ta) {\n        var ua = {\n        };\n        for (var va in aa) {\n            var wa = aa[va], xa = wa.thread_id;\n            ua[xa] = ((ua[xa] || {\n            }));\n            ua[xa][wa.message_id] = h({\n            }, wa);\n        };\n    ;\n        ta.messaging = ((ta.messaging || {\n        }));\n        ta.messaging.local_message_ids = h({\n        }, ba);\n        ta.messaging.messages = ua;\n    });\n    function ma(sa, ta) {\n        sa.forEach(function(ua) {\n            var va = la(ua);\n            va.setReachedEndOfArray();\n            v.reorderedMessages(ua, ta);\n        });\n    };\n;\n    var na = {\n        getMessagesFromIDs: function(sa) {\n            return ((sa || [])).map(da).filter(function(ta) {\n                return ta;\n            });\n        },\n        hasLoadedNMessages: function(sa, ta) {\n            var ua = la(sa);\n            return ((ua.hasReachedEndOfArray() || ((ua.getCurrentArraySize() >= ta))));\n        },\n        getThreadMessagesRangeImmediately: function(sa, ta, ua, va) {\n            return na.getThreadMessagesRange(sa, ta, ua, va, u.IMMEDIATE);\n        },\n        getThreadMessagesRange: function(sa, ta, ua, va, wa) {\n            var xa = la(sa), ya = function(db) {\n                va(oa(db));\n            }, za = xa.executeOrEnqueue(ta, ua, ya), ab = xa.getUnavailableResources(za), bb = ca[sa];\n            if (((ab.length && !bb))) {\n                var cb = ((fa[sa] || 0));\n                t.fetchThreadMessages(sa, cb, ab.length, wa);\n            }\n             else ca[sa] = false;\n        ;\n        ;\n            return za;\n        },\n        getThreadMessagesSinceTimestamp: function(sa, ta) {\n            var ua = la(sa), va = ua.getElementsUntil(ta);\n            return oa(va);\n        },\n        hasLoadedAllMessages: function(sa) {\n            return la(sa).hasReachedEndOfArray();\n        },\n        unsubscribe: function(sa, ta) {\n            n.isThreadID(ta);\n            var ua = la(ta);\n            ua.unsubscribe(sa);\n        },\n        handleUpdates: function(sa, ta, ua) {\n            var va = {\n            }, wa = {\n            }, xa = x.MercuryActionStatus;\n            for (var ya = 0; ((ya < sa.length)); ya++) {\n                var za = sa[ya];\n                if (((za.is_forward || ((ua == x.MercuryPayloadSource.SERVER_SEARCH))))) {\n                    if (!aa[za.message_id]) {\n                        aa[za.message_id] = za;\n                    }\n                ;\n                ;\n                    continue;\n                }\n            ;\n            ;\n                var ab = za.action_type;\n                if (((ab == x.MercuryActionType.SEND_MESSAGE))) {\n                    var bb = za.client_message_id;\n                    if (((((bb && ba[bb])) && za.JSBNG__status))) {\n                        if (((za.JSBNG__status == xa.UNCONFIRMED))) {\n                            if (!wa[za.thread_id]) {\n                                wa[za.thread_id] = [];\n                            }\n                        ;\n                        ;\n                            wa[za.thread_id].push(za.client_message_id);\n                        }\n                         else if (!va[za.thread_id]) {\n                            va[za.thread_id] = [];\n                        }\n                        \n                    ;\n                    ;\n                        var cb = da(za.client_message_id), db = cb.JSBNG__status;\n                        cb.JSBNG__status = za.JSBNG__status;\n                        if (((za.JSBNG__status == xa.SUCCESS))) {\n                            na.updateLocalMessage(za, ua);\n                            if (((za.client_thread_id == z.PENDING_THREAD_ID))) {\n                                cb.thread_id = za.thread_id;\n                                va[za.thread_id].push(cb.message_id);\n                                ga.setResource(cb.message_id, cb.thread_id);\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                        if (((((((((((((typeof db != \"undefined\")) || ((za.JSBNG__status == xa.REQUEST_ERROR)))) || ((za.JSBNG__status == xa.TRANSPORT_ERROR)))) || ((za.JSBNG__status == xa.FAILED_UNKNOWN_REASON)))) || ((za.JSBNG__status == xa.UNABLE_TO_CONFIRM)))) || ((za.JSBNG__status == xa.SUCCESS))))) {\n                            v.updatedMessage(za.thread_id, da(za.client_message_id).message_id, ua);\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    continue;\n                }\n                 else if (((ab == x.MercuryActionType.DELETE_THREAD))) {\n                    la(za.thread_id).removeAllResources();\n                    continue;\n                }\n                 else if (((ab == x.MercuryActionType.DELETE_MESSAGES))) {\n                    var eb = za.message_ids.map(function(mb) {\n                        return da(mb).message_id;\n                    }), fb = la(za.thread_id);\n                    fb.removeResources(eb);\n                    v.reorderedMessages(za.thread_id, ua);\n                    continue;\n                }\n                 else if (((ab == x.MercuryActionType.LOG_MESSAGE))) {\n                    if (((za.log_message_type == x.MercuryLogMessageType.SERVER_ERROR))) {\n                        ca[za.thread_id] = true;\n                    }\n                ;\n                ;\n                }\n                 else if (((ab == x.MercuryActionType.CLEAR_CHAT))) {\n                    var gb = la(za.thread_id).getAllResources();\n                    gb.map(da).forEach(function(mb) {\n                        mb.is_cleared = true;\n                    });\n                    continue;\n                }\n                \n                \n                \n                \n            ;\n            ;\n                var hb = da(za.message_id);\n                if (((((za.threading_id && ba[za.threading_id])) || ((hb && !hb.is_forward))))) {\n                    continue;\n                }\n            ;\n            ;\n                if (!va[za.thread_id]) {\n                    va[za.thread_id] = [];\n                }\n            ;\n            ;\n                va[za.thread_id].push(za.message_id);\n                aa[za.message_id] = za;\n                if (((za.threading_id && ((za.threading_id != za.message_id))))) {\n                    p.addServerID(za.threading_id, za.message_id);\n                }\n            ;\n            ;\n                if (!ta) {\n                    v.receivedMessage(za);\n                }\n            ;\n            ;\n            };\n        ;\n            for (var ib in va) {\n                var fb = la(ib), jb = fb.getAllResources(), kb = jb.filter(function(mb) {\n                    var nb = aa[mb];\n                    return ((((nb.action_type == x.MercuryActionType.LOG_MESSAGE)) && ((nb.log_message_type == x.MercuryLogMessageType.SERVER_ERROR))));\n                });\n                fb.removeResources(kb);\n                pa(ib, va[ib]);\n                if (ta) {\n                    fb.addResources(va[ib]);\n                    v.reorderedMessages(ib, ua);\n                }\n                 else fb.addResourcesWithoutSorting(va[ib].reverse(), 0);\n            ;\n            ;\n                v.updatedThread(ib);\n            };\n        ;\n            var lb = Object.keys(wa);\n            if (lb.length) {\n                t.requestMessageConfirmation(wa);\n            }\n        ;\n        ;\n        },\n        sendMessage: function(sa, ta) {\n            ta = ((ta || Function.prototype));\n            ha(sa);\n            ba[sa.message_id] = sa.message_id;\n            if (((sa.thread_id == ((\"root:\" + sa.message_id))))) {\n                la(sa.thread_id).setReachedEndOfArray();\n            }\n        ;\n        ;\n            t.sendNewMessage(sa);\n            if (((sa.thread_id == z.PENDING_THREAD_ID))) {\n                aa[sa.message_id] = sa;\n                return ga.executeOrEnqueue(sa.message_id, ta);\n            }\n             else ta(sa.thread_id);\n        ;\n        ;\n        },\n        unsubscribeSend: function(sa) {\n            ga.unsubscribe(sa);\n        },\n        resendMessage: function(sa) {\n            var ta = h({\n            }, sa);\n            ta.JSBNG__status = x.MercuryActionStatus.RESENDING;\n            ta.timestamp = (new JSBNG__Date()).getTime();\n            ta.message_id = na.generateNewClientMessageID(ta.timestamp);\n            var ua = la(sa.thread_id);\n            ua.removeResources([sa.message_id,]);\n            na.sendMessage(ta);\n            v.reorderedMessages(sa.thread_id, x.MercuryPayloadSource.CLIENT_SEND_MESSAGE);\n        },\n        deleteMessages: function(sa, ta) {\n            if (ta.length) {\n                var ua = la(sa), va = ((((ua.getCurrentArraySize() == ta.length)) && ua.hasReachedEndOfArray()));\n                t.deleteMessages(sa, ta, va);\n            }\n        ;\n        ;\n        },\n        updateLocalMessage: function(sa, ta) {\n            var ua = sa.message_id, va = sa.client_message_id;\n            ba[va] = ua;\n            aa[ua] = aa[va];\n            p.addServerID(va, ua);\n            aa[va] = {\n            };\n            if (sa.timestamp) {\n                da(va).timestamp = sa.timestamp;\n            }\n        ;\n        ;\n            if (((sa.attachments && sa.attachments.length))) {\n                da(va).raw_attachments = null;\n                da(va).attachments = sa.attachments;\n            }\n        ;\n        ;\n        },\n        constructUserGeneratedMessageObject: function(sa, ta, ua, va) {\n            var wa = ia(x.MercuryActionType.USER_GENERATED_MESSAGE, ta, ua);\n            wa.body = sa;\n            wa.has_attachment = false;\n            wa.html_body = false;\n            wa.attachments = [];\n            wa.specific_to_list = ((va || []));\n            return wa;\n        },\n        constructLogMessageObject: function(sa, ta, ua, va) {\n            var wa = ia(x.MercuryActionType.LOG_MESSAGE, sa, ta);\n            wa.log_message_type = ua;\n            wa.log_message_data = va;\n            return wa;\n        },\n        generateNewClientMessageID: function(sa) {\n            var ta = ((((((((sa + \":\")) + ((k(0, 4294967295) + 1)))) + \"-\")) + r.getSessionID()));\n            return ((((\"\\u003C\" + ta)) + \"@mail.projektitan.com\\u003E\"));\n        }\n    };\n    t.subscribe(\"update-messages\", function(sa, ta) {\n        var ua = ((ta.actions || [])).filter(function(wa) {\n            var xa = wa.action_type;\n            return ((((wa.is_forward || wa.thread_id)) && ((((((((((((xa == x.MercuryActionType.LOG_MESSAGE)) || ((xa == x.MercuryActionType.USER_GENERATED_MESSAGE)))) || ((xa == x.MercuryActionType.SEND_MESSAGE)))) || ((xa == x.MercuryActionType.CLEAR_CHAT)))) || ((xa == x.MercuryActionType.DELETE_THREAD)))) || ((xa == x.MercuryActionType.DELETE_MESSAGES))))));\n        }), va = ja(ta.payload_source);\n        if (ka(ta.payload_source)) {\n            ua.forEach(function(wa) {\n                if (!wa.is_forward) {\n                    var xa = w.getThreadMetaNow(wa.thread_id);\n                    if (xa) {\n                        wa.is_cleared = ((wa.timestamp < xa.chat_clear_time));\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            });\n        }\n    ;\n    ;\n        na.handleUpdates(ua, va, ta.payload_source);\n        if (ta.end_of_history) {\n            ma(ta.end_of_history, ta.payload_source);\n        }\n    ;\n    ;\n    });\n    function oa(sa) {\n        var ta = sa.map(da);\n        return ta.reverse();\n    };\n;\n    function pa(sa, ta) {\n        var ua = ta.filter(function(va) {\n            return qa(da(va));\n        });\n        if (!fa[sa]) {\n            fa[sa] = 0;\n        }\n    ;\n    ;\n        fa[sa] += ua.length;\n    };\n;\n    function qa(sa) {\n        var ta = sa.action_type;\n        if (((ta == x.MercuryActionType.USER_GENERATED_MESSAGE))) {\n            return true;\n        }\n    ;\n    ;\n        switch (sa.log_message_type) {\n          case x.MercuryLogMessageType.SUBSCRIBE:\n        \n          case x.MercuryLogMessageType.UNSUBSCRIBE:\n        \n          case x.MercuryLogMessageType.SERVER_ERROR:\n        \n          case x.MercuryLogMessageType.LIVE_LISTEN:\n            return false;\n          default:\n            return true;\n        };\n    ;\n    };\n;\n    function ra(sa) {\n        switch (sa) {\n          case x.MercurySourceType.CHAT_WEB:\n        \n          case x.MercurySourceType.CHAT_JABBER:\n        \n          case x.MercurySourceType.CHAT_IPHONE:\n        \n          case x.MercurySourceType.CHAT_MEEBO:\n        \n          case x.MercurySourceType.CHAT_ORCA:\n        \n          case x.MercurySourceType.CHAT_TEST:\n        \n          case x.MercurySourceType.CHAT:\n        \n          case x.MercurySourceType.DESKTOP:\n            return true;\n          default:\n            return false;\n        };\n    ;\n    };\n;\n    e.exports = na;\n});\n__d(\"MercuryNotificationRenderer\", [\"MercuryAssert\",\"MercuryMessages\",\"MercuryParticipants\",\"MercuryThreads\",\"tx\",], function(a, b, c, d, e, f) {\n    var g = b(\"MercuryAssert\"), h = b(\"MercuryMessages\"), i = b(\"MercuryParticipants\"), j = b(\"MercuryThreads\"), k = b(\"tx\");\n    function l(m, n) {\n        g.isThreadID(m);\n        j.getThreadMeta(m, function(o) {\n            h.getThreadMessagesRange(m, 0, 1, function(p) {\n                var q = ((p.length && p[((p.length - 1))]));\n                if (((q && ((q.author != i.user))))) {\n                    i.get(q.author, function(r) {\n                        if (o.JSBNG__name) {\n                            n(k._(\"{senderName} messaged {groupName}\", {\n                                senderName: r.short_name,\n                                groupName: o.JSBNG__name\n                            }));\n                        }\n                         else n(k._(\"{name} messaged you\", {\n                            JSBNG__name: r.short_name\n                        }));\n                    ;\n                    ;\n                    });\n                }\n                 else n(\"New message!\");\n            ;\n            ;\n            });\n        });\n    };\n;\n    e.exports = {\n        renderDocumentTitle: l\n    };\n});\n__d(\"MercuryUnseenState\", [\"Arbiter\",\"copyProperties\",\"TimestampConverter\",\"KeyedCallbackManager\",\"JSLogger\",\"createObjectFrom\",\"MercuryServerRequests\",\"MercuryThreadInformer\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"copyProperties\"), i = b(\"TimestampConverter\"), j = b(\"KeyedCallbackManager\"), k = b(\"JSLogger\"), l = b(\"createObjectFrom\"), m = b(\"MercuryServerRequests\"), n = b(\"MercuryThreadInformer\"), o = c(\"MercuryConstants\"), p = o.MercuryThreadlistConstants.MAX_UNSEEN_COUNT, q = 0, r = 0, s = false, t = new j(), u = \"unseen_thread_hash\", v = \"unseen_thread_list\", w = k.create(\"mercury_unseen_state\"), x = {\n        getUnseenCount: function() {\n            if (x.exceedsMaxCount()) {\n                w.error(\"unguarded_unseen_count_fetch\", {\n                });\n                return 0;\n            }\n        ;\n        ;\n            return ba();\n        },\n        exceedsMaxCount: function() {\n            return ((s || ((ba() > p))));\n        },\n        markAsSeen: function() {\n            if (((((ba() > 0)) || s))) {\n                m.markSeen();\n                da(i.convertActionIDToTimestamp(m.getLastActionID()), []);\n            }\n        ;\n        ;\n        },\n        markThreadSeen: function(ka, la) {\n            var ma = {\n            };\n            ma[ka] = null;\n            fa(ma, la);\n        }\n    };\n    function y(ka) {\n        t.setResource(u, ka);\n        t.setResource(v, Object.keys(ka));\n    };\n;\n    function z(ka) {\n        var la = t.executeOrEnqueue(u, ka), ma = t.getUnavailableResources(la);\n        if (ma.length) {\n            m.fetchUnseenThreadIDs();\n        }\n    ;\n    ;\n    };\n;\n    function aa() {\n        return t.getResource(u);\n    };\n;\n    function ba() {\n        var ka = t.getResource(v);\n        if (ka) {\n            return ka.length;\n        }\n         else return q\n    ;\n    };\n;\n    function ca(ka) {\n        var la = ja(ka);\n        if (ka.unseen_thread_ids) {\n            ka.unseen_thread_ids.forEach(function(wa) {\n                if (((wa.folder != o.MessagingTag.INBOX))) {\n                    return;\n                }\n            ;\n            ;\n                var xa = ha(wa.thread_ids), ya = r;\n                if (((la && la.seen_timestamp))) {\n                    ya = la.seen_timestamp;\n                }\n            ;\n            ;\n                da(ya, xa);\n                if (((la && ((la.unseen_count > p))))) {\n                    s = true;\n                }\n            ;\n            ;\n            });\n        }\n         else if (((la && la.seen_timestamp))) {\n            r = la.seen_timestamp;\n            if (((la.unseen_count > p))) {\n                s = true;\n                y({\n                });\n            }\n             else {\n                q = la.unseen_count;\n                if (((q === 0))) {\n                    y({\n                    });\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        }\n         else {\n            if (s) {\n                return;\n            }\n        ;\n        ;\n            var ma = ka.actions;\n            if (((!ma || !(ma.length)))) {\n                return;\n            }\n        ;\n        ;\n            var na = {\n            }, oa = {\n            };\n            for (var pa = 0; ((pa < ma.length)); pa++) {\n                var qa = ma[pa];\n                if (qa.is_forward) {\n                    continue;\n                }\n            ;\n            ;\n                var ra = qa.action_type, sa = qa.action_id, ta = ((qa.thread_id ? qa.thread_id : qa.server_thread_id)), ua = ((((qa.folder === undefined)) || ((qa.folder == o.MessagingTag.INBOX))));\n                if (!ua) {\n                    continue;\n                }\n            ;\n            ;\n                if (((((ra == o.MercuryActionType.USER_GENERATED_MESSAGE)) || ((ra == o.MercuryActionType.LOG_MESSAGE))))) {\n                    var va = i.isGreaterThan(sa, na[ta]);\n                    if (((qa.is_unread && ((!na[ta] || va))))) {\n                        na[ta] = sa;\n                    }\n                ;\n                ;\n                }\n                 else if (((((ra == o.MercuryActionType.CHANGE_READ_STATUS)) && qa.mark_as_read))) {\n                    oa[ta] = sa;\n                }\n                \n            ;\n            ;\n            };\n        ;\n            ea(na);\n            fa(oa);\n        }\n        \n    ;\n    ;\n    };\n;\n    function da(ka, la) {\n        var ma = aa();\n        if (((((((ma === undefined)) || ((ka > r)))) || s))) {\n            r = ka;\n            la = ((la || []));\n            if (((la.length <= p))) {\n                s = false;\n            }\n        ;\n        ;\n            var na = {\n            }, oa = ((aa() || {\n            }));\n            for (var pa in oa) {\n                if (((oa[pa] !== true))) {\n                    var qa = oa[pa];\n                    if (ga(qa)) {\n                        na[pa] = qa;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            var ra = h(l(la, true), na);\n            y(ra);\n            n.updatedUnseenState();\n        }\n    ;\n    ;\n    };\n;\n    function ea(ka) {\n        if (s) {\n            return;\n        }\n    ;\n    ;\n        var la = {\n        }, ma = false;\n        for (var na in ka) {\n            var oa = ka[na];\n            if (ga(oa)) {\n                la[na] = oa;\n                ma = true;\n            }\n        ;\n        ;\n        };\n    ;\n        if (!ma) {\n            return;\n        }\n    ;\n    ;\n        z(function(pa) {\n            for (var qa in la) {\n                var ra = la[qa];\n                if (((!pa[qa] && ga(ra)))) {\n                    pa[qa] = la[qa];\n                }\n            ;\n            ;\n            };\n        ;\n            y(pa);\n            n.updatedUnseenState();\n        });\n    };\n;\n    function fa(ka, la) {\n        var ma = false;\n        for (var na in ka) {\n            ma = true;\n            break;\n        };\n    ;\n        if (ma) {\n            z(function(oa) {\n                var pa = false;\n                for (var qa in ka) {\n                    var ra = ka[qa], sa = i.isGreaterThan(ra, oa[qa]);\n                    if (((oa[qa] && ((!ra || sa))))) {\n                        delete oa[qa];\n                        pa = true;\n                    }\n                ;\n                ;\n                };\n            ;\n                if (pa) {\n                    y(oa);\n                    n.updatedUnseenState();\n                    if (((la && ((ba() === 0))))) {\n                        m.markSeen();\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            });\n        }\n    ;\n    ;\n    };\n;\n    function ga(ka) {\n        return ((i.convertActionIDToTimestamp(ka) > r));\n    };\n;\n    function ha(ka) {\n        return ka.map(m.convertThreadIDIfAvailable);\n    };\n;\n    function ia(ka) {\n        var la = aa();\n        if (!la) {\n            return;\n        }\n    ;\n    ;\n        for (var ma in ka) {\n            var na = ka[ma];\n            if (la[ma]) {\n                la[na] = la[ma];\n                delete la[ma];\n            }\n        ;\n        ;\n        };\n    ;\n        y(la);\n    };\n;\n    function ja(ka) {\n        var la = ((ka.message_counts || []));\n        for (var ma = 0; ((ma < la.length)); ma++) {\n            if (((la[ma].folder == o.MessagingTag.INBOX))) {\n                return la[ma];\n            }\n        ;\n        ;\n        };\n    ;\n        return null;\n    };\n;\n    m.subscribe(\"update-unseen\", function(ka, la) {\n        ca(la);\n    });\n    m.subscribe(\"update-thread-ids\", function(ka, la) {\n        ia(la);\n    });\n    g.subscribe(k.DUMP_EVENT, function(ka, la) {\n        la.messaging = ((la.messaging || {\n        }));\n        la.messaging.unseen = h({\n        }, aa());\n        la.messaging.unseen_max_count = s;\n        la.messaging.unseen_time = r;\n    });\n    e.exports = x;\n});\n__d(\"ChatTitleBarBlinker\", [\"ChatActivity\",\"DocumentTitle\",\"JSLogger\",\"MercuryThreadInformer\",\"MercuryNotificationRenderer\",\"PresenceState\",\"MercuryTimestampTracker\",\"MercuryUnseenState\",], function(a, b, c, d, e, f) {\n    var g = b(\"ChatActivity\"), h = b(\"DocumentTitle\"), i = b(\"JSLogger\"), j = b(\"MercuryThreadInformer\"), k = b(\"MercuryNotificationRenderer\"), l = b(\"PresenceState\"), m = b(\"MercuryTimestampTracker\"), n = b(\"MercuryUnseenState\"), o = i.create(\"chat_title\"), p = null, q = 0, r = false;\n    function s() {\n        if (p) {\n            p.JSBNG__stop();\n            p = null;\n            return true;\n        }\n    ;\n    ;\n        return false;\n    };\n;\n    function t(y) {\n        var z = ((y || m.getLastUserMessageTimestamp()));\n        if (((q <= z))) {\n            q = z;\n            if (((s() || r))) {\n                l.doSync();\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    };\n;\n    var u = {\n        blink: function(y, z) {\n            if (((!p && ((q < z))))) {\n                k.renderDocumentTitle(y, function(aa) {\n                    if (!p) {\n                        p = h.blink(aa);\n                    }\n                ;\n                ;\n                });\n            }\n        ;\n        ;\n        },\n        stopBlinking: function() {\n            t();\n        },\n        blinkingElsewhere: function() {\n            r = true;\n        }\n    };\n    function v(y) {\n        var z = l.verifyNumber(y.sb2);\n        if (((!z || ((z <= q))))) {\n            return null;\n        }\n    ;\n    ;\n        return z;\n    };\n;\n    function w(y) {\n        var z = ((y && v(y)));\n        if (z) {\n            q = z;\n            o.debug(\"load\", q);\n            s();\n            r = false;\n        }\n    ;\n    ;\n    };\n;\n    function x(y) {\n        var z = v(y);\n        if (!z) {\n            o.debug(\"store\", q);\n            y.sb2 = q;\n            r = false;\n        }\n    ;\n    ;\n        return y;\n    };\n;\n    l.registerStateStorer(x);\n    l.registerStateLoader(w);\n    j.subscribe(\"thread-read-changed\", function(y, z) {\n        var aa = m.getLastUserMessageTimestamp(), ba = 0;\n        for (var ca in z) {\n            if (((((z[ca].mark_as_read && ((z[ca].timestamp >= aa)))) && ((z[ca].timestamp > ba))))) {\n                ba = z[ca].timestamp;\n            }\n        ;\n        ;\n        };\n    ;\n        ((ba && t(ba)));\n    });\n    g.subscribe(\"activity\", function() {\n        t();\n    });\n    (function() {\n        var y = l.getInitial();\n        if (y) {\n            q = ((v(y) || 0));\n        }\n    ;\n    ;\n    })();\n    e.exports = u;\n});\n__d(\"MercuryBrowserAlerts\", [\"ArbiterMixin\",\"ChatActivity\",\"ChatConfig\",\"ChatOptions\",\"ChatTitleBarBlinker\",\"copyProperties\",\"MercuryParticipants\",\"Sound\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"ArbiterMixin\"), h = b(\"ChatActivity\"), i = b(\"ChatConfig\"), j = b(\"ChatOptions\"), k = b(\"ChatTitleBarBlinker\"), l = b(\"copyProperties\"), m = b(\"MercuryParticipants\"), n = b(\"Sound\"), o = c(\"MercuryConstants\");\n    n.init([\"audio/ogg\",\"audio/mpeg\",]);\n    function p(r) {\n        if (j.getSetting(\"sound\")) {\n            n.play([i.get(\"sound.notif_ogg_url\"),i.get(\"sound.notif_mp3_url\"),], r, false);\n        }\n    ;\n    ;\n    };\n;\n    var q = {\n        messageReceived: function(r) {\n            var s = o.MessagingTag;\n            if (((((((r.author == m.user)) || !r.is_unread)) || ((((r.folder != s.INBOX)) && ((r.folder != s.ARCHIVED))))))) {\n                return;\n            }\n        ;\n        ;\n            var t = h.isActive(), u = r.thread_id, v = r.timestamp;\n            if (t) {\n                var w = false;\n                q.inform(\"before-alert\", {\n                    threadID: u,\n                    cancelAlert: function() {\n                        w = true;\n                    }\n                });\n                ((!w && p(v)));\n            }\n             else {\n                k.blink(u, v);\n                p(v);\n            }\n        ;\n        ;\n            k.blinkingElsewhere();\n        }\n    };\n    e.exports = l(q, g);\n});\n__d(\"VideoCallRecordMessageDialog\", [\"Dialog\",\"URI\",], function(a, b, c, d, e, f) {\n    var g = b(\"Dialog\"), h = b(\"URI\"), i = {\n        get: function(j, k) {\n            return new g().setTitle(tx._(\"{firstname} is Unavailable\", {\n                firstname: k\n            })).setBody(\"Would you like to leave a video message?\").setButtons([{\n                JSBNG__name: \"record-message\",\n                label: \"Record Message\"\n            },g.CANCEL,]).setHandler(function() {\n                var l = h(\"/ajax/messaging/composer.php\").setQueryData({\n                    ids: [j,],\n                    autoloadvideo: true\n                }).toString();\n                g.bootstrap(l);\n            });\n        }\n    };\n    e.exports = i;\n});\n__d(\"VideoCallCore\", [\"event-extensions\",\"Arbiter\",\"AsyncRequest\",\"AvailableList\",\"AvailableListConstants\",\"Bootloader\",\"ChannelConstants\",\"Cookie\",\"Dialog\",\"UserAgent\",\"ge\",\"ShortProfiles\",\"VideoCallRecordMessageDialog\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"AvailableList\"), j = b(\"AvailableListConstants\"), k = b(\"Bootloader\"), l = b(\"ChannelConstants\"), m = b(\"Cookie\"), n = b(\"Dialog\"), o = b(\"UserAgent\"), p = b(\"ge\"), q = [], r = {\n        isSupported: function() {\n            if (o.windows()) {\n                return ((((((((((o.ie() >= 7)) && !o.ie64())) || ((o.firefox() >= 3.6)))) || ((o.JSBNG__chrome() >= 5)))) || ((o.JSBNG__opera() >= 12))));\n            }\n             else if (((o.osx() > 10.4))) {\n                return ((((((((o.firefox() >= 3.6)) || ((o.JSBNG__chrome() >= 5)))) || ((o.safari() >= 500)))) || ((o.JSBNG__opera() >= 12))));\n            }\n            \n        ;\n        ;\n            return false;\n        },\n        isInstalled: function() {\n            var v = false;\n            if (this.isSupported()) {\n                if (s()) {\n                    var w = null;\n                    try {\n                        w = new ActiveXObject(\"SkypeLimited.SkypeWebPlugin\");\n                        v = !!w;\n                    } catch (x) {\n                    \n                    };\n                ;\n                    w = null;\n                }\n                 else v = t();\n            ;\n            }\n        ;\n        ;\n            return v;\n        },\n        mightReloadPostInstall: function() {\n            return o.windows();\n        },\n        JSBNG__onVideoMessage: function(v) {\n            q.push(v);\n            k.loadModules([\"VideoCallController\",], bagofholding);\n        },\n        setMessageHandler: function(v) {\n            this.JSBNG__onVideoMessage = v;\n            if (v) {\n                while (q.length) {\n                    v(q.shift());\n                ;\n                };\n            }\n        ;\n        ;\n        },\n        availableForCall: function(v) {\n            var w = i.get(v);\n            return ((((w == j.ACTIVE)) || ((w == j.IDLE))));\n        },\n        JSBNG__onProfileButtonClick: function(v) {\n            r.startCallOrLeaveMessage(v, \"profile_button_click\");\n        },\n        attachListenerToProfileButton: function(v) {\n            var w = p(\"videoCallProfileButton\");\n            if (w) {\n                JSBNG__Event.listen(w, \"click\", function(JSBNG__event) {\n                    r.startCallOrLeaveMessage(v, \"profile_button_click_timeline\");\n                });\n            }\n        ;\n        ;\n        },\n        startCallOrLeaveMessage: function(v, w) {\n            if (this.availableForCall(v)) {\n                r.showOutgoingCallDialog(v, w);\n            }\n             else b(\"ShortProfiles\").get(v, function(x) {\n                b(\"VideoCallRecordMessageDialog\").get(v, x.firstName).show();\n            });\n        ;\n        ;\n        },\n        showOutgoingCallDialog: function(v, w) {\n            var x = ((w || \"unknown\"));\n            r.logClick(v, x);\n            var y = ((r.isInstalled() ? \"outgoing_dialog.php\" : \"intro.php\")), z = ((((((\"/ajax/chat/video/\" + y)) + \"?idTarget=\")) + v));\n            new n().setAllowCrossPageTransition(true).setAsync(new h(z)).show();\n        },\n        logClick: function(v, w) {\n            new h().setURI(\"/ajax/chat/video/log_click.php\").setData({\n                targetUserID: v,\n                clickSource: w\n            }).setAllowCrossPageTransition(true).setErrorHandler(bagofholding).send();\n        }\n    };\n    function s() {\n        return ((((o.ie() && o.windows())) && !o.JSBNG__opera()));\n    };\n;\n    function t() {\n        if (!JSBNG__navigator) {\n            return null;\n        }\n    ;\n    ;\n        JSBNG__navigator.plugins.refresh(false);\n        var v = JSBNG__navigator.mimeTypes[\"application/skypesdk-plugin\"];\n        return ((v && v.enabledPlugin));\n    };\n;\n    function u() {\n        if (!r.mightReloadPostInstall()) {\n            return;\n        }\n    ;\n    ;\n        var v = m.get(\"vcpwn\");\n        if (v) {\n            m.clear(\"vcpwn\");\n            var w = m.get(\"vctid\");\n            if (w) {\n                m.clear(\"vctid\");\n                if (m.get(\"vctid\")) {\n                    return;\n                }\n            ;\n            ;\n                if (((w && r.isInstalled()))) {\n                    var x = ((\"/ajax/chat/video/outgoing_dialog.php?idTarget=\" + w));\n                    new n().setAllowCrossPageTransition(true).setAsync(new h(x)).show();\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    };\n;\n    g.subscribe(l.getArbiterType(\"video\"), function(v, w) {\n        r.JSBNG__onVideoMessage(w.obj);\n    });\n    g.subscribe(l.getArbiterType(\"chat_event\"), function(v, w) {\n        if (((w.obj.event_name == \"missed-call\"))) {\n            k.loadModules([\"VideoCallController\",], function(x) {\n                x.JSBNG__onMissedCallEvent(w.obj);\n            });\n        }\n    ;\n    ;\n    });\n    u();\n    e.exports = r;\n});\n__d(\"ChatApp\", [\"CSS\",\"$\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"$\"), i = b(\"copyProperties\"), j = false, k = false, l = false;\n    function m(n, o) {\n        m.init(h(\"fbDockChat\"), n, o);\n    };\n;\n    i(m, {\n        init: function(n, o, p) {\n            this.root = n;\n            d([\"TabsViewport\",\"ChatTabController\",\"ChatTabViewCoordinator\",\"MercuryServerRequests\",\"MercuryChannelHandler\",\"MercuryStateCheck\",], function(q, r, s, t, u, v) {\n                t.handleUpdate(p);\n                this.tabsViewport = new q(o);\n                this.tabController = new r(this.tabsViewport);\n                this.tabViewCoordinator = new s(o, this.tabsViewport);\n                j = k = true;\n            }.bind(this));\n        },\n        hide: function() {\n            if (((!j || l))) {\n                return;\n            }\n        ;\n        ;\n            g.hide(this.root);\n            l = true;\n        },\n        unhide: function() {\n            if (j) {\n                if (l) {\n                    g.show(this.root);\n                    this.tabsViewport.checkWidth();\n                    d([\"Dock\",], function(n) {\n                        n.resizeAllFlyouts();\n                    });\n                    l = false;\n                }\n            ;\n            ;\n            }\n             else if (!k) {\n                d([\"UIPagelet\",], function(n) {\n                    n.loadFromEndpoint(\"DockChatPagelet\", \"pagelet_chat\");\n                });\n                k = true;\n            }\n            \n        ;\n        ;\n        }\n    });\n    e.exports = m;\n});\n__d(\"ChatTabModel\", [\"function-extensions\",\"Arbiter\",\"ArbiterMixin\",\"ChatBehavior\",\"ChatConfig\",\"copyProperties\",\"JSLogger\",\"MercuryAssert\",\"MercuryServerRequests\",\"MercuryThreads\",\"MercuryTimestampTracker\",\"PresenceState\",\"PresenceUtil\",\"areObjectsEqual\",\"PresenceInitialData\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"ChatBehavior\"), j = b(\"ChatConfig\"), k = b(\"copyProperties\"), l = b(\"JSLogger\"), m = b(\"MercuryAssert\"), n = b(\"MercuryServerRequests\"), o = b(\"MercuryThreads\"), p = b(\"MercuryTimestampTracker\"), q = c(\"PresenceInitialData\"), r = b(\"PresenceState\"), s = b(\"PresenceUtil\"), t = b(\"areObjectsEqual\"), u = [], v = null, w = null, x = null, y = null;\n    function z() {\n        return parseInt(q.serverTime, 10);\n    };\n;\n    var aa = ((j.get(\"tab_max_load_age\") || 3600000)), ba = ((z() - aa)), ca = 0, da = 20, ea = l.create(\"chat_tab_model\"), fa = false;\n    function ga(xa) {\n        var ya = r.verifyNumber(xa.uct2);\n        if (((!ya || ((typeof ya !== \"number\"))))) {\n            ea.warn(\"bad_cookie_version\", xa.uct2);\n            return null;\n        }\n    ;\n    ;\n        if (((((ya <= ca)) || ((ya < ba))))) {\n            return null;\n        }\n    ;\n    ;\n        return ya;\n    };\n;\n    function ha(xa) {\n        var ya = ga(xa);\n        if (!ya) {\n            var za = {\n            };\n            za.old_tabs = ((((xa && xa.t2)) && JSON.stringify(xa.t2)));\n            za.old_promoted = ((xa && xa.lm2));\n            za.old_time = ((xa && xa.uct2));\n            za.old_reason = ((xa && xa.tr));\n            za.old_window = ((xa && xa.tw));\n            var ab;\n            if (((w && xa.t2))) {\n                for (var bb = 0; ((bb < xa.t2.length)); bb++) {\n                    var cb = xa.t2[bb];\n                    if (((cb.i === w))) {\n                        ab = cb.r;\n                    }\n                ;\n                ;\n                };\n            }\n        ;\n        ;\n            var db = [];\n            u.forEach(function(eb) {\n                if (!eb.fragile) {\n                    var fb = {\n                        i: eb.id,\n                        si: eb.server_id\n                    };\n                    if (((eb.raised || ((((eb.id === w)) && ab))))) {\n                        fb.r = 1;\n                    }\n                ;\n                ;\n                    db.push(fb);\n                }\n            ;\n            ;\n            });\n            xa.t2 = db;\n            xa.uct2 = ca;\n            xa.lm2 = v;\n            xa.tr = y;\n            xa.tw = s.getSessionID();\n            za.new_tabs = JSON.stringify(xa.t2);\n            za.new_promoted = xa.lm2;\n            za.new_time = xa.uct2;\n            za.new_reason = xa.tr;\n            za.new_window = xa.tw;\n            ea.debug(\"store\", za);\n        }\n    ;\n    ;\n        return xa;\n    };\n;\n    function ia(xa) {\n        if (xa) {\n            var ya = ga(xa);\n            if (ya) {\n                var za = {\n                };\n                za.old_tabs = JSON.stringify(u);\n                za.old_promoted = v;\n                za.old_time = ca;\n                za.old_reason = y;\n                za.window_id = s.getSessionID();\n                za.cookie_tabs = ((((xa && xa.t2)) && JSON.stringify(xa.t2)));\n                za.cookie_promoted = ((xa && xa.lm2));\n                za.cookie_time = ((xa && xa.uct2));\n                za.cookie_reason = ((xa && xa.tr));\n                za.cookie_window = ((xa && xa.tw));\n                ca = ya;\n                y = \"load\";\n                var ab = ja(xa.t2, ((xa.lm2 || null)));\n                za.load_result = ab;\n                za.new_tabs = JSON.stringify(u);\n                za.new_promoted = v;\n                za.new_time = ca;\n                za.new_reason = y;\n                var JSBNG__event = \"load\";\n                if (!fa) {\n                    JSBNG__event += \"_init\";\n                }\n            ;\n            ;\n                ea.log(JSBNG__event, za);\n                return ab;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        return false;\n    };\n;\n    function ja(xa, ya) {\n        if (ka(xa, ya)) {\n            var za = u.filter(function(cb) {\n                return cb.fragile;\n            }), ab = {\n            };\n            v = null;\n            u = xa.map(function(cb) {\n                var db = {\n                    id: cb.i,\n                    server_id: cb.si\n                };\n                if (((db.id == ya))) {\n                    v = db.id;\n                }\n            ;\n            ;\n                if (((w == cb.i))) {\n                    var eb = pa(w);\n                    if (((eb != -1))) {\n                        db.raised = u[eb].raised;\n                        return db;\n                    }\n                     else return null\n                ;\n                }\n            ;\n            ;\n                if (cb.r) {\n                    db.raised = true;\n                }\n            ;\n            ;\n                ab[db.id] = db;\n                return db;\n            });\n            u = u.filter(function(cb) {\n                return ((cb != null));\n            });\n            if (x) {\n                for (var bb in x) {\n                    if (((!ab[bb] || !ab[bb].raised))) {\n                        delete x[bb];\n                    }\n                ;\n                ;\n                };\n            }\n        ;\n        ;\n            za = za.filter(function(cb) {\n                return !ab[cb.id];\n            });\n            u = u.concat(za);\n            oa();\n            return true;\n        }\n    ;\n    ;\n        return false;\n    };\n;\n    function ka(xa, ya) {\n        if (((ya != v))) {\n            return true;\n        }\n    ;\n    ;\n        var za = u.filter(function(cb) {\n            return !cb.fragile;\n        });\n        if (((xa.length != za.length))) {\n            return true;\n        }\n    ;\n    ;\n        for (var ab = 0, bb = xa.length; ((ab < bb)); ab++) {\n            if (((xa[ab].id === w))) {\n                continue;\n            }\n        ;\n        ;\n            if (!t(xa[ab], za[ab])) {\n                return true;\n            }\n        ;\n        ;\n        };\n    ;\n        return false;\n    };\n;\n    function la(xa, ya, za) {\n        var ab = ia(r.get());\n        if (((((ya === undefined)) || ((ya > ca))))) {\n            if (xa()) {\n                ab = true;\n                y = ((za || null));\n                na(ya);\n            }\n        ;\n        ;\n        }\n         else ea.error(\"rejected\", {\n            change_time: ya,\n            state_time: ca\n        });\n    ;\n    ;\n        ((ab && ma()));\n    };\n;\n    function ma() {\n        if (fa) {\n            va.inform(\"chat/tabs-changed\", va.get());\n        }\n    ;\n    ;\n    };\n;\n    function na(xa) {\n        if (((xa === undefined))) {\n            xa = Math.max(((p.getLastUserMessageTimestamp() || 1)), ((ca + 1)));\n        }\n    ;\n    ;\n        ca = xa;\n        r.doSync();\n    };\n;\n    function oa() {\n        var xa = ((u.length - da));\n        if (((xa > 0))) {\n            u = u.filter(function(ya) {\n                return ((ya.raised || ((xa-- <= 0))));\n            });\n        }\n    ;\n    ;\n    };\n;\n    function pa(xa) {\n        for (var ya = 0; ((ya < u.length)); ya++) {\n            if (((u[ya].id == xa))) {\n                return ya;\n            }\n        ;\n        ;\n        };\n    ;\n        return -1;\n    };\n;\n    function qa(xa) {\n        var ya = o.getThreadMetaNow(xa);\n        if (!ya) {\n            return false;\n        }\n    ;\n    ;\n        if (((ya.is_canonical_user || ya.is_canonical_group))) {\n            return sa(xa);\n        }\n         else {\n            var za = ra(xa);\n            if (za) {\n                n.getServerThreadID(xa, function(ab) {\n                    if (ta(xa, ab)) {\n                        na();\n                        ma();\n                    }\n                ;\n                ;\n                });\n            }\n        ;\n        ;\n            return za;\n        }\n    ;\n    ;\n    };\n;\n    function ra(xa) {\n        if (((pa(xa) === -1))) {\n            u.push({\n                id: xa,\n                fragile: true\n            });\n            ea.log(\"open_fragile_tab\", {\n                tabs: JSON.stringify(u),\n                opened: xa,\n                window_id: s.getSessionID()\n            });\n            return true;\n        }\n    ;\n    ;\n        return false;\n    };\n;\n    function sa(xa) {\n        var ya = pa(xa);\n        if (((ya != -1))) {\n            if (u[ya].fragile) {\n                u.splice(ya, 1);\n            }\n             else return false\n        ;\n        }\n    ;\n    ;\n        for (var za = 0; ((za <= u.length)); za++) {\n            if (((((za == u.length)) || u[za].fragile))) {\n                u.splice(za, 0, {\n                    id: xa\n                });\n                oa();\n                ea.log(\"open_tab\", {\n                    tabs: JSON.stringify(u),\n                    opened: xa,\n                    window_id: s.getSessionID()\n                });\n                return true;\n            }\n        ;\n        ;\n        };\n    ;\n    };\n;\n    function ta(xa, ya) {\n        var za = pa(xa);\n        if (((((za != -1)) && u[za].fragile))) {\n            var ab = u[za];\n            ab.fragile = false;\n            ab.server_id = ya;\n            var bb = [];\n            u.forEach(function(cb) {\n                if (((cb.id != xa))) {\n                    if (((ab && cb.fragile))) {\n                        bb.push(ab);\n                        ab = null;\n                    }\n                ;\n                ;\n                    bb.push(cb);\n                }\n            ;\n            ;\n            });\n            if (ab) {\n                bb.push(ab);\n            }\n        ;\n        ;\n            u = bb;\n            ea.log(\"make_permanent\", {\n                tabs: JSON.stringify(u),\n                tab_id: xa,\n                window_id: s.getSessionID()\n            });\n            return true;\n        }\n    ;\n    ;\n        return false;\n    };\n;\n    function ua(xa) {\n        var ya = pa(xa);\n        if (((xa == v))) {\n            v = null;\n        }\n    ;\n    ;\n        if (((ya != -1))) {\n            u.splice(ya, 1);\n            ea.log(\"close_tab\", {\n                tabs: JSON.stringify(u),\n                JSBNG__closed: xa,\n                window_id: s.getSessionID()\n            });\n            return true;\n        }\n    ;\n    ;\n        return false;\n    };\n;\n    r.registerStateStorer(ha);\n    r.registerStateLoader(function(xa) {\n        if (ia(xa)) {\n            ma();\n        }\n    ;\n    ;\n    });\n    function va() {\n    \n    };\n;\n    k(va, h, {\n        indexOf: function(xa) {\n            return pa(xa);\n        },\n        getTab: function(xa) {\n            m.isThreadID(xa);\n            var ya = this.indexOf(xa);\n            if (((ya > -1))) {\n                var za = u[ya];\n                return k({\n                }, za);\n            }\n        ;\n        ;\n            return null;\n        },\n        closeAllTabs: function() {\n            if (u.length) {\n                ea.log(\"close_all_tabs\", {\n                    closed_tabs: JSON.stringify(u),\n                    window_id: s.getSessionID()\n                });\n                u = [];\n                v = null;\n                if (x) {\n                    x = {\n                    };\n                }\n            ;\n            ;\n                na();\n                ma();\n            }\n        ;\n        ;\n        },\n        closeFragileTabs: function() {\n            var xa = [];\n            for (var ya = 0; ((ya < u.length)); ya++) {\n                if (u[ya].fragile) {\n                    xa.push(u[ya]);\n                    u.splice(ya);\n                    ma();\n                    break;\n                }\n            ;\n            ;\n            };\n        ;\n            ea.log(\"close_fragile_tabs\", {\n                tabs: JSON.stringify(u),\n                fragile_closed: xa,\n                window_id: s.getSessionID()\n            });\n        },\n        closeTab: function(xa, ya) {\n            m.isThreadID(xa);\n            var za = false;\n            if (x) {\n                delete x[xa];\n                za = true;\n            }\n        ;\n        ;\n            la(function() {\n                if (ua(xa)) {\n                    za = true;\n                }\n            ;\n            ;\n                return za;\n            }, undefined, ya);\n        },\n        closeTabAndDemote: function(xa, ya, za) {\n            m.isThreadID(xa);\n            var ab = false;\n            if (x) {\n                delete x[xa];\n                ab = true;\n            }\n        ;\n        ;\n            la(function() {\n                if (ua(xa)) {\n                    if (v) {\n                        var bb = pa(v);\n                        if (((bb > ya))) {\n                            var cb = u.splice(bb, 1)[0];\n                            u.splice(ya, 0, cb);\n                            v = null;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    ab = true;\n                }\n            ;\n            ;\n                return ab;\n            }, undefined, za);\n        },\n        raiseTab: function(xa, ya) {\n            m.isThreadID(xa);\n            var za = false;\n            if (((x && ya))) {\n                x[xa] = true;\n                za = true;\n            }\n        ;\n        ;\n            if (((!ya && ((xa === w))))) {\n                ((za && ma()));\n                return;\n            }\n        ;\n        ;\n            la(function() {\n                if (qa(xa)) {\n                    za = true;\n                }\n            ;\n            ;\n                var ab = pa(xa);\n                if (((((ab != -1)) && !u[ab].raised))) {\n                    u[ab].raised = true;\n                    za = true;\n                    ea.log(\"raise_tab\", {\n                        tabs: JSON.stringify(u),\n                        raised: xa,\n                        window_id: s.getSessionID()\n                    });\n                }\n            ;\n            ;\n                return za;\n            });\n        },\n        get: function() {\n            var xa = u.map(function(ya) {\n                var za = k({\n                }, ya);\n                delete za.fragile;\n                if (x) {\n                    za.raised = x[za.id];\n                }\n            ;\n            ;\n                return za;\n            });\n            return {\n                tabs: xa,\n                promoted: v\n            };\n        },\n        openFragileTab: function(xa) {\n            m.isThreadID(xa);\n            if (ra(xa)) {\n                ma();\n            }\n        ;\n        ;\n        },\n        openTab: function(xa) {\n            m.isThreadID(xa);\n            la(qa.curry(xa));\n        },\n        lowerTab: function(xa) {\n            m.isThreadID(xa);\n            var ya = false;\n            if (x) {\n                delete x[xa];\n                ya = true;\n            }\n        ;\n        ;\n            la(function() {\n                var za = pa(xa);\n                if (((((za != -1)) && u[za].raised))) {\n                    delete u[za].raised;\n                    ea.log(\"lower_tab\", {\n                        tabs: JSON.stringify(u),\n                        lowered: xa,\n                        window_id: s.getSessionID()\n                    });\n                    ya = true;\n                }\n            ;\n            ;\n                return ya;\n            });\n        },\n        raiseAndPromoteTab: function(xa, ya, za, ab) {\n            m.isThreadID(xa);\n            var bb = false;\n            if (((x && ya))) {\n                x[xa] = true;\n                bb = true;\n            }\n        ;\n        ;\n            if (((!ya && ((xa === w))))) {\n                ((bb && ma()));\n                return;\n            }\n        ;\n        ;\n            la(function() {\n                if (qa(xa)) {\n                    bb = true;\n                }\n            ;\n            ;\n                var cb = pa(xa);\n                if (((((cb != -1)) && ((!u[cb].raised || ((v != xa))))))) {\n                    u[cb].raised = true;\n                    v = xa;\n                    bb = true;\n                    ea.log(\"raise_and_promote_tab\", {\n                        tabs: JSON.stringify(u),\n                        promoted: xa,\n                        window_id: s.getSessionID()\n                    });\n                }\n            ;\n            ;\n                return bb;\n            }, za, ab);\n        },\n        squelchTab: function(xa) {\n            m.isThreadID(xa);\n            w = xa;\n            this.lowerTab(xa);\n            ea.log(\"squelch_tab\", {\n                squelched: xa,\n                tabs: JSON.stringify(u),\n                window_id: s.getSessionID()\n            });\n        },\n        clearSquelchedTab: function() {\n            if (w) {\n                ea.log(\"unsquelch_tab\", {\n                    squelched: w,\n                    tabs: JSON.stringify(u),\n                    window_id: s.getSessionID()\n                });\n            }\n        ;\n        ;\n            w = null;\n        }\n    });\n    g.subscribe(l.DUMP_EVENT, function(xa, ya) {\n        ya.chat_tabs = {\n            promoted: v,\n            tabs: u.map(function(za) {\n                return k({\n                }, za);\n            }),\n            time: ca,\n            max_load_age: aa\n        };\n    });\n    function wa() {\n        var xa = i.ignoresRemoteTabRaise();\n        if (((xa && !x))) {\n            ea.log(\"start_ignore_remote_raise\");\n            x = {\n            };\n            ma();\n        }\n         else if (((!xa && x))) {\n            ea.log(\"stop_ignore_remote_raise\");\n            x = null;\n            ma();\n        }\n        \n    ;\n    ;\n    };\n;\n    i.subscribe(i.ON_CHANGED, wa);\n    wa();\n    ia(r.getInitial(), true);\n    if (((ca === 0))) {\n        ca = ((z() - 600000));\n    }\n;\n;\n    fa = true;\n    e.exports = va;\n});\n__d(\"VideoCallPromo\", [\"ArbiterMixin\",\"AsyncRequest\",\"AvailableList\",\"AvailableListConstants\",\"ChatConfig\",\"ChatVisibility\",\"ContextualDialogX\",\"copyProperties\",\"CSS\",\"MercuryThreads\",\"MercuryParticipants\",\"VideoCallCore\",\"ChatTabTemplates\",], function(a, b, c, d, e, f) {\n    var g = b(\"ArbiterMixin\"), h = b(\"AsyncRequest\"), i = b(\"AvailableList\"), j = b(\"AvailableListConstants\"), k = b(\"ChatConfig\"), l = b(\"ChatVisibility\"), m = b(\"ContextualDialogX\"), n = b(\"copyProperties\"), o = b(\"CSS\"), p = b(\"MercuryThreads\"), q = b(\"MercuryParticipants\"), r = c(\"ChatTabTemplates\"), s = b(\"VideoCallCore\");\n    function t() {\n        this._dialog = null;\n    };\n;\n    function u(w) {\n        if (!((s.isSupported() && k.get(\"video.show_promo\")))) {\n            return false;\n        }\n    ;\n    ;\n        var x = p.getCanonicalUserInThread(w);\n        if (!x) {\n            return false;\n        }\n    ;\n    ;\n        return ((l.isOnline() && s.availableForCall(x)));\n    };\n;\n    function v(w) {\n        new h().setURI(\"/ajax/chat/video/log_promo.php\").setData({\n            viewedUserID: w\n        }).setAllowCrossPageTransition(true).setErrorHandler(bagofholding).send();\n    };\n;\n    n(t.prototype, g);\n    n(t.prototype, {\n        render: function(w, x) {\n            var y = u(x);\n            if (!y) {\n                return;\n            }\n        ;\n        ;\n            var z = p.getCanonicalUserInThread(x);\n            q.get(((\"fbid:\" + z)), function(aa) {\n                if (!aa.call_promo) {\n                    return;\n                }\n            ;\n            ;\n                var ba = r[\":fb:mercury:call:promo\"].build();\n                this._dialog = new m();\n                this._dialog.init(ba.getRoot()).setWidth(250).setAlignH(\"center\").setContext(w).show();\n                o.addClass(this._dialog.getRoot(), \"uiContextualDialogWithFooterArrowBottom\");\n                o.addClass(w, \"video_call_promo\");\n                v(p.getCanonicalUserInThread(x));\n                this.inform(\"chat/dialog-rendered\", {\n                    dialog: this,\n                    thread_id: x\n                });\n            }.bind(this));\n        },\n        updatePosition: function() {\n            if (((this._dialog && this._dialog.isShown()))) {\n                this._dialog.updatePosition();\n            }\n        ;\n        ;\n        },\n        hide: function() {\n            if (((this._dialog && this._dialog.isShown()))) {\n                this._dialog.hide();\n                this._dialog = null;\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = t;\n});\n__d(\"VideoCallTourDialog\", [\"ArbiterMixin\",\"ContextualDialogX\",\"copyProperties\",\"CSS\",\"MercuryThreads\",\"VideoCallCore\",\"VideoCallingTour\",\"ChatTabTemplates\",], function(a, b, c, d, e, f) {\n    var g = b(\"ArbiterMixin\"), h = b(\"ContextualDialogX\"), i = b(\"copyProperties\"), j = b(\"CSS\"), k = b(\"MercuryThreads\"), l = c(\"ChatTabTemplates\"), m = b(\"VideoCallCore\"), n = b(\"VideoCallingTour\");\n    function o() {\n        this._dialog = null;\n    };\n;\n    i(o.prototype, g);\n    i(o.prototype, {\n        render: function(p, q) {\n            var r = k.getCanonicalUserInThread(q);\n            if (((!r || !m.availableForCall(r)))) {\n                return;\n            }\n        ;\n        ;\n            var s = l[\":fb:mercury:call:tour\"].build();\n            this._dialog = new h();\n            this._dialog.init(s.getRoot()).setWidth(250).setAlignH(\"center\").setContext(p).show();\n            j.addClass(this._dialog.getRoot(), \"uiContextualDialogWithFooterArrowBottom\");\n            j.addClass(p, \"video_call_tour\");\n            this.inform(\"chat/dialog-rendered\", {\n                dialog: this,\n                thread_id: q\n            });\n            n.inform(\"videocallingtour/end\");\n        },\n        updatePosition: function() {\n            if (((this._dialog && this._dialog.isShown()))) {\n                this._dialog.updatePosition();\n            }\n        ;\n        ;\n        },\n        hide: function() {\n            if (((this._dialog && this._dialog.isShown()))) {\n                this._dialog.hide();\n                this._dialog = null;\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = o;\n});\n__d(\"ChatContextualDialogController\", [\"event-extensions\",\"ArbiterMixin\",\"ChatTabModel\",\"VideoCallingTour\",\"VideoCallPromo\",\"VideoCallTourDialog\",\"copyProperties\",\"setTimeoutAcrossTransitions\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"ChatTabModel\"), i = b(\"VideoCallingTour\"), j = b(\"VideoCallPromo\"), k = b(\"VideoCallTourDialog\"), l = b(\"copyProperties\"), m = b(\"setTimeoutAcrossTransitions\"), n = 60000, o = false, p = false, q = function(x, y) {\n        this._videoCallPromo = new j();\n        this._videoCallTour = new k();\n        this._threadID = x;\n        this._tabMainElement = y;\n        this._openDialog = null;\n        this._subscriptionTokens = [];\n        this._scrollListener = null;\n        this._timeout = null;\n    };\n    function r(x, JSBNG__event, y) {\n        if (x._openDialog) {\n            x._openDialog.updatePosition();\n        }\n    ;\n    ;\n    };\n;\n    function s(x) {\n        if (x._openDialog) {\n            x._openDialog.updatePosition();\n        }\n    ;\n    ;\n    };\n;\n    function t(x) {\n        if (x._openDialog) {\n            x._openDialog.hide();\n            x._openDialog = null;\n        }\n    ;\n    ;\n        if (x._timeout) {\n            JSBNG__clearTimeout(x._timeout);\n            x._timeout = null;\n        }\n    ;\n    ;\n        while (x._subscriptionTokens.length) {\n            x._subscriptionTokens.pop().unsubscribe();\n        ;\n        };\n    ;\n        if (x._scrollListener) {\n            x._scrollListener.remove();\n            x._scrollListener = null;\n        }\n    ;\n    ;\n    };\n;\n    function u(x, JSBNG__event, y) {\n        if (((y.thread_id === x._threadID))) {\n            x._openDialog = y.dialog;\n            o = true;\n            w(x);\n            x._timeout = m(x.destroy.bind(x, x._threadID), n);\n            x._scrollListener = JSBNG__Event.listen(window, \"JSBNG__scroll\", s.curry(x));\n        }\n    ;\n    ;\n    };\n;\n    function v(x, y) {\n        if (!x._openDialog) {\n            x._subscriptionTokens.push(y.subscribe(\"chat/dialog-rendered\", u.curry(x)));\n            y.render(x._tabMainElement, x._threadID);\n        }\n    ;\n    ;\n    };\n;\n    function w(x) {\n        x._subscriptionTokens.push(h.subscribe(\"chat/tabs-changed\", r.curry(x)), q.subscribe(\"dialog/close-all\", t.curry(x)));\n    };\n;\n    l(q, g);\n    l(q.prototype, {\n        destroy: function() {\n            t(this);\n        },\n        tabFocused: function() {\n            if (p) {\n                v(this, this._videoCallTour);\n                return;\n            }\n        ;\n        ;\n            if (!o) {\n                v(this, this._videoCallPromo);\n            }\n        ;\n        ;\n        },\n        tabNotActive: function() {\n            t(this);\n        },\n        hideVideoCallouts: function() {\n            t(this);\n        }\n    });\n    i.subscribe(\"videocallingtour/start\", function() {\n        p = true;\n        q.inform(\"dialog/close-all\");\n    });\n    i.subscribe(\"videocallingtour/end\", function() {\n        p = false;\n    });\n    e.exports = q;\n});\n__d(\"ChatPrivacyActionController\", [\"Arbiter\",\"ChatVisibility\",\"JSLogger\",\"PresencePrivacy\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ChatVisibility\"), i = b(\"JSLogger\"), j = b(\"PresencePrivacy\"), k = b(\"copyProperties\"), l = function(m, n) {\n        this._userID = m;\n        this._logger = i.create(\"blackbird\");\n        this._getState = function() {\n            if (h.isOnline()) {\n                return ((j.allows(this._userID) ? l.NORMAL : l.BLOCKED));\n            }\n        ;\n        ;\n            return l.OFFLINE;\n        };\n        this._togglePrivacy = function() {\n            var o = this._getState();\n            switch (this._getState()) {\n              case l.OFFLINE:\n                if (h.isOnline()) {\n                    this._logger.error(\"tabs_already_online\");\n                    break;\n                }\n            ;\n            ;\n                this._logger.log(\"tabs_go_online\", {\n                    tab_id: this._userID\n                });\n                h.goOnline(function() {\n                    if (!j.allows(this._userID)) {\n                        if (((this._getState() !== l.BLOCKED))) {\n                            this._logger.error(\"privacy_action_controller_blocked_inconsistency\");\n                        }\n                    ;\n                    ;\n                        this._togglePrivacy();\n                    }\n                ;\n                ;\n                }.bind(this));\n                break;\n              case l.BLOCKED:\n                j.allow(this._userID);\n                this._logger.log(\"tabs_unblock\", {\n                    tab_id: this._userID\n                });\n                break;\n              case l.NORMAL:\n                j.disallow(this._userID);\n                this._logger.log(\"tabs_block\", {\n                    tab_id: this._userID\n                });\n                break;\n            };\n        ;\n        };\n        (function() {\n            var o = function() {\n                ((n && n(this._getState())));\n            }.bind(this);\n            o();\n            this._subscribeToken = j.subscribe(\"privacy-changed\", o);\n        }.bind(this)).defer();\n    };\n    l.OFFLINE = \"offline\";\n    l.BLOCKED = \"blocked\";\n    l.NORMAL = \"normal\";\n    k(l.prototype, {\n        togglePrivacy: function() {\n            this._logger.log(\"gear_menu_toggle_privacy\", {\n                tab_id: this._userID\n            });\n            this._togglePrivacy();\n        },\n        destroy: function() {\n            j.unsubscribe(this._subscribeToken);\n        }\n    });\n    e.exports = l;\n});\n__d(\"MessagesEmoticonView\", [\"event-extensions\",\"function-extensions\",\"DOM\",\"InputSelection\",\"Parent\",\"TextAreaControl\",\"Toggler\",\"copyProperties\",\"endsWith\",\"startsWith\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"DOM\"), h = b(\"InputSelection\"), i = b(\"Parent\"), j = b(\"TextAreaControl\"), k = b(\"Toggler\"), l = b(\"copyProperties\"), m = b(\"endsWith\"), n = b(\"startsWith\"), o = {\n        smile: \":)\",\n        frown: \":(\",\n        tongue: \":P\",\n        grin: \"=D\",\n        gasp: \":o\",\n        wink: \";)\",\n        glasses: \"8)\",\n        sunglasses: \"B|\",\n        grumpy: \"\\u003E:(\",\n        unsure: \":/\",\n        cry: \":'(\",\n        devil: \"3:)\",\n        angel: \"O:)\",\n        kiss: \":*\",\n        heart: \"\\u003C3\",\n        kiki: \"^_^\",\n        squint: \"-_-\",\n        confused: \"o.O\",\n        upset: \"\\u003E:o\",\n        pacman: \":v\",\n        robot: \":|]\",\n        colonthree: \":3\",\n        penguin: \"\\u003C(\\\")\",\n        putnam: \":putnam:\",\n        shark: \"(^^^)\",\n        42: \":42:\",\n        like: \"(y)\"\n    };\n    function p(r, s, t) {\n        var u = i.byClass(r, \"emoteIcon\");\n        if (!u) {\n            return;\n        }\n    ;\n    ;\n        var v = \"name_\", w = null;\n        u.className.split(\" \").forEach(function(da) {\n            if (n(da, v)) {\n                w = da.substring(v.length);\n            }\n        ;\n        ;\n        });\n        if (!o[w]) {\n            return;\n        }\n    ;\n    ;\n        var x = j.getInstance(s), y = x.getValue(), z = o[w], aa = y.substring(0, t.start), ba = y.substring(t.end);\n        if (((((t.start > 0)) && !m(aa, \" \")))) {\n            z = ((\" \" + z));\n        }\n    ;\n    ;\n        if (!n(ba, \" \")) {\n            z += \" \";\n        }\n    ;\n    ;\n        var ca = ((((aa + z)) + ba));\n        t.start += z.length;\n        t.end = t.start;\n        x.setValue(ca);\n        h.set(s, t.start, t.end);\n    };\n;\n    function q(r, s) {\n        var t = {\n            start: 0,\n            end: 0\n        };\n        function u() {\n            t = h.get(s);\n        };\n    ;\n        var v = g.JSBNG__find(r, \".uiToggleFlyout\");\n        this._subscription = k.subscribe(\"show\", function(w, x) {\n            if (((x.active && g.contains(r, x.active)))) {\n                h.set(s, t.start, t.end);\n            }\n        ;\n        ;\n        });\n        this._eventListeners = [JSBNG__Event.listen(v, \"click\", function(JSBNG__event) {\n            k.hide(r);\n            p(JSBNG__event.getTarget(), s, t);\n        }),JSBNG__Event.listen(s, \"keyup\", u),JSBNG__Event.listen(s, \"click\", u),];\n    };\n;\n    l(q.prototype, {\n        destroy: function() {\n            this._subscription.unsubscribe();\n            while (this._eventListeners.length) {\n                this._eventListeners.pop().remove();\n            ;\n            };\n        ;\n        }\n    });\n    e.exports = q;\n});\n__d(\"MercuryAttachmentRenderer\", [\"CSS\",\"DOM\",\"MercuryAttachment\",\"Style\",\"tx\",\"URI\",\"MercuryAttachmentTemplates\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"MercuryAttachment\"), j = b(\"Style\"), k = b(\"tx\"), l = b(\"URI\"), m = c(\"MercuryAttachmentTemplates\"), n = c(\"MercuryConstants\");\n    function o(q, r) {\n        var s = m[r].build().setNodeContent(\"filename\", q.JSBNG__name), t = s.getNode(\"link\");\n        t.setAttribute(\"href\", q.url);\n        ((q.rel && t.setAttribute(\"rel\", q.rel)));\n        g.addClass(s.getRoot(), i.getAttachIconClass(q.icon_type));\n        return s;\n    };\n;\n    var p = {\n        renderError: function(q) {\n            var r = m[\":fb:mercury:attachment:error\"].build();\n            h.appendContent(r.getNode(\"error\"), q.error_msg);\n            return r.getRoot();\n        },\n        renderExternalLink: function(q) {\n            var r = m[\":fb:mercury:attachment:external-link\"].build().setNodeContent(\"JSBNG__name\", q.JSBNG__name).setNodeContent(\"shortLink\", q.base_url), s = r.getNode(\"preview\");\n            s.setAttribute(\"href\", q.url);\n            ((q.rel && s.setAttribute(\"rel\", q.rel)));\n            if (q.preview_url) {\n                var t = r.getNode(\"preview-image\");\n                t.setAttribute(\"src\", q.preview_url);\n                g.addClass(s, q.preview_class);\n                g.show(t);\n            }\n             else {\n                g.addClass(r.getRoot(), \"noMedia\");\n                g.hide(s);\n            }\n        ;\n        ;\n            r.getNode(\"JSBNG__name\").setAttribute(\"href\", q.url);\n            return r.getRoot();\n        },\n        renderFileLink: function(q) {\n            var r = \":fb:mercury:attachment:file-link\", s = o(q, r);\n            return s.getRoot();\n        },\n        renderExtendedFileLink: function(q) {\n            var r = \":fb:mercury:attachment:extended-file-link\", s = o(q, r);\n            if (q.open_url) {\n                var t = s.getNode(\"openLinkContainer\");\n                g.show(t);\n                var u = s.getNode(\"openFile\");\n                u.setAttribute(\"href\", q.open_url);\n            }\n        ;\n        ;\n            var v = s.getNode(\"downloadFile\");\n            v.setAttribute(\"href\", q.url);\n            ((q.rel && v.setAttribute(\"rel\", q.rel)));\n            return s.getRoot();\n        },\n        renderMusic: function(q) {\n            var r = m[\":fb:mercury:attachment:music\"].build().setNodeContent(\"filename\", q.JSBNG__name), s = r.getNode(\"link\");\n            s.setAttribute(\"href\", q.url);\n            s.setAttribute(\"target\", \"_blank\");\n            ((q.rel && s.setAttribute(\"rel\", q.rel)));\n            var t = r.getNode(\"preview\");\n            t.setAttribute(\"href\", q.url);\n            ((q.rel && t.setAttribute(\"rel\", q.rel)));\n            var u = r.getNode(\"preview-image\");\n            u.setAttribute(\"src\", q.preview_url);\n            g.show(u);\n            g.addClass(r.getNode(\"icon_link\"), \"MercuryMusicIcon\");\n            return r.getRoot();\n        },\n        renderPreview: function(q, r, s, t, u, v) {\n            var w = m[\":fb:mercury:attachment:preview\"].build(), x = w.getNode(\"image-link\"), y = \"\";\n            if (q) {\n                x.setAttribute(\"href\", q.url);\n                ((q.rel && x.setAttribute(\"rel\", q.rel)));\n                y = q.preview_url;\n                if (((s && ((l(y).getPath() == \"/ajax/messaging/attachment.php\"))))) {\n                    y += s;\n                }\n            ;\n            ;\n                if (((((((q.is_social_report_attachment && t)) && v)) && u))) {\n                    var z = h.create(\"a\", {\n                        rel: \"dialog-post\",\n                        className: \"SocialReportLink\",\n                        id: \"respond-link\",\n                        ajaxify: l(\"/ajax/report/social_resolution/photo/\").setQueryData({\n                            attachment_fbid: q.attach_id,\n                            photo_fbid: q.shared_object_id,\n                            sender_id: v\n                        }).toString()\n                    });\n                    h.setContent(z, k._(\"Respond to {name}'s request\", {\n                        JSBNG__name: u.JSBNG__name\n                    }));\n                    h.appendContent(w.getRoot(), z);\n                }\n            ;\n            ;\n                g.addClass(x, q.preview_class);\n            }\n             else {\n                y = \"/images/blank.gif\";\n                g.addClass(x, \"imagePreview\");\n                g.addClass(x, \"thumbnail\");\n            }\n        ;\n        ;\n            var aa = w.getNode(\"preview-image\");\n            if (!r) {\n                g.show(aa);\n                if (!q) {\n                    j.set(aa, \"height\", \"194px\");\n                    j.set(aa, \"width\", \"194px\");\n                }\n            ;\n            ;\n            }\n             else aa.JSBNG__onload = function() {\n                var ba = aa.width, ca = aa.height, da, ea;\n                if (((ba > ca))) {\n                    j.set(aa, \"maxHeight\", ((r + \"px\")));\n                    ea = Math.min(ca, r);\n                    da = Math.ceil(((((ba * ea)) / ca)));\n                }\n                 else {\n                    j.set(aa, \"maxWidth\", ((r + \"px\")));\n                    da = Math.min(ba, r);\n                    ea = Math.ceil(((((ca * da)) / ba)));\n                }\n            ;\n            ;\n                j.set(aa, \"marginTop\", ((((\"-\" + ((ea >>> 1)))) + \"px\")));\n                j.set(aa, \"marginLeft\", ((((\"-\" + ((da >>> 1)))) + \"px\")));\n                g.show(aa);\n            };\n        ;\n        ;\n            aa.setAttribute(\"src\", y);\n            return w.getRoot();\n        },\n        renderMultiplePreviews: function(q) {\n            return this._renderMultiplePreviews(q, q.length);\n        },\n        renderMultipleThumbnails: function(q) {\n            return this._renderMultiplePreviews(null, q);\n        },\n        renderShareLink: function(q) {\n            var r = m[\":fb:mercury:attachment:share-link\"].build().setNodeContent(\"JSBNG__name\", q.JSBNG__name), s = r.getNode(\"link\");\n            s.setAttribute(\"href\", q.url);\n            ((q.rel && s.setAttribute(\"rel\", q.rel)));\n            return r.getRoot();\n        },\n        renderVideoThumb: function(q) {\n            var r = m[\":fb:mercury:attachment:video-thumb\"].build(), s = r.getNode(\"thumb\");\n            s.setAttribute(\"href\", q.url);\n            s.setAttribute(\"rel\", q.rel);\n            var t = h.JSBNG__find(r.getRoot(), \"img\");\n            t.src = q.preview_url;\n            return r.getRoot();\n        },\n        _renderMultiplePreviews: function(q, r) {\n            var s = \"singleImagePreview\", t = 0;\n            if (((((r == 2)) || ((r == 4))))) {\n                s = \"doubleImagePreview\";\n                t = 194;\n            }\n             else if (((r > 1))) {\n                s = \"multipleImagePreview\";\n                t = 129;\n            }\n            \n        ;\n        ;\n            var u = h.create(\"div\", {\n                className: \"imagePreviews\"\n            });\n            g.addClass(u, s);\n            if (q) {\n                var v = ((\"&numPreviews=\" + r));\n                for (var w = 0; ((w < r)); ++w) {\n                    var x = this.renderPreview(q[w], t, v);\n                    h.appendContent(u, x);\n                };\n            ;\n            }\n             else for (w = 0; ((w < r)); ++w) {\n                x = this.renderPreview(null, t);\n                h.appendContent(u, x);\n            }\n        ;\n        ;\n            return u;\n        }\n    };\n    e.exports = p;\n});\n__d(\"MercuryRoger\", [\"ArbiterMixin\",\"MercuryServerRequests\",\"LiveTimer\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"ArbiterMixin\"), h = b(\"MercuryServerRequests\"), i = b(\"LiveTimer\"), j = b(\"copyProperties\"), k = {\n    }, l = {\n        getSeenBy: function(m) {\n            if (!m) {\n                return [];\n            }\n        ;\n        ;\n            var n = [], o = k[m.thread_id];\n            for (var p in o) {\n                if (((((o[p] > m.timestamp)) && ((p != m.author))))) {\n                    n.push(p);\n                }\n            ;\n            ;\n            };\n        ;\n            return n;\n        },\n        getSeenTimestamp: function(m, n) {\n            var o = k[m];\n            return ((o ? o[n] : null));\n        }\n    };\n    j(l, g);\n    h.subscribe(\"update-roger\", function(m, n) {\n        for (var o in n) {\n            if (!k[o]) {\n                k[o] = {\n                };\n            }\n        ;\n        ;\n            for (var p in n[o]) {\n                var q = k[o][p], r = n[o][p];\n                if (((!q || ((r > q))))) {\n                    k[o][p] = r;\n                }\n            ;\n            ;\n            };\n        ;\n        };\n    ;\n        if (n) {\n            l.inform(\"state-changed\", n);\n        }\n    ;\n    ;\n    });\n    e.exports = l;\n});\n__d(\"MercuryTypingReceiver\", [\"Arbiter\",\"ChannelConstants\",\"MercuryParticipants\",\"MercuryServerRequests\",\"MercuryThreads\",\"TypingDetector\",\"setTimeoutAcrossTransitions\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ChannelConstants\"), i = b(\"MercuryParticipants\"), j = b(\"MercuryServerRequests\"), k = b(\"MercuryThreads\"), l = b(\"TypingDetector\"), m = b(\"setTimeoutAcrossTransitions\"), n = c(\"MercuryConstants\"), o, p = {\n    }, q = 30000, r = new g();\n    function s(x) {\n        var y = ((p[x] || {\n        })), z = Object.keys(y);\n        z.sort(function(aa, ba) {\n            return ((y[aa] - y[ba]));\n        });\n        return z;\n    };\n;\n    function t() {\n        o = null;\n        var x = JSBNG__Date.now(), y = {\n        }, z = false;\n        for (var aa in p) {\n            var ba = false;\n            for (var ca in ((p[aa] || {\n            }))) {\n                if (((p[aa][ca] < ((x - q))))) {\n                    delete p[aa][ca];\n                    ba = true;\n                }\n                 else z = true;\n            ;\n            ;\n            };\n        ;\n            if (ba) {\n                y[aa] = s(aa);\n            }\n        ;\n        ;\n        };\n    ;\n        for (var da in y) {\n            r.inform(\"state-changed\", y);\n            break;\n        };\n    ;\n        if (z) {\n            o = m(t, 3000);\n        }\n    ;\n    ;\n    };\n;\n    function u(x, y) {\n        if (((x in p))) {\n            if (((y in p[x]))) {\n                delete p[x][y];\n                v(x);\n            }\n        ;\n        }\n    ;\n    ;\n    };\n;\n    function v(x) {\n        var y = {\n        };\n        y[x] = s(x);\n        r.inform(\"state-changed\", y);\n    };\n;\n    function w(x) {\n        if (x.thread) {\n            return j.getClientThreadIDNow(x.thread);\n        }\n    ;\n    ;\n        if (((x.type === \"typ\"))) {\n            return k.getThreadIdForUser(x.from);\n        }\n    ;\n    ;\n        return null;\n    };\n;\n    g.subscribe([h.getArbiterType(\"typ\"),h.getArbiterType(\"ttyp\"),], function(x, y) {\n        var z = y.obj, aa = w(z);\n        if (aa) {\n            var ba = i.getIDForUser(z.from);\n            if (((z.st == l.TYPING))) {\n                p[aa] = ((p[aa] || {\n                }));\n                var ca = p[aa][ba];\n                p[aa][ba] = JSBNG__Date.now();\n                if (!o) {\n                    o = m(t, 3000);\n                }\n            ;\n            ;\n                ((!ca && v(aa)));\n            }\n             else if (((z.st == l.INACTIVE))) {\n                u(aa, ba);\n            }\n            \n        ;\n        ;\n        }\n    ;\n    ;\n    });\n    j.subscribe(\"update-typing-state\", function(x, y) {\n        var z = y.payload_source;\n        if (((z != n.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE))) {\n            return;\n        }\n    ;\n    ;\n        var aa = y.actions;\n        if (((!aa || !aa.length))) {\n            return;\n        }\n    ;\n    ;\n        var ba = n.MercuryActionType.USER_GENERATED_MESSAGE;\n        aa.forEach(function(ca) {\n            if (((((ca.action_type == ba)) && ((ca.author != i.user))))) {\n                u(ca.thread_id, ca.author);\n            }\n        ;\n        ;\n        });\n    });\n    e.exports = r;\n});\n__d(\"ChatTabIndicatorController\", [\"ArbiterMixin\",\"ChatConfig\",\"DOM\",\"LiveTimer\",\"MercuryParticipants\",\"MercuryRoger\",\"MercuryThreads\",\"MercuryTypingReceiver\",\"copyProperties\",\"setTimeoutAcrossTransitions\",\"tx\",\"date-extensions\",\"MercuryConfig\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"ArbiterMixin\"), h = b(\"ChatConfig\"), i = b(\"DOM\"), j = b(\"LiveTimer\"), k = b(\"MercuryParticipants\"), l = b(\"MercuryRoger\"), m = b(\"MercuryThreads\"), n = b(\"MercuryTypingReceiver\"), o = b(\"copyProperties\"), p = b(\"setTimeoutAcrossTransitions\"), q = b(\"tx\");\n    b(\"date-extensions\");\n    var r = c(\"MercuryConfig\"), s = c(\"MercuryConstants\"), t = r[\"roger.seen_delay\"], u = [];\n    function v(w) {\n        this._threadID = w;\n        this._canonicalUser = m.getCanonicalUserInThread(w);\n        u.push(this);\n    };\n;\n    o(v.prototype, g, {\n        destroy: function() {\n            u.remove(this);\n        },\n        setLastMessage: function(w) {\n            this._lastMsg = w;\n            if (this._stateChangeTimeout) {\n                JSBNG__clearTimeout(this._stateChangeTimeout);\n                this._stateChangeTimeout = null;\n            }\n        ;\n        ;\n            if (w) {\n                var x = t, y = s.MercuryActionStatus.SUCCESS;\n                if (((w.action_id || ((w.JSBNG__status == y))))) {\n                    var z = j.getApproximateServerTime();\n                    x = ((((w.timestamp + t)) - z));\n                }\n            ;\n            ;\n                if (((x > 0))) {\n                    this._stateChangeTimeout = p(function() {\n                        this._stateChangeTimeout = null;\n                        this._handleStateChange();\n                    }.bind(this), x);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            this._handleStateChange();\n        },\n        _informStateChanged: function(w) {\n            if (((((w.activity == \"none\")) && ((this._currentActivity == \"none\"))))) {\n                return;\n            }\n        ;\n        ;\n            this._currentActivity = w.activity;\n            this.inform(\"state-changed\", w);\n        },\n        _notifySentFrom: function() {\n            var w = s.MercurySourceType, x, y, z = this._lastMsg.location_text;\n            if (z) {\n                x = q._(\"Sent from {location}\", {\n                    JSBNG__location: z\n                });\n                y = \"sentFromMobile\";\n            }\n             else switch (this._lastMsg.source) {\n              case w.CHAT_ORCA:\n            \n              case w.TITAN_ORCA:\n                x = i.create(\"a\", {\n                    href: \"/mobile/messenger\",\n                    class: \"fcg\",\n                    target: \"_blank\"\n                }, \"Sent from Messenger\");\n                y = \"sentFromMobile\";\n                break;\n              case w.MOBILE:\n            \n              case w.CHAT_IPHONE:\n            \n              case w.TITAN_API_MOBILE:\n            \n              case w.TITAN_WAP:\n                x = i.create(\"a\", {\n                    href: \"/mobile\",\n                    class: \"fcg\",\n                    target: \"_blank\"\n                }, \"Sent from Mobile\");\n                y = \"sentFromMobile\";\n                break;\n              case w.EMAIL:\n            \n              case w.TITAN_EMAIL_REPLY:\n                x = \"Sent from Email\";\n                y = \"sentFromEmail\";\n                break;\n              default:\n                this._informStateChanged({\n                    activity: \"none\"\n                });\n                return;\n            }\n        ;\n        ;\n            this._informStateChanged({\n                activity: y,\n                text: x\n            });\n        },\n        _notifySeenTimestamp: function(w) {\n            var x = ((l.getSeenTimestamp(this._threadID, w[0]) * 175256)), y = ((JSBNG__Date.now() * 175274)), z = ((r[\"24h_times\"] ? \"H:i\" : \"g:i A\"));\n            if (((x < ((y - 518400))))) {\n                z = \"M j\";\n            }\n             else if (((x < ((y - 86400))))) {\n                z = ((\"D \" + z));\n            }\n            \n        ;\n        ;\n            var aa = JSBNG__Date.format(z, x);\n            this._informStateChanged({\n                activity: \"seen-timestamp\",\n                text: q._(\"Seen {timestamp}\", {\n                    timestamp: aa\n                })\n            });\n        },\n        _notifySeenBy: function(w) {\n            var x = this._lastMsg, y = true;\n            k.getMulti(w, function(z) {\n                y = false;\n                if (((this._lastMsg != x))) {\n                    return;\n                }\n            ;\n            ;\n                var aa = m.getThreadMetaNow(this._threadID), ba = ((aa ? aa.participants.length : 0)), ca = ((w.length + ((x.author != k.user)))), da, ea = false;\n                if (((((ba > 2)) && ((ca >= ((ba - 1))))))) {\n                    da = \"Seen by Everyone\";\n                }\n                 else if (((w.length == 1))) {\n                    da = q._(\"Seen by {user}\", {\n                        user: z[w[0]].short_name\n                    });\n                }\n                 else if (((w.length == 2))) {\n                    da = q._(\"Seen by {user1}, {user2}\", {\n                        user1: z[w[0]].short_name,\n                        user2: z[w[1]].short_name\n                    });\n                }\n                 else if (((w.length == 3))) {\n                    da = q._(\"Seen by {user1}, {user2}, {user3}\", {\n                        user1: z[w[0]].short_name,\n                        user2: z[w[1]].short_name,\n                        user3: z[w[2]].short_name\n                    });\n                }\n                 else if (((w.length > 3))) {\n                    var fa = ((Object.keys(z).length - 2)), ga = q._(\"{num} more\", {\n                        num: fa\n                    }), ha = i.create(\"span\", {\n                        className: \"more\"\n                    }, ga);\n                    da = i.tx._(\"Seen by {user1}, {user2}, {=num more link}\", {\n                        user1: z[w[0]].short_name,\n                        user2: z[w[1]].short_name,\n                        \"=num more link\": ha\n                    });\n                    ea = true;\n                }\n                \n                \n                \n                \n            ;\n            ;\n                this._informStateChanged({\n                    activity: \"seen-by\",\n                    text: da,\n                    seenBy: w,\n                    tooltip: ea\n                });\n            }.bind(this));\n            ((y && this._informStateChanged({\n                activity: \"none\"\n            })));\n        },\n        _notifyTyping: function(w) {\n            var x = this._lastMsg, y = true;\n            k.getMulti(w, function(z) {\n                y = false;\n                if (((this._lastMsg != x))) {\n                    return;\n                }\n            ;\n            ;\n                if (((this._canonicalUser || h.get(\"chat_multi_typ\")))) {\n                    var aa = m.getThreadMetaNow(this._threadID), ba = ((aa ? aa.participants.length : 0)), ca, da = false;\n                    if (((((ba > 2)) && ((w.length >= ((ba - 1))))))) {\n                        ca = \"Everyone is typing...\";\n                    }\n                     else if (((w.length == 1))) {\n                        ca = q._(\"{name} is typing...\", {\n                            JSBNG__name: z[w[0]].short_name\n                        });\n                    }\n                     else if (((w.length == 2))) {\n                        ca = q._(\"{user1} and {user2} are typing...\", {\n                            user1: z[w[0]].short_name,\n                            user2: z[w[1]].short_name\n                        });\n                    }\n                     else if (((w.length == 3))) {\n                        ca = q._(\"{user1}, {user2}, and {user3} are typing...\", {\n                            user1: z[w[0]].short_name,\n                            user2: z[w[1]].short_name,\n                            user3: z[w[2]].short_name\n                        });\n                    }\n                     else if (((w.length > 3))) {\n                        var ea = ((Object.keys(z).length - 2)), fa = q._(\"{num} more\", {\n                            num: ea\n                        }), ga = i.create(\"a\", {\n                            href: \"#\"\n                        }, fa);\n                        ca = i.tx._(\"{user1}, {user2}, and {=num more link} are typing...\", {\n                            user1: z[w[0]].short_name,\n                            user2: z[w[1]].short_name,\n                            \"=num more link\": ga\n                        });\n                        da = true;\n                    }\n                    \n                    \n                    \n                    \n                ;\n                ;\n                    this._informStateChanged({\n                        activity: \"typing\",\n                        text: ca,\n                        typing: w,\n                        tooltip: da\n                    });\n                }\n            ;\n            ;\n            }.bind(this));\n            ((y && this._informStateChanged({\n                activity: \"none\"\n            })));\n        },\n        _handleStateChange: function() {\n            var w = s.MercuryActionType.LOG_MESSAGE;\n            if (((!this._lastMsg || ((this._lastMsg.action_type == w))))) {\n                this._informStateChanged({\n                    activity: \"none\"\n                });\n                return;\n            }\n        ;\n        ;\n            if (((this._typing && this._typing.length))) {\n                this._notifyTyping(this._typing);\n                return;\n            }\n        ;\n        ;\n            if (((this._canonicalUser && ((this._lastMsg.author != k.user))))) {\n                this._notifySentFrom();\n                return;\n            }\n        ;\n        ;\n            if (!this._stateChangeTimeout) {\n                var x = l.getSeenBy(this._lastMsg);\n                if (x.length) {\n                    if (this._canonicalUser) {\n                        this._notifySeenTimestamp(x);\n                        return;\n                    }\n                     else {\n                        this._notifySeenBy(x);\n                        return;\n                    }\n                ;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            this._informStateChanged({\n                activity: \"none\"\n            });\n        }\n    });\n    n.subscribe(\"state-changed\", function(w, x) {\n        u.forEach(function(y) {\n            var z = x[y._threadID];\n            if (((z !== undefined))) {\n                y._typing = z;\n                y._handleStateChange();\n            }\n        ;\n        ;\n        });\n    });\n    l.subscribe(\"state-changed\", function(w, x) {\n        u.forEach(function(y) {\n            if (((x[y._threadID] && !y._stateChangeTimeout))) {\n                y._handleStateChange();\n            }\n        ;\n        ;\n        });\n    });\n    e.exports = v;\n});\n__d(\"ChatTabIndicatorLine\", [\"ChatTabIndicatorController\",\"CSS\",\"DOM\",\"DOMQuery\",\"MercuryParticipants\",\"Tooltip\",\"copyProperties\",\"csx\",], function(a, b, c, d, e, f) {\n    var g = b(\"ChatTabIndicatorController\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"DOMQuery\"), k = b(\"MercuryParticipants\"), l = b(\"Tooltip\"), m = b(\"copyProperties\"), n = b(\"csx\");\n    function o(p, q, r) {\n        this._typingIndicator = q;\n        this._messagesView = r;\n        this._controller = new g(p);\n        this._subscription = this._controller.subscribe(\"state-changed\", this._handleStateChanged.bind(this));\n    };\n;\n    m(o.prototype, {\n        destroy: function() {\n            this._setClass(null);\n            this._subscription.unsubscribe();\n            this._controller.destroy();\n        },\n        setLastMessage: function(p) {\n            this._controller.setLastMessage(p);\n        },\n        _handleStateChanged: function(p, q) {\n            var r = this._messagesView.isScrolledToBottom();\n            this._rerender(q);\n            ((r && this._messagesView.scrollToBottom()));\n        },\n        _rerender: function(p) {\n            if (((p.activity == \"none\"))) {\n                this._setClass(null);\n                return;\n            }\n        ;\n        ;\n            var q = i.JSBNG__find(this._typingIndicator, \".-cx-PRIVATE-mercuryTypingIndicator__text\");\n            if (p.text) {\n                i.setContent(q, p.text);\n            }\n             else i.empty(q);\n        ;\n        ;\n            if (((p.activity.substring(0, 4) == \"seen\"))) {\n                this._setClass(\"seen\");\n                if (((((p.activity == \"seen-by\")) && p.tooltip))) {\n                    k.getMulti(p.seenBy, function(r) {\n                        var s = i.create(\"div\"), t = 0;\n                        for (var u in r) {\n                            if (((t++ >= 2))) {\n                                var v = i.create(\"div\");\n                                i.setContent(v, r[u].JSBNG__name);\n                                i.appendContent(s, v);\n                            }\n                        ;\n                        ;\n                        };\n                    ;\n                        var w = j.JSBNG__find(this._typingIndicator, \"span.more\");\n                        l.set(w, s, \"above\", \"center\");\n                    }.bind(this));\n                }\n            ;\n            ;\n            }\n             else this._setClass(p.activity);\n        ;\n        ;\n        },\n        _setClass: function(p) {\n            if (((this._lastClass === p))) {\n                return;\n            }\n        ;\n        ;\n            ((this._lastClass && h.removeClass(this._typingIndicator, this._lastClass)));\n            ((p && h.addClass(this._typingIndicator, p)));\n            this._lastClass = p;\n        }\n    });\n    e.exports = o;\n});\n__d(\"MercuryEmoji\", [\"Emoji\",\"Emote\",\"MercuryConfig\",], function(a, b, c, d, e, f) {\n    var g = b(\"Emoji\"), h = b(\"Emote\"), i = c(\"MercuryConfig\"), j = {\n        htmlEmojiAndEmote: function(k, l) {\n            if (i.MessagingDisplayEmojiGK) {\n                return g.htmlEmojiAndEmote(k, l);\n            }\n             else return h.htmlEmote(k, l)\n        ;\n        }\n    };\n    e.exports = j;\n});\n__d(\"MercurySeenByAll\", [\"CSS\",\"DataStore\",\"DOM\",\"MercuryMessages\",\"MercuryParticipants\",\"MercuryRoger\",\"MercuryThreads\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"DataStore\"), i = b(\"DOM\"), j = b(\"MercuryMessages\"), k = b(\"MercuryParticipants\"), l = b(\"MercuryRoger\"), m = b(\"MercuryThreads\"), n = {\n    }, o = {\n        updateOnSeenChange: function(r, s) {\n            n[r.tagName] = true;\n            h.set(r, \"thread-id\", s.thread_id);\n            g.addClass(r, \"seenByListener\");\n            p(r, s);\n        }\n    };\n    function p(r, s) {\n        var t = s.participants.filter(function(w) {\n            return ((w !== k.user));\n        }), u = q(s), v = ((((s.participants.length > 0)) && ((s.participants[0] === k.user))));\n        g.conditionClass(r, \"repliedLast\", v);\n        g.conditionClass(r, \"seenByAll\", ((v && ((l.getSeenBy(u).length === t.length)))));\n    };\n;\n    function q(r) {\n        return {\n            author: k.user,\n            thread_id: r.thread_id,\n            timestamp: r.timestamp\n        };\n    };\n;\n    l.subscribe(\"state-changed\", function(r, s) {\n        for (var t in n) {\n            var u = i.scry(JSBNG__document.body, ((t + \".seenByListener\")));\n            for (var v = 0; ((v < u.length)); v++) {\n                var w = u[v], x = h.get(w, \"thread-id\");\n                if (s[x]) {\n                    m.getThreadMeta(x, function(y) {\n                        p(w, y);\n                    });\n                }\n            ;\n            ;\n            };\n        ;\n        };\n    ;\n    });\n    e.exports = o;\n});\n__d(\"WebMessengerPermalinkConstants\", [\"URI\",], function(a, b, c, d, e, f) {\n    var g = b(\"URI\"), h = {\n        ARCHIVED_PATH: \"/messages/archived\",\n        BASE_PATH: \"/messages\",\n        OTHER_PATH: \"/messages/other\",\n        SPAM_PATH: \"/messages/spam\",\n        COMPOSE_POSTFIX_PATH: \"/new\",\n        SEARCH_POSTFIX_PATH: \"/search\",\n        TID_POSTFIX_PARTIAL_PATH: \"/conversation-\",\n        getURIPathForThreadID: function(i, j) {\n            return ((((((j || h.BASE_PATH)) + h.TID_POSTFIX_PARTIAL_PATH)) + g.encodeComponent(g.encodeComponent(i))));\n        },\n        getThreadIDFromURI: function(i) {\n            var j = i.getPath().match(((((((h.BASE_PATH + \"(/[^/]+)*\")) + h.TID_POSTFIX_PARTIAL_PATH)) + \"([^/]+)\")));\n            if (j) {\n                var k = g.decodeComponent(g.decodeComponent(j[2]));\n                return k;\n            }\n        ;\n        ;\n        },\n        getCanonicalUserID: function(i) {\n            var j = i.match(\"(.*/)+(\\\\d+)$\");\n            return ((j && parseInt(j[2], 10)));\n        }\n    };\n    e.exports = h;\n});\n__d(\"MercuryThreadMetadataRenderer\", [\"event-extensions\",\"CSS\",\"DOM\",\"HTML\",\"JSLogger\",\"MercuryAttachment\",\"MercuryEmoji\",\"MercuryParticipants\",\"MercurySeenByAll\",\"MercuryServerRequests\",\"MercuryThreads\",\"Tooltip\",\"URI\",\"WebMessengerPermalinkConstants\",\"cx\",\"createArrayFrom\",\"tx\",\"MercuryImageTemplates\",\"MercuryThreadlistIconTemplates\",\"MercuryStatusTemplates\",\"MercuryConstants\",\"MercuryConfig\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"HTML\"), j = b(\"JSLogger\"), k = b(\"MercuryAttachment\"), l = b(\"MercuryEmoji\"), m = b(\"MercuryParticipants\"), n = b(\"MercurySeenByAll\"), o = b(\"MercuryServerRequests\"), p = b(\"MercuryThreads\"), q = b(\"Tooltip\"), r = b(\"URI\"), s = b(\"WebMessengerPermalinkConstants\"), t = b(\"cx\"), u = c(\"MercuryImageTemplates\"), v = c(\"MercuryThreadlistIconTemplates\"), w = c(\"MercuryStatusTemplates\"), x = c(\"MercuryConstants\"), y = c(\"MercuryConfig\"), z = b(\"createArrayFrom\"), aa = b(\"tx\"), ba = j.create(\"wm_timestamp\");\n    e.exports = {\n        renderTimestamp: function(fa, ga, ha, ia) {\n            if (ia) {\n                if (!ga) {\n                    ba.warn(\"no_title\");\n                    ga = (new JSBNG__Date(ia)).toLocaleDateString();\n                }\n            ;\n            ;\n                fa.setAttribute(\"title\", ga);\n                if (!ha) {\n                    ba.warn(\"no_display\");\n                    ha = JSBNG__Date.format(((y[\"24h_times\"] ? \"H:i\" : \"g:ia\")), Math.floor(((ia / 1000))));\n                }\n            ;\n            ;\n                h.setContent(fa, ha);\n                g.show(fa);\n            }\n        ;\n        ;\n        },\n        renderMessageSourceTags: function(fa, ga, ha, ia) {\n            var ja = x.MercuryMessageSourceTags, ka = \"\", la = \"\", ma = \"\";\n            if (ha.contains(ja.MESSENGER)) {\n                ka = \"Sent from Messenger\";\n                la = new r(\"/mobile/messenger\");\n                ma = \"-cx-PRIVATE-webMessengerMessageGroup__sourceMessenger\";\n            }\n             else if (ha.contains(ja.CHAT)) {\n                ka = \"Sent from Chat\";\n                ma = \"-cx-PRIVATE-webMessengerMessageGroup__sourceChat\";\n            }\n             else if (ha.contains(ja.EMAIL)) {\n                if (ia) {\n                    ka = aa._(\"Sent from {email}\", {\n                        email: ia\n                    });\n                }\n                 else ka = \"Sent from Email\";\n            ;\n            ;\n                ma = \"-cx-PRIVATE-webMessengerMessageGroup__sourceEmail\";\n            }\n             else if (ha.contains(ja.MOBILE)) {\n                ka = \"Sent from Mobile\";\n                la = new r(\"/mobile/\");\n                ma = \"-cx-PRIVATE-webMessengerMessageGroup__sourceMobile\";\n            }\n            \n            \n            \n        ;\n        ;\n            if (ma) {\n                q.set(fa, ka);\n                g.addClass(ga, ma);\n                if (la) {\n                    fa.setAttribute(\"href\", la);\n                }\n                 else fa.removeAttribute(\"href\");\n            ;\n            ;\n            }\n             else g.hide(fa);\n        ;\n        ;\n        },\n        renderMessageLocation: function(fa, ga, ha) {\n            var ia = r(\"/ajax/messaging/hovercard/map.php\").setQueryData(ha);\n            fa.setAttribute(\"data-hovercard\", ia);\n            g.removeClass(fa, \"-cx-PRIVATE-webMessengerMessageGroup__noLocation\");\n            g.show(ga);\n        },\n        renderSpoofWarning: function(fa, ga, ha) {\n            if (ga) {\n                g.addClass(fa, \"-cx-PRIVATE-webMessengerMessageGroup__spoofWarning\");\n                q.set(fa, aa._(\"Unable to confirm {name_or_email} as the sender.\", {\n                    name_or_email: ha.JSBNG__name\n                }));\n            }\n        ;\n        ;\n        },\n        renderCoreThreadlist: function(fa, ga, ha, ia, ja) {\n            ia = ((ia || {\n            }));\n            this.renderThreadImage(fa, ga.getNode(\"image\"));\n            ea(fa, ga.getNode(\"JSBNG__name\"), ia);\n            if (((fa.folder && ja))) {\n                da(ga.getNode(\"folderBadge\"), fa.folder);\n            }\n        ;\n        ;\n            var ka = ga.getNode(\"timestamp\");\n            this.renderTimestamp(ka, fa.timestamp_absolute, fa.timestamp_relative, fa.timestamp);\n            this.renderSnippet(fa, ga.getNode(\"snippet\"));\n            ha(ga, fa);\n        },\n        renderAndSeparatedParticipantList: function(fa, ga, ha) {\n            ha = ((ha || {\n            }));\n            ha.last_separator_uses_and = true;\n            p.getThreadMeta(fa, function(ia) {\n                ea(ia, ga, ha);\n            }.bind(this));\n        },\n        renderSnippet: function(fa, ga) {\n            var ha = h.create(\"span\");\n            g.addClass(ha, \"MercuryRepliedIndicator\");\n            h.appendContent(ga, ha);\n            n.updateOnSeenChange(ha, fa);\n            if (fa.snippet_has_attachment) {\n                if (((!fa.snippet && fa.snippet_attachments))) {\n                    fa.snippet_attachments.forEach(function(ka) {\n                        if (((ka.attach_type != x.MercuryAttachmentType.FILE))) {\n                            return;\n                        }\n                    ;\n                    ;\n                        var la = k.getAttachIconClass(ka.icon_type), ma = v[\":fb:mercury:attachment-icon-text\"].build().getRoot();\n                        h.appendContent(ma, ka.JSBNG__name);\n                        g.addClass(ma, la);\n                        h.appendContent(ga, ma);\n                    }.bind(this));\n                }\n                 else h.appendContent(ga, h.create(\"span\", {\n                    className: \"MercuryAttachmentIndicator\"\n                }));\n            ;\n            }\n        ;\n        ;\n            if (fa.is_forwarded_snippet) {\n                var ia;\n                if (fa.snippet) {\n                    ia = \"Forwarded Message:\";\n                }\n                 else ia = \"Forwarded Message\";\n            ;\n            ;\n                h.appendContent(ga, h.create(\"strong\", {\n                    className: \"mercuryForwardedIndicator\"\n                }, ia));\n            }\n        ;\n        ;\n            var ja = fa.snippet;\n            if (ja) {\n                if (((ja.substr(0, 4) == \"?OTR\"))) {\n                    ja = \"[encrypted message]\";\n                }\n                 else ja = ja.replace(/\\r\\n|[\\r\\n]/g, \" \");\n            ;\n            }\n        ;\n        ;\n            h.appendContent(ga, i(l.htmlEmojiAndEmote(ja)));\n        },\n        renderTitanLink: function(fa, ga, ha) {\n            var ia = fa.indexOf(\":\"), ja = new r().setSubdomain(\"www\");\n            if (((fa.substr(0, ia) == \"user\"))) {\n                ja.setPath(((\"/messages/\" + fa.substr(((ia + 1))))));\n                ga.setAttribute(\"href\", ja.toString());\n                ((ha && ha()));\n            }\n             else o.getServerThreadID(fa, function(ka) {\n                if (y.MessagesMercuryIntegrationGK) {\n                    ja.setPath(s.getURIPathForThreadID(ka));\n                }\n                 else {\n                    ja.setPath(\"/messages/\");\n                    ja.setQueryData({\n                        action: \"read\",\n                        tid: ka\n                    });\n                }\n            ;\n            ;\n                ga.setAttribute(\"href\", ja.toString());\n                ((ha && ha()));\n            });\n        ;\n        ;\n        },\n        renderThreadImage: function(fa, ga) {\n            if (fa.image_src) {\n                this._renderThreadImageSingle(fa.image_src, ga);\n                return;\n            }\n        ;\n        ;\n            var ha = [], ia = fa.participants.filter(function(ja) {\n                return ((ja != m.user));\n            });\n            if (!ia.length) {\n                ha = [m.user,];\n            }\n             else if (((ia.length == 1))) {\n                ha = [ia[0],];\n            }\n             else {\n                ha = ia.slice(0, 3);\n                if (((ha.length == 2))) {\n                    ha.push(m.user);\n                }\n            ;\n            ;\n            }\n            \n        ;\n        ;\n            m.getMulti(ha, function(ja) {\n                var ka = ha.map(function(la) {\n                    return ja[la];\n                });\n                this.renderParticipantImages(ka, ga);\n            }.bind(this));\n        },\n        renderParticipantImages: function(fa, ga) {\n            if (((fa.length > 2))) {\n                this._renderThreadImageSplit(fa, ga);\n            }\n             else this._renderThreadImageSingle(fa[0].image_src, ga);\n        ;\n        ;\n        },\n        renderErrorIndicator: function(fa, ga) {\n            var ha = w[\":fb:mercury:error-indicator\"].render(), ia;\n            switch (fa) {\n              case x.MercuryActionStatus.REQUEST_ERROR:\n            \n              case x.MercuryActionStatus.TRANSPORT_ERROR:\n            \n              case x.MercuryActionStatus.FAILED_UNKNOWN_REASON:\n            \n              case x.MercuryActionStatus.UNABLE_TO_CONFIRM:\n                ia = \"This message failed to send. Click to send again.\";\n                break;\n              default:\n                throw new Error(((\"Invalid error code \" + fa)));\n            };\n        ;\n            q.set(ha, ia, \"above\", \"center\");\n            if (ga) {\n                JSBNG__Event.listen(ha, \"click\", ga);\n                g.addClass(ha, \"mercuryClickableErrorIndicator\");\n            }\n        ;\n        ;\n            return ha;\n        },\n        renderResendIndicator: function() {\n            return w[\":fb:mercury:resend-indicator\"].render();\n        },\n        renderStatusIndicator: function(fa, ga) {\n            var ha = x.MercuryActionStatus, ia;\n            if (((fa == ha.RESENDING))) {\n                ia = this.renderResendIndicator();\n            }\n             else if (((((((((fa !== undefined)) && ((fa != ha.UNSENT)))) && ((fa != ha.UNCONFIRMED)))) && ((fa != ha.SUCCESS))))) {\n                ia = this.renderErrorIndicator(fa, ga);\n            }\n            \n        ;\n        ;\n            return ia;\n        },\n        renderParticipantList: function(fa, ga, ha, ia) {\n            var ja = {\n                abbr_mode: true,\n                last_separator_uses_and: true,\n                link_mode: true,\n                names_renderer: true\n            };\n            ia = ((ia || {\n            }));\n            var ka = null;\n            if (ia.names_renderer) {\n                ka = ia.names_renderer(ga);\n            }\n             else ka = ga.map(function(na) {\n                return na.JSBNG__name;\n            });\n        ;\n        ;\n            var la = null;\n            if (((ka.length == 1))) {\n                la = ka[0];\n            }\n             else if (((ka.length == 2))) {\n                var ma = {\n                    participant1: ka[0],\n                    participant2: ka[1]\n                };\n                if (ia.last_separator_uses_and) {\n                    la = aa._(\"{participant1} and {participant2}\", ma);\n                }\n                 else la = aa._(\"{participant1}, {participant2}\", ma);\n            ;\n            ;\n            }\n             else if (ia.last_separator_uses_and) {\n                if (ia.abbr_mode) {\n                    la = aa._(\"{participant1} and {others_link}\", {\n                        participant1: ka[0],\n                        others_link: this.renderParticipantCount(fa, {\n                            render_subset: true,\n                            count: ((ha - 1)),\n                            as_link: ia.link_mode\n                        })\n                    });\n                }\n                 else if (((ka.length == 3))) {\n                    la = aa._(\"{participant1}, {participant2} and {participant3}\", {\n                        participant1: ka[0],\n                        participant2: ka[1],\n                        participant3: ka[2]\n                    });\n                }\n                 else la = aa._(\"{participant1}, {participant2} and {others_link}\", {\n                    participant1: ka[0],\n                    participant2: ka[1],\n                    others_link: this.renderParticipantCount(fa, {\n                        render_subset: true,\n                        count: ((ha - 2)),\n                        as_link: ia.link_mode\n                    })\n                });\n                \n            ;\n            ;\n            }\n             else if (((ka.length == 3))) {\n                la = aa._(\"{participant1}, {participant2}, {participant3}\", {\n                    participant1: ka[0],\n                    participant2: ka[1],\n                    participant3: ka[2]\n                });\n            }\n             else la = aa._(\"{participant1}, {participant2}, {participant3}, {others_link}\", {\n                participant1: ka[0],\n                participant2: ka[1],\n                participant3: ka[2],\n                others_link: this.renderParticipantCount(fa, {\n                    render_subset: true,\n                    count: ((ha - 3)),\n                    as_link: ia.link_mode\n                })\n            });\n            \n            \n            \n        ;\n        ;\n            if (Array.isArray(la)) {\n                la = h.create(\"span\", {\n                }, la);\n            }\n        ;\n        ;\n            return la;\n        },\n        renderParticipantCount: function(fa, ga) {\n            function ha(la, ma) {\n                return h.create(\"a\", {\n                    className: \"hoverlistLink\",\n                    href: r(\"/ajax/messaging/profile_browser/profile_browser.php\").setQueryData(la),\n                    rel: \"dialog\"\n                }, ma);\n            };\n        ;\n            var ia = ga.render_subset, ja = o.getServerThreadIDNow(fa), ka;\n            if (!ia) {\n                ka = ((((ga.count > 1)) ? aa._(\"{num} people\", {\n                    num: ga.count\n                }) : \"1 person\"));\n            }\n             else ka = ((((ga.count > 1)) ? aa._(\"{others_count} others\", {\n                others_count: ga.count\n            }) : \"1 other\"));\n        ;\n        ;\n            if (((ga.as_link && ja))) {\n                return ha({\n                    tid: ja\n                }, ka);\n            }\n             else return ka\n        ;\n        },\n        renderShortNames: function(fa) {\n            if (((fa.length == 1))) {\n                return [fa[0].JSBNG__name,];\n            }\n        ;\n        ;\n            return fa.map(function(ga) {\n                return ga.short_name;\n            });\n        },\n        _renderThreadImageSingle: function(fa, ga) {\n            var ha = u[\":fb:mercury:thread-image:single\"].build().getRoot();\n            ha.src = fa;\n            h.setContent(ga, ha);\n        },\n        _renderThreadImageSplit: function(fa, ga) {\n            var ha = u[\":fb:mercury:thread-image:split\"].build().setNodeProperty(\"left\", \"src\", fa[0].image_src).setNodeProperty(\"topRight\", \"src\", fa[1].image_src).setNodeProperty(\"bottomRight\", \"src\", fa[2].image_src);\n            h.setContent(ga, ha.getRoot());\n        },\n        _cloneIfDOMElement: function(fa) {\n            if (fa.cloneNode) {\n                return fa.cloneNode();\n            }\n             else return fa\n        ;\n        }\n    };\n    function ca(fa, ga) {\n        var ha = fa;\n        if (((ga && ((ga > 1))))) {\n            ha = h.create(\"span\", {\n            }, aa._(\"{conversation_title} ({unread_count})\", {\n                conversation_title: fa,\n                unread_count: ga\n            }));\n        }\n    ;\n    ;\n        return ha;\n    };\n;\n    function da(fa, ga) {\n        z(fa).forEach(function(ha) {\n            h.setContent(ha, ga);\n        });\n    };\n;\n    function ea(fa, ga, ha) {\n        ga = z(ga);\n        var ia = {\n            callback: true,\n            check_length: true,\n            show_unread_count: true\n        };\n        ha = ((ha || {\n        }));\n        var ja = {\n        };\n        for (var ka in ha) {\n            if (ia[ka]) {\n                ja[ka] = ha[ka];\n                delete ha[ka];\n            }\n        ;\n        ;\n        };\n    ;\n        if (fa.JSBNG__name) {\n            var la = ca(fa.JSBNG__name, ((ja.show_unread_count ? fa.unread_count : 0)));\n            ga.forEach(function(na) {\n                h.setContent(na, la);\n            });\n            ((ja.callback && ja.callback(la)));\n            return;\n        }\n    ;\n    ;\n        var ma = fa.participants;\n        if (((fa.participants.length > 1))) {\n            ma = fa.participants.filter(function(na) {\n                return ((na != m.user));\n            });\n        }\n    ;\n    ;\n        m.getMulti(ma, function(na) {\n            var oa = ma.map(function(ta) {\n                return na[ta];\n            }), pa = e.exports.renderParticipantList(fa.thread_id, oa, ma.length, ha);\n            pa = ca(pa, ((ja.show_unread_count ? fa.unread_count : 0)));\n            var qa = ha.abbr_mode, ra = {\n            };\n            for (var sa in ha) {\n                ra[sa] = ha[sa];\n            ;\n            };\n        ;\n            ra.abbr_mode = true;\n            ga.forEach(function(ta) {\n                var ua = ((((ga.length > 1)) ? e.exports._cloneIfDOMElement(pa) : pa));\n                h.setContent(ta, ua);\n                if (((((ja.check_length && !qa)) && ((ta.scrollWidth > ta.clientWidth))))) {\n                    var va = e.exports.renderParticipantList(fa.thread_id, oa, ma.length, ra);\n                    va = ca(va, ((ja.show_unread_count ? fa.unread_count : 0)));\n                    h.setContent(ta, va);\n                }\n            ;\n            ;\n            }.bind(this));\n            ((ja.callback && ja.callback(pa)));\n        }.bind(this));\n    };\n;\n});\n__d(\"MercuryMessageRenderer\", [\"MercuryAttachmentRenderer\",\"CSS\",\"DOM\",\"DOMQuery\",\"HTML\",\"htmlHyperlink\",\"MercuryEmoji\",\"MercuryParticipants\",\"Tooltip\",\"tx\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"MercuryAttachmentRenderer\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"DOMQuery\"), k = b(\"HTML\"), l = b(\"htmlHyperlink\"), m = b(\"MercuryEmoji\"), n = b(\"MercuryParticipants\"), o = b(\"Tooltip\"), p = c(\"MercuryConstants\"), q = b(\"tx\"), r = {\n        renderTooltipFlyout: function(ha, ia) {\n            ia.forEach(function(ja) {\n                var ka = i.create(\"div\");\n                i.setContent(ka, ja.JSBNG__name);\n                i.appendContent(ha, ka);\n            });\n        },\n        renderLogMessage: function(ha, ia, ja, ka) {\n            t(ha, ka);\n            u(ia, ka);\n            v(ja, ka);\n        },\n        formatMessageBody: function(ha, ia) {\n            ia = ((ia || {\n            }));\n            var ja = ((ha || \"\")).replace(/\\n+$/, \"\"), ka = Object.keys(ia).map(function(na) {\n                return window.parseInt(na);\n            }).sort(function(na, oa) {\n                return ((na - oa));\n            }), la = 0, ma = i.create(\"span\");\n            ka.forEach(function(na) {\n                var oa = ja.slice(la, na);\n                s(ma, oa, false);\n                var pa = ia[na.toString()], qa = ja.slice(na, ((na + pa.length)));\n                s(ma, qa, true);\n                la = ((na + pa.length));\n            });\n            s(ma, ja.slice(la), false);\n            return ma;\n        }\n    };\n    function s(ha, ia, ja) {\n        if (((((ia.length === 0)) && !ja))) {\n            return;\n        }\n    ;\n    ;\n        var ka = k(l(ia, m.htmlEmojiAndEmote, null, true)), la = ((ja ? {\n            class: \"highlight\"\n        } : {\n        })), ma = i.create(\"span\", la, ka);\n        i.appendContent(ha, ma);\n    };\n;\n    function t(ha, ia) {\n        var ja = \"\";\n        switch (ia.log_message_type) {\n          case p.MercuryLogMessageType.SUBSCRIBE:\n            ja = \"mercurySubscribeIcon\";\n            break;\n          case p.MercuryLogMessageType.UNSUBSCRIBE:\n            ja = \"mercuryUnsubscribeIcon\";\n            break;\n          case p.MercuryLogMessageType.THREAD_NAME:\n            ja = \"mercuryThreadNameIcon\";\n            break;\n          case p.MercuryLogMessageType.THREAD_IMAGE:\n            ja = \"mercuryThreadImageIcon\";\n            break;\n          case p.MercuryLogMessageType.VIDEO_CALL:\n            var ka = ia.log_message_data.answered;\n            if (((ka || ga(ia)))) {\n                ja = \"mercuryVideoCallIcon\";\n            }\n             else ja = \"mercuryMissedVideoCallIcon\";\n        ;\n        ;\n            break;\n          case p.MercuryLogMessageType.SERVER_ERROR:\n            ja = \"mercuryErrorIcon\";\n            break;\n        };\n    ;\n        h.addClass(ha, ja);\n    };\n;\n    function u(ha, ia) {\n        switch (ia.log_message_type) {\n          case p.MercuryLogMessageType.SUBSCRIBE:\n            da(ha, ia);\n            break;\n          case p.MercuryLogMessageType.UNSUBSCRIBE:\n            ea(ha, ia);\n            break;\n          case p.MercuryLogMessageType.VIDEO_CALL:\n            if (ga(ia)) {\n                w(ha, ia);\n            }\n             else x(ha, ia);\n        ;\n        ;\n            break;\n          case p.MercuryLogMessageType.THREAD_NAME:\n            y(ha, ia);\n            break;\n          case p.MercuryLogMessageType.THREAD_IMAGE:\n            z(ha, ia);\n            break;\n          case p.MercuryLogMessageType.SERVER_ERROR:\n            fa(ha, ia);\n            break;\n        };\n    ;\n    };\n;\n    function v(ha, ia) {\n        var ja = ia.log_message_type;\n        if (((ja == p.MercuryLogMessageType.THREAD_IMAGE))) {\n            var ka = ia.log_message_data.image;\n            ((ka && i.setContent(ha, g.renderPreview(ka))));\n            h.show(ha);\n        }\n    ;\n    ;\n    };\n;\n    var w = function(ha, ia) {\n        n.get(ia.author, function(ja) {\n            var ka = ja.short_name, la;\n            switch (ia.log_message_data.event_name) {\n              case \"installing\":\n                la = i.tx._(\"{firstname} is setting up video calling...\", {\n                    firstname: ka\n                });\n                break;\n              case \"installed\":\n                la = i.tx._(\"{firstname} finished setting up video calling.\", {\n                    firstname: ka\n                });\n                break;\n              case \"install_canceled\":\n                la = i.tx._(\"You canceled the video calling installation. \", {\n                    firstname: ka\n                });\n                break;\n            };\n        ;\n            if (la) {\n                i.setContent(ha, la);\n            }\n        ;\n        ;\n        });\n    }, x = function(ha, ia) {\n        var ja = ia.log_message_data.caller, ka = ia.log_message_data.callee, la = [ja,ka,];\n        n.getMulti(la, function(ma) {\n            if (((ja == n.user))) {\n                var na = ma[ka].short_name, oa;\n                if (ia.log_message_data.answered) {\n                    oa = i.tx._(\"You called {firstname}.\", {\n                        firstname: na\n                    });\n                }\n                 else oa = i.tx._(\"{firstname} missed a call from you. \", {\n                    firstname: na\n                });\n            ;\n            ;\n            }\n             else {\n                var pa = ma[ja].short_name;\n                if (ia.log_message_data.answered) {\n                    oa = i.tx._(\"{firstname} called you.\", {\n                        firstname: pa\n                    });\n                }\n                 else oa = i.tx._(\"You missed a call from {firstname}. \", {\n                    firstname: pa\n                });\n            ;\n            ;\n            }\n        ;\n        ;\n            i.setContent(ha, oa);\n        });\n    }, y = function(ha, ia) {\n        var ja = ia.log_message_data.JSBNG__name, ka = i.create(\"b\", {\n        }, ja);\n        if (((ia.author == n.user))) {\n            if (ja) {\n                i.setContent(ha, i.tx._(\"You named the conversation: {name}.\", {\n                    JSBNG__name: ka\n                }));\n            }\n             else i.setContent(ha, i.tx._(\"You removed the conversation name.\"));\n        ;\n        ;\n        }\n         else n.get(ia.author, function(la) {\n            var ma, na = aa(la);\n            if (ja) {\n                ma = i.tx._(\"{actor} named the conversation: {name}.\", {\n                    actor: na,\n                    JSBNG__name: ka\n                });\n            }\n             else ma = i.tx._(\"{actor} removed the conversation name.\", {\n                actor: na\n            });\n        ;\n        ;\n            i.setContent(ha, ma);\n        });\n    ;\n    ;\n    }, z = function(ha, ia) {\n        if (((ia.author == n.user))) {\n            if (ia.log_message_data.image) {\n                i.setContent(ha, i.tx._(\"You changed the conversation picture.\"));\n            }\n             else i.setContent(ha, i.tx._(\"You removed the conversation picture.\"));\n        ;\n        ;\n        }\n         else n.get(ia.author, function(ja) {\n            var ka = aa(ja), la;\n            if (ia.log_message_data.image) {\n                la = i.tx._(\"{actor} changed the conversation picture.\", {\n                    actor: ka\n                });\n            }\n             else la = i.tx._(\"{actor} removed the conversation picture.\", {\n                actor: ka\n            });\n        ;\n        ;\n            i.setContent(ha, la);\n        });\n    ;\n    ;\n    }, aa = function(ha) {\n        if (ha.href) {\n            return i.create(\"a\", {\n                href: ha.href\n            }, ha.JSBNG__name);\n        }\n    ;\n    ;\n        return ha.JSBNG__name;\n    }, ba = function(ha) {\n        if (ha.href) {\n            return i.create(\"a\", {\n                href: ha.href\n            }, ha.short_name);\n        }\n    ;\n    ;\n        return ha.short_name;\n    }, ca = function(ha) {\n        var ia = ha.indexOf(n.user);\n        if (((ia > 0))) {\n            return ha.splice(ia, 1).concat(ha);\n        }\n    ;\n    ;\n        return ha;\n    }, da = function(ha, ia) {\n        var ja = ca(ia.log_message_data.added_participants), ka = null, la;\n        if (((ja.length == 1))) {\n            ka = [ia.author,ja[0],];\n            n.getMulti(ka, function(ma) {\n                if (((ia.author == n.user))) {\n                    la = i.tx._(\"You added {subscriber1}.\", {\n                        subscriber1: aa(ma[ja[0]])\n                    });\n                }\n                 else if (((ja[0] == n.user))) {\n                    la = i.tx._(\"{actor} added you.\", {\n                        actor: aa(ma[ia.author])\n                    });\n                }\n                 else la = i.tx._(\"{actor} added {subscriber1}.\", {\n                    actor: aa(ma[ia.author]),\n                    subscriber1: aa(ma[ja[0]])\n                });\n                \n            ;\n            ;\n                i.setContent(ha, la);\n            });\n        }\n         else if (((ja.length == 2))) {\n            ka = [ia.author,].concat(ja);\n            n.getMulti(ka, function(ma) {\n                if (((ia.author == n.user))) {\n                    la = i.tx._(\"You added {subscriber1} and {subscriber2}.\", {\n                        subscriber1: aa(ma[ja[0]]),\n                        subscriber2: aa(ma[ja[1]])\n                    });\n                }\n                 else if (((ja[0] == n.user))) {\n                    la = i.tx._(\"{actor} added you and {subscriber2}.\", {\n                        actor: aa(ma[ia.author]),\n                        subscriber2: aa(ma[ja[1]])\n                    });\n                }\n                 else la = i.tx._(\"{actor} added {subscriber1} and {subscriber2}.\", {\n                    actor: aa(ma[ia.author]),\n                    subscriber1: aa(ma[ja[0]]),\n                    subscriber2: aa(ma[ja[1]])\n                });\n                \n            ;\n            ;\n                i.setContent(ha, la);\n            });\n        }\n         else if (((ja.length == 3))) {\n            ka = [ia.author,].concat(ja);\n            n.getMulti(ka, function(ma) {\n                if (((ia.author == n.user))) {\n                    la = i.tx._(\"You added {subscriber1}, {subscriber2} and {subscriber3}.\", {\n                        subscriber1: aa(ma[ja[0]]),\n                        subscriber2: aa(ma[ja[1]]),\n                        subscriber3: aa(ma[ja[2]])\n                    });\n                }\n                 else if (((ja[0] == n.user))) {\n                    la = i.tx._(\"{actor} added you, {subscriber2} and {subscriber3}.\", {\n                        actor: aa(ma[ia.author]),\n                        subscriber2: aa(ma[ja[1]]),\n                        subscriber3: aa(ma[ja[2]])\n                    });\n                }\n                 else la = i.tx._(\"{actor} added {subscriber1}, {subscriber2} and {subscriber3}.\", {\n                    actor: aa(ma[ia.author]),\n                    subscriber1: aa(ma[ja[0]]),\n                    subscriber2: aa(ma[ja[1]]),\n                    subscriber3: aa(ma[ja[2]])\n                });\n                \n            ;\n            ;\n                i.setContent(ha, la);\n            });\n        }\n         else {\n            ka = [ia.author,].concat(ja);\n            n.getMulti(ka, function(ma) {\n                var na = i.tx._(\"{num} more\", {\n                    num: ((ja.length - 2))\n                }), oa = i.create(\"span\", {\n                    className: \"more\"\n                }, na), pa = i.create(\"div\");\n                r.renderTooltipFlyout(pa, ja.slice(2).map(function(ra) {\n                    return ma[ra];\n                }));\n                if (((ia.author == n.user))) {\n                    la = i.tx._(\"You added {subscriber1}, {subscriber2} and {more_people}.\", {\n                        subscriber1: aa(ma[ja[0]]),\n                        subscriber2: aa(ma[ja[1]]),\n                        more_people: oa\n                    });\n                }\n                 else if (((ja[0] == n.user))) {\n                    la = i.tx._(\"{actor} added you, {subscriber2} and {more_people}.\", {\n                        actor: aa(ma[ia.author]),\n                        subscriber2: aa(ma[ja[1]]),\n                        more_people: oa\n                    });\n                }\n                 else la = i.tx._(\"{actor} added {subscriber1}, {subscriber2} and {more_people}.\", {\n                    actor: aa(ma[ia.author]),\n                    subscriber1: aa(ma[ja[0]]),\n                    subscriber2: aa(ma[ja[1]]),\n                    more_people: oa\n                });\n                \n            ;\n            ;\n                i.setContent(ha, la);\n                var qa = j.JSBNG__find(ha, \"span.more\");\n                o.set(qa, pa, \"above\", \"center\");\n            });\n        }\n        \n        \n    ;\n    ;\n    }, ea = function(ha, ia) {\n        n.get(ia.author, function(ja) {\n            var ka;\n            if (((ia.author == n.user))) {\n                ka = i.tx._(\"You left the conversation.\");\n            }\n             else ka = i.tx._(\"{actor} left the conversation.\", {\n                actor: aa(ja)\n            });\n        ;\n        ;\n            i.setContent(ha, ka);\n        });\n    }, fa = function(ha, ia) {\n        var ja = \"We were unable to fetch previous messages in this conversation.\";\n        i.setContent(ha, ja);\n    }, ga = function(ha) {\n        return ((((ha.log_message_data.event_name === \"installing\")) || ((ha.log_message_data.event_name === \"install_canceled\"))));\n    };\n    e.exports = r;\n});\n__d(\"ChatTabMessagesView\", [\"event-extensions\",\"Arbiter\",\"ArbiterMixin\",\"MercuryAttachmentRenderer\",\"ChannelConstants\",\"ChatConfig\",\"ChatTabIndicatorLine\",\"ChatVisibility\",\"CSS\",\"DOM\",\"Emote\",\"Env\",\"MercuryMessages\",\"MercuryThreadMetadataRenderer\",\"MercuryThreads\",\"MercuryMessageRenderer\",\"MercuryParticipants\",\"MercuryThreadInformer\",\"Tooltip\",\"VideoCallCore\",\"copyProperties\",\"isRTL\",\"tx\",\"date-extensions\",\"ChatTabTemplates\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"MercuryAttachmentRenderer\"), j = b(\"ChannelConstants\"), k = b(\"ChatConfig\"), l = b(\"ChatTabIndicatorLine\"), m = b(\"ChatVisibility\"), n = b(\"CSS\"), o = b(\"DOM\"), p = b(\"Emote\"), q = b(\"Env\"), r = b(\"MercuryMessages\"), s = b(\"MercuryThreadMetadataRenderer\"), t = b(\"MercuryThreads\"), u = b(\"MercuryMessageRenderer\"), v = b(\"MercuryParticipants\"), w = b(\"MercuryThreadInformer\"), x = b(\"Tooltip\"), y = b(\"VideoCallCore\"), z = c(\"ChatTabTemplates\"), aa = c(\"MercuryConstants\"), ba = b(\"copyProperties\"), ca = b(\"isRTL\"), da = b(\"tx\");\n    b(\"date-extensions\");\n    function ea(pa) {\n        return JSBNG__Date.format(((k.get(\"24h_times\") ? \"H:i\" : \"g:ia\")), ((pa / 1000)));\n    };\n;\n    function fa(pa) {\n        var qa = z[\":fb:chat:conversation:message-group\"].build();\n        qa.setNodeContent(\"timestamp\", ea(pa.timestamp));\n        v.get(pa.author, function(ra) {\n            var sa = qa.getNode(\"profileLink\");\n            sa.href = ra.href;\n            var ta = ((((ra.fbid == q.user)) ? \"You\" : ra.JSBNG__name));\n            x.set(sa, ta, \"left\");\n            qa.setNodeProperty(\"profilePhoto\", \"src\", ra.image_src);\n        });\n        return qa;\n    };\n;\n    function ga(pa) {\n        var qa = z[\":fb:chat:conversation:message:event\"].build();\n        qa.setNodeContent(\"timestamp\", ea(pa.timestamp));\n        u.renderLogMessage(qa.getNode(\"icon\"), qa.getNode(\"message\"), qa.getNode(\"attachment\"), pa);\n        var ra = ha(pa);\n        if (ra) {\n            o.appendContent(qa.getNode(\"message\"), ra);\n        }\n    ;\n    ;\n        return qa.getRoot();\n    };\n;\n    function ha(pa) {\n        var qa, ra;\n        if (((pa.log_message_type == aa.MercuryLogMessageType.VIDEO_CALL))) {\n            if (((pa.log_message_data.event_name == \"install_canceled\"))) {\n                qa = o.tx._(\"Retry setup and call back.\");\n                ra = \"callback_cancelinstall_link\";\n                return ia(qa, pa.thread_id, pa.log_message_data.to, ra);\n            }\n             else if (((((!pa.log_message_data.event_name && ((pa.log_message_data.callee == v.user)))) && !pa.log_message_data.answered))) {\n                qa = o.tx._(\"Call Back\");\n                ra = \"callback_link\";\n                return ia(qa, pa.thread_id, pa.log_message_data.caller.split(\":\")[1], ra);\n            }\n            \n        ;\n        }\n    ;\n    ;\n        return null;\n    };\n;\n    function ia(pa, qa, ra, sa) {\n        if (y.isSupported()) {\n            var ta = ((!m.isOnline() || !y.availableForCall(ra))), ua = o.create(\"a\", {\n                href: \"#\",\n                className: \"callBackLink\"\n            }, pa);\n            if (ta) {\n                n.hide(ua);\n            }\n        ;\n        ;\n            ua.setAttribute(\"data-gt\", JSON.stringify({\n                videochat: \"clicked_callback_link\"\n            }));\n            JSBNG__Event.listen(ua, \"click\", function() {\n                na.inform(\"video-call-clicked\", {\n                    userID: ra,\n                    threadID: qa,\n                    clickSource: sa\n                });\n            });\n            return ua;\n        }\n    ;\n    ;\n        return null;\n    };\n;\n    function ja(pa) {\n        var qa = z[\":fb:mercury:chat:message:forward\"].build(), ra = qa.getNode(\"forwardText\");\n        if (ra) {\n            n.hide(qa.getRoot());\n            s.renderTitanLink(pa.thread_id, qa.getNode(\"forwardLink\"), n.show.bind(n, qa.getRoot()));\n            if (((pa.forward_count > 1))) {\n                o.appendContent(ra, da._(\"{count} forwarded messages\", {\n                    count: pa.forward_count\n                }));\n            }\n             else o.appendContent(ra, \"1 forwarded message\");\n        ;\n        ;\n        }\n    ;\n    ;\n        return qa.getRoot();\n    };\n;\n    var ka = [\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\",];\n    function la(pa) {\n        var qa = new JSBNG__Date();\n        qa.setHours(0);\n        qa.setMinutes(0);\n        qa.setSeconds(0);\n        qa.setMilliseconds(0);\n        var ra = ((((((24 * 60)) * 60)) * 1000)), sa = ((qa.getTime() - pa.getTime()));\n        if (((sa <= 0))) {\n            return \"Today\";\n        }\n         else if (((sa < ra))) {\n            return \"Yesterday\";\n        }\n        \n    ;\n    ;\n        return da._(\"{month} {date}\", {\n            month: ka[pa.getMonth()],\n            date: pa.getDate()\n        });\n    };\n;\n    var ma = [];\n    function na(pa, qa, ra, sa) {\n        this.threadID = pa;\n        this.scrollContainer = qa;\n        this.conversationElem = ra;\n        this.messageElements = {\n        };\n        this.messageGroup = null;\n        this.prevMessage = null;\n        var ta = aa.MercuryThreadlistConstants.MESSAGE_TIMESTAMP_THRESHOLD;\n        this._olderTimestamp = (((new JSBNG__Date()).getTime() - ta));\n        ma.push(this);\n        this._subscription = g.subscribe(\"overflow-applied-to-body\", this.scrollToBottom.bind(this));\n        if (sa) {\n            this.indicatorLine = new l(this.threadID, sa, this);\n        }\n    ;\n    ;\n        r.getThreadMessagesRange(this.threadID, 0, aa.MercuryThreadlistConstants.RECENT_MESSAGES_LIMIT, Function.prototype);\n        this.rerender();\n    };\n;\n    ba(na, h);\n    ba(na.prototype, {\n        destroy: function() {\n            o.empty(this.conversationElem);\n            this._subscription.unsubscribe();\n            ma.remove(this);\n            ((this.indicatorLine && this.indicatorLine.destroy()));\n            this.destroyed = true;\n        },\n        _appendMessage: function(pa) {\n            if (((pa == this.prevMessage))) {\n                return;\n            }\n        ;\n        ;\n            var qa = aa.MercuryThreadlistConstants, ra = qa.GROUPING_THRESHOLD, sa = ((((pa.action_type == aa.MercuryActionType.LOG_MESSAGE)) && ((pa.log_message_type == aa.MercuryLogMessageType.SERVER_ERROR))));\n            if (pa.is_cleared) {\n                return;\n            }\n        ;\n        ;\n            var ta = null;\n            if (this.prevMessage) {\n                ta = new JSBNG__Date(this.prevMessage.timestamp);\n            }\n        ;\n        ;\n            var ua = new JSBNG__Date(pa.timestamp);\n            if (((!sa && ((((((!ta || ((ta.getDate() != ua.getDate())))) || ((ta.getMonth() != ua.getMonth())))) || ((ta.getFullYear() != ua.getFullYear()))))))) {\n                var va = z[\":fb:chat:conversation:date-break\"].build();\n                o.setContent(va.getRoot(), la(ua));\n                o.appendContent(this.conversationElem, va.getRoot());\n                this.messageGroup = null;\n            }\n        ;\n        ;\n            if (((pa.action_type == aa.MercuryActionType.LOG_MESSAGE))) {\n                o.appendContent(this.conversationElem, ga(pa));\n                this.messageGroup = null;\n                this.prevMessage = pa;\n                return;\n            }\n        ;\n        ;\n            if (((((!this.messageGroup || ((this.prevMessage.author != pa.author)))) || ((this.prevMessage.timestamp < ((pa.timestamp - ra))))))) {\n                this.messageGroup = fa(pa);\n                o.appendContent(this.conversationElem, this.messageGroup.getRoot());\n            }\n        ;\n        ;\n            var wa = this._renderSingleMessage(pa);\n            this.messageElements[pa.message_id] = wa;\n            o.appendContent(this.messageGroup.getNode(\"messages\"), wa);\n            this.prevMessage = pa;\n        },\n        rerender: function() {\n            o.empty(this.conversationElem);\n            this.messageElements = {\n            };\n            this.messageGroup = null;\n            this.prevMessage = null;\n            var pa = r.getThreadMessagesSinceTimestamp(this.threadID, this._olderTimestamp);\n            this._appendMessages(pa);\n        },\n        update: function(pa) {\n            for (var qa in pa) {\n                var ra = this.messageElements[qa];\n                if (ra) {\n                    var sa = this._renderSingleMessage(r.getMessagesFromIDs([qa,])[0]);\n                    this.messageElements[qa] = sa;\n                    o.replace(ra, sa);\n                }\n            ;\n            ;\n            };\n        ;\n        },\n        _appendMessages: function(pa) {\n            pa.forEach(this._appendMessage.bind(this));\n            ((this.indicatorLine && this.indicatorLine.setLastMessage(this.prevMessage)));\n            this.scrollToBottom();\n        },\n        isScrolledToBottom: function() {\n            var pa = this.scrollContainer;\n            return ((((pa.scrollTop + pa.clientHeight)) >= pa.scrollHeight));\n        },\n        scrollToBottom: function() {\n            this.scrollContainer.scrollTop = this.scrollContainer.scrollHeight;\n        },\n        _renderSingleMessage: function(pa) {\n            var qa = z[\":fb:chat:conversation:message\"].render();\n            if (pa.subject) {\n                var ra = z[\":fb:chat:conversation:message:subject\"].render();\n                o.setContent(ra, pa.subject);\n                o.appendContent(qa, ra);\n            }\n        ;\n        ;\n            if (((pa.body.substr(0, 4) == \"?OTR\"))) {\n                o.setContent(qa, \"[encrypted message]\");\n                n.addClass(qa, \"cyphertext\");\n            }\n             else {\n                n.addClass(qa, ((ca(pa.body) ? \"direction_rtl\" : \"direction_ltr\")));\n                o.appendContent(qa, u.formatMessageBody(pa.body));\n            }\n        ;\n        ;\n            if (pa.has_attachment) {\n                this._appendMessageAttachments(qa, pa);\n            }\n        ;\n        ;\n            if (pa.forward_count) {\n                o.appendContent(qa, ja(pa));\n            }\n        ;\n        ;\n            var sa = s.renderStatusIndicator(pa.JSBNG__status, r.resendMessage.bind(r, pa));\n            if (sa) {\n                n.addClass(qa, \"errorStatus\");\n                var ta = z[\":fb:chat:conversation:message:status\"].build();\n                o.appendContent(ta.getNode(\"message\"), qa);\n                o.appendContent(ta.getNode(\"JSBNG__status\"), sa);\n                return ta.getRoot();\n            }\n        ;\n        ;\n            return qa;\n        },\n        _appendMessageAttachments: function(pa, qa) {\n            var ra = aa.MercuryAttachmentType, sa = qa.attachments;\n            for (var ta = 0, ua = sa.length; ((ta < ua)); ++ta) {\n                var va = sa[ta], wa = va.attach_type, xa = va.share_data_type;\n                if (((wa == ra.ERROR))) {\n                    o.appendContent(pa, i.renderError(va));\n                }\n            ;\n            ;\n                if (((wa == ra.FILE))) {\n                    o.appendContent(pa, i.renderFileLink(va));\n                }\n            ;\n            ;\n                var ya = null, za;\n                if (((((wa == ra.SHARE)) && ((xa == aa.MercurySupportedShareType.FB_VIDEO))))) {\n                    ya = i.renderVideoThumb(va);\n                    za = o.JSBNG__find(ya, \"img\");\n                    JSBNG__Event.listen(za, \"load\", this._thumbLoaded.shield(this, za));\n                }\n                 else if (((((wa == ra.SHARE)) && ((((xa == aa.MercurySupportedShareType.FB_MUSIC_ALBUM)) || ((xa == aa.MercurySupportedShareType.FB_SONG))))))) {\n                    ya = i.renderMusic(va);\n                    za = o.JSBNG__find(ya, \"img\");\n                    JSBNG__Event.listen(za, \"load\", this._thumbLoaded.shield(this, za));\n                }\n                 else if (((((wa == ra.SHARE)) && ((((xa == aa.MercurySupportedShareType.EXTERNAL)) || ((xa == aa.MercurySupportedShareType.FB_TEMPLATE))))))) {\n                    ya = i.renderExternalLink(va);\n                    za = o.JSBNG__find(ya, \"img\");\n                    JSBNG__Event.listen(za, \"load\", this._thumbLoaded.shield(this, za));\n                }\n                 else if (va.preview_url) {\n                    v.get(qa.author, function(ab) {\n                        var bb = v.getUserID(ab.id);\n                        ya = i.renderPreview(va, 0, null, qa, ab, bb);\n                        za = o.JSBNG__find(ya, \"img\");\n                        JSBNG__Event.listen(za, \"load\", this._thumbLoaded.shield(this, za));\n                    }.bind(this));\n                }\n                 else if (((wa == ra.SHARE))) {\n                    ya = i.renderShareLink(va);\n                }\n                \n                \n                \n                \n            ;\n            ;\n                if (ya) {\n                    o.appendContent(pa, ya);\n                }\n            ;\n            ;\n            };\n        ;\n        },\n        _thumbLoaded: function(pa) {\n            var qa = ((this.scrollContainer.scrollTop + this.scrollContainer.clientHeight));\n            if (((((qa + pa.offsetHeight)) >= this.scrollContainer.scrollHeight))) {\n                this.scrollToBottom();\n            }\n        ;\n        ;\n        }\n    });\n    w.subscribe(\"messages-reordered\", function(pa, qa) {\n        ma.forEach(function(ra) {\n            ((qa[ra.threadID] && ra.rerender()));\n        });\n    });\n    w.subscribe(\"messages-updated\", function(pa, qa) {\n        ma.forEach(function(ra) {\n            ((qa[ra.threadID] && ra.update(qa[ra.threadID])));\n        });\n    });\n    w.subscribe(\"messages-received\", function(pa, qa) {\n        ma.forEach(function(ra) {\n            var sa = qa[ra.threadID];\n            ((sa && ra._appendMessages(sa)));\n        });\n    });\n    g.subscribe(j.getArbiterType(\"chat_event\"), function(pa, qa) {\n        if (oa(qa.obj)) {\n            var ra = ((((q.user == qa.obj.from)) ? qa.obj.to : qa.obj.from)), sa = t.getThreadIdForUser(ra), ta = ma.filter(function(wa) {\n                return ((wa.threadID === sa));\n            });\n            if (((ta.length > 0))) {\n                var ua = ta[0], va = r.constructLogMessageObject(aa.MercurySourceType.CHAT_WEB, sa, aa.MercuryLogMessageType.VIDEO_CALL, qa.obj);\n                va.author = ((\"fbid:\" + qa.obj.from));\n                ua._appendMessages([va,]);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    });\n    function oa(pa) {\n        return ((((pa.event_name === \"installing\")) || ((pa.event_name === \"install_canceled\"))));\n    };\n;\n    e.exports = na;\n});\n__d(\"ChatTabSheetPolicy\", [], function(a, b, c, d, e, f) {\n    var g = {\n        canReplaceOpenSheet: function(h, i) {\n            if (((h.getType() == i.getType()))) {\n                return false;\n            }\n        ;\n        ;\n            if (((h.isPermanent() && !i.isPermanent()))) {\n                return false;\n            }\n        ;\n        ;\n            return true;\n        }\n    };\n    e.exports = g;\n});\n__d(\"ChatTabSheetView\", [\"event-extensions\",\"Animation\",\"ChatTabSheetPolicy\",\"CSS\",\"DOM\",\"Style\",\"Vector\",\"copyProperties\",\"ChatTabTemplates\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Animation\"), h = b(\"ChatTabSheetPolicy\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"Style\"), l = b(\"Vector\"), m = b(\"copyProperties\"), n = c(\"ChatTabTemplates\"), o = 5000, p = function(q, r, s) {\n        this._threadID = q;\n        this._rootElement = r;\n        this._tabMainElement = s;\n        this._openSheet = null;\n    };\n    m(p.prototype, {\n        destroy: function() {\n            j.empty(this._rootElement);\n        },\n        _openCommon: function(q, r) {\n            if (((this._openSheet && !h.canReplaceOpenSheet(this._openSheet, q)))) {\n                return;\n            }\n        ;\n        ;\n            this.clear(function() {\n                this._openSheet = q;\n                var s = n[\":fb:mercury:chat:tab-sheet:loading\"].build().getRoot();\n                j.setContent(this._rootElement, s);\n                i.show(s);\n                i.show(this._rootElement);\n                q.render();\n                if (r) {\n                    i.addClass(this._tabMainElement, \"sheetSlide\");\n                    var t = l.getElementDimensions(this._rootElement).y;\n                    k.set(this._rootElement, \"bottom\", ((t + \"px\")));\n                    this._animation = new g(this._rootElement).to(\"bottom\", 0).duration(150).ease(g.ease.both).JSBNG__ondone(function() {\n                        i.removeClass(this._tabMainElement, \"sheetSlide\");\n                    }.bind(this)).go();\n                }\n            ;\n            ;\n                if (!q.isPermanent()) {\n                    var u = o;\n                    if (q.getCloseTimeout) {\n                        u = q.getCloseTimeout();\n                    }\n                ;\n                ;\n                    this._sheetCloseHandler = this.close.bind(this, q).defer(u, false);\n                }\n            ;\n            ;\n            }.bind(this));\n        },\n        set: function(q) {\n            return this._openCommon(q, false);\n        },\n        open: function(q) {\n            return this._openCommon(q, true);\n        },\n        close: function(q, r) {\n            if (((this._openSheet != q))) {\n                return;\n            }\n        ;\n        ;\n            if (!this._openSheet) {\n                ((r && r()));\n                return;\n            }\n        ;\n        ;\n            if (this._animation) {\n                this._animation.JSBNG__stop();\n            }\n        ;\n        ;\n            if (this._sheetCloseHandler) {\n                JSBNG__clearTimeout(this._sheetCloseHandler);\n                this._sheetCloseHandler = null;\n            }\n        ;\n        ;\n            i.addClass(this._tabMainElement, \"sheetSlide\");\n            var s = l.getElementDimensions(this._rootElement).y;\n            this._animation = new g(this._rootElement).to(\"bottom\", ((s + \"px\"))).duration(100).ease(g.ease.begin).JSBNG__ondone(function() {\n                j.empty(this._rootElement);\n                i.hide(this._rootElement);\n                i.removeClass(this._tabMainElement, \"sheetSlide\");\n                this._openSheet = null;\n                ((r && r()));\n            }.bind(this)).go();\n        },\n        clear: function(q) {\n            this.close(this._openSheet, q);\n        }\n    });\n    e.exports = p;\n});\n__d(\"MercuryTypeahead\", [\"event-extensions\",\"ArbiterMixin\",\"DOM\",\"Env\",\"Input\",\"Tokenizer\",\"Typeahead\",\"TypeaheadCore\",\"copyProperties\",\"MercuryTypeaheadTemplates\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"DOM\"), i = b(\"Env\"), j = b(\"Input\"), k = b(\"Tokenizer\"), l = b(\"Typeahead\"), m = b(\"TypeaheadCore\"), n = b(\"copyProperties\"), o = c(\"MercuryTypeaheadTemplates\"), p = function(q, r) {\n        this._domElement = null;\n        this._typeahead = null;\n        this._tokenizer = null;\n        this._placeholder = \"\";\n        this._exclusions = [];\n        this._viewNodeID = null;\n        this._viewOptions = {\n            renderer: \"compact\",\n            autoSelect: true\n        };\n        this._tokenizerBehaviors = [];\n        this._dataSource = q;\n        this._view = r;\n    };\n    n(p.prototype, g);\n    n(p.prototype, {\n        setPlaceholder: function(q) {\n            this._placeholder = q;\n            return this;\n        },\n        setExcludedParticipants: function(q) {\n            this._exclusions = [];\n            q.forEach(function(r) {\n                var s = r.indexOf(\":\");\n                if (((r.substr(0, s) == \"fbid\"))) {\n                    this._exclusions.push(r.substr(((s + 1))));\n                }\n            ;\n            ;\n            }.bind(this));\n            return this;\n        },\n        setViewNodeID: function(q) {\n            this._viewNodeID = q;\n        },\n        setViewOption: function(q, r) {\n            this._viewOptions[q] = r;\n        },\n        addTokenizerBehavior: function(q) {\n            this._tokenizerBehaviors.push(q);\n        },\n        build: function(q) {\n            if (this._domElement) {\n                return;\n            }\n        ;\n        ;\n            var r = o[\":fb:mercury:tokenizer\"].build(), s = o[\":fb:mercury:typeahead\"].build();\n            this._domElement = r.getRoot();\n            h.appendContent(this._domElement, s.getRoot());\n            var t = s.getNode(\"textfield\");\n            j.setPlaceholder(t, this._placeholder);\n            t.setAttribute(\"data-placeholder\", this._placeholder);\n            var u = {\n                node_id: this._viewNodeID,\n                ctor: this._view,\n                options: this._viewOptions\n            }, v = {\n                ctor: m,\n                options: {\n                    setValueOnSelect: true\n                }\n            };\n            this._typeahead = new l(this._dataSource, u, v, s.getRoot());\n            this._typeahead.init();\n            var w = {\n                inline: true,\n                behaviors: this._tokenizerBehaviors\n            };\n            this._tokenizer = new k(this._domElement, this._typeahead);\n            this._tokenizer.init(r.getNode(\"tokenarea\"), \"participants\", [], w);\n            this._tokenizer.subscribe([\"addToken\",\"removeToken\",\"removeAllTokens\",], function() {\n                this.inform(\"tokens-changed\");\n            }.bind(this));\n            JSBNG__Event.listen(t, \"JSBNG__focus\", function() {\n                this._resetDataSource();\n                this._typeahead.init();\n            }.bind(this));\n            JSBNG__Event.listen(this._domElement, \"click\", this.JSBNG__focus.bind(this));\n        },\n        getElement: function() {\n            return this._domElement;\n        },\n        getSelectedParticipantIDs: function() {\n            var q = [];\n            if (this._tokenizer) {\n                ((this._tokenizer.getTokenValues() || [])).forEach(function(r) {\n                    q.push(((\"fbid:\" + r)));\n                });\n            }\n        ;\n        ;\n            return q;\n        },\n        getTokens: function() {\n            var q = [];\n            if (this._tokenizer) {\n                q = this._tokenizer.getTokens();\n            }\n        ;\n        ;\n            return q;\n        },\n        getTokenizer: function() {\n            return this._tokenizer;\n        },\n        reset: function() {\n            ((this._tokenizer && this._tokenizer.removeAllTokens()));\n            ((this._typeahead && this._typeahead.getCore().reset()));\n        },\n        JSBNG__focus: function() {\n            ((this._tokenizer && this._tokenizer.focusInput()));\n        },\n        getTypeahead: function() {\n            return this._typeahead;\n        },\n        _resetDataSource: function() {\n            this._dataSource.setExclusions(this._exclusions);\n        }\n    });\n    e.exports = p;\n});\n__d(\"MultiChatController\", [\"Arbiter\",\"AsyncSignal\",\"copyProperties\",\"Form\",\"MercuryMessages\",\"MercuryServerRequests\",\"MercuryThreads\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AsyncSignal\"), i = b(\"copyProperties\"), j = b(\"Form\"), k = b(\"MercuryMessages\"), l = b(\"MercuryServerRequests\"), m = b(\"MercuryThreads\");\n    function n() {\n    \n    };\n;\n    i(n, {\n        subscribe: function(o, p) {\n            o.subscribe(\"JSBNG__confirm\", function() {\n                this.createGroupThreadFromChooserDialog(o, p);\n            }.bind(this));\n        },\n        createGroupThreadFromChooserDialog: function(o, p) {\n            var q = j.serialize(o.getRoot()), r = JSON.parse(q.profileChooserItems), s = [];\n            for (var t in r) {\n                if (r[t]) {\n                    s.push(t);\n                }\n            ;\n            ;\n            };\n        ;\n            var u = n.createThreadForFBIDs(s);\n            l.subscribe(\"update-thread-ids\", function(v, w) {\n                for (var x in w) {\n                    if (((w[x] == u))) {\n                        new h(\"/ajax/groups/chat/log\", {\n                            group_id: p,\n                            message_id: x\n                        }).send();\n                    }\n                ;\n                ;\n                };\n            ;\n            });\n            o.hide();\n        },\n        createThreadForTokens: function(o) {\n            if (!o.length) {\n                return;\n            }\n        ;\n        ;\n            var p;\n            if (((o.length == 1))) {\n                p = ((\"user:\" + o[0].split(\":\")[1]));\n            }\n             else p = ((\"root:\" + k.generateNewClientMessageID((new JSBNG__Date()).getTime())));\n        ;\n        ;\n            m.createNewLocalThread(p, o);\n            g.inform(\"chat/open-tab\", {\n                thread_id: p\n            });\n            return p;\n        },\n        createThreadForFBIDs: function(o) {\n            var p = [];\n            for (var q = 0; ((q < o.length)); q++) {\n                p.push(((\"fbid:\" + o[q])));\n            ;\n            };\n        ;\n            return n.createThreadForTokens(p);\n        }\n    });\n    e.exports = n;\n});\n__d(\"ChatAddFriendsTabSheet\", [\"event-extensions\",\"Arbiter\",\"ChatTabSheetView\",\"ContextualTypeaheadView\",\"DOM\",\"MercuryTypeahead\",\"MercuryMessages\",\"MultiChatController\",\"MercuryServerRequests\",\"MercuryThreads\",\"copyProperties\",\"tx\",\"MercuryConstants\",\"MercuryDataSource\",\"ChatTabTemplates\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ChatTabSheetView\"), i = b(\"ContextualTypeaheadView\"), j = b(\"DOM\"), k = b(\"MercuryTypeahead\"), l = b(\"MercuryMessages\"), m = b(\"MultiChatController\"), n = b(\"MercuryServerRequests\"), o = b(\"MercuryThreads\"), p = b(\"copyProperties\"), q = c(\"MercuryConstants\"), r = c(\"MercuryDataSource\"), s = c(\"ChatTabTemplates\"), t = b(\"tx\");\n    function u(x, y, z) {\n        this._threadID = x;\n        this._rootElement = y;\n        this._sheetView = z;\n    };\n;\n    p(u.prototype, {\n        render: function() {\n            var x = s[\":fb:mercury:chat:tab-sheet:add-friends\"].build();\n            o.getThreadMeta(this._threadID, function(y) {\n                var z = new k(r, i);\n                z.setExcludedParticipants(y.participants);\n                z.setPlaceholder(\"Enter a friend's name\");\n                z.build();\n                j.replace(x.getNode(\"participantsTypeahead\"), z.getElement());\n                j.setContent(this._rootElement, x.getRoot());\n                z.JSBNG__focus();\n                var aa = y.participants, ba = ((y.is_canonical_user ? v.bind(null, this, this._sheetView, aa, z) : w.bind(null, this, this._sheetView, this._threadID, z)));\n                JSBNG__Event.listen(x.getNode(\"doneButton\"), \"click\", ba);\n            }.bind(this));\n        },\n        isPermanent: function() {\n            return true;\n        },\n        getType: function() {\n            return \"add_friends_type\";\n        },\n        open: function() {\n            this._sheetView.open(this);\n        }\n    });\n    function v(x, y, z, aa) {\n        var ba = aa.getSelectedParticipantIDs();\n        if (ba.length) {\n            m.createThreadForTokens(z.concat(ba));\n        }\n    ;\n    ;\n        y.close(x);\n    };\n;\n    function w(x, y, z, aa) {\n        var ba = aa.getSelectedParticipantIDs();\n        if (ba.length) {\n            if (o.isEmptyLocalThread(z)) {\n                o.addParticipantsToThreadLocally(z, ba);\n            }\n             else l.sendMessage(l.constructLogMessageObject(q.MercurySourceType.CHAT_WEB, z, q.MercuryLogMessageType.SUBSCRIBE, {\n                added_participants: ba\n            }));\n        ;\n        }\n    ;\n    ;\n        y.close(x);\n    };\n;\n    e.exports = u;\n});\n__d(\"ChatAvailabilityTabSheet\", [\"Arbiter\",\"AvailableList\",\"AvailableListConstants\",\"ChatConfig\",\"CSS\",\"DOM\",\"GenderConst\",\"MercuryThreads\",\"ShortProfiles\",\"copyProperties\",\"ChatTabTemplates\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AvailableList\"), i = b(\"AvailableListConstants\"), j = b(\"ChatConfig\"), k = b(\"CSS\"), l = b(\"DOM\"), m = b(\"GenderConst\"), n = b(\"MercuryThreads\"), o = b(\"ShortProfiles\"), p = b(\"copyProperties\"), q = c(\"ChatTabTemplates\");\n    function r(v, w, x, y) {\n        this._handledAvailability = w;\n        this._sheetView = y;\n        this._rootElement = x;\n        this._canonicalUser = n.getCanonicalUserInThread(v);\n        if (this._canonicalUser) {\n            this._currentAvailability = i.ACTIVE;\n            this._handleAvailabilityChange();\n            g.subscribe(i.ON_AVAILABILITY_CHANGED, this._handleAvailabilityChange.bind(this));\n        }\n    ;\n    ;\n    };\n;\n    r.createSheets = function(v, w, x) {\n        var y = {\n        };\n        if (j.get(\"roger.ui\")) {\n            y[i.OFFLINE] = new r(v, i.OFFLINE, w, x);\n            return y;\n        }\n    ;\n    ;\n        [i.ACTIVE,i.OFFLINE,i.MOBILE,].forEach(function(z) {\n            y[z] = new r(v, z, w, x);\n        });\n        return y;\n    };\n    p(r.prototype, {\n        render: function() {\n            !this._canonicalUser;\n            var v = q[\":fb:mercury:chat:tab-sheet:message-icon-sheet\"].build();\n            o.get(this._canonicalUser, function(w) {\n                var x = null;\n                switch (this._currentAvailability) {\n                  case i.ACTIVE:\n                    k.addClass(v.getRoot(), \"active\");\n                    x = s(w);\n                    break;\n                  case i.MOBILE:\n                    k.addClass(v.getRoot(), \"mobile\");\n                    x = t(w);\n                    break;\n                  case i.OFFLINE:\n                    x = u(w);\n                    break;\n                };\n            ;\n                l.setContent(v.getNode(\"text\"), x);\n                l.setContent(this._rootElement, v.getRoot());\n            }.bind(this));\n        },\n        isPermanent: function() {\n            return false;\n        },\n        getType: function() {\n            switch (this._handledAvailability) {\n              case i.ACTIVE:\n                return \"availability_active_type\";\n              case i.MOBILE:\n                return \"availability_mobile_type\";\n              case i.OFFLINE:\n                return \"availability_offline_type\";\n              default:\n                throw new Error(\"Invalid handled availability\");\n            };\n        ;\n        },\n        getCloseTimeout: function() {\n            return 5000;\n        },\n        _handleAvailabilityChange: function() {\n            var v = h.get(this._canonicalUser);\n            if (((v == this._currentAvailability))) {\n                return;\n            }\n        ;\n        ;\n            this._currentAvailability = v;\n            if (((v == this._handledAvailability))) {\n                this._sheetView.open(this);\n            }\n        ;\n        ;\n        }\n    });\n    function s(v) {\n        return l.tx._(\"{name} is now available.\", {\n            JSBNG__name: v.firstName\n        });\n    };\n;\n    function t(v) {\n        return l.tx._(\"Your messages will be sent to {name}'s phone.\", {\n            JSBNG__name: v.firstName\n        });\n    };\n;\n    function u(v) {\n        switch (v.gender) {\n          case m.FEMALE_SINGULAR:\n        \n          case m.FEMALE_SINGULAR_GUESS:\n            return l.tx._(\"{name} is offline, but you can still send her a message.\", {\n                JSBNG__name: v.firstName\n            });\n          case m.MALE_SINGULAR:\n        \n          case m.MALE_SINGULAR_GUESS:\n            return l.tx._(\"{name} is offline, but you can still send him a message.\", {\n                JSBNG__name: v.firstName\n            });\n          default:\n            return l.tx._(\"{name} is offline, but you can still send them a message.\", {\n                JSBNG__name: v.firstName\n            });\n        };\n    ;\n    };\n;\n    e.exports = r;\n});\n__d(\"ChatNoRecipientsTabSheet\", [\"DOM\",\"MercuryParticipants\",\"MercuryThreadInformer\",\"MercuryThreads\",\"copyProperties\",\"ChatTabTemplates\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"MercuryParticipants\"), i = b(\"MercuryThreadInformer\"), j = b(\"MercuryThreads\"), k = b(\"copyProperties\"), l = c(\"ChatTabTemplates\");\n    function m(n, o, p) {\n        this._threadID = n;\n        this._rootElement = o;\n        this._sheetView = p;\n        i.subscribe(\"threads-updated\", this._handleThreadsUpdated.bind(this));\n    };\n;\n    k(m.prototype, {\n        render: function() {\n            var n = l[\":fb:mercury:chat:tab-sheet:message-icon-sheet\"].build();\n            g.setContent(n.getNode(\"text\"), g.tx._(\"All recipients have left this conversation. Please close the stale tab.\"));\n            g.setContent(this._rootElement, n.getRoot());\n        },\n        isPermanent: function() {\n            return true;\n        },\n        getType: function() {\n            return \"no_recipients_type\";\n        },\n        _handleThreadsUpdated: function() {\n            j.getThreadMeta(this._threadID, function(n) {\n                var o = h.user, p = n.participants.filter(function(q) {\n                    return ((q != o));\n                });\n                if (((p.length < 1))) {\n                    this._sheetView.open(this);\n                }\n                 else this._sheetView.close(this);\n            ;\n            ;\n            }.bind(this));\n        }\n    });\n    e.exports = m;\n});\n__d(\"ChatOfflineTabSheet\", [\"event-extensions\",\"ChatPrivacyActionController\",\"ChatTabSheetView\",\"ChatVisibility\",\"CSS\",\"DOM\",\"JSLogger\",\"MercuryParticipants\",\"MercuryThreads\",\"copyProperties\",\"MercuryConfig\",\"ChatTabTemplates\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ChatPrivacyActionController\"), h = b(\"ChatTabSheetView\"), i = b(\"ChatVisibility\"), j = b(\"CSS\"), k = b(\"DOM\"), l = b(\"JSLogger\"), m = b(\"MercuryParticipants\"), n = b(\"MercuryThreads\"), o = b(\"copyProperties\"), o = b(\"copyProperties\"), p = c(\"MercuryConfig\"), q = c(\"ChatTabTemplates\");\n    function r(s, t, u) {\n        this._rootElement = t;\n        this._sheetView = u;\n        this._logger = l.create(\"blackbird\");\n        this._canonicalUser = n.getCanonicalUserInThread(s);\n        if (this._canonicalUser) {\n            this._privacyActionController = new g(this._canonicalUser, this._handlePrivacyChange.bind(this));\n        }\n    ;\n    ;\n    };\n;\n    o(r.prototype, {\n        render: function() {\n            if (!this._canonicalUser) {\n                this._logger.error(\"offline_sheet_open_with_non_friend\");\n                return;\n            }\n        ;\n        ;\n            var s = q[\":fb:mercury:chat:tab-sheet:message-icon-sheet\"].build(), t = ((\"fbid:\" + this._canonicalUser));\n            m.get(t, function(u) {\n                var v = \"fbChatGoOnlineLink\", w = ((p.ChatControlLanguageChangeGK ? k.tx._(\"turn on chat\") : k.tx._(\"go online\"))), x = k.create(\"a\", {\n                    href: \"#\",\n                    className: v\n                }, w), y;\n                if (p.ChatControlLanguageChangeGK) {\n                    y = k.tx._(\"To chat with {name} and other friends, {link}.\", {\n                        JSBNG__name: u.short_name,\n                        link: x\n                    });\n                }\n                 else y = k.tx._(\"You are now offline. To chat with {name} and other friends, {link}.\", {\n                    JSBNG__name: u.short_name,\n                    link: x\n                });\n            ;\n            ;\n                k.setContent(s.getNode(\"text\"), y);\n                j.addClass(s.getRoot(), \"chatOffline\");\n                k.setContent(this._rootElement, s.getRoot());\n                JSBNG__Event.listen(this._rootElement, \"click\", function(JSBNG__event) {\n                    if (j.hasClass(JSBNG__event.getTarget(), v)) {\n                        if (i.isOnline()) {\n                            this._logger.error(\"tab_sheet_already_online\");\n                        }\n                    ;\n                    ;\n                        this._privacyActionController.togglePrivacy();\n                        this._logger.log(\"tab_sheet_go_online\", {\n                            tab_id: this._canonicalUser\n                        });\n                        return false;\n                    }\n                ;\n                ;\n                }.bind(this));\n            }.bind(this));\n        },\n        _handlePrivacyChange: function(s) {\n            if (!this._canonicalUser) {\n                this._logger.error(\"user_blocked_sheet_privacy_changed_non_friend\");\n            }\n        ;\n        ;\n            switch (s) {\n              case g.OFFLINE:\n                this._sheetView.open(this);\n                break;\n              case g.NORMAL:\n            \n              case g.BLOCKED:\n                this._sheetView.close(this);\n                break;\n            };\n        ;\n        },\n        isPermanent: function() {\n            return true;\n        },\n        getType: function() {\n            return \"offline_type\";\n        },\n        destroy: function() {\n            ((this._privacyActionController && this._privacyActionController.destroy()));\n        }\n    });\n    e.exports = r;\n});\n__d(\"ChatUserBlockedTabSheet\", [\"event-extensions\",\"ChatPrivacyActionController\",\"ChatTabSheetView\",\"CSS\",\"DOM\",\"GenderConst\",\"JSLogger\",\"MercuryParticipants\",\"MercuryThreads\",\"copyProperties\",\"tx\",\"MercuryConfig\",\"ChatTabTemplates\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ChatPrivacyActionController\"), h = b(\"ChatTabSheetView\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"GenderConst\"), l = b(\"JSLogger\"), m = b(\"MercuryParticipants\"), n = b(\"MercuryThreads\"), o = b(\"copyProperties\"), p = c(\"MercuryConfig\"), q = c(\"ChatTabTemplates\"), r = b(\"tx\");\n    function s(t, u, v) {\n        this._rootElement = u;\n        this._sheetView = v;\n        this._logger = l.create(\"blackbird\");\n        this._canonicalUser = n.getCanonicalUserInThread(t);\n        if (this._canonicalUser) {\n            this._privacyActionController = new g(this._canonicalUser, this._handlePrivacyChange.bind(this));\n        }\n    ;\n    ;\n    };\n;\n    o(s.prototype, {\n        render: function() {\n            if (!this._canonicalUser) {\n                this._logger.error(\"user_blocked_sheet_open_with_non_friend\");\n                return;\n            }\n        ;\n        ;\n            var t = q[\":fb:mercury:chat:tab-sheet:user-blocked\"].build(), u = ((\"fbid:\" + this._canonicalUser));\n            m.get(u, function(v) {\n                var w = null;\n                switch (v.gender) {\n                  case k.FEMALE_SINGULAR:\n                \n                  case k.FEMALE_SINGULAR_GUESS:\n                    w = ((p.ChatControlLanguageChangeGK ? r._(\"You turned off chat for {name} but you can still send her a message. \", {\n                        JSBNG__name: v.short_name\n                    }) : r._(\"{name} sees you as offline on chat, but you can still send her a message. \", {\n                        JSBNG__name: v.short_name\n                    })));\n                    break;\n                  case k.MALE_SINGULAR:\n                \n                  case k.MALE_SINGULAR_GUESS:\n                    w = ((p.ChatControlLanguageChangeGK ? r._(\"You turned off chat for {name} but you can still send him a message. \", {\n                        JSBNG__name: v.short_name\n                    }) : r._(\"{name} sees you as offline on chat, but you can still send him a message. \", {\n                        JSBNG__name: v.short_name\n                    })));\n                    break;\n                  default:\n                    w = ((p.ChatControlLanguageChangeGK ? r._(\"You turned off chat for {name} but you can still send them a message. \", {\n                        JSBNG__name: v.short_name\n                    }) : r._(\"{name} sees you as offline on chat, but you can still send them a message. \", {\n                        JSBNG__name: v.short_name\n                    })));\n                };\n            ;\n                j.setContent(t.getNode(\"text\"), w);\n                var x = ((p.ChatControlLanguageChangeGK ? r._(\"Turn on chat for {name}?\", {\n                    JSBNG__name: v.short_name\n                }) : r._(\"Go Online to {name}\", {\n                    JSBNG__name: v.short_name\n                })));\n                j.setContent(t.getNode(\"actionLink\"), x);\n                i.addClass(t.getRoot(), \"blocked\");\n                j.setContent(this._rootElement, t.getRoot());\n                JSBNG__Event.listen(t.getNode(\"actionLink\"), \"click\", this._privacyActionController.togglePrivacy.bind(this._privacyActionController));\n            }.bind(this));\n        },\n        _handlePrivacyChange: function(t) {\n            if (!this._canonicalUser) {\n                this._logger.error(\"user_blocked_sheet_privacy_changed_non_friend\");\n            }\n        ;\n        ;\n            switch (t) {\n              case g.BLOCKED:\n                this._sheetView.open(this);\n                break;\n              case g.NORMAL:\n            \n              case g.OFFLINE:\n                this._sheetView.close(this);\n                break;\n            };\n        ;\n        },\n        isPermanent: function() {\n            return true;\n        },\n        getType: function() {\n            return \"user_blocked_type\";\n        },\n        destroy: function() {\n            ((this._privacyActionController && this._privacyActionController.destroy()));\n        }\n    });\n    e.exports = s;\n});\n__d(\"ChatTabSheetController\", [\"ChatAddFriendsTabSheet\",\"ChatAvailabilityTabSheet\",\"ChatNoRecipientsTabSheet\",\"ChatOfflineTabSheet\",\"ChatTabSheetView\",\"ChatUserBlockedTabSheet\",\"copyProperties\",\"MercuryServerRequests\",\"MercuryThreads\",], function(a, b, c, d, e, f) {\n    var g = b(\"ChatAddFriendsTabSheet\"), h = b(\"ChatAvailabilityTabSheet\"), i = b(\"ChatNoRecipientsTabSheet\"), j = b(\"ChatOfflineTabSheet\"), k = b(\"ChatTabSheetView\"), l = b(\"ChatUserBlockedTabSheet\"), m = b(\"copyProperties\"), n = b(\"MercuryServerRequests\"), o = b(\"MercuryThreads\"), p = function(q, r, s) {\n        this._sheetView = new k(q, r, s);\n        this._addFriendsTabSheet = new g(q, r, this._sheetView);\n        this._userBlockedTabSheet = new l(q, r, this._sheetView);\n        this._offlineTabSheet = new j(q, r, this._sheetView);\n        this._availabilityTabSheets = h.createSheets(q, r, this._sheetView);\n        if (o.isMultichatThread(q)) {\n            this._noRecipientsTabSheet = new i(q, r, this._sheetView);\n        }\n    ;\n    ;\n    };\n    m(p.prototype, {\n        openAddFriendsSheet: function() {\n            this._addFriendsTabSheet.open();\n        },\n        destroy: function() {\n            this._sheetView.destroy();\n            this._offlineTabSheet.destroy();\n            this._userBlockedTabSheet.destroy();\n        }\n    });\n    e.exports = p;\n});\n__d(\"ChatTabView\", [\"event-extensions\",\"function-extensions\",\"Arbiter\",\"ArbiterMixin\",\"AsyncDialog\",\"AsyncRequest\",\"AvailableList\",\"AvailableListConstants\",\"ChatConfig\",\"ChatContextualDialogController\",\"ChatQuietLinks\",\"ChatPrivacyActionController\",\"MessagesEmoticonView\",\"ChatTabMessagesView\",\"ChatTabSheetController\",\"ChatVisibility\",\"CSS\",\"Dialog\",\"Dock\",\"DOM\",\"JSLogger\",\"Keys\",\"MercuryMessages\",\"MercuryParticipants\",\"MercuryServerRequests\",\"MercuryThreadInformer\",\"MercuryThreadMetadataRenderer\",\"MercuryThreads\",\"MercuryTypingReceiver\",\"NubController\",\"Parent\",\"PresencePrivacy\",\"Style\",\"TextAreaControl\",\"Tooltip\",\"TypingIndicator\",\"URI\",\"UserAgent\",\"VideoCallCore\",\"copyProperties\",\"setIntervalAcrossTransitions\",\"tx\",\"MercuryConfig\",\"MercuryConstants\",\"ChatTabTemplates\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"AsyncDialog\"), j = b(\"AsyncRequest\"), k = b(\"AvailableList\"), l = b(\"AvailableListConstants\"), m = b(\"ChatConfig\"), n = b(\"ChatContextualDialogController\"), o = b(\"ChatQuietLinks\"), p = b(\"ChatPrivacyActionController\"), q = b(\"MessagesEmoticonView\"), r = b(\"ChatTabMessagesView\"), s = b(\"ChatTabSheetController\"), t = b(\"ChatVisibility\"), u = b(\"CSS\"), v = b(\"Dialog\"), w = b(\"Dock\"), x = b(\"DOM\"), y = b(\"JSLogger\"), z = b(\"Keys\"), aa = b(\"MercuryMessages\"), ba = b(\"MercuryParticipants\"), ca = b(\"MercuryServerRequests\"), da = b(\"MercuryThreadInformer\"), ea = b(\"MercuryThreadMetadataRenderer\"), fa = b(\"MercuryThreads\"), ga = b(\"MercuryTypingReceiver\"), ha = b(\"NubController\"), ia = b(\"Parent\"), ja = b(\"PresencePrivacy\"), ka = b(\"Style\"), la = b(\"TextAreaControl\"), ma = b(\"Tooltip\"), na = b(\"TypingIndicator\"), oa = b(\"URI\"), pa = b(\"UserAgent\"), qa = b(\"VideoCallCore\"), ra = c(\"MercuryConfig\"), sa = c(\"MercuryConstants\"), ta = c(\"ChatTabTemplates\"), ua = b(\"copyProperties\"), va = b(\"setIntervalAcrossTransitions\"), wa = b(\"tx\"), xa = y.create(\"tab_view\"), ya = {\n    };\n    function za(ib, jb) {\n        var kb = x.create(\"div\");\n        jb = jb.filter(function(lb) {\n            return ((lb != ba.user));\n        });\n        ba.getMulti(jb, function(lb) {\n            for (var mb in lb) {\n                var nb = lb[mb], ob = ta[\":fb:mercury:chat:multichat-tooltip-item\"].build();\n                x.setContent(ob.getNode(\"JSBNG__name\"), nb.JSBNG__name);\n                var pb = ba.getUserID(mb), qb = ((pb && ((k.get(pb) == l.ACTIVE))));\n                u.conditionShow(ob.getNode(\"icon\"), qb);\n                u.conditionClass(ob.getNode(\"JSBNG__name\"), \"tooltipItemWithIcon\", qb);\n                x.appendContent(kb, ob.getRoot());\n            };\n        ;\n            ma.set(ib, kb, \"above\", \"center\");\n        });\n    };\n;\n    var ab = {\n    }, bb = null, cb = false;\n    function db(ib, jb, kb) {\n        if (kb) {\n            ab[ib] = jb;\n            if (!bb) {\n                bb = va(eb, 600);\n            }\n        ;\n        ;\n        }\n         else {\n            u.removeClass(jb, \"highlightTitle\");\n            delete ab[ib];\n        }\n    ;\n    ;\n    };\n;\n    function eb() {\n        for (var ib in ab) {\n            var jb = ab[ib];\n            if (jb.parentNode) {\n                u.conditionClass(jb, \"highlightTitle\", cb);\n            }\n             else delete ab[ib];\n        ;\n        ;\n        };\n    ;\n        cb = !cb;\n        if (!Object.keys(ab).length) {\n            JSBNG__clearInterval(bb);\n            bb = null;\n        }\n    ;\n    ;\n    };\n;\n    function fb(ib) {\n        var jb = ca.tokenizeThreadID(ib);\n        switch (jb.type) {\n          case \"user\":\n            return ta[\":fb:mercury:chat:user-tab\"].build();\n          case \"group\":\n            return ta[\":fb:mercury:chat:group-tab\"].build();\n        };\n    ;\n        return ta[\":fb:mercury:chat:multichat-tab\"].build();\n    };\n;\n    function gb(ib, jb) {\n        if (jb) {\n            ca.ensureThreadIsFetched(jb);\n        }\n    ;\n    ;\n        this._threadID = ib;\n        this._eventListeners = [];\n        this._tabTemplate = fb(ib);\n        this._tabElem = this._tabTemplate.getRoot();\n        if (!((this._getNode instanceof Function))) {\n            xa.log(\"getnode_undefined\", {\n                is_getnode_set: !!this._getNode,\n                is_prototype_set: !!gb.prototype,\n                is_window: ((window == this)),\n                is_chat_tab_view: ((this instanceof gb)),\n                ctor_name: ((this.constructor && this.constructor.JSBNG__name))\n            });\n        }\n    ;\n    ;\n        this._sheetController = new s(this._threadID, this._getNode(\"sheet\"), this._tabElem);\n        this._contextualDialogController = new n(this._threadID, this._getNode(\"videoCallLink\"));\n        this._messagesView = null;\n        var kb = this._getNode(\"conversationLink\");\n        if (kb) {\n            u.hide(kb);\n            ea.renderTitanLink(ib, kb, u.show.bind(u, kb));\n        }\n    ;\n    ;\n        if (fa.isMultichatThread(this._threadID)) {\n            this._titlebarTooltipAnchor = this._getNode(\"titlebarText\");\n        }\n    ;\n    ;\n        var lb = this._getCanonicalUserID();\n        if (this._isTitleTextLinked()) {\n            ba.get(((\"fbid:\" + lb)), function(pb) {\n                var qb = this._getNode(\"titlebarText\");\n                qb.setAttribute(\"href\", pb.href);\n                qb.removeAttribute(\"rel\");\n                u.removeClass(qb, \"noLink\");\n            }.bind(this));\n        }\n    ;\n    ;\n        this._nubController = new ha().init(this._tabElem);\n        la.getInstance(this._getNode(\"input\")).subscribe(\"resize\", function() {\n            this._nubController.flyoutContentChanged();\n        }.bind(this));\n        this._nubController.subscribe(\"resize\", function() {\n            this._emoticonsNode.style.left = ((((this._getNode(\"input\").clientWidth + 3)) + \"px\"));\n            la.getInstance(this._getNode(\"input\")).update();\n        }.bind(this));\n        this._listen(\"closeButton\", \"click\", this._closeClicked);\n        this._listen(\"titlebarCloseButton\", \"click\", this._closeClicked);\n        this._listen(\"dockButton\", \"click\", this._nubClicked);\n        this._listen(\"dockButton\", \"keydown\", this._dockKeyDown);\n        this._listen(\"nubFlyoutTitlebar\", \"click\", this._titleClicked);\n        this._listen(\"chatConv\", \"click\", this._chatConvClicked);\n        this._listen(\"addFriendLink\", \"click\", this._addFriendLinkClicked, true);\n        this._listen(\"addToThreadLink\", \"click\", this._addFriendLinkClicked, true);\n        this._listen(\"clearWindowLink\", \"click\", this._clearHistory, true);\n        this._listen(\"unsubscribeLink\", \"click\", this._unsubscribeLinkClicked, true);\n        this._listen(\"videoCallLink\", \"click\", this._callClicked, true);\n        this._listen(\"reportSpamLink\", \"click\", this._reportSpamClicked, true);\n        this._listen(\"input\", \"JSBNG__focus\", this._focusTab);\n        this._listen(\"input\", \"JSBNG__blur\", this._blurTab);\n        this._emoticonsNode = this._getNode(\"emoticons\");\n        this._emoticonView = new q(this._emoticonsNode, this._getNode(\"input\"));\n        if (pa.firefox()) {\n            this._listen(\"input\", \"keypress\", this._inputKeyDown);\n        }\n         else this._listen(\"input\", \"keydown\", this._inputKeyDown);\n    ;\n    ;\n        this._privacyLink = this._getNode(\"privacyLink\");\n        if (this._privacyLink) {\n            this._privacyActionController = new p(lb, this._updatePrivacyLink.bind(this));\n            this._eventListeners.push(JSBNG__Event.listen(this._privacyLink, \"click\", this._privacyActionController.togglePrivacy.bind(this._privacyActionController)));\n        }\n    ;\n    ;\n        var mb = ((lb || ((m.get(\"chat_multi_typ_send\") && fa.isMultichatThread(this._threadID)))));\n        if (mb) {\n            ca.getServerThreadID(this._threadID, function(pb) {\n                this._typingIndicator = new na(lb, this._getNode(\"input\"), \"mercury-chat\", null, pb);\n            }.bind(this));\n        }\n    ;\n    ;\n        var nb = this._getNode(\"muteGroupLink\");\n        if (nb) {\n            var ob = fa.getCanonicalGroupInThread(this._threadID);\n            if (ob) {\n                nb.setAttribute(\"ajaxify\", oa(nb.getAttribute(\"ajaxify\")).addQueryData({\n                    id: ob\n                }));\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        o.removeEmptyHrefs(this._tabElem);\n        ya[ib] = this;\n        this.updateAvailableStatus();\n        this.updateTab();\n    };\n;\n    function hb() {\n        for (var ib in ya) {\n            ya[ib].updateAvailableStatus();\n            ya[ib].updateMultichatTooltip();\n        };\n    ;\n    };\n;\n    g.subscribe([\"buddylist/availability-changed\",], hb);\n    ja.subscribe([\"privacy-changed\",\"privacy-availability-changed\",], hb);\n    ga.subscribe(\"state-changed\", function(ib, jb) {\n        for (var kb in jb) {\n            var lb = ((jb[kb] && jb[kb].length)), mb = ya[kb];\n            ((mb && mb.showTypingIndicator(lb)));\n        };\n    ;\n    });\n    da.subscribe(\"threads-updated\", function(ib, jb) {\n        for (var kb in ya) {\n            ((jb[kb] && ya[kb].updateTab()));\n        ;\n        };\n    ;\n    });\n    da.subscribe(\"threads-deleted\", function(ib, jb) {\n        for (var kb in ya) {\n            gb.inform(\"thread-deleted\", kb);\n        ;\n        };\n    ;\n    });\n    ua(gb, h, {\n        get: function(ib) {\n            return ya[ib];\n        }\n    });\n    ua(gb.prototype, {\n        getThreadID: function() {\n            return this._threadID;\n        },\n        isVisible: function() {\n            return u.shown(this._tabElem);\n        },\n        setVisibleState: function(ib, jb) {\n            var kb = u.shown(this._tabElem), lb = u.hasClass(this._tabElem, \"opened\");\n            u.conditionShow(this._tabElem, ib);\n            u.conditionClass(this._tabElem, \"opened\", jb);\n            if (((((!((kb && lb)) && ib)) && jb))) {\n                if (!this._messagesView) {\n                    this._messagesView = new r(this._threadID, this._getNode(\"chatConv\"), this._getNode(\"conversation\"), this._getNode(\"typingIndicator\"));\n                }\n            ;\n            ;\n                this._nubController.flyoutContentChanged();\n                this._messagesView.scrollToBottom();\n            }\n        ;\n        ;\n            if (((((kb && lb)) && !((ib && jb))))) {\n                this._contextualDialogController.tabNotActive();\n            }\n        ;\n        ;\n        },\n        JSBNG__focus: function() {\n            var ib = ((u.hasClass(this._tabElem, \"opened\") ? \"input\" : \"dockButton\"));\n            this._getNode(ib).JSBNG__focus();\n        },\n        isFocused: function() {\n            var ib = JSBNG__document.activeElement;\n            return ((ia.byClass(ib, \"fbMercuryChatTab\") === this._tabElem));\n        },\n        setInput: function(ib) {\n            this._getNode(\"input\").value = ib;\n        },\n        insertBefore: function(ib) {\n            x.insertBefore(ib._tabElem, this._tabElem);\n        },\n        appendTo: function(ib) {\n            x.appendContent(ib, this._tabElem);\n        },\n        nextTabIs: function(ib) {\n            var jb = ((ib && ib._tabElem));\n            return ((this._tabElem.nextSibling == jb));\n        },\n        destroy: function() {\n            x.remove(this._tabElem);\n            ((this._emoticonView && this._emoticonView.destroy()));\n            while (this._eventListeners.length) {\n                this._eventListeners.pop().remove();\n            ;\n            };\n        ;\n            ((this._messagesView && this._messagesView.destroy()));\n            this._sheetController.destroy();\n            this._contextualDialogController.destroy();\n            ((this._privacyActionController && this._privacyActionController.destroy()));\n            delete ya[this._threadID];\n            w.unregisterNubController(this._nubController);\n        },\n        updateAvailableStatus: function() {\n            var ib = {\n                active: false,\n                mobile: false,\n                greenphone: false\n            }, jb = this._getCanonicalUserID(), kb = true, lb = false;\n            if (jb) {\n                var mb = k.get(jb);\n                kb = !t.isOnline();\n                lb = !ja.allows(jb);\n                ib.active = ((mb === l.ACTIVE));\n                if (m.get(\"sidebar_mobile_icon_green\")) {\n                    ib.greenphone = ((mb === l.MOBILE));\n                }\n                 else ib.mobile = ((mb === l.MOBILE));\n            ;\n            ;\n                this._updateCallLink(mb);\n            }\n        ;\n        ;\n            u.conditionClass(this._tabElem, \"chatOffline\", kb);\n            u.conditionClass(this._tabElem, \"blocked\", ((!kb && lb)));\n            for (var nb in ib) {\n                u.conditionClass(this._tabElem, nb, ((((!kb && !lb)) && ib[nb])));\n            ;\n            };\n        ;\n        },\n        updateTab: function() {\n            fa.getThreadMeta(this._threadID, function(ib) {\n                if (!ib.is_subscribed) {\n                    gb.inform(\"unsubscribed\", this._threadID);\n                    return;\n                }\n            ;\n            ;\n                ea.renderAndSeparatedParticipantList(this._threadID, [this._getNode(\"JSBNG__name\"),this._getNode(\"titlebarText\"),], {\n                    names_renderer: ea.renderShortNames,\n                    check_length: true\n                });\n                this._updateUnreadCount(ib);\n                this.updateMultichatTooltip();\n                this._updateArchiveWarning(ib);\n            }.bind(this));\n        },\n        _updateArchiveWarning: function(ib) {\n            var jb = false;\n            ba.get(ba.user, function(kb) {\n                jb = kb.employee;\n                if (jb) {\n                    ba.getMulti(ib.participants, this._showArchiveWarningIfAllParticipantsAreEmployees.bind(this));\n                }\n            ;\n            ;\n            }.bind(this));\n        },\n        _showArchiveWarningIfAllParticipantsAreEmployees: function(ib) {\n            var jb = true;\n            for (var kb in ib) {\n                jb = ((jb && ib[kb].employee));\n            ;\n            };\n        ;\n            var lb = this._getNode(\"titanArchiveWarning\");\n            if (lb) {\n                if (this._titlebarTooltipAnchor) {\n                    u.conditionClass(this._titlebarTooltipAnchor, \"narrowTitleBar\", jb);\n                }\n            ;\n            ;\n                u.conditionShow(lb, jb);\n            }\n        ;\n        ;\n        },\n        updateMultichatTooltip: function() {\n            if (fa.isMultichatThread(this._threadID)) {\n                fa.getThreadMeta(this._threadID, function(ib) {\n                    za(this._titlebarTooltipAnchor, ib.participants);\n                }.bind(this));\n            }\n        ;\n        ;\n        },\n        _getNode: function(ib) {\n            return this._tabTemplate.getNode(ib);\n        },\n        _getCanonicalUserID: function() {\n            return fa.getCanonicalUserInThread(this._threadID);\n        },\n        _listen: function(ib, JSBNG__event, jb, kb) {\n            var lb = this._getNode(ib);\n            if (lb) {\n                this._eventListeners.push(JSBNG__Event.listen(lb, JSBNG__event, jb.bind(this)));\n            }\n             else if (!kb) {\n                throw new Error(((((\"Could not find node \\\"\" + ib)) + \"\\\"\")));\n            }\n            \n        ;\n        ;\n        },\n        _closeClicked: function(ib) {\n            gb.inform(\"closed-tab\", this._threadID);\n            ib.prevent();\n        },\n        _nubClicked: function() {\n            return gb.inform(\"nub-activated\", this._threadID);\n        },\n        _dockKeyDown: function(JSBNG__event) {\n            if (((((JSBNG__event.keyCode === z.RETURN)) || ((JSBNG__event.keyCode === z.SPACE))))) {\n                gb.inform(\"nub-activated\", this._threadID);\n                JSBNG__event.kill();\n            }\n             else this._handleHotkeyPressed(JSBNG__event);\n        ;\n        ;\n        },\n        _handleHotkeyPressed: function(JSBNG__event) {\n            if (((JSBNG__event.keyCode === z.ESC))) {\n                gb.inform(\"esc-pressed\", this._threadID);\n                JSBNG__event.kill();\n            }\n             else if (((JSBNG__event.keyCode === z.TAB))) {\n                var ib = gb.inform(\"tab-pressed\", {\n                    id: this._threadID,\n                    shiftPressed: JSBNG__event.shiftKey\n                });\n                ((!ib && JSBNG__event.kill()));\n            }\n            \n        ;\n        ;\n        },\n        _isTitleTextLinked: function() {\n            var ib = this._getCanonicalUserID();\n            return ((ib && m.get(\"chat_tab_title_link_timeline\")));\n        },\n        _titleClicked: function(JSBNG__event) {\n            var ib = JSBNG__event.getTarget(), jb = ia.byClass(ib, \"titlebarText\"), kb = ((jb && this._isTitleTextLinked()));\n            if (((((!kb && !ia.byClass(ib, \"uiSelector\"))) && !ia.byClass(ib, \"addToThread\")))) {\n                gb.inform(\"lower-activated\", this._threadID);\n            }\n        ;\n        ;\n        },\n        _callClicked: function(ib) {\n            var jb = this._getCanonicalUserID();\n            if (qa.availableForCall(jb)) {\n                var kb = \"chat_tab_icon\";\n                if (((ib.target && u.hasClass(ib.target, \"video_call_promo\")))) {\n                    kb = \"chat_tab_icon_promo\";\n                }\n                 else if (((ib.target && u.hasClass(ib.target, \"video_call_tour\")))) {\n                    kb = \"chat_tab_icon_tour\";\n                }\n                \n            ;\n            ;\n                gb.inform(\"video-call-clicked\", {\n                    threadID: this._threadID,\n                    userID: jb,\n                    clickSource: kb\n                });\n            }\n        ;\n        ;\n            return false;\n        },\n        _addFriendLinkClicked: function() {\n            this._sheetController.openAddFriendsSheet();\n        },\n        _clearHistory: function() {\n            var ib = fa.getThreadMetaNow(this._threadID);\n            if (ib) {\n                var jb = this._getCanonicalUserID();\n                ca.clearChat(this._threadID, jb, ib.timestamp);\n            }\n        ;\n        ;\n        },\n        _unsubscribeLinkClicked: function() {\n            var ib = [];\n            ib.push({\n                JSBNG__name: \"unsubscribe\",\n                label: \"Leave Conversation\",\n                handler: this._unsubscribeToThread.bind(this)\n            });\n            ib.push(v.CANCEL);\n            new v().setTitle(\"Leave Conversation?\").setBody(\"You will stop receiving messages from this conversation and people will see that you left.\").setButtons(ib).show();\n        },\n        _reportSpamClicked: function() {\n            var ib = this._getCanonicalUserID(), jb = oa(\"/ajax/chat/report.php\").addQueryData({\n                id: ib\n            }).addQueryData({\n                src: \"top_report_link\"\n            });\n            i.send(new j(jb));\n        },\n        _focusTab: function() {\n            u.addClass(this._tabElem, \"focusedTab\");\n            gb.inform(\"focused\", this._threadID);\n            this._contextualDialogController.tabFocused();\n        },\n        _blurTab: function() {\n            u.removeClass(this._tabElem, \"focusedTab\");\n        },\n        _inputKeyDown: function(JSBNG__event) {\n            if (((((JSBNG__event.keyCode === z.RETURN)) && !JSBNG__event.shiftKey))) {\n                var ib = this._getNode(\"input\"), jb = ((ib.value || \"\"));\n                if (!/^\\s*$/.test(jb)) {\n                    fa.getThreadMeta(this._threadID, function(kb) {\n                        var lb = aa.constructUserGeneratedMessageObject(jb, sa.MercurySourceType.CHAT_WEB, this._threadID);\n                        if (fa.isEmptyLocalThread(this._threadID)) {\n                            var mb = ca.tokenizeThreadID(this._threadID);\n                            lb.message_id = mb.value;\n                            lb.specific_to_list = kb.participants;\n                        }\n                    ;\n                    ;\n                        aa.sendMessage(lb);\n                        this._getNode(\"input\").value = \"\";\n                        ((this._typingIndicator && this._typingIndicator.resetState()));\n                    }.bind(this));\n                }\n            ;\n            ;\n                JSBNG__event.kill();\n            }\n        ;\n        ;\n            if (((((((JSBNG__event.keyCode === z.DOWN)) && JSBNG__event.shiftKey)) && ((this._getNode(\"input\").value === \"\"))))) {\n                gb.inform(\"lower-activated\", this._threadID);\n                JSBNG__event.kill();\n                return;\n            }\n        ;\n        ;\n            this._handleHotkeyPressed(JSBNG__event);\n        },\n        _chatConvClicked: function() {\n            ((!x.JSBNG__getSelection() && this.JSBNG__focus()));\n        },\n        showTypingIndicator: function(ib) {\n            var jb = ((this._getCanonicalUserID() || ((m.get(\"chat_multi_typ\") && fa.isMultichatThread(this._threadID)))));\n            if (jb) {\n                u.conditionClass(this._tabElem, \"typing\", ib);\n            }\n        ;\n        ;\n        },\n        _updateUnreadCount: function(ib) {\n            var jb = ib.unread_count;\n            if (((typeof jb != \"undefined\"))) {\n                var kb = this._getNode(\"numMessages\");\n                u.conditionShow(kb, jb);\n                u.conditionClass(this._tabElem, \"highlightTab\", jb);\n                db(this._threadID, this._tabElem, !!jb);\n                x.setContent(kb, jb);\n            }\n        ;\n        ;\n        },\n        _updateCallLink: function(ib) {\n            var jb = this._getNode(\"videoCallLink\");\n            if (t.isOnline()) {\n                var kb = this._getCanonicalUserID(), lb = ((\"fbid:\" + kb));\n                ba.get(lb, function(mb) {\n                    if (qa.availableForCall(kb)) {\n                        ma.set(jb, wa._(\"Start a video call with {firstname}\", {\n                            firstname: mb.short_name\n                        }));\n                        this._updateCallBackLinks(this._tabElem, true);\n                    }\n                     else {\n                        ma.set(jb, wa._(\"{firstname} is currently unavailable for video calling\", {\n                            firstname: mb.short_name\n                        }));\n                        this._hideVideoCallouts();\n                        this._updateCallBackLinks(this._tabElem, false);\n                    }\n                ;\n                ;\n                }.bind(this));\n            }\n             else {\n                ma.set(jb, \"You must be online to make a call.\");\n                this._hideVideoCallouts();\n                this._updateCallBackLinks(JSBNG__document.body, false);\n            }\n        ;\n        ;\n        },\n        _updateCallBackLinks: function(ib, jb) {\n            var kb = x.scry(ib, \"a.callBackLink\");\n            if (jb) {\n                kb.forEach(u.show);\n            }\n             else kb.forEach(u.hide);\n        ;\n        ;\n        },\n        _hideVideoCallouts: function() {\n            this._contextualDialogController.hideVideoCallouts();\n        },\n        _updatePrivacyLink: function(ib) {\n            if (((ib == p.OFFLINE))) {\n                x.setContent(this._privacyLink, \"Go online\");\n            }\n             else {\n                var jb = this._getCanonicalUserID(), kb = ((\"fbid:\" + jb));\n                ba.get(kb, function(lb) {\n                    var mb = null;\n                    if (((ib == p.BLOCKED))) {\n                        if (ra.ChatControlLanguageChangeGK) {\n                            mb = wa._(\"Turn On Chat for {name}\", {\n                                JSBNG__name: lb.short_name\n                            });\n                        }\n                         else mb = wa._(\"Go Online to {name}\", {\n                            JSBNG__name: lb.short_name\n                        });\n                    ;\n                    ;\n                    }\n                     else if (ra.ChatControlLanguageChangeGK) {\n                        mb = wa._(\"Turn Off Chat for {name}\", {\n                            JSBNG__name: lb.short_name\n                        });\n                    }\n                     else mb = wa._(\"Go Offline to {name}\", {\n                        JSBNG__name: lb.short_name\n                    });\n                    \n                ;\n                ;\n                    x.setContent(this._privacyLink, mb);\n                }.bind(this));\n            }\n        ;\n        ;\n        },\n        _unsubscribeToThread: function() {\n            if (fa.isEmptyLocalThread(this._threadID)) {\n                gb.inform(\"unsubscribed\", this._threadID);\n            }\n             else {\n                var ib = aa.constructLogMessageObject(sa.MercurySourceType.CHAT_WEB, this._threadID, sa.MercuryLogMessageType.UNSUBSCRIBE, {\n                });\n                aa.sendMessage(ib);\n            }\n        ;\n        ;\n            return true;\n        },\n        _emoticonView: null\n    });\n    e.exports = gb;\n});\n__d(\"ChatNewMessageHandler\", [\"ChatActivity\",\"ChatTabModel\",\"ChatTabView\",\"JSLogger\",\"MercuryAssert\",\"MercuryBrowserAlerts\",\"MercuryThreads\",\"MercuryUnseenState\",], function(a, b, c, d, e, f) {\n    var g = b(\"ChatActivity\"), h = b(\"ChatTabModel\"), i = b(\"ChatTabView\"), j = b(\"JSLogger\"), k = b(\"MercuryAssert\"), l = b(\"MercuryBrowserAlerts\"), m = b(\"MercuryThreads\"), n = b(\"MercuryUnseenState\"), o = j.create(\"chat_new_message\"), p = {\n        _raiseTab: function(q, r) {\n            var s = h.getTab(q), t = false;\n            if (s) {\n                t = s.raised;\n            }\n             else {\n                h.raiseTab(q, false);\n                t = true;\n            }\n        ;\n        ;\n            r.to_new_tab = !s;\n            r.to_raised_tab = !!t;\n        },\n        _notify: function(q, r, s) {\n            var t = i.get(q);\n            s.view_is_visible = ((t && t.isVisible()));\n            s.view_is_focused = ((t && t.isFocused()));\n            if (!s.view_is_visible) {\n                o.log(\"message_to_hidden\");\n            }\n        ;\n        ;\n            s.is_active = g.isActive();\n            l.messageReceived(r);\n        },\n        newMessage: function(q, r) {\n            k.isThreadID(q);\n            var s = {\n                thread_id: q,\n                message_id: r.message_id\n            };\n            this._raiseTab(q, s);\n            this._notify(q, r, s);\n            o.log(\"message\", s);\n        }\n    };\n    l.subscribe(\"before-alert\", function(q, JSBNG__event) {\n        var r = JSBNG__event.threadID, s = i.get(r), t = h.getTab(r);\n        if (((((((((t && t.raised)) && s)) && s.isVisible())) && s.isFocused()))) {\n            m.changeThreadReadStatus(r, true);\n            n.markThreadSeen(r);\n            JSBNG__event.cancelAlert();\n        }\n    ;\n    ;\n    });\n    e.exports = p;\n});\n__d(\"ChatTabPresence\", [\"Arbiter\",\"AvailableList\",\"ChatTabModel\",\"MercuryThreads\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AvailableList\"), i = b(\"ChatTabModel\"), j = b(\"MercuryThreads\"), k = {\n    };\n    function l(m) {\n        var n = j.getCanonicalUserInThread(m);\n        if (n) {\n            h.updateForID(n);\n        }\n    ;\n    ;\n    };\n;\n    i.subscribe(\"chat/tabs-changed\", function(JSBNG__event, m) {\n        m.tabs.forEach(function(n) {\n            if (((n.raised && !k[n.id]))) {\n                l(n.id);\n            }\n        ;\n        ;\n        });\n        k = {\n        };\n        m.tabs.forEach(function(n) {\n            if (n.raised) {\n                k[n.id] = true;\n            }\n        ;\n        ;\n        });\n    });\n    e.exports = {\n    };\n});\n__d(\"ChatTabPolicy\", [\"ChatBehavior\",\"ChatConfig\",\"FBDesktopPlugin\",\"JSLogger\",\"MercuryAssert\",\"MercuryParticipants\",\"MercuryThreads\",\"MercuryUnseenState\",\"PresencePrivacy\",\"ShortProfiles\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"ChatBehavior\"), h = b(\"ChatConfig\"), i = b(\"FBDesktopPlugin\"), j = b(\"JSLogger\"), k = b(\"MercuryAssert\"), l = b(\"MercuryParticipants\"), m = b(\"MercuryThreads\"), n = b(\"MercuryUnseenState\"), o = b(\"PresencePrivacy\"), p = b(\"ShortProfiles\"), q = c(\"MercuryConstants\"), r = j.create(\"tab_policy\");\n    function s(t, u) {\n        n.markThreadSeen(t, u);\n    };\n;\n    e.exports = {\n        messageIsAllowed: function(t, u, v) {\n            var w = t.thread_id, x = u.message_id;\n            k.isThreadID(w);\n            k.isParticipantID(u.author);\n            var y;\n            if (((t.mode == q.MercuryThreadMode.OBJECT_ORIGINATED))) {\n                y = {\n                    thread_id: w,\n                    message_id: x,\n                    mode: t.mode\n                };\n                r.log(\"message_object_originated\", y);\n                return;\n            }\n        ;\n        ;\n            var z = q.MercurySourceType;\n            if (((((u.source == z.EMAIL)) || ((u.source == z.TITAN_EMAIL_REPLY))))) {\n                y = {\n                    thread_id: w,\n                    message_id: x,\n                    source: u.source\n                };\n                r.log(\"message_source_not_allowed\", y);\n                return;\n            }\n        ;\n        ;\n            var aa = l.getUserID(u.author);\n            if (!aa) {\n                r.log(\"message_bad_author\", {\n                    thread_id: w,\n                    message_id: x,\n                    user: aa\n                });\n                return;\n            }\n        ;\n        ;\n            if (((u.action_type != q.MercuryActionType.USER_GENERATED_MESSAGE))) {\n                y = {\n                    thread_id: w,\n                    message_id: x,\n                    type: u.action_type\n                };\n                r.log(\"message_non_user_generated\", y);\n                return;\n            }\n        ;\n        ;\n            if (((t.is_canonical_user && !g.notifiesUserMessages()))) {\n                r.log(\"message_jabber\", {\n                    thread_id: w,\n                    message_id: x\n                });\n                s(w, true);\n                return;\n            }\n        ;\n        ;\n            if (i.shouldSuppressMessages()) {\n                r.log(\"message_desktop\", {\n                    thread_id: w,\n                    message_id: x\n                });\n                return;\n            }\n        ;\n        ;\n            if (((!t.is_canonical_group && ((t.folder != q.MessagingTag.INBOX))))) {\n                r.log(\"message_folder\", {\n                    thread_id: w,\n                    message_id: x,\n                    folder: t.folder\n                });\n                return;\n            }\n        ;\n        ;\n            p.get(aa, function(ba) {\n                if (!o.allows(aa)) {\n                    r.log(\"message_privacy\", {\n                        thread_id: w,\n                        message_id: x,\n                        user: aa\n                    });\n                    return;\n                }\n            ;\n            ;\n                if (!t.is_canonical_group) {\n                    if (((ba.type != \"friend\"))) {\n                        r.log(\"message_non_friend\", {\n                            thread_id: w,\n                            message_id: x,\n                            user: aa\n                        });\n                        return;\n                    }\n                ;\n                }\n            ;\n            ;\n                v();\n            });\n        }\n    };\n});\n__d(\"ChatTabViewSelector\", [\"Arbiter\",\"copyProperties\",\"CSS\",\"DataStore\",\"DOM\",\"Menu\",\"MercuryThreadInformer\",\"MercuryThreads\",\"NubController\",\"MercuryThreadMetadataRenderer\",\"Toggler\",\"ChatTabTemplates\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"copyProperties\"), i = b(\"CSS\"), j = b(\"DataStore\"), k = b(\"DOM\"), l = b(\"Menu\"), m = b(\"MercuryThreadInformer\"), n = b(\"MercuryThreads\"), o = b(\"NubController\"), p = b(\"MercuryThreadMetadataRenderer\"), q = b(\"Toggler\"), r = c(\"ChatTabTemplates\");\n    function s(t) {\n        var u = r[\":fb:chat:tab:selector\"].build(), v = u.getRoot(), w = u.getNode(\"menu\"), x = k.JSBNG__find(w, \".uiMenuInner\"), y = {\n        }, z = new o().init(v);\n        i.hide(v);\n        k.insertBefore(t, v);\n        function aa(da) {\n            var ea = 0;\n            for (var fa in y) {\n                var ga = y[fa], ha = n.getThreadMetaNow(fa), ia = ga.getNode(\"unreadCount\"), ja = ((((ha && ha.unread_count)) || 0));\n                ea += ja;\n                if (((ja > 9))) {\n                    ja = \"+\";\n                }\n            ;\n            ;\n                i.conditionClass(ia, \"invisible_elem\", !ja);\n                k.setContent(ia, ja);\n            };\n        ;\n            var ka = u.getNode(\"numMessages\");\n            i.conditionShow(ka, ea);\n            k.setContent(ka, ea);\n        };\n    ;\n        this.setTabData = function(da) {\n            y = {\n            };\n            if (((da.length < 1))) {\n                i.hide(v);\n                return;\n            }\n        ;\n        ;\n            i.show(v);\n            k.empty(x);\n            da.forEach(function(ea) {\n                var fa = r[\":fb:chat:tab:selector:item\"].build();\n                y[ea.id] = fa;\n                var ga = fa.getNode(\"JSBNG__content\");\n                p.renderAndSeparatedParticipantList(ea.id, ga);\n                k.prependContent(x, fa.getRoot());\n                j.set(fa.getRoot(), \"threadID\", ea.id);\n            });\n            z.flyoutContentChanged();\n            k.setContent(u.getNode(\"numTabs\"), da.length);\n            aa();\n        };\n        function ba(JSBNG__event, da) {\n            if (((da.menu != w))) {\n                return;\n            }\n        ;\n        ;\n            var ea = j.get(da.item, \"threadID\");\n            s.inform(\"selected\", ea);\n            q.hide(v);\n        };\n    ;\n        function ca(JSBNG__event, da) {\n            l.register(w);\n        };\n    ;\n        l.subscribe(\"select\", ba.bind(this));\n        q.listen(\"show\", v, function() {\n            g.inform(\"layer_shown\", {\n                type: \"ChatTabSelector\"\n            });\n            ca();\n        });\n        q.listen(\"hide\", v, function() {\n            g.inform(\"layer_hidden\", {\n                type: \"ChatTabSelector\"\n            });\n        });\n        m.subscribe(\"threads-updated\", aa);\n    };\n;\n    h(s, new g());\n    e.exports = s;\n});\n__d(\"ChatTabController\", [\"ChatTabPresence\",\"Arbiter\",\"AsyncRequest\",\"ChatActivity\",\"ChatConfig\",\"ChatNewMessageHandler\",\"ChatTabMessagesView\",\"ChatTabModel\",\"ChatTabPolicy\",\"ChatTabView\",\"ChatTabViewSelector\",\"ChatTitleBarBlinker\",\"Dialog\",\"JSLogger\",\"MercuryMessages\",\"MercuryParticipants\",\"MercuryServerRequests\",\"MercuryThreadInformer\",\"MercuryThreads\",\"MercuryUnseenState\",\"Style\",\"UserAgent\",\"VideoCallCore\",], function(a, b, c, d, e, f) {\n    b(\"ChatTabPresence\");\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"ChatActivity\"), j = b(\"ChatConfig\"), k = b(\"ChatNewMessageHandler\"), l = b(\"ChatTabMessagesView\"), m = b(\"ChatTabModel\"), n = b(\"ChatTabPolicy\"), o = b(\"ChatTabView\"), p = b(\"ChatTabViewSelector\"), q = b(\"ChatTitleBarBlinker\"), r = b(\"Dialog\"), s = b(\"JSLogger\"), t = b(\"MercuryMessages\"), u = b(\"MercuryParticipants\"), v = b(\"MercuryServerRequests\"), w = b(\"MercuryThreadInformer\"), x = b(\"MercuryThreads\"), y = b(\"MercuryUnseenState\"), z = b(\"Style\"), aa = b(\"UserAgent\"), ba = b(\"VideoCallCore\"), ca = ((j.get(\"tab_auto_close_timeout\") || 7200000)), da = s.create(\"tab_controller\");\n    function ea(pa) {\n        x.changeThreadReadStatus(pa, true);\n        fa(pa);\n    };\n;\n    function fa(pa) {\n        y.markThreadSeen(pa);\n    };\n;\n    function ga() {\n        var pa = m.get();\n        pa.tabs.forEach(function(qa) {\n            var ra = o.get(qa.id);\n            if (((((qa.raised && ra)) && ra.isVisible()))) {\n                ea(qa.id);\n            }\n        ;\n        ;\n        });\n    };\n;\n    function ha() {\n        var pa = m.get();\n        pa.tabs.forEach(function(qa) {\n            fa(qa.id);\n        });\n    };\n;\n    function ia(pa, qa, ra) {\n        var sa = m.get().tabs;\n        pa += ((qa ? 1 : -1));\n        while (((((pa >= 0)) && ((pa < sa.length))))) {\n            var ta = sa[pa], ua = o.get(ta.id);\n            if (((((ua && ua.isVisible())) && ((!ra || ta.raised))))) {\n                ua.JSBNG__focus();\n                return true;\n            }\n        ;\n        ;\n            pa += ((qa ? 1 : -1));\n        };\n    ;\n        return false;\n    };\n;\n    function ja(pa) {\n        function qa(ta) {\n            var ua = pa.shouldPromoteOnRaise(ta);\n            g.inform(\"chat/promote-tab\", ta);\n            if (ua) {\n                m.raiseAndPromoteTab(ta, true);\n            }\n             else m.raiseTab(ta, true);\n        ;\n        ;\n            var va = o.get(ta);\n            ((va && va.JSBNG__focus()));\n        };\n    ;\n        function ra(ta, ua) {\n            var va = m.get(), wa = pa.getMaxTabsToShow(), xa = m.indexOf(ta);\n            m.closeTabAndDemote(ta, ((wa - 2)), ua);\n            return xa;\n        };\n    ;\n        p.subscribe(\"selected\", function(ta, ua) {\n            qa(ua);\n        });\n        g.subscribe(\"chat/open-tab\", function(ta, ua) {\n            qa(ua.thread_id);\n        });\n        g.subscribe(\"page_transition\", function(ta, ua) {\n            m.closeFragileTabs();\n        });\n        v.subscribe(\"model-update-completed\", ha);\n        o.subscribe(\"focused\", function(JSBNG__event, ta) {\n            ea(ta);\n        });\n        i.subscribe(\"idle\", function(ta, ua) {\n            if (((ua > ca))) {\n                var va = m.get().tabs;\n                va.forEach(function(wa) {\n                    var xa = wa.id;\n                    x.getThreadMeta(xa, function(ya) {\n                        if (!ya.unread_count) {\n                            da.log(\"autoclose_idle_seen\", {\n                                thread_id: xa,\n                                idleness: ua\n                            });\n                            m.closeTab(xa, \"autoclose_idle_seen\");\n                        }\n                    ;\n                    ;\n                    });\n                });\n            }\n        ;\n        ;\n        });\n        o.subscribe(\"nub-activated\", function(ta, ua) {\n            qa(ua);\n        });\n        o.subscribe(\"lower-activated\", function(ta, ua) {\n            m.lowerTab(ua);\n            var va = o.get(ua);\n            ((va && va.JSBNG__focus()));\n            ea(ua);\n        });\n        function sa(ta, ua) {\n            ba.showOutgoingCallDialog(ua.userID, ua.clickSource);\n            m.lowerTab(ua.threadID);\n        };\n    ;\n        o.subscribe(\"video-call-clicked\", sa);\n        l.subscribe(\"video-call-clicked\", sa);\n        o.subscribe(\"closed-tab\", function(ta, ua) {\n            da.log(\"close_view\", {\n                thread_id: ua\n            });\n            ra(ua, \"close_view\");\n            ea(ua);\n            return false;\n        });\n        o.subscribe(\"thread-deleted\", function(ta, ua) {\n            da.log(\"close_thread_deleted\", {\n                thread_id: ua\n            });\n            ra(ua, \"close_thread_deleted\");\n            return false;\n        });\n        o.subscribe(\"unsubscribed\", function(ta, ua) {\n            da.log(\"close_view_unsubscribed\", {\n                thread_id: ua\n            });\n            ra(ua, \"close_view_unsubscribed\");\n            return false;\n        });\n        o.subscribe(\"esc-pressed\", function(ta, ua) {\n            da.log(\"close_esc\", {\n                thread_id: ua\n            });\n            var va = ra(ua, \"close_esc\");\n            ((ia(((va - 1)), true, true) || ia(va, false, true)));\n        });\n        w.subscribe(\"messages-received\", function(ta, ua) {\n            for (var va in ua) {\n                var wa = ua[va];\n                for (var xa = 0; ((xa < wa.length)); xa++) {\n                    var ya = wa[xa];\n                    if (((ya.author != u.user))) {\n                        if (!ya.is_unread) {\n                            da.log(\"message_already_read\", {\n                                action_id: ya.action_id,\n                                thread_id: ya.thread_id\n                            });\n                            continue;\n                        }\n                    ;\n                    ;\n                        x.getThreadMeta(va, function(za) {\n                            n.messageIsAllowed(za, ya, function() {\n                                k.newMessage(va, ya);\n                            });\n                        });\n                    }\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n        });\n        w.subscribe(\"thread-read-changed\", function(ta, ua) {\n            for (var va in ua) {\n                if (!ua[va].mark_as_read) {\n                    da.log(\"autoclose_marked_unread\", {\n                        thread_id: va\n                    });\n                    m.closeTab(va, \"autoclose_marked_unread\");\n                }\n            ;\n            ;\n            };\n        ;\n        });\n        o.subscribe(\"tab-pressed\", function(ta, ua) {\n            return !ia(m.indexOf(ua.id), ua.shiftPressed);\n        });\n        g.subscribe(s.DUMP_EVENT, function(ta, ua) {\n            ua.chat_controller = {\n                auto_close_timeout: ca\n            };\n        });\n    };\n;\n    if (aa.firefox()) {\n        var ka = function() {\n            return ((((z.get(JSBNG__document.body, \"overflowX\") + \" \")) + z.get(JSBNG__document.body, \"overflowY\")));\n        }, la = ka(), ma = function() {\n            var pa = ka();\n            if (((pa !== la))) {\n                la = pa;\n                g.inform(\"overflow-applied-to-body\");\n            }\n        ;\n        ;\n        };\n        if (((\"MutationObserver\" in window))) {\n            var na = new MutationObserver(ma), oa = {\n                attributes: true,\n                attributeFilter: [\"class\",\"style\",]\n            };\n            na.observe(JSBNG__document.documentElement, oa);\n        }\n         else JSBNG__document.documentElement.JSBNG__addEventListener(\"DOMAttrModified\", function(JSBNG__event) {\n            if (((((JSBNG__event.getTarget() === JSBNG__document.documentElement)) && ((((JSBNG__event.attrName === \"class\")) || ((JSBNG__event.attrName === \"style\"))))))) {\n                ma();\n            }\n        ;\n        ;\n        }, false);\n    ;\n    ;\n    }\n;\n;\n    e.exports = ja;\n});\n__d(\"ChatTabViewCoordinator\", [\"Arbiter\",\"ChatConfig\",\"ChatTabModel\",\"ChatTabView\",\"ChatTabViewSelector\",\"CSS\",\"VideoCallCore\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ChatConfig\"), i = b(\"ChatTabModel\"), j = b(\"ChatTabView\"), k = b(\"ChatTabViewSelector\"), l = b(\"CSS\"), m = b(\"VideoCallCore\");\n    function n(o, p) {\n        var q = new k(o), r = {\n        }, s = false;\n        function t() {\n            var y = i.get(), z = {\n            };\n            y.tabs.forEach(function(ba) {\n                z[ba.id] = 1;\n            });\n            for (var aa in r) {\n                if (!z[aa]) {\n                    r[aa].destroy();\n                    delete (r[aa]);\n                }\n            ;\n            ;\n            };\n        ;\n            u(y);\n            v(y);\n        };\n    ;\n        function u(y) {\n            var z = null;\n            y.tabs.forEach(function(aa) {\n                var ba = aa.id, ca = false;\n                if (!r[ba]) {\n                    r[ba] = new j(ba, aa.server_id);\n                    ca = true;\n                }\n            ;\n            ;\n                if (((ca || !r[ba].nextTabIs(z)))) {\n                    if (z) {\n                        r[ba].insertBefore(z);\n                    }\n                     else r[ba].appendTo(o);\n                ;\n                }\n            ;\n            ;\n                z = r[ba];\n            });\n        };\n    ;\n        function v(y) {\n            var z = p.getTabsToShow(y), aa = [], ba = false;\n            y.tabs.forEach(function(ca) {\n                if (!z[ca.id]) {\n                    r[ca.id].setVisibleState(false, ca.raised);\n                    aa.push(ca);\n                }\n            ;\n            ;\n            });\n            y.tabs.forEach(function(ca) {\n                if (z[ca.id]) {\n                    r[ca.id].setVisibleState(true, ca.raised);\n                    ba |= ca.raised;\n                }\n            ;\n            ;\n            });\n            q.setTabData(aa);\n            x(ba);\n        };\n    ;\n        function w(y) {\n            for (var z = 0, aa = y.tabs.length; ((z < aa)); z++) {\n                var ba = y.tabs[z];\n                if (ba.raised) {\n                    if (((((ba.id === y.promoted)) || ((z < ((p.getMaxTabsToShow() - 1))))))) {\n                        return true;\n                    }\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            return false;\n        };\n    ;\n        function x(y) {\n            if (((!y && s))) {\n                g.inform(\"layer_hidden\", {\n                    type: \"ChatTab\"\n                });\n                s = false;\n            }\n             else if (((y && !s))) {\n                g.inform(\"layer_shown\", {\n                    type: \"ChatTab\"\n                });\n                s = true;\n            }\n            \n        ;\n        ;\n        };\n    ;\n        if (m.isSupported()) {\n            l.addClass(o, \"videoCallEnabled\");\n        }\n    ;\n    ;\n        p.subscribe(\"tabs-changed\", t);\n        t();\n    };\n;\n    e.exports = n;\n});\n__d(\"TabsViewport\", [\"event-extensions\",\"ArbiterMixin\",\"ChatConfig\",\"ChatTabModel\",\"Class\",\"CSS\",\"Dock\",\"DOM\",\"Parent\",\"Vector\",\"areObjectsEqual\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"ChatConfig\"), i = b(\"ChatTabModel\"), j = b(\"Class\"), k = b(\"CSS\"), l = b(\"Dock\"), m = b(\"DOM\"), n = b(\"Parent\"), o = b(\"Vector\"), p = b(\"areObjectsEqual\"), q = b(\"copyProperties\");\n    function r(s) {\n        this._root = s;\n        JSBNG__Event.listen(window, \"resize\", this._recalculateWidth.bind(this));\n        l.subscribe(\"resize\", this._recalculateWidth.bind(this));\n        i.subscribe(\"chat/tabs-changed\", this._recalculateTabs.shield(this, true));\n        this._recalculateWidth();\n        this._initialized = true;\n    };\n;\n    q(r.prototype, g, {\n        _root: null,\n        _initialized: false,\n        _availableWidth: 0,\n        _maxShown: 1,\n        _viewState: null,\n        _recalculateWidth: function() {\n            var s = r._getAvailableDockWidth(this._root), t = Math.max(1, Math.floor(((s / 264)))), u = ((t != this._maxShown));\n            if (((((((!this._viewState || u)) || ((s <= this._viewState.usedWidth)))) || ((s > this._viewState.widthToShowNext))))) {\n                this._availableWidth = s;\n                this._maxShown = t;\n                this._viewState = null;\n                this._recalculateTabs(u);\n            }\n        ;\n        ;\n        },\n        _onTabsChanged: function() {\n            if (this._initialized) {\n                this.inform(\"tabs-changed\");\n                this.inform(\"max-to-show-changed\", this._maxShown);\n                this.inform(\"max-to-show-change-completed\");\n            }\n        ;\n        ;\n        },\n        _recalculateTabs: function(s) {\n            var t = r._getTabsToShow(i.get(), this._availableWidth);\n            if (((s || !p(this._viewState, t)))) {\n                this._viewState = t;\n                this._onTabsChanged();\n            }\n        ;\n        ;\n        },\n        getMaxTabsToShow: function() {\n            return this._maxShown;\n        },\n        checkWidth: function() {\n            this._recalculateWidth();\n        },\n        getTabsToShow: function() {\n            return JSON.parse(JSON.stringify(this._viewState.tabsToShow));\n        },\n        shouldPromoteOnRaise: function(s) {\n            if (!this._viewState.tabsToShow[s]) {\n                return true;\n            }\n        ;\n        ;\n            if (((this._viewState.nextToHide != s))) {\n                return false;\n            }\n        ;\n        ;\n            var t = i.getTab(s), u = ((t && t.raised));\n            return ((!u && ((((this._availableWidth - this._viewState.usedWidth)) < 100))));\n        }\n    });\n    q(r, {\n        _getAvailableDockWidth: function(s) {\n            var t = o.getViewportDimensions().x;\n            t -= 230;\n            t -= 50;\n            var u = n.byClass(s, \"fbDock\"), v = o.getElementDimensions(u), w = n.byClass(s, \"fbDockChat\"), x = o.getElementDimensions(w), y = ((v.x - x.x));\n            t -= y;\n            t -= 20;\n            return Math.max(t, 0);\n        },\n        _getTabsToShow: function(s, t) {\n            var u = 164, v = 264;\n            t = Math.max(t, ((v + 1)));\n            function w(la) {\n                return ((la.raised ? v : u));\n            };\n        ;\n            var x = JSON.parse(JSON.stringify(s.tabs)), y = -1, z = null;\n            if (s.promoted) {\n                x.forEach(function(la, ma) {\n                    if (((la.id === s.promoted))) {\n                        y = ma;\n                        z = la;\n                    }\n                ;\n                ;\n                });\n            }\n        ;\n        ;\n            var aa = 0, ba = 0, ca = !z;\n            x.forEach(function(la, ma) {\n                var na = w(la);\n                la.leftmostOffset = ((aa + v));\n                aa += na;\n                if (((la.leftmostOffset < t))) {\n                    ba++;\n                }\n            ;\n            ;\n                ca |= ((ma == y));\n                la.alreadyPlacedPromoted = ca;\n            });\n            function da(la, ma, na) {\n                var oa = {\n                };\n                for (var pa = 0; ((pa < ma)); pa++) {\n                    var qa = la[pa];\n                    if (((!qa.alreadyPlacedPromoted && ((pa == ((ma - 1))))))) {\n                        oa[na] = true;\n                    }\n                     else oa[qa.id] = true;\n                ;\n                ;\n                };\n            ;\n                return oa;\n            };\n        ;\n            var ea = da(x, ba, s.promoted), fa = da(x, ((ba - 1)), s.promoted), ga = null;\n            for (var ha in ea) {\n                if (!fa[ha]) {\n                    ga = ha;\n                }\n            ;\n            ;\n            };\n        ;\n            var ia = x[((ba - 1))], ja = ((ia ? ia.leftmostOffset : 0)), ka = Infinity;\n            if (((ba < x.length))) {\n                ka = x[ba].leftmostOffset;\n            }\n        ;\n        ;\n            return {\n                nextToHide: ga,\n                tabsToShow: ea,\n                usedWidth: ja,\n                widthToShowNext: ka\n            };\n        }\n    });\n    e.exports = r;\n});\n__d(\"MercuryChannelHandler\", [\"Arbiter\",\"ChannelConstants\",\"copyProperties\",\"Env\",\"MessagingReliabilityLogger\",\"MercuryParticipants\",\"PresenceUtil\",\"MercuryServerRequests\",\"MercuryThreadInformer\",\"MercuryThreads\",\"MercuryConstants\",\"MercuryConfig\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ChannelConstants\"), i = b(\"copyProperties\"), j = b(\"Env\"), k = b(\"MessagingReliabilityLogger\"), l = b(\"MercuryParticipants\"), m = b(\"PresenceUtil\"), n = b(\"MercuryServerRequests\"), o = b(\"MercuryThreadInformer\"), p = b(\"MercuryThreads\"), q = c(\"MercuryConstants\"), r = c(\"MercuryConfig\");\n    function s(ia, ja) {\n        var ka = ja.obj.to;\n        p.getCanonicalThreadToGroup(ka, function(la) {\n            var ma = la.thread_id;\n            n.getServerThreadID(ma, function(na) {\n                var oa = ba(ka, ja.obj.from, ja.obj.msg.time), pa = ((ja.obj.from != j.user)), qa = JSBNG__Date.format(((r[\"24h_times\"] ? \"H:i\" : \"g:ia\")), Math.floor(((ja.obj.msg.time / 1000)))), ra = new JSBNG__Date(ja.obj.msg.time).toLocaleDateString(), sa = {\n                    obj: {\n                        message: {\n                            action_id: null,\n                            body: ja.obj.msg.text,\n                            is_unread: pa,\n                            mid: oa,\n                            mercury_author_id: ((\"fbid:\" + ja.obj.from)),\n                            mercury_author_email: null,\n                            mercury_coordinates: null,\n                            mercury_spoof_warning: false,\n                            mercury_source: q.MercurySourceType.CHAT_WEB,\n                            mercury_source_tags: [q.MercuryMessageSourceTags.CHAT,],\n                            sender_fbid: ja.obj.from,\n                            tid: na,\n                            timestamp: ja.obj.msg.time,\n                            timestamp_absolute: ra,\n                            timestamp_relative: qa,\n                            threading_id: ja.obj.sync_id\n                        },\n                        folder: \"group_chat\"\n                    }\n                };\n                t(h.getArbiterType(\"messaging\"), sa);\n            });\n        });\n    };\n;\n    function t(ia, ja) {\n        if (((((((ia != h.getArbiterType(\"messaging\"))) || !ja.obj)) || !ja.obj.message))) {\n            k.addEntry(\"channel_receive\", \"invalid_data\");\n            return;\n        }\n    ;\n    ;\n        var ka = ja.obj.message, la = {\n            author: ka.mercury_author_id,\n            author_email: ka.mercury_author_email,\n            body: ka.body,\n            subject: ka.subject,\n            has_attachment: ka.has_attachment,\n            attachments: ka.attachments,\n            html_body: ka.html_body,\n            thread_id: ka.tid,\n            message_id: ka.mid,\n            coordinates: ka.mercury_coordinates,\n            spoof_warning: ka.mercury_spoof_warning,\n            source: ka.mercury_source,\n            source_tags: ka.mercury_source_tags,\n            threading_id: ka.threading_id,\n            timestamp: ka.timestamp,\n            timestamp_absolute: ka.timestamp_absolute,\n            timestamp_relative: ka.timestamp_relative,\n            action_type: q.MercuryActionType.USER_GENERATED_MESSAGE,\n            is_unread: ka.is_unread,\n            action_id: ka.action_id,\n            is_forward: false,\n            forward_count: ((ka.forward_count || ka.JSBNG__forward)),\n            forward_message_ids: ka.forward_msg_ids,\n            location_text: ka.location_text,\n            folder: ja.obj.folder\n        }, ma = [i({\n        }, la),];\n        ma = ma.concat(((ka.forward_actions || [])));\n        var na = q.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE;\n        n.handleUpdateWaitForThread({\n            actions: ma,\n            payload_source: na\n        }, ka.tid);\n        if (((!ka.is_unread && ((ka.mercury_author_id === l.user))))) {\n            var oa = {\n            };\n            oa[ka.tid] = ja.obj.folder;\n            u(h.getArbiterType(\"messaging\"), {\n                obj: {\n                    JSBNG__event: q.MessagingEventTypes.READ,\n                    tids: [ka.tid,],\n                    folder_info: oa\n                }\n            });\n        }\n    ;\n    ;\n        k.addEntry(\"channel_receive\", \"success\", [la.thread_id,la.message_id,m.getSessionID(),]);\n    };\n;\n    function u(ia, ja) {\n        if (((((((ia != h.getArbiterType(\"messaging\"))) || !ja.obj)) || !ja.obj.tids))) {\n            return;\n        }\n    ;\n    ;\n        var ka = [], la = ((ja.obj.JSBNG__event == q.MessagingEventTypes.READ));\n        ja.obj.tids.forEach(function(ma) {\n            ka.push({\n                action_type: q.MercuryActionType.CHANGE_READ_STATUS,\n                action_id: null,\n                thread_id: ma,\n                mark_as_read: la,\n                timestamp: ((ja.obj.timestamp || 0)),\n                folder: ja.obj.folder_info[ma]\n            });\n        });\n        n.handleUpdate({\n            actions: ka,\n            payload_source: q.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE\n        });\n    };\n;\n    function v(ia, ja) {\n        if (((((((ia != h.getArbiterType(\"messaging\"))) || !ja.obj)) || !ja.obj.tids))) {\n            return;\n        }\n    ;\n    ;\n        var ka = [];\n        ja.obj.tids.forEach(function(la) {\n            ka.push({\n                action_type: q.MercuryActionType.DELETE_THREAD,\n                action_id: null,\n                thread_id: la\n            });\n        });\n        n.handleUpdate({\n            actions: ka,\n            payload_source: q.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE\n        });\n    };\n;\n    function w(ia, ja) {\n        if (((((((((ia != h.getArbiterType(\"messaging\"))) || !ja.obj)) || !ja.obj.tids)) || !ja.obj.mids))) {\n            return;\n        }\n    ;\n    ;\n        var ka = ja.obj.tids[0], la = {\n            action_type: q.MercuryActionType.DELETE_MESSAGES,\n            action_id: null,\n            thread_id: ka,\n            message_ids: ja.obj.mids\n        };\n        n.handleUpdate({\n            actions: [la,],\n            threads: [ja.obj.updated_thread,],\n            payload_source: q.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE\n        });\n    };\n;\n    function x(ia, ja) {\n        if (((((((ia != h.getArbiterType(\"messaging\"))) || !ja.obj)) || !ja.obj.folder))) {\n            return;\n        }\n    ;\n    ;\n        var ka = {\n            action_type: q.MercuryGlobalActionType.MARK_ALL_READ,\n            action_id: ja.obj.action_id,\n            folder: ja.obj.folder\n        };\n        n.handleUpdate({\n            global_actions: [ka,]\n        });\n    };\n;\n    function y(ia, ja) {\n        if (((((ia != h.getArbiterType(\"messaging\"))) || !ja.obj.tids))) {\n            return;\n        }\n    ;\n    ;\n        var ka = q.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE;\n        ja.obj.tids.forEach(function(la) {\n            var ma = {\n                action_type: q.MercuryActionType.CHANGE_ARCHIVED_STATUS,\n                action_id: null,\n                thread_id: la,\n                archived: ja.obj.state\n            };\n            n.handleUpdateWaitForThread({\n                actions: [i({\n                }, ma),],\n                payload_source: ka\n            }, la);\n        });\n    };\n;\n    function z(ia, ja) {\n        if (((((ia != h.getArbiterType(\"messaging\"))) || !ja.obj.tids))) {\n            return;\n        }\n    ;\n    ;\n        var ka = q.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE, la;\n        ja.obj.tids.forEach(function(ma) {\n            if (((ja.obj.JSBNG__event == q.MessagingEventTypes.TAG))) {\n                la = ja.obj.tag;\n            }\n             else la = ((ja.obj.marked_as_spam ? q.MessagingTag.SPAM : q.MessagingTag.INBOX));\n        ;\n        ;\n            var na = {\n                action_type: q.MercuryActionType.CHANGE_FOLDER,\n                action_id: null,\n                thread_id: ma,\n                new_folder: la\n            };\n            n.handleUpdateWaitForThread({\n                actions: [i({\n                }, na),],\n                payload_source: ka\n            }, ma);\n        });\n    };\n;\n    function aa(ia, ja) {\n        if (((((ia != h.getArbiterType(\"messaging\"))) || !ja.obj.tag))) {\n            return;\n        }\n    ;\n    ;\n        switch (ja.obj.tag) {\n          case q.MessagingTag.ACTION_ARCHIVED:\n            y(ia, ja);\n            break;\n          case q.MessagingTag.INBOX:\n        \n          case q.MessagingTag.OTHER:\n            z(ia, ja);\n            break;\n        };\n    ;\n    };\n;\n    function ba(ia, ja, ka) {\n        return ((((((((ia + \":\")) + ja)) + \":\")) + ka));\n    };\n;\n    function ca(ia, ja) {\n        if (((((((ia != h.getArbiterType(\"inbox\"))) || !ja.obj)) || !ja.obj.seen_timestamp))) {\n            return;\n        }\n    ;\n    ;\n        n.handleUpdate({\n            message_counts: [{\n                seen_timestamp: ja.obj.seen_timestamp,\n                folder: q.MessagingTag.INBOX\n            },],\n            unseen_thread_ids: [{\n                thread_ids: [],\n                folder: q.MessagingTag.INBOX\n            },],\n            payload_source: q.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE\n        });\n    };\n;\n    function da(ia, ja) {\n        if (((((ia != h.getArbiterType(\"mercury\"))) || !ja.obj))) {\n            return;\n        }\n    ;\n    ;\n        o.synchronizeInforms(function() {\n            var ka = ja.obj, la = [];\n            ((ka.actions || [])).forEach(function(ma) {\n                var na = q.MercuryActionType.USER_GENERATED_MESSAGE;\n                if (((ma.action_type == q.MercuryActionType.LOG_MESSAGE))) {\n                    var oa = q.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE;\n                    n.handleUpdateWaitForThread({\n                        actions: [i({\n                        }, ma),],\n                        payload_source: oa\n                    }, ma.thread_id);\n                }\n                 else if (((ma.action_type != na))) {\n                    la.push(ma);\n                }\n                \n            ;\n            ;\n            });\n            ka.actions = la;\n            ka.payload_source = q.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE;\n            n.handleUpdate(ka);\n        });\n    };\n;\n    function ea(ia, ja) {\n        n.handleRoger(ja.obj);\n    };\n;\n    function fa(ia, ja) {\n        switch (ja.obj.JSBNG__event) {\n          case q.MessagingEventTypes.DELIVER:\n            t(ia, ja);\n            break;\n          case q.MessagingEventTypes.READ:\n        \n          case q.MessagingEventTypes.UNREAD:\n            u(ia, ja);\n            break;\n          case q.MessagingEventTypes.READ_ALL:\n            x(ia, ja);\n            break;\n          case q.MessagingEventTypes.DELETE:\n            v(ia, ja);\n            break;\n          case q.MessagingEventTypes.DELETE_MESSAGES:\n            w(ia, ja);\n            break;\n          case q.MessagingEventTypes.TAG:\n            aa(ia, ja);\n            break;\n          case q.MessagingEventTypes.REPORT_SPAM:\n            z(ia, ja);\n            break;\n          case q.MessagingEventTypes.READ_RECEIPT:\n            ea(ia, ja);\n            break;\n        };\n    ;\n    };\n;\n    var ga = [], ha = {\n        turnOn: function() {\n            if (!ga.length) {\n                var ia = {\n                    mercury: da,\n                    messaging: fa,\n                    group_msg: s,\n                    inbox: ca\n                };\n                for (var ja in ia) {\n                    ga.push(g.subscribe(h.getArbiterType(ja), ia[ja]));\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n        },\n        turnOff: function() {\n            if (ga.length) {\n                ga.forEach(g.unsubscribe);\n                ga = [];\n            }\n        ;\n        ;\n        }\n    };\n    ha.turnOn();\n    e.exports = ha;\n});\n__d(\"MercuryJewelCountControl\", [\"Arbiter\",\"DOM\",\"JewelX\",\"MercuryUnseenState\",\"MercuryServerRequests\",\"MercuryThreadInformer\",\"copyProperties\",\"tx\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = c(\"MercuryConstants\"), i = b(\"DOM\"), j = b(\"JewelX\"), k = b(\"MercuryUnseenState\"), l = b(\"MercuryServerRequests\"), m = b(\"MercuryThreadInformer\"), n = b(\"copyProperties\"), o = b(\"tx\"), p, q, r, s = function(u) {\n        if (((u || r.isOpen()))) {\n            k.markAsSeen();\n        }\n    ;\n    ;\n    }, t = function(u, v) {\n        p = u;\n        q = i.JSBNG__find(p, \"#mercurymessagesCountValue\");\n        r = v;\n        this.render();\n        l.subscribe(\"model-update-completed\", function(w, x) {\n            s(false);\n        });\n        m.subscribe(\"unseen-updated\", this.render.bind(this));\n        r.subscribe(\"marked-seen\", s.shield(this, true));\n    };\n    n(t.prototype, {\n        render: function() {\n            var u = \"\";\n            if (k.exceedsMaxCount()) {\n                u = o._(\"{count}+\", {\n                    count: h.MercuryThreadlistConstants.MAX_UNSEEN_COUNT\n                });\n            }\n             else u = k.getUnseenCount().toString();\n        ;\n        ;\n            g.inform(\"jewel/count-updated\", {\n                jewel: \"mercurymessages\",\n                count: u\n            }, g.BEHAVIOR_STATE);\n        }\n    });\n    e.exports = t;\n});\n__d(\"MercuryFilters\", [\"array-extensions\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    var g = c(\"MercuryConstants\"), h = [g.MessagingTag.UNREAD,], i = {\n        ALL: \"all\",\n        getSupportedFilters: function() {\n            return h.concat();\n        },\n        isSupportedFilter: function(j) {\n            return h.contains(j);\n        }\n    };\n    e.exports = i;\n});\n__d(\"MercuryOrderedThreadlist\", [\"JSLogger\",\"MercuryFolders\",\"MercuryFilters\",\"MercuryServerRequests\",\"RangedCallbackManager\",\"MercuryThreadInformer\",\"MercuryThreads\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"JSLogger\"), h = b(\"MercuryFolders\"), i = b(\"MercuryFilters\"), j = b(\"MercuryServerRequests\"), k = b(\"RangedCallbackManager\"), l = b(\"MercuryThreadInformer\"), m = b(\"MercuryThreads\"), n = c(\"MercuryConstants\"), o = g.create(\"ordered_threadlist_model\"), p = i.getSupportedFilters().concat([i.ALL,]), q = h.getSupportedFolders(), r = {\n    };\n    q.forEach(function(ca) {\n        r[ca] = {\n        };\n        p.forEach(function(da) {\n            r[ca][da] = new k(function(ea) {\n                return m.getThreadMetaNow(ea).timestamp;\n            }, function(ea, fa) {\n                return ((fa - ea));\n            }, j.canLinkExternally.bind(j));\n        });\n    });\n    function s(ca, da, ea) {\n        var fa = [], ga = false, ha = ((ca || [])).filter(function(oa) {\n            var pa = ((oa.filter || i.ALL));\n            return ((((((oa.folder == da)) || ((!oa.folder && ((da == n.MessagingTag.INBOX)))))) && ((pa == ea))));\n        }), ia = r[da][ea].getAllResources(), ja;\n        ha.forEach(function(oa) {\n            fa = fa.concat(oa.thread_ids);\n            var pa = ((oa.end - oa.start));\n            if (((oa.thread_ids.length < pa))) {\n                ga = true;\n            }\n        ;\n        ;\n            if (((!ja || ((oa.end > ja))))) {\n                ja = oa.end;\n            }\n        ;\n        ;\n        });\n        w(fa, da, ea);\n        if (ga) {\n            r[da][ea].setReachedEndOfArray();\n        }\n         else {\n            var ka = r[da][ea].getCurrentArraySize();\n            if (((ja && ((ka < ja))))) {\n                var la = {\n                }, ma = ia.concat(fa), na = ma.filter(function(oa) {\n                    var pa = la[oa];\n                    la[oa] = true;\n                    return pa;\n                });\n                if (na.length) {\n                    o.warn(\"duplicate_threads\", {\n                        folder: da,\n                        expected_final_size: ja,\n                        actual_final_size: ka,\n                        duplicate_thread_ids: na\n                    });\n                    j.fetchThreadlistInfo(ja, na.length, da, ((((ea == i.ALL)) ? null : ea)));\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    };\n;\n    function t(ca) {\n        q.forEach(function(da) {\n            p.forEach(function(ea) {\n                s(ca, da, ea);\n            });\n        });\n    };\n;\n    function u(ca) {\n        var da = {\n        };\n        q.forEach(function(ea) {\n            da[ea] = {\n            };\n            p.forEach(function(fa) {\n                da[ea][fa] = {\n                    to_add: [],\n                    to_remove: [],\n                    to_remove_if_last_after_add: {\n                    }\n                };\n            });\n        });\n        ca.forEach(function(ea) {\n            if (ea.is_forward) {\n                return;\n            }\n        ;\n        ;\n            var fa = ea.thread_id, ga = x(fa), ha = y(fa);\n            function ia() {\n                ha.forEach(function(ka) {\n                    da[ga][ka].to_add.push(fa);\n                    if (((!r[ga][ka].hasReachedEndOfArray() && !r[ga][ka].hasResource(fa)))) {\n                        da[ga][ka].to_remove_if_last_after_add[fa] = true;\n                    }\n                ;\n                ;\n                });\n            };\n        ;\n            function ja(ka) {\n                if (p.contains(ka)) {\n                    if (ha.contains(ka)) {\n                        da[ga][ka].to_add.push(fa);\n                    }\n                     else da[ga][ka].to_remove.push(fa);\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            if (!ga) {\n                if (((((ea.action_type === n.MercuryActionType.CHANGE_FOLDER)) || ((ea.action_type === n.MercuryActionType.CHANGE_ARCHIVED_STATUS))))) {\n                    q.forEach(function(ka) {\n                        if (((ka !== ga))) {\n                            p.forEach(function(la) {\n                                r[ka][la].removeResources([fa,]);\n                            });\n                        }\n                    ;\n                    ;\n                    });\n                }\n            ;\n            ;\n                return;\n            }\n        ;\n        ;\n            switch (ea.action_type) {\n              case n.MercuryActionType.DELETE_THREAD:\n                ha.forEach(function(ka) {\n                    da[ga][ka].to_remove.push(fa);\n                });\n                break;\n              case n.MercuryActionType.CHANGE_ARCHIVED_STATUS:\n            \n              case n.MercuryActionType.CHANGE_FOLDER:\n                ia();\n                break;\n              case n.MercuryActionType.CHANGE_READ_STATUS:\n                ja(n.MessagingTag.UNREAD);\n                break;\n              case n.MercuryActionType.USER_GENERATED_MESSAGE:\n            \n              case n.MercuryActionType.LOG_MESSAGE:\n                ha.forEach(function(ka) {\n                    if (z(fa, ga, ka)) {\n                        da[ga][ka].to_add.push(fa);\n                    }\n                ;\n                ;\n                });\n                break;\n            };\n        ;\n        });\n        q.forEach(function(ea) {\n            p.forEach(function(fa) {\n                var ga = r[ea][fa];\n                w(da[ea][fa].to_add, ea, fa);\n                for (var ha = ((ga.getCurrentArraySize() - 1)); ((ha >= 0)); ha--) {\n                    var ia = ga.getResourceAtIndex(ha);\n                    if (!da[ea][fa].to_remove_if_last_after_add[ia]) {\n                        break;\n                    }\n                ;\n                ;\n                    da[ea][fa].to_remove.push(ia);\n                };\n            ;\n                ga.removeResources(da[ea][fa].to_remove);\n            });\n        });\n    };\n;\n    function v(ca) {\n        var da = {\n        };\n        q.forEach(function(ea) {\n            da[ea] = {\n            };\n            p.forEach(function(fa) {\n                da[ea][fa] = [];\n            });\n        });\n        ca.forEach(function(ea) {\n            var fa = x(ea.thread_id), ga = y(ea.thread_id);\n            ga.forEach(function(ha) {\n                if (((fa && z(ea.thread_id, fa, ha)))) {\n                    da[fa][ha].push(ea.thread_id);\n                }\n            ;\n            ;\n            });\n        });\n        q.forEach(function(ea) {\n            p.forEach(function(fa) {\n                if (((da[ea][fa].length > 0))) {\n                    w(da[ea][fa], ea, fa);\n                }\n            ;\n            ;\n            });\n        });\n    };\n;\n    function w(ca, da, ea) {\n        ea = ((ea || i.ALL));\n        r[da][ea].addResources(ca);\n        q.forEach(function(fa) {\n            if (((fa != da))) {\n                r[fa][ea].removeResources(ca);\n            }\n        ;\n        ;\n        });\n    };\n;\n    function x(ca) {\n        var da = m.getThreadMetaNow(ca), ea = null;\n        if (!da) {\n            ea = \"No thread metadata\";\n        }\n         else if (!da.folder) {\n            ea = \"No thread folder\";\n        }\n        \n    ;\n    ;\n        if (ea) {\n            var fa = {\n                error: ea,\n                tid: ca\n            };\n            o.warn(\"no_thread_folder\", fa);\n            return null;\n        }\n    ;\n    ;\n        var ga = da.folder;\n        if (da.is_archived) {\n            ga = n.MessagingTag.ACTION_ARCHIVED;\n        }\n    ;\n    ;\n        if (r[ga]) {\n            return ga;\n        }\n         else return null\n    ;\n    };\n;\n    function y(ca) {\n        var da = m.getThreadMetaNow(ca), ea = [i.ALL,];\n        if (!da) {\n            var fa = {\n                error: \"no_thread_metadata\",\n                tid: ca\n            };\n            o.warn(\"no_thread_metadata\", fa);\n            return [];\n        }\n    ;\n    ;\n        if (da.unread_count) {\n            ea.push(n.MessagingTag.UNREAD);\n        }\n    ;\n    ;\n        return ea;\n    };\n;\n    function z(ca, da, ea) {\n        var fa = m.getThreadMetaNow(ca);\n        return ((((((fa && fa.timestamp)) && ((x(ca) == da)))) && y(ca).contains(ea)));\n    };\n;\n    var aa = {\n        getThreadlist: function(ca, da, ea, fa, ga) {\n            return aa.getFilteredThreadlist(ca, da, ea, i.ALL, fa, ga);\n        },\n        getFilteredThreadlist: function(ca, da, ea, fa, ga, ha) {\n            var ia = r[ea][fa], ja = ia.executeOrEnqueue(ca, da, ga, ha), ka = ia.getUnavailableResources(ja);\n            if (ka.length) {\n                if (((ia.getCurrentArraySize() < ca))) {\n                    var la = {\n                        start: ca,\n                        limit: da,\n                        filter: fa,\n                        resources_size: ia.getCurrentArraySize()\n                    };\n                    o.warn(\"range_with_gap\", la);\n                }\n            ;\n            ;\n                j.fetchThreadlistInfo(ia.getCurrentArraySize(), ka.length, ea, ((((fa == i.ALL)) ? null : fa)));\n            }\n        ;\n        ;\n            return ja;\n        },\n        getThreadlistUntilTimestamp: function(ca, da, ea) {\n            ea = ((ea || i.ALL));\n            return r[da][ea].getElementsUntil(ca);\n        },\n        unsubscribe: function(ca, da, ea) {\n            ea = ((ea || i.ALL));\n            r[da][ea].unsubscribe(ca);\n        }\n    };\n    function ba(ca) {\n        switch (ca.payload_source) {\n          case n.MercuryPayloadSource.CLIENT_CHANGE_ARCHIVED_STATUS:\n        \n          case n.MercuryPayloadSource.CLIENT_CHANGE_READ_STATUS:\n        \n          case n.MercuryPayloadSource.CLIENT_CHANGE_FOLDER:\n        \n          case n.MercuryPayloadSource.CLIENT_CHANNEL_MESSAGE:\n        \n          case n.MercuryPayloadSource.CLIENT_DELETE_MESSAGES:\n        \n          case n.MercuryPayloadSource.CLIENT_DELETE_THREAD:\n        \n          case n.MercuryPayloadSource.CLIENT_SEND_MESSAGE:\n        \n          case n.MercuryPayloadSource.SERVER_SEND_MESSAGE:\n        \n          case n.MercuryPayloadSource.SERVER_CONFIRM_MESSAGES:\n        \n          case n.MercuryPayloadSource.SERVER_FETCH_THREADLIST_INFO:\n        \n          case n.MercuryPayloadSource.SERVER_THREAD_SYNC:\n            return true;\n          case n.MercuryPayloadSource.SERVER_INITIAL_DATA:\n            return ca.ordered_threadlists;\n          default:\n            return false;\n        };\n    ;\n    };\n;\n    j.subscribe(\"update-threadlist\", function(ca, da) {\n        if (!ba(da)) {\n            return;\n        }\n    ;\n    ;\n        var ea = da.ordered_threadlists;\n        if (((ea && ea.length))) {\n            t(ea);\n        }\n         else {\n            var fa = ((da.actions || [])).filter(function(ga) {\n                return ga.thread_id;\n            });\n            v(((da.threads || [])));\n            u(fa);\n        }\n    ;\n    ;\n        l.updatedThreadlist();\n    });\n    e.exports = aa;\n});\n__d(\"WebMessengerStateConstants\", [], function(a, b, c, d, e, f) {\n    var g = {\n        SELECTION: \"selection\",\n        COMPOSE: \"compose\",\n        SEARCH_THREAD: \"search-thread\",\n        SEARCH_THREAD_SELECTION: \"search-thread-selection\",\n        SEARCH_SNIPPET: \"search-snippet\",\n        SEARCH_SNIPPET_SELECTION: \"search-snippet-selection\",\n        STATE_CHANGE_EVENT: \"state-changed\",\n        COMPOSE_SHOWING_CONTEXT: \"showing_context\",\n        COMPOSE_SHOWING_TYPEAHEAD_RESULTS: \"showing_typeahead_results\",\n        COMPOSE_SHOWING_ALL_PEOPLE: \"showing_all_people\",\n        MESSAGE_ACTION: {\n            DELETE: \"delete\",\n            FORWARD: \"JSBNG__forward\"\n        }\n    };\n    e.exports = g;\n});\n__d(\"WebMessengerOldToNewPermalink\", [\"WebMessengerPermalinkConstants\",\"WebMessengerStateConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"WebMessengerPermalinkConstants\"), h = b(\"WebMessengerStateConstants\");\n    function i(n) {\n        if (!j(n)) {\n            return n;\n        }\n    ;\n    ;\n        k(n);\n        m(n);\n        l(n);\n        return n;\n    };\n;\n    function j(n) {\n        var o = n.getQueryData();\n        if (o.sk) {\n            switch (o.sk) {\n              case \"inbox\":\n                n.setPath(g.BASE_PATH);\n                n.removeQueryData(\"sk\");\n                break;\n              case \"other\":\n                n.setPath(g.OTHER_PATH);\n                n.removeQueryData(\"sk\");\n                break;\n              default:\n                return false;\n            };\n        }\n    ;\n    ;\n        return true;\n    };\n;\n    function k(n) {\n        var o = n.getQueryData();\n        switch (o.action) {\n          case \"read\":\n            if (!o.tid) {\n                n.addQueryData({\n                    action: h.SELECTION\n                });\n            }\n             else n.removeQueryData(\"action\");\n        ;\n        ;\n            break;\n        };\n    ;\n    };\n;\n    function l(n) {\n        var o = n.getQueryData();\n        if (o.tid) {\n            n.setPath(g.getURIPathForThreadID(o.tid, n.getPath()));\n            n.removeQueryData(\"tid\");\n        }\n    ;\n    ;\n    };\n;\n    function m(n) {\n        var o = n.getQueryData();\n        if (!n.getPath().match(g.SEARCH_POSTFIX_PATH)) {\n            var p = o.query;\n            if (o.query) {\n                var q = /\\bis:(archived|spam)\\b(.*)/, r = q.exec(o.query);\n                if (r) {\n                    switch (r[1]) {\n                      case \"archived\":\n                        n.setPath(g.ARCHIVED_PATH);\n                        break;\n                      case \"spam\":\n                        n.setPath(g.SPAM_PATH);\n                        break;\n                    };\n                ;\n                    var s = o.query.substr(0, ((o.query.length - r[0].length))), t = r[2];\n                    p = ((((s.trim() + \" \")) + t.trim())).trim();\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            if (o.thread_query) {\n                n.setPath(((n.getPath() + g.SEARCH_POSTFIX_PATH)));\n                n.setQueryData({\n                    query: o.thread_query\n                });\n            }\n             else if (p) {\n                n.setPath(((n.getPath() + g.SEARCH_POSTFIX_PATH)));\n                n.addQueryData({\n                    query: p\n                });\n            }\n             else n.removeQueryData(\"query\");\n            \n        ;\n        ;\n        }\n    ;\n    ;\n    };\n;\n    e.exports = i;\n});\n__d(\"WebMessengerPermalinks\", [\"goURI\",\"MercuryIDs\",\"MercuryParticipants\",\"MercuryFilters\",\"WebMessengerOldToNewPermalink\",\"WebMessengerPermalinkConstants\",\"MercuryServerRequests\",\"WebMessengerStateConstants\",\"MercuryThreads\",\"Token\",\"URI\",\"MercuryConstants\",\"WebMessengerConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"goURI\"), h = b(\"MercuryIDs\"), i = b(\"MercuryParticipants\"), j = b(\"MercuryFilters\"), k = b(\"WebMessengerOldToNewPermalink\"), l = b(\"WebMessengerPermalinkConstants\"), m = b(\"MercuryServerRequests\"), n = b(\"WebMessengerStateConstants\"), o = b(\"MercuryThreads\"), p = b(\"Token\"), q = b(\"URI\"), r = c(\"MercuryConstants\"), s = c(\"WebMessengerConstants\"), t = {\n        getDefaultURI: function() {\n            var da = new q().setSubdomain(\"www\");\n            da.setPath(l.BASE_PATH);\n            return da;\n        },\n        goNextURI: function(da, ea) {\n            if (aa(da, ea)) {\n                var fa = t.getURI(da, ea);\n                g(fa);\n                return true;\n            }\n        ;\n        ;\n            return false;\n        },\n        getURI: function(da, ea) {\n            var fa = t.getDefaultURI();\n            if (((!da || !ea))) {\n                return fa;\n            }\n        ;\n        ;\n            switch (ea.folder) {\n              case r.MessagingTag.OTHER:\n                fa.setPath(l.OTHER_PATH);\n                break;\n              case r.MessagingTag.ACTION_ARCHIVED:\n                fa.setPath(l.ARCHIVED_PATH);\n                break;\n              case r.MessagingTag.SPAM:\n                fa.setPath(l.SPAM_PATH);\n                break;\n            };\n        ;\n            if (((ea.filter && ((ea.filter != j.ALL))))) {\n                fa.addQueryData({\n                    filter: ea.filter\n                });\n            }\n        ;\n        ;\n            var ga;\n            switch (da) {\n              case n.COMPOSE:\n                fa.setPath(((fa.getPath() + l.COMPOSE_POSTFIX_PATH)));\n                ga = false;\n                break;\n              case n.SEARCH_SNIPPET:\n            \n              case n.SEARCH_THREAD_SELECTION:\n            \n              case n.SEARCH_SNIPPET_SELECTION:\n                ga = false;\n                fa.setPath(((fa.getPath() + l.SEARCH_POSTFIX_PATH)));\n                break;\n              case n.SEARCH_THREAD:\n                ga = true;\n                fa.setPath(((fa.getPath() + l.SEARCH_POSTFIX_PATH)));\n                break;\n              case n.SELECTION:\n                ga = !ea.thread_id;\n                break;\n              default:\n                ga = true;\n                break;\n            };\n        ;\n            if (da) {\n                if (ga) {\n                    fa.addQueryData({\n                        action: da\n                    });\n                }\n            ;\n            ;\n                if (ea.thread_id) {\n                    var ha = m.getServerThreadIDNow(ea.thread_id), ia = ((ha ? ha : ea.thread_id));\n                    fa.setPath(l.getURIPathForThreadID(ia, fa.getPath()));\n                }\n            ;\n            ;\n                if (ea.query) {\n                    fa.addQueryData({\n                        query: ea.query\n                    });\n                }\n            ;\n            ;\n                if (ea.message_id) {\n                    fa.addQueryData({\n                        mid: ea.message_id\n                    });\n                }\n            ;\n            ;\n                if (ea.reuse_composer) {\n                    fa.addQueryData({\n                        rc: true\n                    });\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            return fa;\n        },\n        processURI: function(da) {\n            da = k(da);\n            if (!t.isWebMessengerURI(da)) {\n                return false;\n            }\n        ;\n        ;\n            var ea = ba(da);\n            if (!ea) {\n                return ca(da);\n            }\n        ;\n        ;\n            var fa = {\n                data: {\n                    folder: y(da),\n                    filter: z(da)\n                },\n                redirect: false,\n                state: ea\n            };\n            if (da.getQueryData().rc) {\n                fa.data.reuse_composer = true;\n            }\n        ;\n        ;\n            switch (ea) {\n              case n.SELECTION:\n                return x(da, fa);\n              case n.COMPOSE:\n                return u(da, fa);\n              case n.SEARCH_SNIPPET:\n                return w(da, fa);\n              case n.SEARCH_THREAD:\n            \n              case n.SEARCH_THREAD_SELECTION:\n                fa = w(da, fa);\n                return x(da, fa);\n              case n.SEARCH_SNIPPET_SELECTION:\n                fa = w(da, fa);\n                fa = x(da, fa);\n                return v(da, fa);\n            };\n        ;\n            fa.redirect = true;\n            return fa;\n        },\n        isWebMessengerURI: function(da) {\n            return (/^(\\/messages|\\/webmessenger)/).test(da.getPath());\n        }\n    };\n    function u(da, ea) {\n        var fa = da.getQueryData().to;\n        if (fa) {\n            var ga = i.getNow(((\"fbid:\" + fa)));\n            if (ga) {\n                var ha = {\n                    uid: fa,\n                    text: ga.JSBNG__name,\n                    type: s.USER_TYPE\n                };\n                ea.data.new_tokens = [new p(ha),];\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        ea.data.start = true;\n        ea.data.contents_state = n.COMPOSE_SHOWING_CONTEXT;\n        return ea;\n    };\n;\n    function v(da, ea) {\n        var fa = da.getQueryData().mid;\n        if (fa) {\n            ea.data.message_id = fa;\n        }\n         else ea.redirect = true;\n    ;\n    ;\n        return ea;\n    };\n;\n    function w(da, ea) {\n        var fa = da.getQueryData().query;\n        ea.data.query = fa;\n        return ea;\n    };\n;\n    function x(da, ea) {\n        var fa = l.getThreadIDFromURI(da);\n        if (fa) {\n            var ga = ((h.isValid(fa) ? fa : m.getClientThreadIDNow(fa)));\n            if (ga) {\n                ea.data.thread_id = ga;\n            }\n             else ea.redirect = true;\n        ;\n        ;\n        }\n         else {\n            var ha = l.getCanonicalUserID(da.getPath());\n            if (ha) {\n                var ia = o.getCanonicalThreadToUser(ha);\n                if (ia) {\n                    ea.data.thread_id = ia.thread_id;\n                }\n                 else ea.redirect = true;\n            ;\n            ;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        return ea;\n    };\n;\n    function y(da) {\n        var ea = da.getPath();\n        if (ea.match(((\"^\" + l.ARCHIVED_PATH)))) {\n            return r.MessagingTag.ACTION_ARCHIVED;\n        }\n    ;\n    ;\n        if (ea.match(((\"^\" + l.OTHER_PATH)))) {\n            return r.MessagingTag.OTHER;\n        }\n    ;\n    ;\n        if (ea.match(((\"^\" + l.SPAM_PATH)))) {\n            return r.MessagingTag.SPAM;\n        }\n    ;\n    ;\n        return r.MessagingTag.INBOX;\n    };\n;\n    function z(da) {\n        return ((da.getQueryData().filter || j.ALL));\n    };\n;\n    function aa(da, ea) {\n        if (((((da == n.COMPOSE)) && !ea.start))) {\n            return false;\n        }\n    ;\n    ;\n        if (((da == n.SEARCH_THREAD))) {\n            return false;\n        }\n    ;\n    ;\n        if (((!da || !ea))) {\n            return true;\n        }\n    ;\n    ;\n        if (ea.bug_reporting_enabled) {\n            return false;\n        }\n    ;\n    ;\n        return !ea.message_action;\n    };\n;\n    function ba(da) {\n        var ea = da.getQueryData();\n        if (ea.action) {\n            return ea.action;\n        }\n    ;\n    ;\n        var fa = da.getPath();\n        if (fa.match(((((l.BASE_PATH + \"(/[^/]+)?\")) + l.COMPOSE_POSTFIX_PATH)))) {\n            return n.COMPOSE;\n        }\n    ;\n    ;\n        var ga = fa.match(((((((l.BASE_PATH + \"(/[^/]+)?\")) + l.SEARCH_POSTFIX_PATH)) + \"(/[^/]+)?\")));\n        if (ga) {\n            var ha = ga[2];\n            if (((ha && ha.match(l.TID_POSTFIX_PARTIAL_PATH)))) {\n                if (ea.mid) {\n                    return n.SEARCH_SNIPPET_SELECTION;\n                }\n                 else return n.SEARCH_THREAD_SELECTION\n            ;\n            }\n             else return n.SEARCH_SNIPPET\n        ;\n        }\n    ;\n    ;\n        if (((fa.match(l.TID_POSTFIX_PARTIAL_PATH) || l.getCanonicalUserID(fa)))) {\n            return n.SELECTION;\n        }\n    ;\n    ;\n    };\n;\n    function ca(da) {\n        var ea = {\n            redirect: false,\n            state: n.COMPOSE,\n            data: {\n                contents_state: n.COMPOSE_SHOWING_CONTEXT,\n                folder: y(da),\n                filter: z(da),\n                start: true\n            }\n        };\n        return ea;\n    };\n;\n    e.exports = t;\n});\n__d(\"MercuryJewelThreadlistControl\", [\"event-extensions\",\"ArbiterMixin\",\"CSS\",\"DOM\",\"MercuryOrderedThreadlist\",\"Parent\",\"MercuryThreadInformer\",\"MercuryThreadMetadataRenderer\",\"MercuryThreads\",\"WebMessengerPermalinks\",\"WebMessengerStateConstants\",\"copyProperties\",\"tx\",\"MercuryConfig\",\"MercuryConstants\",\"MercuryJewelTemplates\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"MercuryOrderedThreadlist\"), k = b(\"Parent\"), l = b(\"MercuryThreadInformer\"), m = b(\"MercuryThreadMetadataRenderer\"), n = b(\"MercuryThreads\"), o = b(\"WebMessengerPermalinks\"), p = b(\"WebMessengerStateConstants\"), q = b(\"copyProperties\"), r = b(\"tx\"), s = c(\"MercuryConfig\"), t = c(\"MercuryConstants\"), u = c(\"MercuryJewelTemplates\");\n    function v(w) {\n        this._rootElement = w;\n        this._contentElement = i.JSBNG__find(this._rootElement, \".jewelContent\");\n        this._loadingElement = i.JSBNG__find(this._rootElement, \".jewelLoading\");\n        l.subscribe(\"threadlist-updated\", this.render.bind(this));\n        this.render();\n    };\n;\n    q(v, {\n        EVENT_THREADS_LOADED: \"threads-loaded\",\n        EVENT_THREADS_RENDERED: \"threads-rendered\"\n    });\n    q(v.prototype, g);\n    q(v.prototype, {\n        render: function() {\n            i.empty(this._contentElement);\n            h.show(this._loadingElement);\n            var w = i.create(\"div\");\n            i.appendContent(this._contentElement, w);\n            j.getThreadlist(t.MercuryThreadlistConstants.RECENT_THREAD_OFFSET, t.MercuryThreadlistConstants.JEWEL_THREAD_COUNT, t.MessagingTag.INBOX, this.renderThreads.bind(this, w), true);\n        },\n        renderThreads: function(w, x) {\n            this.inform(v.EVENT_THREADS_LOADED);\n            if (x.length) {\n                x.forEach(function(y) {\n                    var z = u[\":fb:mercury:jewel:threadlist-row\"].build();\n                    n.getThreadMeta(y, function(aa) {\n                        m.renderCoreThreadlist(aa, z, this.renderSingleThread.bind(this), {\n                            show_unread_count: true\n                        });\n                    }.bind(this));\n                    i.appendContent(w, z.getRoot());\n                }.bind(this));\n            }\n             else i.setContent(this._rootElement, this.renderEmptyThreadlist());\n        ;\n        ;\n            h.hide(this._loadingElement);\n            this.inform(v.EVENT_THREADS_RENDERED);\n        },\n        renderSingleThread: function(w, x) {\n            if (((x.unread_count > 0))) {\n                h.addClass(w.getRoot(), \"jewelItemNew\");\n            }\n        ;\n        ;\n            if (s.MessagesMercuryIntegrationGK) {\n                w.getNode(\"link\").setAttribute(\"href\", o.getURI(p.SELECTION, {\n                    thread_id: x.thread_id\n                }).toString());\n            }\n             else m.renderTitanLink(x.thread_id, w.getNode(\"link\"));\n        ;\n        ;\n            JSBNG__Event.listen(w.getRoot(), \"mouseover\", function(JSBNG__event) {\n                var y = w.getRoot();\n                if (!k.byClass(y, \"notifNegativeBase\")) {\n                    h.addClass(y, \"selected\");\n                }\n            ;\n            ;\n            });\n            JSBNG__Event.listen(w.getRoot(), \"mouseout\", function(JSBNG__event) {\n                h.removeClass(w.getRoot(), \"selected\");\n            });\n        },\n        renderEmptyThreadlist: function() {\n            return i.create(\"li\", {\n                className: \"empty\"\n            }, \"No messages\");\n        }\n    });\n    e.exports = v;\n});\n__d(\"MercuryJewel\", [\"MercuryChannelHandler\",\"MercuryJewelCountControl\",\"DOM\",\"MercuryJewelThreadlistControl\",\"MercuryServerRequests\",\"userAction\",], function(a, b, c, d, e, f) {\n    b(\"MercuryChannelHandler\");\n    var g = b(\"MercuryJewelCountControl\"), h = b(\"DOM\"), i = b(\"MercuryJewelThreadlistControl\"), j = b(\"MercuryServerRequests\"), k = b(\"userAction\"), l = false;\n    function m(q, r, s, t) {\n        j.handleUpdate(t);\n        var u = new g(r, s), v = h.JSBNG__find(q, \"#MercuryJewelThreadList\");\n        if (((s.getRoot() && s.isOpen()))) {\n            n.call(this, v);\n        }\n         else s.subscribe(\"opened\", n.bind(this, v));\n    ;\n    ;\n    };\n;\n    e.exports = m;\n    function n(q) {\n        this._ua = k(\"click\").set_namespace(\"messages\").set_ua_id(\"jewel\");\n        this._listenForLoad = this._listenForRender = true;\n        if (!l) {\n            var r = new i(q);\n            r.subscribe(i.EVENT_THREADS_LOADED, o.bind(this));\n            r.subscribe(i.EVENT_THREADS_RENDERED, p.bind(this));\n            l = true;\n        }\n    ;\n    ;\n    };\n;\n    function o() {\n        if (this._listenForLoad) {\n            this._ua.add_event(\"loaded\");\n            this._listenForLoad = false;\n        }\n    ;\n    ;\n    };\n;\n    function p() {\n        if (this._listenForRender) {\n            this._ua.add_event(\"rendered\");\n            this._listenForRender = false;\n        }\n    ;\n    ;\n    };\n;\n});\n__d(\"TitanLeftNav\", [\"CounterDisplay\",\"MessagingEvents\",], function(a, b, c, d, e, f) {\n    var g = b(\"CounterDisplay\"), h = b(\"MessagingEvents\"), i = {\n        initialize: function() {\n            h.subscribe(\"count/other_unseen\", function(j, k) {\n                g.setCount(\"other_unseen\", k);\n            });\n        }\n    };\n    e.exports = i;\n});\n__d(\"MercuryStateCheck\", [\"Arbiter\",\"copyProperties\",\"ChannelConnection\",\"ChannelConstants\",\"MercuryFolders\",\"MercuryServerRequests\",\"URI\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"copyProperties\"), i = b(\"ChannelConnection\"), j = b(\"ChannelConstants\"), k = b(\"MercuryFolders\"), l = b(\"MercuryServerRequests\"), m = b(\"URI\"), n = c(\"MercuryConstants\"), o = h(new g(), {\n        initialize: function() {\n            g.subscribe(j.ON_INVALID_HISTORY, p);\n            i.subscribe(i.CONNECTED, function(q, r) {\n                if (!r.init) {\n                    p();\n                }\n            ;\n            ;\n            });\n        }\n    });\n    function p() {\n        var q;\n        if (((m.getRequestURI().getPath().search(/webmessenger/) !== -1))) {\n            q = k.getSupportedFolders();\n        }\n         else q = [n.MessagingTag.INBOX,];\n    ;\n    ;\n        l.fetchMissedMessages(q);\n    };\n;\n    o.initialize();\n    e.exports = o;\n});\n__d(\"LiveMessageReceiver\", [\"Arbiter\",\"AsyncRequest\",\"ChannelConstants\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"ChannelConstants\"), j = b(\"copyProperties\");\n    function k(l) {\n        this.eventName = l;\n        this.subs = null;\n        this.handler = bagofholding;\n        this.shutdownHandler = null;\n        this.registered = false;\n        this.appId = 1;\n    };\n;\n    j(k, {\n        getAppMessageType: function(l, m) {\n            return ((((((\"live_message/\" + l)) + \":\")) + m));\n        },\n        route: function(l) {\n            var m = function(n) {\n                var o = k.getAppMessageType(l.app_id, l.event_name);\n                g.inform(o, n, g.BEHAVIOR_PERSISTENT);\n            };\n            if (l.hasCapture) {\n                new h().setHandler(function(n) {\n                    m(n.getPayload());\n                }).setAllowCrossPageTransition(true).handleResponse(l.response);\n            }\n             else m(l.response);\n        ;\n        ;\n        }\n    });\n    j(k.prototype, {\n        setAppId: function(l) {\n            this.appId = l;\n            return this;\n        },\n        setHandler: function(l) {\n            this.handler = l;\n            this._dirty();\n            return this;\n        },\n        setRestartHandler: bagofholding,\n        setShutdownHandler: function(l) {\n            this.shutdownHandler = l.shield();\n            this._dirty();\n            return this;\n        },\n        _dirty: function() {\n            if (this.registered) {\n                this.unregister();\n                this.register();\n            }\n        ;\n        ;\n        },\n        register: function() {\n            var l = function(n, o) {\n                return this.handler(o);\n            }.bind(this), m = k.getAppMessageType(this.appId, this.eventName);\n            this.subs = {\n            };\n            this.subs.main = g.subscribe(m, l);\n            if (this.shutdownHandler) {\n                this.subs.shut = g.subscribe(i.ON_SHUTDOWN, this.shutdownHandler);\n            }\n        ;\n        ;\n            this.registered = true;\n            return this;\n        },\n        unregister: function() {\n            if (!this.subs) {\n                return this;\n            }\n        ;\n        ;\n            for (var l in this.subs) {\n                if (this.subs[l]) {\n                    this.subs[l].unsubscribe();\n                }\n            ;\n            ;\n            };\n        ;\n            this.subs = null;\n            this.registered = false;\n            return this;\n        }\n    });\n    e.exports = k;\n});\nfunction PresenceIndicator() {\n\n};\n;\ncopyProperties(PresenceIndicator.prototype, {\n    init: function(a, b, c) {\n        this._id = a;\n        this._firstname = b;\n        this._tooltip = c;\n        this._image = DOM.scry(this._tooltip, \"i\")[0];\n        this._previousAvail = null;\n        this._jslog = JSLogger.create(\"presence_indicator\");\n        requireLazy([\"ChatVisibility\",], function(e) {\n            this._jslog.log(\"vis_init\", e.isOnline());\n            this._chatVisibility = e;\n            this._updateVisibility();\n        }.bind(this));\n        this._subscriptions = [Arbiter.subscribe([AvailableListConstants.ON_AVAILABILITY_CHANGED,], this._updateAvailability.bind(this)),Arbiter.subscribe([\"chat/visibility-changed\",], this._updateVisibility.bind(this)),];\n        this._updateAvailability.bind(this).defer();\n        var d = JSBNG__Event.listen(this._tooltip, \"click\", function() {\n            requireLazy([\"AvailableList\",], function(e) {\n                if (((this._previousAvail != AvailableListConstants.OFFLINE))) {\n                    Chat.openTab(this._id);\n                }\n            ;\n            ;\n            }.bind(this));\n        }.bind(this));\n        JSBNG__onleaveRegister(function() {\n            d.remove();\n            while (this._subscriptions.length) {\n                Arbiter.unsubscribe(this._subscriptions.pop());\n            ;\n            };\n        ;\n        }.bind(this));\n    },\n    _updateAvailability: function() {\n        requireLazy([\"AvailableList\",\"ChatConfig\",], function(a, b) {\n            if (!a.isReady()) {\n                return;\n            }\n        ;\n        ;\n            var c, d, e = a.get(this._id);\n            if (((e === this._previousAvail))) {\n                return;\n            }\n        ;\n        ;\n            this._previousAvail = e;\n            switch (e) {\n              case AvailableListConstants.OFFLINE:\n                c = tx._(\"{name} is offline\", {\n                    JSBNG__name: this._firstname\n                });\n                d = \"offline\";\n                break;\n              case AvailableListConstants.IDLE:\n                c = tx._(\"{name} is idle\", {\n                    JSBNG__name: this._firstname\n                });\n                d = \"idle\";\n                break;\n              case AvailableListConstants.ACTIVE:\n                c = tx._(\"{name} is online\", {\n                    JSBNG__name: this._firstname\n                });\n                d = \"JSBNG__online\";\n                break;\n              case AvailableListConstants.MOBILE:\n                c = tx._(\"{name} is available on mobile\", {\n                    JSBNG__name: this._firstname\n                });\n                d = \"mobile\";\n                break;\n              default:\n                throw new Error(\"Invalid availability\");\n            };\n        ;\n            TooltipLink.setTooltipText(this._tooltip, c);\n            CSS.setClass(this._image, d);\n        }.bind(this));\n    },\n    _updateVisibility: function() {\n        if (this._chatVisibility.isOnline()) {\n            CSS.show(this._tooltip);\n        }\n         else CSS.hide(this._tooltip);\n    ;\n    ;\n    }\n});\n__d(\"legacy:livemessage\", [\"LiveMessageReceiver\",], function(a, b, c, d) {\n    a.LiveMessageReceiver = b(\"LiveMessageReceiver\");\n}, 3);");
// 2892
JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_84[0](o25,false,o26);
// undefined
o25 = null;
// undefined
o26 = null;
// 2900
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"6n1TR\",]);\n}\n;\n__d(\"legacy:fbdesktop-plugin\", [\"FBDesktopPlugin\",], function(a, b, c, d) {\n    a.FbDesktopPlugin = b(\"FBDesktopPlugin\");\n}, 3);\n__d(\"FbdEventLog\", [\"URI\",\"AsyncSignal\",], function(a, b, c, d, e, f) {\n    var g = b(\"URI\"), h = b(\"AsyncSignal\"), i = {\n        log: function(j, k, l, m) {\n            if (!j) {\n                return\n            };\n            var n = g(\"/desktop/eventlog.php\"), o = new h(n.toString(), {\n                event: j,\n                category: (k || \"unknown\"),\n                payload: (l || \"\")\n            });\n            o.setHandler(m).send();\n        }\n    };\n    e.exports = i;\n});\n__d(\"ModalMask\", [\"DOM\",\"UserAgent\",\"Vector\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"UserAgent\"), i = b(\"Vector\"), j = {\n        _modalMask: null,\n        _depth: 0,\n        show: function() {\n            if (!this._modalMask) {\n                this._modalMask = g.create(\"div\", {\n                    id: \"modalMaskOverlay\"\n                });\n                g.appendContent(document.body, this._modalMask);\n            }\n        ;\n            this._depth++;\n            if ((h.ie() < 7)) {\n                this._modalMask.height = (i.getDocumentDimensions().y + \"px\");\n            };\n        },\n        hide: function() {\n            this._depth--;\n            if ((!this._depth && this._modalMask)) {\n                g.remove(this._modalMask);\n                this._modalMask = null;\n            }\n        ;\n        }\n    };\n    e.exports = j;\n});\n__d(\"DownloadDialog\", [\"event-extensions\",\"Arbiter\",\"Class\",\"CSS\",\"DataStore\",\"ModalMask\",\"Overlay\",\"Parent\",\"Style\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"Class\"), i = b(\"CSS\"), j = b(\"DataStore\"), k = b(\"ModalMask\"), l = b(\"Overlay\"), m = b(\"Parent\"), n = b(\"Style\"), o = b(\"copyProperties\");\n    function p() {\n        this.parent.construct(this);\n        return this;\n    };\n    h.extend(p, l);\n    o(p, {\n        POSITIONS: {\n            BOTTOM_LEFT: \"bottom_left\",\n            TOP_LEFT: \"top_left\",\n            IE9_BOTTOM: \"ie9_bottom\"\n        },\n        activeDialogs: {\n        },\n        dismissAll: function() {\n            for (var q in this.POSITIONS) {\n                this.hideDialog(this.POSITIONS[q]);;\n            };\n        },\n        hideDialog: function(q) {\n            var r = this.activeDialogs[q];\n            (r && r.hide());\n            this.activeDialogs[q] = null;\n        }\n    });\n    o(p.prototype, {\n        _cancelHandler: bagofholding,\n        _closeHandler: bagofholding,\n        _width: null,\n        position: p.POSITIONS.BOTTOM_LEFT,\n        init: function(q, r) {\n            this.parent.init(q);\n            this.position = r;\n            var s = ((j.get(this._root, \"modal\") === \"true\"));\n            p.hideDialog(r);\n            p.activeDialogs[r] = this;\n            Event.listen(this._root, \"click\", function(event) {\n                if (m.byClass(event.getTarget(), \"closeButton\")) {\n                    if ((this._cancelHandler() !== false)) {\n                        p.hideDialog(this.position);\n                    }\n                };\n            }.bind(this));\n            this.subscribe(\"show\", function() {\n                if (s) {\n                    k.show();\n                };\n                g.inform(\"layer_shown\", {\n                    type: \"DownloadDialog\"\n                });\n            }.bind(this));\n            this.subscribe(\"hide\", function() {\n                if (s) {\n                    k.hide();\n                };\n                g.inform(\"layer_hidden\", {\n                    type: \"DownloadDialog\"\n                });\n                this._closeHandler();\n            }.bind(this));\n        },\n        setWidth: function(q) {\n            this._width = Math.floor(q);\n            return this;\n        },\n        updatePosition: function() {\n            if (this._width) {\n                n.set(this._overlay, \"width\", (this._width + \"px\"));\n            };\n            return true;\n        },\n        setCancelHandler: function(q) {\n            this._cancelHandler = (q || bagofholding);\n            return this;\n        },\n        setCloseHandler: function(q) {\n            this._closeHandler = (q || bagofholding);\n            return this;\n        }\n    });\n    e.exports = p;\n});\n__d(\"FbdConversionTracking\", [\"AsyncRequest\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncRequest\"), h = {\n        logClick: function(i) {\n            new g().setURI(\"/ajax/desktop/log_clicks.php\").setData({\n                click_source: i\n            }).setAllowCrossPageTransition(true).setErrorHandler(bagofholding).send();\n        },\n        logConversion: function(i) {\n            new g().setURI(\"/ajax/desktop/log_conversions.php\").setData({\n                conversion_action: i\n            }).setAllowCrossPageTransition(true).setErrorHandler(bagofholding).send();\n        }\n    };\n    e.exports = h;\n});\n__d(\"MegaphoneHelper\", [\"Animation\",\"AsyncRequest\",\"Dialog\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"Animation\"), h = b(\"AsyncRequest\"), i = b(\"Dialog\"), j = b(\"ge\"), k = {\n        hideStory: function(l, m, n, o, p) {\n            var q = {\n                mp_id: l,\n                location: m,\n                context: o\n            };\n            new h().setURI(\"/ajax/megaphone/megaphone_hide.php\").setMethod(\"POST\").setData(q).setHandler(function(s) {\n                (p && p(s));\n            }).send();\n            var r = j(n);\n            if (r) {\n                g(r).to(\"height\", 0).duration(500).hide().go();\n            };\n        },\n        createModalStory: function(l, m, n, o) {\n            var p;\n            if ((!l.buttons || !l.buttons.length)) {\n                l.buttons = i.CLOSE;\n                p = this.hideStory.bind(this, m, n, o, null);\n            }\n        ;\n            var q = new i(l);\n            if (p) {\n                q.setHandler(p);\n            };\n            q.show();\n        },\n        buttonOnClick: function(l, m, n, o, p, q) {\n            var r = function() {\n                if (p) {\n                    new h().setURI(o).send();\n                }\n                 else document.location.href = o;\n            ;\n            };\n            if (q) {\n                this.hideStory(l, m, \"\", n, function() {\n                    r();\n                });\n            }\n             else r();\n        ;\n        }\n    };\n    e.exports = k;\n});\n__d(\"FbdInstall\", [\"$\",\"AsyncRequest\",\"CSS\",\"DOM\",\"DownloadDialog\",\"FbdConversionTracking\",\"FbdEventLog\",\"FBDesktopDetect\",\"FBDesktopPlugin\",\"MegaphoneHelper\",], function(a, b, c, d, e, f) {\n    var g = b(\"$\"), h = b(\"AsyncRequest\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"DownloadDialog\"), l = b(\"FbdConversionTracking\"), m = b(\"FbdEventLog\"), n = b(\"FBDesktopDetect\"), o = b(\"FBDesktopPlugin\"), p = b(\"MegaphoneHelper\"), q = 1000, r = (300 * q), s = {\n        cancelSetup: function() {\n            var t = JSON.stringify({\n                ref: this.ref\n            });\n            m.log(\"download_canceled\", \"setup\", t);\n            l.logConversion(\"download_canceled\");\n        },\n        hideMegaphone: function() {\n            if ((this.megaphoneId && this.megaphoneLoc)) {\n                p.hideStory(this.megaphoneId, this.megaphoneLoc, this.elementId, \"\", null);\n            };\n        },\n        init: function(t, u) {\n            this.downloadUrl = t;\n            this.ref = (u || \"unknown\");\n        },\n        initInstallWait: function(t, u, v) {\n            this.megaphoneId = t;\n            this.megaphoneLoc = u;\n            this.elementId = v;\n            this._waitForInstall(r);\n        },\n        promptDownload: function(t) {\n            t = (t || this.downloadUrl);\n            if (t) {\n                var u = JSON.stringify({\n                    ref: this.ref\n                });\n                m.log(\"download_prompted\", \"setup\", u);\n                l.logConversion(\"download_prompted\");\n                var v = j.create(\"iframe\", {\n                    src: t,\n                    className: \"hidden_elem\"\n                });\n                j.appendContent(document.body, v);\n            }\n        ;\n        },\n        _responseHandler: function(t) {\n            if (t.payload) {\n                this._authToken = t.payload.access_token;\n                this._userId = t.payload.id;\n            }\n        ;\n            if ((this._authToken && this._userId)) {\n                this._waitForRunningStart = new Date().getTime();\n                setTimeout(this._waitForRunning.bind(this), q);\n            }\n        ;\n        },\n        setupPlugin: function() {\n            new h(\"/ajax/desktop/download\").send();\n            this.promptDownload();\n        },\n        updateSidebarLinkVisibility: function() {\n            if (!n.isPluginInstalled()) {\n                i.show(g(\"sidebar-messenger-install-link\"));\n                i.show(g(\"sidebar-messenger-install-separator\"));\n            }\n        ;\n        },\n        _waitForInstall: function(t) {\n            var u = JSON.stringify({\n                ref: this.ref\n            });\n            if (n.isPluginInstalled()) {\n                m.log(\"install_success\", \"setup\", u);\n                l.logConversion(\"install_success\");\n                o.recheck();\n                new h(\"/desktop/fbdesktop2/transfer.php\").setMethod(\"POST\").setHandler(this._responseHandler.bind(this)).send();\n                k.dismissAll();\n                this.hideMegaphone();\n                return;\n            }\n        ;\n            if ((t <= 0)) {\n                m.log(\"install_timeout\", \"setup\", u);\n                l.logConversion(\"install_timeout\");\n                k.dismissAll();\n            }\n             else setTimeout(this._waitForInstall.bind(this, (t - q)), q);\n        ;\n        },\n        _waitForRunning: function() {\n            var t = (new Date().getTime() - this._waitForRunningStart);\n            if (o.isAppRunning()) {\n                o.transferAuthToken(this._authToken, this._userId);\n            }\n             else if ((t < r)) {\n                setTimeout(this._waitForRunning.bind(this), q);\n            }\n        ;\n        }\n    };\n    e.exports = s;\n});\n__d(\"legacy:fbdesktop2-install-js\", [\"FbdInstall\",], function(a, b, c, d) {\n    a.FbdInstall = b(\"FbdInstall\");\n}, 3);\n__d(\"FbdPromo\", [\"event-extensions\",\"Arbiter\",\"AsyncRequest\",\"ChatSidebar\",\"copyProperties\",\"CSS\",\"DOM\",\"FbdConversionTracking\",\"FBDesktopDetect\",\"FbdInstall\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"ChatSidebar\"), j = b(\"copyProperties\"), k = b(\"CSS\"), l = b(\"DOM\"), m = b(\"FbdConversionTracking\"), n = b(\"FBDesktopDetect\"), o = b(\"FbdInstall\"), p = \"show\", q = \"install\", r = \"cancel\", s = \"learn_more\";\n    function t(u, v, w) {\n        this._root = u;\n        Event.listen(l.find(u, \".install-button\"), \"click\", this.installClick.bind(this, v));\n        Event.listen(l.find(u, \".learn-more\"), \"click\", this.learnMoreClick.bind(this));\n        Event.listen(l.find(u, \".promo-close-button\"), \"click\", this.cancelClick.bind(this));\n        this.type = w;\n        this.showPromo();\n    };\n    j(t.prototype, {\n        cancelClick: function() {\n            this.hidePromo();\n            this.postPromoAction(r);\n        },\n        hidePromo: function(u) {\n            k.hide(this._root);\n            i.resize();\n        },\n        installClick: function(u) {\n            o.init(u, this.type);\n            o.setupPlugin();\n            this.postPromoAction(q);\n            setTimeout(function() {\n                this.hidePromo();\n            }.bind(this), 3000);\n        },\n        learnMoreClick: function() {\n            this.postPromoAction(s);\n        },\n        postPromoAction: function(u) {\n            new h(\"/ajax/desktop/promo_action.php\").setMethod(\"POST\").setData({\n                action: u,\n                type: this.type\n            }).send();\n            m.logClick(((this.type + \"_promo_\") + u));\n        },\n        showPromo: function() {\n            if (n.isPluginInstalled()) {\n                return\n            };\n            k.show(this._root);\n            if (i.isVisible()) {\n                this.postPromoAction(p);\n            }\n             else {\n                var u = true;\n                g.subscribe(\"sidebar/show\", function() {\n                    if (u) {\n                        u = false;\n                        this.postPromoAction(p);\n                    }\n                ;\n                }.bind(this));\n            }\n        ;\n        }\n    });\n    e.exports = t;\n});\n__d(\"legacy:fbdesktop-conversion-tracking\", [\"FbdConversionTracking\",], function(a, b, c, d) {\n    a.FbdConversionTracking = b(\"FbdConversionTracking\");\n}, 3);\nfunction FriendBrowserCheckboxController() {\n\n};\ncopyProperties(FriendBrowserCheckboxController, {\n    instances: {\n    },\n    getInstance: function(a) {\n        return this.instances[a];\n    }\n});\ncopyProperties(FriendBrowserCheckboxController.prototype, {\n    init: function(a, b) {\n        FriendBrowserCheckboxController.instances[a] = this;\n        this._id = a;\n        this._form = b;\n        this._contentGrid = DOM.find(b, \".friendBrowserCheckboxContentGrid\");\n        this._loadingIndicator = DOM.find(b, \".friendBrowsingCheckboxContentLoadingIndicator\");\n        this._checkboxResults = DOM.find(b, \".friendBrowserCheckboxResults\");\n        this._contentPager = DOM.find(b, \".friendBrowserCheckboxContentPager\");\n        this.numGetNewRequests = 0;\n        this.queuedRequests = {\n        };\n    },\n    addTypeahead: function(a, b) {\n        a.subscribe(\"select\", this.onHubSelect.bind(this, a, b));\n    },\n    onHubSelect: function(a, b, event, c) {\n        if (!((((event == \"select\")) && c.selected))) {\n            return\n        };\n        var d = this.buildNewCheckbox(b, c.selected.text, c.selected.uid), e = DOM.find(this._form, (\".checkboxes_\" + b));\n        DOM.appendContent(e.firstChild, d);\n        var f = DOM.scry(a.getElement(), \"input[type=\\\"button\\\"]\");\n        if ((f && f[0])) {\n            f[0].click();\n        };\n        this.getNew(true);\n    },\n    buildNewCheckbox: function(a, b, c) {\n        var d = ((a + \"_ids_\") + c), e = (a + \"_ids[]\"), f = DOM.create(\"input\", {\n            id: d,\n            type: \"checkbox\",\n            value: c,\n            name: e,\n            checked: true\n        });\n        Event.listen(f, \"click\", bind(this, \"getNew\", false));\n        var g = DOM.create(\"td\", null, f);\n        CSS.addClass(g, \"vTop\");\n        CSS.addClass(g, \"hLeft\");\n        var h = DOM.create(\"label\", null, b), i = DOM.create(\"td\", null, h);\n        CSS.addClass(i, \"vMid\");\n        CSS.addClass(i, \"hLeft\");\n        var j = DOM.create(\"tr\");\n        j.appendChild(g);\n        j.appendChild(i);\n        return j;\n    },\n    showMore: function() {\n        var a = DOM.scry(this._contentPager, \".friendBrowserMorePager\")[0];\n        if (!a) {\n            return false\n        };\n        if (CSS.hasClass(a, \"async_saving\")) {\n            return false\n        };\n        var b = this.numGetNewRequests, c = Form.serialize(this._form);\n        c.show_more = true;\n        var d = new AsyncRequest().setURI(\"/ajax/growth/friend_browser/checkbox.php\").setData(c).setHandler(bind(this, function(e) {\n            this.showMoreHandler(e, b);\n        })).setStatusElement(a).send();\n    },\n    showMoreHandler: function(a, b) {\n        if ((b == this.numGetNewRequests)) {\n            var c = a.payload;\n            DOM.appendContent(this._contentGrid, c.results);\n            this.updatePagerAndExtraData(c.pager, c.extra_data);\n        }\n    ;\n    },\n    getNew: function(a) {\n        this.numGetNewRequests++;\n        var b = this.numGetNewRequests;\n        CSS.addClass(this._checkboxResults, \"friendBrowserCheckboxContentOnload\");\n        if (ge(\"friendBrowserCI\")) {\n            CSS.addClass($(\"friendBrowserCI\"), \"friendBrowserCheckboxContentOnload\");\n        };\n        CSS.show(this._loadingIndicator);\n        var c = Form.serialize(this._form);\n        c.used_typeahead = a;\n        new AsyncRequest().setURI(\"/ajax/growth/friend_browser/checkbox.php\").setData(c).setHandler(bind(this, function(d) {\n            this.getNewHandler(d, b);\n        })).send();\n    },\n    getNewHandler: function(a, b) {\n        if ((b == this.numGetNewRequests)) {\n            var c = a.payload;\n            DOM.setContent(this._contentGrid, c.results);\n            CSS.removeClass(this._checkboxResults, \"friendBrowserCheckboxContentOnload\");\n            if (ge(\"friendBrowserCI\")) {\n                CSS.hide($(\"friendBrowserCI\"));\n            };\n            CSS.hide(this._loadingIndicator);\n            this.updatePagerAndExtraData(c.pager, c.extra_data);\n        }\n    ;\n    },\n    updatePagerAndExtraData: function(a, b) {\n        DOM.setContent(this._contentPager, a);\n        this.setupOnVisible();\n        DOM.replace(this._form.elements.extra_data, b);\n    },\n    setupOnVisible: function() {\n        var a = DOM.scry(this._contentPager, \".friendBrowserMorePager\")[0];\n        if ((a && (this._id != \"jewel\"))) {\n            (this._onVisible && this._onVisible.remove());\n            this._onVisible = new OnVisible(a, bind(this, \"showMore\"), false, 1000);\n        }\n    ;\n    }\n});\n__d(\"legacy:SimpleDrag\", [\"SimpleDrag\",], function(a, b, c, d) {\n    a.SimpleDrag = b(\"SimpleDrag\");\n}, 3);\nfunction SidebarTicker() {\n\n};\ncopyProperties(SidebarTicker.prototype, {\n    ALMOST_ZERO: 1e-7,\n    init: function() {\n        this._ticker = $(\"pagelet_ticker\");\n        this._initSubscriptions();\n        if (CSS.hasClass(document.documentElement, \"sidebarMode\")) {\n            this._onSidebarShow();\n        };\n        return this;\n    },\n    initResizeBehavior: function(a) {\n        var b = this._ticker, c = b.parentNode, d = this._saveResizedState.bind(this), e = this.ALMOST_ZERO, f, g, h, i = function(l, event) {\n            f = event.clientY;\n            g = b.offsetHeight;\n            h = c.offsetHeight;\n        }, j = function(l, event) {\n            var m = (g + ((event.clientY - f))), n = (100 - ((((((h - m)) / h)) * 100)));\n            n = Math.max(e, Math.min(90, n));\n            b.style.height = (n + \"\u0025\");\n            if ((l == \"end\")) {\n                d(n);\n                Arbiter.inform(\"Ticker/resized\");\n            }\n        ;\n            (window.ChatSidebar && ChatSidebar.resize());\n        }, k = new SimpleDrag(a);\n        k.subscribe(\"start\", i);\n        k.subscribe([\"update\",\"end\",], j);\n    },\n    _saveResizedState: function(a) {\n        new AsyncRequest(\"/ajax/feed/ticker/resize\").setData({\n            height: (\"\" + a)\n        }).setMethod(\"POST\").send();\n    },\n    _initSubscriptions: function() {\n        this._subscriptions = [Arbiter.subscribe(\"sidebar/show\", this._onSidebarShow.bind(this)),];\n    },\n    _onSidebarShow: function() {\n        TickerController.show(this._ticker);\n    }\n});\nfunction RequestsJewel() {\n\n};\ncopyProperties(RequestsJewel.prototype, {\n    init: function(a, b, c) {\n        this.countNew = 0;\n        this.jewel = a;\n        this.jewelFlyoutCase = a.getRoot();\n        this.jewelFlyout = ge(\"fbRequestsFlyout\");\n        this.newCountSpan = ge(\"newRequestCount\");\n        this.folder = b;\n        this.doNewMarkRead = c;\n        this._requestList = {\n        };\n        this._requestCount = 0;\n        var d = ge(\"requestsMarkReadButton\");\n        if (d) {\n            Event.listen(d, \"click\", this._markRead.shield(this));\n        };\n        this.jewel.subscribe(\"marked-seen\", this._markSeenCallback.shield(this));\n        this.jewel.subscribe(\"closed\", this._clearNewItems.shield(this));\n        this.jewel.subscribe(\"updated\", this._updateCount.bind(this));\n        this.jewel.subscribe(\"opened\", this._openHandler.bind(this));\n        LinkController.registerHandler(this._handleLink.bind(this));\n        Arbiter.subscribe(ChannelConstants.getArbiterType(\"jewel_requests_add\"), this._addRequest.bind(this));\n        Arbiter.subscribe(ChannelConstants.getArbiterType(\"jewel_requests_remove_old\"), this._removeOldRequest.bind(this));\n        Event.listen(this.jewelFlyout, \"submit\", function(f) {\n            var g = Parent.byClass(f.getTarget(), \"objectListItem\");\n            if (g) {\n                CSS.removeClass(g, \"jewelItemNew\");\n                CSS.addClass(g, \"jewelItemResponded\");\n            }\n        ;\n        }.bind(this));\n        var e = DOM.scry(this.jewelFlyout, \".uiScrollableAreaWrap\")[0];\n        if (e) {\n            this._scrollableWrap = e;\n            this._lastLinkPosition = 0;\n            this._scrollListener = Event.listen(e, \"scroll\", this._handleScroll.bind(this), Event.Priority._BUBBLE);\n        }\n    ;\n        return this;\n    },\n    fromDom: function() {\n        DOM.scry(this.jewelFlyout, \".jewelItemList li.objectListItem\").forEach(function(a) {\n            var b = a.getAttribute(\"id\"), c = (b && parseInt(this._parseID(b).requester, 10));\n            if ((c && !isNaN(c))) {\n                this._requestList[c] = b;\n                ++this._requestCount;\n            }\n        ;\n        }.bind(this));\n        this._conditionShowEmptyMessage();\n    },\n    _parseID: function(a) {\n        var b = a.match(/^(\\d+)_(\\d+)/);\n        return ((b) ? {\n            requester: b[1],\n            type: b[2]\n        } : undefined);\n    },\n    _handleLink: function(a, event) {\n        var b = Parent.byClass(a, \"jewelItemNew\");\n        if (((b && Parent.byClass(b, \"fbRequestList\")) && Parent.byClass(b, \"beeperEnabled\"))) {\n            var c = this._parseID(b.id);\n            (c && this._markSeenCallback(c.requester, c.type));\n            Arbiter.inform(\"jewel/count-updated\", {\n                jewel: \"requests\",\n                count: --this.countNew\n            });\n            CSS.removeClass(b, \"jewelItemNew\");\n        }\n    ;\n        return true;\n    },\n    _handleScroll: function() {\n        var a = DOM.scry(this._scrollableWrap, \".uiMorePager\")[0];\n        if (a) {\n            var b = Vector2.getElementPosition(a, \"viewport\").y;\n            if ((b > 0)) {\n                CSS.addClass(Parent.byClass(this._scrollableWrap, \"uiScrollableArea\"), \"contentAfter\");\n            };\n            var c = DOM.find(a, \"a\");\n            if (!c) {\n                return\n            };\n            var d = Vector2.getElementPosition(c, \"viewport\").y;\n            if ((d == this._lastLinkPosition)) {\n                return\n            };\n            var e = (Vector2.getElementPosition(this._scrollableWrap, \"viewport\").y + Vector2.getElementDimensions(this._scrollableWrap).y);\n            if ((((d - 300) < e) && (d > 0))) {\n                this._lastLinkPosition = d;\n                var f = c.getAttribute(\"ajaxify\");\n                if (f) {\n                    new AsyncRequest(f).setRelativeTo(c).setStatusElement(Parent.byClass(c, \"stat_elem\")).send();\n                }\n                 else FriendBrowserCheckboxController.getInstance(\"jewel\").showMore();\n            ;\n            }\n        ;\n        }\n    ;\n    },\n    _addRequest: function(a, b) {\n        if ((!b || this._requestList[b.obj.from])) {\n            return\n        };\n        var c = DOM.scry(this.jewelFlyout, \".fbRequestList .uiList\")[0];\n        if (!c) {\n            return\n        };\n        DOM.prependContent(c, b.obj.markup);\n        var d = DOM.scry(this.jewelFlyout, \"#fbRequestsPYMKContainer\")[0];\n        if (!d) {\n            var e = DOM.find(ge(b.obj.itemid), \"form\"), f = DOM.create(\"input\", {\n                type: \"hidden\",\n                name: \"num_visible_requests\",\n                value: (this._requestCount + 1)\n            });\n            DOM.appendContent(e, f);\n        }\n    ;\n        var g = {\n            jewel: \"requests\",\n            count: ++this.countNew\n        };\n        Arbiter.inform(\"jewel/count-updated\", g);\n        this._requestList[b.obj.from] = b.obj.itemid;\n        ++this._requestCount;\n        this._conditionShowEmptyMessage();\n    },\n    _removeOldRequest: function(a, b) {\n        if (!b) {\n            return\n        };\n        var c = this._requestList[b.obj.from], d = (c && ge(c));\n        if (d) {\n            (CSS.hasClass(d, \"jewelItemNew\") && Arbiter.inform(\"jewel/count-updated\", {\n                jewel: \"requests\",\n                count: --this.countNew\n            }));\n            if (!CSS.hasClass(d, \"jewelItemResponded\")) {\n                DOM.remove(d);\n                delete this._requestList[c];\n                --this._requestCount;\n                this._conditionShowEmptyMessage();\n            }\n        ;\n        }\n    ;\n    },\n    _markRead: function() {\n        this.jewel.markSeen();\n        this._clearNewItems();\n    },\n    _markSeenCallback: function(a, b) {\n        new AsyncSignal(\"/ajax/gigaboxx/endpoint/UpdateLastSeenTime.php\", {\n            folder: this.folder\n        }).send();\n        var c = (((typeof a != \"undefined\") && (typeof b != \"undefined\")) ? {\n            requester: a,\n            type: b\n        } : {\n        });\n        (this.doNewMarkRead && new AsyncSignal(\"/ajax/requests/mark_read/\", c).send());\n    },\n    _removeRequest: function(a, b) {\n        var c = b.obj.item_id;\n        if (c) {\n            var d = ge(c), e = (d && CSS.hasClass(d, \"jewelItemNew\"));\n            (d ? DOM.remove(d) : false);\n            (e && Arbiter.inform(\"jewel/count-updated\", {\n                jewel: \"requests\",\n                count: --this.countNew\n            }));\n        }\n    ;\n    },\n    _clearNewItems: function(a, b) {\n        DOM.scry(this.jewel.root, \"li.jewelItemNew\").forEach(function(c) {\n            CSS.removeClass(c, \"jewelItemNew\");\n        });\n    },\n    _updateCount: function(a, b) {\n        this.countNew = b.count;\n        CSS.conditionClass(this.jewelFlyout, \"beeperUnread\", (this.countNew > 0));\n        CSS.conditionClass(this.jewelFlyoutCase, \"showRequests\", (this.countNew > 0));\n        if (this.newCountSpan) {\n            var c = ((this.countNew == 1) ? tx._(\"{num} NEW REQUEST\", {\n                num: this.countNew\n            }) : tx._(\"{num} NEW REQUESTS\", {\n                num: this.countNew\n            }));\n            DOM.setContent(this.newCountSpan, c);\n        }\n    ;\n    },\n    _conditionShowEmptyMessage: function() {\n        DOM.scry(this.jewelFlyout, \"li.empty\").forEach(function(a) {\n            CSS.conditionShow(a, (this._requestCount <= 0));\n        }.bind(this));\n    },\n    _openHandler: function() {\n        var a = DOM.scry(this.jewelFlyout, \".uiScrollableArea\")[0];\n        (a && ScrollableArea.poke(a));\n    }\n});\n__d(\"ContextualBlind\", [\"event-extensions\",\"Animation\",\"DOM\",\"Rect\",\"Vector\",\"$\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Animation\"), h = b(\"DOM\"), i = b(\"Rect\"), j = b(\"Vector\"), k = b(\"$\"), l = [], m = null, n = null, o = false, p = 17572, q = 500;\n    function r(u, v) {\n        v.getPositionVector().setElementPosition(u);\n        v.getDimensionVector().setElementDimensions(u);\n    };\n    function s() {\n        l = [];\n        (m && m.remove());\n        (n && h.remove(n));\n        o = false;\n    };\n    var t = {\n        show: function(u, v, w) {\n            t.hide();\n            for (var x = 0; (x < 4); x++) {\n                l.push(h.create(\"div\", {\n                    className: \"contextualBlind\"\n                }));;\n            };\n            h.appendContent(document.body, l);\n            if ((w !== false)) {\n                n = h.create(\"div\", {\n                    className: \"contextualBlindContext\"\n                });\n                h.appendContent(document.body, n);\n            }\n        ;\n            t.updatePosition(u, v);\n            m = Event.listen(window, \"resize\", t.updatePosition.bind(t, u, v));\n            o = true;\n        },\n        fadeIn: function(u, v, w, x, y) {\n            var z = o;\n            t.show(u, v, w);\n            if (z) {\n                return\n            };\n            p = ((x !== undefined) ? x : p);\n            q = ((y !== undefined) ? y : q);\n            for (var aa = 0; (aa < l.length); aa++) {\n                var ba = l[aa];\n                new g(ba).duration(q).from(\"opacity\", 0).to(\"opacity\", p).go();\n            };\n        },\n        hide: function() {\n            l.forEach(h.remove);\n            s();\n        },\n        fadeOut: function() {\n            for (var u = 0; (u < l.length); u++) {\n                var v = l[u];\n                new g(v).duration(q).from(\"opacity\", p).to(\"opacity\", 0).ondone(h.remove.curry(v)).go();\n            };\n            s();\n        },\n        updatePosition: function(u, v) {\n            var w = j.getDocumentDimensions().y, x = i.getElementBounds(k(u));\n            if (v) {\n                x = new i((x.t - v), (x.r + v), (x.b + v), (x.l - v), x.domain);\n            };\n            var y = document, z = (((((y && y.documentElement) && y.documentElement.clientWidth)) || (((y && y.body) && y.body.clientWidth))) || 0);\n            r(l[0], new i(0, z, x.t, 0, \"document\"));\n            r(l[1], new i(x.t, z, x.b, x.r, \"document\"));\n            r(l[2], new i(x.b, z, w, 0, \"document\"));\n            r(l[3], new i(x.t, x.l, x.b, 0, \"document\"));\n            if (n) {\n                r(n, x);\n            };\n        }\n    };\n    e.exports = (a.ContextualBlind || t);\n});\n__d(\"JewelX\", [\"event-extensions\",\"Arbiter\",\"ArbiterMixin\",\"Class\",\"ContextualBlind\",\"CSS\",\"DOM\",\"HTML\",\"Keys\",\"Toggler\",\"copyProperties\",\"reportData\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"Class\"), j = b(\"ContextualBlind\"), k = b(\"CSS\"), l = b(\"DOM\"), m = b(\"HTML\"), n = b(\"Keys\"), o = b(\"Toggler\"), p = b(\"copyProperties\"), q = b(\"reportData\"), r = function(s, t) {\n        ((s && t) && this.init(s, t));\n    };\n    p(r, {\n        _instancesByName: {\n        },\n        _resizeListener: null\n    });\n    p(r.prototype, h, {\n        init: function(s, t) {\n            this.name = t.name;\n            this.root = s;\n            this.countNew = 0;\n            this.initialCount = 0;\n            this.escHandler = null;\n            this.fadeOnOpen = t.fade_on_open;\n            r._instancesByName[this.name] = this;\n            o.listen(\"show\", this.root, function(u) {\n                this._logFirstClick();\n                (this.hasNew() && this.markSeen());\n                this.reset();\n                this.inform(\"opened\");\n                g.inform(\"layer_shown\", {\n                    type: \"Jewel\"\n                });\n                this.setupEvents();\n                (this.fadeOnOpen && j.fadeIn(this.root, 0, true, 19805, 100));\n            }.bind(this));\n            o.listen(\"hide\", this.root, function(u, v) {\n                (this.hasNew() && this.markSeen());\n                this.reset();\n                this.inform(\"closed\");\n                g.inform(\"layer_hidden\", {\n                    type: \"Jewel\"\n                });\n                this.removeEvents();\n                if ((this.fadeOnOpen && ((((!v || !v.clickedTarget) || !k.hasClass(v.clickedTarget, \"jewelButton\")) || l.contains(this.root, v.clickedTarget))))) {\n                    j.fadeOut();\n                };\n            }.bind(this));\n            g.subscribe(\"jewel/count-updated\", function(u, v) {\n                ((v.jewel == this.name) && this.update(v));\n            }.bind(this));\n            g.subscribe(\"jewel/count-initial\", function(u, v) {\n                ((v.jewel == this.name) && this.setInitial(v));\n            }.bind(this));\n            g.subscribe(\"jewel/reset\", function(u, v) {\n                ((v.jewel == this.name) && this.reset());\n            }.bind(this));\n            r._resizeListener = (r._resizeListener || (function() {\n                var u = null;\n                return Event.listen(window, \"resize\", function() {\n                    clearTimeout(u);\n                    u = g.inform.bind(g, \"jewel/resize\").defer(100, false);\n                });\n            })());\n        },\n        getRoot: function() {\n            return this.root;\n        },\n        hasNew: function() {\n            return k.hasClass(this.root, \"hasNew\");\n        },\n        isOpen: function() {\n            return k.hasClass(this.root, \"openToggler\");\n        },\n        reset: function() {\n            k.removeClass(this.root, \"hasNew\");\n        },\n        setContent: function(s) {\n            var t = l.find(this.root, \"ul.jewelItemList\");\n            l.setContent(t, m(s));\n        },\n        update: function(s) {\n            this.countNew = s.count;\n            var t = l.find(this.root, \"span.jewelCount span\");\n            l.setContent(t, this.countNew);\n            var u = (isNaN(this.countNew) || (this.countNew > 0));\n            k.conditionClass(this.root, \"hasNew\", u);\n            this.inform(\"updated\", s);\n        },\n        setInitial: function(s) {\n            this.initialCount = s;\n        },\n        setupEvents: function() {\n            this.escHandler = Event.listen(document.documentElement, \"keydown\", function(s) {\n                if (((s.keyCode === n.ESC) && this.isOpen())) {\n                    o.hide(this.root);\n                };\n            }.bind(this));\n        },\n        removeEvents: function() {\n            if (this.escHandler) {\n                this.escHandler.remove();\n            };\n        },\n        markSeen: function() {\n            g.inform(\"jewel/count-updated\", {\n                jewel: this.name,\n                count: 0\n            }, g.BEHAVIOR_STATE);\n            this.inform(\"marked-seen\");\n        },\n        _logFirstClick: function() {\n            this._logFirstClick = bagofholding;\n            q(\"jewel_click\", {\n                gt: {\n                    count: this.countNew,\n                    initial: this.initialCount,\n                    jewel: this.name\n                }\n            });\n        }\n    });\n    e.exports = r;\n});\n__d(\"UserNoOp\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\"), h = function() {\n    \n    }, i = function() {\n        return this;\n    };\n    g(h.prototype, {\n        add_event: i,\n        add_data: i,\n        set_ua_id: i,\n        set_namespace: i\n    });\n    e.exports = h;\n});\n__d(\"legacy:UserAction\", [\"UserNoOp\",\"userAction\",], function(a, b, c, d) {\n    a.UserNoOp = b(\"UserNoOp\");\n    a.user_action = b(\"userAction\");\n    a.report_data = function(e, f) {\n        user_action(e, null, null, \"FORCE\", f);\n    };\n}, 3);\n__d(\"legacy:DocumentTitle\", [\"DocumentTitle\",], function(a, b, c, d) {\n    a.DocumentTitle = b(\"DocumentTitle\");\n}, 3);\n__d(\"legacy:Poller\", [\"Poller\",], function(a, b, c, d) {\n    a.Poller = b(\"Poller\");\n}, 3);\n__d(\"deferUntil\", [], function(a, b, c, d, e, f) {\n    function g(h, i, j, k, l) {\n        var m = i();\n        if (m) {\n            h(m);\n            return null;\n        }\n    ;\n        var n = Date.now(), o = setInterval(function() {\n            m = i();\n            if (!m) {\n                if ((!j || ((j < (new Date() - n))))) {\n                    return\n                };\n                (l && l());\n            }\n        ;\n            clearInterval(o);\n            h(m);\n        }, 20, k);\n        return o;\n    };\n    e.exports = g;\n});\n__d(\"legacy:function-utils\", [\"debounce\",\"throttle\",\"deferUntil\",], function(a, b, c, d) {\n    a.debounce = b(\"debounce\");\n    a.throttle = b(\"throttle\");\n    a.defer_until = b(\"deferUntil\");\n}, 3);\n__d(\"legacy:user-activity\", [\"UserActivity\",], function(a, b, c, d) {\n    a.UserActivity = (a.UserActivity || b(\"UserActivity\"));\n}, 3);\n__d(\"BanzaiODS\", [\"BanzaiDesktop\",], function(a, b, c, d, e, f) {\n    var g = b(\"BanzaiDesktop\"), h = {\n    };\n    function i(k, l, m, n) {\n        var o = (h[k] || (h[k] = {\n        }));\n        o = (o[l] || (o[l] = {\n        }));\n        o = (o[m] || (o[m] = []));\n        for (var p = 0; (p < n.length); p++) {\n            var q = ((n[p] == null) ? 1 : Number(n[p]));\n            if (isFinite(q)) {\n                o[p] = (((o[p] || 0)) + q);\n            };\n        };\n    };\n    g.subscribe(g.SEND, function() {\n        for (var k in h) {\n            g.post(\"ods\", h);\n            break;\n        };\n        h = {\n        };\n    });\n    var j = {\n        bumpEntityKey: function(k, l, m) {\n            i(\"bEK\", k, l, [m,]);\n        },\n        bumpFraction: function(k, l, m, n) {\n            i(\"bF\", k, l, [m,n,]);\n        }\n    };\n    e.exports = j;\n});\n__d(\"OptionStorage\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\"), h = (window.localStorage || null);\n    function i(j, k, l) {\n        this.name = j;\n        this.reviver = (k || this._reviver);\n        this.replacer = (l || this._replacer);\n        this._read();\n    };\n    g(i.prototype, {\n        _read: function(j, k) {\n            if ((h && h[this.name])) {\n                this.options = JSON.parse(h[this.name], this.reviver);\n            }\n             else this.options = {\n            };\n        ;\n        },\n        _write: function() {\n            if (h) {\n                var j = g({\n                }, this.options);\n                h[this.name] = JSON.stringify(j, this.replacer);\n            }\n        ;\n        },\n        _reviver: function(j, k) {\n            if (k) {\n                var l = (/^\\[RegExp (.*)\\]$/.test(k) && RegExp.$1);\n                if (l) {\n                    k = new RegExp(l.replace(/^\\/|\\/$/g, \"\"));\n                };\n                return k;\n            }\n        ;\n        },\n        _replacer: function(j, k) {\n            if ((k instanceof RegExp)) {\n                k = ((\"[RegExp \" + k) + \"]\");\n                this[j] = k;\n            }\n        ;\n            return k;\n        },\n        get: function(j, k) {\n            return ((j in this.options) ? this.options[j] : k);\n        },\n        set: function(j, k) {\n            if ((k == null)) {\n                delete this.options[j];\n            }\n             else this.options[j] = k;\n        ;\n            this._write();\n        }\n    });\n    e.exports = i;\n});\n__d(\"legacy:megaphone\", [\"MegaphoneHelper\",], function(a, b, c, d) {\n    a.MegaphoneHelper = b(\"MegaphoneHelper\");\n}, 3);\n__d(\"MessagingEvents\", [\"array-extensions\",\"Arbiter\",\"ChannelConstants\",\"copyProperties\",\"isEmpty\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ChannelConstants\"), i = b(\"copyProperties\"), j = b(\"isEmpty\"), k = {\n    }, l = new g();\n    function m(n) {\n        if (!j(k)) {\n            return\n        };\n        for (var o in n) {\n            l.inform((\"count/\" + o), n[o]);;\n        };\n    };\n    l.subscribe(\"mark-as-read\", function(n, o) {\n        (((o.tids || o.chat_ids) || [])).forEach(function(p) {\n            p = (\"\" + p);\n            if (!((p in k))) {\n                k[p] = true;\n                var q = function() {\n                    l.unsubscribe(r);\n                    clearTimeout(s);\n                    delete k[p];\n                }, r = l.subscribe(\"read\", function(t, u) {\n                    if ((((u.tids || [])).contains(p) || ((u.chat_ids || [])).contains(p))) {\n                        q();\n                    };\n                }), s = q.defer(60000);\n            }\n        ;\n        });\n    });\n    g.subscribe(h.getArbiterType(\"messaging\"), function(n, o) {\n        var p = i({\n        }, o.obj), event = (p.event || \"\");\n        delete p.type;\n        delete p.event;\n        l.inform(event, p);\n        if ((\"unread_counts\" in p)) {\n            var q = p.unread_counts;\n            m({\n                unread: q.inbox,\n                other_unseen: q.other\n            });\n        }\n    ;\n    });\n    g.subscribe(h.getArbiterType(\"inbox\"), function(n, o) {\n        var p = i(o.obj);\n        delete p.type;\n        m(p);\n    });\n    a.MessagingEvents = e.exports = l;\n}, 3);\n__d(\"DoublyLinkedListMap\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\");\n    function h() {\n        this._head = null;\n        this._tail = null;\n        this._nodes = {\n        };\n        this._nodeCount = 0;\n    };\n    g(h.prototype, {\n        get: function(i) {\n            return (this._nodes[i] ? this._nodes[i].data : null);\n        },\n        _insert: function(i, j, k, l) {\n            ((k && !this._nodes[k]) && (k = null));\n            var m = (((k && this._nodes[k])) || ((l ? this._head : this._tail))), n = {\n                data: j,\n                key: i,\n                next: null,\n                prev: null\n            };\n            if (m) {\n                this.remove(i);\n                if (l) {\n                    n.prev = m.prev;\n                    (m.prev && (m.prev.next = n));\n                    m.prev = n;\n                    n.next = m;\n                }\n                 else {\n                    n.next = m.next;\n                    (m.next && (m.next.prev = n));\n                    m.next = n;\n                    n.prev = m;\n                }\n            ;\n            }\n        ;\n            ((n.prev === null) && (this._head = n));\n            ((n.next === null) && (this._tail = n));\n            this._nodes[i] = n;\n            this._nodeCount++;\n            return this;\n        },\n        insertBefore: function(i, j, k) {\n            return this._insert(i, j, k, true);\n        },\n        insertAfter: function(i, j, k) {\n            return this._insert(i, j, k, false);\n        },\n        prepend: function(i, j) {\n            return this.insertBefore(i, j, (this._head && this._head.key));\n        },\n        append: function(i, j) {\n            return this.insertAfter(i, j, (this._tail && this._tail.key));\n        },\n        remove: function(i) {\n            var j = this._nodes[i];\n            if (j) {\n                var k = j.next, l = j.prev;\n                (k && (k.prev = l));\n                (l && (l.next = k));\n                ((this._head === j) && (this._head = k));\n                ((this._tail === j) && (this._tail = l));\n                delete this._nodes[i];\n                this._nodeCount--;\n            }\n        ;\n            return this;\n        },\n        find: function(i) {\n            for (var j = this._head; j; j = j.next) {\n                if (i(j.data)) {\n                    return j.key\n                };\n            };\n            return null;\n        },\n        reduce: function(i, j) {\n            for (var k = this._head; k; k = k.next) {\n                j = i(k.data, j);;\n            };\n            return j;\n        },\n        exists: function(i) {\n            return !!this._nodes[i];\n        },\n        isEmpty: function() {\n            return !this._head;\n        },\n        reset: function() {\n            this._head = null;\n            this._tail = null;\n            this._nodes = {\n            };\n            this._nodeCount = 0;\n        },\n        map: function(i) {\n            for (var j = this._head; j; j = j.next) {\n                i(j.data);;\n            };\n        },\n        getCount: function() {\n            return this._nodeCount;\n        },\n        getHead: function() {\n            return this._head.data;\n        },\n        getTail: function() {\n            return this._tail.data;\n        },\n        getNext: function(i) {\n            var j = this._nodes[i];\n            if ((j && j.next)) {\n                return j.next.data\n            };\n            return null;\n        },\n        getPrev: function(i) {\n            var j = this._nodes[i];\n            if ((j && j.prev)) {\n                return j.prev.data\n            };\n            return null;\n        }\n    });\n    e.exports = h;\n});\n__d(\"Quickling\", [\"AjaxPipeRequest\",\"Arbiter\",\"Class\",\"DocumentTitle\",\"DOM\",\"HTML\",\"OnloadHooks\",\"PageTransitions\",\"Run\",\"URI\",\"UserAgent\",\"copyProperties\",\"goOrReplace\",\"isEmpty\",\"QuicklingConfig\",], function(a, b, c, d, e, f) {\n    var g = b(\"AjaxPipeRequest\"), h = b(\"Arbiter\"), i = b(\"Class\"), j = b(\"DocumentTitle\"), k = b(\"DOM\"), l = b(\"HTML\"), m = b(\"OnloadHooks\"), n = b(\"PageTransitions\"), o = b(\"Run\"), p = b(\"URI\"), q = b(\"UserAgent\"), r = b(\"copyProperties\"), s = b(\"goOrReplace\"), t = b(\"isEmpty\"), u = c(\"QuicklingConfig\"), v = u.version, w = u.sessionLength, x = new RegExp(u.inactivePageRegex), y = 0, z, aa = \"\", ba = [], ca = {\n        isActive: function() {\n            return true;\n        },\n        isPageActive: function(ka) {\n            if ((ka == \"#\")) {\n                return false\n            };\n            ka = new p(ka);\n            if ((ka.getDomain() && (ka.getDomain() != p().getDomain()))) {\n                return false\n            };\n            if ((ka.getPath() == \"/l.php\")) {\n                var la = ka.getQueryData().u;\n                if (la) {\n                    la = p(unescape(la)).getDomain();\n                    if ((la && (la != p().getDomain()))) {\n                        return false\n                    };\n                }\n            ;\n            }\n        ;\n            var ma = ka.getPath(), na = ka.getQueryData();\n            if (!t(na)) {\n                ma += (\"?\" + p.implodeQuery(na));\n            };\n            return !x.test(ma);\n        },\n        addURIQueryAugmenter: function(ka) {\n            ba.push(ka);\n        }\n    };\n    function da(ka) {\n        ka = (ka || \"Facebook\");\n        j.set(ka);\n        if (q.ie()) {\n            aa = ka;\n            if (!z) {\n                z = window.setInterval(function() {\n                    var la = aa, ma = j.get();\n                    if ((la != ma)) {\n                        j.set(la);\n                    };\n                }, 5000, false);\n            };\n        }\n    ;\n    };\n    function ea(ka) {\n        var la = document.getElementsByTagName(\"link\");\n        for (var ma = 0; (ma < la.length); ++ma) {\n            if ((la[ma].rel != \"alternate\")) {\n                continue;\n            };\n            k.remove(la[ma]);\n        };\n        if (ka.length) {\n            var na = k.find(document, \"head\");\n            (na && k.appendContent(na, l(ka[0])));\n        }\n    ;\n    };\n    function fa(ka) {\n        var la = {\n            version: v\n        };\n        this.parent.construct(this, ka, {\n            quickling: la\n        });\n    };\n    i.extend(fa, g);\n    r(fa.prototype, {\n        _preBootloadFirstResponse: function(ka) {\n            return true;\n        },\n        _fireDomContentCallback: function() {\n            (this._request.cavalry && this._request.cavalry.setTimeStamp(\"t_domcontent\"));\n            n.transitionComplete();\n            (this._onPageDisplayed && this._onPageDisplayed(this.pipe));\n            this.parent._fireDomContentCallback();\n        },\n        _fireOnloadCallback: function() {\n            if (this._request.cavalry) {\n                this._request.cavalry.setTimeStamp(\"t_hooks\");\n                this._request.cavalry.setTimeStamp(\"t_layout\");\n                this._request.cavalry.setTimeStamp(\"t_onload\");\n            }\n        ;\n            this.parent._fireOnloadCallback();\n        },\n        isPageActive: function(ka) {\n            return ca.isPageActive(ka);\n        },\n        _versionCheck: function(ka) {\n            if ((ka.version == v)) {\n                return true\n            };\n            var la = [\"quickling\",\"ajaxpipe\",\"ajaxpipe_token\",];\n            s(window.location, p(ka.uri).removeQueryData(la), true);\n            return false;\n        },\n        _processFirstResponse: function(ka) {\n            var la = ka.getPayload();\n            da(la.title);\n            ea((la.syndication || []));\n            window.scrollTo(0, 0);\n            var ma = (la.body_class || \"\");\n            document.body.className = ma;\n        },\n        getSanitizedParameters: function() {\n            return [\"quickling\",];\n        }\n    });\n    function ga(ka) {\n        var la = [], ma = p(ka);\n        ba.forEach(function(na) {\n            var oa = na(ma);\n            if (!oa) {\n                return\n            };\n            la.push(na);\n            ma = ma.addQueryData(oa);\n        });\n        ba = la;\n        return ma;\n    };\n    function ha() {\n        y++;\n        return (y >= w);\n    };\n    function ia(ka) {\n        g.setCurrentRequest(null);\n        if (ha()) {\n            return false\n        };\n        ka = ga(ka);\n        if (!ca.isPageActive(ka)) {\n            return false\n        };\n        window.ExitTime = Date.now();\n        o.__removeHook(\"onafterloadhooks\");\n        o.__removeHook(\"onloadhooks\");\n        m.runHooks(\"onleavehooks\");\n        h.inform(\"onload/exit\", true);\n        new fa(ka).setCanvasId(\"content\").send();\n        return true;\n    };\n    function ja(ka) {\n        window[(ka + \"_native\")] = (function(la) {\n            return function ma(na, oa) {\n                return la(na, oa);\n            };\n        })(window[ka]);\n        window[ka] = function la(ma, na, oa) {\n            var pa = window[(ka + \"_native\")](ma, na);\n            if ((na > 0)) {\n                if ((oa !== false)) {\n                    o.onLeave(function() {\n                        clearInterval(pa);\n                    });\n                }\n            };\n            return pa;\n        };\n    };\n    ja(\"setInterval\");\n    ja(\"setTimeout\");\n    n.registerHandler(ia, 1);\n    e.exports = a.Quickling = ca;\n});\n__d(\"MusicButtonStore\", [], function(a, b, c, d, e, f) {\n    var g = {\n    }, h = {\n        addButton: function(i, j) {\n            g[i] = j;\n            return j;\n        },\n        getButton: function(i) {\n            return g[i];\n        },\n        getButtons: function() {\n            return g;\n        },\n        removeButton: function(i) {\n            (g[i] && g[i].resetLoadingTimers());\n            delete g[i];\n        }\n    };\n    e.exports = h;\n});\n__d(\"MusicEvents\", [\"Arbiter\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\");\n    e.exports = a.MusicEvents = new g();\n});\n__d(\"MusicProviders\", [], function(a, b, c, d, e, f) {\n    e.exports = a.MusicProviders = {\n        SPOTIFY: \"open.spotify.com\"\n    };\n});\n__d(\"MusicConstants\", [\"Arbiter\",\"MusicEvents\",\"MusicProviders\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"MusicEvents\"), i = b(\"MusicProviders\"), j = {\n        DEBUG: false,\n        LIVE_LISTEN_MIN_SPOTIFY_VERSION: \"spotify-0.6.6.0.g5a9eaca5\",\n        enableDebug: function() {\n            this.DEBUG = true;\n        },\n        sameURLs: function(k, l) {\n            var m = /\\/$/;\n            if ((k && l)) {\n                k = URI(k);\n                l = URI(l);\n                return ((k.getDomain() == l.getDomain()) && (k.getPath() == l.getPath()));\n            }\n        ;\n            return false;\n        },\n        greaterOrEqualToMinimumVersion: function(k, l) {\n            var m = /(?:\\d+\\.)+/, n = k.match(m)[0].split(\".\").slice(0, -1), o = l.match(m)[0].split(\".\").slice(0, -1);\n            if ((n.length !== o.length)) {\n                return false\n            };\n            for (var p = 0; (p < o.length); p++) {\n                if ((+n[p] < +o[p])) {\n                    return false;\n                }\n                 else if ((+n[p] > +o[p])) {\n                    return true\n                }\n            ;\n            };\n            return true;\n        },\n        sanitizeForProviders: function(k) {\n            var l = {\n            };\n            for (var m in k) {\n                if (this.ALLOWED_EXTERNAL_CONTEXT_PARAMS[m]) {\n                    l[m] = k[m];\n                };\n            };\n            return l;\n        },\n        OP: {\n            RESUME: \"RESUME\",\n            PAUSE: \"PAUSE\",\n            PLAY: \"PLAY\",\n            VERSION: \"VERSION\"\n        },\n        STATUS_CHANGE_OP: {\n            STATUS: \"STATUS\",\n            LOGIN: \"LOGIN\",\n            REINFORM: \"REINFORM\"\n        },\n        STATUS_CHANGE_EVENT: {\n            playing: \"PLAY_STATE_CHANGED\",\n            track: \"TRACK_CHANGED\"\n        },\n        DIAGNOSTIC_EVENT: {\n            ALL_PAUSED: \"ALL_PAUSED\",\n            ALL_OFFLINE: \"ALL_OFFLINE\",\n            OFFLINE: \"OFFLINE\",\n            ONLINE: \"ONLINE\",\n            SEARCHING: \"SEARCHING\",\n            HIT: \"HIT\",\n            MISS: \"MISS\",\n            RESIGN: \"RESIGN\",\n            IFRAME_POLLING: \"IFRAME_POLLING\",\n            RELAUNCH: \"RELAUNCH\",\n            STATE_CHANGE: \"STATE_CHANGE\",\n            WRONG_VERSION: \"WRONG_VERSION\",\n            SERVICE_ERROR: \"SERVICE_ERROR\",\n            INCORRECT_ONLINE_STATE: \"INCORRECT_ONLINE_STATE\",\n            LOG_SEND_OP: \"LOG_SEND_OP\",\n            REQUEUE_OP: \"REQUEUE_OP\"\n        },\n        ALLOWED_STATUS_PARAMS: {\n            playing: \"playing\",\n            track: \"track\",\n            context: \"context\",\n            client_version: \"client_version\",\n            start_time: \"start_time\",\n            expires_in: \"expires_in\",\n            open_graph_state: \"open_graph_state\"\n        },\n        ALLOWED_EXTERNAL_CONTEXT_PARAMS: {\n            uri: true,\n            song: true,\n            radio_station: true,\n            album: true,\n            playlist: true,\n            musician: true,\n            song_list: true,\n            offset: true,\n            title: true,\n            request_id: true,\n            listen_with_friends: true,\n            needs_tos: true\n        },\n        LIVE_LISTEN_OP: {\n            NOW_LEADING: \"NOW_LEADING\",\n            NOW_LISTENING: \"NOW_LISTENING\",\n            END_SESSION: \"END_SESSION\",\n            SONG_PLAYING: \"SONG_PLAYING\",\n            LISTENER_UPDATE: \"LISTENER_UPDATE\",\n            QUEUE_SESSION: \"QUEUE_SESSION\",\n            PLAY_ERROR: \"PLAY_ERROR\",\n            SESSION_UPDATED: \"SESSION_UPDATED\",\n            QUEUING_SESSION: \"QUEUING_SESSION\"\n        },\n        MUSIC_BUTTON: {\n            ACTIVATE: \"ACTIVATE\"\n        },\n        ERROR: {\n            1: \"SERVICE_UNAVAILABLE_WITHOUT_PREMIUM\",\n            2: \"SERVICE_UNAVAILABLE_WITHOUT_PREMIUM_OR_WAIT\",\n            3: \"SERVICE_UNAVAILABLE_BILLING_ISSUE\",\n            4: \"SERVICE_UNAVAILABLE_TECHNICAL_ISSUE\",\n            5: \"AUDIO_AD_PLAYING\",\n            99: \"SERVICE_TEMPORARILY_UNAVAILABLE\",\n            101: \"SONG_UNAVAILABLE_WITHOUT_PURCHASE\",\n            102: \"SONG_UNAVAILABLE_WITHOUT_PREMIUM\",\n            103: \"SONG_UNAVAILABLE_INDEFINITELY\"\n        }\n    };\n    e.exports = (a.MusicConstants || j);\n});\n__d(\"MusicWaterfallLogger\", [\"JSLogger\",], function(a, b, c, d, e, f) {\n    var g = b(\"JSLogger\"), h = g.create(\"music_waterfall\"), i = {\n        click: function(l) {\n            j(\"click\", l);\n        },\n        musicLoadedFromClick: function(l) {\n            j(\"music_loaded_from_click\", l);\n        },\n        playPause: function(l) {\n            j(\"play_pause\", l);\n        }\n    };\n    function j(l, m) {\n        h.debug((l + \"_debug\"), m);\n        h.bump(l);\n        h.bump(((l + \"_\") + k(m)));\n    };\n    function k(l) {\n        return (l ? l.replace(/\\.|-/g, \"_\") : \"\");\n    };\n    e.exports = i;\n});\n__d(\"MusicButton\", [\"Bootloader\",\"copyProperties\",\"CSS\",\"DOM\",\"MusicButtonStore\",\"MusicConstants\",\"MusicEvents\",\"MusicWaterfallLogger\",\"Parent\",\"Tooltip\",], function(a, b, c, d, e, f) {\n    var g = b(\"Bootloader\"), h = b(\"copyProperties\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"MusicButtonStore\"), l = b(\"MusicConstants\"), m = b(\"MusicEvents\"), n = b(\"MusicWaterfallLogger\"), o = b(\"Parent\"), p = b(\"Tooltip\"), q = function(r, s, t, u, v, w) {\n        this.provider = r;\n        this.buttonElem = s;\n        this.url = t;\n        this.context = (u || {\n        });\n        this.mediaType = v;\n        this.setState(this.STATES.OFFLINE);\n        this.tooltip = (w || \"\");\n        m.subscribe(l.MUSIC_BUTTON.ACTIVATE, this.processClick.bind(this));\n    };\n    h(q, {\n        tracksetableTypes: []\n    });\n    h(q.prototype, {\n        SHOW_LOADING_TIMEOUT: 500,\n        HIDE_LOADING_TIMEOUT: 4000,\n        RECENTLY_ONLINE_TIMEOUT: 6000,\n        STATES: {\n            PLAYING: \"music_playing\",\n            PAUSED: \"music_paused\",\n            LOADING: \"music_loading\",\n            DISABLED: \"music_disabled\",\n            OFFLINE: \"music_offline\"\n        },\n        setState: function(r) {\n            if ((r !== this.STATES.LOADING)) {\n                this.resetLoadingTimers();\n                this.previousState = (this.state || r);\n            }\n        ;\n            if ((r === this.STATES.PLAYING)) {\n                p.set(this.buttonElem, this.tooltip);\n            }\n             else p.set(this.buttonElem, \"\");\n        ;\n            var s = this.buttonElem.parentNode;\n            (this.state && i.removeClass(s, this.state));\n            this.state = r;\n            i.addClass(s, this.state);\n        },\n        isTracksetable: function(r) {\n            return (q.tracksetableTypes.indexOf(this.mediaType) !== -1);\n        },\n        handleIncomingEvent: function(r, s) {\n            clearTimeout(this._showLoadingTimer);\n            if (((s && s.provider) && (s.provider != this.provider))) {\n                return\n            };\n            switch (r) {\n              case l.DIAGNOSTIC_EVENT.ONLINE:\n            \n              case l.STATUS_CHANGE_EVENT.track:\n            \n              case l.STATUS_CHANGE_EVENT.playing:\n                var t = ((s && s.track) && s.track.uri), u = ((s && s.context) && s.context.uri);\n                if (((s && s.playing) && ((l.sameURLs(t, this.url) || l.sameURLs(u, this.url))))) {\n                    this.setState(this.STATES.PLAYING);\n                }\n                 else if (((this.state === this.STATES.LOADING) && (((this.previousState === this.STATES.PAUSED) || (this.previousState === this.STATES.OFFLINE))))) {\n                    clearTimeout(this._attemptingPlayTimer);\n                    this._attemptingPlayTimer = this.setState.bind(this, this.STATES.PAUSED).defer(this.RECENTLY_ONLINE_TIMEOUT, false);\n                }\n                 else if (!this._attemptingPlayTimer) {\n                    this.setState(this.STATES.PAUSED);\n                }\n                \n            ;\n                break;\n              case l.DIAGNOSTIC_EVENT.OFFLINE:\n                this.setState(this.STATES.OFFLINE);\n                break;\n              case l.DIAGNOSTIC_EVENT.ALL_OFFLINE:\n                this.setState(this.STATES.OFFLINE);\n                break;\n            };\n        },\n        processClick: function(r, s) {\n            if ((s != this.buttonElem)) {\n                if ((this.state === this.STATES.LOADING)) {\n                    (this.previousState && this.setState(this.previousState));\n                };\n                return;\n            }\n        ;\n            n.click(this.provider);\n            var t = (this.isTracksetable() && o.byClass(this.buttonElem, \"music_trackset_container\")), u = [];\n            if (t) {\n                var v = t.getAttribute(\"data-trackset-title\"), w = this.provider, x = j.scry(t, \".music_button\");\n                for (var y = 0; (y < x.length); y++) {\n                    var z = k.getButton([x[y].id,]);\n                    if (((z && (z.provider == w)) && z.isTracksetable())) {\n                        u.push(z.url);\n                    };\n                };\n            }\n        ;\n            if (!a.Music) {\n                this.showLoading(true);\n            };\n            g.loadModules([\"Music\",], function(aa) {\n                n.musicLoadedFromClick(this.provider);\n                var ba = (((t && (u.length > 1))) ? aa.playPauseSongList(this.provider, this.url, u, v, this.context) : aa.playPauseSong(this.provider, this.url, this.context));\n                this.showLoading(!ba);\n            }.bind(this));\n        },\n        showLoading: function(r) {\n            this.resetLoadingTimers();\n            this._hideLoadingTimer = this._timeout.bind(this, r).defer(this.HIDE_LOADING_TIMEOUT, false);\n            this._showLoadingTimer = this.setState.bind(this, this.STATES.LOADING).defer(this.SHOW_LOADING_TIMEOUT, false);\n        },\n        resetLoadingTimers: function() {\n            clearTimeout(this._hideLoadingTimer);\n            clearTimeout(this._showLoadingTimer);\n            clearTimeout(this._attemptingPlayTimer);\n            this._attemptingPlayTimer = null;\n        },\n        destroy: function() {\n            this.resetLoadingTimers();\n            this.buttonElem = null;\n        },\n        _timeout: function(r) {\n            (a.Music && a.Music.reInform([this.provider,]));\n            if ((!r && (this.state === this.STATES.LOADING))) {\n                this.setState(this.STATES.PAUSED);\n            };\n        }\n    });\n    e.exports = q;\n});\n__d(\"MusicButtonManager\", [\"DOM\",\"Layer\",\"MusicButton\",\"MusicButtonStore\",\"MusicConstants\",\"MusicEvents\",\"Parent\",\"$\",\"event-extensions\",\"copyProperties\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"Layer\"), i = b(\"MusicButton\"), j = b(\"MusicButtonStore\"), k = b(\"MusicConstants\"), l = b(\"MusicEvents\"), m = b(\"Parent\"), n = b(\"$\"), o = b(\"event-extensions\").$E, p = b(\"copyProperties\"), q = b(\"ge\"), r = (function() {\n        var s = null, t = {\n        };\n        function u(event) {\n            var z = o(event).getTarget(), aa = m.byClass(z, \"music_button\");\n            aa = (aa || ((!event.getModifiers().any && v(z))));\n            if (!aa) {\n                return\n            };\n            return w(aa, event);\n        };\n        function v(z) {\n            var aa = (m.byClass(z, \"music_button_trigger\") && m.byClass(z, \"music_button_trigger_group\"));\n            if (aa) {\n                var ba = g.scry(aa, \".music_button\");\n                if (ba.length) {\n                    return ba[0]\n                };\n            }\n        ;\n            return null;\n        };\n        function w(z, event) {\n            (event && o(event).stop());\n            l.inform(k.MUSIC_BUTTON.ACTIVATE, z);\n            return false;\n        };\n        function x(z) {\n            (a.Music && a.Music.reInform(z));\n        };\n        function y(z, aa) {\n            var ba = j.getButtons();\n            for (var ca in ba) {\n                if ((ba[ca].noGC || q(ca))) {\n                    ba[ca].handleIncomingEvent(z, aa);\n                }\n                 else j.removeButton(ca);\n            ;\n            };\n        };\n        return {\n            init: function(z) {\n                if (s) {\n                    return\n                };\n                s = true;\n                i.tracksetableTypes = (z || []);\n                Event.listen(document.body, \"click\", u);\n                l.subscribe([k.STATUS_CHANGE_EVENT.playing,k.STATUS_CHANGE_EVENT.track,k.DIAGNOSTIC_EVENT.OFFLINE,k.DIAGNOSTIC_EVENT.ALL_OFFLINE,k.DIAGNOSTIC_EVENT.ONLINE,], y);\n            },\n            add: function(z, aa, ba, ca, da, ea) {\n                (s || r.init());\n                var fa = aa.id, ga = j.getButton(fa);\n                if (ga) {\n                    return ga\n                };\n                ga = j.addButton(fa, new i(z, aa, ba, p({\n                    button_id: fa\n                }, ca), da, ea));\n                var ha = m.byClass(aa, \"uiOverlay\");\n                if (ha) {\n                    ga.noGC = true;\n                    var ia = h.subscribe(\"destroy\", function(ja, ka) {\n                        if (g.contains(ka.getRoot(), aa)) {\n                            j.removeButton(fa);\n                            h.unsubscribe(ia);\n                        }\n                    ;\n                    });\n                }\n            ;\n                if ((z && !t[z])) {\n                    t[z] = function() {\n                        var ja = Object.keys(t);\n                        (ja.length && x(ja));\n                        t = {\n                        };\n                    }.defer();\n                };\n                return ga;\n            },\n            addButton: function(z, aa, ba, ca, da, ea) {\n                if (!q(aa)) {\n                    return\n                };\n                var fa = n(aa);\n                return this.add(z, fa, ba, ca, da, ea);\n            }\n        };\n    })();\n    e.exports = (a.MusicButtonManager || r);\n});\n__d(\"NotificationCounter\", [\"Arbiter\",\"DocumentTitle\",\"JSLogger\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"DocumentTitle\"), i = b(\"JSLogger\"), j = {\n        messages: 0,\n        notifications: 0,\n        requests: 0\n    }, k = {\n        init: function() {\n            g.subscribe(\"update_title\", this._handleUpdate.bind(this));\n            g.subscribe(\"jewel/count-updated\", this._handleCountUpdate.bind(this));\n        },\n        getCount: function() {\n            var l = 0;\n            for (var m in j) {\n                var n = Number(j[m]);\n                if (((typeof j[m] == \"string\") && isNaN(n))) {\n                    return j[m]\n                };\n                if ((isNaN(n) || (n < 0))) {\n                    i.create(\"jewels\").error(\"bad_count\", {\n                        jewel: m,\n                        count: j[m]\n                    });\n                    continue;\n                }\n            ;\n                l += n;\n            };\n            return l;\n        },\n        updateTitle: function() {\n            var l = this.getCount(), m = h.get();\n            m = (l ? (((\"(\" + l) + \") \") + m) : m);\n            h.set(m, true);\n        },\n        _handleCountUpdate: function(l, m) {\n            j[m.jewel] = m.count;\n            this.updateTitle();\n        },\n        _handleUpdate: function(l, m) {\n            this.updateTitle();\n        }\n    };\n    e.exports = k;\n});\n__d(\"legacy:notifications-counter\", [\"NotificationCounter\",], function(a, b, c, d) {\n    a.NotificationCounter = b(\"NotificationCounter\");\n}, 3);\n__d(\"NotificationSound\", [\"Sound\",\"ChatOptions\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Sound\"), h = b(\"ChatOptions\"), i = b(\"copyProperties\");\n    g.init([\"audio/mpeg\",]);\n    function j(k) {\n        this._soundPath = k;\n    };\n    i(j.prototype, {\n        play: function() {\n            if (((this._soundPath !== null) && h.getSetting(\"sound\"))) {\n                g.play(this._soundPath);\n            };\n        }\n    });\n    e.exports = j;\n});\n__d(\"legacy:notifications-sound\", [\"NotificationSound\",], function(a, b, c, d) {\n    a.NotificationSound = b(\"NotificationSound\");\n}, 3);\n__d(\"legacy:notif-xlist\", [\"NotifXList\",], function(a, b, c, d) {\n    a.NotifXList = b(\"NotifXList\");\n}, 3);\nfunction NegativeNotif(a, b) {\n    copyProperties(this, b);\n    this.owner = a;\n    this.xLink = DOM.find(this.obj, \".notif_x\");\n    this.confirmingMsg = DOM.find(this.obj, \".confirmingMsg\");\n    this.mainLink = DOM.find(this.obj, \".notifMainLink\");\n    this.userXClicked = false;\n    this.userUnsubscribed = false;\n    Event.listen(this.xLink, \"click\", this.xClick.bind(this));\n};\ncopyProperties(NegativeNotif.prototype, {\n    FADE_AWAY_DURATION: 2500,\n    X_OUT_DURATION: 100,\n    X_OUT_DURATION_SHORT: 2,\n    xClick: function(event) {\n        this._activateX();\n        var a = this.xLink.getAttribute(\"data-gt\"), b = (a ? {\n            gt: JSON.parse(a)\n        } : {\n        });\n        user_action(\"click\", this.xLink, event, null, b);\n        return false;\n    },\n    restore: function() {\n        if (this.owner.notifXList.newNotifExist(this.id)) {\n            this.owner.notifXList.resumeInsert(this.id);\n        }\n         else this.owner.notifXList.removeNotif(this.id);\n    ;\n        this._confirmingMsgFadeAway(this.confirmingMsg);\n        this._notifMainLinkShowUp(this.mainLink);\n        this._buttonShowUp(this.xLink);\n        this._adjustContainer(this.obj);\n    },\n    reset: function() {\n        if ((this.userXClicked && !this.userUnsubscribed)) {\n            this.userXClicked = false;\n            this.restore();\n        }\n    ;\n    },\n    onTurnedOff: function() {\n        this.userUnsubscribed = true;\n        CSS.hide(this.confirmingMsg);\n        this._notifMainLinkShowUp(DOM.find(this.obj, \".confirmedMsg\"));\n        this._adjustContainer(this.obj);\n    },\n    onUndid: function() {\n        this.userXClicked = false;\n        this.userUnsubscribed = false;\n        this.restore();\n        CSS.show(this.confirmingMsg);\n        this._notifMainLinkFadeAway(DOM.find(this.obj, \".confirmedMsg\"));\n        DOM.remove(DOM.find(this.obj, \".confirmedMsg\"));\n    },\n    onMarkedSpam: function() {\n        DOM.remove(DOM.find(this.obj, \".confirmedMsg\"));\n        this._fadeAway(DOM.find(this.obj, \".spamMsg\"));\n    },\n    onFirstReceiptYes: function() {\n        this._hideFirstReceiptDiv();\n        this._fadeAway(DOM.find(this.obj, \".firstConfirmedMsg\"));\n    },\n    onFirstReceiptNo: function() {\n        this._hideFirstReceiptDiv();\n        CSS.hide(this.confirmingMsg);\n        this._activateX();\n        new AsyncRequest().setURI(\"/ajax/notifications/negative_req.php\").setData({\n            request_type: \"turn_off\",\n            notification_id: this.id\n        }).send();\n    },\n    _activateX: function() {\n        CSS.addClass(this.obj, \"forPushSafety\");\n        this.userXClicked = true;\n        this.owner.notifXList.userXClick(this.id);\n        this._notifMainLinkFadeAway(this.mainLink);\n        this._buttonFadeAway(this.xLink);\n        if (CSS.shown(this.confirmingMsg)) {\n            this._confirmingMsgShowUp(this.confirmingMsg);\n        };\n        this._adjustContainer(this.obj);\n    },\n    _hideFirstReceiptDiv: function() {\n        CSS.hide(DOM.find(this.obj, \".first_receipt_div\"));\n    },\n    _fadeAway: function(a) {\n        animation(a).from(\"backgroundColor\", \"#FFF9D7\").to(\"backgroundColor\", \"#FFFFFF\").duration(this.FADE_AWAY_DURATION).checkpoint().to(\"opacity\", \"0\").blind().duration(this.X_OUT_DURATION).checkpoint().to(\"height\", \"0px\").to(\"paddingTop\", \"0px\").to(\"paddingBottom\", \"0px\").blind().hide().duration(this.X_OUT_DURATION).go();\n    },\n    _adjustContainer: function(a) {\n        animation(a).by(\"height\", \"0px\").duration(this.X_OUT_DURATION).checkpoint().by(\"height\", \"0px\").duration(this.X_OUT_DURATION_SHORT).checkpoint().to(\"height\", \"auto\").duration(this.X_OUT_DURATION).go();\n    },\n    _notifMainLinkShowUp: function(a) {\n        animation(a).duration(this.X_OUT_DURATION).checkpoint().to(\"height\", \"auto\").to(\"paddingTop\", \"4px\").to(\"paddingBottom\", \"4px\").blind().show().duration(this.X_OUT_DURATION_SHORT).checkpoint().to(\"opacity\", \"1\").blind().duration(this.X_OUT_DURATION).go();\n    },\n    _confirmingMsgShowUp: function(a) {\n        animation(a).duration(this.X_OUT_DURATION).checkpoint().to(\"height\", \"auto\").to(\"paddingTop\", \"10px\").to(\"paddingBottom\", \"10px\").blind().show().duration(this.X_OUT_DURATION_SHORT).checkpoint().to(\"opacity\", \"1\").blind().duration(this.X_OUT_DURATION).go();\n    },\n    _notifMainLinkFadeAway: function(a) {\n        animation(a).to(\"opacity\", \"0\").blind().duration(this.X_OUT_DURATION).checkpoint().to(\"height\", \"0px\").to(\"paddingTop\", \"0px\").to(\"paddingBottom\", \"0px\").blind().hide().duration(this.X_OUT_DURATION_SHORT).go();\n    },\n    _confirmingMsgFadeAway: function(a) {\n        animation(a).to(\"opacity\", \"0\").blind().duration(this.X_OUT_DURATION).checkpoint().to(\"height\", \"0px\").to(\"paddingTop\", \"0px\").to(\"paddingBottom\", \"0px\").blind().duration(this.X_OUT_DURATION_SHORT).go();\n    },\n    _buttonShowUp: function(a) {\n        animation(a).duration(this.X_OUT_DURATION).checkpoint().show().duration(this.X_OUT_DURATION_SHORT).checkpoint().to(\"opacity\", \"1\").blind().duration(this.X_OUT_DURATION).go();\n    },\n    _buttonFadeAway: function(a) {\n        animation(a).to(\"opacity\", \"0\").blind().duration(this.X_OUT_DURATION).checkpoint().hide().duration(this.X_OUT_DURATION_SHORT).go();\n    }\n});\n__d(\"NotificationList\", [\"Animation\",\"Arbiter\",\"ArbiterMixin\",\"Class\",\"CSS\",\"DOM\",\"DoublyLinkedListMap\",\"HTML\",\"URI\",\"$\",\"copyProperties\",\"ge\",\"isEmpty\",\"tx\",\"hasArrayNature\",], function(a, b, c, d, e, f) {\n    var g = b(\"Animation\"), h = b(\"Arbiter\"), i = b(\"ArbiterMixin\"), j = b(\"Class\"), k = b(\"CSS\"), l = b(\"DOM\"), m = b(\"DoublyLinkedListMap\"), n = b(\"HTML\"), o = b(\"URI\"), p = b(\"$\"), q = b(\"copyProperties\"), r = b(\"ge\"), s = b(\"isEmpty\"), t = b(\"tx\"), u = b(\"hasArrayNature\"), v = \"0\", w = \"1\", x = \"2\";\n    function y(ba) {\n        return ((ba == w) || (ba == x));\n    };\n    function z(ba) {\n        return (ba == w);\n    };\n    function aa(ba, ca) {\n        this._list = new m();\n        this._filter_func = null;\n        this.unseenCount = 0;\n        this.contentRoot = ba;\n        this.noItemsElement = null;\n        this.ITEM_TAG = \"li\";\n        this.ITEM_CLASS = \"notification\";\n        this.NO_ITEMS_ID = \"jewelNoNotifications\";\n        this.NO_ITEMS_CLASS = \"empty\";\n        this.compare = (ca.compare || this.compare);\n        this.shouldBlockAnimation = (ca.shouldBlockAnimation || null);\n        this.unseenVsUnread = (ca.unseenVsUnread || false);\n        this.animations = {\n        };\n    };\n    q(aa, {\n        ITEM_UNREAD_CLASS: \"jewelItemNew\",\n        MARK_READ_TYPE: \"mark_read\",\n        UNREAD_COUNT_CHANGE_TYPE: \"unread_count_change\",\n        INSERTION_TYPE: \"insert\",\n        REMOVAL_TYPE: \"remove\",\n        getIdFromDom: function(ba) {\n            return ba.getAttribute(\"id\").replace(\"notification_\", \"\");\n        },\n        localizeUrls: function(ba) {\n            l.scry(ba, \"a\").forEach(function(ca) {\n                (o(ca.href).isFacebookURI() && (ca.href = o(ca.href).getUnqualifiedURI().getQualifiedURI().setSubdomain(o(ca.href).getSubdomain()).toString()));\n            });\n        }\n    });\n    q(aa.prototype, i, {\n        FADE_DURATION: 250,\n        RESIZE_DURATION: 200,\n        _getField: function(ba, ca) {\n            var da = this._list.get(ba);\n            return (da && da[ca]);\n        },\n        getDomObj: function(ba) {\n            return this._getField(ba, \"obj\");\n        },\n        fromDom: function() {\n            var ba = ((this.ITEM_TAG + \".\") + this.ITEM_CLASS), ca = l.scry(this.contentRoot, ba);\n            for (var da = 0; (da < ca.length); ++da) {\n                var ea = ca[da], fa = aa.getIdFromDom(ea);\n                this.insert(fa, ea.getAttribute(\"data-notiftime\"), null);\n            };\n        },\n        compare: function(ba, ca) {\n            return ((ba.time < ca.time) || (((ba.time === ca.time) && (ba.id < ca.id))));\n        },\n        insert: function(ba, ca, da, ea, fa, ga) {\n            var ha = w, ia = 0, ja = this._list.exists(ba), ka = (ga && this._list.exists(ga)), la = null, ma;\n            if ((ja || ka)) {\n                if (!((ea && da))) {\n                    return false;\n                }\n                 else {\n                    if (this._filter_func) {\n                        ma = {\n                            notif_id: ba,\n                            notif_time: ca,\n                            notif_markup: da,\n                            replace: ea,\n                            ignoreUnread: fa,\n                            notif_alt_id: ga\n                        };\n                        if (this._filter_func(ma)) {\n                            return false\n                        };\n                    }\n                ;\n                    ha = this._getField(ba, \"readness\");\n                    ia = this._getField(ba, \"time\");\n                    if ((ia > ca)) {\n                        return false\n                    };\n                    la = (ja ? ba : ga);\n                    this._remove(la);\n                }\n            \n            };\n            var na = (((da && n(da).getRootNode())) || p((\"notification_\" + ba))), oa = Math.max(ca, ia), pa = na.getAttribute(\"data-readness\");\n            if ((!this.unseenVsUnread && (x == pa))) {\n                pa = v;\n            };\n            ma = {\n                id: ba,\n                obj: na,\n                time: oa,\n                readness: pa,\n                app_id: na.getAttribute(\"data-appid\")\n            };\n            this._insert(ma);\n            aa.localizeUrls(na);\n            (this.noItemsElement && k.hide(this.noItemsElement));\n            if (z(pa)) {\n                ((fa && !y(ha)) && this.markRead([ba,]));\n                this.unseenCount = this.getUnseenIds().length;\n                this.inform(aa.UNREAD_COUNT_CHANGE_TYPE);\n            }\n        ;\n            var qa = ((!la || (ia < oa)) || (((pa && !ha) && !fa)));\n            this.inform(aa.INSERTION_TYPE, {\n                id: ba,\n                is_new: qa,\n                obj: na,\n                replaced_id: la,\n                time: oa\n            });\n            return true;\n        },\n        showNoNotifications: function() {\n            if ((null == this.noItemsElement)) {\n                this.noItemsElement = r(this.NO_ITEMS_ID);\n            };\n            if ((null == this.noItemsElement)) {\n                this.noItemsElement = l.create(this.ITEM_TAG, {\n                    id: this.NO_ITEMS_ID,\n                    className: this.NO_ITEMS_CLASS\n                }, \"No new notifications\");\n                l.appendContent(this.contentRoot, this.noItemsElement);\n            }\n        ;\n            k.show(this.noItemsElement);\n        },\n        _insert: function(ba) {\n            this._list.remove(ba.id);\n            var ca = null;\n            this._list.find(function(ea) {\n                var fa = this.compare(ea, ba);\n                (!fa && (ca = ea.id));\n                return fa;\n            }.bind(this));\n            var da = this.getDomObj(ca);\n            if (da) {\n                this._list.insertAfter(ba.id, ba, ca);\n                l.insertAfter(da, ba.obj);\n            }\n             else {\n                this._list.prepend(ba.id, ba);\n                l.prependContent(this.contentRoot, ba.obj);\n            }\n        ;\n        },\n        _remove: function(ba) {\n            var ca = this._getField(ba, \"obj\");\n            if (!ca) {\n                return false\n            };\n            this.inform(aa.REMOVAL_TYPE, {\n                id: ba\n            });\n            this._list.remove(ba);\n            l.remove(ca);\n            (this.isEmpty() && this.showNoNotifications());\n            return true;\n        },\n        getUnreadIds: function() {\n            return this._list.reduce(function(ba, ca) {\n                (y(ba.readness) && ca.push(ba.id));\n                return ca;\n            }, []);\n        },\n        getUnseenIds: function() {\n            return this._list.reduce(function(ba, ca) {\n                (z(ba.readness) && ca.push(ba.id));\n                return ca;\n            }, []);\n        },\n        getIds: function() {\n            return this._list.reduce(function(ba, ca) {\n                ca.push(ba.id);\n                return ca;\n            }, []);\n        },\n        isUnreadId: function(ba) {\n            var ca = this.getDomObj(ba);\n            return (y(this._getField(ba, \"readness\")) || ((ca && k.hasClass(ca, aa.ITEM_UNREAD_CLASS))));\n        },\n        isUnseenId: function(ba) {\n            return z(this._getField(ba, \"readness\"));\n        },\n        markRead: function(ba, ca) {\n            ba = (ba ? ba.filter(this.isUnreadId.bind(this)) : this.getUnreadIds());\n            var da = false;\n            for (var ea = 0; (ea < ba.length); ea++) {\n                var fa = this._list.get(ba[ea]);\n                if (fa) {\n                    if (this._setReadness(ba[ea], v)) {\n                        da = true;\n                    };\n                    if (ca) {\n                        this._markReadInDom(ba[ea], fa.obj);\n                    }\n                     else this.animateMarkRead(fa.obj);\n                ;\n                }\n            ;\n            };\n            if (da) {\n                this.unseenCount = this.getUnseenIds().length;\n                this.inform(aa.UNREAD_COUNT_CHANGE_TYPE);\n            }\n        ;\n        },\n        markSeen: function(ba) {\n            if (!u(ba)) {\n                return\n            };\n            if (!this.unseenVsUnread) {\n                this.markRead(ba);\n                return;\n            }\n        ;\n            ba = ba.filter(this.isUnseenId.bind(this));\n            var ca = false;\n            for (var da = 0; (da < ba.length); da++) {\n                if (this._setReadness(ba[da], x)) {\n                    ca = true;\n                };\n            };\n            if (ca) {\n                this.unseenCount = this.getUnseenIds().length;\n                this.inform(aa.UNREAD_COUNT_CHANGE_TYPE);\n            }\n        ;\n        },\n        _setReadness: function(ba, ca) {\n            var da = this._list.get(ba);\n            if ((!da || (da.readness == ca))) {\n                return false\n            };\n            if (((da.readness == v) && (ca == x))) {\n                return false\n            };\n            da.readness = ca;\n            da.obj.setAttribute(\"data-readness\", ca);\n            return true;\n        },\n        _markReadInDom: function(ba, ca) {\n            if (!this.isUnreadId(ba)) {\n                return\n            };\n            var da = p(ca);\n            if (da) {\n                this.stopAnimation(ba);\n                k.removeClass(da, aa.ITEM_UNREAD_CLASS);\n            }\n        ;\n        },\n        animateMarkRead: function(ba) {\n            if (!k.hasClass(ba, aa.ITEM_UNREAD_CLASS)) {\n                return\n            };\n            var ca = aa.getIdFromDom(ba), da = this._markReadInDom.bind(this, ca, ba);\n            if (k.hasClass(ba, \"fbJewelBeep\")) {\n                da();\n                return;\n            }\n        ;\n            if ((this.shouldBlockAnimation && this.shouldBlockAnimation(ba))) {\n                return\n            };\n            da.defer(10000);\n        },\n        stopAnimation: function(ba) {\n            ((ba in this.animations) && this.animations[ba].stop());\n            delete this.animations[ba];\n            return true;\n        },\n        insertMany: function(ba, ca) {\n            if (((\"object\" == typeof ba) && !s(ba))) {\n                for (var da in ba) {\n                    var ea = ba[da];\n                    this.insert(da, ea.time, ea.markup, true, ca, (ea.alt_id || null));\n                };\n                (this.noItemsElement && k.hide(this.noItemsElement));\n            }\n             else (this.isEmpty() && this.showNoNotifications());\n        ;\n        },\n        isEmpty: function() {\n            return this._list.isEmpty();\n        },\n        getEarliestNotifTime: function() {\n            return (this._list.isEmpty() ? 0 : Math.min.apply(null, this.getIds().map(function(ba) {\n                return this._getField(ba, \"time\");\n            }.bind(this))));\n        },\n        setFilterFn: function(ba) {\n            this._filter_func = ba;\n        },\n        toggleNotifsSimilarTo: function(ba, ca, da) {\n            var ea = this._getField(ba, \"app_id\");\n            if (ea) {\n                var fa = this.getIds();\n                for (var ga = 0; (ga < fa.length); ++ga) {\n                    if ((ea == this._getField(fa[ga], \"app_id\"))) {\n                        var ha = this.getDomObj(fa[ga]);\n                        if ((ba != fa[ga])) {\n                            (ca ? this._hideWithAnimation(ha) : this._showWithAnimation(ha));\n                        };\n                        var ia = l.scry(ha, \".first_receipt_div\");\n                        if ((ia.length == 1)) {\n                            if (da) {\n                                k.hide(ia[0]);\n                                k.removeClass(ha, \"first_receipt\");\n                            }\n                             else {\n                                k.show(ia[0]);\n                                k.addClass(ha, \"first_receipt\");\n                            }\n                        \n                        };\n                    }\n                ;\n                };\n            }\n        ;\n        },\n        _hideWithAnimation: function(ba) {\n            g(ba).to(\"opacity\", \"0\").blind().duration(this.FADE_DURATION).checkpoint().to(\"height\", \"0px\").to(\"paddingTop\", \"0px\").to(\"paddingBottom\", \"0px\").blind().hide().duration(this.RESIZE_DURATION).go();\n        },\n        _showWithAnimation: function(ba) {\n            g(ba).to(\"height\", \"auto\").to(\"paddingTop\", \"auto\").to(\"paddingBottom\", \"auto\").blind().show().duration(this.RESIZE_DURATION).checkpoint().to(\"opacity\", \"1\").blind().duration(this.FADE_DURATION).go();\n        }\n    });\n    e.exports = aa;\n});\n__d(\"legacy:notifications-list\", [\"NotificationList\",], function(a, b, c, d) {\n    a.NotificationList = b(\"NotificationList\");\n}, 3);\nfunction Notifications(a) {\n    this.updateTime = (a.updateTime || Date.now());\n    this.update_period = (a.updatePeriod || 60000);\n    this.latest_notif_time = (a.latestNotif || 0);\n    this.latest_read_notif_time = (a.latestReadNotif || 0);\n    this.cache_version = (a.cacheVersion || 0);\n    this.notifReceivedType = (a.notifReceivedType || \"notification\");\n    this.wrapperID = (a.wrapperID || \"notificationsWrapper\");\n    this.contentID = (a.contentID || \"jewelNotifs\");\n    this.shouldLogImpressions = (a.shouldLogImpressions || false);\n    this.allowDesktopNotifications = (a.allowDesktopNotifications || false);\n    this.useInfiniteScroll = (a.useInfiniteScroll || false);\n    this.useUnaggregatedBeeper = (a.unaggregatedBeeper || false);\n    this.unseenVsUnread = (a.unseenVsUnread || false);\n    this.receiveSoundPath = (a.receiveSoundPath || null);\n    this.useAggregatedBottomBeeper = (a.useAggregatedBottomBeeper || false);\n    this.fadeInDuration = (a.fadeInDuration || -1);\n    this.fadeOutDuration = (a.fadeOutDuration || -1);\n    this.fadeOutDelay = (a.fadeOutDelay || -1);\n    this.scrollableAreaNode = null;\n    this.firstReceiptMap = {\n    };\n    this.user = Env.user;\n    this.timeElement = \"small.time\";\n    this.ua = new UserNoOp();\n    this._init();\n};\nNotifications.BEEPS_EXPIRED = \"beeper/beeps_expired\";\ncopyProperties(Notifications.prototype, {\n    TIME_TRAVEL: \"time_travel\",\n    ONLINE: \"online\",\n    SCROLL_OFF_TINY: \"scroll_off_tiny\",\n    INACTIVE_REFRESH: \"inactive_refresh\",\n    _init: function() {\n        this.BEEPER_APPID = 30729425562;\n        this.ignoreBeeps = false;\n        this.cookieName = (\"notifications_\" + this.user);\n        this.beepsExpiredToken = null;\n        this.updateCheckCount = 0;\n        this.fetchListeners = [];\n        this.currentFetchRequest = null;\n        this.wrapper = ge(this.wrapperID);\n        this.content = ge(this.contentID);\n        this.jewelFlyout = ge(\"fbNotificationsFlyout\");\n        this.footer = DOM.find(this.jewelFlyout, \".jewelFooter\");\n        this.loadingIndicator = ge((this.contentID + \"_loading_indicator\"));\n        this.NOTIF_JEWEL_REF = \"notif_jewel\";\n        this.BEEPER_REF = \"beeper\";\n        this.notifLogger = JSLogger.create(\"notifications\");\n        NotificationCounter.init();\n        this.alertList = new NotificationList(this.content, this._getListParams());\n        this._updateCount();\n        ((window.MinNotifications && MinNotifications.fetchSent()) && (this.fetch = bagofholding));\n        Arbiter.subscribe(ChannelConstants.getArbiterType(this.notifReceivedType), this._handleNotificationMsg.bind(this));\n        Arbiter.subscribe(ChannelConstants.getArbiterType(\"notifications_read\"), this._handleNotificationsReadMsg.bind(this));\n        Arbiter.subscribe(ChannelConstants.getArbiterType(\"notifications_seen\"), this._handleNotificationsSeenMsg.bind(this));\n        Arbiter.subscribe(\"jewel/resize\", this._hideOverflow.shield(this));\n        this.alertList.subscribe(NotificationList.UNREAD_COUNT_CHANGE_TYPE, this._updateCount.bind(this));\n        this._poller = new Poller(this.update_period, this._update.bind(this), true);\n        if (this.wrapper) {\n            this.countSpan = DOM.find(this.wrapper, \"span.jewelCount span\");\n        };\n        this.initializeEvents();\n        this.fromDom();\n        if (this.useInfiniteScroll) {\n            this._autoLoadNotifIndex = 1;\n            this._truncate = false;\n            this.alertList.subscribe(NotificationList.INSERTION_TYPE, this._handleInsert.bind(this));\n        }\n    ;\n        this._notifSound = null;\n    },\n    _getListParams: function() {\n        return {\n            shouldBlockAnimation: function(a) {\n                return this.isNotifJewelOpen();\n            }.bind(this),\n            unseenVsUnread: this.unseenVsUnread\n        };\n    },\n    fromDom: function() {\n        this.ignoreBeeps = true;\n        this.alertList.fromDom();\n        (((window.MinNotifications && MinNotifications.fetched()) && this.alertList.isEmpty()) && this.alertList.showNoNotifications());\n        this.ignoreBeeps = false;\n    },\n    initializeEvents: function() {\n        var a = this.alertList.ITEM_TAG, b = null;\n        Event.listen(this.content, {\n            mouseover: function(event) {\n                var d = event.getTarget();\n                b = Parent.byTag(d, a);\n                if ((b && (d != b))) {\n                    if (Parent.byClass(b, \"notifNegativeBase\")) {\n                        CSS.addClass(b, \"notifHover\");\n                    }\n                     else CSS.addClass(b, \"selected\");\n                \n                };\n            },\n            mouseout: function(event) {\n                (b && CSS.removeClass(b, \"selected\"));\n                (b && CSS.removeClass(b, \"notifHover\"));\n                b = null;\n            },\n            mousedown: this.onContentMouseDown.bind(this)\n        });\n        Event.listen(this.wrapper, \"mouseover\", this.onMouseOver.bind(this));\n        Toggler.listen(\"show\", this.wrapper, this.onClick.bind(this));\n        Toggler.listen(\"hide\", this.wrapper, this.onHide.bind(this));\n        (this.shouldLogImpressions && Toggler.listen(\"show\", this.wrapper, this._logImpression.bind(this)));\n        var c = function(d) {\n            this._poller.requestNow();\n            this.notifLogger.bump(d);\n        }.bind(this);\n        SystemEvents.subscribe(SystemEvents.TIME_TRAVEL, c.curry(this.TIME_TRAVEL));\n        SystemEvents.subscribe(SystemEvents.ONLINE, function(d, e) {\n            (e && c(this.ONLINE));\n        });\n        INACTIVE_REFRESH_MS = ((1000 * 60) * 60);\n        UserActivity.subscribe(function(d, e) {\n            (((e.idleness > INACTIVE_REFRESH_MS)) && c(this.INACTIVE_REFRESH));\n        }.bind(this));\n        if (((Parent.byClass(this.wrapper, \"notifJewelBeeper\") && !FbDesktopPlugin.shouldSuppressBeeper()) && (this.beeper = window.NotifBeeper))) {\n            this._initBeeper();\n        };\n        this.negativeNotifs = {\n        };\n        this._initNotifNegativeFeedback();\n        if (this.useInfiniteScroll) {\n            this._setupScroll();\n            this._initializeScrollEvents();\n            this._updateScrollDataStructures.bind(this).defer();\n            this._hideOverflow();\n        }\n    ;\n    },\n    _setupScroll: function() {\n        this._scrollArea = DOM.scry(this.jewelFlyout, \"div.uiScrollableAreaWrap\")[0];\n        this._morePagerLink = DOM.find(this.jewelFlyout, \".notifMorePager a\");\n        this._morePager = (Parent.byClass(this._morePagerLink, \"notifMorePager\") || this._morePagerLink);\n        this._infiniteScrollNotif = null;\n        this.afterFirstFetch = false;\n        this.animate = false;\n        if ((window.MinNotifications && MinNotifications.fetched())) {\n            this.afterFirstFetch = true;\n            CSS.show(this._morePager);\n        }\n    ;\n    },\n    _initializeScrollEvents: function() {\n        Event.listen(this._scrollArea, \"scroll\", throttle(this._handleScroll.bind(this)));\n        Event.listen(this._morePagerLink, \"success\", function(a) {\n            this.fetchHandler(a.getData().response);\n        }.bind(this));\n    },\n    _updateScrollDataStructures: function() {\n        var a = this.alertList.getIds(), b = Math.max(0, (a.length - this._autoLoadNotifIndex));\n        this._infiniteScrollNotif = this.alertList.getDomObj(a[b]);\n        this._annotateMorePagerURI();\n    },\n    _annotateMorePagerURI: function() {\n        this._morePagerLink.setAttribute(\"ajaxify\", new URI(this._morePagerLink.getAttribute(\"ajaxify\")).addQueryData({\n            earliest_time: this.alertList.getEarliestNotifTime()\n        }));\n    },\n    onContentMouseDown: function(event) {\n        var a = Parent.byTag(event.getTarget(), this.alertList.ITEM_TAG), b = (a && NotificationList.getIdFromDom(a));\n        if ((b && this.alertList.isUnreadId(b))) {\n            this.markRead(true, [b,]);\n        };\n    },\n    onMouseOver: function(event) {\n        this.ua = user_action(\"jewel\", event.target, event).set_namespace(\"notifs\").set_ua_id(\"prefetch\").add_event(\"hover\");\n        this.fetch();\n    },\n    onClick: function() {\n        (this.beeper && this.beeper.clearBeeps());\n        ((window.ArbiterMonitor && (this.fetch != bagofholding)) && Arbiter.registerCallback(bagofholding, [\"notifs/fetched\",]));\n        this.ua.add_event(\"show\");\n        this.fetch();\n        this.markRead(true);\n        this._hideOverflow();\n        if (this.scrollableAreaNode) {\n            var a = ScrollableArea.getInstance(this.scrollableAreaNode);\n            (a && a.poke());\n        }\n    ;\n    },\n    onHide: function() {\n        this.animate = false;\n        (this.animation && this.animation.stop());\n        this.ua.add_event(\"hide\");\n        this.markRead(true);\n    },\n    _handleScroll: function() {\n        if (this._checkInfiniteScroll()) {\n            this._autoLoadNotifIndex = 5;\n            this._sendFetchRequest(this._morePager);\n        }\n    ;\n    },\n    _handleInsert: function(a, b) {\n        if (b.is_new) {\n            this._newDataFromInsert = true;\n        };\n        this._updateScrollDataStructures();\n    },\n    _checkInfiniteScroll: function() {\n        if ((this._infiniteScrollNotif && this._scrollArea)) {\n            var a = Vector2.getElementPosition(this._infiniteScrollNotif).y, b = (Vector2.getElementPosition(this._scrollArea).y + Vector2.getElementDimensions(this._scrollArea).y);\n            return (a < b);\n        }\n    ;\n        return false;\n    },\n    _initBeeper: function() {\n        this.beeper.init(this.jewelFlyout);\n        this.beeper.setFadeInDuration(this.fadeInDuration);\n        this.beeper.setFadeOutDuration(this.fadeOutDuration);\n        this.beeper.setFadeOutDelay(this.fadeOutDelay);\n        (!this.useUnaggregatedBeeper && this.alertList.subscribe(NotificationList.INSERTION_TYPE, function(a, b) {\n            if (((!this.isNotifJewelOpen() && !this.ignoreBeeps) && this.alertList.isUnreadId(b.id))) {\n                (b.is_new ? this.beeper.addBeep(b.id, b.obj) : this.beeper.updateBeep(b.replaced_id, b.id, b.obj));\n                this.logImpressionIds([b.id,], this.BEEPER_REF);\n            }\n        ;\n        }.bind(this)));\n        (!this.useUnaggregatedBeeper && this.alertList.subscribe(NotificationList.REMOVAL_TYPE, function(a, b) {\n            this.beeper.removeBeep(b.id);\n        }.bind(this)));\n        (this.useUnaggregatedBeeper && new LiveMessageReceiver(\"unaggregated_beep\").setAppId(this.BEEPER_APPID).setHandler(function(a) {\n            (!this.isNotifJewelOpen() && this.beeper.fromMessage(a));\n        }.bind(this)).register());\n    },\n    _initNotifNegativeFeedback: function() {\n        this.notifXList = null;\n        this.notifXList = window.NotifXList;\n        this.notifXList.init(this);\n        this.alertList.setFilterFn(this.notifXList.filterStoreClicked);\n        Toggler.listen(\"hide\", $(this.wrapperID), function() {\n            for (var a in this.negativeNotifs) {\n                if (a) {\n                    ((this.negativeNotifs[a] instanceof NegativeNotif) && this.negativeNotifs[a].reset());\n                };\n            };\n        }.bind(this));\n        Arbiter.subscribe(\"notif/negativeCancel\", function(a, b) {\n            (this.negativeNotifs[b.id] && this.negativeNotifs[b.id].restore());\n        }.bind(this));\n        Arbiter.subscribe(\"notif/negativeConfirmed\", function(a, b) {\n            (this.negativeNotifs[b.id] && this.negativeNotifs[b.id].onTurnedOff());\n            this.alertList.toggleNotifsSimilarTo(b.id, true, true);\n            this._hideOverflow();\n            this._handleScroll();\n        }.bind(this));\n        Arbiter.subscribe(\"notif/negativeUndid\", function(a, b) {\n            (this.negativeNotifs[b.id] && this.negativeNotifs[b.id].onUndid());\n            this.alertList.toggleNotifsSimilarTo(b.id, false, true);\n            this._hideOverflow();\n        }.bind(this));\n        Arbiter.subscribe(\"notif/negativeMarkedSpam\", function(a, b) {\n            (this.negativeNotifs[b.id] && this.negativeNotifs[b.id].onMarkedSpam());\n        }.bind(this));\n        Arbiter.subscribe(\"notif/negativeFirstReceiptYes\", function(a, b) {\n            (this.negativeNotifs[b.id] && this.negativeNotifs[b.id].onFirstReceiptYes());\n            this.alertList.toggleNotifsSimilarTo(b.id, false, true);\n        }.bind(this));\n        Arbiter.subscribe(\"notif/negativeFirstReceiptNo\", function(a, b) {\n            (this.negativeNotifs[b.id] && this.negativeNotifs[b.id].onFirstReceiptNo());\n            this.alertList.toggleNotifsSimilarTo(b.id, false, true);\n        }.bind(this));\n        this.alertList.subscribe(NotificationList.INSERTION_TYPE, function(a, b) {\n            var c = DOM.scry(b.obj, \".notif_x\");\n            if ((c.length == 1)) {\n                this.negativeNotifs[b.id] = new NegativeNotif(this, b);\n            };\n            this._updateFirstReceipt(b);\n        }.bind(this));\n    },\n    _sendIDs: function(a, b, c) {\n        var d = (c || {\n        });\n        for (var e = 0; (e < a.length); ++e) {\n            d[((\"alert_ids[\" + e) + \"]\")] = a[e];;\n        };\n        new AsyncSignal(URI(b).getQualifiedURI().toString(), d).send();\n    },\n    _waitForFetch: function(a) {\n        return (this.currentFetchRequest && this.fetchListeners.push(a.bind(this)));\n    },\n    _logImpression: function() {\n        var a = this.alertList.getIds();\n        if (((a.length === 0) && this._waitForFetch(this._logImpression))) {\n            return\n        };\n        this.logImpressionIds(a, this.NOTIF_JEWEL_REF);\n    },\n    logImpressionIds: function(a, b) {\n        (this.shouldLogImpressions && this._sendIDs(a, \"/ajax/notifications/impression.php\", {\n            ref: b\n        }));\n    },\n    markRead: function(a, b) {\n        var c = !hasArrayNature(b);\n        b = (c ? this.alertList.getUnseenIds() : b.filter(this.alertList.isUnreadId.bind(this.alertList)));\n        if (b.length) {\n            (a && this._sendIDs(b, \"/ajax/notifications/mark_read.php\", {\n                seen: (c ? 1 : 0)\n            }));\n            var d = a;\n            (c ? this.alertList.markSeen(b) : this.alertList.markRead(b, d));\n        }\n    ;\n        (c && this._waitForFetch(this.markRead.bind(this, a)));\n    },\n    markAllRead: function() {\n        var a = this.alertList.getUnreadIds();\n        this.markRead(true, a);\n    },\n    _updateErrorHandler: function(a) {\n    \n    },\n    _updateURI: \"/ajax/presence/update.php\",\n    _update: function(a) {\n        a.setHandler(this._handleUpdate.bind(this)).setOption(\"suppressErrorAlerts\", true).setErrorHandler(this._updateErrorHandler.bind(this)).setData({\n            notif_latest: this.latest_notif_time,\n            notif_latest_read: this.latest_read_notif_time\n        }).setURI(this._updateURI).setAllowCrossPageTransition(true);\n    },\n    _handleUpdate: function(a) {\n        var b = a.payload.notifications;\n        if (!b.no_change) {\n            this.updateTime = a.payload.time;\n            this.latest_notif_time = b.latest_notif;\n            this.latest_read_notif_time = b.latest_read_notif;\n            this._updateDisplayDelayed();\n            this.alertList.insertMany(b.notifications);\n        }\n    ;\n    },\n    _updateDisplayDelayed: function() {\n        if ((typeof Beeper != \"undefined\")) {\n            this.beepsExpiredToken = Arbiter.subscribe(Notifications.BEEPS_EXPIRED, this._updateDisplay.bind(this));\n        }\n         else this._updateDisplay();\n    ;\n    },\n    _updateDisplay: function() {\n        if (!this.content) {\n            return\n        };\n        this._updateCount();\n        if (this.beepsExpiredToken) {\n            this.beepsExpiredToken.unsubscribe();\n        };\n    },\n    _updateCount: function() {\n        Arbiter.inform(\"jewel/count-updated\", {\n            jewel: \"notifications\",\n            count: this.alertList.unseenCount\n        }, Arbiter.BEHAVIOR_STATE);\n        this._hideOverflow();\n    },\n    fetch: function(a) {\n        this._sendFetchRequest(a);\n    },\n    _getFetchQueryData: function() {\n        var a = {\n            time: this.latest_notif_time,\n            user: this.user,\n            version: this.cache_version,\n            locale: Env.locale\n        };\n        if (this.useInfiniteScroll) {\n            a.earliest_time = this.alertList.getEarliestNotifTime();\n        };\n        return a;\n    },\n    _sendFetchRequest: function(a) {\n        if (this.useInfiniteScroll) {\n            this._infiniteScrollNotif = null;\n            this._newDataFromInsert = false;\n            this._truncate = true;\n        }\n    ;\n        var b = URI(\"/ajax/notifications/get.php\"), c = (a || this.loadingIndicator);\n        if (this.currentFetchRequest) {\n            return true\n        };\n        this.ua.add_event(\"fetch\");\n        b.setQueryData(this._getFetchQueryData());\n        this.currentFetchRequest = new AsyncRequest().setURI(b).setStatusElement(c).setMethod(\"GET\").setReadOnly(true).setTimeoutHandler(30000, this.fetchErrorHandler.bind(this)).setHandler(this.fetchHandler.bind(this)).setErrorHandler(this.fetchErrorHandler.bind(this)).setAllowCrossPageTransition(true);\n        (!this.currentFetchRequest.send() && this.fetchErrorHandler());\n        return true;\n    },\n    fetchErrorHandler: function(a) {\n        this.currentFetchRequest = null;\n        this.ua.add_event(\"fetch_error\");\n        (this.useInfiniteScroll && this._updateScrollDataStructures());\n    },\n    fetchHandler: function(a) {\n        this.ua.add_event(\"fetch_success\");\n        var b = a.getPayload();\n        this.alertList.insertMany(b.notifications, true);\n        (this.loadingIndicator && CSS.hide(this.loadingIndicator));\n        this.loadingIndicator = null;\n        this.currentFetchRequest = null;\n        this.fetch = bagofholding;\n        if (this.fetchListeners) {\n            for (var c = 0; (c < this.fetchListeners.length); c++) {\n                this.fetchListeners[c]();;\n            };\n            this.fetchListeners = [];\n        }\n    ;\n        (window.ArbiterMonitor && Arbiter.inform(\"notifs/fetched\", \"\", Arbiter.BEHAVIOR_STATE));\n        var d = b.generated, e = Math.round(((new Date()).getTime() / 1000));\n        if (((e - d) > 15)) {\n            d = e;\n        };\n        Bootloader.loadComponents(\"live-timer\", function() {\n            LiveTimer.restart(d);\n            LiveTimer.startLoop(0);\n        });\n        if (this.useInfiniteScroll) {\n            if ((is_empty(b.notifications) || !this._newDataFromInsert)) {\n                this._noMoreNotifications();\n            }\n             else CSS.show(this._morePager);\n        ;\n            this._updateScrollDataStructures();\n            if ((this.isNotifJewelOpen() && this.afterFirstFetch)) {\n                this.animate = true;\n            };\n            this.afterFirstFetch = true;\n        }\n    ;\n        this._hideOverflow();\n    },\n    _noMoreNotifications: function() {\n        CSS.hide(this._morePager);\n        this.useInfiniteScroll = false;\n    },\n    _mergeNotification: function(a, b, c, d) {\n        var e = !this.alertList.isUnreadId(a);\n        this.alertList.insert(a, b, c, true, null, (d || null));\n        this.latest_notif_time = 0;\n        if (e) {\n            this._updateCount();\n        };\n        var f = this.alertList.getDomObj(a);\n        if (f) {\n            Bootloader.loadComponents(\"live-timer\", function() {\n                LiveTimer.addTimeStamps(f);\n            });\n        };\n    },\n    _handleNotificationMsg: function(a, b) {\n        var c = b.obj;\n        if ((typeof this.useDesktopNotifications == \"undefined\")) {\n            var d;\n            this.useDesktopNotifications = ((this.allowDesktopNotifications && window.webkitNotifications) && (window.webkitNotifications.checkPermission() === 0));\n        }\n    ;\n        if (this.useDesktopNotifications) {\n            Bootloader.loadComponents(\"desktop-notifications\", function() {\n                DesktopNotifications.addNotification(c.alert_id);\n            });\n        };\n        if (c.markup) {\n            this._mergeNotification(c.alert_id, c.time, c.markup, (c.alt_id || null));\n            requireLazy([\"NotificationSound\",], function(e) {\n                if ((this._notifSound === null)) {\n                    this._notifSound = new e(this.receiveSoundPath);\n                };\n                this._notifSound.play();\n            }.bind(this));\n        }\n         else this._poller.requestNow();\n    ;\n    },\n    _handleNotificationsReadMsg: function(a, b) {\n        var c = b.obj;\n        if ((typeof Beeper != \"undefined\")) {\n            Beeper.getInstance().markRead(false, c.alert_ids);\n        };\n        this.markRead(false, c.alert_ids);\n        (this.beeper && this.beeper.fadeOutBeeps(b.obj.alert_ids));\n    },\n    _handleNotificationsSeenMsg: function(a, b) {\n        if (!this.unseenVsUnread) {\n            this._handleNotificationsReadMsg(a, b);\n            return;\n        }\n    ;\n        var c = b.obj;\n        if ((typeof Beeper != \"undefined\")) {\n            Beeper.getInstance().markRead(false, c.alert_ids);\n        };\n        this.alertList.markSeen(c.alert_ids);\n        (this.beeper && this.beeper.fadeOutBeeps(b.obj.alert_ids));\n    },\n    _hideOverflow: function() {\n        if (!this.isNotifJewelOpen()) {\n            return\n        };\n        var a = DOM.scry($(\"fbNotificationsList\"), \".notification\");\n        this.scrollableAreaNode = (this.scrollableAreaNode || DOM.scry(this.jewelFlyout, \".uiScrollableArea\")[0]);\n        var b = 20, c = (CSS.hasClass(document.documentElement, \"tinyViewport\") && !CSS.hasClass(document.body, \"fixedBody\"));\n        if ((!a.length || c)) {\n            Style.set(this.scrollableAreaNode, \"height\", \"100\u0025\");\n            this.notifLogger.rate(this.SCROLL_OFF_TINY, c);\n            return;\n        }\n    ;\n        var d = (this.scrollableAreaNode || a[0]), e = (((Vector2.getViewportDimensions().y - Vector2.getElementPosition(d, \"viewport\").y) - Vector2.getElementDimensions(this.footer).y) - 5), f = e, g = 0;\n        for (; ((g < a.length) && (f > 0)); ++g) {\n            if (CSS.shown(a[g])) {\n                f -= Vector2.getElementDimensions(a[g]).y;\n            };\n        };\n        var h = 530, i = Math.min(h, (e - Math.max(f, 0)));\n        if (((f >= 0) && (i < h))) {\n            if ((!this.useInfiniteScroll || ((this.beeper && this.beeper.hasBeeps())))) {\n                i = \"100\u0025\";\n            }\n             else {\n                if ((this._truncate && (a.length >= 5))) {\n                    i -= b;\n                };\n                i += \"px\";\n            }\n        ;\n        }\n         else i += \"px\";\n    ;\n        if (((this.useInfiniteScroll && this.animate) && (i != \"100\u0025\"))) {\n            (this.animation && this.animation.stop());\n            this.animation = animation(this.scrollableAreaNode).to(\"height\", i).duration(200).go();\n        }\n         else {\n            var j = ScrollableArea.getInstance(this.scrollableAreaNode);\n            (j && j.showScrollbar.bind(j).defer());\n            Style.set(this.scrollableAreaNode, \"height\", i);\n        }\n    ;\n    },\n    _updateFirstReceipt: function(a) {\n        var b = a.obj.getAttribute(\"data-appid\"), c = DOM.scry(a.obj, \".first_receipt_div\");\n        if ((b && (c.length == 1))) {\n            if (this.firstReceiptMap[b]) {\n                if (((a.id != this.firstReceiptMap[b].id) && (this.firstReceiptMap[b].time > a.time))) {\n                    return\n                };\n                CSS.removeClass(this.firstReceiptMap[b].obj, \"first_receipt\");\n            }\n        ;\n            this.firstReceiptMap[b] = a;\n            CSS.addClass(a.obj, \"first_receipt\");\n        }\n    ;\n    },\n    isNotifJewelOpen: function() {\n        return (Toggler.getInstance(this.wrapper).getActive() === this.wrapper);\n    }\n});\nvar OriginalNotifications = Notifications;\n__d(\"legacy:notif-beeper\", [\"NotifBeeper\",], function(a, b, c, d) {\n    a.NotifBeeper = b(\"NotifBeeper\");\n}, 3);\n__d(\"PagesVoiceBar\", [\"$\",\"Arbiter\",\"AsyncRequest\",\"CSS\",\"ChannelConstants\",\"DOM\",\"PageTransitions\",], function(a, b, c, d, e, f) {\n    var g = b(\"$\"), h = b(\"Arbiter\"), i = b(\"AsyncRequest\"), j = b(\"CSS\"), k = b(\"ChannelConstants\"), l = b(\"DOM\"), m = b(\"PageTransitions\"), n = \"PagesVoiceBar/toggle\", o = \"PagesVoiceBar/initialized\", p = \"PagesVoiceBar/switchVoice\", q = \"page_transition\", r = \"pages_voice_bar_sync\", s = null, t = null, u = false, v = false;\n    function w() {\n        v = !v;\n        j.conditionClass(document.body, \"hasVoiceBar\", v);\n    };\n    function x(da, ea) {\n        new i(\"/ajax/pages/switch_voice.php\").setData(ea).setHandler(function(fa) {\n            ba();\n        }).send();\n    };\n    function y() {\n        s = null;\n    };\n    function z(da, ea) {\n        if ((ea.obj.profile_id && (ea.obj.profile_id == s))) {\n            ba();\n        };\n    };\n    function aa(da) {\n        h.subscribe(o, da);\n    };\n    function ba() {\n        m.getNextURI().go();\n    };\n    var ca = {\n        initVoiceBar: function() {\n            if (u) {\n                return\n            };\n            t = g(\"pagesVoiceBarContent\");\n            v = j.hasClass(document.body, \"hasVoiceBar\");\n            h.subscribe(n, w);\n            h.subscribe(p, x);\n            h.subscribe(q, y);\n            h.subscribe(k.getArbiterType(r), z);\n            u = true;\n            h.inform(o, null, h.BEHAVIOR_STATE);\n        },\n        update: function(da, ea) {\n            aa(function() {\n                s = ea;\n                l.setContent(t, da);\n            });\n        }\n    };\n    e.exports = ca;\n});\n__d(\"TypeaheadSearchSponsored\", [\"event-extensions\",\"Arbiter\",\"CSS\",\"DOM\",\"URI\",\"copyProperties\",\"tx\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"URI\"), k = b(\"copyProperties\"), l = b(\"tx\");\n    function m(n) {\n        this._typeahead = n;\n    };\n    m.auctionOptions = {\n        rerankingStrategy: 4,\n        neverRerankToTop1: true,\n        minQueryLengthForTopResult: 2,\n        minBootstrapScoreForTopResult: 0,\n        maxNumberAds: 3,\n        maxNumberRemovedResults: 2,\n        maxNumberResultsAndAds: 8,\n        debug: false\n    };\n    m.query = null;\n    m.needTopResult = function(n, o, p) {\n        if ((p.rerankingStrategy == 5)) {\n            return ((n.type != \"user\"))\n        };\n        if ((p.rerankingStrategy != 4)) {\n            return false\n        };\n        if ((o == null)) {\n            return false\n        };\n        if ((o.length < p.minQueryLengthForTopResult)) {\n            return false\n        };\n        if ((n == null)) {\n            return false\n        };\n        if (!n.bootstrapped) {\n            return false\n        };\n        if ((n.index == null)) {\n            return false\n        };\n        if ((n.index >= p.minBootstrapScoreForTopResult)) {\n            return false\n        };\n        if ((n.type == \"user\")) {\n            return false\n        };\n        return true;\n    };\n    m.getOriginalOrganics = function(n) {\n        return n.map(function(o) {\n            return {\n                uid: o.uid,\n                text: o.text,\n                type: m.getRealType(o),\n                source: (o.bootstrapped ? 1 : 0),\n                index: o.index\n            };\n        });\n    };\n    m.setDebugString = function(n, o) {\n        if (!m.auctionOptions.debug) {\n            return\n        };\n        n.debug_string = o;\n    };\n    m.runAuction = function(n, o, p, q) {\n        n = n.slice(0, q.maxNumberResultsAndAds);\n        if ((n.length === 0)) {\n            return n\n        };\n        n = m.initResults(n);\n        if (m.needTopResult(n[0], m.query, q)) {\n            n[0].renderTypeOverride = true;\n            n[0].orig_render_type = n[0].render_type;\n            n[0].render_type = \"tophit\";\n        }\n    ;\n        if (!o) {\n            var r = m.bucketResults(n);\n            return r.results;\n        }\n    ;\n        var s = m.prepareAndSortAds(n, o, p), t = m.selectAds(n, s, q), u = 0;\n        for (var v = 0; (v < t.length); ++v) {\n            if ((t[v].s_target != t[v].uid)) {\n                u++;\n            };\n        };\n        n = n.slice(0, (q.maxNumberResultsAndAds - u));\n        var w = m.bucketResults(n), x = m.rerankAds(w.results, t, w.buckets, q);\n        return x;\n    };\n    m.bucketResults = function(n) {\n        var o, p, q, r, s = [], t = {\n        };\n        p = n.length;\n        for (o = 0; (o < p); o++) {\n            q = n[o];\n            r = (q.render_type || q.type);\n            if (!t.hasOwnProperty(r)) {\n                t[r] = s.length;\n                s.push([]);\n            }\n        ;\n            s[t[r]].push(q);\n        };\n        var u = [], v = {\n        };\n        p = s.length;\n        for (o = 0; (o < p); ++o) {\n            q = s[o][0];\n            r = (q.render_type || q.type);\n            v[r] = u.length;\n            u = u.concat(s[o]);\n        };\n        return {\n            results: u,\n            buckets: v\n        };\n    };\n    m.prepareAndSortAds = function(n, o, p) {\n        if (!o) {\n            return []\n        };\n        var q = [], r = n.length;\n        for (var s = 0; (s < r); s++) {\n            var t = n[s];\n            if (o[t.uid]) {\n                for (var u in o[t.uid]) {\n                    var v = o[t.uid][u];\n                    if ((p && p.hasOwnProperty(v.uid))) {\n                        continue;\n                    };\n                    q.push(v);\n                }\n            };\n        };\n        q.sort(function(w, x) {\n            return (x.s_value - w.s_value);\n        });\n        return q;\n    };\n    m.selectAds = function(n, o, p) {\n        var q = Math.min(p.maxNumberAds, ((p.maxNumberRemovedResults + p.maxNumberResultsAndAds) - n.length)), r = [], s = {\n        }, t = n.map(function(ca) {\n            return String(ca.uid);\n        }), u = {\n        }, v = {\n        }, w = -1, x = false, y = 0;\n        for (var z = 0; (z < o.length); z++) {\n            if ((r.length >= q)) {\n                for (var aa = z; (aa < o.length); aa++) {\n                    m.setDebugString(o[aa], ((\"filtered: \" + q) + \" ads already selected\"));;\n                };\n                break;\n            }\n        ;\n            while (((y + t.length) >= p.maxNumberResultsAndAds)) {\n                w = t.pop();;\n            };\n            if (u.hasOwnProperty(w)) {\n                x = true;\n            };\n            var ba = o[z];\n            if ((x && (ba.s_target != ba.uid))) {\n                m.setDebugString(ba, ((\"filtered: last organic \" + w) + \" is targeted\"));\n                continue;\n            }\n        ;\n            if (((ba.s_target != ba.uid) && (t.indexOf(String(ba.uid)) != -1))) {\n                m.setDebugString(ba, (((\"filtered: organic \" + ba.uid) + \" targets another organic \") + ba.s_target));\n                continue;\n            }\n        ;\n            if (s.hasOwnProperty(ba.s_account)) {\n                m.setDebugString(ba, ((\"filtered: ad account \" + ba.s_account) + \" already selected\"));\n                continue;\n            }\n        ;\n            if (v.hasOwnProperty(ba.uid)) {\n                m.setDebugString(ba, ((\"filtered: ad promoted id \" + ba.uid) + \" already selected\"));\n                continue;\n            }\n        ;\n            if ((t.indexOf(String(ba.s_target)) == -1)) {\n                if (((ba.s_target != ba.uid) || (ba.s_target != w))) {\n                    m.setDebugString(ba, ((((((\"filtered: targeted organic \" + ba.s_target) + \" will go away \") + \"promoted id \") + ba.uid) + \" last organic \") + w));\n                    continue;\n                }\n            \n            };\n            m.setDebugString(ba, \"selected\");\n            r.push(ba);\n            s[ba.s_account] = true;\n            u[ba.s_target] = true;\n            v[ba.uid] = true;\n            if ((ba.s_target != ba.uid)) {\n                ++y;\n            };\n        };\n        return r;\n    };\n    m.finalizeAd = function(n, o, p) {\n        var q = \"Sponsored\";\n        n.rankType = ((n.rankType || n.render_type) || n.type);\n        if ((n.s_target == n.uid)) {\n            o.s_token = n.s_token;\n            o.message = n.s_message;\n            if ((p.rerankingStrategy === 0)) {\n                o.subtextOverride = (o.subtext ? ((o.subtext + \" \\u00b7 \") + q) : q);\n            };\n            if (n.path) {\n                o.pathOverride = true;\n                o.orig_path = o.path;\n                o.path = n.path;\n            }\n        ;\n            o.is_self = true;\n        }\n         else {\n            n.message = n.s_message;\n            n.subtextOverride = null;\n            if ((p.rerankingStrategy === 0)) {\n                n.subtextOverride = (n.subtext ? ((n.subtext + \" \\u00b7 \") + q) : q);\n            };\n            if (p.debug) {\n                if ((!n.subtextOverride && n.subtext)) {\n                    n.subtextOverride = n.subtext;\n                };\n                if (n.subtextOverride) {\n                    n.subtextOverride += ((\" \\u00b7 (Debug: \" + o.text) + \")\");\n                }\n                 else n.subtextOverride = ((\"(Debug: \" + o.text) + \")\");\n            ;\n            }\n        ;\n            n.type = o.type;\n            n.render_type = o.render_type;\n            n.is_self = false;\n        }\n    ;\n    };\n    m.buildResultIndices = function(n) {\n        var o = {\n        }, p = n.length;\n        for (var q = 0; (q < p); q++) {\n            o[n[q].uid] = q;;\n        };\n        return o;\n    };\n    m.rerankMethod0 = function(n, o, p, q) {\n        var r = m.buildResultIndices(n);\n        for (var s = (o.length - 1); (s >= 0); s--) {\n            var t = o[s], u = r[t.s_target], v = n[u];\n            m.finalizeAd(t, v, q);\n            var w = false;\n            if ((t.uid == t.s_target)) {\n                w = m.promoteSelfPromotedResult(n, u, p, q);\n            }\n             else {\n                m.insertAdToTopOfSection(n, v, p, t, q);\n                w = true;\n            }\n        ;\n            if (w) {\n                r = m.buildResultIndices(n);\n            };\n        };\n    };\n    m.promoteSelfPromotedResult = function(n, o, p, q) {\n        var r = n[o], s = (r.render_type || r.type), t = p[s];\n        if ((q.neverRerankToTop1 && (t === 0))) {\n            t = 1;\n        };\n        var u = false;\n        if ((o > t)) {\n            n.splice(t, 0, n.splice(o, 1)[0]);\n            u = true;\n        }\n    ;\n        return u;\n    };\n    m.promoteSelfPromotedResultToTop = function(n, o, p, q) {\n        var r = n[o];\n        if ((o < p)) {\n            var s = \"Sponsored\";\n            r.subtextOverride = (r.subtext ? ((r.subtext + \" \\u00b7 \") + s) : s);\n            return;\n        }\n    ;\n        if ((o > p)) {\n            n.splice(p, 0, n.splice(o, 1)[0]);\n        };\n        r = n[p];\n        r.renderTypeOverride = true;\n        r.orig_render_type = r.render_type;\n        r.render_type = \"ownsection\";\n    };\n    m.insertAdToTopOfSection = function(n, o, p, q, r) {\n        var s = (o.render_type || o.type), t = p[s];\n        if ((r.neverRerankToTop1 && (t === 0))) {\n            t = 1;\n        };\n        n.splice(t, 0, q);\n        t = p[s];\n        for (var u in p) {\n            if ((p[u] > t)) {\n                p[u] += 1;\n            };\n        };\n    };\n    m.insertAdToTop = function(n, o, p, q) {\n        n.splice(p, 0, o);\n        o.render_type = \"ownsection\";\n    };\n    m.getTopAdPosition = function(n) {\n        if ((n.length < 1)) {\n            return null\n        };\n        var o = (n[0].render_type || n[0].type);\n        if ((o == \"tophit\")) {\n            return 1\n        };\n        if ((o == \"user\")) {\n            for (var p = 1; (p < n.length); ++p) {\n                o = (n[p].render_type || n[p].type);\n                if ((o != \"user\")) {\n                    return p\n                };\n            };\n            return n.length;\n        }\n    ;\n        return 0;\n    };\n    m.rerankMethod345 = function(n, o, p) {\n        var q = 0;\n        if ((((p.rerankingStrategy == 4)) || ((p.rerankingStrategy == 5)))) {\n            q = m.getTopAdPosition(n);\n        };\n        var r = m.buildResultIndices(n);\n        for (var s = (o.length - 1); (s >= 0); s--) {\n            var t = o[s], u = r[t.s_target], v = n[u];\n            m.finalizeAd(t, v, p);\n            if ((t.uid == t.s_target)) {\n                m.promoteSelfPromotedResultToTop(n, u, q, p);\n            }\n             else m.insertAdToTop(n, t, q, p);\n        ;\n            r = m.buildResultIndices(n);\n        };\n    };\n    m.rerankAds = function(n, o, p, q) {\n        switch (q.rerankingStrategy) {\n          case 0:\n            m.rerankMethod0(n, o, p, q);\n            break;\n          case 3:\n        \n          case 4:\n        \n          case 5:\n            m.rerankMethod345(n, o, q);\n            break;\n          default:\n            break;\n        };\n        return n.slice(0, q.maxNumberResultsAndAds);\n    };\n    m.initResults = function(n) {\n        var o = n.length;\n        for (var p = 0; (p < o); p++) {\n            var q = n[p];\n            q.is_self = null;\n            q.s_token = null;\n            q.message = null;\n            q.subtextOverride = null;\n            if (q.pathOverride) {\n                q.path = q.orig_path;\n                q.pathOverride = false;\n            }\n        ;\n            if (q.renderTypeOverride) {\n                q.render_type = q.orig_render_type;\n                q.renderTypeOverride = false;\n            }\n        ;\n            q.rankType = ((q.rankType || q.render_type) || q.type);\n        };\n        return n;\n    };\n    m.setAuctionOptions = function(n) {\n        for (var o in n) {\n            m.auctionOptions[o] = n[o];;\n        };\n    };\n    m.getRealType = function(n) {\n        if (n.renderTypeOverride) {\n            return (n.orig_render_type || n.type)\n        };\n        return (n.render_type || n.type);\n    };\n    m.hideAdResult = function(n, o) {\n        g.inform(\"TypeaheadSearchSponsored/hideAdResult\", {\n            uid: n,\n            reason_dialog: o\n        });\n    };\n    m.undoHideAdResult = function(n) {\n        g.inform(\"TypeaheadSearchSponsored/undoHideAdResult\", {\n            uid: n\n        });\n    };\n    k(m.prototype, {\n        _dataSubscriptions: null,\n        _viewSubscriptions: null,\n        _globalSubscriptions: null,\n        _data: null,\n        _view: null,\n        _sponsoredEntries: null,\n        _hiddenSponsoredEntities: null,\n        _hideReasonDialog: null,\n        _debugData: null,\n        _sBootstrapID: null,\n        enable: function() {\n            this._data = this._typeahead.getData();\n            this._dataSubscriptions = [this._data.subscribe(\"beginFetchHandler\", function(n, o) {\n                var p = o.response.getPayload();\n                if (p.s_entries) {\n                    this._sponsoredEntries = (this._sponsoredEntries || {\n                    });\n                    var q = p.s_entries.length;\n                    for (var r = 0; (r < q); r++) {\n                        var s = p.s_entries[r], t = s.s_target;\n                        if (!this._sponsoredEntries[t]) {\n                            this._sponsoredEntries[t] = {\n                            };\n                        };\n                        this._sponsoredEntries[t][s.uid] = s;\n                    };\n                    if (p.s_bootstrap_id) {\n                        this._sBootstrapID = p.s_bootstrap_id;\n                    };\n                }\n            ;\n            }.bind(this)),this._data.subscribe(\"onload\", function(n, o) {\n                var p = k(this.bootstrapData, {\n                    no_cache: 1,\n                    options: [\"sponsored\",]\n                });\n                this.fetch(this.bootstrapEndpoint, p, {\n                    type: \"sponsored\"\n                });\n            }.bind(this._data)),];\n            this._view = this._typeahead.getView();\n            this._viewSubscriptions = [this._view.subscribe(\"finalResultsReordering\", function(n, o) {\n                m.query = o.value;\n                var p = m.getOriginalOrganics(o.results);\n                m.setAuctionOptions({\n                    maxNumberResultsAndAds: ((this._data && this._data._maxResults) || 8)\n                });\n                var q = m.runAuction(o.results, this._sponsoredEntries, this._hiddenSponsoredEntities, m.auctionOptions), r = m.prepareAndSortAds(o.results, this._sponsoredEntries, this._hiddenSponsoredEntities), s = r.map(function(y) {\n                    return y.s_token;\n                }), t = [];\n                for (var u = 0; (u < q.length); u++) {\n                    var v = q[u];\n                    if (v.s_token) {\n                        t.push({\n                            position: u,\n                            is_self: v.is_self\n                        });\n                    };\n                };\n                this._view.inform(\"recordAfterReorder\", {\n                    organic: p,\n                    tokens: s,\n                    position_data: t,\n                    s_bootstrap_id: this._sBootstrapID,\n                    options: m.auctionOptions,\n                    variant: m.auctionOptions.rerankingStrategy\n                });\n                if (m.auctionOptions.debug) {\n                    var w = r.map(function(y) {\n                        return {\n                            s_token: y.s_token,\n                            s_account: y.s_account,\n                            uid: y.uid,\n                            promoted_text: (y.text || \"SELF_PROMOTED\"),\n                            s_target: y.s_target,\n                            target_text: \"PLACEHOLDER\",\n                            s_value: y.s_value,\n                            debug_string: y.debug_string,\n                            source: (y.bootstrapped ? 1 : 0)\n                        };\n                    }), x = q.map(function(y) {\n                        return {\n                            uid: y.uid,\n                            text: y.text,\n                            s_token: y.s_token,\n                            is_ad: (y.s_token ? \"true\" : \"false\")\n                        };\n                    });\n                    this._debugData = {\n                        options: m.auctionOptions,\n                        query: o.value,\n                        results: x,\n                        original_organic: p,\n                        ads_in_auction: w\n                    };\n                }\n            ;\n                o.results = q;\n            }.bind(this)),this._view.subscribe(\"highlight\", function(n, o) {\n                if (this._view.content) {\n                    i.scry(this._view.content, \"a.report\").forEach(h.hide);\n                };\n                if (((!o.element || !o.selected) || !o.selected.s_token)) {\n                    return\n                };\n                var p = i.scry(o.element, \"a.report\");\n                if (p.length) {\n                    h.show(p[0]);\n                }\n                 else i.appendContent(o.element, this._createHideAdLink(o.selected));\n            ;\n            }.bind(this)),];\n            if (m.auctionOptions.debug) {\n                this._viewSubscriptions.push(this._view.subscribe(\"render\", function(n, o) {\n                    var p = new j(\"/ads/debug/search_ads_debug.php\").addQueryData(this._debugData).toString(), q = {\n                        rel: \"dialog-post\",\n                        href: \"#\",\n                        ajaxify: p\n                    }, r = i.create(\"div\", {\n                        className: \"debug\"\n                    }, [i.create(\"a\", q, [i.create(\"span\", {\n                    }, [\"Click to debug\",]),]),]);\n                    Event.listen(r, \"mouseup\", function() {\n                        this._view.index = -1;\n                    }.bind(this));\n                    i.appendContent(this._view.content, r);\n                }.bind(this)));\n            };\n            this._globalSubscriptions = [g.subscribe(\"TypeaheadSearchSponsored/hideAdResult\", function(n, o) {\n                this._hiddenSponsoredEntities = (this._hiddenSponsoredEntities || {\n                });\n                this._hiddenSponsoredEntities[o.uid] = true;\n                this._hideReasonDialog = o.reason_dialog;\n                this._forceRefreshResults();\n            }.bind(this)),g.subscribe(\"TypeaheadSearchSponsored/undoHideAdResult\", function(n, o) {\n                if (this._hiddenSponsoredEntities) {\n                    delete this._hiddenSponsoredEntities[o.uid];\n                };\n                if (this._hideReasonDialog) {\n                    this._hideReasonDialog.hide();\n                    this._hideReasonDialog = null;\n                }\n            ;\n                this._forceRefreshResults();\n            }.bind(this)),];\n        },\n        disable: function() {\n            this._dataSubscriptions.forEach(this._data.unsubscribe.bind(this._data));\n            this._dataSubscriptions = null;\n            this._viewSubscriptions.forEach(this._view.unsubscribe.bind(this._view));\n            this._viewSubscriptions = null;\n            this._globalSubscriptions.forEach(g.unsubscribe.bind(g));\n            this._globalSubscriptions = null;\n            this._data = null;\n            this._view = null;\n            this._sponsoredEntries = null;\n        },\n        _forceRefreshResults: function() {\n            if ((this._data && this._data.value)) {\n                this._data.respond(this._data.value, this._data.buildUids(this._data.value));\n            };\n        },\n        _createHideAdLink: function(n) {\n            var o = new j(\"/ajax/emu/end.php\").addQueryData({\n                eid: n.s_token,\n                f: 0,\n                ui: n.s_token,\n                en: \"fad_hide\",\n                ed: \"true\",\n                a: 1\n            }).toString(), p = {\n                className: \"report\",\n                rel: \"dialog-post\",\n                href: \"#\",\n                ajaxify: o,\n                title: \"Hide the ad\"\n            }, q = i.create(\"a\", p);\n            Event.listen(q, \"mouseover\", function(event) {\n                this._view.index = -1;\n                this._view.highlight(-1, false);\n                event.kill();\n            }.bind(this));\n            return q;\n        }\n    });\n    e.exports = m;\n});\n__d(\"legacy:SearchSponsoredTypeaheadBehavior\", [\"TypeaheadSearchSponsored\",], function(a, b, c, d) {\n    var e = b(\"TypeaheadSearchSponsored\");\n    if (!a.TypeaheadBehaviors) {\n        a.TypeaheadBehaviors = {\n        };\n    };\n    a.TypeaheadBehaviors.searchSponsored = function(f) {\n        f.enableBehavior(e);\n    };\n}, 3);\n__d(\"SearchDataSource\", [\"event-extensions\",\"Arbiter\",\"AsyncResponse\",\"Class\",\"DataSource\",\"copyProperties\",\"createArrayFrom\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"AsyncResponse\"), i = b(\"Class\"), j = b(\"DataSource\"), k = b(\"copyProperties\"), l = b(\"createArrayFrom\");\n    function m(n) {\n        this._token = (n.token || \"\");\n        this._lazyonload = ((n.lazyonload === false) ? false : true);\n        this._extraTypes = n.extraTypes;\n        this._buckets = n.buckets;\n        this._noMultiFetch = (n.noMultiFetch || false);\n        var o = (n.maxResults || 8);\n        this.parent.construct(this, n);\n        this._numResults = {\n            min: 3,\n            max: o\n        };\n        this._minWebSugg = (n.minWebSugg || 1);\n        this._genTime = n.genTime;\n    };\n    i.extend(m, j);\n    k(m.prototype, {\n        init: function() {\n            this.parent.init();\n            this._leanPayload = null;\n            this._bootstrapRequestsPending = 0;\n            this._criticalOnly = true;\n            this._updateMaxResults();\n            Event.listen(window, \"resize\", this._updateMaxResults.bind(this));\n        },\n        dirty: function() {\n            this.parent.dirty();\n            this._fetchOnUseRequests = [];\n        },\n        asyncErrorHandler: function(n) {\n            if (((window.Dialog && (window.Dialog.getCurrent() == null)) && (n.getError() == 1400003))) {\n                h.verboseErrorHandler(n);\n            };\n        },\n        fetch: function(n, o, p) {\n            p = (p || {\n            });\n            p.fetch_start = Date.now();\n            this.parent.fetch(n, o, p);\n        },\n        fetchHandler: function(n, o) {\n            var p = n.getPayload(), q = k({\n                fetch_end: Date.now()\n            }, o), r = (q.value ? g.BEHAVIOR_EVENT : g.BEHAVIOR_PERSISTENT);\n            this.inform(\"beginFetchHandler\", {\n                response: n\n            });\n            if ((o.type == \"lean\")) {\n                this._leanPayload = p;\n                this._processLean();\n            }\n             else {\n                if (p.coeff2_ts) {\n                    q.coeff2_ts = p.coeff2_ts;\n                };\n                this.parent.fetchHandler(n, o);\n                if ((o.bootstrap && !n.getRequest().getData().no_cache)) {\n                    q.browserCacheHit = ((p.timestamp < this._genTime));\n                };\n                if (((o.bootstrap && !p.no_data) && (this._bootstrapRequestsPending > 0))) {\n                    o.bootstrap = false;\n                    --this._bootstrapRequestsPending;\n                    (!this._bootstrapRequestsPending && this._bootstrapPostProcess());\n                }\n            ;\n                if ((p.no_data || (p.token !== this._token))) {\n                    var s = k({\n                    }, n.getRequest().getData());\n                    if (s.lazy) {\n                        delete s.lazy;\n                        s.token = this._token;\n                        this._fetchOnUse(s, o);\n                    }\n                ;\n                }\n            ;\n            }\n        ;\n            this.inform(\"endpointStats\", q, r);\n        },\n        buildData: function(n) {\n            var o = [], p = [], q = Math.min(n.length, (this._maxResults + this._minWebSugg));\n            for (var r = 0; (r < q); r++) {\n                var s = this.getEntry(n[r]);\n                if ((s.type === \"websuggestion\")) {\n                    o.push(s);\n                }\n                 else p.push(s);\n            ;\n            };\n            if ((p.length >= this._maxResults)) {\n                return p.slice(0, this._maxResults)\n            };\n            return p.concat(o.slice(0, Math.max((this._maxResults - p.length), this._minWebSugg)));\n        },\n        _bootstrapPostProcess: function() {\n            var n = {\n                time: Date.now()\n            };\n            this.inform(\"bootstrapped\", n, g.BEHAVIOR_PERSISTENT);\n            this._processLean();\n        },\n        _processLean: function() {\n            if (this._leanPayload) {\n                var n, o = this._leanPayload.entries;\n                for (var p in o) {\n                    n = this.getEntry(p);\n                    (n && (n.index = o[p]));\n                };\n                this.setExclusions(this._leanPayload.blocked);\n                this._leanPayload = null;\n            }\n        ;\n        },\n        _updateMaxResults: function() {\n            var n = (window.innerHeight || document.documentElement.clientHeight);\n            this.setMaxResults(Math.max(this._numResults.min, Math.min(this._numResults.max, Math.ceil((2 + ((((n - 370)) / 56)))))));\n        },\n        _bootstrapFetch: function(n, o) {\n            var p = k(o, this.bootstrapData);\n            if ((this._criticalOnly && this._lazyonload)) {\n                p.lazy = 1;\n            };\n            this.fetch(this.bootstrapEndpoint, p, {\n                bootstrap: true,\n                type: n\n            });\n            ++this._bootstrapRequestsPending;\n        },\n        _fetchOnUse: function(n, o) {\n            for (var p in this.bootstrapData) {\n                (!n.hasOwnProperty(p) && (n[p] = this.bootstrapData[p]));;\n            };\n            if (this._criticalOnly) {\n                this._fetchOnUseRequests.push({\n                    args: n,\n                    ctx: o\n                });\n            }\n             else this.fetch(this.bootstrapEndpoint, n, o);\n        ;\n        },\n        _fetchLean: function() {\n            var n = {\n                no_cache: 1\n            };\n            n.options = l(n.options);\n            n.options.push(\"lean\");\n            this._fetchOnUse(n, {\n                type: \"lean\"\n            });\n        },\n        bootstrap: function(n) {\n            if (!n) {\n                this._criticalOnly = false;\n                this._flushFetchOnUseRequests();\n            }\n        ;\n            if (this._bootstrapped) {\n                return\n            };\n            var o = {\n                filter: [\"event\",],\n                no_cache: 1\n            };\n            this._fetchOnUse(o, {\n                type: \"event\"\n            });\n            var p = [\"app\",\"page\",\"group\",\"friendlist\",];\n            p = p.concat((this._extraTypes || []));\n            if (this._noMultiFetch) {\n                p.push(\"user\");\n                this._bootstrapFetch(\"user\", {\n                    filter: p\n                });\n            }\n             else {\n                this._bootstrapFetch(\"other\", {\n                    filter: p\n                });\n                if (this._buckets) {\n                    for (var q = 0; (q < this._buckets.length); ++q) {\n                        var r = {\n                            filter: [\"user\",],\n                            buckets: this._buckets[q]\n                        };\n                        this._bootstrapFetch(\"user\", r);\n                    };\n                }\n                 else this._bootstrapFetch(\"user\", {\n                    filter: [\"user\",]\n                });\n            ;\n            }\n        ;\n            this._fetchLean();\n            this._bootstrapped = true;\n        },\n        _flushFetchOnUseRequests: function() {\n            var n = this._fetchOnUseRequests.length;\n            for (var o = 0; (o < n); ++o) {\n                var p = this._fetchOnUseRequests[o];\n                this.fetch(this.bootstrapEndpoint, p.args, p.ctx);\n            };\n            this._fetchOnUseRequests = [];\n        },\n        onLoad: function(n, o) {\n            this.inform(\"onload\", {\n                time: Date.now()\n            }, g.BEHAVIOR_PERSISTENT);\n            if (n) {\n                this.bootstrap.bind(this, o).defer();\n            };\n        },\n        mergeUids: function(n, o, p, q) {\n            var r = (p[0] ? this.getEntry(p[0]) : null), s = (o[0] ? this.getEntry(o[0]) : null), t = (((r && r.replace_results)) ? r : null);\n            t = ((((!t && s) && s.replace_results)) ? s : t);\n            var u = this.parent.mergeUids(n, o, p, q);\n            if (t) {\n                this.inform(\"backend_topreplace\", {\n                });\n                return this.deduplicateByKey([t.uid,].concat(u));\n            }\n        ;\n            return u;\n        }\n    });\n    e.exports = m;\n});\n__d(\"legacy:SearchDataSource\", [\"SearchDataSource\",], function(a, b, c, d) {\n    a.SearchDataSource = b(\"SearchDataSource\");\n}, 3);\n__d(\"SearchTypeaheadCore\", [\"event-extensions\",\"function-extensions\",\"Arbiter\",\"Class\",\"DOM\",\"Input\",\"Parent\",\"TypeaheadCore\",\"URI\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"Class\"), i = b(\"DOM\"), j = b(\"Input\"), k = b(\"Parent\"), l = b(\"TypeaheadCore\"), m = b(\"URI\"), n = b(\"copyProperties\");\n    function o(p) {\n        this.parent.construct(this, p);\n    };\n    h.extend(o, l);\n    n(o.prototype, {\n        init: function(p, q, r) {\n            this.parent.init(p, q, r);\n            var s = k.byTag(r, \"form\"), t = this.reset.bind(this);\n            g.subscribe(\"pre_page_transition\", function(event, v) {\n                var w = /^\\/search/, x = w.test(v.from.path), y = w.test(v.to.path);\n                if ((x && !y)) {\n                    t.defer();\n                };\n            });\n            if (s) {\n                var u = i.find(s, \"input.search_sid_input\");\n                Event.listen(s, \"submit\", function() {\n                    if ((this.data && this.data.queryData)) {\n                        u.value = this.data.queryData.sid;\n                    };\n                    t.defer();\n                }.bind(this), Event.Priority.URGENT);\n            }\n        ;\n        },\n        select: function() {\n            this.reset();\n            this.element.focus();\n            (function() {\n                this.element.blur();\n            }).bind(this).defer();\n        },\n        handleTab: function(event) {\n            var p = this.view.getQuerySuggestion(this.value);\n            if (p) {\n                j.setValue(this.element, p);\n                this.checkValue();\n                event.kill();\n            }\n             else this.parent.handleTab(event);\n        ;\n        }\n    });\n    e.exports = o;\n});\n__d(\"legacy:SearchTypeaheadCore\", [\"SearchTypeaheadCore\",], function(a, b, c, d) {\n    a.SearchTypeaheadCore = b(\"SearchTypeaheadCore\");\n}, 3);\n__d(\"SearchTypeaheadView\", [\"Arbiter\",\"ContextualTypeaheadView\",\"Class\",\"ContextualLayerUpdateOnScroll\",\"copyProperties\",\"DOM\",\"goURI\",\"MusicConstants\",\"MusicEvents\",\"tx\",\"URI\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ContextualTypeaheadView\"), i = b(\"Class\"), j = b(\"ContextualLayerUpdateOnScroll\"), k = b(\"copyProperties\"), l = b(\"DOM\"), m = b(\"goURI\"), n = b(\"MusicConstants\"), o = b(\"MusicEvents\"), p = b(\"tx\"), q = b(\"URI\");\n    function r(s, t) {\n        this.parent.construct(this, s, t);\n    };\n    i.extend(r, h);\n    k(r.prototype, {\n        initializeLayer: function() {\n            this.parent.initializeLayer();\n            this.layer.setOffsetY(-1);\n            this.layer.enableBehavior(j);\n        },\n        ignoreClick: function(event) {\n            event.prevent();\n        },\n        shouldShowSeeMore: true,\n        queryData: {\n            init: \"quick\"\n        },\n        render: function(s, t, u) {\n            var v = {\n                results: t,\n                value: s\n            };\n            this.inform(\"finalResultsReordering\", v);\n            return this.parent.render(s, v.results, u);\n        },\n        buildBuckets: function(s, t) {\n            var u = t.length;\n            this.setWebSuggLoggingParams(s, t);\n            t = this.parent.buildBuckets(s, t);\n            if ((s && this.shouldShowSeeMore)) {\n                t.push(this.buildSeeMore(s, u));\n            };\n            return t;\n        },\n        buildSeeMore: function(s, t) {\n            var u = ((t > 0) ? p._(\"See more results for {query}\", {\n                query: s\n            }) : p._(\"See results for {query}\", {\n                query: s\n            })), v = ((t == 1) ? \"Displaying top result\" : p._(\"Displaying top {number} results\", {\n                number: t\n            })), w = l.create(\"li\", {\n                className: \"calltoaction\"\n            }, [l.create(\"a\", {\n                href: this.getSeeMoreEndpoint(s),\n                rel: \"ignore\"\n            }, [l.create(\"span\", {\n                className: \"text\"\n            }, [l.create(\"span\", {\n                className: \"seeMore\"\n            }, [u,l.create(\"span\", {\n                className: \"arrow\"\n            }),]),l.create(\"span\", {\n                className: \"subtext\"\n            }, [v,]),]),]),]);\n            w.setAttribute(\"aria-label\", u);\n            return {\n                uid: \"search\",\n                node: w,\n                search: true\n            };\n        },\n        searchPageQueryData: function(s) {\n            return k({\n                q: s\n            }, (this.queryData || {\n            }));\n        },\n        select: function(s) {\n            var t = this.index, u = this.results[t];\n            if ((!u || (u.type == \"header\"))) {\n                return\n            };\n            var v = this.items[t], w = l.scry(v, \"a\")[0];\n            if (u.song) {\n                if (w) {\n                    o.inform(n.MUSIC_BUTTON.ACTIVATE, w);\n                };\n                (s && this.inform(\"highlight\", {\n                    index: t,\n                    selected: u\n                }));\n            }\n             else {\n                this.parent.select(s);\n                if ((w && w.href)) {\n                    if ((w.target == \"_blank\")) {\n                        window.open(w.href);\n                    }\n                     else m(w.href);\n                \n                };\n            }\n        ;\n        },\n        setSid: function(s) {\n            this.queryData.tas = s;\n        },\n        getSeeMoreEndpoint: function(s) {\n            return q(this.seeMoreEndpoint).addQueryData(this.searchPageQueryData(s)).toString();\n        },\n        show: function() {\n            if (!this.isVisible()) {\n                g.inform(\"layer_shown\", {\n                    type: \"SearchTypeahead\"\n                });\n                this.parent.show();\n            }\n        ;\n        },\n        hide: function() {\n            if (this.isVisible()) {\n                g.inform(\"layer_hidden\", {\n                    type: \"SearchTypeahead\"\n                });\n                this.parent.hide();\n            }\n        ;\n        },\n        getQuerySuggestion: function(s) {\n            var t = this.results[this.index], u = ((t && (t.type != \"header\")) ? t.text.toLowerCase() : \"\");\n            return ((u == s.toLowerCase()) ? \"\" : u);\n        },\n        setWebSuggLoggingParams: function(s, t) {\n            var u = 0, v = 0;\n            for (var w = 0; (w < t.length); w++) {\n                if ((t[w].type === \"websuggestion\")) {\n                    if ((v === 0)) {\n                        v = (w + 1);\n                    };\n                    var x = (((\"FR\" + ((w - u))) + \"AS\") + u), y = (w + 1);\n                    t[w].path += (((((\"&wssk=\" + x) + \"&wssp=\") + y) + \"&wspq=\") + encodeURIComponent(s));\n                    u++;\n                }\n            ;\n            };\n            var z = (((((((\"&wssc=\" + t.length) + \"-\") + s.length) + \"&wsbp=\") + u) + \"-\") + v);\n            for (w = 0; (w < t.length); w++) {\n                if ((t[w].type === \"websuggestion\")) {\n                    t[w].path += z;\n                };\n            };\n        }\n    });\n    e.exports = r;\n});\n__d(\"legacy:SearchTypeaheadView\", [\"SearchTypeaheadView\",], function(a, b, c, d) {\n    a.SearchTypeaheadView = b(\"SearchTypeaheadView\");\n}, 3);\n__d(\"legacy:Typeahead\", [\"Typeahead\",], function(a, b, c, d) {\n    a.Typeahead = b(\"Typeahead\");\n}, 3);\n__d(\"SearchTypeaheadRecorder\", [\"event-extensions\",\"AsyncRequest\",\"Keys\",\"$\",\"copyProperties\",\"userAction\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"AsyncRequest\"), h = b(\"Keys\"), i = b(\"$\"), j = b(\"copyProperties\"), k = b(\"userAction\");\n    function l(m) {\n        this.init(m);\n        this.initEvents();\n    };\n    j(l.prototype, {\n        _endPoint: \"/ajax/typeahead/record_metrics.php\",\n        init: function(m) {\n            this.core = m.getCore();\n            this.data = m.getData();\n            this.view = m.getView();\n            this.element = this.core.getElement();\n            this.initTime = Date.now();\n            this._onloadTime = 0;\n            this.initStartTime = i(\"search_first_focus\").value;\n            this.bootstrapStats = {\n                bootstrapped: 0\n            };\n            this._reset();\n        },\n        _reset: function() {\n            this.stats = {\n            };\n            this.avgStats = {\n            };\n            this.appendStats = {\n            };\n            this._backspacing = false;\n            this._topreplace = false;\n            this._inflightRequests = {\n            };\n            var m = Math.random();\n            this.data.setQueryData({\n                sid: m\n            });\n            this.view.setSid(m);\n            this.recordStat(\"sid\", m);\n        },\n        initEvents: function() {\n            this.core.subscribe(\"focus\", function(event) {\n                if (!this.stats.session_start_time) {\n                    this.recordStat(\"session_start_time\", Date.now());\n                };\n            }.bind(this));\n            this.core.subscribe(\"blur\", function(event) {\n                var m = Date.now();\n                for (var n in this._inflightRequests) {\n                    var o = this._inflightRequests[n], p = (m - o);\n                    this.recordAvgStat(\"search_endpoint_ms_from_js\", p);\n                };\n                this.recordStat(\"session_end_time\", m);\n                this.submit();\n            }.bind(this));\n            this.view.subscribe(\"select\", function(m, n) {\n                this.recordSelectInfo(n);\n            }.bind(this));\n            this.view.subscribe(\"render\", function(m, n) {\n                this.recordRender(n);\n            }.bind(this));\n            this.view.subscribe(\"recordAfterReorder\", function(m, n) {\n                this._reorderInfo = n;\n            }.bind(this));\n            this.data.subscribe(\"activity\", function(m, n) {\n                this.recordStat(\"pending_request\", n.activity);\n            }.bind(this));\n            this.data.subscribe(\"beforeQuery\", function(m, n) {\n                if (!n.value) {\n                    return\n                };\n                if (!this.stats.first_query_time) {\n                    this.recordStat(\"first_query_time\", Date.now());\n                };\n                this.query = n.value;\n                this.recordCountStat(\"num_queries\");\n            }.bind(this));\n            this.data.subscribe(\"queryEndpoint\", function(m, n) {\n                this.recordCountStat(\"num_search_ajax_requests\");\n                this.recordAvgStat(\"endpoint_query_length\", n.value.length);\n                this._inflightRequests[n.value] = Date.now();\n            }.bind(this));\n            this.data.subscribe(\"onload\", function(m, n) {\n                this._onloadTime = n.time;\n            }.bind(this));\n            this.data.subscribe(\"bootstrapped\", function(m, n) {\n                this.bootstrapStats.endTime = n.time;\n                this.bootstrapStats.bootstrapped = 1;\n            }.bind(this));\n            this.data.subscribe(\"endpointStats\", function(m, n) {\n                var o = (n.fetch_end - n.fetch_start);\n                if (n.value) {\n                    this.recordAvgStat(\"search_endpoint_ms_from_js\", o);\n                }\n                 else this.bootstrapStats[n.type] = o;\n            ;\n                if (n.coeff2_ts) {\n                    this.bootstrapStats.coeff2_ts = n.coeff2_ts;\n                };\n                if ((typeof n.browserCacheHit != \"undefined\")) {\n                    this.recordCountStat((n.browserCacheHit ? \"bootstrap_cachehits\" : \"bootstrap_cachemisses\"));\n                };\n                if (this._inflightRequests[n.value]) {\n                    delete this._inflightRequests[n.value];\n                };\n            }.bind(this));\n            this.data.subscribe(\"query\", function(m, n) {\n                this.recordAvgStat(\"num_results_from_cache\", n.results.length);\n            }.bind(this));\n            this.data.subscribe(\"backend_topreplace\", function(m, n) {\n                if ((false === this._topreplace)) {\n                    this.recordStat(\"backend_topreplace\", 1);\n                    this._topreplace = true;\n                }\n            ;\n            }.bind(this));\n            Event.listen(this.element, \"keydown\", function(event) {\n                if ((Event.getKeyCode(event) == h.BACKSPACE)) {\n                    if (!this._backspacing) {\n                        this._backspacing = true;\n                        this.recordAppendStat(\"before_backspace_queries\", this.query);\n                    }\n                ;\n                }\n                 else this._backspacing = false;\n            ;\n            }.bind(this));\n        },\n        recordStat: function(m, n) {\n            this.stats[m] = n;\n        },\n        recordCountStat: function(m) {\n            var n = this.stats[m];\n            this.stats[m] = (n ? (n + 1) : 1);\n        },\n        recordAvgStat: function(m, n) {\n            if (this.avgStats[m]) {\n                this.avgStats[m][0] += n;\n                ++this.avgStats[m][1];\n            }\n             else this.avgStats[m] = [n,1,];\n        ;\n        },\n        recordAppendStat: function(m, n) {\n            if (!this.appendStats.hasOwnProperty(m)) {\n                this.appendStats[m] = [];\n            };\n            this.appendStats[m].push(n);\n        },\n        recordRender: function(m) {\n            this.results = m.filter(function(n) {\n                return ((n.uid != \"search\") && (n.type != \"header\"));\n            });\n            if (((this.results.length > 0) && !this.stats.first_result_time)) {\n                this.recordStat(\"first_result_time\", Date.now());\n            };\n        },\n        recordSelectInfo: function(m) {\n            var n = m.selected, o = ((m.index - n.groupIndex) - 1), p = {\n                href: n.path\n            }, q = (n.dataGT ? {\n                gt: JSON.parse(n.dataGT)\n            } : {\n            });\n            k(\"click\", p, null, null, q);\n            if ((n.uid == \"search\")) {\n                this.recordStat(\"selected_search\", 1);\n            }\n             else {\n                var r = ((n.rankType || n.render_type) || n.type), s = (((r == \"friend\") ? \"user\" : r));\n                this.recordStat((\"selected_\" + s), 1);\n                this.recordStat(\"selected_position\", o);\n                this.recordStat(\"selected_type\", r);\n                this.recordStat(\"selected_name_length\", n.text.length);\n                this.recordStat(\"selected_id\", n.uid);\n                this.recordStat(\"selected_degree\", (n.bootstrapped ? 1 : 2));\n            }\n        ;\n            this.recordStat(\"selected_with_mouse\", (m.clicked ? 1 : 0));\n        },\n        _dataToSubmit: function() {\n            this.recordStat(\"candidate_results\", this.buildResults());\n            this.recordStat(\"query\", this.query);\n            this.recordStat(\"init_time\", this.initTime);\n            if (this.initStartTime) {\n                this.recordStat(\"init_start_time\", this.initStartTime);\n                this.recordStat(\"onload_time\", this._onloadTime);\n                this.initStartTime = 0;\n            }\n        ;\n            this.recordStat(\"bootstrapped\", this.bootstrapStats.bootstrapped);\n            if (this.bootstrapStats.endTime) {\n                this.recordStat(\"bootstrapped_time\", this.bootstrapStats.endTime);\n                this.recordStat(\"user_bootstrap_ms\", this.bootstrapStats.user);\n                this.recordStat(\"other_bootstrap_ms\", this.bootstrapStats.other);\n                this.bootstrapStats.endTime = 0;\n            }\n        ;\n            this.recordStat(\"coeff2_ts\", this.bootstrapStats.coeff2_ts);\n            this.recordStat(\"max_results\", this.data._maxResults);\n            if (this._reorderInfo) {\n                var m = this._reorderInfo;\n                m.organic.forEach(function(q) {\n                    delete q.text;\n                });\n                this.recordStat(\"s_count\", m.position_data.length);\n                this.recordStat(\"s_bootstrap_id\", m.s_bootstrap_id);\n                this.recordStat(\"s_organic_results\", JSON.stringify(m.organic));\n                this.recordStat(\"s_candidate_tokens\", JSON.stringify(m.tokens));\n                this.recordStat(\"s_positions\", JSON.stringify(m.position_data));\n                this.recordStat(\"s_options\", JSON.stringify(m.options));\n                this.recordStat(\"s_variant\", JSON.stringify(m.variant));\n            }\n        ;\n            var n = this.stats;\n            for (var o in this.avgStats) {\n                var m = this.avgStats[o];\n                n[o] = (m[0] / m[1]);\n            };\n            for (var p in this.appendStats) {\n                n[p] = JSON.stringify(this.appendStats[p]);;\n            };\n            return n;\n        },\n        buildResults: function() {\n            var m = ((this.results || [])).map(function(n, o) {\n                var p = ((n.rankType || n.render_type) || n.type), q = (n.bootstrapped ? 1 : 0), r = (n.s_token || \"\");\n                if ((typeof n.groupIndex == \"number\")) {\n                    return [n.groupIndex,n.indexInGroup,n.uid,p,q,r,]\n                };\n                return [0,o,n.uid,p,q,r,];\n            });\n            return JSON.stringify(m);\n        },\n        submit: function() {\n            var m = this._dataToSubmit();\n            if ((Object.keys(m).length > 0)) {\n                new g().setURI(this._endPoint).setMethod(\"POST\").setData({\n                    stats: m\n                }).setOption(\"handleErrorAfterUnload\", true).setErrorHandler(function(n) {\n                    m.retry = true;\n                    new g().setURI(this._endPoint).setMethod(\"POST\").setData({\n                        stats: m\n                    }).setOption(\"asynchronous\", false).send();\n                }.bind(this)).send();\n            };\n            this._reset();\n        }\n    });\n    e.exports = l;\n});\n__d(\"TypeaheadSearchRecorderBasic\", [\"SearchTypeaheadRecorder\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"SearchTypeaheadRecorder\"), h = b(\"copyProperties\");\n    function i(j) {\n        this._typeahead = j;\n    };\n    h(i.prototype, {\n        enable: function() {\n            new g(this._typeahead);\n        },\n        disable: bagofholding\n    });\n    e.exports = i;\n});\n__d(\"legacy:SearchRecorderBasicTypeaheadBehavior\", [\"TypeaheadSearchRecorderBasic\",], function(a, b, c, d) {\n    var e = b(\"TypeaheadSearchRecorderBasic\");\n    if (!a.TypeaheadBehaviors) {\n        a.TypeaheadBehaviors = {\n        };\n    };\n    a.TypeaheadBehaviors.searchRecorderBasic = function(f) {\n        f.enableBehavior(e);\n    };\n}, 3);\n__d(\"SearchTypeaheadRenderer\", [\"DOM\",\"Env\",\"MusicButtonManager\",\"TypeaheadUtil\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"Env\"), i = b(\"MusicButtonManager\"), j = b(\"TypeaheadUtil\");\n    function k(l, m) {\n        var n = [];\n        if (l.photo) {\n            n.push(g.create(\"img\", {\n                className: \"photo\",\n                alt: \"\",\n                src: l.photo\n            }));\n            if (l.song) {\n                n.push(g.create(\"span\", {\n                    className: \"playButton\"\n                }));\n                n.push(g.create(\"span\", {\n                    className: \"playLoader\"\n                }));\n            }\n        ;\n        }\n    ;\n        if (l.text) {\n            var o = l.alias, p = this.value, q = l.text, r = [q,];\n            if (((o && j.isQueryMatch(p, o)) && !j.isQueryMatch(p, q))) {\n                r.push(g.create(\"span\", {\n                    className: \"alias\"\n                }, [(\" \\u00b7 \" + o),]));\n            };\n            n.push(g.create(\"span\", {\n                className: \"text\"\n            }, r));\n        }\n    ;\n        if (l.category) {\n            var s = [l.category,];\n            if (l.is_external) {\n                s.push(g.create(\"span\", {\n                    className: \"arrow\"\n                }));\n            };\n            var t = (l.message ? \"preCategory\" : \"category\");\n            n.push(g.create(\"span\", {\n                className: t\n            }, s));\n        }\n    ;\n        if (l.message) {\n            n.push(g.create(\"span\", {\n                className: \"category\"\n            }, [l.message,]));\n        };\n        var u = (l.subtextOverride || l.subtext);\n        if (u) {\n            n.push(g.create(\"span\", {\n                className: \"subtext\"\n            }, [u,]));\n        };\n        var v = ((l.classNames || l.type) || \"\"), w = (l.is_external ? \"_blank\" : \"\"), x = ((!l.song && l.path) || \"\");\n        if (x) {\n            if (!(/^https?\\:\\/\\//).test(x)) {\n                x = (h.www_base + x.substr(1));\n            };\n            x += ((((x.indexOf(\"?\") > 0) ? \"&\" : \"?\")) + \"ref=ts\");\n        }\n    ;\n        var y = g.create(\"a\", {\n            href: x,\n            rel: \"ignore\",\n            target: w\n        }, n);\n        if (l.song) {\n            y.id = (\"mb_\" + (((Math.random() * 1000000) | 0)));\n            i.addButton.curry(l.song.provider, y.id, l.song.url, l.song.context, l.song.media_type).defer();\n            y.onclick = this.ignoreClick;\n        }\n    ;\n        var z = g.create(\"li\", {\n            className: v\n        }, [y,]);\n        z.setAttribute(\"role\", \"option\");\n        if (l.text) {\n            z.setAttribute(\"aria-label\", l.text);\n        };\n        return z;\n    };\n    k.className = \"search\";\n    e.exports = k;\n});\n__d(\"legacy:SearchTypeaheadRenderer\", [\"SearchTypeaheadRenderer\",], function(a, b, c, d) {\n    if (!a.TypeaheadRenderers) {\n        a.TypeaheadRenderers = {\n        };\n    };\n    a.TypeaheadRenderers.search = b(\"SearchTypeaheadRenderer\");\n}, 3);\nvoid (0);\n__d(\"TypeaheadSearchFilter\", [\"Arbiter\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"copyProperties\");\n    function i(j) {\n        this._typeahead = j;\n    };\n    h(i.prototype, {\n        _subscription: null,\n        enable: function() {\n            var j = this._typeahead;\n            this._subscriptions = [g.subscribe(\"search/typeahead/updateFilter\", function(k, l) {\n                if ((l.filter_type == \"web\")) {\n                    j.getView().queryData.form = \"FBKBFR\";\n                };\n                j.getView().queryData.type = l.filter_type;\n            }),g.subscribe(\"page_transition\", function(k, l) {\n                if (j.getView().queryData.form) {\n                    delete j.getView().queryData.form;\n                };\n                delete j.getView().queryData.type;\n            }, g.SUBSCRIBE_NEW),];\n        },\n        disable: function() {\n            this._subscriptions.forEach(function(j) {\n                j.unsubscribe();\n            });\n            this._subscriptions = null;\n        }\n    });\n    e.exports = i;\n});\n__d(\"legacy:SearchFilterTypeaheadBehavior\", [\"TypeaheadSearchFilter\",], function(a, b, c, d) {\n    var e = b(\"TypeaheadSearchFilter\");\n    if (!a.TypeaheadBehaviors) {\n        a.TypeaheadBehaviors = {\n        };\n    };\n    a.TypeaheadBehaviors.initFilters = function(f) {\n        f.enableBehavior(e);\n    };\n}, 3);\n__d(\"JewelSuggestFriendsFollowupUnit\", [\"DOM\",\"Arbiter\",\"CSS\",\"csx\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"Arbiter\"), i = b(\"CSS\"), j = b(\"csx\"), k = b(\"copyProperties\");\n    function l(m, n) {\n        this._friend_id = m;\n        this._container = n.parentElement;\n        var o = [\"FriendRequest/confirming\",\"FriendSuggestion/accepting\",];\n        h.subscribe(o, function(q, r) {\n            (((r.uid == m)) && this._renderPromotion());\n        }.bind(this));\n        g.find(this._container, \".-cx-PRIVATE-jewelFollowupUnitLayout__skip\").onclick = this._restore.bind(this);\n        var p = [\"FriendSuggestion/sent\",\"FriendRequest/confirmFail\",\"FriendSuggestion/acceptFail\",];\n        h.subscribe(p, function(q, r) {\n            (((r.uid == m)) && this._restore());\n        }.bind(this));\n    };\n    k(l.prototype, {\n        _renderPromotion: function() {\n            i.addClass(this._container, \"followupActivated\");\n        },\n        _restore: function() {\n            i.removeClass(this._container, \"followupActivated\");\n        }\n    });\n    e.exports = l;\n});\n__d(\"StickyArea\", [\"event-extensions\",\"ContextualLayer\",\"CSS\",\"DataStore\",\"DOM\",\"LayerHideOnTransition\",\"Parent\",\"Style\",\"Vector\",\"copyProperties\",\"cx\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ContextualLayer\"), h = b(\"CSS\"), i = b(\"DataStore\"), j = b(\"DOM\"), k = b(\"LayerHideOnTransition\"), l = b(\"Parent\"), m = b(\"Style\"), n = b(\"Vector\"), o = b(\"copyProperties\"), p = b(\"cx\");\n    function q(s) {\n        var t = (l.byClass(s, \"scrollable\") || m.getScrollParent(s.parentNode));\n        this.node = s;\n        this._extracted = false;\n        this._placeholder = j.create(\"div\", {\n            className: \"-cx-PRIVATE-uiStickyArea__placeholder\"\n        });\n        r.getInstance(t).register(this);\n    };\n    o(q.prototype, {\n        update: function() {\n            if (this._extracted) {\n                n.getElementDimensions(this._placeholder).setElementWidth(this.node);\n                n.getElementDimensions(this.node).setElementHeight(this._placeholder);\n            }\n             else n.getElementDimensions(this.node).setElementWidth(this.node).setElementHeight(this._placeholder);\n        ;\n            return this;\n        },\n        setExtracted: function(s) {\n            if ((s === this._extracted)) {\n                return this\n            };\n            if (s) {\n                this.update();\n                j.replace(this.node, this._placeholder);\n            }\n             else {\n                m.set(this.node, \"height\", null);\n                m.set(this.node, \"width\", null);\n                j.replace(this._placeholder, this.node);\n            }\n        ;\n            this._extracted = s;\n            return this;\n        },\n        getOffsetTop: function() {\n            return ((this._extracted ? this._placeholder : this.node)).offsetTop;\n        }\n    });\n    function r(s) {\n        this.node = s;\n        this._areas = [];\n        this._fixTarget = null;\n        this._fixedArea = null;\n        this._initialized = false;\n        this._layer = new g({\n        }, j.create(\"div\")).setInsertParent(this.node.parentNode).disableBehavior(k);\n        this._listener = Event.listen(s, \"scroll\", this.update.bind(this));\n        h.addClass(s, \"-cx-PRIVATE-uiStickyArea__container\");\n        i.set(s, \"StickyContainer\", this);\n    };\n    r.getInstance = function(s) {\n        var t = i.get(s, \"StickyContainer\");\n        return (t || new r(s));\n    };\n    o(r.prototype, {\n        isDisplayed: function() {\n            return (this.node.offsetParent !== null);\n        },\n        register: function(s) {\n            this._areas.push(s);\n            return this;\n        },\n        update: function() {\n            if (!this.isDisplayed()) {\n                return this\n            };\n            var s = null, t = this, u = this.node.scrollTop;\n            for (var v = 0; (v < this._areas.length); v++) {\n                var w = this._areas[v], x = w.getOffsetTop();\n                if ((x <= u)) {\n                    s = w;\n                }\n                 else if (s) {\n                    var y = n.getElementDimensions(s.node).y;\n                    if (((x - y) < u)) {\n                        t = w;\n                    };\n                    break;\n                }\n                \n            ;\n            };\n            if (((this._fixedArea === s) && (this._fixTarget === t))) {\n                (this._fixedArea && this._fixedArea.update());\n            }\n             else {\n                if ((this._fixedArea && (this._fixedArea !== s))) {\n                    this._unfixArea(this._fixedArea);\n                };\n                if (s) {\n                    this._fixAreaTo(s, t);\n                };\n                this._fixedArea = s;\n                this._fixTarget = t;\n            }\n        ;\n            return this;\n        },\n        destroy: function() {\n            (this._listener && this._listener.remove());\n            this._listener = null;\n        },\n        _fixAreaTo: function(s, t) {\n            this._layer.hide();\n            s.setExtracted(true);\n            if ((t instanceof r)) {\n                this._layer.setInsertParent(this.node.parentNode).setContext(this.node);\n            }\n             else this._layer.setInsertParent(this.node).setContext(t.node);\n        ;\n            this._layer.setContent(s.node).show();\n        },\n        _unfixArea: function(s) {\n            this._layer.hide();\n            s.setExtracted(false);\n        }\n    });\n    e.exports = q;\n});\n__d(\"TypeaheadRegulateMemorializedUsers\", [\"copyProperties\",\"TypeaheadUtil\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\"), h = b(\"TypeaheadUtil\");\n    function i(j) {\n        this._typeahead = j;\n    };\n    g(i.prototype, {\n        _filterRegistry: null,\n        _filter: function(j, k) {\n            if (((j.type !== \"user\") || !j.memorialized)) {\n                return true\n            };\n            var l = h.parse(j.text).tokens;\n            if (((l.length === 1) && h.isExactMatch(k, j.text))) {\n                return true\n            };\n            var m = this._typeahead.getData().getTextToIndex(j), n = h.parse(k).tokens;\n            return (((n.length > 1) && h.isQueryMatch(k, m)));\n        },\n        enable: function() {\n            this._filterRegistry = this._typeahead.getData().addFilter(this._filter.bind(this));\n        },\n        disable: function() {\n            this._filterRegistry.remove();\n            this._filterRegistry = null;\n        }\n    });\n    e.exports = i;\n});\n__d(\"legacy:RegulateMemorializedUsersTypeaheadBehavior\", [\"TypeaheadRegulateMemorializedUsers\",], function(a, b, c, d) {\n    var e = b(\"TypeaheadRegulateMemorializedUsers\");\n    if (!a.TypeaheadBehaviors) {\n        a.TypeaheadBehaviors = {\n        };\n    };\n    a.TypeaheadBehaviors.regulateMemorializedUsers = function(f) {\n        f.enableBehavior(e);\n    };\n}, 3);\n__d(\"legacy:CompactTypeaheadRenderer\", [\"CompactTypeaheadRenderer\",], function(a, b, c, d) {\n    if (!a.TypeaheadRenderers) {\n        a.TypeaheadRenderers = {\n        };\n    };\n    a.TypeaheadRenderers.compact = b(\"CompactTypeaheadRenderer\");\n}, 3);");
// 2901
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"scc05bc1d232ca63b0fd4c6bf8ca63db078ee33bf");
// 2902
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"6n1TR\",]);\n}\n;\n;\n__d(\"legacy:fbdesktop-plugin\", [\"FBDesktopPlugin\",], function(a, b, c, d) {\n    a.FbDesktopPlugin = b(\"FBDesktopPlugin\");\n}, 3);\n__d(\"FbdEventLog\", [\"URI\",\"AsyncSignal\",], function(a, b, c, d, e, f) {\n    var g = b(\"URI\"), h = b(\"AsyncSignal\"), i = {\n        log: function(j, k, l, m) {\n            if (!j) {\n                return;\n            }\n        ;\n        ;\n            var n = g(\"/desktop/eventlog.php\"), o = new h(n.toString(), {\n                JSBNG__event: j,\n                category: ((k || \"unknown\")),\n                payload: ((l || \"\"))\n            });\n            o.setHandler(m).send();\n        }\n    };\n    e.exports = i;\n});\n__d(\"ModalMask\", [\"DOM\",\"UserAgent\",\"Vector\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"UserAgent\"), i = b(\"Vector\"), j = {\n        _modalMask: null,\n        _depth: 0,\n        show: function() {\n            if (!this._modalMask) {\n                this._modalMask = g.create(\"div\", {\n                    id: \"modalMaskOverlay\"\n                });\n                g.appendContent(JSBNG__document.body, this._modalMask);\n            }\n        ;\n        ;\n            this._depth++;\n            if (((h.ie() < 7))) {\n                this._modalMask.height = ((i.getDocumentDimensions().y + \"px\"));\n            }\n        ;\n        ;\n        },\n        hide: function() {\n            this._depth--;\n            if (((!this._depth && this._modalMask))) {\n                g.remove(this._modalMask);\n                this._modalMask = null;\n            }\n        ;\n        ;\n        }\n    };\n    e.exports = j;\n});\n__d(\"DownloadDialog\", [\"event-extensions\",\"Arbiter\",\"Class\",\"CSS\",\"DataStore\",\"ModalMask\",\"Overlay\",\"Parent\",\"Style\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"Class\"), i = b(\"CSS\"), j = b(\"DataStore\"), k = b(\"ModalMask\"), l = b(\"Overlay\"), m = b(\"Parent\"), n = b(\"Style\"), o = b(\"copyProperties\");\n    function p() {\n        this.parent.construct(this);\n        return this;\n    };\n;\n    h.extend(p, l);\n    o(p, {\n        POSITIONS: {\n            BOTTOM_LEFT: \"bottom_left\",\n            TOP_LEFT: \"top_left\",\n            IE9_BOTTOM: \"ie9_bottom\"\n        },\n        activeDialogs: {\n        },\n        dismissAll: function() {\n            for (var q in this.POSITIONS) {\n                this.hideDialog(this.POSITIONS[q]);\n            ;\n            };\n        ;\n        },\n        hideDialog: function(q) {\n            var r = this.activeDialogs[q];\n            ((r && r.hide()));\n            this.activeDialogs[q] = null;\n        }\n    });\n    o(p.prototype, {\n        _cancelHandler: bagofholding,\n        _closeHandler: bagofholding,\n        _width: null,\n        position: p.POSITIONS.BOTTOM_LEFT,\n        init: function(q, r) {\n            this.parent.init(q);\n            this.position = r;\n            var s = ((j.get(this._root, \"modal\") === \"true\"));\n            p.hideDialog(r);\n            p.activeDialogs[r] = this;\n            JSBNG__Event.listen(this._root, \"click\", function(JSBNG__event) {\n                if (m.byClass(JSBNG__event.getTarget(), \"closeButton\")) {\n                    if (((this._cancelHandler() !== false))) {\n                        p.hideDialog(this.position);\n                    }\n                ;\n                }\n            ;\n            ;\n            }.bind(this));\n            this.subscribe(\"show\", function() {\n                if (s) {\n                    k.show();\n                }\n            ;\n            ;\n                g.inform(\"layer_shown\", {\n                    type: \"DownloadDialog\"\n                });\n            }.bind(this));\n            this.subscribe(\"hide\", function() {\n                if (s) {\n                    k.hide();\n                }\n            ;\n            ;\n                g.inform(\"layer_hidden\", {\n                    type: \"DownloadDialog\"\n                });\n                this._closeHandler();\n            }.bind(this));\n        },\n        setWidth: function(q) {\n            this._width = Math.floor(q);\n            return this;\n        },\n        updatePosition: function() {\n            if (this._width) {\n                n.set(this._overlay, \"width\", ((this._width + \"px\")));\n            }\n        ;\n        ;\n            return true;\n        },\n        setCancelHandler: function(q) {\n            this._cancelHandler = ((q || bagofholding));\n            return this;\n        },\n        setCloseHandler: function(q) {\n            this._closeHandler = ((q || bagofholding));\n            return this;\n        }\n    });\n    e.exports = p;\n});\n__d(\"FbdConversionTracking\", [\"AsyncRequest\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncRequest\"), h = {\n        logClick: function(i) {\n            new g().setURI(\"/ajax/desktop/log_clicks.php\").setData({\n                click_source: i\n            }).setAllowCrossPageTransition(true).setErrorHandler(bagofholding).send();\n        },\n        logConversion: function(i) {\n            new g().setURI(\"/ajax/desktop/log_conversions.php\").setData({\n                conversion_action: i\n            }).setAllowCrossPageTransition(true).setErrorHandler(bagofholding).send();\n        }\n    };\n    e.exports = h;\n});\n__d(\"MegaphoneHelper\", [\"Animation\",\"AsyncRequest\",\"Dialog\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"Animation\"), h = b(\"AsyncRequest\"), i = b(\"Dialog\"), j = b(\"ge\"), k = {\n        hideStory: function(l, m, n, o, p) {\n            var q = {\n                mp_id: l,\n                JSBNG__location: m,\n                context: o\n            };\n            new h().setURI(\"/ajax/megaphone/megaphone_hide.php\").setMethod(\"POST\").setData(q).setHandler(function(s) {\n                ((p && p(s)));\n            }).send();\n            var r = j(n);\n            if (r) {\n                g(r).to(\"height\", 0).duration(500).hide().go();\n            }\n        ;\n        ;\n        },\n        createModalStory: function(l, m, n, o) {\n            var p;\n            if (((!l.buttons || !l.buttons.length))) {\n                l.buttons = i.CLOSE;\n                p = this.hideStory.bind(this, m, n, o, null);\n            }\n        ;\n        ;\n            var q = new i(l);\n            if (p) {\n                q.setHandler(p);\n            }\n        ;\n        ;\n            q.show();\n        },\n        buttonOnClick: function(l, m, n, o, p, q) {\n            var r = function() {\n                if (p) {\n                    new h().setURI(o).send();\n                }\n                 else JSBNG__document.JSBNG__location.href = o;\n            ;\n            ;\n            };\n            if (q) {\n                this.hideStory(l, m, \"\", n, function() {\n                    r();\n                });\n            }\n             else r();\n        ;\n        ;\n        }\n    };\n    e.exports = k;\n});\n__d(\"FbdInstall\", [\"$\",\"AsyncRequest\",\"CSS\",\"DOM\",\"DownloadDialog\",\"FbdConversionTracking\",\"FbdEventLog\",\"FBDesktopDetect\",\"FBDesktopPlugin\",\"MegaphoneHelper\",], function(a, b, c, d, e, f) {\n    var g = b(\"$\"), h = b(\"AsyncRequest\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"DownloadDialog\"), l = b(\"FbdConversionTracking\"), m = b(\"FbdEventLog\"), n = b(\"FBDesktopDetect\"), o = b(\"FBDesktopPlugin\"), p = b(\"MegaphoneHelper\"), q = 1000, r = ((300 * q)), s = {\n        cancelSetup: function() {\n            var t = JSON.stringify({\n                ref: this.ref\n            });\n            m.log(\"download_canceled\", \"setup\", t);\n            l.logConversion(\"download_canceled\");\n        },\n        hideMegaphone: function() {\n            if (((this.megaphoneId && this.megaphoneLoc))) {\n                p.hideStory(this.megaphoneId, this.megaphoneLoc, this.elementId, \"\", null);\n            }\n        ;\n        ;\n        },\n        init: function(t, u) {\n            this.downloadUrl = t;\n            this.ref = ((u || \"unknown\"));\n        },\n        initInstallWait: function(t, u, v) {\n            this.megaphoneId = t;\n            this.megaphoneLoc = u;\n            this.elementId = v;\n            this._waitForInstall(r);\n        },\n        promptDownload: function(t) {\n            t = ((t || this.downloadUrl));\n            if (t) {\n                var u = JSON.stringify({\n                    ref: this.ref\n                });\n                m.log(\"download_prompted\", \"setup\", u);\n                l.logConversion(\"download_prompted\");\n                var v = j.create(\"div\", {\n                    src: t,\n                    className: \"hidden_elem\"\n                });\n                j.appendContent(JSBNG__document.body, v);\n            }\n        ;\n        ;\n        },\n        _responseHandler: function(t) {\n            if (t.payload) {\n                this._authToken = t.payload.access_token;\n                this._userId = t.payload.id;\n            }\n        ;\n        ;\n            if (((this._authToken && this._userId))) {\n                this._waitForRunningStart = new JSBNG__Date().getTime();\n                JSBNG__setTimeout(this._waitForRunning.bind(this), q);\n            }\n        ;\n        ;\n        },\n        setupPlugin: function() {\n            new h(\"/ajax/desktop/download\").send();\n            this.promptDownload();\n        },\n        updateSidebarLinkVisibility: function() {\n            if (!n.isPluginInstalled()) {\n                i.show(g(\"sidebar-messenger-install-link\"));\n                i.show(g(\"sidebar-messenger-install-separator\"));\n            }\n        ;\n        ;\n        },\n        _waitForInstall: function(t) {\n            var u = JSON.stringify({\n                ref: this.ref\n            });\n            if (n.isPluginInstalled()) {\n                m.log(\"install_success\", \"setup\", u);\n                l.logConversion(\"install_success\");\n                o.recheck();\n                new h(\"/desktop/fbdesktop2/transfer.php\").setMethod(\"POST\").setHandler(this._responseHandler.bind(this)).send();\n                k.dismissAll();\n                this.hideMegaphone();\n                return;\n            }\n        ;\n        ;\n            if (((t <= 0))) {\n                m.log(\"install_timeout\", \"setup\", u);\n                l.logConversion(\"install_timeout\");\n                k.dismissAll();\n            }\n             else JSBNG__setTimeout(this._waitForInstall.bind(this, ((t - q))), q);\n        ;\n        ;\n        },\n        _waitForRunning: function() {\n            var t = ((new JSBNG__Date().getTime() - this._waitForRunningStart));\n            if (o.isAppRunning()) {\n                o.transferAuthToken(this._authToken, this._userId);\n            }\n             else if (((t < r))) {\n                JSBNG__setTimeout(this._waitForRunning.bind(this), q);\n            }\n            \n        ;\n        ;\n        }\n    };\n    e.exports = s;\n});\n__d(\"legacy:fbdesktop2-install-js\", [\"FbdInstall\",], function(a, b, c, d) {\n    a.FbdInstall = b(\"FbdInstall\");\n}, 3);\n__d(\"FbdPromo\", [\"event-extensions\",\"Arbiter\",\"AsyncRequest\",\"ChatSidebar\",\"copyProperties\",\"CSS\",\"DOM\",\"FbdConversionTracking\",\"FBDesktopDetect\",\"FbdInstall\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"ChatSidebar\"), j = b(\"copyProperties\"), k = b(\"CSS\"), l = b(\"DOM\"), m = b(\"FbdConversionTracking\"), n = b(\"FBDesktopDetect\"), o = b(\"FbdInstall\"), p = \"show\", q = \"install\", r = \"cancel\", s = \"learn_more\";\n    function t(u, v, w) {\n        this._root = u;\n        JSBNG__Event.listen(l.JSBNG__find(u, \".install-button\"), \"click\", this.installClick.bind(this, v));\n        JSBNG__Event.listen(l.JSBNG__find(u, \".learn-more\"), \"click\", this.learnMoreClick.bind(this));\n        JSBNG__Event.listen(l.JSBNG__find(u, \".promo-close-button\"), \"click\", this.cancelClick.bind(this));\n        this.type = w;\n        this.showPromo();\n    };\n;\n    j(t.prototype, {\n        cancelClick: function() {\n            this.hidePromo();\n            this.postPromoAction(r);\n        },\n        hidePromo: function(u) {\n            k.hide(this._root);\n            i.resize();\n        },\n        installClick: function(u) {\n            o.init(u, this.type);\n            o.setupPlugin();\n            this.postPromoAction(q);\n            JSBNG__setTimeout(function() {\n                this.hidePromo();\n            }.bind(this), 3000);\n        },\n        learnMoreClick: function() {\n            this.postPromoAction(s);\n        },\n        postPromoAction: function(u) {\n            new h(\"/ajax/desktop/promo_action.php\").setMethod(\"POST\").setData({\n                action: u,\n                type: this.type\n            }).send();\n            m.logClick(((((this.type + \"_promo_\")) + u)));\n        },\n        showPromo: function() {\n            if (n.isPluginInstalled()) {\n                return;\n            }\n        ;\n        ;\n            k.show(this._root);\n            if (i.isVisible()) {\n                this.postPromoAction(p);\n            }\n             else {\n                var u = true;\n                g.subscribe(\"sidebar/show\", function() {\n                    if (u) {\n                        u = false;\n                        this.postPromoAction(p);\n                    }\n                ;\n                ;\n                }.bind(this));\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = t;\n});\n__d(\"legacy:fbdesktop-conversion-tracking\", [\"FbdConversionTracking\",], function(a, b, c, d) {\n    a.FbdConversionTracking = b(\"FbdConversionTracking\");\n}, 3);\nfunction FriendBrowserCheckboxController() {\n\n};\n;\ncopyProperties(FriendBrowserCheckboxController, {\n    instances: {\n    },\n    getInstance: function(a) {\n        return this.instances[a];\n    }\n});\ncopyProperties(FriendBrowserCheckboxController.prototype, {\n    init: function(a, b) {\n        FriendBrowserCheckboxController.instances[a] = this;\n        this._id = a;\n        this._form = b;\n        this._contentGrid = DOM.JSBNG__find(b, \".friendBrowserCheckboxContentGrid\");\n        this._loadingIndicator = DOM.JSBNG__find(b, \".friendBrowsingCheckboxContentLoadingIndicator\");\n        this._checkboxResults = DOM.JSBNG__find(b, \".friendBrowserCheckboxResults\");\n        this._contentPager = DOM.JSBNG__find(b, \".friendBrowserCheckboxContentPager\");\n        this.numGetNewRequests = 0;\n        this.queuedRequests = {\n        };\n    },\n    addTypeahead: function(a, b) {\n        a.subscribe(\"select\", this.JSBNG__onHubSelect.bind(this, a, b));\n    },\n    JSBNG__onHubSelect: function(a, b, JSBNG__event, c) {\n        if (!((((JSBNG__event == \"select\")) && c.selected))) {\n            return;\n        }\n    ;\n    ;\n        var d = this.buildNewCheckbox(b, c.selected.text, c.selected.uid), e = DOM.JSBNG__find(this._form, ((\".checkboxes_\" + b)));\n        DOM.appendContent(e.firstChild, d);\n        var f = DOM.scry(a.getElement(), \"input[type=\\\"button\\\"]\");\n        if (((f && f[0]))) {\n            f[0].click();\n        }\n    ;\n    ;\n        this.getNew(true);\n    },\n    buildNewCheckbox: function(a, b, c) {\n        var d = ((((a + \"_ids_\")) + c)), e = ((a + \"_ids[]\")), f = DOM.create(\"input\", {\n            id: d,\n            type: \"checkbox\",\n            value: c,\n            JSBNG__name: e,\n            checked: true\n        });\n        JSBNG__Event.listen(f, \"click\", bind(this, \"getNew\", false));\n        var g = DOM.create(\"td\", null, f);\n        CSS.addClass(g, \"vTop\");\n        CSS.addClass(g, \"hLeft\");\n        var h = DOM.create(\"label\", null, b), i = DOM.create(\"td\", null, h);\n        CSS.addClass(i, \"vMid\");\n        CSS.addClass(i, \"hLeft\");\n        var j = DOM.create(\"tr\");\n        j.appendChild(g);\n        j.appendChild(i);\n        return j;\n    },\n    showMore: function() {\n        var a = DOM.scry(this._contentPager, \".friendBrowserMorePager\")[0];\n        if (!a) {\n            return false;\n        }\n    ;\n    ;\n        if (CSS.hasClass(a, \"async_saving\")) {\n            return false;\n        }\n    ;\n    ;\n        var b = this.numGetNewRequests, c = Form.serialize(this._form);\n        c.show_more = true;\n        var d = new AsyncRequest().setURI(\"/ajax/growth/friend_browser/checkbox.php\").setData(c).setHandler(bind(this, function(e) {\n            this.showMoreHandler(e, b);\n        })).setStatusElement(a).send();\n    },\n    showMoreHandler: function(a, b) {\n        if (((b == this.numGetNewRequests))) {\n            var c = a.payload;\n            DOM.appendContent(this._contentGrid, c.results);\n            this.updatePagerAndExtraData(c.pager, c.extra_data);\n        }\n    ;\n    ;\n    },\n    getNew: function(a) {\n        this.numGetNewRequests++;\n        var b = this.numGetNewRequests;\n        CSS.addClass(this._checkboxResults, \"friendBrowserCheckboxContentOnload\");\n        if (ge(\"friendBrowserCI\")) {\n            CSS.addClass($(\"friendBrowserCI\"), \"friendBrowserCheckboxContentOnload\");\n        }\n    ;\n    ;\n        CSS.show(this._loadingIndicator);\n        var c = Form.serialize(this._form);\n        c.used_typeahead = a;\n        new AsyncRequest().setURI(\"/ajax/growth/friend_browser/checkbox.php\").setData(c).setHandler(bind(this, function(d) {\n            this.getNewHandler(d, b);\n        })).send();\n    },\n    getNewHandler: function(a, b) {\n        if (((b == this.numGetNewRequests))) {\n            var c = a.payload;\n            DOM.setContent(this._contentGrid, c.results);\n            CSS.removeClass(this._checkboxResults, \"friendBrowserCheckboxContentOnload\");\n            if (ge(\"friendBrowserCI\")) {\n                CSS.hide($(\"friendBrowserCI\"));\n            }\n        ;\n        ;\n            CSS.hide(this._loadingIndicator);\n            this.updatePagerAndExtraData(c.pager, c.extra_data);\n        }\n    ;\n    ;\n    },\n    updatePagerAndExtraData: function(a, b) {\n        DOM.setContent(this._contentPager, a);\n        this.setupOnVisible();\n        DOM.replace(this._form.elements.extra_data, b);\n    },\n    setupOnVisible: function() {\n        var a = DOM.scry(this._contentPager, \".friendBrowserMorePager\")[0];\n        if (((a && ((this._id != \"jewel\"))))) {\n            ((this._onVisible && this._onVisible.remove()));\n            this._onVisible = new OnVisible(a, bind(this, \"showMore\"), false, 1000);\n        }\n    ;\n    ;\n    }\n});\n__d(\"legacy:SimpleDrag\", [\"SimpleDrag\",], function(a, b, c, d) {\n    a.SimpleDrag = b(\"SimpleDrag\");\n}, 3);\nfunction SidebarTicker() {\n\n};\n;\ncopyProperties(SidebarTicker.prototype, {\n    ALMOST_ZERO: 1e-7,\n    init: function() {\n        this._ticker = $(\"pagelet_ticker\");\n        this._initSubscriptions();\n        if (CSS.hasClass(JSBNG__document.documentElement, \"sidebarMode\")) {\n            this._onSidebarShow();\n        }\n    ;\n    ;\n        return this;\n    },\n    initResizeBehavior: function(a) {\n        var b = this._ticker, c = b.parentNode, d = this._saveResizedState.bind(this), e = this.ALMOST_ZERO, f, g, h, i = function(l, JSBNG__event) {\n            f = JSBNG__event.clientY;\n            g = b.offsetHeight;\n            h = c.offsetHeight;\n        }, j = function(l, JSBNG__event) {\n            var m = ((g + ((JSBNG__event.clientY - f)))), n = ((100 - ((((((h - m)) / h)) * 100))));\n            n = Math.max(e, Math.min(90, n));\n            b.style.height = ((n + \"%\"));\n            if (((l == \"end\"))) {\n                d(n);\n                Arbiter.inform(\"Ticker/resized\");\n            }\n        ;\n        ;\n            ((window.ChatSidebar && ChatSidebar.resize()));\n        }, k = new SimpleDrag(a);\n        k.subscribe(\"start\", i);\n        k.subscribe([\"update\",\"end\",], j);\n    },\n    _saveResizedState: function(a) {\n        new AsyncRequest(\"/ajax/feed/ticker/resize\").setData({\n            height: ((\"\" + a))\n        }).setMethod(\"POST\").send();\n    },\n    _initSubscriptions: function() {\n        this._subscriptions = [Arbiter.subscribe(\"sidebar/show\", this._onSidebarShow.bind(this)),];\n    },\n    _onSidebarShow: function() {\n        TickerController.show(this._ticker);\n    }\n});\nfunction RequestsJewel() {\n\n};\n;\ncopyProperties(RequestsJewel.prototype, {\n    init: function(a, b, c) {\n        this.countNew = 0;\n        this.jewel = a;\n        this.jewelFlyoutCase = a.getRoot();\n        this.jewelFlyout = ge(\"fbRequestsFlyout\");\n        this.newCountSpan = ge(\"newRequestCount\");\n        this.folder = b;\n        this.doNewMarkRead = c;\n        this._requestList = {\n        };\n        this._requestCount = 0;\n        var d = ge(\"requestsMarkReadButton\");\n        if (d) {\n            JSBNG__Event.listen(d, \"click\", this._markRead.shield(this));\n        }\n    ;\n    ;\n        this.jewel.subscribe(\"marked-seen\", this._markSeenCallback.shield(this));\n        this.jewel.subscribe(\"JSBNG__closed\", this._clearNewItems.shield(this));\n        this.jewel.subscribe(\"updated\", this._updateCount.bind(this));\n        this.jewel.subscribe(\"opened\", this._openHandler.bind(this));\n        LinkController.registerHandler(this._handleLink.bind(this));\n        Arbiter.subscribe(ChannelConstants.getArbiterType(\"jewel_requests_add\"), this._addRequest.bind(this));\n        Arbiter.subscribe(ChannelConstants.getArbiterType(\"jewel_requests_remove_old\"), this._removeOldRequest.bind(this));\n        JSBNG__Event.listen(this.jewelFlyout, \"submit\", function(f) {\n            var g = Parent.byClass(f.getTarget(), \"objectListItem\");\n            if (g) {\n                CSS.removeClass(g, \"jewelItemNew\");\n                CSS.addClass(g, \"jewelItemResponded\");\n            }\n        ;\n        ;\n        }.bind(this));\n        var e = DOM.scry(this.jewelFlyout, \".uiScrollableAreaWrap\")[0];\n        if (e) {\n            this._scrollableWrap = e;\n            this._lastLinkPosition = 0;\n            this._scrollListener = JSBNG__Event.listen(e, \"JSBNG__scroll\", this._handleScroll.bind(this), JSBNG__Event.Priority._BUBBLE);\n        }\n    ;\n    ;\n        return this;\n    },\n    fromDom: function() {\n        DOM.scry(this.jewelFlyout, \".jewelItemList li.objectListItem\").forEach(function(a) {\n            var b = a.getAttribute(\"id\"), c = ((b && parseInt(this._parseID(b).requester, 10)));\n            if (((c && !isNaN(c)))) {\n                this._requestList[c] = b;\n                ++this._requestCount;\n            }\n        ;\n        ;\n        }.bind(this));\n        this._conditionShowEmptyMessage();\n    },\n    _parseID: function(a) {\n        var b = a.match(/^(\\d+)_(\\d+)/);\n        return (((b) ? {\n            requester: b[1],\n            type: b[2]\n        } : undefined));\n    },\n    _handleLink: function(a, JSBNG__event) {\n        var b = Parent.byClass(a, \"jewelItemNew\");\n        if (((((b && Parent.byClass(b, \"fbRequestList\"))) && Parent.byClass(b, \"beeperEnabled\")))) {\n            var c = this._parseID(b.id);\n            ((c && this._markSeenCallback(c.requester, c.type)));\n            Arbiter.inform(\"jewel/count-updated\", {\n                jewel: \"requests\",\n                count: --this.countNew\n            });\n            CSS.removeClass(b, \"jewelItemNew\");\n        }\n    ;\n    ;\n        return true;\n    },\n    _handleScroll: function() {\n        var a = DOM.scry(this._scrollableWrap, \".uiMorePager\")[0];\n        if (a) {\n            var b = Vector2.getElementPosition(a, \"viewport\").y;\n            if (((b > 0))) {\n                CSS.addClass(Parent.byClass(this._scrollableWrap, \"uiScrollableArea\"), \"contentAfter\");\n            }\n        ;\n        ;\n            var c = DOM.JSBNG__find(a, \"a\");\n            if (!c) {\n                return;\n            }\n        ;\n        ;\n            var d = Vector2.getElementPosition(c, \"viewport\").y;\n            if (((d == this._lastLinkPosition))) {\n                return;\n            }\n        ;\n        ;\n            var e = ((Vector2.getElementPosition(this._scrollableWrap, \"viewport\").y + Vector2.getElementDimensions(this._scrollableWrap).y));\n            if (((((((d - 300)) < e)) && ((d > 0))))) {\n                this._lastLinkPosition = d;\n                var f = c.getAttribute(\"ajaxify\");\n                if (f) {\n                    new AsyncRequest(f).setRelativeTo(c).setStatusElement(Parent.byClass(c, \"stat_elem\")).send();\n                }\n                 else FriendBrowserCheckboxController.getInstance(\"jewel\").showMore();\n            ;\n            ;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    _addRequest: function(a, b) {\n        if (((!b || this._requestList[b.obj.from]))) {\n            return;\n        }\n    ;\n    ;\n        var c = DOM.scry(this.jewelFlyout, \".fbRequestList .uiList\")[0];\n        if (!c) {\n            return;\n        }\n    ;\n    ;\n        DOM.prependContent(c, b.obj.markup);\n        var d = DOM.scry(this.jewelFlyout, \"#fbRequestsPYMKContainer\")[0];\n        if (!d) {\n            var e = DOM.JSBNG__find(ge(b.obj.itemid), \"form\"), f = DOM.create(\"input\", {\n                type: \"hidden\",\n                JSBNG__name: \"num_visible_requests\",\n                value: ((this._requestCount + 1))\n            });\n            DOM.appendContent(e, f);\n        }\n    ;\n    ;\n        var g = {\n            jewel: \"requests\",\n            count: ++this.countNew\n        };\n        Arbiter.inform(\"jewel/count-updated\", g);\n        this._requestList[b.obj.from] = b.obj.itemid;\n        ++this._requestCount;\n        this._conditionShowEmptyMessage();\n    },\n    _removeOldRequest: function(a, b) {\n        if (!b) {\n            return;\n        }\n    ;\n    ;\n        var c = this._requestList[b.obj.from], d = ((c && ge(c)));\n        if (d) {\n            ((CSS.hasClass(d, \"jewelItemNew\") && Arbiter.inform(\"jewel/count-updated\", {\n                jewel: \"requests\",\n                count: --this.countNew\n            })));\n            if (!CSS.hasClass(d, \"jewelItemResponded\")) {\n                DOM.remove(d);\n                delete this._requestList[c];\n                --this._requestCount;\n                this._conditionShowEmptyMessage();\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    _markRead: function() {\n        this.jewel.markSeen();\n        this._clearNewItems();\n    },\n    _markSeenCallback: function(a, b) {\n        new AsyncSignal(\"/ajax/gigaboxx/endpoint/UpdateLastSeenTime.php\", {\n            folder: this.folder\n        }).send();\n        var c = ((((((typeof a != \"undefined\")) && ((typeof b != \"undefined\")))) ? {\n            requester: a,\n            type: b\n        } : {\n        }));\n        ((this.doNewMarkRead && new AsyncSignal(\"/ajax/requests/mark_read/\", c).send()));\n    },\n    _removeRequest: function(a, b) {\n        var c = b.obj.item_id;\n        if (c) {\n            var d = ge(c), e = ((d && CSS.hasClass(d, \"jewelItemNew\")));\n            ((d ? DOM.remove(d) : false));\n            ((e && Arbiter.inform(\"jewel/count-updated\", {\n                jewel: \"requests\",\n                count: --this.countNew\n            })));\n        }\n    ;\n    ;\n    },\n    _clearNewItems: function(a, b) {\n        DOM.scry(this.jewel.root, \"li.jewelItemNew\").forEach(function(c) {\n            CSS.removeClass(c, \"jewelItemNew\");\n        });\n    },\n    _updateCount: function(a, b) {\n        this.countNew = b.count;\n        CSS.conditionClass(this.jewelFlyout, \"beeperUnread\", ((this.countNew > 0)));\n        CSS.conditionClass(this.jewelFlyoutCase, \"showRequests\", ((this.countNew > 0)));\n        if (this.newCountSpan) {\n            var c = ((((this.countNew == 1)) ? tx._(\"{num} NEW REQUEST\", {\n                num: this.countNew\n            }) : tx._(\"{num} NEW REQUESTS\", {\n                num: this.countNew\n            })));\n            DOM.setContent(this.newCountSpan, c);\n        }\n    ;\n    ;\n    },\n    _conditionShowEmptyMessage: function() {\n        DOM.scry(this.jewelFlyout, \"li.empty\").forEach(function(a) {\n            CSS.conditionShow(a, ((this._requestCount <= 0)));\n        }.bind(this));\n    },\n    _openHandler: function() {\n        var a = DOM.scry(this.jewelFlyout, \".uiScrollableArea\")[0];\n        ((a && ScrollableArea.poke(a)));\n    }\n});\n__d(\"ContextualBlind\", [\"event-extensions\",\"Animation\",\"DOM\",\"JSBNG__Rect\",\"Vector\",\"$\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Animation\"), h = b(\"DOM\"), i = b(\"JSBNG__Rect\"), j = b(\"Vector\"), k = b(\"$\"), l = [], m = null, n = null, o = false, p = 17572, q = 500;\n    function r(u, v) {\n        v.getPositionVector().setElementPosition(u);\n        v.getDimensionVector().setElementDimensions(u);\n    };\n;\n    function s() {\n        l = [];\n        ((m && m.remove()));\n        ((n && h.remove(n)));\n        o = false;\n    };\n;\n    var t = {\n        show: function(u, v, w) {\n            t.hide();\n            for (var x = 0; ((x < 4)); x++) {\n                l.push(h.create(\"div\", {\n                    className: \"contextualBlind\"\n                }));\n            ;\n            };\n        ;\n            h.appendContent(JSBNG__document.body, l);\n            if (((w !== false))) {\n                n = h.create(\"div\", {\n                    className: \"contextualBlindContext\"\n                });\n                h.appendContent(JSBNG__document.body, n);\n            }\n        ;\n        ;\n            t.updatePosition(u, v);\n            m = JSBNG__Event.listen(window, \"resize\", t.updatePosition.bind(t, u, v));\n            o = true;\n        },\n        fadeIn: function(u, v, w, x, y) {\n            var z = o;\n            t.show(u, v, w);\n            if (z) {\n                return;\n            }\n        ;\n        ;\n            p = ((((x !== undefined)) ? x : p));\n            q = ((((y !== undefined)) ? y : q));\n            for (var aa = 0; ((aa < l.length)); aa++) {\n                var ba = l[aa];\n                new g(ba).duration(q).from(\"opacity\", 0).to(\"opacity\", p).go();\n            };\n        ;\n        },\n        hide: function() {\n            l.forEach(h.remove);\n            s();\n        },\n        fadeOut: function() {\n            for (var u = 0; ((u < l.length)); u++) {\n                var v = l[u];\n                new g(v).duration(q).from(\"opacity\", p).to(\"opacity\", 0).JSBNG__ondone(h.remove.curry(v)).go();\n            };\n        ;\n            s();\n        },\n        updatePosition: function(u, v) {\n            var w = j.getDocumentDimensions().y, x = i.getElementBounds(k(u));\n            if (v) {\n                x = new i(((x.t - v)), ((x.r + v)), ((x.b + v)), ((x.l - v)), x.domain);\n            }\n        ;\n        ;\n            var y = JSBNG__document, z = ((((((((y && y.documentElement)) && y.documentElement.clientWidth)) || ((((y && y.body)) && y.body.clientWidth)))) || 0));\n            r(l[0], new i(0, z, x.t, 0, \"JSBNG__document\"));\n            r(l[1], new i(x.t, z, x.b, x.r, \"JSBNG__document\"));\n            r(l[2], new i(x.b, z, w, 0, \"JSBNG__document\"));\n            r(l[3], new i(x.t, x.l, x.b, 0, \"JSBNG__document\"));\n            if (n) {\n                r(n, x);\n            }\n        ;\n        ;\n        }\n    };\n    e.exports = ((a.ContextualBlind || t));\n});\n__d(\"JewelX\", [\"event-extensions\",\"Arbiter\",\"ArbiterMixin\",\"Class\",\"ContextualBlind\",\"CSS\",\"DOM\",\"HTML\",\"Keys\",\"Toggler\",\"copyProperties\",\"reportData\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"Class\"), j = b(\"ContextualBlind\"), k = b(\"CSS\"), l = b(\"DOM\"), m = b(\"HTML\"), n = b(\"Keys\"), o = b(\"Toggler\"), p = b(\"copyProperties\"), q = b(\"reportData\"), r = function(s, t) {\n        ((((s && t)) && this.init(s, t)));\n    };\n    p(r, {\n        _instancesByName: {\n        },\n        _resizeListener: null\n    });\n    p(r.prototype, h, {\n        init: function(s, t) {\n            this.JSBNG__name = t.JSBNG__name;\n            this.root = s;\n            this.countNew = 0;\n            this.initialCount = 0;\n            this.escHandler = null;\n            this.fadeOnOpen = t.fade_on_open;\n            r._instancesByName[this.JSBNG__name] = this;\n            o.listen(\"show\", this.root, function(u) {\n                this._logFirstClick();\n                ((this.hasNew() && this.markSeen()));\n                this.reset();\n                this.inform(\"opened\");\n                g.inform(\"layer_shown\", {\n                    type: \"Jewel\"\n                });\n                this.setupEvents();\n                ((this.fadeOnOpen && j.fadeIn(this.root, 0, true, 19805, 100)));\n            }.bind(this));\n            o.listen(\"hide\", this.root, function(u, v) {\n                ((this.hasNew() && this.markSeen()));\n                this.reset();\n                this.inform(\"JSBNG__closed\");\n                g.inform(\"layer_hidden\", {\n                    type: \"Jewel\"\n                });\n                this.removeEvents();\n                if (((this.fadeOnOpen && ((((((!v || !v.clickedTarget)) || !k.hasClass(v.clickedTarget, \"jewelButton\"))) || l.contains(this.root, v.clickedTarget)))))) {\n                    j.fadeOut();\n                }\n            ;\n            ;\n            }.bind(this));\n            g.subscribe(\"jewel/count-updated\", function(u, v) {\n                ((((v.jewel == this.JSBNG__name)) && this.update(v)));\n            }.bind(this));\n            g.subscribe(\"jewel/count-initial\", function(u, v) {\n                ((((v.jewel == this.JSBNG__name)) && this.setInitial(v)));\n            }.bind(this));\n            g.subscribe(\"jewel/reset\", function(u, v) {\n                ((((v.jewel == this.JSBNG__name)) && this.reset()));\n            }.bind(this));\n            r._resizeListener = ((r._resizeListener || (function() {\n                var u = null;\n                return JSBNG__Event.listen(window, \"resize\", function() {\n                    JSBNG__clearTimeout(u);\n                    u = g.inform.bind(g, \"jewel/resize\").defer(100, false);\n                });\n            })()));\n        },\n        getRoot: function() {\n            return this.root;\n        },\n        hasNew: function() {\n            return k.hasClass(this.root, \"hasNew\");\n        },\n        isOpen: function() {\n            return k.hasClass(this.root, \"openToggler\");\n        },\n        reset: function() {\n            k.removeClass(this.root, \"hasNew\");\n        },\n        setContent: function(s) {\n            var t = l.JSBNG__find(this.root, \"ul.jewelItemList\");\n            l.setContent(t, m(s));\n        },\n        update: function(s) {\n            this.countNew = s.count;\n            var t = l.JSBNG__find(this.root, \"span.jewelCount span\");\n            l.setContent(t, this.countNew);\n            var u = ((isNaN(this.countNew) || ((this.countNew > 0))));\n            k.conditionClass(this.root, \"hasNew\", u);\n            this.inform(\"updated\", s);\n        },\n        setInitial: function(s) {\n            this.initialCount = s;\n        },\n        setupEvents: function() {\n            this.escHandler = JSBNG__Event.listen(JSBNG__document.documentElement, \"keydown\", function(s) {\n                if (((((s.keyCode === n.ESC)) && this.isOpen()))) {\n                    o.hide(this.root);\n                }\n            ;\n            ;\n            }.bind(this));\n        },\n        removeEvents: function() {\n            if (this.escHandler) {\n                this.escHandler.remove();\n            }\n        ;\n        ;\n        },\n        markSeen: function() {\n            g.inform(\"jewel/count-updated\", {\n                jewel: this.JSBNG__name,\n                count: 0\n            }, g.BEHAVIOR_STATE);\n            this.inform(\"marked-seen\");\n        },\n        _logFirstClick: function() {\n            this._logFirstClick = bagofholding;\n            q(\"jewel_click\", {\n                gt: {\n                    count: this.countNew,\n                    initial: this.initialCount,\n                    jewel: this.JSBNG__name\n                }\n            });\n        }\n    });\n    e.exports = r;\n});\n__d(\"UserNoOp\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\"), h = function() {\n    \n    }, i = function() {\n        return this;\n    };\n    g(h.prototype, {\n        add_event: i,\n        add_data: i,\n        set_ua_id: i,\n        set_namespace: i\n    });\n    e.exports = h;\n});\n__d(\"legacy:UserAction\", [\"UserNoOp\",\"userAction\",], function(a, b, c, d) {\n    a.UserNoOp = b(\"UserNoOp\");\n    a.user_action = b(\"userAction\");\n    a.report_data = function(e, f) {\n        user_action(e, null, null, \"FORCE\", f);\n    };\n}, 3);\n__d(\"legacy:DocumentTitle\", [\"DocumentTitle\",], function(a, b, c, d) {\n    a.DocumentTitle = b(\"DocumentTitle\");\n}, 3);\n__d(\"legacy:Poller\", [\"Poller\",], function(a, b, c, d) {\n    a.Poller = b(\"Poller\");\n}, 3);\n__d(\"deferUntil\", [], function(a, b, c, d, e, f) {\n    function g(h, i, j, k, l) {\n        var m = i();\n        if (m) {\n            h(m);\n            return null;\n        }\n    ;\n    ;\n        var n = JSBNG__Date.now(), o = JSBNG__setInterval(function() {\n            m = i();\n            if (!m) {\n                if (((!j || ((j < ((new JSBNG__Date() - n))))))) {\n                    return;\n                }\n            ;\n            ;\n                ((l && l()));\n            }\n        ;\n        ;\n            JSBNG__clearInterval(o);\n            h(m);\n        }, 20, k);\n        return o;\n    };\n;\n    e.exports = g;\n});\n__d(\"legacy:function-utils\", [\"debounce\",\"throttle\",\"deferUntil\",], function(a, b, c, d) {\n    a.debounce = b(\"debounce\");\n    a.throttle = b(\"throttle\");\n    a.defer_until = b(\"deferUntil\");\n}, 3);\n__d(\"legacy:user-activity\", [\"UserActivity\",], function(a, b, c, d) {\n    a.UserActivity = ((a.UserActivity || b(\"UserActivity\")));\n}, 3);\n__d(\"BanzaiODS\", [\"BanzaiDesktop\",], function(a, b, c, d, e, f) {\n    var g = b(\"BanzaiDesktop\"), h = {\n    };\n    function i(k, l, m, n) {\n        var o = ((h[k] || (h[k] = {\n        })));\n        o = ((o[l] || (o[l] = {\n        })));\n        o = ((o[m] || (o[m] = [])));\n        for (var p = 0; ((p < n.length)); p++) {\n            var q = ((((n[p] == null)) ? 1 : Number(n[p])));\n            if (isFinite(q)) {\n                o[p] = ((((o[p] || 0)) + q));\n            }\n        ;\n        ;\n        };\n    ;\n    };\n;\n    g.subscribe(g.SEND, function() {\n        for (var k in h) {\n            g.post(\"ods\", h);\n            break;\n        };\n    ;\n        h = {\n        };\n    });\n    var j = {\n        bumpEntityKey: function(k, l, m) {\n            i(\"bEK\", k, l, [m,]);\n        },\n        bumpFraction: function(k, l, m, n) {\n            i(\"bF\", k, l, [m,n,]);\n        }\n    };\n    e.exports = j;\n});\n__d(\"OptionStorage\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\"), h = ((window.JSBNG__localStorage || null));\n    function i(j, k, l) {\n        this.JSBNG__name = j;\n        this.reviver = ((k || this._reviver));\n        this.replacer = ((l || this._replacer));\n        this._read();\n    };\n;\n    g(i.prototype, {\n        _read: function(j, k) {\n            if (((h && h[this.JSBNG__name]))) {\n                this.options = JSON.parse(h[this.JSBNG__name], this.reviver);\n            }\n             else this.options = {\n            };\n        ;\n        ;\n        },\n        _write: function() {\n            if (h) {\n                var j = g({\n                }, this.options);\n                h[this.JSBNG__name] = JSON.stringify(j, this.replacer);\n            }\n        ;\n        ;\n        },\n        _reviver: function(j, k) {\n            if (k) {\n                var l = ((/^\\[RegExp (.*)\\]$/.test(k) && RegExp.$1));\n                if (l) {\n                    k = new RegExp(l.replace(/^\\/|\\/$/g, \"\"));\n                }\n            ;\n            ;\n                return k;\n            }\n        ;\n        ;\n        },\n        _replacer: function(j, k) {\n            if (((k instanceof RegExp))) {\n                k = ((((\"[RegExp \" + k)) + \"]\"));\n                this[j] = k;\n            }\n        ;\n        ;\n            return k;\n        },\n        get: function(j, k) {\n            return ((((j in this.options)) ? this.options[j] : k));\n        },\n        set: function(j, k) {\n            if (((k == null))) {\n                delete this.options[j];\n            }\n             else this.options[j] = k;\n        ;\n        ;\n            this._write();\n        }\n    });\n    e.exports = i;\n});\n__d(\"legacy:megaphone\", [\"MegaphoneHelper\",], function(a, b, c, d) {\n    a.MegaphoneHelper = b(\"MegaphoneHelper\");\n}, 3);\n__d(\"MessagingEvents\", [\"array-extensions\",\"Arbiter\",\"ChannelConstants\",\"copyProperties\",\"isEmpty\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ChannelConstants\"), i = b(\"copyProperties\"), j = b(\"isEmpty\"), k = {\n    }, l = new g();\n    function m(n) {\n        if (!j(k)) {\n            return;\n        }\n    ;\n    ;\n        for (var o in n) {\n            l.inform(((\"count/\" + o)), n[o]);\n        ;\n        };\n    ;\n    };\n;\n    l.subscribe(\"mark-as-read\", function(n, o) {\n        ((((o.tids || o.chat_ids)) || [])).forEach(function(p) {\n            p = ((\"\" + p));\n            if (!((p in k))) {\n                k[p] = true;\n                var q = function() {\n                    l.unsubscribe(r);\n                    JSBNG__clearTimeout(s);\n                    delete k[p];\n                }, r = l.subscribe(\"read\", function(t, u) {\n                    if (((((u.tids || [])).contains(p) || ((u.chat_ids || [])).contains(p)))) {\n                        q();\n                    }\n                ;\n                ;\n                }), s = q.defer(60000);\n            }\n        ;\n        ;\n        });\n    });\n    g.subscribe(h.getArbiterType(\"messaging\"), function(n, o) {\n        var p = i({\n        }, o.obj), JSBNG__event = ((p.JSBNG__event || \"\"));\n        delete p.type;\n        delete p.JSBNG__event;\n        l.inform(JSBNG__event, p);\n        if (((\"unread_counts\" in p))) {\n            var q = p.unread_counts;\n            m({\n                unread: q.inbox,\n                other_unseen: q.other\n            });\n        }\n    ;\n    ;\n    });\n    g.subscribe(h.getArbiterType(\"inbox\"), function(n, o) {\n        var p = i(o.obj);\n        delete p.type;\n        m(p);\n    });\n    a.MessagingEvents = e.exports = l;\n}, 3);\n__d(\"DoublyLinkedListMap\", [\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\");\n    function h() {\n        this._head = null;\n        this._tail = null;\n        this._nodes = {\n        };\n        this._nodeCount = 0;\n    };\n;\n    g(h.prototype, {\n        get: function(i) {\n            return ((this._nodes[i] ? this._nodes[i].data : null));\n        },\n        _insert: function(i, j, k, l) {\n            ((((k && !this._nodes[k])) && (k = null)));\n            var m = ((((k && this._nodes[k])) || ((l ? this._head : this._tail)))), n = {\n                data: j,\n                key: i,\n                next: null,\n                prev: null\n            };\n            if (m) {\n                this.remove(i);\n                if (l) {\n                    n.prev = m.prev;\n                    ((m.prev && (m.prev.next = n)));\n                    m.prev = n;\n                    n.next = m;\n                }\n                 else {\n                    n.next = m.next;\n                    ((m.next && (m.next.prev = n)));\n                    m.next = n;\n                    n.prev = m;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            ((((n.prev === null)) && (this._head = n)));\n            ((((n.next === null)) && (this._tail = n)));\n            this._nodes[i] = n;\n            this._nodeCount++;\n            return this;\n        },\n        insertBefore: function(i, j, k) {\n            return this._insert(i, j, k, true);\n        },\n        insertAfter: function(i, j, k) {\n            return this._insert(i, j, k, false);\n        },\n        prepend: function(i, j) {\n            return this.insertBefore(i, j, ((this._head && this._head.key)));\n        },\n        append: function(i, j) {\n            return this.insertAfter(i, j, ((this._tail && this._tail.key)));\n        },\n        remove: function(i) {\n            var j = this._nodes[i];\n            if (j) {\n                var k = j.next, l = j.prev;\n                ((k && (k.prev = l)));\n                ((l && (l.next = k)));\n                ((((this._head === j)) && (this._head = k)));\n                ((((this._tail === j)) && (this._tail = l)));\n                delete this._nodes[i];\n                this._nodeCount--;\n            }\n        ;\n        ;\n            return this;\n        },\n        JSBNG__find: function(i) {\n            for (var j = this._head; j; j = j.next) {\n                if (i(j.data)) {\n                    return j.key;\n                }\n            ;\n            ;\n            };\n        ;\n            return null;\n        },\n        reduce: function(i, j) {\n            for (var k = this._head; k; k = k.next) {\n                j = i(k.data, j);\n            ;\n            };\n        ;\n            return j;\n        },\n        exists: function(i) {\n            return !!this._nodes[i];\n        },\n        isEmpty: function() {\n            return !this._head;\n        },\n        reset: function() {\n            this._head = null;\n            this._tail = null;\n            this._nodes = {\n            };\n            this._nodeCount = 0;\n        },\n        map: function(i) {\n            for (var j = this._head; j; j = j.next) {\n                i(j.data);\n            ;\n            };\n        ;\n        },\n        getCount: function() {\n            return this._nodeCount;\n        },\n        getHead: function() {\n            return this._head.data;\n        },\n        getTail: function() {\n            return this._tail.data;\n        },\n        getNext: function(i) {\n            var j = this._nodes[i];\n            if (((j && j.next))) {\n                return j.next.data;\n            }\n        ;\n        ;\n            return null;\n        },\n        getPrev: function(i) {\n            var j = this._nodes[i];\n            if (((j && j.prev))) {\n                return j.prev.data;\n            }\n        ;\n        ;\n            return null;\n        }\n    });\n    e.exports = h;\n});\n__d(\"Quickling\", [\"AjaxPipeRequest\",\"Arbiter\",\"Class\",\"DocumentTitle\",\"DOM\",\"HTML\",\"OnloadHooks\",\"PageTransitions\",\"Run\",\"URI\",\"UserAgent\",\"copyProperties\",\"goOrReplace\",\"isEmpty\",\"QuicklingConfig\",], function(a, b, c, d, e, f) {\n    var g = b(\"AjaxPipeRequest\"), h = b(\"Arbiter\"), i = b(\"Class\"), j = b(\"DocumentTitle\"), k = b(\"DOM\"), l = b(\"HTML\"), m = b(\"OnloadHooks\"), n = b(\"PageTransitions\"), o = b(\"Run\"), p = b(\"URI\"), q = b(\"UserAgent\"), r = b(\"copyProperties\"), s = b(\"goOrReplace\"), t = b(\"isEmpty\"), u = c(\"QuicklingConfig\"), v = u.version, w = u.sessionLength, x = new RegExp(u.inactivePageRegex), y = 0, z, aa = \"\", ba = [], ca = {\n        isActive: function() {\n            return true;\n        },\n        isPageActive: function(ka) {\n            if (((ka == \"#\"))) {\n                return false;\n            }\n        ;\n        ;\n            ka = new p(ka);\n            if (((ka.getDomain() && ((ka.getDomain() != p().getDomain()))))) {\n                return false;\n            }\n        ;\n        ;\n            if (((ka.getPath() == \"/l.php\"))) {\n                var la = ka.getQueryData().u;\n                if (la) {\n                    la = p(unescape(la)).getDomain();\n                    if (((la && ((la != p().getDomain()))))) {\n                        return false;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            var ma = ka.getPath(), na = ka.getQueryData();\n            if (!t(na)) {\n                ma += ((\"?\" + p.implodeQuery(na)));\n            }\n        ;\n        ;\n            return !x.test(ma);\n        },\n        addURIQueryAugmenter: function(ka) {\n            ba.push(ka);\n        }\n    };\n    function da(ka) {\n        ka = ((ka || \"Facebook\"));\n        j.set(ka);\n        if (q.ie()) {\n            aa = ka;\n            if (!z) {\n                z = window.JSBNG__setInterval(function() {\n                    var la = aa, ma = j.get();\n                    if (((la != ma))) {\n                        j.set(la);\n                    }\n                ;\n                ;\n                }, 5000, false);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    };\n;\n    function ea(ka) {\n        var la = JSBNG__document.getElementsByTagName(\"link\");\n        for (var ma = 0; ((ma < la.length)); ++ma) {\n            if (((la[ma].rel != \"alternate\"))) {\n                continue;\n            }\n        ;\n        ;\n            k.remove(la[ma]);\n        };\n    ;\n        if (ka.length) {\n            var na = k.JSBNG__find(JSBNG__document, \"head\");\n            ((na && k.appendContent(na, l(ka[0]))));\n        }\n    ;\n    ;\n    };\n;\n    function fa(ka) {\n        var la = {\n            version: v\n        };\n        this.parent.construct(this, ka, {\n            quickling: la\n        });\n    };\n;\n    i.extend(fa, g);\n    r(fa.prototype, {\n        _preBootloadFirstResponse: function(ka) {\n            return true;\n        },\n        _fireDomContentCallback: function() {\n            ((this._request.cavalry && this._request.cavalry.setTimeStamp(\"t_domcontent\")));\n            n.transitionComplete();\n            ((this._onPageDisplayed && this._onPageDisplayed(this.pipe)));\n            this.parent._fireDomContentCallback();\n        },\n        _fireOnloadCallback: function() {\n            if (this._request.cavalry) {\n                this._request.cavalry.setTimeStamp(\"t_hooks\");\n                this._request.cavalry.setTimeStamp(\"t_layout\");\n                this._request.cavalry.setTimeStamp(\"t_onload\");\n            }\n        ;\n        ;\n            this.parent._fireOnloadCallback();\n        },\n        isPageActive: function(ka) {\n            return ca.isPageActive(ka);\n        },\n        _versionCheck: function(ka) {\n            if (((ka.version == v))) {\n                return true;\n            }\n        ;\n        ;\n            var la = [\"quickling\",\"ajaxpipe\",\"ajaxpipe_token\",];\n            s(window.JSBNG__location, p(ka.uri).removeQueryData(la), true);\n            return false;\n        },\n        _processFirstResponse: function(ka) {\n            var la = ka.getPayload();\n            da(la.title);\n            ea(((la.syndication || [])));\n            window.JSBNG__scrollTo(0, 0);\n            var ma = ((la.body_class || \"\"));\n            JSBNG__document.body.className = ma;\n        },\n        getSanitizedParameters: function() {\n            return [\"quickling\",];\n        }\n    });\n    function ga(ka) {\n        var la = [], ma = p(ka);\n        ba.forEach(function(na) {\n            var oa = na(ma);\n            if (!oa) {\n                return;\n            }\n        ;\n        ;\n            la.push(na);\n            ma = ma.addQueryData(oa);\n        });\n        ba = la;\n        return ma;\n    };\n;\n    function ha() {\n        y++;\n        return ((y >= w));\n    };\n;\n    function ia(ka) {\n        g.setCurrentRequest(null);\n        if (ha()) {\n            return false;\n        }\n    ;\n    ;\n        ka = ga(ka);\n        if (!ca.isPageActive(ka)) {\n            return false;\n        }\n    ;\n    ;\n        window.ExitTime = JSBNG__Date.now();\n        o.__removeHook(\"JSBNG__onafterloadhooks\");\n        o.__removeHook(\"JSBNG__onloadhooks\");\n        m.runHooks(\"JSBNG__onleavehooks\");\n        h.inform(\"JSBNG__onload/exit\", true);\n        new fa(ka).setCanvasId(\"JSBNG__content\").send();\n        return true;\n    };\n;\n    function ja(ka) {\n        window[((ka + \"_native\"))] = (function(la) {\n            return function ma(na, oa) {\n                return la(na, oa);\n            };\n        })(window[ka]);\n        window[ka] = function la(ma, na, oa) {\n            var pa = window[((ka + \"_native\"))](ma, na);\n            if (((na > 0))) {\n                if (((oa !== false))) {\n                    o.JSBNG__onLeave(function() {\n                        JSBNG__clearInterval(pa);\n                    });\n                }\n            ;\n            }\n        ;\n        ;\n            return pa;\n        };\n    };\n;\n    ja(\"JSBNG__setInterval\");\n    ja(\"JSBNG__setTimeout\");\n    n.registerHandler(ia, 1);\n    e.exports = a.Quickling = ca;\n});\n__d(\"MusicButtonStore\", [], function(a, b, c, d, e, f) {\n    var g = {\n    }, h = {\n        addButton: function(i, j) {\n            g[i] = j;\n            return j;\n        },\n        getButton: function(i) {\n            return g[i];\n        },\n        getButtons: function() {\n            return g;\n        },\n        removeButton: function(i) {\n            ((g[i] && g[i].resetLoadingTimers()));\n            delete g[i];\n        }\n    };\n    e.exports = h;\n});\n__d(\"MusicEvents\", [\"Arbiter\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\");\n    e.exports = a.MusicEvents = new g();\n});\n__d(\"MusicProviders\", [], function(a, b, c, d, e, f) {\n    e.exports = a.MusicProviders = {\n        SPOTIFY: \"open.spotify.com\"\n    };\n});\n__d(\"MusicConstants\", [\"Arbiter\",\"MusicEvents\",\"MusicProviders\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"MusicEvents\"), i = b(\"MusicProviders\"), j = {\n        DEBUG: false,\n        LIVE_LISTEN_MIN_SPOTIFY_VERSION: \"spotify-0.6.6.0.g5a9eaca5\",\n        enableDebug: function() {\n            this.DEBUG = true;\n        },\n        sameURLs: function(k, l) {\n            var m = /\\/$/;\n            if (((k && l))) {\n                k = URI(k);\n                l = URI(l);\n                return ((((k.getDomain() == l.getDomain())) && ((k.getPath() == l.getPath()))));\n            }\n        ;\n        ;\n            return false;\n        },\n        greaterOrEqualToMinimumVersion: function(k, l) {\n            var m = /(?:\\d+\\.)+/, n = k.match(m)[0].split(\".\").slice(0, -1), o = l.match(m)[0].split(\".\").slice(0, -1);\n            if (((n.length !== o.length))) {\n                return false;\n            }\n        ;\n        ;\n            for (var p = 0; ((p < o.length)); p++) {\n                if (((+n[p] < +o[p]))) {\n                    return false;\n                }\n                 else if (((+n[p] > +o[p]))) {\n                    return true;\n                }\n                \n            ;\n            ;\n            };\n        ;\n            return true;\n        },\n        sanitizeForProviders: function(k) {\n            var l = {\n            };\n            for (var m in k) {\n                if (this.ALLOWED_EXTERNAL_CONTEXT_PARAMS[m]) {\n                    l[m] = k[m];\n                }\n            ;\n            ;\n            };\n        ;\n            return l;\n        },\n        OP: {\n            RESUME: \"RESUME\",\n            PAUSE: \"PAUSE\",\n            PLAY: \"PLAY\",\n            VERSION: \"VERSION\"\n        },\n        STATUS_CHANGE_OP: {\n            STATUS: \"STATUS\",\n            LOGIN: \"LOGIN\",\n            REINFORM: \"REINFORM\"\n        },\n        STATUS_CHANGE_EVENT: {\n            playing: \"PLAY_STATE_CHANGED\",\n            track: \"TRACK_CHANGED\"\n        },\n        DIAGNOSTIC_EVENT: {\n            ALL_PAUSED: \"ALL_PAUSED\",\n            ALL_OFFLINE: \"ALL_OFFLINE\",\n            OFFLINE: \"OFFLINE\",\n            ONLINE: \"ONLINE\",\n            SEARCHING: \"SEARCHING\",\n            HIT: \"HIT\",\n            MISS: \"MISS\",\n            RESIGN: \"RESIGN\",\n            IFRAME_POLLING: \"IFRAME_POLLING\",\n            RELAUNCH: \"RELAUNCH\",\n            STATE_CHANGE: \"STATE_CHANGE\",\n            WRONG_VERSION: \"WRONG_VERSION\",\n            SERVICE_ERROR: \"SERVICE_ERROR\",\n            INCORRECT_ONLINE_STATE: \"INCORRECT_ONLINE_STATE\",\n            LOG_SEND_OP: \"LOG_SEND_OP\",\n            REQUEUE_OP: \"REQUEUE_OP\"\n        },\n        ALLOWED_STATUS_PARAMS: {\n            playing: \"playing\",\n            track: \"track\",\n            context: \"context\",\n            client_version: \"client_version\",\n            start_time: \"start_time\",\n            expires_in: \"expires_in\",\n            open_graph_state: \"open_graph_state\"\n        },\n        ALLOWED_EXTERNAL_CONTEXT_PARAMS: {\n            uri: true,\n            song: true,\n            radio_station: true,\n            album: true,\n            playlist: true,\n            musician: true,\n            song_list: true,\n            offset: true,\n            title: true,\n            request_id: true,\n            listen_with_friends: true,\n            needs_tos: true\n        },\n        LIVE_LISTEN_OP: {\n            NOW_LEADING: \"NOW_LEADING\",\n            NOW_LISTENING: \"NOW_LISTENING\",\n            END_SESSION: \"END_SESSION\",\n            SONG_PLAYING: \"SONG_PLAYING\",\n            LISTENER_UPDATE: \"LISTENER_UPDATE\",\n            QUEUE_SESSION: \"QUEUE_SESSION\",\n            PLAY_ERROR: \"PLAY_ERROR\",\n            SESSION_UPDATED: \"SESSION_UPDATED\",\n            QUEUING_SESSION: \"QUEUING_SESSION\"\n        },\n        MUSIC_BUTTON: {\n            ACTIVATE: \"ACTIVATE\"\n        },\n        ERROR: {\n            1: \"SERVICE_UNAVAILABLE_WITHOUT_PREMIUM\",\n            2: \"SERVICE_UNAVAILABLE_WITHOUT_PREMIUM_OR_WAIT\",\n            3: \"SERVICE_UNAVAILABLE_BILLING_ISSUE\",\n            4: \"SERVICE_UNAVAILABLE_TECHNICAL_ISSUE\",\n            5: \"AUDIO_AD_PLAYING\",\n            99: \"SERVICE_TEMPORARILY_UNAVAILABLE\",\n            101: \"SONG_UNAVAILABLE_WITHOUT_PURCHASE\",\n            102: \"SONG_UNAVAILABLE_WITHOUT_PREMIUM\",\n            103: \"SONG_UNAVAILABLE_INDEFINITELY\"\n        }\n    };\n    e.exports = ((a.MusicConstants || j));\n});\n__d(\"MusicWaterfallLogger\", [\"JSLogger\",], function(a, b, c, d, e, f) {\n    var g = b(\"JSLogger\"), h = g.create(\"music_waterfall\"), i = {\n        click: function(l) {\n            j(\"click\", l);\n        },\n        musicLoadedFromClick: function(l) {\n            j(\"music_loaded_from_click\", l);\n        },\n        playPause: function(l) {\n            j(\"play_pause\", l);\n        }\n    };\n    function j(l, m) {\n        h.debug(((l + \"_debug\")), m);\n        h.bump(l);\n        h.bump(((((l + \"_\")) + k(m))));\n    };\n;\n    function k(l) {\n        return ((l ? l.replace(/\\.|-/g, \"_\") : \"\"));\n    };\n;\n    e.exports = i;\n});\n__d(\"MusicButton\", [\"Bootloader\",\"copyProperties\",\"CSS\",\"DOM\",\"MusicButtonStore\",\"MusicConstants\",\"MusicEvents\",\"MusicWaterfallLogger\",\"Parent\",\"Tooltip\",], function(a, b, c, d, e, f) {\n    var g = b(\"Bootloader\"), h = b(\"copyProperties\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"MusicButtonStore\"), l = b(\"MusicConstants\"), m = b(\"MusicEvents\"), n = b(\"MusicWaterfallLogger\"), o = b(\"Parent\"), p = b(\"Tooltip\"), q = function(r, s, t, u, v, w) {\n        this.provider = r;\n        this.buttonElem = s;\n        this.url = t;\n        this.context = ((u || {\n        }));\n        this.mediaType = v;\n        this.setState(this.STATES.OFFLINE);\n        this.tooltip = ((w || \"\"));\n        m.subscribe(l.MUSIC_BUTTON.ACTIVATE, this.processClick.bind(this));\n    };\n    h(q, {\n        tracksetableTypes: []\n    });\n    h(q.prototype, {\n        SHOW_LOADING_TIMEOUT: 500,\n        HIDE_LOADING_TIMEOUT: 4000,\n        RECENTLY_ONLINE_TIMEOUT: 6000,\n        STATES: {\n            PLAYING: \"music_playing\",\n            PAUSED: \"music_paused\",\n            LOADING: \"music_loading\",\n            DISABLED: \"music_disabled\",\n            OFFLINE: \"music_offline\"\n        },\n        setState: function(r) {\n            if (((r !== this.STATES.LOADING))) {\n                this.resetLoadingTimers();\n                this.previousState = ((this.state || r));\n            }\n        ;\n        ;\n            if (((r === this.STATES.PLAYING))) {\n                p.set(this.buttonElem, this.tooltip);\n            }\n             else p.set(this.buttonElem, \"\");\n        ;\n        ;\n            var s = this.buttonElem.parentNode;\n            ((this.state && i.removeClass(s, this.state)));\n            this.state = r;\n            i.addClass(s, this.state);\n        },\n        isTracksetable: function(r) {\n            return ((q.tracksetableTypes.indexOf(this.mediaType) !== -1));\n        },\n        handleIncomingEvent: function(r, s) {\n            JSBNG__clearTimeout(this._showLoadingTimer);\n            if (((((s && s.provider)) && ((s.provider != this.provider))))) {\n                return;\n            }\n        ;\n        ;\n            switch (r) {\n              case l.DIAGNOSTIC_EVENT.ONLINE:\n            \n              case l.STATUS_CHANGE_EVENT.track:\n            \n              case l.STATUS_CHANGE_EVENT.playing:\n                var t = ((((s && s.track)) && s.track.uri)), u = ((((s && s.context)) && s.context.uri));\n                if (((((s && s.playing)) && ((l.sameURLs(t, this.url) || l.sameURLs(u, this.url)))))) {\n                    this.setState(this.STATES.PLAYING);\n                }\n                 else if (((((this.state === this.STATES.LOADING)) && ((((this.previousState === this.STATES.PAUSED)) || ((this.previousState === this.STATES.OFFLINE))))))) {\n                    JSBNG__clearTimeout(this._attemptingPlayTimer);\n                    this._attemptingPlayTimer = this.setState.bind(this, this.STATES.PAUSED).defer(this.RECENTLY_ONLINE_TIMEOUT, false);\n                }\n                 else if (!this._attemptingPlayTimer) {\n                    this.setState(this.STATES.PAUSED);\n                }\n                \n                \n            ;\n            ;\n                break;\n              case l.DIAGNOSTIC_EVENT.OFFLINE:\n                this.setState(this.STATES.OFFLINE);\n                break;\n              case l.DIAGNOSTIC_EVENT.ALL_OFFLINE:\n                this.setState(this.STATES.OFFLINE);\n                break;\n            };\n        ;\n        },\n        processClick: function(r, s) {\n            if (((s != this.buttonElem))) {\n                if (((this.state === this.STATES.LOADING))) {\n                    ((this.previousState && this.setState(this.previousState)));\n                }\n            ;\n            ;\n                return;\n            }\n        ;\n        ;\n            n.click(this.provider);\n            var t = ((this.isTracksetable() && o.byClass(this.buttonElem, \"music_trackset_container\"))), u = [];\n            if (t) {\n                var v = t.getAttribute(\"data-trackset-title\"), w = this.provider, x = j.scry(t, \".music_button\");\n                for (var y = 0; ((y < x.length)); y++) {\n                    var z = k.getButton([x[y].id,]);\n                    if (((((z && ((z.provider == w)))) && z.isTracksetable()))) {\n                        u.push(z.url);\n                    }\n                ;\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            if (!a.Music) {\n                this.showLoading(true);\n            }\n        ;\n        ;\n            g.loadModules([\"Music\",], function(aa) {\n                n.musicLoadedFromClick(this.provider);\n                var ba = ((((t && ((u.length > 1)))) ? aa.playPauseSongList(this.provider, this.url, u, v, this.context) : aa.playPauseSong(this.provider, this.url, this.context)));\n                this.showLoading(!ba);\n            }.bind(this));\n        },\n        showLoading: function(r) {\n            this.resetLoadingTimers();\n            this._hideLoadingTimer = this._timeout.bind(this, r).defer(this.HIDE_LOADING_TIMEOUT, false);\n            this._showLoadingTimer = this.setState.bind(this, this.STATES.LOADING).defer(this.SHOW_LOADING_TIMEOUT, false);\n        },\n        resetLoadingTimers: function() {\n            JSBNG__clearTimeout(this._hideLoadingTimer);\n            JSBNG__clearTimeout(this._showLoadingTimer);\n            JSBNG__clearTimeout(this._attemptingPlayTimer);\n            this._attemptingPlayTimer = null;\n        },\n        destroy: function() {\n            this.resetLoadingTimers();\n            this.buttonElem = null;\n        },\n        _timeout: function(r) {\n            ((a.Music && a.Music.reInform([this.provider,])));\n            if (((!r && ((this.state === this.STATES.LOADING))))) {\n                this.setState(this.STATES.PAUSED);\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = q;\n});\n__d(\"MusicButtonManager\", [\"DOM\",\"Layer\",\"MusicButton\",\"MusicButtonStore\",\"MusicConstants\",\"MusicEvents\",\"Parent\",\"$\",\"event-extensions\",\"copyProperties\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"Layer\"), i = b(\"MusicButton\"), j = b(\"MusicButtonStore\"), k = b(\"MusicConstants\"), l = b(\"MusicEvents\"), m = b(\"Parent\"), n = b(\"$\"), o = b(\"event-extensions\").$E, p = b(\"copyProperties\"), q = b(\"ge\"), r = (function() {\n        var s = null, t = {\n        };\n        function u(JSBNG__event) {\n            var z = o(JSBNG__event).getTarget(), aa = m.byClass(z, \"music_button\");\n            aa = ((aa || ((!JSBNG__event.getModifiers().any && v(z)))));\n            if (!aa) {\n                return;\n            }\n        ;\n        ;\n            return w(aa, JSBNG__event);\n        };\n    ;\n        function v(z) {\n            var aa = ((m.byClass(z, \"music_button_trigger\") && m.byClass(z, \"music_button_trigger_group\")));\n            if (aa) {\n                var ba = g.scry(aa, \".music_button\");\n                if (ba.length) {\n                    return ba[0];\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            return null;\n        };\n    ;\n        function w(z, JSBNG__event) {\n            ((JSBNG__event && o(JSBNG__event).JSBNG__stop()));\n            l.inform(k.MUSIC_BUTTON.ACTIVATE, z);\n            return false;\n        };\n    ;\n        function x(z) {\n            ((a.Music && a.Music.reInform(z)));\n        };\n    ;\n        function y(z, aa) {\n            var ba = j.getButtons();\n            for (var ca in ba) {\n                if (((ba[ca].noGC || q(ca)))) {\n                    ba[ca].handleIncomingEvent(z, aa);\n                }\n                 else j.removeButton(ca);\n            ;\n            ;\n            };\n        ;\n        };\n    ;\n        return {\n            init: function(z) {\n                if (s) {\n                    return;\n                }\n            ;\n            ;\n                s = true;\n                i.tracksetableTypes = ((z || []));\n                JSBNG__Event.listen(JSBNG__document.body, \"click\", u);\n                l.subscribe([k.STATUS_CHANGE_EVENT.playing,k.STATUS_CHANGE_EVENT.track,k.DIAGNOSTIC_EVENT.OFFLINE,k.DIAGNOSTIC_EVENT.ALL_OFFLINE,k.DIAGNOSTIC_EVENT.ONLINE,], y);\n            },\n            add: function(z, aa, ba, ca, da, ea) {\n                ((s || r.init()));\n                var fa = aa.id, ga = j.getButton(fa);\n                if (ga) {\n                    return ga;\n                }\n            ;\n            ;\n                ga = j.addButton(fa, new i(z, aa, ba, p({\n                    button_id: fa\n                }, ca), da, ea));\n                var ha = m.byClass(aa, \"uiOverlay\");\n                if (ha) {\n                    ga.noGC = true;\n                    var ia = h.subscribe(\"destroy\", function(ja, ka) {\n                        if (g.contains(ka.getRoot(), aa)) {\n                            j.removeButton(fa);\n                            h.unsubscribe(ia);\n                        }\n                    ;\n                    ;\n                    });\n                }\n            ;\n            ;\n                if (((z && !t[z]))) {\n                    t[z] = function() {\n                        var ja = Object.keys(t);\n                        ((ja.length && x(ja)));\n                        t = {\n                        };\n                    }.defer();\n                }\n            ;\n            ;\n                return ga;\n            },\n            addButton: function(z, aa, ba, ca, da, ea) {\n                if (!q(aa)) {\n                    return;\n                }\n            ;\n            ;\n                var fa = n(aa);\n                return this.add(z, fa, ba, ca, da, ea);\n            }\n        };\n    })();\n    e.exports = ((a.MusicButtonManager || r));\n});\n__d(\"NotificationCounter\", [\"Arbiter\",\"DocumentTitle\",\"JSLogger\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"DocumentTitle\"), i = b(\"JSLogger\"), j = {\n        messages: 0,\n        notifications: 0,\n        requests: 0\n    }, k = {\n        init: function() {\n            g.subscribe(\"update_title\", this._handleUpdate.bind(this));\n            g.subscribe(\"jewel/count-updated\", this._handleCountUpdate.bind(this));\n        },\n        getCount: function() {\n            var l = 0;\n            for (var m in j) {\n                var n = Number(j[m]);\n                if (((((typeof j[m] == \"string\")) && isNaN(n)))) {\n                    return j[m];\n                }\n            ;\n            ;\n                if (((isNaN(n) || ((n < 0))))) {\n                    i.create(\"jewels\").error(\"bad_count\", {\n                        jewel: m,\n                        count: j[m]\n                    });\n                    continue;\n                }\n            ;\n            ;\n                l += n;\n            };\n        ;\n            return l;\n        },\n        updateTitle: function() {\n            var l = this.getCount(), m = h.get();\n            m = ((l ? ((((((\"(\" + l)) + \") \")) + m)) : m));\n            h.set(m, true);\n        },\n        _handleCountUpdate: function(l, m) {\n            j[m.jewel] = m.count;\n            this.updateTitle();\n        },\n        _handleUpdate: function(l, m) {\n            this.updateTitle();\n        }\n    };\n    e.exports = k;\n});\n__d(\"legacy:notifications-counter\", [\"NotificationCounter\",], function(a, b, c, d) {\n    a.NotificationCounter = b(\"NotificationCounter\");\n}, 3);\n__d(\"NotificationSound\", [\"Sound\",\"ChatOptions\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Sound\"), h = b(\"ChatOptions\"), i = b(\"copyProperties\");\n    g.init([\"audio/mpeg\",]);\n    function j(k) {\n        this._soundPath = k;\n    };\n;\n    i(j.prototype, {\n        play: function() {\n            if (((((this._soundPath !== null)) && h.getSetting(\"sound\")))) {\n                g.play(this._soundPath);\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = j;\n});\n__d(\"legacy:notifications-sound\", [\"NotificationSound\",], function(a, b, c, d) {\n    a.NotificationSound = b(\"NotificationSound\");\n}, 3);\n__d(\"legacy:notif-xlist\", [\"NotifXList\",], function(a, b, c, d) {\n    a.NotifXList = b(\"NotifXList\");\n}, 3);\nfunction NegativeNotif(a, b) {\n    copyProperties(this, b);\n    this.owner = a;\n    this.xLink = DOM.JSBNG__find(this.obj, \".notif_x\");\n    this.confirmingMsg = DOM.JSBNG__find(this.obj, \".confirmingMsg\");\n    this.mainLink = DOM.JSBNG__find(this.obj, \".notifMainLink\");\n    this.userXClicked = false;\n    this.userUnsubscribed = false;\n    JSBNG__Event.listen(this.xLink, \"click\", this.xClick.bind(this));\n};\n;\ncopyProperties(NegativeNotif.prototype, {\n    FADE_AWAY_DURATION: 2500,\n    X_OUT_DURATION: 100,\n    X_OUT_DURATION_SHORT: 2,\n    xClick: function(JSBNG__event) {\n        this._activateX();\n        var a = this.xLink.getAttribute(\"data-gt\"), b = ((a ? {\n            gt: JSON.parse(a)\n        } : {\n        }));\n        user_action(\"click\", this.xLink, JSBNG__event, null, b);\n        return false;\n    },\n    restore: function() {\n        if (this.owner.notifXList.newNotifExist(this.id)) {\n            this.owner.notifXList.resumeInsert(this.id);\n        }\n         else this.owner.notifXList.removeNotif(this.id);\n    ;\n    ;\n        this._confirmingMsgFadeAway(this.confirmingMsg);\n        this._notifMainLinkShowUp(this.mainLink);\n        this._buttonShowUp(this.xLink);\n        this._adjustContainer(this.obj);\n    },\n    reset: function() {\n        if (((this.userXClicked && !this.userUnsubscribed))) {\n            this.userXClicked = false;\n            this.restore();\n        }\n    ;\n    ;\n    },\n    JSBNG__onTurnedOff: function() {\n        this.userUnsubscribed = true;\n        CSS.hide(this.confirmingMsg);\n        this._notifMainLinkShowUp(DOM.JSBNG__find(this.obj, \".confirmedMsg\"));\n        this._adjustContainer(this.obj);\n    },\n    JSBNG__onUndid: function() {\n        this.userXClicked = false;\n        this.userUnsubscribed = false;\n        this.restore();\n        CSS.show(this.confirmingMsg);\n        this._notifMainLinkFadeAway(DOM.JSBNG__find(this.obj, \".confirmedMsg\"));\n        DOM.remove(DOM.JSBNG__find(this.obj, \".confirmedMsg\"));\n    },\n    JSBNG__onMarkedSpam: function() {\n        DOM.remove(DOM.JSBNG__find(this.obj, \".confirmedMsg\"));\n        this._fadeAway(DOM.JSBNG__find(this.obj, \".spamMsg\"));\n    },\n    JSBNG__onFirstReceiptYes: function() {\n        this._hideFirstReceiptDiv();\n        this._fadeAway(DOM.JSBNG__find(this.obj, \".firstConfirmedMsg\"));\n    },\n    JSBNG__onFirstReceiptNo: function() {\n        this._hideFirstReceiptDiv();\n        CSS.hide(this.confirmingMsg);\n        this._activateX();\n        new AsyncRequest().setURI(\"/ajax/notifications/negative_req.php\").setData({\n            request_type: \"turn_off\",\n            notification_id: this.id\n        }).send();\n    },\n    _activateX: function() {\n        CSS.addClass(this.obj, \"forPushSafety\");\n        this.userXClicked = true;\n        this.owner.notifXList.userXClick(this.id);\n        this._notifMainLinkFadeAway(this.mainLink);\n        this._buttonFadeAway(this.xLink);\n        if (CSS.shown(this.confirmingMsg)) {\n            this._confirmingMsgShowUp(this.confirmingMsg);\n        }\n    ;\n    ;\n        this._adjustContainer(this.obj);\n    },\n    _hideFirstReceiptDiv: function() {\n        CSS.hide(DOM.JSBNG__find(this.obj, \".first_receipt_div\"));\n    },\n    _fadeAway: function(a) {\n        animation(a).from(\"backgroundColor\", \"#FFF9D7\").to(\"backgroundColor\", \"#FFFFFF\").duration(this.FADE_AWAY_DURATION).checkpoint().to(\"opacity\", \"0\").blind().duration(this.X_OUT_DURATION).checkpoint().to(\"height\", \"0px\").to(\"paddingTop\", \"0px\").to(\"paddingBottom\", \"0px\").blind().hide().duration(this.X_OUT_DURATION).go();\n    },\n    _adjustContainer: function(a) {\n        animation(a).by(\"height\", \"0px\").duration(this.X_OUT_DURATION).checkpoint().by(\"height\", \"0px\").duration(this.X_OUT_DURATION_SHORT).checkpoint().to(\"height\", \"auto\").duration(this.X_OUT_DURATION).go();\n    },\n    _notifMainLinkShowUp: function(a) {\n        animation(a).duration(this.X_OUT_DURATION).checkpoint().to(\"height\", \"auto\").to(\"paddingTop\", \"4px\").to(\"paddingBottom\", \"4px\").blind().show().duration(this.X_OUT_DURATION_SHORT).checkpoint().to(\"opacity\", \"1\").blind().duration(this.X_OUT_DURATION).go();\n    },\n    _confirmingMsgShowUp: function(a) {\n        animation(a).duration(this.X_OUT_DURATION).checkpoint().to(\"height\", \"auto\").to(\"paddingTop\", \"10px\").to(\"paddingBottom\", \"10px\").blind().show().duration(this.X_OUT_DURATION_SHORT).checkpoint().to(\"opacity\", \"1\").blind().duration(this.X_OUT_DURATION).go();\n    },\n    _notifMainLinkFadeAway: function(a) {\n        animation(a).to(\"opacity\", \"0\").blind().duration(this.X_OUT_DURATION).checkpoint().to(\"height\", \"0px\").to(\"paddingTop\", \"0px\").to(\"paddingBottom\", \"0px\").blind().hide().duration(this.X_OUT_DURATION_SHORT).go();\n    },\n    _confirmingMsgFadeAway: function(a) {\n        animation(a).to(\"opacity\", \"0\").blind().duration(this.X_OUT_DURATION).checkpoint().to(\"height\", \"0px\").to(\"paddingTop\", \"0px\").to(\"paddingBottom\", \"0px\").blind().duration(this.X_OUT_DURATION_SHORT).go();\n    },\n    _buttonShowUp: function(a) {\n        animation(a).duration(this.X_OUT_DURATION).checkpoint().show().duration(this.X_OUT_DURATION_SHORT).checkpoint().to(\"opacity\", \"1\").blind().duration(this.X_OUT_DURATION).go();\n    },\n    _buttonFadeAway: function(a) {\n        animation(a).to(\"opacity\", \"0\").blind().duration(this.X_OUT_DURATION).checkpoint().hide().duration(this.X_OUT_DURATION_SHORT).go();\n    }\n});\n__d(\"NotificationList\", [\"Animation\",\"Arbiter\",\"ArbiterMixin\",\"Class\",\"CSS\",\"DOM\",\"DoublyLinkedListMap\",\"HTML\",\"URI\",\"$\",\"copyProperties\",\"ge\",\"isEmpty\",\"tx\",\"hasArrayNature\",], function(a, b, c, d, e, f) {\n    var g = b(\"Animation\"), h = b(\"Arbiter\"), i = b(\"ArbiterMixin\"), j = b(\"Class\"), k = b(\"CSS\"), l = b(\"DOM\"), m = b(\"DoublyLinkedListMap\"), n = b(\"HTML\"), o = b(\"URI\"), p = b(\"$\"), q = b(\"copyProperties\"), r = b(\"ge\"), s = b(\"isEmpty\"), t = b(\"tx\"), u = b(\"hasArrayNature\"), v = \"0\", w = \"1\", x = \"2\";\n    function y(ba) {\n        return ((((ba == w)) || ((ba == x))));\n    };\n;\n    function z(ba) {\n        return ((ba == w));\n    };\n;\n    function aa(ba, ca) {\n        this._list = new m();\n        this._filter_func = null;\n        this.unseenCount = 0;\n        this.contentRoot = ba;\n        this.noItemsElement = null;\n        this.ITEM_TAG = \"li\";\n        this.ITEM_CLASS = \"notification\";\n        this.NO_ITEMS_ID = \"jewelNoNotifications\";\n        this.NO_ITEMS_CLASS = \"empty\";\n        this.compare = ((ca.compare || this.compare));\n        this.shouldBlockAnimation = ((ca.shouldBlockAnimation || null));\n        this.unseenVsUnread = ((ca.unseenVsUnread || false));\n        this.animations = {\n        };\n    };\n;\n    q(aa, {\n        ITEM_UNREAD_CLASS: \"jewelItemNew\",\n        MARK_READ_TYPE: \"mark_read\",\n        UNREAD_COUNT_CHANGE_TYPE: \"unread_count_change\",\n        INSERTION_TYPE: \"insert\",\n        REMOVAL_TYPE: \"remove\",\n        getIdFromDom: function(ba) {\n            return ba.getAttribute(\"id\").replace(\"notification_\", \"\");\n        },\n        localizeUrls: function(ba) {\n            l.scry(ba, \"a\").forEach(function(ca) {\n                ((o(ca.href).isFacebookURI() && (ca.href = o(ca.href).getUnqualifiedURI().getQualifiedURI().setSubdomain(o(ca.href).getSubdomain()).toString())));\n            });\n        }\n    });\n    q(aa.prototype, i, {\n        FADE_DURATION: 250,\n        RESIZE_DURATION: 200,\n        _getField: function(ba, ca) {\n            var da = this._list.get(ba);\n            return ((da && da[ca]));\n        },\n        getDomObj: function(ba) {\n            return this._getField(ba, \"obj\");\n        },\n        fromDom: function() {\n            var ba = ((((this.ITEM_TAG + \".\")) + this.ITEM_CLASS)), ca = l.scry(this.contentRoot, ba);\n            for (var da = 0; ((da < ca.length)); ++da) {\n                var ea = ca[da], fa = aa.getIdFromDom(ea);\n                this.insert(fa, ea.getAttribute(\"data-notiftime\"), null);\n            };\n        ;\n        },\n        compare: function(ba, ca) {\n            return ((((ba.time < ca.time)) || ((((ba.time === ca.time)) && ((ba.id < ca.id))))));\n        },\n        insert: function(ba, ca, da, ea, fa, ga) {\n            var ha = w, ia = 0, ja = this._list.exists(ba), ka = ((ga && this._list.exists(ga))), la = null, ma;\n            if (((ja || ka))) {\n                if (!((ea && da))) {\n                    return false;\n                }\n                 else {\n                    if (this._filter_func) {\n                        ma = {\n                            notif_id: ba,\n                            notif_time: ca,\n                            notif_markup: da,\n                            replace: ea,\n                            ignoreUnread: fa,\n                            notif_alt_id: ga\n                        };\n                        if (this._filter_func(ma)) {\n                            return false;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    ha = this._getField(ba, \"readness\");\n                    ia = this._getField(ba, \"time\");\n                    if (((ia > ca))) {\n                        return false;\n                    }\n                ;\n                ;\n                    la = ((ja ? ba : ga));\n                    this._remove(la);\n                }\n            ;\n            }\n        ;\n        ;\n            var na = ((((da && n(da).getRootNode())) || p(((\"notification_\" + ba))))), oa = Math.max(ca, ia), pa = na.getAttribute(\"data-readness\");\n            if (((!this.unseenVsUnread && ((x == pa))))) {\n                pa = v;\n            }\n        ;\n        ;\n            ma = {\n                id: ba,\n                obj: na,\n                time: oa,\n                readness: pa,\n                app_id: na.getAttribute(\"data-appid\")\n            };\n            this._insert(ma);\n            aa.localizeUrls(na);\n            ((this.noItemsElement && k.hide(this.noItemsElement)));\n            if (z(pa)) {\n                ((((fa && !y(ha))) && this.markRead([ba,])));\n                this.unseenCount = this.getUnseenIds().length;\n                this.inform(aa.UNREAD_COUNT_CHANGE_TYPE);\n            }\n        ;\n        ;\n            var qa = ((((!la || ((ia < oa)))) || ((((pa && !ha)) && !fa))));\n            this.inform(aa.INSERTION_TYPE, {\n                id: ba,\n                is_new: qa,\n                obj: na,\n                replaced_id: la,\n                time: oa\n            });\n            return true;\n        },\n        showNoNotifications: function() {\n            if (((null == this.noItemsElement))) {\n                this.noItemsElement = r(this.NO_ITEMS_ID);\n            }\n        ;\n        ;\n            if (((null == this.noItemsElement))) {\n                this.noItemsElement = l.create(this.ITEM_TAG, {\n                    id: this.NO_ITEMS_ID,\n                    className: this.NO_ITEMS_CLASS\n                }, \"No new notifications\");\n                l.appendContent(this.contentRoot, this.noItemsElement);\n            }\n        ;\n        ;\n            k.show(this.noItemsElement);\n        },\n        _insert: function(ba) {\n            this._list.remove(ba.id);\n            var ca = null;\n            this._list.JSBNG__find(function(ea) {\n                var fa = this.compare(ea, ba);\n                ((!fa && (ca = ea.id)));\n                return fa;\n            }.bind(this));\n            var da = this.getDomObj(ca);\n            if (da) {\n                this._list.insertAfter(ba.id, ba, ca);\n                l.insertAfter(da, ba.obj);\n            }\n             else {\n                this._list.prepend(ba.id, ba);\n                l.prependContent(this.contentRoot, ba.obj);\n            }\n        ;\n        ;\n        },\n        _remove: function(ba) {\n            var ca = this._getField(ba, \"obj\");\n            if (!ca) {\n                return false;\n            }\n        ;\n        ;\n            this.inform(aa.REMOVAL_TYPE, {\n                id: ba\n            });\n            this._list.remove(ba);\n            l.remove(ca);\n            ((this.isEmpty() && this.showNoNotifications()));\n            return true;\n        },\n        getUnreadIds: function() {\n            return this._list.reduce(function(ba, ca) {\n                ((y(ba.readness) && ca.push(ba.id)));\n                return ca;\n            }, []);\n        },\n        getUnseenIds: function() {\n            return this._list.reduce(function(ba, ca) {\n                ((z(ba.readness) && ca.push(ba.id)));\n                return ca;\n            }, []);\n        },\n        getIds: function() {\n            return this._list.reduce(function(ba, ca) {\n                ca.push(ba.id);\n                return ca;\n            }, []);\n        },\n        isUnreadId: function(ba) {\n            var ca = this.getDomObj(ba);\n            return ((y(this._getField(ba, \"readness\")) || ((ca && k.hasClass(ca, aa.ITEM_UNREAD_CLASS)))));\n        },\n        isUnseenId: function(ba) {\n            return z(this._getField(ba, \"readness\"));\n        },\n        markRead: function(ba, ca) {\n            ba = ((ba ? ba.filter(this.isUnreadId.bind(this)) : this.getUnreadIds()));\n            var da = false;\n            for (var ea = 0; ((ea < ba.length)); ea++) {\n                var fa = this._list.get(ba[ea]);\n                if (fa) {\n                    if (this._setReadness(ba[ea], v)) {\n                        da = true;\n                    }\n                ;\n                ;\n                    if (ca) {\n                        this._markReadInDom(ba[ea], fa.obj);\n                    }\n                     else this.animateMarkRead(fa.obj);\n                ;\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            if (da) {\n                this.unseenCount = this.getUnseenIds().length;\n                this.inform(aa.UNREAD_COUNT_CHANGE_TYPE);\n            }\n        ;\n        ;\n        },\n        markSeen: function(ba) {\n            if (!u(ba)) {\n                return;\n            }\n        ;\n        ;\n            if (!this.unseenVsUnread) {\n                this.markRead(ba);\n                return;\n            }\n        ;\n        ;\n            ba = ba.filter(this.isUnseenId.bind(this));\n            var ca = false;\n            for (var da = 0; ((da < ba.length)); da++) {\n                if (this._setReadness(ba[da], x)) {\n                    ca = true;\n                }\n            ;\n            ;\n            };\n        ;\n            if (ca) {\n                this.unseenCount = this.getUnseenIds().length;\n                this.inform(aa.UNREAD_COUNT_CHANGE_TYPE);\n            }\n        ;\n        ;\n        },\n        _setReadness: function(ba, ca) {\n            var da = this._list.get(ba);\n            if (((!da || ((da.readness == ca))))) {\n                return false;\n            }\n        ;\n        ;\n            if (((((da.readness == v)) && ((ca == x))))) {\n                return false;\n            }\n        ;\n        ;\n            da.readness = ca;\n            da.obj.setAttribute(\"data-readness\", ca);\n            return true;\n        },\n        _markReadInDom: function(ba, ca) {\n            if (!this.isUnreadId(ba)) {\n                return;\n            }\n        ;\n        ;\n            var da = p(ca);\n            if (da) {\n                this.stopAnimation(ba);\n                k.removeClass(da, aa.ITEM_UNREAD_CLASS);\n            }\n        ;\n        ;\n        },\n        animateMarkRead: function(ba) {\n            if (!k.hasClass(ba, aa.ITEM_UNREAD_CLASS)) {\n                return;\n            }\n        ;\n        ;\n            var ca = aa.getIdFromDom(ba), da = this._markReadInDom.bind(this, ca, ba);\n            if (k.hasClass(ba, \"fbJewelBeep\")) {\n                da();\n                return;\n            }\n        ;\n        ;\n            if (((this.shouldBlockAnimation && this.shouldBlockAnimation(ba)))) {\n                return;\n            }\n        ;\n        ;\n            da.defer(10000);\n        },\n        stopAnimation: function(ba) {\n            ((((ba in this.animations)) && this.animations[ba].JSBNG__stop()));\n            delete this.animations[ba];\n            return true;\n        },\n        insertMany: function(ba, ca) {\n            if (((((\"object\" == typeof ba)) && !s(ba)))) {\n                for (var da in ba) {\n                    var ea = ba[da];\n                    this.insert(da, ea.time, ea.markup, true, ca, ((ea.alt_id || null)));\n                };\n            ;\n                ((this.noItemsElement && k.hide(this.noItemsElement)));\n            }\n             else ((this.isEmpty() && this.showNoNotifications()));\n        ;\n        ;\n        },\n        isEmpty: function() {\n            return this._list.isEmpty();\n        },\n        getEarliestNotifTime: function() {\n            return ((this._list.isEmpty() ? 0 : Math.min.apply(null, this.getIds().map(function(ba) {\n                return this._getField(ba, \"time\");\n            }.bind(this)))));\n        },\n        setFilterFn: function(ba) {\n            this._filter_func = ba;\n        },\n        toggleNotifsSimilarTo: function(ba, ca, da) {\n            var ea = this._getField(ba, \"app_id\");\n            if (ea) {\n                var fa = this.getIds();\n                for (var ga = 0; ((ga < fa.length)); ++ga) {\n                    if (((ea == this._getField(fa[ga], \"app_id\")))) {\n                        var ha = this.getDomObj(fa[ga]);\n                        if (((ba != fa[ga]))) {\n                            ((ca ? this._hideWithAnimation(ha) : this._showWithAnimation(ha)));\n                        }\n                    ;\n                    ;\n                        var ia = l.scry(ha, \".first_receipt_div\");\n                        if (((ia.length == 1))) {\n                            if (da) {\n                                k.hide(ia[0]);\n                                k.removeClass(ha, \"first_receipt\");\n                            }\n                             else {\n                                k.show(ia[0]);\n                                k.addClass(ha, \"first_receipt\");\n                            }\n                        ;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n        },\n        _hideWithAnimation: function(ba) {\n            g(ba).to(\"opacity\", \"0\").blind().duration(this.FADE_DURATION).checkpoint().to(\"height\", \"0px\").to(\"paddingTop\", \"0px\").to(\"paddingBottom\", \"0px\").blind().hide().duration(this.RESIZE_DURATION).go();\n        },\n        _showWithAnimation: function(ba) {\n            g(ba).to(\"height\", \"auto\").to(\"paddingTop\", \"auto\").to(\"paddingBottom\", \"auto\").blind().show().duration(this.RESIZE_DURATION).checkpoint().to(\"opacity\", \"1\").blind().duration(this.FADE_DURATION).go();\n        }\n    });\n    e.exports = aa;\n});\n__d(\"legacy:notifications-list\", [\"NotificationList\",], function(a, b, c, d) {\n    a.NotificationList = b(\"NotificationList\");\n}, 3);\nfunction Notifications(a) {\n    this.updateTime = ((a.updateTime || JSBNG__Date.now()));\n    this.update_period = ((a.updatePeriod || 60000));\n    this.latest_notif_time = ((a.latestNotif || 0));\n    this.latest_read_notif_time = ((a.latestReadNotif || 0));\n    this.cache_version = ((a.cacheVersion || 0));\n    this.notifReceivedType = ((a.notifReceivedType || \"notification\"));\n    this.wrapperID = ((a.wrapperID || \"notificationsWrapper\"));\n    this.contentID = ((a.contentID || \"jewelNotifs\"));\n    this.shouldLogImpressions = ((a.shouldLogImpressions || false));\n    this.allowDesktopNotifications = ((a.allowDesktopNotifications || false));\n    this.useInfiniteScroll = ((a.useInfiniteScroll || false));\n    this.useUnaggregatedBeeper = ((a.unaggregatedBeeper || false));\n    this.unseenVsUnread = ((a.unseenVsUnread || false));\n    this.receiveSoundPath = ((a.receiveSoundPath || null));\n    this.useAggregatedBottomBeeper = ((a.useAggregatedBottomBeeper || false));\n    this.fadeInDuration = ((a.fadeInDuration || -1));\n    this.fadeOutDuration = ((a.fadeOutDuration || -1));\n    this.fadeOutDelay = ((a.fadeOutDelay || -1));\n    this.scrollableAreaNode = null;\n    this.firstReceiptMap = {\n    };\n    this.user = Env.user;\n    this.timeElement = \"small.time\";\n    this.ua = new UserNoOp();\n    this._init();\n};\n;\nNotifications.BEEPS_EXPIRED = \"beeper/beeps_expired\";\ncopyProperties(Notifications.prototype, {\n    TIME_TRAVEL: \"time_travel\",\n    ONLINE: \"JSBNG__online\",\n    SCROLL_OFF_TINY: \"scroll_off_tiny\",\n    INACTIVE_REFRESH: \"inactive_refresh\",\n    _init: function() {\n        this.BEEPER_APPID = 30729425562;\n        this.ignoreBeeps = false;\n        this.cookieName = ((\"notifications_\" + this.user));\n        this.beepsExpiredToken = null;\n        this.updateCheckCount = 0;\n        this.fetchListeners = [];\n        this.currentFetchRequest = null;\n        this.wrapper = ge(this.wrapperID);\n        this.JSBNG__content = ge(this.contentID);\n        this.jewelFlyout = ge(\"fbNotificationsFlyout\");\n        this.footer = DOM.JSBNG__find(this.jewelFlyout, \".jewelFooter\");\n        this.loadingIndicator = ge(((this.contentID + \"_loading_indicator\")));\n        this.NOTIF_JEWEL_REF = \"notif_jewel\";\n        this.BEEPER_REF = \"beeper\";\n        this.notifLogger = JSLogger.create(\"notifications\");\n        NotificationCounter.init();\n        this.alertList = new NotificationList(this.JSBNG__content, this._getListParams());\n        this._updateCount();\n        ((((window.MinNotifications && MinNotifications.fetchSent())) && (this.fetch = bagofholding)));\n        Arbiter.subscribe(ChannelConstants.getArbiterType(this.notifReceivedType), this._handleNotificationMsg.bind(this));\n        Arbiter.subscribe(ChannelConstants.getArbiterType(\"notifications_read\"), this._handleNotificationsReadMsg.bind(this));\n        Arbiter.subscribe(ChannelConstants.getArbiterType(\"notifications_seen\"), this._handleNotificationsSeenMsg.bind(this));\n        Arbiter.subscribe(\"jewel/resize\", this._hideOverflow.shield(this));\n        this.alertList.subscribe(NotificationList.UNREAD_COUNT_CHANGE_TYPE, this._updateCount.bind(this));\n        this._poller = new Poller(this.update_period, this._update.bind(this), true);\n        if (this.wrapper) {\n            this.countSpan = DOM.JSBNG__find(this.wrapper, \"span.jewelCount span\");\n        }\n    ;\n    ;\n        this.initializeEvents();\n        this.fromDom();\n        if (this.useInfiniteScroll) {\n            this._autoLoadNotifIndex = 1;\n            this._truncate = false;\n            this.alertList.subscribe(NotificationList.INSERTION_TYPE, this._handleInsert.bind(this));\n        }\n    ;\n    ;\n        this._notifSound = null;\n    },\n    _getListParams: function() {\n        return {\n            shouldBlockAnimation: function(a) {\n                return this.isNotifJewelOpen();\n            }.bind(this),\n            unseenVsUnread: this.unseenVsUnread\n        };\n    },\n    fromDom: function() {\n        this.ignoreBeeps = true;\n        this.alertList.fromDom();\n        ((((((window.MinNotifications && MinNotifications.fetched())) && this.alertList.isEmpty())) && this.alertList.showNoNotifications()));\n        this.ignoreBeeps = false;\n    },\n    initializeEvents: function() {\n        var a = this.alertList.ITEM_TAG, b = null;\n        JSBNG__Event.listen(this.JSBNG__content, {\n            mouseover: function(JSBNG__event) {\n                var d = JSBNG__event.getTarget();\n                b = Parent.byTag(d, a);\n                if (((b && ((d != b))))) {\n                    if (Parent.byClass(b, \"notifNegativeBase\")) {\n                        CSS.addClass(b, \"notifHover\");\n                    }\n                     else CSS.addClass(b, \"selected\");\n                ;\n                }\n            ;\n            ;\n            },\n            mouseout: function(JSBNG__event) {\n                ((b && CSS.removeClass(b, \"selected\")));\n                ((b && CSS.removeClass(b, \"notifHover\")));\n                b = null;\n            },\n            mousedown: this.JSBNG__onContentMouseDown.bind(this)\n        });\n        JSBNG__Event.listen(this.wrapper, \"mouseover\", this.JSBNG__onMouseOver.bind(this));\n        Toggler.listen(\"show\", this.wrapper, this.JSBNG__onClick.bind(this));\n        Toggler.listen(\"hide\", this.wrapper, this.JSBNG__onHide.bind(this));\n        ((this.shouldLogImpressions && Toggler.listen(\"show\", this.wrapper, this._logImpression.bind(this))));\n        var c = function(d) {\n            this._poller.requestNow();\n            this.notifLogger.bump(d);\n        }.bind(this);\n        SystemEvents.subscribe(SystemEvents.TIME_TRAVEL, c.curry(this.TIME_TRAVEL));\n        SystemEvents.subscribe(SystemEvents.ONLINE, function(d, e) {\n            ((e && c(this.ONLINE)));\n        });\n        INACTIVE_REFRESH_MS = ((((1000 * 60)) * 60));\n        UserActivity.subscribe(function(d, e) {\n            ((((e.idleness > INACTIVE_REFRESH_MS)) && c(this.INACTIVE_REFRESH)));\n        }.bind(this));\n        if (((((Parent.byClass(this.wrapper, \"notifJewelBeeper\") && !FbDesktopPlugin.shouldSuppressBeeper())) && (this.beeper = window.NotifBeeper)))) {\n            this._initBeeper();\n        }\n    ;\n    ;\n        this.negativeNotifs = {\n        };\n        this._initNotifNegativeFeedback();\n        if (this.useInfiniteScroll) {\n            this._setupScroll();\n            this._initializeScrollEvents();\n            this._updateScrollDataStructures.bind(this).defer();\n            this._hideOverflow();\n        }\n    ;\n    ;\n    },\n    _setupScroll: function() {\n        this._scrollArea = DOM.scry(this.jewelFlyout, \"div.uiScrollableAreaWrap\")[0];\n        this._morePagerLink = DOM.JSBNG__find(this.jewelFlyout, \".notifMorePager a\");\n        this._morePager = ((Parent.byClass(this._morePagerLink, \"notifMorePager\") || this._morePagerLink));\n        this._infiniteScrollNotif = null;\n        this.afterFirstFetch = false;\n        this.animate = false;\n        if (((window.MinNotifications && MinNotifications.fetched()))) {\n            this.afterFirstFetch = true;\n            CSS.show(this._morePager);\n        }\n    ;\n    ;\n    },\n    _initializeScrollEvents: function() {\n        JSBNG__Event.listen(this._scrollArea, \"JSBNG__scroll\", throttle(this._handleScroll.bind(this)));\n        JSBNG__Event.listen(this._morePagerLink, \"success\", function(a) {\n            this.fetchHandler(a.getData().response);\n        }.bind(this));\n    },\n    _updateScrollDataStructures: function() {\n        var a = this.alertList.getIds(), b = Math.max(0, ((a.length - this._autoLoadNotifIndex)));\n        this._infiniteScrollNotif = this.alertList.getDomObj(a[b]);\n        this._annotateMorePagerURI();\n    },\n    _annotateMorePagerURI: function() {\n        this._morePagerLink.setAttribute(\"ajaxify\", new URI(this._morePagerLink.getAttribute(\"ajaxify\")).addQueryData({\n            earliest_time: this.alertList.getEarliestNotifTime()\n        }));\n    },\n    JSBNG__onContentMouseDown: function(JSBNG__event) {\n        var a = Parent.byTag(JSBNG__event.getTarget(), this.alertList.ITEM_TAG), b = ((a && NotificationList.getIdFromDom(a)));\n        if (((b && this.alertList.isUnreadId(b)))) {\n            this.markRead(true, [b,]);\n        }\n    ;\n    ;\n    },\n    JSBNG__onMouseOver: function(JSBNG__event) {\n        this.ua = user_action(\"jewel\", JSBNG__event.target, JSBNG__event).set_namespace(\"notifs\").set_ua_id(\"prefetch\").add_event(\"hover\");\n        this.fetch();\n    },\n    JSBNG__onClick: function() {\n        ((this.beeper && this.beeper.clearBeeps()));\n        ((((window.ArbiterMonitor && ((this.fetch != bagofholding)))) && Arbiter.registerCallback(bagofholding, [\"notifs/fetched\",])));\n        this.ua.add_event(\"show\");\n        this.fetch();\n        this.markRead(true);\n        this._hideOverflow();\n        if (this.scrollableAreaNode) {\n            var a = ScrollableArea.getInstance(this.scrollableAreaNode);\n            ((a && a.poke()));\n        }\n    ;\n    ;\n    },\n    JSBNG__onHide: function() {\n        this.animate = false;\n        ((this.animation && this.animation.JSBNG__stop()));\n        this.ua.add_event(\"hide\");\n        this.markRead(true);\n    },\n    _handleScroll: function() {\n        if (this._checkInfiniteScroll()) {\n            this._autoLoadNotifIndex = 5;\n            this._sendFetchRequest(this._morePager);\n        }\n    ;\n    ;\n    },\n    _handleInsert: function(a, b) {\n        if (b.is_new) {\n            this._newDataFromInsert = true;\n        }\n    ;\n    ;\n        this._updateScrollDataStructures();\n    },\n    _checkInfiniteScroll: function() {\n        if (((this._infiniteScrollNotif && this._scrollArea))) {\n            var a = Vector2.getElementPosition(this._infiniteScrollNotif).y, b = ((Vector2.getElementPosition(this._scrollArea).y + Vector2.getElementDimensions(this._scrollArea).y));\n            return ((a < b));\n        }\n    ;\n    ;\n        return false;\n    },\n    _initBeeper: function() {\n        this.beeper.init(this.jewelFlyout);\n        this.beeper.setFadeInDuration(this.fadeInDuration);\n        this.beeper.setFadeOutDuration(this.fadeOutDuration);\n        this.beeper.setFadeOutDelay(this.fadeOutDelay);\n        ((!this.useUnaggregatedBeeper && this.alertList.subscribe(NotificationList.INSERTION_TYPE, function(a, b) {\n            if (((((!this.isNotifJewelOpen() && !this.ignoreBeeps)) && this.alertList.isUnreadId(b.id)))) {\n                ((b.is_new ? this.beeper.addBeep(b.id, b.obj) : this.beeper.updateBeep(b.replaced_id, b.id, b.obj)));\n                this.logImpressionIds([b.id,], this.BEEPER_REF);\n            }\n        ;\n        ;\n        }.bind(this))));\n        ((!this.useUnaggregatedBeeper && this.alertList.subscribe(NotificationList.REMOVAL_TYPE, function(a, b) {\n            this.beeper.removeBeep(b.id);\n        }.bind(this))));\n        ((this.useUnaggregatedBeeper && new LiveMessageReceiver(\"unaggregated_beep\").setAppId(this.BEEPER_APPID).setHandler(function(a) {\n            ((!this.isNotifJewelOpen() && this.beeper.fromMessage(a)));\n        }.bind(this)).register()));\n    },\n    _initNotifNegativeFeedback: function() {\n        this.notifXList = null;\n        this.notifXList = window.NotifXList;\n        this.notifXList.init(this);\n        this.alertList.setFilterFn(this.notifXList.filterStoreClicked);\n        Toggler.listen(\"hide\", $(this.wrapperID), function() {\n            for (var a in this.negativeNotifs) {\n                if (a) {\n                    ((((this.negativeNotifs[a] instanceof NegativeNotif)) && this.negativeNotifs[a].reset()));\n                }\n            ;\n            ;\n            };\n        ;\n        }.bind(this));\n        Arbiter.subscribe(\"notif/negativeCancel\", function(a, b) {\n            ((this.negativeNotifs[b.id] && this.negativeNotifs[b.id].restore()));\n        }.bind(this));\n        Arbiter.subscribe(\"notif/negativeConfirmed\", function(a, b) {\n            ((this.negativeNotifs[b.id] && this.negativeNotifs[b.id].JSBNG__onTurnedOff()));\n            this.alertList.toggleNotifsSimilarTo(b.id, true, true);\n            this._hideOverflow();\n            this._handleScroll();\n        }.bind(this));\n        Arbiter.subscribe(\"notif/negativeUndid\", function(a, b) {\n            ((this.negativeNotifs[b.id] && this.negativeNotifs[b.id].JSBNG__onUndid()));\n            this.alertList.toggleNotifsSimilarTo(b.id, false, true);\n            this._hideOverflow();\n        }.bind(this));\n        Arbiter.subscribe(\"notif/negativeMarkedSpam\", function(a, b) {\n            ((this.negativeNotifs[b.id] && this.negativeNotifs[b.id].JSBNG__onMarkedSpam()));\n        }.bind(this));\n        Arbiter.subscribe(\"notif/negativeFirstReceiptYes\", function(a, b) {\n            ((this.negativeNotifs[b.id] && this.negativeNotifs[b.id].JSBNG__onFirstReceiptYes()));\n            this.alertList.toggleNotifsSimilarTo(b.id, false, true);\n        }.bind(this));\n        Arbiter.subscribe(\"notif/negativeFirstReceiptNo\", function(a, b) {\n            ((this.negativeNotifs[b.id] && this.negativeNotifs[b.id].JSBNG__onFirstReceiptNo()));\n            this.alertList.toggleNotifsSimilarTo(b.id, false, true);\n        }.bind(this));\n        this.alertList.subscribe(NotificationList.INSERTION_TYPE, function(a, b) {\n            var c = DOM.scry(b.obj, \".notif_x\");\n            if (((c.length == 1))) {\n                this.negativeNotifs[b.id] = new NegativeNotif(this, b);\n            }\n        ;\n        ;\n            this._updateFirstReceipt(b);\n        }.bind(this));\n    },\n    _sendIDs: function(a, b, c) {\n        var d = ((c || {\n        }));\n        for (var e = 0; ((e < a.length)); ++e) {\n            d[((((\"alert_ids[\" + e)) + \"]\"))] = a[e];\n        ;\n        };\n    ;\n        new AsyncSignal(URI(b).getQualifiedURI().toString(), d).send();\n    },\n    _waitForFetch: function(a) {\n        return ((this.currentFetchRequest && this.fetchListeners.push(a.bind(this))));\n    },\n    _logImpression: function() {\n        var a = this.alertList.getIds();\n        if (((((a.length === 0)) && this._waitForFetch(this._logImpression)))) {\n            return;\n        }\n    ;\n    ;\n        this.logImpressionIds(a, this.NOTIF_JEWEL_REF);\n    },\n    logImpressionIds: function(a, b) {\n        ((this.shouldLogImpressions && this._sendIDs(a, \"/ajax/notifications/impression.php\", {\n            ref: b\n        })));\n    },\n    markRead: function(a, b) {\n        var c = !hasArrayNature(b);\n        b = ((c ? this.alertList.getUnseenIds() : b.filter(this.alertList.isUnreadId.bind(this.alertList))));\n        if (b.length) {\n            ((a && this._sendIDs(b, \"/ajax/notifications/mark_read.php\", {\n                seen: ((c ? 1 : 0))\n            })));\n            var d = a;\n            ((c ? this.alertList.markSeen(b) : this.alertList.markRead(b, d)));\n        }\n    ;\n    ;\n        ((c && this._waitForFetch(this.markRead.bind(this, a))));\n    },\n    markAllRead: function() {\n        var a = this.alertList.getUnreadIds();\n        this.markRead(true, a);\n    },\n    _updateErrorHandler: function(a) {\n    \n    },\n    _updateURI: \"/ajax/presence/update.php\",\n    _update: function(a) {\n        a.setHandler(this._handleUpdate.bind(this)).setOption(\"suppressErrorAlerts\", true).setErrorHandler(this._updateErrorHandler.bind(this)).setData({\n            notif_latest: this.latest_notif_time,\n            notif_latest_read: this.latest_read_notif_time\n        }).setURI(this._updateURI).setAllowCrossPageTransition(true);\n    },\n    _handleUpdate: function(a) {\n        var b = a.payload.notifications;\n        if (!b.no_change) {\n            this.updateTime = a.payload.time;\n            this.latest_notif_time = b.latest_notif;\n            this.latest_read_notif_time = b.latest_read_notif;\n            this._updateDisplayDelayed();\n            this.alertList.insertMany(b.notifications);\n        }\n    ;\n    ;\n    },\n    _updateDisplayDelayed: function() {\n        if (((typeof Beeper != \"undefined\"))) {\n            this.beepsExpiredToken = Arbiter.subscribe(Notifications.BEEPS_EXPIRED, this._updateDisplay.bind(this));\n        }\n         else this._updateDisplay();\n    ;\n    ;\n    },\n    _updateDisplay: function() {\n        if (!this.JSBNG__content) {\n            return;\n        }\n    ;\n    ;\n        this._updateCount();\n        if (this.beepsExpiredToken) {\n            this.beepsExpiredToken.unsubscribe();\n        }\n    ;\n    ;\n    },\n    _updateCount: function() {\n        Arbiter.inform(\"jewel/count-updated\", {\n            jewel: \"notifications\",\n            count: this.alertList.unseenCount\n        }, Arbiter.BEHAVIOR_STATE);\n        this._hideOverflow();\n    },\n    fetch: function(a) {\n        this._sendFetchRequest(a);\n    },\n    _getFetchQueryData: function() {\n        var a = {\n            time: this.latest_notif_time,\n            user: this.user,\n            version: this.cache_version,\n            locale: Env.locale\n        };\n        if (this.useInfiniteScroll) {\n            a.earliest_time = this.alertList.getEarliestNotifTime();\n        }\n    ;\n    ;\n        return a;\n    },\n    _sendFetchRequest: function(a) {\n        if (this.useInfiniteScroll) {\n            this._infiniteScrollNotif = null;\n            this._newDataFromInsert = false;\n            this._truncate = true;\n        }\n    ;\n    ;\n        var b = URI(\"/ajax/notifications/get.php\"), c = ((a || this.loadingIndicator));\n        if (this.currentFetchRequest) {\n            return true;\n        }\n    ;\n    ;\n        this.ua.add_event(\"fetch\");\n        b.setQueryData(this._getFetchQueryData());\n        this.currentFetchRequest = new AsyncRequest().setURI(b).setStatusElement(c).setMethod(\"GET\").setReadOnly(true).setTimeoutHandler(30000, this.fetchErrorHandler.bind(this)).setHandler(this.fetchHandler.bind(this)).setErrorHandler(this.fetchErrorHandler.bind(this)).setAllowCrossPageTransition(true);\n        ((!this.currentFetchRequest.send() && this.fetchErrorHandler()));\n        return true;\n    },\n    fetchErrorHandler: function(a) {\n        this.currentFetchRequest = null;\n        this.ua.add_event(\"fetch_error\");\n        ((this.useInfiniteScroll && this._updateScrollDataStructures()));\n    },\n    fetchHandler: function(a) {\n        this.ua.add_event(\"fetch_success\");\n        var b = a.getPayload();\n        this.alertList.insertMany(b.notifications, true);\n        ((this.loadingIndicator && CSS.hide(this.loadingIndicator)));\n        this.loadingIndicator = null;\n        this.currentFetchRequest = null;\n        this.fetch = bagofholding;\n        if (this.fetchListeners) {\n            for (var c = 0; ((c < this.fetchListeners.length)); c++) {\n                this.fetchListeners[c]();\n            ;\n            };\n        ;\n            this.fetchListeners = [];\n        }\n    ;\n    ;\n        ((window.ArbiterMonitor && Arbiter.inform(\"notifs/fetched\", \"\", Arbiter.BEHAVIOR_STATE)));\n        var d = b.generated, e = Math.round((((new JSBNG__Date()).getTime() / 1000)));\n        if (((((e - d)) > 15))) {\n            d = e;\n        }\n    ;\n    ;\n        Bootloader.loadComponents(\"live-timer\", function() {\n            LiveTimer.restart(d);\n            LiveTimer.startLoop(0);\n        });\n        if (this.useInfiniteScroll) {\n            if (((is_empty(b.notifications) || !this._newDataFromInsert))) {\n                this._noMoreNotifications();\n            }\n             else CSS.show(this._morePager);\n        ;\n        ;\n            this._updateScrollDataStructures();\n            if (((this.isNotifJewelOpen() && this.afterFirstFetch))) {\n                this.animate = true;\n            }\n        ;\n        ;\n            this.afterFirstFetch = true;\n        }\n    ;\n    ;\n        this._hideOverflow();\n    },\n    _noMoreNotifications: function() {\n        CSS.hide(this._morePager);\n        this.useInfiniteScroll = false;\n    },\n    _mergeNotification: function(a, b, c, d) {\n        var e = !this.alertList.isUnreadId(a);\n        this.alertList.insert(a, b, c, true, null, ((d || null)));\n        this.latest_notif_time = 0;\n        if (e) {\n            this._updateCount();\n        }\n    ;\n    ;\n        var f = this.alertList.getDomObj(a);\n        if (f) {\n            Bootloader.loadComponents(\"live-timer\", function() {\n                LiveTimer.addTimeStamps(f);\n            });\n        }\n    ;\n    ;\n    },\n    _handleNotificationMsg: function(a, b) {\n        var c = b.obj;\n        if (((typeof this.useDesktopNotifications == \"undefined\"))) {\n            var d;\n            this.useDesktopNotifications = ((((this.allowDesktopNotifications && window.JSBNG__webkitNotifications)) && ((window.JSBNG__webkitNotifications.checkPermission() === 0))));\n        }\n    ;\n    ;\n        if (this.useDesktopNotifications) {\n            Bootloader.loadComponents(\"desktop-notifications\", function() {\n                DesktopNotifications.addNotification(c.alert_id);\n            });\n        }\n    ;\n    ;\n        if (c.markup) {\n            this._mergeNotification(c.alert_id, c.time, c.markup, ((c.alt_id || null)));\n            requireLazy([\"NotificationSound\",], function(e) {\n                if (((this._notifSound === null))) {\n                    this._notifSound = new e(this.receiveSoundPath);\n                }\n            ;\n            ;\n                this._notifSound.play();\n            }.bind(this));\n        }\n         else this._poller.requestNow();\n    ;\n    ;\n    },\n    _handleNotificationsReadMsg: function(a, b) {\n        var c = b.obj;\n        if (((typeof Beeper != \"undefined\"))) {\n            Beeper.getInstance().markRead(false, c.alert_ids);\n        }\n    ;\n    ;\n        this.markRead(false, c.alert_ids);\n        ((this.beeper && this.beeper.fadeOutBeeps(b.obj.alert_ids)));\n    },\n    _handleNotificationsSeenMsg: function(a, b) {\n        if (!this.unseenVsUnread) {\n            this._handleNotificationsReadMsg(a, b);\n            return;\n        }\n    ;\n    ;\n        var c = b.obj;\n        if (((typeof Beeper != \"undefined\"))) {\n            Beeper.getInstance().markRead(false, c.alert_ids);\n        }\n    ;\n    ;\n        this.alertList.markSeen(c.alert_ids);\n        ((this.beeper && this.beeper.fadeOutBeeps(b.obj.alert_ids)));\n    },\n    _hideOverflow: function() {\n        if (!this.isNotifJewelOpen()) {\n            return;\n        }\n    ;\n    ;\n        var a = DOM.scry($(\"fbNotificationsList\"), \".notification\");\n        this.scrollableAreaNode = ((this.scrollableAreaNode || DOM.scry(this.jewelFlyout, \".uiScrollableArea\")[0]));\n        var b = 20, c = ((CSS.hasClass(JSBNG__document.documentElement, \"tinyViewport\") && !CSS.hasClass(JSBNG__document.body, \"fixedBody\")));\n        if (((!a.length || c))) {\n            Style.set(this.scrollableAreaNode, \"height\", \"100%\");\n            this.notifLogger.rate(this.SCROLL_OFF_TINY, c);\n            return;\n        }\n    ;\n    ;\n        var d = ((this.scrollableAreaNode || a[0])), e = ((((((Vector2.getViewportDimensions().y - Vector2.getElementPosition(d, \"viewport\").y)) - Vector2.getElementDimensions(this.footer).y)) - 5)), f = e, g = 0;\n        for (; ((((g < a.length)) && ((f > 0)))); ++g) {\n            if (CSS.shown(a[g])) {\n                f -= Vector2.getElementDimensions(a[g]).y;\n            }\n        ;\n        ;\n        };\n    ;\n        var h = 530, i = Math.min(h, ((e - Math.max(f, 0))));\n        if (((((f >= 0)) && ((i < h))))) {\n            if (((!this.useInfiniteScroll || ((this.beeper && this.beeper.hasBeeps()))))) {\n                i = \"100%\";\n            }\n             else {\n                if (((this._truncate && ((a.length >= 5))))) {\n                    i -= b;\n                }\n            ;\n            ;\n                i += \"px\";\n            }\n        ;\n        ;\n        }\n         else i += \"px\";\n    ;\n    ;\n        if (((((this.useInfiniteScroll && this.animate)) && ((i != \"100%\"))))) {\n            ((this.animation && this.animation.JSBNG__stop()));\n            this.animation = animation(this.scrollableAreaNode).to(\"height\", i).duration(200).go();\n        }\n         else {\n            var j = ScrollableArea.getInstance(this.scrollableAreaNode);\n            ((j && j.showScrollbar.bind(j).defer()));\n            Style.set(this.scrollableAreaNode, \"height\", i);\n        }\n    ;\n    ;\n    },\n    _updateFirstReceipt: function(a) {\n        var b = a.obj.getAttribute(\"data-appid\"), c = DOM.scry(a.obj, \".first_receipt_div\");\n        if (((b && ((c.length == 1))))) {\n            if (this.firstReceiptMap[b]) {\n                if (((((a.id != this.firstReceiptMap[b].id)) && ((this.firstReceiptMap[b].time > a.time))))) {\n                    return;\n                }\n            ;\n            ;\n                CSS.removeClass(this.firstReceiptMap[b].obj, \"first_receipt\");\n            }\n        ;\n        ;\n            this.firstReceiptMap[b] = a;\n            CSS.addClass(a.obj, \"first_receipt\");\n        }\n    ;\n    ;\n    },\n    isNotifJewelOpen: function() {\n        return ((Toggler.getInstance(this.wrapper).getActive() === this.wrapper));\n    }\n});\nvar OriginalNotifications = Notifications;\n__d(\"legacy:notif-beeper\", [\"NotifBeeper\",], function(a, b, c, d) {\n    a.NotifBeeper = b(\"NotifBeeper\");\n}, 3);\n__d(\"PagesVoiceBar\", [\"$\",\"Arbiter\",\"AsyncRequest\",\"CSS\",\"ChannelConstants\",\"DOM\",\"PageTransitions\",], function(a, b, c, d, e, f) {\n    var g = b(\"$\"), h = b(\"Arbiter\"), i = b(\"AsyncRequest\"), j = b(\"CSS\"), k = b(\"ChannelConstants\"), l = b(\"DOM\"), m = b(\"PageTransitions\"), n = \"PagesVoiceBar/toggle\", o = \"PagesVoiceBar/initialized\", p = \"PagesVoiceBar/switchVoice\", q = \"page_transition\", r = \"pages_voice_bar_sync\", s = null, t = null, u = false, v = false;\n    function w() {\n        v = !v;\n        j.conditionClass(JSBNG__document.body, \"hasVoiceBar\", v);\n    };\n;\n    function x(da, ea) {\n        new i(\"/ajax/pages/switch_voice.php\").setData(ea).setHandler(function(fa) {\n            ba();\n        }).send();\n    };\n;\n    function y() {\n        s = null;\n    };\n;\n    function z(da, ea) {\n        if (((ea.obj.profile_id && ((ea.obj.profile_id == s))))) {\n            ba();\n        }\n    ;\n    ;\n    };\n;\n    function aa(da) {\n        h.subscribe(o, da);\n    };\n;\n    function ba() {\n        m.getNextURI().go();\n    };\n;\n    var ca = {\n        initVoiceBar: function() {\n            if (u) {\n                return;\n            }\n        ;\n        ;\n            t = g(\"pagesVoiceBarContent\");\n            v = j.hasClass(JSBNG__document.body, \"hasVoiceBar\");\n            h.subscribe(n, w);\n            h.subscribe(p, x);\n            h.subscribe(q, y);\n            h.subscribe(k.getArbiterType(r), z);\n            u = true;\n            h.inform(o, null, h.BEHAVIOR_STATE);\n        },\n        update: function(da, ea) {\n            aa(function() {\n                s = ea;\n                l.setContent(t, da);\n            });\n        }\n    };\n    e.exports = ca;\n});\n__d(\"TypeaheadSearchSponsored\", [\"event-extensions\",\"Arbiter\",\"CSS\",\"DOM\",\"URI\",\"copyProperties\",\"tx\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"URI\"), k = b(\"copyProperties\"), l = b(\"tx\");\n    function m(n) {\n        this._typeahead = n;\n    };\n;\n    m.auctionOptions = {\n        rerankingStrategy: 4,\n        neverRerankToTop1: true,\n        minQueryLengthForTopResult: 2,\n        minBootstrapScoreForTopResult: 0,\n        maxNumberAds: 3,\n        maxNumberRemovedResults: 2,\n        maxNumberResultsAndAds: 8,\n        debug: false\n    };\n    m.query = null;\n    m.needTopResult = function(n, o, p) {\n        if (((p.rerankingStrategy == 5))) {\n            return ((n.type != \"user\"));\n        }\n    ;\n    ;\n        if (((p.rerankingStrategy != 4))) {\n            return false;\n        }\n    ;\n    ;\n        if (((o == null))) {\n            return false;\n        }\n    ;\n    ;\n        if (((o.length < p.minQueryLengthForTopResult))) {\n            return false;\n        }\n    ;\n    ;\n        if (((n == null))) {\n            return false;\n        }\n    ;\n    ;\n        if (!n.bootstrapped) {\n            return false;\n        }\n    ;\n    ;\n        if (((n.index == null))) {\n            return false;\n        }\n    ;\n    ;\n        if (((n.index >= p.minBootstrapScoreForTopResult))) {\n            return false;\n        }\n    ;\n    ;\n        if (((n.type == \"user\"))) {\n            return false;\n        }\n    ;\n    ;\n        return true;\n    };\n    m.getOriginalOrganics = function(n) {\n        return n.map(function(o) {\n            return {\n                uid: o.uid,\n                text: o.text,\n                type: m.getRealType(o),\n                source: ((o.bootstrapped ? 1 : 0)),\n                index: o.index\n            };\n        });\n    };\n    m.setDebugString = function(n, o) {\n        if (!m.auctionOptions.debug) {\n            return;\n        }\n    ;\n    ;\n        n.debug_string = o;\n    };\n    m.runAuction = function(n, o, p, q) {\n        n = n.slice(0, q.maxNumberResultsAndAds);\n        if (((n.length === 0))) {\n            return n;\n        }\n    ;\n    ;\n        n = m.initResults(n);\n        if (m.needTopResult(n[0], m.query, q)) {\n            n[0].renderTypeOverride = true;\n            n[0].orig_render_type = n[0].render_type;\n            n[0].render_type = \"tophit\";\n        }\n    ;\n    ;\n        if (!o) {\n            var r = m.bucketResults(n);\n            return r.results;\n        }\n    ;\n    ;\n        var s = m.prepareAndSortAds(n, o, p), t = m.selectAds(n, s, q), u = 0;\n        for (var v = 0; ((v < t.length)); ++v) {\n            if (((t[v].s_target != t[v].uid))) {\n                u++;\n            }\n        ;\n        ;\n        };\n    ;\n        n = n.slice(0, ((q.maxNumberResultsAndAds - u)));\n        var w = m.bucketResults(n), x = m.rerankAds(w.results, t, w.buckets, q);\n        return x;\n    };\n    m.bucketResults = function(n) {\n        var o, p, q, r, s = [], t = {\n        };\n        p = n.length;\n        for (o = 0; ((o < p)); o++) {\n            q = n[o];\n            r = ((q.render_type || q.type));\n            if (!t.hasOwnProperty(r)) {\n                t[r] = s.length;\n                s.push([]);\n            }\n        ;\n        ;\n            s[t[r]].push(q);\n        };\n    ;\n        var u = [], v = {\n        };\n        p = s.length;\n        for (o = 0; ((o < p)); ++o) {\n            q = s[o][0];\n            r = ((q.render_type || q.type));\n            v[r] = u.length;\n            u = u.concat(s[o]);\n        };\n    ;\n        return {\n            results: u,\n            buckets: v\n        };\n    };\n    m.prepareAndSortAds = function(n, o, p) {\n        if (!o) {\n            return [];\n        }\n    ;\n    ;\n        var q = [], r = n.length;\n        for (var s = 0; ((s < r)); s++) {\n            var t = n[s];\n            if (o[t.uid]) {\n                for (var u in o[t.uid]) {\n                    var v = o[t.uid][u];\n                    if (((p && p.hasOwnProperty(v.uid)))) {\n                        continue;\n                    }\n                ;\n                ;\n                    q.push(v);\n                };\n            }\n        ;\n        ;\n        };\n    ;\n        q.sort(function(w, x) {\n            return ((x.s_value - w.s_value));\n        });\n        return q;\n    };\n    m.selectAds = function(n, o, p) {\n        var q = Math.min(p.maxNumberAds, ((((p.maxNumberRemovedResults + p.maxNumberResultsAndAds)) - n.length))), r = [], s = {\n        }, t = n.map(function(ca) {\n            return String(ca.uid);\n        }), u = {\n        }, v = {\n        }, w = -1, x = false, y = 0;\n        for (var z = 0; ((z < o.length)); z++) {\n            if (((r.length >= q))) {\n                for (var aa = z; ((aa < o.length)); aa++) {\n                    m.setDebugString(o[aa], ((((\"filtered: \" + q)) + \" ads already selected\")));\n                ;\n                };\n            ;\n                break;\n            }\n        ;\n        ;\n            while (((((y + t.length)) >= p.maxNumberResultsAndAds))) {\n                w = t.pop();\n            ;\n            };\n        ;\n            if (u.hasOwnProperty(w)) {\n                x = true;\n            }\n        ;\n        ;\n            var ba = o[z];\n            if (((x && ((ba.s_target != ba.uid))))) {\n                m.setDebugString(ba, ((((\"filtered: last organic \" + w)) + \" is targeted\")));\n                continue;\n            }\n        ;\n        ;\n            if (((((ba.s_target != ba.uid)) && ((t.indexOf(String(ba.uid)) != -1))))) {\n                m.setDebugString(ba, ((((((\"filtered: organic \" + ba.uid)) + \" targets another organic \")) + ba.s_target)));\n                continue;\n            }\n        ;\n        ;\n            if (s.hasOwnProperty(ba.s_account)) {\n                m.setDebugString(ba, ((((\"filtered: ad account \" + ba.s_account)) + \" already selected\")));\n                continue;\n            }\n        ;\n        ;\n            if (v.hasOwnProperty(ba.uid)) {\n                m.setDebugString(ba, ((((\"filtered: ad promoted id \" + ba.uid)) + \" already selected\")));\n                continue;\n            }\n        ;\n        ;\n            if (((t.indexOf(String(ba.s_target)) == -1))) {\n                if (((((ba.s_target != ba.uid)) || ((ba.s_target != w))))) {\n                    m.setDebugString(ba, ((((((((((((\"filtered: targeted organic \" + ba.s_target)) + \" will go away \")) + \"promoted id \")) + ba.uid)) + \" last organic \")) + w)));\n                    continue;\n                }\n            ;\n            }\n        ;\n        ;\n            m.setDebugString(ba, \"selected\");\n            r.push(ba);\n            s[ba.s_account] = true;\n            u[ba.s_target] = true;\n            v[ba.uid] = true;\n            if (((ba.s_target != ba.uid))) {\n                ++y;\n            }\n        ;\n        ;\n        };\n    ;\n        return r;\n    };\n    m.finalizeAd = function(n, o, p) {\n        var q = \"Sponsored\";\n        n.rankType = ((((n.rankType || n.render_type)) || n.type));\n        if (((n.s_target == n.uid))) {\n            o.s_token = n.s_token;\n            o.message = n.s_message;\n            if (((p.rerankingStrategy === 0))) {\n                o.subtextOverride = ((o.subtext ? ((((o.subtext + \" \\u00b7 \")) + q)) : q));\n            }\n        ;\n        ;\n            if (n.path) {\n                o.pathOverride = true;\n                o.orig_path = o.path;\n                o.path = n.path;\n            }\n        ;\n        ;\n            o.is_self = true;\n        }\n         else {\n            n.message = n.s_message;\n            n.subtextOverride = null;\n            if (((p.rerankingStrategy === 0))) {\n                n.subtextOverride = ((n.subtext ? ((((n.subtext + \" \\u00b7 \")) + q)) : q));\n            }\n        ;\n        ;\n            if (p.debug) {\n                if (((!n.subtextOverride && n.subtext))) {\n                    n.subtextOverride = n.subtext;\n                }\n            ;\n            ;\n                if (n.subtextOverride) {\n                    n.subtextOverride += ((((\" \\u00b7 (Debug: \" + o.text)) + \")\"));\n                }\n                 else n.subtextOverride = ((((\"(Debug: \" + o.text)) + \")\"));\n            ;\n            ;\n            }\n        ;\n        ;\n            n.type = o.type;\n            n.render_type = o.render_type;\n            n.is_self = false;\n        }\n    ;\n    ;\n    };\n    m.buildResultIndices = function(n) {\n        var o = {\n        }, p = n.length;\n        for (var q = 0; ((q < p)); q++) {\n            o[n[q].uid] = q;\n        ;\n        };\n    ;\n        return o;\n    };\n    m.rerankMethod0 = function(n, o, p, q) {\n        var r = m.buildResultIndices(n);\n        for (var s = ((o.length - 1)); ((s >= 0)); s--) {\n            var t = o[s], u = r[t.s_target], v = n[u];\n            m.finalizeAd(t, v, q);\n            var w = false;\n            if (((t.uid == t.s_target))) {\n                w = m.promoteSelfPromotedResult(n, u, p, q);\n            }\n             else {\n                m.insertAdToTopOfSection(n, v, p, t, q);\n                w = true;\n            }\n        ;\n        ;\n            if (w) {\n                r = m.buildResultIndices(n);\n            }\n        ;\n        ;\n        };\n    ;\n    };\n    m.promoteSelfPromotedResult = function(n, o, p, q) {\n        var r = n[o], s = ((r.render_type || r.type)), t = p[s];\n        if (((q.neverRerankToTop1 && ((t === 0))))) {\n            t = 1;\n        }\n    ;\n    ;\n        var u = false;\n        if (((o > t))) {\n            n.splice(t, 0, n.splice(o, 1)[0]);\n            u = true;\n        }\n    ;\n    ;\n        return u;\n    };\n    m.promoteSelfPromotedResultToTop = function(n, o, p, q) {\n        var r = n[o];\n        if (((o < p))) {\n            var s = \"Sponsored\";\n            r.subtextOverride = ((r.subtext ? ((((r.subtext + \" \\u00b7 \")) + s)) : s));\n            return;\n        }\n    ;\n    ;\n        if (((o > p))) {\n            n.splice(p, 0, n.splice(o, 1)[0]);\n        }\n    ;\n    ;\n        r = n[p];\n        r.renderTypeOverride = true;\n        r.orig_render_type = r.render_type;\n        r.render_type = \"ownsection\";\n    };\n    m.insertAdToTopOfSection = function(n, o, p, q, r) {\n        var s = ((o.render_type || o.type)), t = p[s];\n        if (((r.neverRerankToTop1 && ((t === 0))))) {\n            t = 1;\n        }\n    ;\n    ;\n        n.splice(t, 0, q);\n        t = p[s];\n        for (var u in p) {\n            if (((p[u] > t))) {\n                p[u] += 1;\n            }\n        ;\n        ;\n        };\n    ;\n    };\n    m.insertAdToTop = function(n, o, p, q) {\n        n.splice(p, 0, o);\n        o.render_type = \"ownsection\";\n    };\n    m.getTopAdPosition = function(n) {\n        if (((n.length < 1))) {\n            return null;\n        }\n    ;\n    ;\n        var o = ((n[0].render_type || n[0].type));\n        if (((o == \"tophit\"))) {\n            return 1;\n        }\n    ;\n    ;\n        if (((o == \"user\"))) {\n            for (var p = 1; ((p < n.length)); ++p) {\n                o = ((n[p].render_type || n[p].type));\n                if (((o != \"user\"))) {\n                    return p;\n                }\n            ;\n            ;\n            };\n        ;\n            return n.length;\n        }\n    ;\n    ;\n        return 0;\n    };\n    m.rerankMethod345 = function(n, o, p) {\n        var q = 0;\n        if (((((p.rerankingStrategy == 4)) || ((p.rerankingStrategy == 5))))) {\n            q = m.getTopAdPosition(n);\n        }\n    ;\n    ;\n        var r = m.buildResultIndices(n);\n        for (var s = ((o.length - 1)); ((s >= 0)); s--) {\n            var t = o[s], u = r[t.s_target], v = n[u];\n            m.finalizeAd(t, v, p);\n            if (((t.uid == t.s_target))) {\n                m.promoteSelfPromotedResultToTop(n, u, q, p);\n            }\n             else m.insertAdToTop(n, t, q, p);\n        ;\n        ;\n            r = m.buildResultIndices(n);\n        };\n    ;\n    };\n    m.rerankAds = function(n, o, p, q) {\n        switch (q.rerankingStrategy) {\n          case 0:\n            m.rerankMethod0(n, o, p, q);\n            break;\n          case 3:\n        \n          case 4:\n        \n          case 5:\n            m.rerankMethod345(n, o, q);\n            break;\n          default:\n            break;\n        };\n    ;\n        return n.slice(0, q.maxNumberResultsAndAds);\n    };\n    m.initResults = function(n) {\n        var o = n.length;\n        for (var p = 0; ((p < o)); p++) {\n            var q = n[p];\n            q.is_self = null;\n            q.s_token = null;\n            q.message = null;\n            q.subtextOverride = null;\n            if (q.pathOverride) {\n                q.path = q.orig_path;\n                q.pathOverride = false;\n            }\n        ;\n        ;\n            if (q.renderTypeOverride) {\n                q.render_type = q.orig_render_type;\n                q.renderTypeOverride = false;\n            }\n        ;\n        ;\n            q.rankType = ((((q.rankType || q.render_type)) || q.type));\n        };\n    ;\n        return n;\n    };\n    m.setAuctionOptions = function(n) {\n        for (var o in n) {\n            m.auctionOptions[o] = n[o];\n        ;\n        };\n    ;\n    };\n    m.getRealType = function(n) {\n        if (n.renderTypeOverride) {\n            return ((n.orig_render_type || n.type));\n        }\n    ;\n    ;\n        return ((n.render_type || n.type));\n    };\n    m.hideAdResult = function(n, o) {\n        g.inform(\"TypeaheadSearchSponsored/hideAdResult\", {\n            uid: n,\n            reason_dialog: o\n        });\n    };\n    m.undoHideAdResult = function(n) {\n        g.inform(\"TypeaheadSearchSponsored/undoHideAdResult\", {\n            uid: n\n        });\n    };\n    k(m.prototype, {\n        _dataSubscriptions: null,\n        _viewSubscriptions: null,\n        _globalSubscriptions: null,\n        _data: null,\n        _view: null,\n        _sponsoredEntries: null,\n        _hiddenSponsoredEntities: null,\n        _hideReasonDialog: null,\n        _debugData: null,\n        _sBootstrapID: null,\n        enable: function() {\n            this._data = this._typeahead.getData();\n            this._dataSubscriptions = [this._data.subscribe(\"beginFetchHandler\", function(n, o) {\n                var p = o.response.getPayload();\n                if (p.s_entries) {\n                    this._sponsoredEntries = ((this._sponsoredEntries || {\n                    }));\n                    var q = p.s_entries.length;\n                    for (var r = 0; ((r < q)); r++) {\n                        var s = p.s_entries[r], t = s.s_target;\n                        if (!this._sponsoredEntries[t]) {\n                            this._sponsoredEntries[t] = {\n                            };\n                        }\n                    ;\n                    ;\n                        this._sponsoredEntries[t][s.uid] = s;\n                    };\n                ;\n                    if (p.s_bootstrap_id) {\n                        this._sBootstrapID = p.s_bootstrap_id;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            }.bind(this)),this._data.subscribe(\"JSBNG__onload\", function(n, o) {\n                var p = k(this.bootstrapData, {\n                    no_cache: 1,\n                    options: [\"sponsored\",]\n                });\n                this.fetch(this.bootstrapEndpoint, p, {\n                    type: \"sponsored\"\n                });\n            }.bind(this._data)),];\n            this._view = this._typeahead.getView();\n            this._viewSubscriptions = [this._view.subscribe(\"finalResultsReordering\", function(n, o) {\n                m.query = o.value;\n                var p = m.getOriginalOrganics(o.results);\n                m.setAuctionOptions({\n                    maxNumberResultsAndAds: ((((this._data && this._data._maxResults)) || 8))\n                });\n                var q = m.runAuction(o.results, this._sponsoredEntries, this._hiddenSponsoredEntities, m.auctionOptions), r = m.prepareAndSortAds(o.results, this._sponsoredEntries, this._hiddenSponsoredEntities), s = r.map(function(y) {\n                    return y.s_token;\n                }), t = [];\n                for (var u = 0; ((u < q.length)); u++) {\n                    var v = q[u];\n                    if (v.s_token) {\n                        t.push({\n                            position: u,\n                            is_self: v.is_self\n                        });\n                    }\n                ;\n                ;\n                };\n            ;\n                this._view.inform(\"recordAfterReorder\", {\n                    organic: p,\n                    tokens: s,\n                    position_data: t,\n                    s_bootstrap_id: this._sBootstrapID,\n                    options: m.auctionOptions,\n                    variant: m.auctionOptions.rerankingStrategy\n                });\n                if (m.auctionOptions.debug) {\n                    var w = r.map(function(y) {\n                        return {\n                            s_token: y.s_token,\n                            s_account: y.s_account,\n                            uid: y.uid,\n                            promoted_text: ((y.text || \"SELF_PROMOTED\")),\n                            s_target: y.s_target,\n                            target_text: \"PLACEHOLDER\",\n                            s_value: y.s_value,\n                            debug_string: y.debug_string,\n                            source: ((y.bootstrapped ? 1 : 0))\n                        };\n                    }), x = q.map(function(y) {\n                        return {\n                            uid: y.uid,\n                            text: y.text,\n                            s_token: y.s_token,\n                            is_ad: ((y.s_token ? \"true\" : \"false\"))\n                        };\n                    });\n                    this._debugData = {\n                        options: m.auctionOptions,\n                        query: o.value,\n                        results: x,\n                        original_organic: p,\n                        ads_in_auction: w\n                    };\n                }\n            ;\n            ;\n                o.results = q;\n            }.bind(this)),this._view.subscribe(\"highlight\", function(n, o) {\n                if (this._view.JSBNG__content) {\n                    i.scry(this._view.JSBNG__content, \"a.report\").forEach(h.hide);\n                }\n            ;\n            ;\n                if (((((!o.element || !o.selected)) || !o.selected.s_token))) {\n                    return;\n                }\n            ;\n            ;\n                var p = i.scry(o.element, \"a.report\");\n                if (p.length) {\n                    h.show(p[0]);\n                }\n                 else i.appendContent(o.element, this._createHideAdLink(o.selected));\n            ;\n            ;\n            }.bind(this)),];\n            if (m.auctionOptions.debug) {\n                this._viewSubscriptions.push(this._view.subscribe(\"render\", function(n, o) {\n                    var p = new j(\"/ads/debug/search_ads_debug.php\").addQueryData(this._debugData).toString(), q = {\n                        rel: \"dialog-post\",\n                        href: \"#\",\n                        ajaxify: p\n                    }, r = i.create(\"div\", {\n                        className: \"debug\"\n                    }, [i.create(\"a\", q, [i.create(\"span\", {\n                    }, [\"Click to debug\",]),]),]);\n                    JSBNG__Event.listen(r, \"mouseup\", function() {\n                        this._view.index = -1;\n                    }.bind(this));\n                    i.appendContent(this._view.JSBNG__content, r);\n                }.bind(this)));\n            }\n        ;\n        ;\n            this._globalSubscriptions = [g.subscribe(\"TypeaheadSearchSponsored/hideAdResult\", function(n, o) {\n                this._hiddenSponsoredEntities = ((this._hiddenSponsoredEntities || {\n                }));\n                this._hiddenSponsoredEntities[o.uid] = true;\n                this._hideReasonDialog = o.reason_dialog;\n                this._forceRefreshResults();\n            }.bind(this)),g.subscribe(\"TypeaheadSearchSponsored/undoHideAdResult\", function(n, o) {\n                if (this._hiddenSponsoredEntities) {\n                    delete this._hiddenSponsoredEntities[o.uid];\n                }\n            ;\n            ;\n                if (this._hideReasonDialog) {\n                    this._hideReasonDialog.hide();\n                    this._hideReasonDialog = null;\n                }\n            ;\n            ;\n                this._forceRefreshResults();\n            }.bind(this)),];\n        },\n        disable: function() {\n            this._dataSubscriptions.forEach(this._data.unsubscribe.bind(this._data));\n            this._dataSubscriptions = null;\n            this._viewSubscriptions.forEach(this._view.unsubscribe.bind(this._view));\n            this._viewSubscriptions = null;\n            this._globalSubscriptions.forEach(g.unsubscribe.bind(g));\n            this._globalSubscriptions = null;\n            this._data = null;\n            this._view = null;\n            this._sponsoredEntries = null;\n        },\n        _forceRefreshResults: function() {\n            if (((this._data && this._data.value))) {\n                this._data.respond(this._data.value, this._data.buildUids(this._data.value));\n            }\n        ;\n        ;\n        },\n        _createHideAdLink: function(n) {\n            var o = new j(\"/ajax/emu/end.php\").addQueryData({\n                eid: n.s_token,\n                f: 0,\n                ui: n.s_token,\n                en: \"fad_hide\",\n                ed: \"true\",\n                a: 1\n            }).toString(), p = {\n                className: \"report\",\n                rel: \"dialog-post\",\n                href: \"#\",\n                ajaxify: o,\n                title: \"Hide the ad\"\n            }, q = i.create(\"a\", p);\n            JSBNG__Event.listen(q, \"mouseover\", function(JSBNG__event) {\n                this._view.index = -1;\n                this._view.highlight(-1, false);\n                JSBNG__event.kill();\n            }.bind(this));\n            return q;\n        }\n    });\n    e.exports = m;\n});\n__d(\"legacy:SearchSponsoredTypeaheadBehavior\", [\"TypeaheadSearchSponsored\",], function(a, b, c, d) {\n    var e = b(\"TypeaheadSearchSponsored\");\n    if (!a.TypeaheadBehaviors) {\n        a.TypeaheadBehaviors = {\n        };\n    }\n;\n;\n    a.TypeaheadBehaviors.searchSponsored = function(f) {\n        f.enableBehavior(e);\n    };\n}, 3);\n__d(\"SearchDataSource\", [\"event-extensions\",\"Arbiter\",\"AsyncResponse\",\"Class\",\"DataSource\",\"copyProperties\",\"createArrayFrom\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"AsyncResponse\"), i = b(\"Class\"), j = b(\"DataSource\"), k = b(\"copyProperties\"), l = b(\"createArrayFrom\");\n    function m(n) {\n        this._token = ((n.token || \"\"));\n        this._lazyonload = ((((n.lazyonload === false)) ? false : true));\n        this._extraTypes = n.extraTypes;\n        this._buckets = n.buckets;\n        this._noMultiFetch = ((n.noMultiFetch || false));\n        var o = ((n.maxResults || 8));\n        this.parent.construct(this, n);\n        this._numResults = {\n            min: 3,\n            max: o\n        };\n        this._minWebSugg = ((n.minWebSugg || 1));\n        this._genTime = n.genTime;\n    };\n;\n    i.extend(m, j);\n    k(m.prototype, {\n        init: function() {\n            this.parent.init();\n            this._leanPayload = null;\n            this._bootstrapRequestsPending = 0;\n            this._criticalOnly = true;\n            this._updateMaxResults();\n            JSBNG__Event.listen(window, \"resize\", this._updateMaxResults.bind(this));\n        },\n        dirty: function() {\n            this.parent.dirty();\n            this._fetchOnUseRequests = [];\n        },\n        asyncErrorHandler: function(n) {\n            if (((((window.Dialog && ((window.Dialog.getCurrent() == null)))) && ((n.getError() == 1400003))))) {\n                h.verboseErrorHandler(n);\n            }\n        ;\n        ;\n        },\n        fetch: function(n, o, p) {\n            p = ((p || {\n            }));\n            p.fetch_start = JSBNG__Date.now();\n            this.parent.fetch(n, o, p);\n        },\n        fetchHandler: function(n, o) {\n            var p = n.getPayload(), q = k({\n                fetch_end: JSBNG__Date.now()\n            }, o), r = ((q.value ? g.BEHAVIOR_EVENT : g.BEHAVIOR_PERSISTENT));\n            this.inform(\"beginFetchHandler\", {\n                response: n\n            });\n            if (((o.type == \"lean\"))) {\n                this._leanPayload = p;\n                this._processLean();\n            }\n             else {\n                if (p.coeff2_ts) {\n                    q.coeff2_ts = p.coeff2_ts;\n                }\n            ;\n            ;\n                this.parent.fetchHandler(n, o);\n                if (((o.bootstrap && !n.getRequest().getData().no_cache))) {\n                    q.browserCacheHit = ((p.timestamp < this._genTime));\n                }\n            ;\n            ;\n                if (((((o.bootstrap && !p.no_data)) && ((this._bootstrapRequestsPending > 0))))) {\n                    o.bootstrap = false;\n                    --this._bootstrapRequestsPending;\n                    ((!this._bootstrapRequestsPending && this._bootstrapPostProcess()));\n                }\n            ;\n            ;\n                if (((p.no_data || ((p.token !== this._token))))) {\n                    var s = k({\n                    }, n.getRequest().getData());\n                    if (s.lazy) {\n                        delete s.lazy;\n                        s.token = this._token;\n                        this._fetchOnUse(s, o);\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            this.inform(\"endpointStats\", q, r);\n        },\n        buildData: function(n) {\n            var o = [], p = [], q = Math.min(n.length, ((this._maxResults + this._minWebSugg)));\n            for (var r = 0; ((r < q)); r++) {\n                var s = this.getEntry(n[r]);\n                if (((s.type === \"websuggestion\"))) {\n                    o.push(s);\n                }\n                 else p.push(s);\n            ;\n            ;\n            };\n        ;\n            if (((p.length >= this._maxResults))) {\n                return p.slice(0, this._maxResults);\n            }\n        ;\n        ;\n            return p.concat(o.slice(0, Math.max(((this._maxResults - p.length)), this._minWebSugg)));\n        },\n        _bootstrapPostProcess: function() {\n            var n = {\n                time: JSBNG__Date.now()\n            };\n            this.inform(\"bootstrapped\", n, g.BEHAVIOR_PERSISTENT);\n            this._processLean();\n        },\n        _processLean: function() {\n            if (this._leanPayload) {\n                var n, o = this._leanPayload.entries;\n                for (var p in o) {\n                    n = this.getEntry(p);\n                    ((n && (n.index = o[p])));\n                };\n            ;\n                this.setExclusions(this._leanPayload.blocked);\n                this._leanPayload = null;\n            }\n        ;\n        ;\n        },\n        _updateMaxResults: function() {\n            var n = ((window.JSBNG__innerHeight || JSBNG__document.documentElement.clientHeight));\n            this.setMaxResults(Math.max(this._numResults.min, Math.min(this._numResults.max, Math.ceil(((2 + ((((n - 370)) / 56))))))));\n        },\n        _bootstrapFetch: function(n, o) {\n            var p = k(o, this.bootstrapData);\n            if (((this._criticalOnly && this._lazyonload))) {\n                p.lazy = 1;\n            }\n        ;\n        ;\n            this.fetch(this.bootstrapEndpoint, p, {\n                bootstrap: true,\n                type: n\n            });\n            ++this._bootstrapRequestsPending;\n        },\n        _fetchOnUse: function(n, o) {\n            for (var p in this.bootstrapData) {\n                ((!n.hasOwnProperty(p) && (n[p] = this.bootstrapData[p])));\n            ;\n            };\n        ;\n            if (this._criticalOnly) {\n                this._fetchOnUseRequests.push({\n                    args: n,\n                    ctx: o\n                });\n            }\n             else this.fetch(this.bootstrapEndpoint, n, o);\n        ;\n        ;\n        },\n        _fetchLean: function() {\n            var n = {\n                no_cache: 1\n            };\n            n.options = l(n.options);\n            n.options.push(\"lean\");\n            this._fetchOnUse(n, {\n                type: \"lean\"\n            });\n        },\n        bootstrap: function(n) {\n            if (!n) {\n                this._criticalOnly = false;\n                this._flushFetchOnUseRequests();\n            }\n        ;\n        ;\n            if (this._bootstrapped) {\n                return;\n            }\n        ;\n        ;\n            var o = {\n                filter: [\"JSBNG__event\",],\n                no_cache: 1\n            };\n            this._fetchOnUse(o, {\n                type: \"JSBNG__event\"\n            });\n            var p = [\"app\",\"page\",\"group\",\"friendlist\",];\n            p = p.concat(((this._extraTypes || [])));\n            if (this._noMultiFetch) {\n                p.push(\"user\");\n                this._bootstrapFetch(\"user\", {\n                    filter: p\n                });\n            }\n             else {\n                this._bootstrapFetch(\"other\", {\n                    filter: p\n                });\n                if (this._buckets) {\n                    for (var q = 0; ((q < this._buckets.length)); ++q) {\n                        var r = {\n                            filter: [\"user\",],\n                            buckets: this._buckets[q]\n                        };\n                        this._bootstrapFetch(\"user\", r);\n                    };\n                ;\n                }\n                 else this._bootstrapFetch(\"user\", {\n                    filter: [\"user\",]\n                });\n            ;\n            ;\n            }\n        ;\n        ;\n            this._fetchLean();\n            this._bootstrapped = true;\n        },\n        _flushFetchOnUseRequests: function() {\n            var n = this._fetchOnUseRequests.length;\n            for (var o = 0; ((o < n)); ++o) {\n                var p = this._fetchOnUseRequests[o];\n                this.fetch(this.bootstrapEndpoint, p.args, p.ctx);\n            };\n        ;\n            this._fetchOnUseRequests = [];\n        },\n        JSBNG__onLoad: function(n, o) {\n            this.inform(\"JSBNG__onload\", {\n                time: JSBNG__Date.now()\n            }, g.BEHAVIOR_PERSISTENT);\n            if (n) {\n                this.bootstrap.bind(this, o).defer();\n            }\n        ;\n        ;\n        },\n        mergeUids: function(n, o, p, q) {\n            var r = ((p[0] ? this.getEntry(p[0]) : null)), s = ((o[0] ? this.getEntry(o[0]) : null)), t = ((((r && r.replace_results)) ? r : null));\n            t = ((((((!t && s)) && s.replace_results)) ? s : t));\n            var u = this.parent.mergeUids(n, o, p, q);\n            if (t) {\n                this.inform(\"backend_topreplace\", {\n                });\n                return this.deduplicateByKey([t.uid,].concat(u));\n            }\n        ;\n        ;\n            return u;\n        }\n    });\n    e.exports = m;\n});\n__d(\"legacy:SearchDataSource\", [\"SearchDataSource\",], function(a, b, c, d) {\n    a.SearchDataSource = b(\"SearchDataSource\");\n}, 3);\n__d(\"SearchTypeaheadCore\", [\"event-extensions\",\"function-extensions\",\"Arbiter\",\"Class\",\"DOM\",\"Input\",\"Parent\",\"TypeaheadCore\",\"URI\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"Class\"), i = b(\"DOM\"), j = b(\"Input\"), k = b(\"Parent\"), l = b(\"TypeaheadCore\"), m = b(\"URI\"), n = b(\"copyProperties\");\n    function o(p) {\n        this.parent.construct(this, p);\n    };\n;\n    h.extend(o, l);\n    n(o.prototype, {\n        init: function(p, q, r) {\n            this.parent.init(p, q, r);\n            var s = k.byTag(r, \"form\"), t = this.reset.bind(this);\n            g.subscribe(\"pre_page_transition\", function(JSBNG__event, v) {\n                var w = /^\\/search/, x = w.test(v.from.path), y = w.test(v.to.path);\n                if (((x && !y))) {\n                    t.defer();\n                }\n            ;\n            ;\n            });\n            if (s) {\n                var u = i.JSBNG__find(s, \"input.search_sid_input\");\n                JSBNG__Event.listen(s, \"submit\", function() {\n                    if (((this.data && this.data.queryData))) {\n                        u.value = this.data.queryData.sid;\n                    }\n                ;\n                ;\n                    t.defer();\n                }.bind(this), JSBNG__Event.Priority.URGENT);\n            }\n        ;\n        ;\n        },\n        select: function() {\n            this.reset();\n            this.element.JSBNG__focus();\n            (function() {\n                this.element.JSBNG__blur();\n            }).bind(this).defer();\n        },\n        handleTab: function(JSBNG__event) {\n            var p = this.view.getQuerySuggestion(this.value);\n            if (p) {\n                j.setValue(this.element, p);\n                this.checkValue();\n                JSBNG__event.kill();\n            }\n             else this.parent.handleTab(JSBNG__event);\n        ;\n        ;\n        }\n    });\n    e.exports = o;\n});\n__d(\"legacy:SearchTypeaheadCore\", [\"SearchTypeaheadCore\",], function(a, b, c, d) {\n    a.SearchTypeaheadCore = b(\"SearchTypeaheadCore\");\n}, 3);\n__d(\"SearchTypeaheadView\", [\"Arbiter\",\"ContextualTypeaheadView\",\"Class\",\"ContextualLayerUpdateOnScroll\",\"copyProperties\",\"DOM\",\"goURI\",\"MusicConstants\",\"MusicEvents\",\"tx\",\"URI\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ContextualTypeaheadView\"), i = b(\"Class\"), j = b(\"ContextualLayerUpdateOnScroll\"), k = b(\"copyProperties\"), l = b(\"DOM\"), m = b(\"goURI\"), n = b(\"MusicConstants\"), o = b(\"MusicEvents\"), p = b(\"tx\"), q = b(\"URI\");\n    function r(s, t) {\n        this.parent.construct(this, s, t);\n    };\n;\n    i.extend(r, h);\n    k(r.prototype, {\n        initializeLayer: function() {\n            this.parent.initializeLayer();\n            this.layer.setOffsetY(-1);\n            this.layer.enableBehavior(j);\n        },\n        ignoreClick: function(JSBNG__event) {\n            JSBNG__event.prevent();\n        },\n        shouldShowSeeMore: true,\n        queryData: {\n            init: \"quick\"\n        },\n        render: function(s, t, u) {\n            var v = {\n                results: t,\n                value: s\n            };\n            this.inform(\"finalResultsReordering\", v);\n            return this.parent.render(s, v.results, u);\n        },\n        buildBuckets: function(s, t) {\n            var u = t.length;\n            this.setWebSuggLoggingParams(s, t);\n            t = this.parent.buildBuckets(s, t);\n            if (((s && this.shouldShowSeeMore))) {\n                t.push(this.buildSeeMore(s, u));\n            }\n        ;\n        ;\n            return t;\n        },\n        buildSeeMore: function(s, t) {\n            var u = ((((t > 0)) ? p._(\"See more results for {query}\", {\n                query: s\n            }) : p._(\"See results for {query}\", {\n                query: s\n            }))), v = ((((t == 1)) ? \"Displaying top result\" : p._(\"Displaying top {number} results\", {\n                number: t\n            }))), w = l.create(\"li\", {\n                className: \"calltoaction\"\n            }, [l.create(\"a\", {\n                href: this.getSeeMoreEndpoint(s),\n                rel: \"ignore\"\n            }, [l.create(\"span\", {\n                className: \"text\"\n            }, [l.create(\"span\", {\n                className: \"seeMore\"\n            }, [u,l.create(\"span\", {\n                className: \"arrow\"\n            }),]),l.create(\"span\", {\n                className: \"subtext\"\n            }, [v,]),]),]),]);\n            w.setAttribute(\"aria-label\", u);\n            return {\n                uid: \"search\",\n                node: w,\n                search: true\n            };\n        },\n        searchPageQueryData: function(s) {\n            return k({\n                q: s\n            }, ((this.queryData || {\n            })));\n        },\n        select: function(s) {\n            var t = this.index, u = this.results[t];\n            if (((!u || ((u.type == \"header\"))))) {\n                return;\n            }\n        ;\n        ;\n            var v = this.items[t], w = l.scry(v, \"a\")[0];\n            if (u.song) {\n                if (w) {\n                    o.inform(n.MUSIC_BUTTON.ACTIVATE, w);\n                }\n            ;\n            ;\n                ((s && this.inform(\"highlight\", {\n                    index: t,\n                    selected: u\n                })));\n            }\n             else {\n                this.parent.select(s);\n                if (((w && w.href))) {\n                    if (((w.target == \"_blank\"))) {\n                        window.open(w.href);\n                    }\n                     else m(w.href);\n                ;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        setSid: function(s) {\n            this.queryData.tas = s;\n        },\n        getSeeMoreEndpoint: function(s) {\n            return q(this.seeMoreEndpoint).addQueryData(this.searchPageQueryData(s)).toString();\n        },\n        show: function() {\n            if (!this.isVisible()) {\n                g.inform(\"layer_shown\", {\n                    type: \"SearchTypeahead\"\n                });\n                this.parent.show();\n            }\n        ;\n        ;\n        },\n        hide: function() {\n            if (this.isVisible()) {\n                g.inform(\"layer_hidden\", {\n                    type: \"SearchTypeahead\"\n                });\n                this.parent.hide();\n            }\n        ;\n        ;\n        },\n        getQuerySuggestion: function(s) {\n            var t = this.results[this.index], u = ((((t && ((t.type != \"header\")))) ? t.text.toLowerCase() : \"\"));\n            return ((((u == s.toLowerCase())) ? \"\" : u));\n        },\n        setWebSuggLoggingParams: function(s, t) {\n            var u = 0, v = 0;\n            for (var w = 0; ((w < t.length)); w++) {\n                if (((t[w].type === \"websuggestion\"))) {\n                    if (((v === 0))) {\n                        v = ((w + 1));\n                    }\n                ;\n                ;\n                    var x = ((((((\"FR\" + ((w - u)))) + \"AS\")) + u)), y = ((w + 1));\n                    t[w].path += ((((((((((\"&wssk=\" + x)) + \"&wssp=\")) + y)) + \"&wspq=\")) + encodeURIComponent(s)));\n                    u++;\n                }\n            ;\n            ;\n            };\n        ;\n            var z = ((((((((((((((\"&wssc=\" + t.length)) + \"-\")) + s.length)) + \"&wsbp=\")) + u)) + \"-\")) + v));\n            for (w = 0; ((w < t.length)); w++) {\n                if (((t[w].type === \"websuggestion\"))) {\n                    t[w].path += z;\n                }\n            ;\n            ;\n            };\n        ;\n        }\n    });\n    e.exports = r;\n});\n__d(\"legacy:SearchTypeaheadView\", [\"SearchTypeaheadView\",], function(a, b, c, d) {\n    a.SearchTypeaheadView = b(\"SearchTypeaheadView\");\n}, 3);\n__d(\"legacy:Typeahead\", [\"Typeahead\",], function(a, b, c, d) {\n    a.Typeahead = b(\"Typeahead\");\n}, 3);\n__d(\"SearchTypeaheadRecorder\", [\"event-extensions\",\"AsyncRequest\",\"Keys\",\"$\",\"copyProperties\",\"userAction\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"AsyncRequest\"), h = b(\"Keys\"), i = b(\"$\"), j = b(\"copyProperties\"), k = b(\"userAction\");\n    function l(m) {\n        this.init(m);\n        this.initEvents();\n    };\n;\n    j(l.prototype, {\n        _endPoint: \"/ajax/typeahead/record_metrics.php\",\n        init: function(m) {\n            this.core = m.getCore();\n            this.data = m.getData();\n            this.view = m.getView();\n            this.element = this.core.getElement();\n            this.initTime = JSBNG__Date.now();\n            this._onloadTime = 0;\n            this.initStartTime = i(\"search_first_focus\").value;\n            this.bootstrapStats = {\n                bootstrapped: 0\n            };\n            this._reset();\n        },\n        _reset: function() {\n            this.stats = {\n            };\n            this.avgStats = {\n            };\n            this.appendStats = {\n            };\n            this._backspacing = false;\n            this._topreplace = false;\n            this._inflightRequests = {\n            };\n            var m = Math.JSBNG__random();\n            this.data.setQueryData({\n                sid: m\n            });\n            this.view.setSid(m);\n            this.recordStat(\"sid\", m);\n        },\n        initEvents: function() {\n            this.core.subscribe(\"JSBNG__focus\", function(JSBNG__event) {\n                if (!this.stats.session_start_time) {\n                    this.recordStat(\"session_start_time\", JSBNG__Date.now());\n                }\n            ;\n            ;\n            }.bind(this));\n            this.core.subscribe(\"JSBNG__blur\", function(JSBNG__event) {\n                var m = JSBNG__Date.now();\n                for (var n in this._inflightRequests) {\n                    var o = this._inflightRequests[n], p = ((m - o));\n                    this.recordAvgStat(\"search_endpoint_ms_from_js\", p);\n                };\n            ;\n                this.recordStat(\"session_end_time\", m);\n                this.submit();\n            }.bind(this));\n            this.view.subscribe(\"select\", function(m, n) {\n                this.recordSelectInfo(n);\n            }.bind(this));\n            this.view.subscribe(\"render\", function(m, n) {\n                this.recordRender(n);\n            }.bind(this));\n            this.view.subscribe(\"recordAfterReorder\", function(m, n) {\n                this._reorderInfo = n;\n            }.bind(this));\n            this.data.subscribe(\"activity\", function(m, n) {\n                this.recordStat(\"pending_request\", n.activity);\n            }.bind(this));\n            this.data.subscribe(\"beforeQuery\", function(m, n) {\n                if (!n.value) {\n                    return;\n                }\n            ;\n            ;\n                if (!this.stats.first_query_time) {\n                    this.recordStat(\"first_query_time\", JSBNG__Date.now());\n                }\n            ;\n            ;\n                this.query = n.value;\n                this.recordCountStat(\"num_queries\");\n            }.bind(this));\n            this.data.subscribe(\"queryEndpoint\", function(m, n) {\n                this.recordCountStat(\"num_search_ajax_requests\");\n                this.recordAvgStat(\"endpoint_query_length\", n.value.length);\n                this._inflightRequests[n.value] = JSBNG__Date.now();\n            }.bind(this));\n            this.data.subscribe(\"JSBNG__onload\", function(m, n) {\n                this._onloadTime = n.time;\n            }.bind(this));\n            this.data.subscribe(\"bootstrapped\", function(m, n) {\n                this.bootstrapStats.endTime = n.time;\n                this.bootstrapStats.bootstrapped = 1;\n            }.bind(this));\n            this.data.subscribe(\"endpointStats\", function(m, n) {\n                var o = ((n.fetch_end - n.fetch_start));\n                if (n.value) {\n                    this.recordAvgStat(\"search_endpoint_ms_from_js\", o);\n                }\n                 else this.bootstrapStats[n.type] = o;\n            ;\n            ;\n                if (n.coeff2_ts) {\n                    this.bootstrapStats.coeff2_ts = n.coeff2_ts;\n                }\n            ;\n            ;\n                if (((typeof n.browserCacheHit != \"undefined\"))) {\n                    this.recordCountStat(((n.browserCacheHit ? \"bootstrap_cachehits\" : \"bootstrap_cachemisses\")));\n                }\n            ;\n            ;\n                if (this._inflightRequests[n.value]) {\n                    delete this._inflightRequests[n.value];\n                }\n            ;\n            ;\n            }.bind(this));\n            this.data.subscribe(\"query\", function(m, n) {\n                this.recordAvgStat(\"num_results_from_cache\", n.results.length);\n            }.bind(this));\n            this.data.subscribe(\"backend_topreplace\", function(m, n) {\n                if (((false === this._topreplace))) {\n                    this.recordStat(\"backend_topreplace\", 1);\n                    this._topreplace = true;\n                }\n            ;\n            ;\n            }.bind(this));\n            JSBNG__Event.listen(this.element, \"keydown\", function(JSBNG__event) {\n                if (((JSBNG__Event.getKeyCode(JSBNG__event) == h.BACKSPACE))) {\n                    if (!this._backspacing) {\n                        this._backspacing = true;\n                        this.recordAppendStat(\"before_backspace_queries\", this.query);\n                    }\n                ;\n                ;\n                }\n                 else this._backspacing = false;\n            ;\n            ;\n            }.bind(this));\n        },\n        recordStat: function(m, n) {\n            this.stats[m] = n;\n        },\n        recordCountStat: function(m) {\n            var n = this.stats[m];\n            this.stats[m] = ((n ? ((n + 1)) : 1));\n        },\n        recordAvgStat: function(m, n) {\n            if (this.avgStats[m]) {\n                this.avgStats[m][0] += n;\n                ++this.avgStats[m][1];\n            }\n             else this.avgStats[m] = [n,1,];\n        ;\n        ;\n        },\n        recordAppendStat: function(m, n) {\n            if (!this.appendStats.hasOwnProperty(m)) {\n                this.appendStats[m] = [];\n            }\n        ;\n        ;\n            this.appendStats[m].push(n);\n        },\n        recordRender: function(m) {\n            this.results = m.filter(function(n) {\n                return ((((n.uid != \"search\")) && ((n.type != \"header\"))));\n            });\n            if (((((this.results.length > 0)) && !this.stats.first_result_time))) {\n                this.recordStat(\"first_result_time\", JSBNG__Date.now());\n            }\n        ;\n        ;\n        },\n        recordSelectInfo: function(m) {\n            var n = m.selected, o = ((((m.index - n.groupIndex)) - 1)), p = {\n                href: n.path\n            }, q = ((n.dataGT ? {\n                gt: JSON.parse(n.dataGT)\n            } : {\n            }));\n            k(\"click\", p, null, null, q);\n            if (((n.uid == \"search\"))) {\n                this.recordStat(\"selected_search\", 1);\n            }\n             else {\n                var r = ((((n.rankType || n.render_type)) || n.type)), s = ((((r == \"friend\")) ? \"user\" : r));\n                this.recordStat(((\"selected_\" + s)), 1);\n                this.recordStat(\"selected_position\", o);\n                this.recordStat(\"selected_type\", r);\n                this.recordStat(\"selected_name_length\", n.text.length);\n                this.recordStat(\"selected_id\", n.uid);\n                this.recordStat(\"selected_degree\", ((n.bootstrapped ? 1 : 2)));\n            }\n        ;\n        ;\n            this.recordStat(\"selected_with_mouse\", ((m.clicked ? 1 : 0)));\n        },\n        _dataToSubmit: function() {\n            this.recordStat(\"candidate_results\", this.buildResults());\n            this.recordStat(\"query\", this.query);\n            this.recordStat(\"init_time\", this.initTime);\n            if (this.initStartTime) {\n                this.recordStat(\"init_start_time\", this.initStartTime);\n                this.recordStat(\"JSBNG__onload_time\", this._onloadTime);\n                this.initStartTime = 0;\n            }\n        ;\n        ;\n            this.recordStat(\"bootstrapped\", this.bootstrapStats.bootstrapped);\n            if (this.bootstrapStats.endTime) {\n                this.recordStat(\"bootstrapped_time\", this.bootstrapStats.endTime);\n                this.recordStat(\"user_bootstrap_ms\", this.bootstrapStats.user);\n                this.recordStat(\"other_bootstrap_ms\", this.bootstrapStats.other);\n                this.bootstrapStats.endTime = 0;\n            }\n        ;\n        ;\n            this.recordStat(\"coeff2_ts\", this.bootstrapStats.coeff2_ts);\n            this.recordStat(\"max_results\", this.data._maxResults);\n            if (this._reorderInfo) {\n                var m = this._reorderInfo;\n                m.organic.forEach(function(q) {\n                    delete q.text;\n                });\n                this.recordStat(\"s_count\", m.position_data.length);\n                this.recordStat(\"s_bootstrap_id\", m.s_bootstrap_id);\n                this.recordStat(\"s_organic_results\", JSON.stringify(m.organic));\n                this.recordStat(\"s_candidate_tokens\", JSON.stringify(m.tokens));\n                this.recordStat(\"s_positions\", JSON.stringify(m.position_data));\n                this.recordStat(\"s_options\", JSON.stringify(m.options));\n                this.recordStat(\"s_variant\", JSON.stringify(m.variant));\n            }\n        ;\n        ;\n            var n = this.stats;\n            for (var o in this.avgStats) {\n                var m = this.avgStats[o];\n                n[o] = ((m[0] / m[1]));\n            };\n        ;\n            for (var p in this.appendStats) {\n                n[p] = JSON.stringify(this.appendStats[p]);\n            ;\n            };\n        ;\n            return n;\n        },\n        buildResults: function() {\n            var m = ((this.results || [])).map(function(n, o) {\n                var p = ((((n.rankType || n.render_type)) || n.type)), q = ((n.bootstrapped ? 1 : 0)), r = ((n.s_token || \"\"));\n                if (((typeof n.groupIndex == \"number\"))) {\n                    return [n.groupIndex,n.indexInGroup,n.uid,p,q,r,];\n                }\n            ;\n            ;\n                return [0,o,n.uid,p,q,r,];\n            });\n            return JSON.stringify(m);\n        },\n        submit: function() {\n            var m = this._dataToSubmit();\n            if (((Object.keys(m).length > 0))) {\n                new g().setURI(this._endPoint).setMethod(\"POST\").setData({\n                    stats: m\n                }).setOption(\"handleErrorAfterUnload\", true).setErrorHandler(function(n) {\n                    m.retry = true;\n                    new g().setURI(this._endPoint).setMethod(\"POST\").setData({\n                        stats: m\n                    }).setOption(\"asynchronous\", false).send();\n                }.bind(this)).send();\n            }\n        ;\n        ;\n            this._reset();\n        }\n    });\n    e.exports = l;\n});\n__d(\"TypeaheadSearchRecorderBasic\", [\"SearchTypeaheadRecorder\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"SearchTypeaheadRecorder\"), h = b(\"copyProperties\");\n    function i(j) {\n        this._typeahead = j;\n    };\n;\n    h(i.prototype, {\n        enable: function() {\n            new g(this._typeahead);\n        },\n        disable: bagofholding\n    });\n    e.exports = i;\n});\n__d(\"legacy:SearchRecorderBasicTypeaheadBehavior\", [\"TypeaheadSearchRecorderBasic\",], function(a, b, c, d) {\n    var e = b(\"TypeaheadSearchRecorderBasic\");\n    if (!a.TypeaheadBehaviors) {\n        a.TypeaheadBehaviors = {\n        };\n    }\n;\n;\n    a.TypeaheadBehaviors.searchRecorderBasic = function(f) {\n        f.enableBehavior(e);\n    };\n}, 3);\n__d(\"SearchTypeaheadRenderer\", [\"DOM\",\"Env\",\"MusicButtonManager\",\"TypeaheadUtil\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"Env\"), i = b(\"MusicButtonManager\"), j = b(\"TypeaheadUtil\");\n    function k(l, m) {\n        var n = [];\n        if (l.photo) {\n            n.push(g.create(\"img\", {\n                className: \"photo\",\n                alt: \"\",\n                src: l.photo\n            }));\n            if (l.song) {\n                n.push(g.create(\"span\", {\n                    className: \"playButton\"\n                }));\n                n.push(g.create(\"span\", {\n                    className: \"playLoader\"\n                }));\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        if (l.text) {\n            var o = l.alias, p = this.value, q = l.text, r = [q,];\n            if (((((o && j.isQueryMatch(p, o))) && !j.isQueryMatch(p, q)))) {\n                r.push(g.create(\"span\", {\n                    className: \"alias\"\n                }, [((\" \\u00b7 \" + o)),]));\n            }\n        ;\n        ;\n            n.push(g.create(\"span\", {\n                className: \"text\"\n            }, r));\n        }\n    ;\n    ;\n        if (l.category) {\n            var s = [l.category,];\n            if (l.is_external) {\n                s.push(g.create(\"span\", {\n                    className: \"arrow\"\n                }));\n            }\n        ;\n        ;\n            var t = ((l.message ? \"preCategory\" : \"category\"));\n            n.push(g.create(\"span\", {\n                className: t\n            }, s));\n        }\n    ;\n    ;\n        if (l.message) {\n            n.push(g.create(\"span\", {\n                className: \"category\"\n            }, [l.message,]));\n        }\n    ;\n    ;\n        var u = ((l.subtextOverride || l.subtext));\n        if (u) {\n            n.push(g.create(\"span\", {\n                className: \"subtext\"\n            }, [u,]));\n        }\n    ;\n    ;\n        var v = ((((l.classNames || l.type)) || \"\")), w = ((l.is_external ? \"_blank\" : \"\")), x = ((((!l.song && l.path)) || \"\"));\n        if (x) {\n            if (!(/^https?\\:\\/\\//).test(x)) {\n                x = ((h.www_base + x.substr(1)));\n            }\n        ;\n        ;\n            x += ((((((x.indexOf(\"?\") > 0)) ? \"&\" : \"?\")) + \"ref=ts\"));\n        }\n    ;\n    ;\n        var y = g.create(\"a\", {\n            href: x,\n            rel: \"ignore\",\n            target: w\n        }, n);\n        if (l.song) {\n            y.id = ((\"mb_\" + ((((Math.JSBNG__random() * 1000000)) | 0))));\n            i.addButton.curry(l.song.provider, y.id, l.song.url, l.song.context, l.song.media_type).defer();\n            y.JSBNG__onclick = this.ignoreClick;\n        }\n    ;\n    ;\n        var z = g.create(\"li\", {\n            className: v\n        }, [y,]);\n        z.setAttribute(\"role\", \"option\");\n        if (l.text) {\n            z.setAttribute(\"aria-label\", l.text);\n        }\n    ;\n    ;\n        return z;\n    };\n;\n    k.className = \"search\";\n    e.exports = k;\n});\n__d(\"legacy:SearchTypeaheadRenderer\", [\"SearchTypeaheadRenderer\",], function(a, b, c, d) {\n    if (!a.TypeaheadRenderers) {\n        a.TypeaheadRenderers = {\n        };\n    }\n;\n;\n    a.TypeaheadRenderers.search = b(\"SearchTypeaheadRenderer\");\n}, 3);\nvoid (0);\n__d(\"TypeaheadSearchFilter\", [\"Arbiter\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"copyProperties\");\n    function i(j) {\n        this._typeahead = j;\n    };\n;\n    h(i.prototype, {\n        _subscription: null,\n        enable: function() {\n            var j = this._typeahead;\n            this._subscriptions = [g.subscribe(\"search/typeahead/updateFilter\", function(k, l) {\n                if (((l.filter_type == \"web\"))) {\n                    j.getView().queryData.form = \"FBKBFR\";\n                }\n            ;\n            ;\n                j.getView().queryData.type = l.filter_type;\n            }),g.subscribe(\"page_transition\", function(k, l) {\n                if (j.getView().queryData.form) {\n                    delete j.getView().queryData.form;\n                }\n            ;\n            ;\n                delete j.getView().queryData.type;\n            }, g.SUBSCRIBE_NEW),];\n        },\n        disable: function() {\n            this._subscriptions.forEach(function(j) {\n                j.unsubscribe();\n            });\n            this._subscriptions = null;\n        }\n    });\n    e.exports = i;\n});\n__d(\"legacy:SearchFilterTypeaheadBehavior\", [\"TypeaheadSearchFilter\",], function(a, b, c, d) {\n    var e = b(\"TypeaheadSearchFilter\");\n    if (!a.TypeaheadBehaviors) {\n        a.TypeaheadBehaviors = {\n        };\n    }\n;\n;\n    a.TypeaheadBehaviors.initFilters = function(f) {\n        f.enableBehavior(e);\n    };\n}, 3);\n__d(\"JewelSuggestFriendsFollowupUnit\", [\"DOM\",\"Arbiter\",\"CSS\",\"csx\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"Arbiter\"), i = b(\"CSS\"), j = b(\"csx\"), k = b(\"copyProperties\");\n    function l(m, n) {\n        this._friend_id = m;\n        this._container = n.parentElement;\n        var o = [\"FriendRequest/confirming\",\"FriendSuggestion/accepting\",];\n        h.subscribe(o, function(q, r) {\n            ((((r.uid == m)) && this._renderPromotion()));\n        }.bind(this));\n        g.JSBNG__find(this._container, \".-cx-PRIVATE-jewelFollowupUnitLayout__skip\").JSBNG__onclick = this._restore.bind(this);\n        var p = [\"FriendSuggestion/sent\",\"FriendRequest/confirmFail\",\"FriendSuggestion/acceptFail\",];\n        h.subscribe(p, function(q, r) {\n            ((((r.uid == m)) && this._restore()));\n        }.bind(this));\n    };\n;\n    k(l.prototype, {\n        _renderPromotion: function() {\n            i.addClass(this._container, \"followupActivated\");\n        },\n        _restore: function() {\n            i.removeClass(this._container, \"followupActivated\");\n        }\n    });\n    e.exports = l;\n});\n__d(\"TypeaheadRegulateMemorializedUsers\", [\"copyProperties\",\"TypeaheadUtil\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\"), h = b(\"TypeaheadUtil\");\n    function i(j) {\n        this._typeahead = j;\n    };\n;\n    g(i.prototype, {\n        _filterRegistry: null,\n        _filter: function(j, k) {\n            if (((((j.type !== \"user\")) || !j.memorialized))) {\n                return true;\n            }\n        ;\n        ;\n            var l = h.parse(j.text).tokens;\n            if (((((l.length === 1)) && h.isExactMatch(k, j.text)))) {\n                return true;\n            }\n        ;\n        ;\n            var m = this._typeahead.getData().getTextToIndex(j), n = h.parse(k).tokens;\n            return ((((n.length > 1)) && h.isQueryMatch(k, m)));\n        },\n        enable: function() {\n            this._filterRegistry = this._typeahead.getData().addFilter(this._filter.bind(this));\n        },\n        disable: function() {\n            this._filterRegistry.remove();\n            this._filterRegistry = null;\n        }\n    });\n    e.exports = i;\n});\n__d(\"legacy:RegulateMemorializedUsersTypeaheadBehavior\", [\"TypeaheadRegulateMemorializedUsers\",], function(a, b, c, d) {\n    var e = b(\"TypeaheadRegulateMemorializedUsers\");\n    if (!a.TypeaheadBehaviors) {\n        a.TypeaheadBehaviors = {\n        };\n    }\n;\n;\n    a.TypeaheadBehaviors.regulateMemorializedUsers = function(f) {\n        f.enableBehavior(e);\n    };\n}, 3);\n__d(\"legacy:CompactTypeaheadRenderer\", [\"CompactTypeaheadRenderer\",], function(a, b, c, d) {\n    if (!a.TypeaheadRenderers) {\n        a.TypeaheadRenderers = {\n        };\n    }\n;\n;\n    a.TypeaheadRenderers.compact = b(\"CompactTypeaheadRenderer\");\n}, 3);");
// 2994
JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_84[0](o27,false,o28);
// undefined
o27 = null;
// undefined
o28 = null;
// 3002
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"28ZbA\",]);\n}\n;\n__d(\"ReactErrors\", [], function(a, b, c, d, e, f) {\n    var g;\n    g = {\n        COULD_NOT_CREATE_SINGLE_DOM: 100,\n        MUST_SPECIFY_TOP_COMP: 101,\n        CLASS_SPEC: 102,\n        CONTROL_WITHOUT_BACKING_DOM: 103,\n        NO_RENDER_NODE: 104,\n        MERGE_ARRAY_FAIL: 105,\n        MERGE_CORE_FAILURE: 106,\n        MERGE_TYPE_USAGE_FAILURE: 107,\n        MERGE_DEEP_MAX_LEVELS: 108,\n        USING_CHILD_TWICE: 109,\n        DUAL_TRANSACTION: 110,\n        MISSING_TRANSACTION: 111,\n        INVALID_STATE: 112,\n        ON_DOM_READY_MISMATCH: 113,\n        INVALID_COMPONENT: 114,\n        RUNAWAY_TREE: 114,\n        ESCAPE_TYPE: 115\n    };\n    g.throwIf = function(h, i) {\n        if (h) {\n            throw new Error(i)\n        };\n    };\n    e.exports = g;\n});\n__d(\"mergeHelpers\", [\"ReactErrors\",], function(a, b, c, d, e, f) {\n    var g = b(\"ReactErrors\"), h = 36, i = function(l) {\n        return ((typeof l !== \"object\") || (l === null));\n    }, j = function(l, m) {\n        g.throwIf((Array.isArray(l) || Array.isArray(m)), g.MERGE_ARRAY_FAIL);\n    }, k = {\n        MAX_MERGE_DEPTH: h,\n        isTerminal: i,\n        normalizeMergeArg: function(l) {\n            return (((l === undefined) || (l === null)) ? {\n            } : l);\n        },\n        checkMergeArgs: function(l, m) {\n            j(l, m);\n            g.throwIf(((((i(l) && (l !== null)) && (l !== undefined))) || (((i(m) && (m !== null)) && (m !== undefined)))), g.MERGE_TYPE_USAGE_FAILURE);\n        },\n        checkMergeDeepImplArgs: function(l, m) {\n            j(l, m);\n            g.throwIf((i(l) || i(m)), g.MERGE_CORE_FAILURE);\n        },\n        checkMergeIntoArgs: function(l, m) {\n            j(l, m);\n            g.throwIf((i(l) || (((i(m) && (m !== null)) && (m !== undefined)))), g.MERGE_TYPE_USAGE_FAILURE);\n        },\n        checkMergeLevel: function(l) {\n            g.throwIf((l >= h), g.MERGE_DEEP_MAX_LEVELS);\n        }\n    };\n    e.exports = k;\n});\n__d(\"merge\", [\"mergeHelpers\",], function(a, b, c, d, e, f) {\n    var g = b(\"mergeHelpers\"), h = g.checkMergeArgs, i = g.normalizeMergeArg, j = function(k, l) {\n        h(k, l);\n        var m = i(k), n = i(l), o, p, q = {\n        };\n        for (o in m) {\n            if (m.hasOwnProperty(o)) {\n                q[o] = m[o];\n            };\n        };\n        for (p in n) {\n            if (n.hasOwnProperty(p)) {\n                q[p] = n[p];\n            };\n        };\n        return q;\n    };\n    e.exports = j;\n});");
// 3003
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s94fb848a4e5deb89306c7b6f837c2bc49c00270a");
// 3004
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"28ZbA\",]);\n}\n;\n;\n__d(\"ReactErrors\", [], function(a, b, c, d, e, f) {\n    var g;\n    g = {\n        COULD_NOT_CREATE_SINGLE_DOM: 100,\n        MUST_SPECIFY_TOP_COMP: 101,\n        CLASS_SPEC: 102,\n        CONTROL_WITHOUT_BACKING_DOM: 103,\n        NO_RENDER_NODE: 104,\n        MERGE_ARRAY_FAIL: 105,\n        MERGE_CORE_FAILURE: 106,\n        MERGE_TYPE_USAGE_FAILURE: 107,\n        MERGE_DEEP_MAX_LEVELS: 108,\n        USING_CHILD_TWICE: 109,\n        DUAL_TRANSACTION: 110,\n        MISSING_TRANSACTION: 111,\n        INVALID_STATE: 112,\n        ON_DOM_READY_MISMATCH: 113,\n        INVALID_COMPONENT: 114,\n        RUNAWAY_TREE: 114,\n        ESCAPE_TYPE: 115\n    };\n    g.throwIf = function(h, i) {\n        if (h) {\n            throw new Error(i);\n        }\n    ;\n    ;\n    };\n    e.exports = g;\n});\n__d(\"mergeHelpers\", [\"ReactErrors\",], function(a, b, c, d, e, f) {\n    var g = b(\"ReactErrors\"), h = 36, i = function(l) {\n        return ((((typeof l !== \"object\")) || ((l === null))));\n    }, j = function(l, m) {\n        g.throwIf(((Array.isArray(l) || Array.isArray(m))), g.MERGE_ARRAY_FAIL);\n    }, k = {\n        MAX_MERGE_DEPTH: h,\n        isTerminal: i,\n        normalizeMergeArg: function(l) {\n            return ((((((l === undefined)) || ((l === null)))) ? {\n            } : l));\n        },\n        checkMergeArgs: function(l, m) {\n            j(l, m);\n            g.throwIf(((((((i(l) && ((l !== null)))) && ((l !== undefined)))) || ((((i(m) && ((m !== null)))) && ((m !== undefined)))))), g.MERGE_TYPE_USAGE_FAILURE);\n        },\n        checkMergeDeepImplArgs: function(l, m) {\n            j(l, m);\n            g.throwIf(((i(l) || i(m))), g.MERGE_CORE_FAILURE);\n        },\n        checkMergeIntoArgs: function(l, m) {\n            j(l, m);\n            g.throwIf(((i(l) || ((((i(m) && ((m !== null)))) && ((m !== undefined)))))), g.MERGE_TYPE_USAGE_FAILURE);\n        },\n        checkMergeLevel: function(l) {\n            g.throwIf(((l >= h)), g.MERGE_DEEP_MAX_LEVELS);\n        }\n    };\n    e.exports = k;\n});\n__d(\"merge\", [\"mergeHelpers\",], function(a, b, c, d, e, f) {\n    var g = b(\"mergeHelpers\"), h = g.checkMergeArgs, i = g.normalizeMergeArg, j = function(k, l) {\n        h(k, l);\n        var m = i(k), n = i(l), o, p, q = {\n        };\n        for (o in m) {\n            if (m.hasOwnProperty(o)) {\n                q[o] = m[o];\n            }\n        ;\n        ;\n        };\n    ;\n        for (p in n) {\n            if (n.hasOwnProperty(p)) {\n                q[p] = n[p];\n            }\n        ;\n        ;\n        };\n    ;\n        return q;\n    };\n    e.exports = j;\n});");
// 3007
JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_84[0](o29,false,o30);
// undefined
o29 = null;
// undefined
o30 = null;
// 3018
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"C6rJk\",]);\n}\n;\n__d(\"NotifXList\", [], function(a, b, c, d, e, f) {\n    var g = {\n    }, h = null;\n    function i(p) {\n        if (!p) {\n            throw new Error(\"You have to init NotifXList with a non-null owner\")\n        };\n        h = p;\n    };\n    function j(p) {\n        g[p] = null;\n    };\n    function k(p, q) {\n        if (!q) {\n            throw new Error(\"You have to add a non-null data to xList\")\n        };\n        g[p] = q;\n    };\n    function l(p) {\n        var q = ((undefined !== g[p.notif_id])), r = ((p.notif_alt_id && (undefined !== g[p.notif_alt_id])));\n        if ((q || r)) {\n            k((q ? p.notif_id : p.notif_alt_id), p);\n            return true;\n        }\n    ;\n        return false;\n    };\n    function m(p) {\n        return (null != g[p]);\n    };\n    function n(p) {\n        if (m(p)) {\n            var q = g[p];\n            o(p);\n            h.alertList.insert(q.notif_id, q.notif_time, q.notif_markup, q.replace, q.ignoreUnread, q.notif_alt_id);\n        }\n    ;\n    };\n    function o(p) {\n        delete g[p];\n    };\n    e.exports = {\n        init: i,\n        userXClick: j,\n        filterStoreClicked: l,\n        newNotifExist: m,\n        resumeInsert: n,\n        removeNotif: o\n    };\n});");
// 3019
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s0ca72405ff6db4436ab1830798951cd159877aed");
// 3020
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"C6rJk\",]);\n}\n;\n;\n__d(\"NotifXList\", [], function(a, b, c, d, e, f) {\n    var g = {\n    }, h = null;\n    function i(p) {\n        if (!p) {\n            throw new Error(\"You have to init NotifXList with a non-null owner\");\n        }\n    ;\n    ;\n        h = p;\n    };\n;\n    function j(p) {\n        g[p] = null;\n    };\n;\n    function k(p, q) {\n        if (!q) {\n            throw new Error(\"You have to add a non-null data to xList\");\n        }\n    ;\n    ;\n        g[p] = q;\n    };\n;\n    function l(p) {\n        var q = ((undefined !== g[p.notif_id])), r = ((p.notif_alt_id && ((undefined !== g[p.notif_alt_id]))));\n        if (((q || r))) {\n            k(((q ? p.notif_id : p.notif_alt_id)), p);\n            return true;\n        }\n    ;\n    ;\n        return false;\n    };\n;\n    function m(p) {\n        return ((null != g[p]));\n    };\n;\n    function n(p) {\n        if (m(p)) {\n            var q = g[p];\n            o(p);\n            h.alertList.insert(q.notif_id, q.notif_time, q.notif_markup, q.replace, q.ignoreUnread, q.notif_alt_id);\n        }\n    ;\n    ;\n    };\n;\n    function o(p) {\n        delete g[p];\n    };\n;\n    e.exports = {\n        init: i,\n        userXClick: j,\n        filterStoreClicked: l,\n        newNotifExist: m,\n        resumeInsert: n,\n        removeNotif: o\n    };\n});");
// 3023
JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_84[0](o31,false,o32);
// undefined
o31 = null;
// undefined
o32 = null;
// 3028
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"u8TjK\",]);\n}\n;\n__d(\"NotifBeeper\", [\"event-extensions\",\"Animation\",\"ARIA\",\"CSS\",\"DOM\",\"DoublyLinkedListMap\",\"HTML\",\"NotificationList\",\"Style\",\"Toggler\",\"UserAgent\",\"$\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Animation\"), h = b(\"ARIA\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"DoublyLinkedListMap\"), l = b(\"HTML\"), m = b(\"NotificationList\"), n = b(\"Style\"), o = b(\"Toggler\"), p = b(\"UserAgent\"), q = b(\"$\"), r = null, s = null, t = null, u = 0, v = {\n    }, w = {\n    }, x = null, y = null, z = false, aa = new k(), ba = null, ca = null, da = \"fbJewelBeep\", ea = \"fbTopJewelBeep\", fa = \"fbBottomJewelBeep\", ga = \"beeper\", ha = 300, ia = 300, ja = 150, ka = 10000, la = 2000, ma = ((p.ie() >= 8) && (p.ie() < 9)), na = 1, oa = 2, pa = 3, qa = ha, ra = ia, sa = ka;\n    function ta() {\n        return (u === 0);\n    };\n    function ua() {\n        return (!ta() || (aa.getCount() !== 0));\n    };\n    function va(yb) {\n        r = yb;\n        o.subscribe(\"show\", function() {\n            tb();\n        });\n        o.subscribe(\"hide\", function() {\n            aa.map(function(ac) {\n                ac();\n            });\n            aa.reset();\n        });\n        var zb = j.scry(r, \".beeperArea .uiScrollableAreaContent\");\n        if ((zb.length === 1)) {\n            s = zb[0];\n        };\n        x = q(\"fbNotificationsList\");\n    };\n    function wa() {\n        ca = Event.listen(r, \"mouseover\", ib);\n        i.addClass(r, \"hasBeeps\");\n        y = ab();\n        za(ga);\n    };\n    function xa() {\n        ca.remove();\n        i.removeClass(r, \"hasBeeps\");\n        za(y);\n        ya.defer();\n    };\n    function ya() {\n        if (!ta()) {\n            return\n        };\n        for (var yb in w) {\n            delete w[yb];;\n        };\n        lb();\n    };\n    function za(yb) {\n        var zb = bb();\n        if (yb) {\n            zb.ref = yb;\n        }\n         else delete zb.ref;\n    ;\n        x.setAttribute(\"data-gt\", JSON.stringify(zb));\n    };\n    function ab() {\n        return bb().ref;\n    };\n    function bb() {\n        var yb = x.getAttribute(\"data-gt\");\n        return (yb ? JSON.parse(yb) : {\n        });\n    };\n    function cb(yb, zb, ac) {\n        if (ma) {\n            return db(yb, ac)\n        };\n        return db(yb, ac).to(\"opacity\", zb);\n    };\n    function db(yb, zb, ac) {\n        var bc = (ac || new g(yb));\n        return bc.ease(g.ease.both).duration(zb);\n    };\n    function eb(yb, zb) {\n        v[yb].state = na;\n        jb(yb);\n        var ac = (qa * ((1 - n.getOpacity(v[yb].obj))));\n        if (!v[yb].animations) {\n            v[yb].animations = [];\n        };\n        v[yb].animations.push(cb(v[yb].obj, 1, ac).ondone(fb.curry(yb, sa)).go());\n        ((u > 1) && v[yb].animations.push(db(v[yb].obj, ja).from(\"height\", zb).to(\"height\", \"auto\").go()));\n        if ((u === 1)) {\n            t = cb(r, 1, ac).go();\n        };\n    };\n    function fb(yb, zb) {\n        v[yb].state = oa;\n        if (z) {\n            return\n        };\n        (v[yb].delay && clearTimeout(v[yb].delay));\n        v[yb].delay = gb.curry(yb).defer(zb);\n    };\n    function gb(yb) {\n        if (!((yb in v))) {\n            return\n        };\n        v[yb].state = pa;\n        jb(yb);\n        (v[yb].delay && clearTimeout(v[yb].delay));\n        var zb = (ra * n.getOpacity(v[yb].obj));\n        function ac(bc) {\n            if ((u > 1)) {\n                var cc = (((zb - ja)) / zb), dc = bc.checkpoint(cc);\n                return db(v[yb].obj, ja, dc).to(\"height\", 0);\n            }\n             else return bc\n        ;\n        };\n        v[yb].animations.push(ac(cb(v[yb].obj, 0, zb)).ondone(rb.curry(yb)).go());\n        if ((u === 1)) {\n            t = cb(r, 0, zb).go();\n        };\n    };\n    function hb(yb) {\n        if (z) {\n            return\n        };\n        (yb && yb.forEach(gb));\n        aa.reset();\n    };\n    function ib() {\n        var yb = [];\n        for (var zb in v) {\n            yb.push(zb);;\n        };\n        nb(yb);\n        kb();\n    };\n    function jb(yb) {\n        ((v[yb].animations && v[yb].animations.length) && v[yb].animations.forEach(function(zb) {\n            zb.stop();\n        }));\n        v[yb].animations = [];\n    };\n    function kb() {\n        z = true;\n        for (var yb in v) {\n            jb(yb);\n            n.set(v[yb].obj, \"opacity\", 1);\n            n.set(v[yb].obj, \"height\", \"auto\");\n            (v[yb].delay && clearTimeout(v[yb].delay));\n            v[yb].delay = null;\n            v[yb].state = oa;\n        };\n        lb();\n        ba = (ba || Event.listen(r, \"mouseout\", mb));\n    };\n    function lb() {\n        if (t) {\n            t.stop();\n            t = null;\n        }\n    ;\n        n.set(r, \"opacity\", 1);\n    };\n    function mb() {\n        z = false;\n        for (var yb in v) {\n            fb(yb, la);;\n        };\n        (ba && ba.remove());\n        ba = null;\n    };\n    function nb(yb) {\n        (a.presenceNotifications && a.presenceNotifications.markRead(true, yb));\n    };\n    function ob(yb) {\n        rb(yb);\n        nb([yb,]);\n        mb();\n    };\n    function pb() {\n        var yb = j.scry(r, (\".\" + da)), zb = yb[0], ac = yb[(yb.length - 1)];\n        j.scry(r, (\".\" + ea)).forEach(function(bc) {\n            i.removeClass(bc, ea);\n        });\n        j.scry(r, (\".\" + fa)).forEach(function(bc) {\n            i.removeClass(bc, fa);\n        });\n        (zb && i.addClass(zb, ea));\n        (ac && i.addClass(ac, fa));\n    };\n    function qb(yb, zb, ac, bc, cc) {\n        if (o.isShown()) {\n            aa.append(bc, qb.curry(yb, zb, ac, bc, cc));\n            return;\n        }\n    ;\n        if ((bc in v)) {\n            rb(bc);\n        };\n        (s && j.appendContent(s, cc));\n        var dc = ta();\n        v[bc] = {\n            obj: cc\n        };\n        u++;\n        i.addClass(cc, da);\n        pb();\n        (!ma && n.set(cc, \"opacity\", yb));\n        (dc && wa());\n        h.notify(j.getText(cc));\n        var ec = j.scry(cc, \".notifMainLink\"), fc = null;\n        if ((ec.length == 1)) {\n            fc = ec[0];\n        }\n         else {\n            fc = j.find(cc, \"a\");\n            i.addClass(fc, \"notifMainLink\");\n        }\n    ;\n        v[bc].beepClick = Event.listen(fc, \"click\", ob.curry(bc));\n        switch (ac) {\n          case na:\n            eb(bc, zb);\n            break;\n          case oa:\n            fb(bc, sa);\n            break;\n          case pa:\n            gb(bc);\n            break;\n        };\n    };\n    function rb(yb) {\n        var zb = ((yb in v) && v[yb].obj);\n        if (!zb) {\n            return\n        };\n        jb(yb);\n        (v[yb].beepClick && v[yb].beepClick.remove());\n        clearTimeout(v[yb].delay);\n        var ac = [\"opacity\",\"height\",];\n        ac.forEach(function(bc) {\n            var cc = n.get(v[yb].obj, bc);\n            if ((cc !== \"\")) {\n                v[yb][bc] = cc;\n            };\n        });\n        i.removeClass(zb, da);\n        pb();\n        n.set(zb, \"opacity\", 1);\n        n.set(zb, \"height\", \"auto\");\n        w[yb] = v[yb];\n        delete v[yb];\n        u--;\n        (s && j.remove(zb));\n        (ta() && xa());\n    };\n    function sb(yb, zb, ac) {\n        rb(yb);\n        var bc = w[yb];\n        if (!bc) {\n            return\n        };\n        qb(bc.opacity, bc.height, bc.state, zb, ac);\n    };\n    function tb() {\n        aa.reset();\n        for (var yb in v) {\n            rb(yb);;\n        };\n    };\n    function ub(yb) {\n        var zb = q(l(yb.html).getNodes()[0]);\n        m.localizeUrls(zb);\n        rb(yb.alertId);\n        qb(0, 0, na, yb.alertId, zb);\n    };\n    function vb(yb) {\n        if ((yb >= 0)) {\n            qa = yb;\n        };\n    };\n    function wb(yb) {\n        if ((yb >= 0)) {\n            ra = yb;\n        };\n    };\n    function xb(yb) {\n        if ((yb >= 0)) {\n            sa = yb;\n        };\n    };\n    e.exports = {\n        addBeep: qb.curry(0, 0, na),\n        clearBeeps: tb,\n        empty: ta,\n        fadeOutBeeps: hb,\n        fromMessage: ub,\n        hasBeeps: ua,\n        init: va,\n        removeBeep: rb,\n        setFadeInDuration: vb,\n        setFadeOutDelay: xb,\n        setFadeOutDuration: wb,\n        updateBeep: sb\n    };\n});");
// 3029
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s8f4bb5475aade0f9b4b4603a4336212c66b3b8cd");
// 3030
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"u8TjK\",]);\n}\n;\n;\n__d(\"NotifBeeper\", [\"event-extensions\",\"Animation\",\"ARIA\",\"CSS\",\"DOM\",\"DoublyLinkedListMap\",\"HTML\",\"NotificationList\",\"Style\",\"Toggler\",\"UserAgent\",\"$\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Animation\"), h = b(\"ARIA\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"DoublyLinkedListMap\"), l = b(\"HTML\"), m = b(\"NotificationList\"), n = b(\"Style\"), o = b(\"Toggler\"), p = b(\"UserAgent\"), q = b(\"$\"), r = null, s = null, t = null, u = 0, v = {\n    }, w = {\n    }, x = null, y = null, z = false, aa = new k(), ba = null, ca = null, da = \"fbJewelBeep\", ea = \"fbTopJewelBeep\", fa = \"fbBottomJewelBeep\", ga = \"beeper\", ha = 300, ia = 300, ja = 150, ka = 10000, la = 2000, ma = ((((p.ie() >= 8)) && ((p.ie() < 9)))), na = 1, oa = 2, pa = 3, qa = ha, ra = ia, sa = ka;\n    function ta() {\n        return ((u === 0));\n    };\n;\n    function ua() {\n        return ((!ta() || ((aa.getCount() !== 0))));\n    };\n;\n    function va(yb) {\n        r = yb;\n        o.subscribe(\"show\", function() {\n            tb();\n        });\n        o.subscribe(\"hide\", function() {\n            aa.map(function(ac) {\n                ac();\n            });\n            aa.reset();\n        });\n        var zb = j.scry(r, \".beeperArea .uiScrollableAreaContent\");\n        if (((zb.length === 1))) {\n            s = zb[0];\n        }\n    ;\n    ;\n        x = q(\"fbNotificationsList\");\n    };\n;\n    function wa() {\n        ca = JSBNG__Event.listen(r, \"mouseover\", ib);\n        i.addClass(r, \"hasBeeps\");\n        y = ab();\n        za(ga);\n    };\n;\n    function xa() {\n        ca.remove();\n        i.removeClass(r, \"hasBeeps\");\n        za(y);\n        ya.defer();\n    };\n;\n    function ya() {\n        if (!ta()) {\n            return;\n        }\n    ;\n    ;\n        for (var yb in w) {\n            delete w[yb];\n        ;\n        };\n    ;\n        lb();\n    };\n;\n    function za(yb) {\n        var zb = bb();\n        if (yb) {\n            zb.ref = yb;\n        }\n         else delete zb.ref;\n    ;\n    ;\n        x.setAttribute(\"data-gt\", JSON.stringify(zb));\n    };\n;\n    function ab() {\n        return bb().ref;\n    };\n;\n    function bb() {\n        var yb = x.getAttribute(\"data-gt\");\n        return ((yb ? JSON.parse(yb) : {\n        }));\n    };\n;\n    function cb(yb, zb, ac) {\n        if (ma) {\n            return db(yb, ac);\n        }\n    ;\n    ;\n        return db(yb, ac).to(\"opacity\", zb);\n    };\n;\n    function db(yb, zb, ac) {\n        var bc = ((ac || new g(yb)));\n        return bc.ease(g.ease.both).duration(zb);\n    };\n;\n    function eb(yb, zb) {\n        v[yb].state = na;\n        jb(yb);\n        var ac = ((qa * ((1 - n.getOpacity(v[yb].obj)))));\n        if (!v[yb].animations) {\n            v[yb].animations = [];\n        }\n    ;\n    ;\n        v[yb].animations.push(cb(v[yb].obj, 1, ac).JSBNG__ondone(fb.curry(yb, sa)).go());\n        ((((u > 1)) && v[yb].animations.push(db(v[yb].obj, ja).from(\"height\", zb).to(\"height\", \"auto\").go())));\n        if (((u === 1))) {\n            t = cb(r, 1, ac).go();\n        }\n    ;\n    ;\n    };\n;\n    function fb(yb, zb) {\n        v[yb].state = oa;\n        if (z) {\n            return;\n        }\n    ;\n    ;\n        ((v[yb].delay && JSBNG__clearTimeout(v[yb].delay)));\n        v[yb].delay = gb.curry(yb).defer(zb);\n    };\n;\n    function gb(yb) {\n        if (!((yb in v))) {\n            return;\n        }\n    ;\n    ;\n        v[yb].state = pa;\n        jb(yb);\n        ((v[yb].delay && JSBNG__clearTimeout(v[yb].delay)));\n        var zb = ((ra * n.getOpacity(v[yb].obj)));\n        function ac(bc) {\n            if (((u > 1))) {\n                var cc = ((((zb - ja)) / zb)), dc = bc.checkpoint(cc);\n                return db(v[yb].obj, ja, dc).to(\"height\", 0);\n            }\n             else return bc\n        ;\n        };\n    ;\n        v[yb].animations.push(ac(cb(v[yb].obj, 0, zb)).JSBNG__ondone(rb.curry(yb)).go());\n        if (((u === 1))) {\n            t = cb(r, 0, zb).go();\n        }\n    ;\n    ;\n    };\n;\n    function hb(yb) {\n        if (z) {\n            return;\n        }\n    ;\n    ;\n        ((yb && yb.forEach(gb)));\n        aa.reset();\n    };\n;\n    function ib() {\n        var yb = [];\n        for (var zb in v) {\n            yb.push(zb);\n        ;\n        };\n    ;\n        nb(yb);\n        kb();\n    };\n;\n    function jb(yb) {\n        ((((v[yb].animations && v[yb].animations.length)) && v[yb].animations.forEach(function(zb) {\n            zb.JSBNG__stop();\n        })));\n        v[yb].animations = [];\n    };\n;\n    function kb() {\n        z = true;\n        for (var yb in v) {\n            jb(yb);\n            n.set(v[yb].obj, \"opacity\", 1);\n            n.set(v[yb].obj, \"height\", \"auto\");\n            ((v[yb].delay && JSBNG__clearTimeout(v[yb].delay)));\n            v[yb].delay = null;\n            v[yb].state = oa;\n        };\n    ;\n        lb();\n        ba = ((ba || JSBNG__Event.listen(r, \"mouseout\", mb)));\n    };\n;\n    function lb() {\n        if (t) {\n            t.JSBNG__stop();\n            t = null;\n        }\n    ;\n    ;\n        n.set(r, \"opacity\", 1);\n    };\n;\n    function mb() {\n        z = false;\n        for (var yb in v) {\n            fb(yb, la);\n        ;\n        };\n    ;\n        ((ba && ba.remove()));\n        ba = null;\n    };\n;\n    function nb(yb) {\n        ((a.presenceNotifications && a.presenceNotifications.markRead(true, yb)));\n    };\n;\n    function ob(yb) {\n        rb(yb);\n        nb([yb,]);\n        mb();\n    };\n;\n    function pb() {\n        var yb = j.scry(r, ((\".\" + da))), zb = yb[0], ac = yb[((yb.length - 1))];\n        j.scry(r, ((\".\" + ea))).forEach(function(bc) {\n            i.removeClass(bc, ea);\n        });\n        j.scry(r, ((\".\" + fa))).forEach(function(bc) {\n            i.removeClass(bc, fa);\n        });\n        ((zb && i.addClass(zb, ea)));\n        ((ac && i.addClass(ac, fa)));\n    };\n;\n    function qb(yb, zb, ac, bc, cc) {\n        if (o.isShown()) {\n            aa.append(bc, qb.curry(yb, zb, ac, bc, cc));\n            return;\n        }\n    ;\n    ;\n        if (((bc in v))) {\n            rb(bc);\n        }\n    ;\n    ;\n        ((s && j.appendContent(s, cc)));\n        var dc = ta();\n        v[bc] = {\n            obj: cc\n        };\n        u++;\n        i.addClass(cc, da);\n        pb();\n        ((!ma && n.set(cc, \"opacity\", yb)));\n        ((dc && wa()));\n        h.notify(j.getText(cc));\n        var ec = j.scry(cc, \".notifMainLink\"), fc = null;\n        if (((ec.length == 1))) {\n            fc = ec[0];\n        }\n         else {\n            fc = j.JSBNG__find(cc, \"a\");\n            i.addClass(fc, \"notifMainLink\");\n        }\n    ;\n    ;\n        v[bc].beepClick = JSBNG__Event.listen(fc, \"click\", ob.curry(bc));\n        switch (ac) {\n          case na:\n            eb(bc, zb);\n            break;\n          case oa:\n            fb(bc, sa);\n            break;\n          case pa:\n            gb(bc);\n            break;\n        };\n    ;\n    };\n;\n    function rb(yb) {\n        var zb = ((((yb in v)) && v[yb].obj));\n        if (!zb) {\n            return;\n        }\n    ;\n    ;\n        jb(yb);\n        ((v[yb].beepClick && v[yb].beepClick.remove()));\n        JSBNG__clearTimeout(v[yb].delay);\n        var ac = [\"opacity\",\"height\",];\n        ac.forEach(function(bc) {\n            var cc = n.get(v[yb].obj, bc);\n            if (((cc !== \"\"))) {\n                v[yb][bc] = cc;\n            }\n        ;\n        ;\n        });\n        i.removeClass(zb, da);\n        pb();\n        n.set(zb, \"opacity\", 1);\n        n.set(zb, \"height\", \"auto\");\n        w[yb] = v[yb];\n        delete v[yb];\n        u--;\n        ((s && j.remove(zb)));\n        ((ta() && xa()));\n    };\n;\n    function sb(yb, zb, ac) {\n        rb(yb);\n        var bc = w[yb];\n        if (!bc) {\n            return;\n        }\n    ;\n    ;\n        qb(bc.opacity, bc.height, bc.state, zb, ac);\n    };\n;\n    function tb() {\n        aa.reset();\n        for (var yb in v) {\n            rb(yb);\n        ;\n        };\n    ;\n    };\n;\n    function ub(yb) {\n        var zb = q(l(yb.html).getNodes()[0]);\n        m.localizeUrls(zb);\n        rb(yb.alertId);\n        qb(0, 0, na, yb.alertId, zb);\n    };\n;\n    function vb(yb) {\n        if (((yb >= 0))) {\n            qa = yb;\n        }\n    ;\n    ;\n    };\n;\n    function wb(yb) {\n        if (((yb >= 0))) {\n            ra = yb;\n        }\n    ;\n    ;\n    };\n;\n    function xb(yb) {\n        if (((yb >= 0))) {\n            sa = yb;\n        }\n    ;\n    ;\n    };\n;\n    e.exports = {\n        addBeep: qb.curry(0, 0, na),\n        clearBeeps: tb,\n        empty: ta,\n        fadeOutBeeps: hb,\n        fromMessage: ub,\n        hasBeeps: ua,\n        init: va,\n        removeBeep: rb,\n        setFadeInDuration: vb,\n        setFadeOutDelay: xb,\n        setFadeOutDuration: wb,\n        updateBeep: sb\n    };\n});");
// 3033
JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_84[0](o33,false,o34);
// undefined
o33 = null;
// undefined
o34 = null;
// 3038
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"tZ04z\",]);\n}\n;\n__d(\"BuddyListNub\", [\"event-extensions\",\"Arbiter\",\"AvailableList\",\"ChannelConnection\",\"ChannelConstants\",\"ChatConfig\",\"ChatVisibility\",\"Class\",\"CSS\",\"Dock\",\"DOM\",\"HTML\",\"Keys\",\"NubController\",\"OrderedFriendsList\",\"PresencePrivacy\",\"Selector\",\"Toggler\",\"Vector\",\"copyProperties\",\"ge\",\"tx\",\"MercuryConfig\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"AvailableList\"), i = b(\"ChannelConnection\"), j = b(\"ChannelConstants\"), k = b(\"ChatConfig\"), l = b(\"ChatVisibility\"), m = b(\"Class\"), n = b(\"CSS\"), o = b(\"Dock\"), p = b(\"DOM\"), q = b(\"HTML\"), r = b(\"Keys\"), s = c(\"MercuryConfig\"), t = b(\"NubController\"), u = b(\"OrderedFriendsList\"), v = b(\"PresencePrivacy\"), w = b(\"Selector\"), x = b(\"Toggler\"), y = b(\"Vector\"), z = b(\"copyProperties\"), aa = b(\"ge\"), ba = b(\"tx\"), ca = 32, da = 10;\n    function ea(fa, ga, ha) {\n        this.parent.construct(this);\n        this.parent.init(fa);\n        this.root = fa;\n        this.orderedList = ga;\n        this.typeahead = ha;\n        this.button = p.find(fa, \"a.fbNubButton\");\n        this.label = p.find(fa, \"span.label\");\n        this.body = p.scry(fa, \"div.fbNubFlyoutBody\")[0];\n        var ia = p.find(fa, \"div.fbNubFlyoutTitlebar\");\n        x.createInstance(ia).setSticky(false);\n        ga.subscribe(\"render\", this.flyoutContentChanged.bind(this));\n        ga.setScrollContainer(this.body);\n        h.subscribe(\"buddylist/availability-changed\", this._updateCount.bind(this));\n        g.subscribe(\"chat/connect\", this._handleConnect.bind(this));\n        v.subscribe(\"privacy-user-presence-changed\", this._handleVisibilityChange.bind(this));\n        this.message = p.find(fa, \"div.fbDockChatBuddyListNubMessage div.message\");\n        this.warningMsgText = null;\n        this.warningMsgEventListener = null;\n        this.showWarningTimeout = null;\n        i.subscribe(i.CONNECTED, this._handleChannelConnected.bind(this));\n        i.subscribe(i.SHUTDOWN, this._handleChannelShutdown.bind(this));\n        i.subscribe(i.RECONNECTING, this._handleChannelReconnecting.bind(this));\n        i.subscribe([i.MUTE_WARNING,i.UNMUTE_WARNING,], this._updateView.bind(this));\n        this.subscribe(\"show\", this.onShow.bind(this));\n        this.subscribe(\"hide\", this.onHide.bind(this));\n        this.subscribe(\"resize\", this.onResize.bind(this));\n        Event.listen(fa, \"keydown\", this._onKeyDown.bind(this));\n        Event.listen(this.button, \"click\", this.onButtonClick.bind(this));\n        ha.subscribe([\"respond\",\"reset\",], function(ja, ka) {\n            if (this._isOpen) {\n                var la = this.orderedList.isVisible();\n                if ((((ka && ka.value) && (ka.value === ha.getCore().getValue())) && ha.getView().isVisible())) {\n                    o.setUseMaxHeight(this.root, false);\n                    this.orderedList.hide();\n                }\n                 else this._showBuddyList();\n            ;\n                if ((la !== this.orderedList.isVisible())) {\n                    this.flyoutContentChanged();\n                };\n            }\n        ;\n        }.bind(this));\n        g.subscribe(\"sidebar/show\", this.hide.bind(this));\n        this._orderedListCount = u.getList().length;\n        g.inform(\"buddylist-nub/initialized\", this, g.BEHAVIOR_PERSISTENT);\n        this._handleVisibilityChange();\n    };\n    m.extend(ea, t);\n    z(ea.prototype, {\n        getButton: function() {\n            return this.button;\n        },\n        getRoot: function() {\n            return this.root;\n        },\n        _handleConnect: function(fa) {\n            this._updateView(true);\n        },\n        _getShutdownReason: function(fa) {\n            switch (fa) {\n              case j.HINT_AUTH:\n                return \"Your session has timed out. Please log in.\";\n              case j.HINT_CONN:\n                return ba._(\"Facebook {Chat} is currently unavailable.\", {\n                    Chat: \"Chat\"\n                });\n              case j.HINT_MAINT:\n                return ba._(\"Facebook {Chat} is currently down for maintenance.\", {\n                    Chat: \"Chat\"\n                });\n              default:\n                return ba._(\"Facebook {Chat} is currently unavailable.\", {\n                    Chat: \"Chat\"\n                });\n            };\n        },\n        _getReconnectMsg: function(fa) {\n            var ga;\n            if ((fa === null)) {\n                ga = \"Unable to connect to chat. Check your Internet connection.\";\n            }\n             else if ((fa > k.get(\"warning_countdown_threshold_msec\"))) {\n                var ha = p.create(\"a\", {\n                    href: \"#\",\n                    className: \"fbChatReconnectLink\"\n                }, \"Try again\"), ia = p.create(\"div\", null, ha), ja = ia.innerHTML;\n                ga = q(ba._(\"Unable to connect to chat. {try-again-link}\", {\n                    \"try-again-link\": ja\n                }));\n            }\n             else if ((fa > 1000)) {\n                ga = ba._(\"Unable to connect to chat. Reconnecting in {seconds}...\", {\n                    seconds: Math.floor((fa / 1000))\n                });\n            }\n             else ga = \"Unable to connect to chat. Reconnecting...\";\n            \n            \n        ;\n            return ga;\n        },\n        _resetShowWarningTimeout: function() {\n            if (this.showWarningTimeout) {\n                clearTimeout(this.showWarningTimeout);\n                this.showWarningTimeout = null;\n            }\n        ;\n        },\n        _handleChannelConnected: function(fa) {\n            this._resetShowWarningTimeout();\n            if (this.orderedList.isVisible()) {\n                l.goOnline();\n            };\n            this.warningMsgText = null;\n            this._updateView();\n        },\n        _handleChannelShutdown: function(fa, ga) {\n            this._resetShowWarningTimeout();\n            this.warningMsgText = this._getShutdownReason(ga);\n            this._updateView();\n        },\n        _handleChannelReconnecting: function(fa, ga) {\n            this._resetShowWarningTimeout();\n            this.warningMsgText = this._getReconnectMsg(ga);\n            if ((ga > 1000)) {\n                if ((ga > k.get(\"warning_countdown_threshold_msec\"))) {\n                    if (this.warningMsgEventListener) {\n                        this.warningMsgEventListener.remove();\n                        this.warningMsgEventListener = null;\n                    }\n                ;\n                    this.warningMsgEventListener = Event.listen(this.message, \"click\", function(event) {\n                        if (n.hasClass(event.getTarget(), \"fbChatReconnectLink\")) {\n                            this._tryReconnect();\n                            event.kill();\n                        }\n                    ;\n                    }.bind(this));\n                }\n            ;\n                this.showWarningTimeout = setTimeout(this._handleChannelReconnecting.bind(this, fa, (ga - 1000)), 1000, false);\n            }\n        ;\n            this._updateView();\n        },\n        _tryReconnect: function() {\n            if (i.disconnected()) {\n                i.reconnect();\n            };\n        },\n        _handleVisibilityChange: function() {\n            this._updateView();\n            if (!l.isOnline()) {\n                this.hide();\n            };\n        },\n        _updateView: function(fa) {\n            var ga = aa(\"fbDockChat\");\n            n.conditionClass(ga, \"offline\", !l.isOnline());\n            n.conditionClass(ga, \"error\", i.disconnected());\n            if (i.disconnected()) {\n                p.setContent(this.message, this.warningMsgText);\n            };\n            if (!l.isOnline()) {\n                if (s.ChatControlLanguageChangeGK) {\n                    this._setLabel(ba._(\"{Chat} (Off)\", {\n                        Chat: \"Chat\"\n                    }));\n                }\n                 else this._setLabel(ba._(\"{Chat} (Offline)\", {\n                    Chat: \"Chat\"\n                }));\n            ;\n            }\n             else if (i.disconnected()) {\n                this._setLabel(ba._(\"{Chat} (Disconnected)\", {\n                    Chat: \"Chat\"\n                }));\n            }\n             else {\n                var ha = h.getOnlineCount();\n                if (ha) {\n                    var ia = ba._(\"{Chat} {number-available}\", {\n                        Chat: \"Chat\",\n                        \"number-available\": [\"\\u003Cspan class=\\\"count\\\"\\u003E\",\"(\\u003Cstrong\\u003E\",ha,\"\\u003C/strong\\u003E)\",\"\\u003C/span\\u003E\",].join(\"\")\n                    });\n                    this._setLabel(q(ia));\n                }\n                 else this._setLabel(\"Chat\", fa);\n            ;\n            }\n            \n        ;\n        },\n        onButtonClick: function() {\n            this._conditionallyShowTypeahead();\n            if (n.shown(this.typeahead.getElement())) {\n                var fa = this.subscribe(\"show\", function() {\n                    this.typeahead.getCore().getElement().focus();\n                }.bind(this));\n                this.unsubscribe.bind(this, fa).defer();\n            }\n        ;\n        },\n        onHide: function() {\n            this._isOpen = false;\n            if (this._buddyListRenderSubscription) {\n                this.orderedList.unsubscribe(this._buddyListRenderSubscription);\n                this._buddyListRenderSubscription = null;\n            }\n        ;\n            this.orderedList.hide();\n            this.typeahead.getCore().reset();\n        },\n        _onKeyDown: function(event) {\n            var fa = Event.getKeyCode(event);\n            if (((fa === r.ESC) && !n.hasClass(this.root, \"menuOpened\"))) {\n                this.hide();\n                return false;\n            }\n        ;\n        },\n        onResize: function() {\n            var fa = (y.getElementDimensions(this.body).y - 5);\n            this.orderedList.setNumTopFriends(Math.floor((fa / ca)));\n        },\n        _showBuddyList: function() {\n            if (!this._buddyListRenderSubscription) {\n                this._buddyListRenderSubscription = this.orderedList.subscribe(\"render\", o.setUseMaxHeight.bind(o, this.root, false));\n            };\n            this.orderedList.show();\n        },\n        onShow: function() {\n            this._isOpen = true;\n            if (i.disconnected()) {\n                this._tryReconnect();\n                this._showBuddyList();\n            }\n             else l.goOnline(this._showBuddyList.bind(this));\n        ;\n        },\n        _setLabel: function(fa, ga) {\n            var ha = this.label.cloneNode(true);\n            p.setContent(ha, fa);\n            p.replace(this.label, ha);\n            this.label = ha;\n            (this.throbber && n.conditionShow(this.throbber, !!ga));\n        },\n        _conditionallyShowTypeahead: function() {\n            n.conditionShow(this.typeahead.getElement(), (this._orderedListCount >= da));\n        },\n        _updateCount: function() {\n            this._updateView();\n            this._conditionallyShowTypeahead();\n        }\n    });\n    e.exports = ea;\n});\n__d(\"ChatOnlineFriends\", [\"event-extensions\",\"AvailableList\",\"AvailableListConstants\",\"ChannelConnection\",\"Chat\",\"ChatConfig\",\"ChatVisibility\",\"Class\",\"CSS\",\"DataStore\",\"DOM\",\"OrderedFriendsList\",\"Parent\",\"Run\",\"ShortProfiles\",\"TooltipLink\",\"XHPTemplate\",\"copyProperties\",\"createObjectFrom\",\"ChatTypeaheadBehavior\",\"ChatTypeaheadCore\",\"ChatTypeaheadDataSource\",\"ChatTypeaheadRenderer\",\"Typeahead\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"AvailableList\"), h = b(\"AvailableListConstants\"), i = b(\"ChannelConnection\"), j = b(\"Chat\"), k = b(\"ChatConfig\"), l = b(\"ChatVisibility\"), m = b(\"Class\"), n = b(\"CSS\"), o = b(\"DataStore\"), p = b(\"DOM\"), q = b(\"OrderedFriendsList\"), r = b(\"Parent\"), s = b(\"Run\"), t = b(\"ShortProfiles\"), u = b(\"TooltipLink\"), v = b(\"XHPTemplate\"), w = b(\"copyProperties\"), x = b(\"createObjectFrom\");\n    b(\"ChatTypeaheadBehavior\");\n    b(\"ChatTypeaheadCore\");\n    b(\"ChatTypeaheadDataSource\");\n    b(\"ChatTypeaheadRenderer\");\n    b(\"Typeahead\");\n    function y(aa) {\n        switch (aa) {\n          case h.OFFLINE:\n            return \"chatOffline\";\n          case h.IDLE:\n            return \"chatIdle\";\n          case h.ACTIVE:\n            return \"chatOnline\";\n          case h.MOBILE:\n            return \"chatMobile\";\n        };\n    };\n    var z = function(aa, ba, ca, da, ea, fa, ga) {\n        var ha = (((da && ea)) || ((fa && ga)));\n        if ((((aa && ba) && ca) && ha)) {\n            this.init(aa, ba, ca, da, ea, fa, ga);\n        };\n    };\n    w(z.prototype, {\n        chatFriends: {\n        },\n        chatStatuses: [\"chatOnline\",\"chatIdle\",\"chatMobile\",\"chatOffline\",],\n        _availableListSubscribe: function(event, aa) {\n            this._arbiterTokens.push(g.subscribe(event, aa));\n        },\n        _channelSubscribe: function(event, aa) {\n            this._arbiterTokens.push(i.subscribe(event, aa));\n        },\n        onunload: function() {\n            this._arbiterTokens.forEach(function(aa) {\n                aa.unsubscribe();\n            });\n        },\n        _setStatus: function(aa, ba) {\n            if (n.hasClass(aa, ba)) {\n                return\n            };\n            this.chatStatuses.forEach(function(ca) {\n                n.conditionClass(aa, ca, (ca == ba));\n            });\n        },\n        initTypeahead: function(aa, ba, ca) {\n            aa.subscribe(\"reset\", function() {\n                n.show(ba);\n            });\n            aa.subscribe(\"query\", function(da, ea) {\n                n.conditionShow(ba, !ea.value);\n            });\n            if (ca) {\n                aa.subscribe([\"query\",\"reset\",], function(da) {\n                    n.conditionShow(ca, (da === \"reset\"));\n                });\n            };\n        },\n        init: function(aa, ba, ca, da, ea, fa, ga) {\n            this.maxElements = aa;\n            this._faceTmpl = ea;\n            this._arbiterTokens = [];\n            this._root = ca;\n            s.onLeave(this.onunload.bind(this));\n            var ha = p.scry(ca, \".chatUpgradeLink\");\n            this.initTypeahead(ba, (da || fa), ha[0]);\n            var ia = p.find(ca, \".sidebarBtn\");\n            Event.listen(ia, \"click\", function(event) {\n                j.toggleSidebar();\n                event.kill();\n            });\n            (this._faceFutures && this._hideAllFaces());\n            this._faceFutures = [];\n            this._orderedFriends = q.getList();\n            this._hashedFriends = x(this._orderedFriends);\n            this._availableListSubscribe(h.ON_AVAILABILITY_CHANGED, this.update.shield(this));\n            this.update.bind(this).defer();\n            this._channelSubscribe(i.CONNECTED, this.update.shield(this));\n            this._channelSubscribe(i.RECONNECTING, this._handleChannelReconnecting.bind(this));\n            this._channelSubscribe(i.SHUTDOWN, this._handleChannelShutdown.bind(this));\n            this._channelSubscribe([i.MUTE_WARNING,i.UNMUTE_WARNING,], this.update.shield(this));\n            if (da) {\n                this._facepile = da.firstChild;\n                Event.listen(da, \"click\", this.clickHandler.bind(this));\n            }\n             else {\n                this._miniDivebar = fa;\n                this._divebarTmpl = ga;\n            }\n        ;\n            Event.listen(p.find(ca, \".fbChatGoOnlineLink\"), \"click\", function(event) {\n                if (i.disconnected()) {\n                    j.openBuddyList();\n                }\n                 else l.goOnline(j.openBuddyList);\n            ;\n                event.kill();\n            }.bind(this));\n            Event.listen(p.find(ca, \".fbChatReconnectLink\"), \"click\", function(event) {\n                if (i.disconnected()) {\n                    i.reconnect();\n                };\n                event.kill();\n            }.bind(this));\n            g.update();\n        },\n        _updateMiniDivebar: function() {\n            var aa = Math.min(this._orderedFriends.length, 10), ba = [];\n            for (var ca = 0; (ca < aa); ca++) {\n                ba.push(this._renderDivebarItem(this._orderedFriends[ca]));;\n            };\n            p.setContent(this._miniDivebar, ba);\n        },\n        _renderDivebarItem: function(aa) {\n            var ba = this._divebarTmpl.build(), ca = ba.getNode(\"anchor\"), da = ba.getNode(\"status\"), ea = g.get(aa);\n            if ((ea === h.ACTIVE)) {\n                n.addClass(da, \"active\");\n            }\n             else if ((ea === h.MOBILE)) {\n                n.addClass(da, \"mobile\");\n            }\n        ;\n            t.get(aa, function(fa) {\n                ba.setNodeContent(\"name\", fa.name).setNodeProperty(\"profile-photo\", \"src\", fa.thumbSrc);\n                Event.listen(ca, \"click\", function() {\n                    j.openTab(aa, null, \"friend\", \"online_friends\");\n                    return false;\n                });\n            });\n            return ba.getRoot();\n        },\n        _handleChannelReconnecting: function(aa, ba) {\n            var ca = ((ba < 1000)), da = p.find(this._root, \".fbChatReconnectLink\"), ea = p.find(this._root, \".fbChatReconnecting\");\n            n.conditionShow(da, !ca);\n            n.conditionShow(ea, ca);\n        },\n        _handleChannelShutdown: function() {\n            var aa = p.find(this._root, \".fbChatReconnectLink\"), ba = p.find(this._root, \".fbChatReconnecting\");\n            n.hide(aa);\n            n.hide(ba);\n        },\n        update: function() {\n            var aa = i.disconnected(), ba = l.isOnline();\n            n.conditionClass(this._root, \"disconnected\", aa);\n            if (this._facepile) {\n                n.conditionShow(this._facepile, ba);\n                (ba && this._updateFacepile(aa));\n            }\n             else (ba && this._updateMiniDivebar());\n        ;\n            var ca = p.find(this._root, \".typeaheadContainer\");\n            n.conditionShow(ca, ba);\n            if (k.get(\"chat_upgrade_link\")) {\n                var da = p.find(this._root, \".chatUpgradeLink\");\n                n.conditionShow(da, ba);\n            }\n        ;\n            var ea = p.find(this._root, \".chatGoOnlineLink\");\n            n.conditionShow(ea, !ba);\n            var fa = p.find(this._root, \".chatReconnectLink\");\n            n.conditionShow(fa, (ba && aa));\n        },\n        _updateFacepile: function(aa) {\n            g.getAvailableIDs().forEach(function(ha) {\n                if (!this._hashedFriends[ha]) {\n                    this._orderedFriends.push(ha);\n                    this._hashedFriends[ha] = true;\n                }\n            ;\n            }.bind(this));\n            var ba = 0;\n            for (var ca = 0; (ca < this._orderedFriends.length); ca++) {\n                var da = this._orderedFriends[ca], ea = g.get(da), fa = this._faceFutures[ca], ga = (((aa || (ea !== h.OFFLINE))) && ((ba < this.maxElements)));\n                if (ga) {\n                    if (!fa) {\n                        fa = this._makeFace(ca);\n                        this._faceFutures[ca] = fa;\n                    }\n                ;\n                    ba++;\n                }\n            ;\n                this._updateFace(fa, ga, y(ea));\n            };\n        },\n        _updateFace: function(aa, ba, ca) {\n            (aa && aa(function(da) {\n                this._setStatus(da, ca);\n                n.conditionShow(da, ba);\n            }.bind(this)));\n        },\n        _makeFace: function(aa) {\n            var ba = null, ca = null, da = this._orderedFriends[aa];\n            t.get(da, function(ea) {\n                ca = this._faceTmpl.render();\n                o.set(ca, \"friendID\", da);\n                var fa = v.getNode(ca, \"img\"), ga = fa.cloneNode(false);\n                ga.setAttribute(\"src\", ea.thumbSrc);\n                p.replace(fa, ga);\n                var ha = v.getNode(ca, \"anchor\");\n                u.setTooltipText(ha, ea.name);\n                (ba && ba(ca));\n                var ia = false;\n                for (var ja = (aa + 1); ((ja < this._orderedFriends.length) && !ia); ja++) {\n                    var ka = this._faceFutures[ja], la = (ka && ka());\n                    if (la) {\n                        this._facepile.insertBefore(ca, la);\n                        ia = true;\n                    }\n                ;\n                };\n                if (!ia) {\n                    this._facepile.appendChild(ca);\n                };\n            }.bind(this));\n            return function ea(fa) {\n                if (fa) {\n                    if (ca) {\n                        fa(ca);\n                    }\n                     else ba = fa;\n                \n                };\n                return ca;\n            };\n        },\n        clickHandler: function(event) {\n            var aa = event.getTarget(), ba = r.byClass(aa, \"uiFacepileItem\");\n            if (ba) {\n                var ca = o.get(ba, \"friendID\");\n                if ((ca && l.isOnline())) {\n                    j.openTab(ca, null, \"friend\", \"online_friends\");\n                    return false;\n                }\n            ;\n            }\n        ;\n        },\n        _hideAllFaces: function() {\n            this._faceFutures.forEach(function(aa) {\n                (aa && aa(function(ba) {\n                    p.remove(ba);\n                }));\n            });\n        }\n    });\n    e.exports = z;\n});\n__d(\"LiveBarData\", [\"function-extensions\",\"Arbiter\",\"ArbiterMixin\",\"AsyncRequest\",\"ChannelConstants\",\"LayerDestroyOnHide\",\"copyProperties\",\"setTimeoutAcrossTransitions\",\"throttle\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"AsyncRequest\"), j = b(\"ChannelConstants\"), k = b(\"LayerDestroyOnHide\"), l = b(\"copyProperties\"), m = b(\"setTimeoutAcrossTransitions\"), n = b(\"throttle\"), o = false, p = {\n    }, q = {\n    }, r = {\n    };\n    function s(z) {\n        if (((((z.expires * 1000)) - Date.now()) > 0)) {\n            return true\n        };\n        return false;\n    };\n    function t(z) {\n        var aa = z.payload.actions;\n        if (!((aa && aa.length))) {\n            return\n        };\n        var ba;\n        for (var ca = 0; (ca < aa.length); ca++) {\n            ba = aa[ca].actor_id;\n            if ((!p[ba] || (aa[ca].action_id != p[ba].action_id))) {\n                continue;\n            };\n            if ((aa[ca].delete_action || aa[ca].remove)) {\n                w(aa[ca]);\n                continue;\n            }\n        ;\n        };\n    };\n    function u(z) {\n        var aa = false;\n        for (var ba = 0; (ba < z.length); ba++) {\n            if ((z[ba].delete_action || z[ba].remove)) {\n                w(z[ba]);\n                continue;\n            }\n        ;\n            var ca = z[ba].actor_id, da = z[ba].action_id;\n            if (p[ca]) {\n                if ((p[ca].action_id == da)) {\n                    continue;\n                };\n                w(p[ca]);\n            }\n        ;\n            aa = true;\n            p[ca] = z[ba];\n            v(z[ba]);\n        };\n        if (aa) {\n            y.inform(\"new-actions\");\n        };\n    };\n    function v(z) {\n        var aa = (((z.expires * 1000)) - Date.now());\n        q[z.actor_id] = m(w.curry(z), Math.max(0, aa));\n    };\n    function w(z) {\n        if (!p[z.actor_id]) {\n            return\n        };\n        if ((p[z.actor_id].action_id != z.action_id)) {\n            return\n        };\n        delete p[z.actor_id];\n        var aa = z.actor_id;\n        if (q[aa]) {\n            clearTimeout(q[aa]);\n            delete q[aa];\n        }\n    ;\n        x(aa);\n        y.inform(\"remove-action\", z);\n    };\n    function x(z) {\n        var aa = r[z];\n        if (aa) {\n            aa.enableBehavior(k);\n            if (!aa.isShown()) {\n                aa.destroy();\n            };\n            delete r[z];\n        }\n    ;\n    };\n    g.subscribe(j.getArbiterType(\"livebar_update\"), function(z, aa) {\n        u(aa.obj.actions);\n    });\n    var y = {\n    };\n    l(y, h, {\n        fetch: function() {\n            if (o) {\n                return\n            };\n            var z = [];\n            for (var aa in p) {\n                var ba = p[aa];\n                if (!r[ba.actor_id]) {\n                    z.push(p[aa]);\n                };\n            };\n            if ((z.length > 0)) {\n                o = true;\n                new i().setURI(\"/ajax/chat/livebar.php\").setData({\n                    actions: z\n                }).setHandler(t).setFinallyHandler(function() {\n                    o = false;\n                }).setAllowCrossPageTransition(true).send();\n            }\n        ;\n        },\n        addActions: u,\n        getAction: function(z) {\n            var aa = p[z];\n            if ((aa && s(aa))) {\n                return aa\n            };\n            return null;\n        },\n        getDialog: function(z) {\n            var aa = this.getAction(z);\n            if ((aa && r[aa.actor_id])) {\n                return r[aa.actor_id]\n            };\n            return null;\n        },\n        setDialog: function(z, aa, ba) {\n            var ca = p[z];\n            if ((ca && (ca.action_id == aa))) {\n                x(z);\n                r[z] = ba;\n                y.inform(\"dialog-fetched\", z);\n            }\n        ;\n        }\n    });\n    e.exports = y;\n});\n__d(\"LiveBar\", [\"event-extensions\",\"function-extensions\",\"ChatConfig\",\"CSS\",\"LiveBarData\",\"$\",\"copyProperties\",\"ge\",\"setTimeoutAcrossTransitions\",\"tx\",\"ChatOrderedList\",\"ContextualDialogX\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"ChatConfig\"), h = b(\"CSS\"), i = b(\"LiveBarData\"), j = b(\"$\"), k = b(\"copyProperties\"), l = b(\"ge\"), m = b(\"setTimeoutAcrossTransitions\"), n = b(\"tx\");\n    b(\"ChatOrderedList\");\n    b(\"ContextualDialogX\");\n    var o = (g.get(\"livebar_fetch_defer\") || 1000);\n    function p(q, r, s) {\n        this._orderedList = q;\n        this._root = q.getRoot();\n        this._liveBarTypes = s;\n        this._hoverController = q.getHoverController();\n        this._hoverController.subscribe(\"hover\", this._mouseMove.bind(this));\n        this._hoverController.subscribe(\"leave\", this._mouseLeave.bind(this));\n        q.subscribe(\"render\", this._handleChatListUpdate.shield(this));\n        i.subscribe(\"new-actions\", this._updateIcons.bind(this));\n        i.subscribe(\"remove-action\", this._handleRemoveAction.bind(this));\n        i.subscribe(\"dialog-fetched\", function(t, u) {\n            this._setDialogContent(u);\n        }.bind(this));\n        i.addActions(r);\n    };\n    k(p, {\n        setDialog: function(q, r, s) {\n            i.setDialog(q, r, s);\n        }\n    });\n    k(p.prototype, {\n        _root: null,\n        _liveBarTypes: null,\n        _hoverController: null,\n        _registrations: {\n        },\n        _renderedIcons: {\n        },\n        _fetchTimer: null,\n        _mouseLeftRoot: false,\n        _chatListRendered: false,\n        _getLiveBarTypes: function() {\n            return this._liveBarTypes;\n        },\n        _handleChatListUpdate: function() {\n            if (!this._chatListRendered) {\n                this._chatListRendered = true;\n                this._updateIcons();\n            }\n        ;\n        },\n        _handleShow: function(q) {\n            this._setDialogContent(q);\n        },\n        _mouseMove: function() {\n            if (!this._fetchTimer) {\n                this._fetchTimer = m(this._fetch.bind(this), o);\n                this._mouseLeftRoot = false;\n            }\n        ;\n        },\n        _mouseLeave: function() {\n            this._mouseLeftRoot = true;\n            clearTimeout(this._fetchTimer);\n            this._fetchTimer = null;\n        },\n        _setDialogContent: function(q) {\n            var r = i.getDialog(q);\n            if (r) {\n                this._hoverController.showHovercard(q, r);\n            };\n        },\n        _fetch: function() {\n            if (this._mouseLeftRoot) {\n                return\n            };\n            this._fetchTimer = null;\n            i.fetch();\n        },\n        _updateIcons: function() {\n            if (!this._chatListRendered) {\n                return\n            };\n            var q = this._orderedList.getAllNodes(), r = this._getLiveBarTypes();\n            for (var s in q) {\n                var t = i.getAction(s);\n                if ((t && ((!this._renderedIcons[s] || (this._renderedIcons[s] != t.action_id))))) {\n                    for (var u = 0; (u < r.length); u++) {\n                        h.removeClass(q[s], r[u]);;\n                    };\n                    h.addClass(q[s], t.livebar_type);\n                    this._renderedIcons[s] = t.action_id;\n                    var v = this._hoverController.register(s, this._handleShow.bind(this));\n                    if (v) {\n                        this._registrations[s] = v;\n                    };\n                }\n            ;\n            };\n        },\n        _handleRemoveAction: function(q, r) {\n            var s = r.action_id, t = r.actor_id;\n            (this._registrations[t] && this._registrations[t].unregister());\n            delete this._registrations[t];\n            if ((this._renderedIcons[t] == s)) {\n                var u = this._getLiveBarTypes(), v = this._orderedList.getAllNodes();\n                if (v[t]) {\n                    for (var w = 0; (w < u.length); w++) {\n                        h.removeClass(v[t], u[w]);;\n                    }\n                };\n                delete this._renderedIcons[t];\n            }\n        ;\n        }\n    });\n    e.exports = p;\n});\n__d(\"LiveBarDark\", [\"Class\",\"LiveBar\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Class\"), h = b(\"LiveBar\"), i = b(\"copyProperties\");\n    function j(k, l, m) {\n        this.parent.construct(this, k, l, m);\n    };\n    g.extend(j, h);\n    i(j.prototype, {\n        _setupDialogContent: bagofholding,\n        _show: bagofholding,\n        _updateIcons: bagofholding,\n        _handleRemoveAction: bagofholding,\n        _handleChatListUpdate: bagofholding\n    });\n    e.exports = j;\n});\n__d(\"ChatSidebarDropdown\", [\"Arbiter\",\"AsyncRequest\",\"Chat\",\"ChatOptions\",\"ChatVisibility\",\"CSS\",\"DOM\",\"JSLogger\",\"PresenceState\",\"Selector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"Chat\"), j = b(\"ChatOptions\"), k = b(\"ChatVisibility\"), l = b(\"CSS\"), m = b(\"DOM\"), n = b(\"JSLogger\"), o = b(\"PresenceState\"), p = b(\"Selector\"), q = b(\"copyProperties\");\n    function r(s) {\n        this._root = s;\n        this._logger = n.create(\"blackbird\");\n        this._displayBrowserNotificationsIfNeeded();\n        p.listen(s, \"select\", this._onSelect.bind(this));\n        p.listen(s, \"toggle\", this._onToggle.bind(this));\n        g.subscribe(\"chat/option-changed\", this._onOptionChanged.bind(this));\n    };\n    q(r.prototype, {\n        changeSetting: function(s, t) {\n            if (this._pendingChange) {\n                return false\n            };\n            this._pendingChange = true;\n            var u = {\n            };\n            u[s] = t;\n            j.setSetting(s, t, \"sidebar_menu\");\n            new h(\"/ajax/chat/settings.php\").setHandler(this._onChangeSettingResponse.bind(this, s, t)).setErrorHandler(this._onChangeSettingError.bind(this, s, t)).setFinallyHandler(this._onChangeFinally.bind(this)).setData(u).setAllowCrossPageTransition(true).send();\n        },\n        _displayBrowserNotificationsIfNeeded: function() {\n            if (window.webkitNotifications) {\n                m.scry(document, \"li.sidebar-browser-notif\").forEach(l.show);\n                if ((window.webkitNotifications.checkPermission() !== 0)) {\n                    m.scry(document, \"li.sidebar-browser-notif\").forEach(function(s) {\n                        l.removeClass(s, \"checked\");\n                    });\n                };\n            }\n        ;\n        },\n        _conditionEnabled: function(s, t) {\n            var u = p.getOption(this._root, s);\n            (u && p.setOptionEnabled(u, t));\n        },\n        _onChangeSettingResponse: function(s, t, u) {\n            o.doSync();\n        },\n        _onChangeSettingError: function(s, t, u) {\n            j.setSetting(s, !t, \"sidebar_menu_error\");\n        },\n        _onChangeFinally: function() {\n            this._pendingChange = false;\n        },\n        _onOptionChanged: function(s, t) {\n            var u = t.name, v = t.value;\n            if (((u === \"sound\") || (u === \"browser_notif\"))) {\n                var w = p.getOption(this._root, u);\n                if ((v !== p.isOptionSelected(w))) {\n                    p.setSelected(this._root, u, v);\n                };\n            }\n        ;\n        },\n        _onSelect: function(s) {\n            if (this._pendingChange) {\n                return false\n            };\n            var t = false, u = false, v = p.getOptionValue(s.option);\n            switch (v) {\n              case \"sidebar\":\n                return this.toggleSidebar();\n              case \"online\":\n                if (!k.isOnline()) {\n                    k.goOnline();\n                }\n                 else u = true;\n            ;\n                t = true;\n                break;\n              case \"offline\":\n                if (k.isOnline()) {\n                    k.goOffline();\n                }\n                 else u = true;\n            ;\n                t = true;\n                break;\n              case \"advanced_settings\":\n                g.inform(\"chat/advanced-settings-dialog-opened\");\n                t = true;\n                break;\n            };\n            if (u) {\n                this._logger.error(\"sidebar_dropdown_visibility_error\", {\n                    action: v\n                });\n            }\n             else this._logger.log(\"sidebar_dropdown_set_visibility\", {\n                action: v\n            });\n        ;\n            if (t) {\n                p.toggle(this._root);\n                return false;\n            }\n        ;\n        },\n        _onToggle: function(s) {\n            if (this._pendingChange) {\n                return false\n            };\n            var t = p.getOptionValue(s.option), u = p.isOptionSelected(s.option);\n            switch (t) {\n              case \"visibility\":\n                if (!k) {\n                    this._jslogger.error(\"on_toggle_visibility_undefined\");\n                    return;\n                }\n            ;\n                k.toggleVisibility();\n                this._logger.log(\"sidebar_dropdown_toggle_visibility\", {\n                    available: u\n                });\n                break;\n              case \"browser_notif\":\n                if (((u && window.webkitNotifications) && (window.webkitNotifications.checkPermission() !== 0))) {\n                    window.webkitNotifications.requestPermission(function() {\n                        this.changeSetting(t, u);\n                    }.bind(this));\n                }\n                 else this.changeSetting(t, u);\n            ;\n                break;\n              case \"sound\":\n                this.changeSetting(t, u);\n                break;\n            };\n            p.toggle(this._root);\n        },\n        _onVisibilityChanged: function() {\n            var s = k.isOnline(), t = p.getOption(this._root, \"visibility\");\n            if ((s !== p.isOptionSelected(t))) {\n                p.setSelected(this._root, \"visibility\", s);\n            };\n        },\n        toggleSidebar: function() {\n            i.toggleSidebar();\n            p.toggle(this._root);\n            return false;\n        }\n    });\n    e.exports = r;\n});\n__d(\"MercuryUnreadState\", [\"Arbiter\",\"copyProperties\",\"MercuryFolders\",\"JSLogger\",\"KeyedCallbackManager\",\"createObjectFrom\",\"MercuryServerRequests\",\"MercuryThreadInformer\",\"MercuryThreads\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"copyProperties\"), i = b(\"MercuryFolders\"), j = b(\"JSLogger\"), k = b(\"KeyedCallbackManager\"), l = b(\"createObjectFrom\"), m = b(\"MercuryServerRequests\"), n = b(\"MercuryThreadInformer\"), o = b(\"MercuryThreads\"), p = c(\"MercuryConstants\"), q = ((i.getSupportedFolders() || [])).filter(function(la) {\n        return (la != p.MessagingTag.ACTION_ARCHIVED);\n    }), r = {\n    }, s = {\n    }, t = {\n    };\n    q.forEach(function(la) {\n        r[la] = 0;\n        s[la] = false;\n        t[la] = new k();\n    });\n    var u = \"unread_thread_hash\", v = \"unseen_thread_list\", w = p.MercuryThreadlistConstants.MAX_UNREAD_COUNT, x = j.create(\"mercury_unread_state\"), y = {\n        getUnreadCount: function(la) {\n            if (y.exceedsMaxCount(la)) {\n                x.error(\"unguarded_unread_count_fetch\", {\n                });\n                return 0;\n            }\n        ;\n            return ca(la);\n        },\n        exceedsMaxCount: function(la) {\n            return (s[la] || ((ca(la) > w)));\n        },\n        markFolderAsRead: function(la) {\n            if ((s[la] || (ca(la) > 0))) {\n                m.markFolderAsRead(la);\n            };\n        }\n    };\n    function z(la, ma) {\n        t[la].setResource(u, ma);\n        t[la].setResource(v, Object.keys(ma));\n    };\n    function aa(la, ma) {\n        var na = t[la].executeOrEnqueue(u, ma), oa = t[la].getUnavailableResources(na);\n        if (oa.length) {\n            m.fetchUnreadThreadIDs(la);\n        };\n    };\n    function ba(la) {\n        return t[la].getResource(u);\n    };\n    function ca(la) {\n        var ma = t[la].getResource(v);\n        if (ma) {\n            return ma.length;\n        }\n         else return r[la]\n    ;\n    };\n    function da(la) {\n        var ma;\n        ((la.unread_thread_ids || [])).forEach(function(na) {\n            ma = na.folder;\n            if (!ka(ma)) {\n                return\n            };\n            var oa = ia(na.thread_ids);\n            z(ma, l(oa, true));\n            if ((oa.length > w)) {\n                s[ma] = true;\n            };\n            n.updatedUnreadState();\n        });\n        ((la.message_counts || [])).forEach(function(na) {\n            if ((na.unread_count === undefined)) {\n                return\n            };\n            ma = na.folder;\n            if ((na.unread_count > w)) {\n                s[ma] = true;\n                z(ma, {\n                });\n                n.updatedUnreadState();\n            }\n             else {\n                r[ma] = na.unread_count;\n                if ((r[ma] === 0)) {\n                    z(ma, {\n                    });\n                };\n                n.updatedUnreadState();\n            }\n        ;\n        });\n        ((la.actions || [])).forEach(function(na) {\n            if (na.is_forward) {\n                return\n            };\n            var oa = p.MercuryActionType, pa = (na.thread_id ? na.thread_id : na.server_thread_id);\n            if ((na.action_type == oa.DELETE_THREAD)) {\n                q.forEach(function(ra) {\n                    ga(ra, pa);\n                });\n            }\n             else if (((na.action_type == oa.CHANGE_ARCHIVED_STATUS) || (na.action_type == oa.CHANGE_FOLDER))) {\n                var qa = o.getThreadMetaNow(na.thread_id);\n                ma = i.getFromMeta(qa);\n                if ((ka(ma) && (qa.unread_count > 0))) {\n                    fa(ma, pa);\n                };\n                q.forEach(function(ra) {\n                    if ((ra != ma)) {\n                        ga(ra, pa);\n                    };\n                });\n            }\n             else {\n                ma = na.folder;\n                if (!ka(ma)) {\n                    return\n                };\n                if ((na.action_type == oa.CHANGE_READ_STATUS)) {\n                    ea(ma, pa, na.mark_as_read);\n                }\n                 else if (((na.action_type == oa.USER_GENERATED_MESSAGE) || (na.action_type == oa.LOG_MESSAGE))) {\n                    if (na.is_unread) {\n                        fa(ma, pa);\n                    }\n                }\n            ;\n            }\n            \n        ;\n        });\n    };\n    function ea(la, ma, na) {\n        if (na) {\n            ga(la, ma);\n        }\n         else fa(la, ma);\n    ;\n    };\n    function fa(la, ma) {\n        if (s[la]) {\n            return\n        };\n        aa(la, function(na) {\n            if (!na[ma]) {\n                na[ma] = true;\n                z(la, na);\n                n.updatedUnreadState();\n            }\n        ;\n        });\n    };\n    function ga(la, ma) {\n        if (s[la]) {\n            return\n        };\n        aa(la, function(na) {\n            if (na[ma]) {\n                delete na[ma];\n                z(la, na);\n                n.updatedUnreadState();\n            }\n        ;\n        });\n    };\n    function ha(la) {\n        s[la] = false;\n        z(la, {\n        });\n        n.updatedUnreadState();\n    };\n    function ia(la) {\n        return la.map(m.convertThreadIDIfAvailable);\n    };\n    function ja(la) {\n        q.forEach(function(ma) {\n            var na = ba(ma);\n            if (!na) {\n                return\n            };\n            for (var oa in la) {\n                var pa = la[oa];\n                if (na[oa]) {\n                    na[pa] = na[oa];\n                    delete na[oa];\n                }\n            ;\n            };\n            z(ma, na);\n        });\n    };\n    function ka(la) {\n        return q.contains(la);\n    };\n    m.subscribe(\"update-unread\", function(la, ma) {\n        da(ma);\n        var na = (ma.global_actions || []);\n        for (var oa = 0; (oa < na.length); oa++) {\n            var pa = na[oa];\n            if ((pa.action_type == p.MercuryGlobalActionType.MARK_ALL_READ)) {\n                ha(pa.folder);\n            };\n        };\n    });\n    m.subscribe(\"update-thread-ids\", function(la, ma) {\n        ja(ma);\n    });\n    g.subscribe(j.DUMP_EVENT, function(la, ma) {\n        ma.messaging = (ma.messaging || {\n        });\n        ma.messaging.unread = {\n        };\n        ma.messaging.unread_max_count = {\n        };\n        q.forEach(function(na) {\n            ma.messaging.unread[na] = h({\n            }, ba(na));\n            ma.messaging.unread_max_count[na] = s[na];\n        });\n    });\n    e.exports = y;\n});\n__d(\"MercuryLeftNavCountControl\", [\"Arbiter\",\"CSS\",\"DOM\",\"URI\",\"MercuryUnreadState\",\"MercuryServerRequests\",\"MercuryThreadInformer\",\"copyProperties\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"URI\"), k = b(\"MercuryUnreadState\"), l = b(\"MercuryServerRequests\"), m = b(\"MercuryThreadInformer\"), n = c(\"MercuryConstants\"), o = b(\"copyProperties\"), p, q, r = function(s, t) {\n        p = s;\n        q = t;\n        this.render();\n        this.listenerToken = m.subscribe(\"unread-updated\", this.render.bind(this));\n        this.subscriptions = [g.subscribe(\"onload/exit\", this.cleanup.bind(this)),];\n    };\n    o(r.prototype, {\n        render: function() {\n            var s = k.exceedsMaxCount(n.MessagingTag.INBOX);\n            if (s) {\n                i.setContent(p, n.MercuryThreadlistConstants.MAX_UNREAD_COUNT);\n            }\n             else {\n                var t = k.getUnreadCount(n.MessagingTag.INBOX);\n                i.setContent(p, t.toString());\n                h.conditionClass(p.parentNode, \"hidden_elem\", (t <= 0));\n            }\n        ;\n            i.setContent(q, (s ? \"+\" : \"\"));\n        },\n        cleanup: function() {\n            this.subscriptions.forEach(g.unsubscribe);\n            m.unsubscribe(this.listenerToken);\n        }\n    });\n    e.exports = r;\n});\n__d(\"MercuryLeftNav\", [\"DOM\",\"MercuryServerRequests\",\"MercuryLeftNavCountControl\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"MercuryServerRequests\"), i = b(\"MercuryLeftNavCountControl\");\n    e.exports = function(j, k) {\n        h.handleUpdate(k);\n        var l = g.scry(j, \"span.countValue\")[0], m = g.scry(j, \"span.maxCountIndicator\")[0], n = new i(l, m);\n    };\n});\n__d(\"MercuryTitanReadViewIntegration\", [\"Arbiter\",\"ChatTabModel\",\"MercuryServerRequests\",\"MercuryThreads\",\"UserActivity\",\"copyProperties\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ChatTabModel\"), i = b(\"MercuryServerRequests\"), j = b(\"MercuryThreads\"), k = b(\"UserActivity\"), l = c(\"MercuryConstants\"), m = b(\"copyProperties\"), n = function(p, q) {\n        this._clientID = o(p, q);\n        this._markAsReadSubscription = i.subscribe(\"model-update-completed\", this.markAsRead.bind(this));\n        h.squelchTab(this._clientID);\n    };\n    m(n.prototype, {\n        markAsRead: function() {\n            if (!k.isActive(l.MessagingConfig.IDLE_CUTOFF)) {\n                return\n            };\n            j.changeThreadReadStatus(this._clientID, true);\n        },\n        openInChat: function() {\n            g.inform(\"chat/open-tab\", {\n                thread_id: this._clientID\n            });\n        },\n        unload: function() {\n            i.unsubscribe(this._markAsReadSubscription);\n            h.clearSquelchedTab();\n        }\n    });\n    function o(p, q) {\n        var r = p.tid, s = i.getClientThreadIDNow(r);\n        if (!s) {\n            var t = null;\n            if ((p.single_thread_id && !p.canonical_participant)) {\n                p.canonical_participant = (\"fbid:\" + p.single_thread_id);\n            };\n            if (p.canonical_participant) {\n                t = j.getCanonicalThreadToParticipant(p.canonical_participant, p.unread_count);\n                s = t.thread_id;\n                var u = m({\n                }, t);\n                u.thread_id = r;\n                i.handleUpdate({\n                    threads: [u,]\n                });\n            }\n             else {\n                var v = p.mercury_data;\n                t = {\n                    thread_id: r,\n                    participants: v.participants,\n                    name: v.name,\n                    unread_count: p.unread_count,\n                    image_src: v.image_src,\n                    timestamp: v.timestamp,\n                    is_canonical_user: false,\n                    is_subscribed: !p.unsubscribed,\n                    is_canonical_group: false,\n                    is_chatlogger_thread: false,\n                    root_message_threading_id: v.root_message_threading_id,\n                    folder: p.folder,\n                    is_archived: q.archived,\n                    mode: l.MercuryThreadMode.TITAN_ORIGINATED\n                };\n                i.handleUpdate({\n                    threads: [t,]\n                });\n                s = i.getClientThreadIDNow(r);\n            }\n        ;\n        }\n    ;\n        return s;\n    };\n    e.exports = n;\n});\nwindow.init_live_message_receive = (window.init_live_message_receive || function(a) {\n    window.init_live_message_receive = bagofholding;\n    Arbiter.subscribe(ChannelConstants.getArbiterType(\"app_msg\"), function(b, c) {\n        if ((c.obj.event_name == \"beep_event\")) {\n            Bootloader.loadComponents(\"beeper\", function() {\n                Beeper.ensureInitialized();\n                Beeper.setParams(a);\n                LiveMessageReceiver.route(c.obj);\n            });\n        }\n         else LiveMessageReceiver.route(c.obj);\n    ;\n    });\n});");
// 3039
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s1b1d6aaa8912c7fb2779ca0f362b9400f765c7d2");
// 3040
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"tZ04z\",]);\n}\n;\n;\n__d(\"BuddyListNub\", [\"event-extensions\",\"Arbiter\",\"AvailableList\",\"ChannelConnection\",\"ChannelConstants\",\"ChatConfig\",\"ChatVisibility\",\"Class\",\"CSS\",\"Dock\",\"DOM\",\"HTML\",\"Keys\",\"NubController\",\"OrderedFriendsList\",\"PresencePrivacy\",\"Selector\",\"Toggler\",\"Vector\",\"copyProperties\",\"ge\",\"tx\",\"MercuryConfig\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"AvailableList\"), i = b(\"ChannelConnection\"), j = b(\"ChannelConstants\"), k = b(\"ChatConfig\"), l = b(\"ChatVisibility\"), m = b(\"Class\"), n = b(\"CSS\"), o = b(\"Dock\"), p = b(\"DOM\"), q = b(\"HTML\"), r = b(\"Keys\"), s = c(\"MercuryConfig\"), t = b(\"NubController\"), u = b(\"OrderedFriendsList\"), v = b(\"PresencePrivacy\"), w = b(\"Selector\"), x = b(\"Toggler\"), y = b(\"Vector\"), z = b(\"copyProperties\"), aa = b(\"ge\"), ba = b(\"tx\"), ca = 32, da = 10;\n    function ea(fa, ga, ha) {\n        this.parent.construct(this);\n        this.parent.init(fa);\n        this.root = fa;\n        this.orderedList = ga;\n        this.typeahead = ha;\n        this.button = p.JSBNG__find(fa, \"a.fbNubButton\");\n        this.label = p.JSBNG__find(fa, \"span.label\");\n        this.body = p.scry(fa, \"div.fbNubFlyoutBody\")[0];\n        var ia = p.JSBNG__find(fa, \"div.fbNubFlyoutTitlebar\");\n        x.createInstance(ia).setSticky(false);\n        ga.subscribe(\"render\", this.flyoutContentChanged.bind(this));\n        ga.setScrollContainer(this.body);\n        h.subscribe(\"buddylist/availability-changed\", this._updateCount.bind(this));\n        g.subscribe(\"chat/connect\", this._handleConnect.bind(this));\n        v.subscribe(\"privacy-user-presence-changed\", this._handleVisibilityChange.bind(this));\n        this.message = p.JSBNG__find(fa, \"div.fbDockChatBuddyListNubMessage div.message\");\n        this.warningMsgText = null;\n        this.warningMsgEventListener = null;\n        this.showWarningTimeout = null;\n        i.subscribe(i.CONNECTED, this._handleChannelConnected.bind(this));\n        i.subscribe(i.SHUTDOWN, this._handleChannelShutdown.bind(this));\n        i.subscribe(i.RECONNECTING, this._handleChannelReconnecting.bind(this));\n        i.subscribe([i.MUTE_WARNING,i.UNMUTE_WARNING,], this._updateView.bind(this));\n        this.subscribe(\"show\", this.JSBNG__onShow.bind(this));\n        this.subscribe(\"hide\", this.JSBNG__onHide.bind(this));\n        this.subscribe(\"resize\", this.JSBNG__onResize.bind(this));\n        JSBNG__Event.listen(fa, \"keydown\", this._onKeyDown.bind(this));\n        JSBNG__Event.listen(this.button, \"click\", this.JSBNG__onButtonClick.bind(this));\n        ha.subscribe([\"respond\",\"reset\",], function(ja, ka) {\n            if (this._isOpen) {\n                var la = this.orderedList.isVisible();\n                if (((((((ka && ka.value)) && ((ka.value === ha.getCore().getValue())))) && ha.getView().isVisible()))) {\n                    o.setUseMaxHeight(this.root, false);\n                    this.orderedList.hide();\n                }\n                 else this._showBuddyList();\n            ;\n            ;\n                if (((la !== this.orderedList.isVisible()))) {\n                    this.flyoutContentChanged();\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        }.bind(this));\n        g.subscribe(\"sidebar/show\", this.hide.bind(this));\n        this._orderedListCount = u.getList().length;\n        g.inform(\"buddylist-nub/initialized\", this, g.BEHAVIOR_PERSISTENT);\n        this._handleVisibilityChange();\n    };\n;\n    m.extend(ea, t);\n    z(ea.prototype, {\n        getButton: function() {\n            return this.button;\n        },\n        getRoot: function() {\n            return this.root;\n        },\n        _handleConnect: function(fa) {\n            this._updateView(true);\n        },\n        _getShutdownReason: function(fa) {\n            switch (fa) {\n              case j.HINT_AUTH:\n                return \"Your session has timed out. Please log in.\";\n              case j.HINT_CONN:\n                return ba._(\"Facebook {Chat} is currently unavailable.\", {\n                    Chat: \"Chat\"\n                });\n              case j.HINT_MAINT:\n                return ba._(\"Facebook {Chat} is currently down for maintenance.\", {\n                    Chat: \"Chat\"\n                });\n              default:\n                return ba._(\"Facebook {Chat} is currently unavailable.\", {\n                    Chat: \"Chat\"\n                });\n            };\n        ;\n        },\n        _getReconnectMsg: function(fa) {\n            var ga;\n            if (((fa === null))) {\n                ga = \"Unable to connect to chat. Check your Internet connection.\";\n            }\n             else if (((fa > k.get(\"warning_countdown_threshold_msec\")))) {\n                var ha = p.create(\"a\", {\n                    href: \"#\",\n                    className: \"fbChatReconnectLink\"\n                }, \"Try again\"), ia = p.create(\"div\", null, ha), ja = ia.innerHTML;\n                ga = q(ba._(\"Unable to connect to chat. {try-again-link}\", {\n                    \"try-again-link\": ja\n                }));\n            }\n             else if (((fa > 1000))) {\n                ga = ba._(\"Unable to connect to chat. Reconnecting in {seconds}...\", {\n                    seconds: Math.floor(((fa / 1000)))\n                });\n            }\n             else ga = \"Unable to connect to chat. Reconnecting...\";\n            \n            \n        ;\n        ;\n            return ga;\n        },\n        _resetShowWarningTimeout: function() {\n            if (this.showWarningTimeout) {\n                JSBNG__clearTimeout(this.showWarningTimeout);\n                this.showWarningTimeout = null;\n            }\n        ;\n        ;\n        },\n        _handleChannelConnected: function(fa) {\n            this._resetShowWarningTimeout();\n            if (this.orderedList.isVisible()) {\n                l.goOnline();\n            }\n        ;\n        ;\n            this.warningMsgText = null;\n            this._updateView();\n        },\n        _handleChannelShutdown: function(fa, ga) {\n            this._resetShowWarningTimeout();\n            this.warningMsgText = this._getShutdownReason(ga);\n            this._updateView();\n        },\n        _handleChannelReconnecting: function(fa, ga) {\n            this._resetShowWarningTimeout();\n            this.warningMsgText = this._getReconnectMsg(ga);\n            if (((ga > 1000))) {\n                if (((ga > k.get(\"warning_countdown_threshold_msec\")))) {\n                    if (this.warningMsgEventListener) {\n                        this.warningMsgEventListener.remove();\n                        this.warningMsgEventListener = null;\n                    }\n                ;\n                ;\n                    this.warningMsgEventListener = JSBNG__Event.listen(this.message, \"click\", function(JSBNG__event) {\n                        if (n.hasClass(JSBNG__event.getTarget(), \"fbChatReconnectLink\")) {\n                            this._tryReconnect();\n                            JSBNG__event.kill();\n                        }\n                    ;\n                    ;\n                    }.bind(this));\n                }\n            ;\n            ;\n                this.showWarningTimeout = JSBNG__setTimeout(this._handleChannelReconnecting.bind(this, fa, ((ga - 1000))), 1000, false);\n            }\n        ;\n        ;\n            this._updateView();\n        },\n        _tryReconnect: function() {\n            if (i.disconnected()) {\n                i.reconnect();\n            }\n        ;\n        ;\n        },\n        _handleVisibilityChange: function() {\n            this._updateView();\n            if (!l.isOnline()) {\n                this.hide();\n            }\n        ;\n        ;\n        },\n        _updateView: function(fa) {\n            var ga = aa(\"fbDockChat\");\n            n.conditionClass(ga, \"offline\", !l.isOnline());\n            n.conditionClass(ga, \"error\", i.disconnected());\n            if (i.disconnected()) {\n                p.setContent(this.message, this.warningMsgText);\n            }\n        ;\n        ;\n            if (!l.isOnline()) {\n                if (s.ChatControlLanguageChangeGK) {\n                    this._setLabel(ba._(\"{Chat} (Off)\", {\n                        Chat: \"Chat\"\n                    }));\n                }\n                 else this._setLabel(ba._(\"{Chat} (Offline)\", {\n                    Chat: \"Chat\"\n                }));\n            ;\n            ;\n            }\n             else if (i.disconnected()) {\n                this._setLabel(ba._(\"{Chat} (Disconnected)\", {\n                    Chat: \"Chat\"\n                }));\n            }\n             else {\n                var ha = h.getOnlineCount();\n                if (ha) {\n                    var ia = ba._(\"{Chat} {number-available}\", {\n                        Chat: \"Chat\",\n                        \"number-available\": [\"\\u003Cspan class=\\\"count\\\"\\u003E\",\"(\\u003Cstrong\\u003E\",ha,\"\\u003C/strong\\u003E)\",\"\\u003C/span\\u003E\",].join(\"\")\n                    });\n                    this._setLabel(q(ia));\n                }\n                 else this._setLabel(\"Chat\", fa);\n            ;\n            ;\n            }\n            \n        ;\n        ;\n        },\n        JSBNG__onButtonClick: function() {\n            this._conditionallyShowTypeahead();\n            if (n.shown(this.typeahead.getElement())) {\n                var fa = this.subscribe(\"show\", function() {\n                    this.typeahead.getCore().getElement().JSBNG__focus();\n                }.bind(this));\n                this.unsubscribe.bind(this, fa).defer();\n            }\n        ;\n        ;\n        },\n        JSBNG__onHide: function() {\n            this._isOpen = false;\n            if (this._buddyListRenderSubscription) {\n                this.orderedList.unsubscribe(this._buddyListRenderSubscription);\n                this._buddyListRenderSubscription = null;\n            }\n        ;\n        ;\n            this.orderedList.hide();\n            this.typeahead.getCore().reset();\n        },\n        _onKeyDown: function(JSBNG__event) {\n            var fa = JSBNG__Event.getKeyCode(JSBNG__event);\n            if (((((fa === r.ESC)) && !n.hasClass(this.root, \"menuOpened\")))) {\n                this.hide();\n                return false;\n            }\n        ;\n        ;\n        },\n        JSBNG__onResize: function() {\n            var fa = ((y.getElementDimensions(this.body).y - 5));\n            this.orderedList.setNumTopFriends(Math.floor(((fa / ca))));\n        },\n        _showBuddyList: function() {\n            if (!this._buddyListRenderSubscription) {\n                this._buddyListRenderSubscription = this.orderedList.subscribe(\"render\", o.setUseMaxHeight.bind(o, this.root, false));\n            }\n        ;\n        ;\n            this.orderedList.show();\n        },\n        JSBNG__onShow: function() {\n            this._isOpen = true;\n            if (i.disconnected()) {\n                this._tryReconnect();\n                this._showBuddyList();\n            }\n             else l.goOnline(this._showBuddyList.bind(this));\n        ;\n        ;\n        },\n        _setLabel: function(fa, ga) {\n            var ha = this.label.cloneNode(true);\n            p.setContent(ha, fa);\n            p.replace(this.label, ha);\n            this.label = ha;\n            ((this.throbber && n.conditionShow(this.throbber, !!ga)));\n        },\n        _conditionallyShowTypeahead: function() {\n            n.conditionShow(this.typeahead.getElement(), ((this._orderedListCount >= da)));\n        },\n        _updateCount: function() {\n            this._updateView();\n            this._conditionallyShowTypeahead();\n        }\n    });\n    e.exports = ea;\n});\n__d(\"ChatOnlineFriends\", [\"event-extensions\",\"AvailableList\",\"AvailableListConstants\",\"ChannelConnection\",\"Chat\",\"ChatConfig\",\"ChatVisibility\",\"Class\",\"CSS\",\"DataStore\",\"DOM\",\"OrderedFriendsList\",\"Parent\",\"Run\",\"ShortProfiles\",\"TooltipLink\",\"XHPTemplate\",\"copyProperties\",\"createObjectFrom\",\"ChatTypeaheadBehavior\",\"ChatTypeaheadCore\",\"ChatTypeaheadDataSource\",\"ChatTypeaheadRenderer\",\"Typeahead\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"AvailableList\"), h = b(\"AvailableListConstants\"), i = b(\"ChannelConnection\"), j = b(\"Chat\"), k = b(\"ChatConfig\"), l = b(\"ChatVisibility\"), m = b(\"Class\"), n = b(\"CSS\"), o = b(\"DataStore\"), p = b(\"DOM\"), q = b(\"OrderedFriendsList\"), r = b(\"Parent\"), s = b(\"Run\"), t = b(\"ShortProfiles\"), u = b(\"TooltipLink\"), v = b(\"XHPTemplate\"), w = b(\"copyProperties\"), x = b(\"createObjectFrom\");\n    b(\"ChatTypeaheadBehavior\");\n    b(\"ChatTypeaheadCore\");\n    b(\"ChatTypeaheadDataSource\");\n    b(\"ChatTypeaheadRenderer\");\n    b(\"Typeahead\");\n    function y(aa) {\n        switch (aa) {\n          case h.OFFLINE:\n            return \"chatOffline\";\n          case h.IDLE:\n            return \"chatIdle\";\n          case h.ACTIVE:\n            return \"chatOnline\";\n          case h.MOBILE:\n            return \"chatMobile\";\n        };\n    ;\n    };\n;\n    var z = function(aa, ba, ca, da, ea, fa, ga) {\n        var ha = ((((da && ea)) || ((fa && ga))));\n        if (((((((aa && ba)) && ca)) && ha))) {\n            this.init(aa, ba, ca, da, ea, fa, ga);\n        }\n    ;\n    ;\n    };\n    w(z.prototype, {\n        chatFriends: {\n        },\n        chatStatuses: [\"chatOnline\",\"chatIdle\",\"chatMobile\",\"chatOffline\",],\n        _availableListSubscribe: function(JSBNG__event, aa) {\n            this._arbiterTokens.push(g.subscribe(JSBNG__event, aa));\n        },\n        _channelSubscribe: function(JSBNG__event, aa) {\n            this._arbiterTokens.push(i.subscribe(JSBNG__event, aa));\n        },\n        JSBNG__onunload: function() {\n            this._arbiterTokens.forEach(function(aa) {\n                aa.unsubscribe();\n            });\n        },\n        _setStatus: function(aa, ba) {\n            if (n.hasClass(aa, ba)) {\n                return;\n            }\n        ;\n        ;\n            this.chatStatuses.forEach(function(ca) {\n                n.conditionClass(aa, ca, ((ca == ba)));\n            });\n        },\n        initTypeahead: function(aa, ba, ca) {\n            aa.subscribe(\"reset\", function() {\n                n.show(ba);\n            });\n            aa.subscribe(\"query\", function(da, ea) {\n                n.conditionShow(ba, !ea.value);\n            });\n            if (ca) {\n                aa.subscribe([\"query\",\"reset\",], function(da) {\n                    n.conditionShow(ca, ((da === \"reset\")));\n                });\n            }\n        ;\n        ;\n        },\n        init: function(aa, ba, ca, da, ea, fa, ga) {\n            this.maxElements = aa;\n            this._faceTmpl = ea;\n            this._arbiterTokens = [];\n            this._root = ca;\n            s.JSBNG__onLeave(this.JSBNG__onunload.bind(this));\n            var ha = p.scry(ca, \".chatUpgradeLink\");\n            this.initTypeahead(ba, ((da || fa)), ha[0]);\n            var ia = p.JSBNG__find(ca, \".sidebarBtn\");\n            JSBNG__Event.listen(ia, \"click\", function(JSBNG__event) {\n                j.toggleSidebar();\n                JSBNG__event.kill();\n            });\n            ((this._faceFutures && this._hideAllFaces()));\n            this._faceFutures = [];\n            this._orderedFriends = q.getList();\n            this._hashedFriends = x(this._orderedFriends);\n            this._availableListSubscribe(h.ON_AVAILABILITY_CHANGED, this.update.shield(this));\n            this.update.bind(this).defer();\n            this._channelSubscribe(i.CONNECTED, this.update.shield(this));\n            this._channelSubscribe(i.RECONNECTING, this._handleChannelReconnecting.bind(this));\n            this._channelSubscribe(i.SHUTDOWN, this._handleChannelShutdown.bind(this));\n            this._channelSubscribe([i.MUTE_WARNING,i.UNMUTE_WARNING,], this.update.shield(this));\n            if (da) {\n                this._facepile = da.firstChild;\n                JSBNG__Event.listen(da, \"click\", this.clickHandler.bind(this));\n            }\n             else {\n                this._miniDivebar = fa;\n                this._divebarTmpl = ga;\n            }\n        ;\n        ;\n            JSBNG__Event.listen(p.JSBNG__find(ca, \".fbChatGoOnlineLink\"), \"click\", function(JSBNG__event) {\n                if (i.disconnected()) {\n                    j.openBuddyList();\n                }\n                 else l.goOnline(j.openBuddyList);\n            ;\n            ;\n                JSBNG__event.kill();\n            }.bind(this));\n            JSBNG__Event.listen(p.JSBNG__find(ca, \".fbChatReconnectLink\"), \"click\", function(JSBNG__event) {\n                if (i.disconnected()) {\n                    i.reconnect();\n                }\n            ;\n            ;\n                JSBNG__event.kill();\n            }.bind(this));\n            g.update();\n        },\n        _updateMiniDivebar: function() {\n            var aa = Math.min(this._orderedFriends.length, 10), ba = [];\n            for (var ca = 0; ((ca < aa)); ca++) {\n                ba.push(this._renderDivebarItem(this._orderedFriends[ca]));\n            ;\n            };\n        ;\n            p.setContent(this._miniDivebar, ba);\n        },\n        _renderDivebarItem: function(aa) {\n            var ba = this._divebarTmpl.build(), ca = ba.getNode(\"anchor\"), da = ba.getNode(\"JSBNG__status\"), ea = g.get(aa);\n            if (((ea === h.ACTIVE))) {\n                n.addClass(da, \"active\");\n            }\n             else if (((ea === h.MOBILE))) {\n                n.addClass(da, \"mobile\");\n            }\n            \n        ;\n        ;\n            t.get(aa, function(fa) {\n                ba.setNodeContent(\"JSBNG__name\", fa.JSBNG__name).setNodeProperty(\"profile-photo\", \"src\", fa.thumbSrc);\n                JSBNG__Event.listen(ca, \"click\", function() {\n                    j.openTab(aa, null, \"friend\", \"JSBNG__online_friends\");\n                    return false;\n                });\n            });\n            return ba.getRoot();\n        },\n        _handleChannelReconnecting: function(aa, ba) {\n            var ca = ((ba < 1000)), da = p.JSBNG__find(this._root, \".fbChatReconnectLink\"), ea = p.JSBNG__find(this._root, \".fbChatReconnecting\");\n            n.conditionShow(da, !ca);\n            n.conditionShow(ea, ca);\n        },\n        _handleChannelShutdown: function() {\n            var aa = p.JSBNG__find(this._root, \".fbChatReconnectLink\"), ba = p.JSBNG__find(this._root, \".fbChatReconnecting\");\n            n.hide(aa);\n            n.hide(ba);\n        },\n        update: function() {\n            var aa = i.disconnected(), ba = l.isOnline();\n            n.conditionClass(this._root, \"disconnected\", aa);\n            if (this._facepile) {\n                n.conditionShow(this._facepile, ba);\n                ((ba && this._updateFacepile(aa)));\n            }\n             else ((ba && this._updateMiniDivebar()));\n        ;\n        ;\n            var ca = p.JSBNG__find(this._root, \".typeaheadContainer\");\n            n.conditionShow(ca, ba);\n            if (k.get(\"chat_upgrade_link\")) {\n                var da = p.JSBNG__find(this._root, \".chatUpgradeLink\");\n                n.conditionShow(da, ba);\n            }\n        ;\n        ;\n            var ea = p.JSBNG__find(this._root, \".chatGoOnlineLink\");\n            n.conditionShow(ea, !ba);\n            var fa = p.JSBNG__find(this._root, \".chatReconnectLink\");\n            n.conditionShow(fa, ((ba && aa)));\n        },\n        _updateFacepile: function(aa) {\n            g.getAvailableIDs().forEach(function(ha) {\n                if (!this._hashedFriends[ha]) {\n                    this._orderedFriends.push(ha);\n                    this._hashedFriends[ha] = true;\n                }\n            ;\n            ;\n            }.bind(this));\n            var ba = 0;\n            for (var ca = 0; ((ca < this._orderedFriends.length)); ca++) {\n                var da = this._orderedFriends[ca], ea = g.get(da), fa = this._faceFutures[ca], ga = ((((aa || ((ea !== h.OFFLINE)))) && ((ba < this.maxElements))));\n                if (ga) {\n                    if (!fa) {\n                        fa = this._makeFace(ca);\n                        this._faceFutures[ca] = fa;\n                    }\n                ;\n                ;\n                    ba++;\n                }\n            ;\n            ;\n                this._updateFace(fa, ga, y(ea));\n            };\n        ;\n        },\n        _updateFace: function(aa, ba, ca) {\n            ((aa && aa(function(da) {\n                this._setStatus(da, ca);\n                n.conditionShow(da, ba);\n            }.bind(this))));\n        },\n        _makeFace: function(aa) {\n            var ba = null, ca = null, da = this._orderedFriends[aa];\n            t.get(da, function(ea) {\n                ca = this._faceTmpl.render();\n                o.set(ca, \"friendID\", da);\n                var fa = v.getNode(ca, \"img\"), ga = fa.cloneNode(false);\n                ga.setAttribute(\"src\", ea.thumbSrc);\n                p.replace(fa, ga);\n                var ha = v.getNode(ca, \"anchor\");\n                u.setTooltipText(ha, ea.JSBNG__name);\n                ((ba && ba(ca)));\n                var ia = false;\n                for (var ja = ((aa + 1)); ((((ja < this._orderedFriends.length)) && !ia)); ja++) {\n                    var ka = this._faceFutures[ja], la = ((ka && ka()));\n                    if (la) {\n                        this._facepile.insertBefore(ca, la);\n                        ia = true;\n                    }\n                ;\n                ;\n                };\n            ;\n                if (!ia) {\n                    this._facepile.appendChild(ca);\n                }\n            ;\n            ;\n            }.bind(this));\n            return function ea(fa) {\n                if (fa) {\n                    if (ca) {\n                        fa(ca);\n                    }\n                     else ba = fa;\n                ;\n                }\n            ;\n            ;\n                return ca;\n            };\n        },\n        clickHandler: function(JSBNG__event) {\n            var aa = JSBNG__event.getTarget(), ba = r.byClass(aa, \"uiFacepileItem\");\n            if (ba) {\n                var ca = o.get(ba, \"friendID\");\n                if (((ca && l.isOnline()))) {\n                    j.openTab(ca, null, \"friend\", \"JSBNG__online_friends\");\n                    return false;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        _hideAllFaces: function() {\n            this._faceFutures.forEach(function(aa) {\n                ((aa && aa(function(ba) {\n                    p.remove(ba);\n                })));\n            });\n        }\n    });\n    e.exports = z;\n});\n__d(\"LiveBarData\", [\"function-extensions\",\"Arbiter\",\"ArbiterMixin\",\"AsyncRequest\",\"ChannelConstants\",\"LayerDestroyOnHide\",\"copyProperties\",\"setTimeoutAcrossTransitions\",\"throttle\",], function(a, b, c, d, e, f) {\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ArbiterMixin\"), i = b(\"AsyncRequest\"), j = b(\"ChannelConstants\"), k = b(\"LayerDestroyOnHide\"), l = b(\"copyProperties\"), m = b(\"setTimeoutAcrossTransitions\"), n = b(\"throttle\"), o = false, p = {\n    }, q = {\n    }, r = {\n    };\n    function s(z) {\n        if (((((((z.expires * 1000)) - JSBNG__Date.now())) > 0))) {\n            return true;\n        }\n    ;\n    ;\n        return false;\n    };\n;\n    function t(z) {\n        var aa = z.payload.actions;\n        if (!((aa && aa.length))) {\n            return;\n        }\n    ;\n    ;\n        var ba;\n        for (var ca = 0; ((ca < aa.length)); ca++) {\n            ba = aa[ca].actor_id;\n            if (((!p[ba] || ((aa[ca].action_id != p[ba].action_id))))) {\n                continue;\n            }\n        ;\n        ;\n            if (((aa[ca].delete_action || aa[ca].remove))) {\n                w(aa[ca]);\n                continue;\n            }\n        ;\n        ;\n        };\n    ;\n    };\n;\n    function u(z) {\n        var aa = false;\n        for (var ba = 0; ((ba < z.length)); ba++) {\n            if (((z[ba].delete_action || z[ba].remove))) {\n                w(z[ba]);\n                continue;\n            }\n        ;\n        ;\n            var ca = z[ba].actor_id, da = z[ba].action_id;\n            if (p[ca]) {\n                if (((p[ca].action_id == da))) {\n                    continue;\n                }\n            ;\n            ;\n                w(p[ca]);\n            }\n        ;\n        ;\n            aa = true;\n            p[ca] = z[ba];\n            v(z[ba]);\n        };\n    ;\n        if (aa) {\n            y.inform(\"new-actions\");\n        }\n    ;\n    ;\n    };\n;\n    function v(z) {\n        var aa = ((((z.expires * 1000)) - JSBNG__Date.now()));\n        q[z.actor_id] = m(w.curry(z), Math.max(0, aa));\n    };\n;\n    function w(z) {\n        if (!p[z.actor_id]) {\n            return;\n        }\n    ;\n    ;\n        if (((p[z.actor_id].action_id != z.action_id))) {\n            return;\n        }\n    ;\n    ;\n        delete p[z.actor_id];\n        var aa = z.actor_id;\n        if (q[aa]) {\n            JSBNG__clearTimeout(q[aa]);\n            delete q[aa];\n        }\n    ;\n    ;\n        x(aa);\n        y.inform(\"remove-action\", z);\n    };\n;\n    function x(z) {\n        var aa = r[z];\n        if (aa) {\n            aa.enableBehavior(k);\n            if (!aa.isShown()) {\n                aa.destroy();\n            }\n        ;\n        ;\n            delete r[z];\n        }\n    ;\n    ;\n    };\n;\n    g.subscribe(j.getArbiterType(\"livebar_update\"), function(z, aa) {\n        u(aa.obj.actions);\n    });\n    var y = {\n    };\n    l(y, h, {\n        fetch: function() {\n            if (o) {\n                return;\n            }\n        ;\n        ;\n            var z = [];\n            for (var aa in p) {\n                var ba = p[aa];\n                if (!r[ba.actor_id]) {\n                    z.push(p[aa]);\n                }\n            ;\n            ;\n            };\n        ;\n            if (((z.length > 0))) {\n                o = true;\n                new i().setURI(\"/ajax/chat/livebar.php\").setData({\n                    actions: z\n                }).setHandler(t).setFinallyHandler(function() {\n                    o = false;\n                }).setAllowCrossPageTransition(true).send();\n            }\n        ;\n        ;\n        },\n        addActions: u,\n        getAction: function(z) {\n            var aa = p[z];\n            if (((aa && s(aa)))) {\n                return aa;\n            }\n        ;\n        ;\n            return null;\n        },\n        getDialog: function(z) {\n            var aa = this.getAction(z);\n            if (((aa && r[aa.actor_id]))) {\n                return r[aa.actor_id];\n            }\n        ;\n        ;\n            return null;\n        },\n        setDialog: function(z, aa, ba) {\n            var ca = p[z];\n            if (((ca && ((ca.action_id == aa))))) {\n                x(z);\n                r[z] = ba;\n                y.inform(\"dialog-fetched\", z);\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = y;\n});\n__d(\"LiveBar\", [\"event-extensions\",\"function-extensions\",\"ChatConfig\",\"CSS\",\"LiveBarData\",\"$\",\"copyProperties\",\"ge\",\"setTimeoutAcrossTransitions\",\"tx\",\"ChatOrderedList\",\"ContextualDialogX\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"ChatConfig\"), h = b(\"CSS\"), i = b(\"LiveBarData\"), j = b(\"$\"), k = b(\"copyProperties\"), l = b(\"ge\"), m = b(\"setTimeoutAcrossTransitions\"), n = b(\"tx\");\n    b(\"ChatOrderedList\");\n    b(\"ContextualDialogX\");\n    var o = ((g.get(\"livebar_fetch_defer\") || 1000));\n    function p(q, r, s) {\n        this._orderedList = q;\n        this._root = q.getRoot();\n        this._liveBarTypes = s;\n        this._hoverController = q.getHoverController();\n        this._hoverController.subscribe(\"hover\", this._mouseMove.bind(this));\n        this._hoverController.subscribe(\"leave\", this._mouseLeave.bind(this));\n        q.subscribe(\"render\", this._handleChatListUpdate.shield(this));\n        i.subscribe(\"new-actions\", this._updateIcons.bind(this));\n        i.subscribe(\"remove-action\", this._handleRemoveAction.bind(this));\n        i.subscribe(\"dialog-fetched\", function(t, u) {\n            this._setDialogContent(u);\n        }.bind(this));\n        i.addActions(r);\n    };\n;\n    k(p, {\n        setDialog: function(q, r, s) {\n            i.setDialog(q, r, s);\n        }\n    });\n    k(p.prototype, {\n        _root: null,\n        _liveBarTypes: null,\n        _hoverController: null,\n        _registrations: {\n        },\n        _renderedIcons: {\n        },\n        _fetchTimer: null,\n        _mouseLeftRoot: false,\n        _chatListRendered: false,\n        _getLiveBarTypes: function() {\n            return this._liveBarTypes;\n        },\n        _handleChatListUpdate: function() {\n            if (!this._chatListRendered) {\n                this._chatListRendered = true;\n                this._updateIcons();\n            }\n        ;\n        ;\n        },\n        _handleShow: function(q) {\n            this._setDialogContent(q);\n        },\n        _mouseMove: function() {\n            if (!this._fetchTimer) {\n                this._fetchTimer = m(this._fetch.bind(this), o);\n                this._mouseLeftRoot = false;\n            }\n        ;\n        ;\n        },\n        _mouseLeave: function() {\n            this._mouseLeftRoot = true;\n            JSBNG__clearTimeout(this._fetchTimer);\n            this._fetchTimer = null;\n        },\n        _setDialogContent: function(q) {\n            var r = i.getDialog(q);\n            if (r) {\n                this._hoverController.showHovercard(q, r);\n            }\n        ;\n        ;\n        },\n        _fetch: function() {\n            if (this._mouseLeftRoot) {\n                return;\n            }\n        ;\n        ;\n            this._fetchTimer = null;\n            i.fetch();\n        },\n        _updateIcons: function() {\n            if (!this._chatListRendered) {\n                return;\n            }\n        ;\n        ;\n            var q = this._orderedList.getAllNodes(), r = this._getLiveBarTypes();\n            for (var s in q) {\n                var t = i.getAction(s);\n                if (((t && ((!this._renderedIcons[s] || ((this._renderedIcons[s] != t.action_id))))))) {\n                    for (var u = 0; ((u < r.length)); u++) {\n                        h.removeClass(q[s], r[u]);\n                    ;\n                    };\n                ;\n                    h.addClass(q[s], t.livebar_type);\n                    this._renderedIcons[s] = t.action_id;\n                    var v = this._hoverController.register(s, this._handleShow.bind(this));\n                    if (v) {\n                        this._registrations[s] = v;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n        },\n        _handleRemoveAction: function(q, r) {\n            var s = r.action_id, t = r.actor_id;\n            ((this._registrations[t] && this._registrations[t].unregister()));\n            delete this._registrations[t];\n            if (((this._renderedIcons[t] == s))) {\n                var u = this._getLiveBarTypes(), v = this._orderedList.getAllNodes();\n                if (v[t]) {\n                    for (var w = 0; ((w < u.length)); w++) {\n                        h.removeClass(v[t], u[w]);\n                    ;\n                    };\n                }\n            ;\n            ;\n                delete this._renderedIcons[t];\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = p;\n});\n__d(\"LiveBarDark\", [\"Class\",\"LiveBar\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Class\"), h = b(\"LiveBar\"), i = b(\"copyProperties\");\n    function j(k, l, m) {\n        this.parent.construct(this, k, l, m);\n    };\n;\n    g.extend(j, h);\n    i(j.prototype, {\n        _setupDialogContent: bagofholding,\n        _show: bagofholding,\n        _updateIcons: bagofholding,\n        _handleRemoveAction: bagofholding,\n        _handleChatListUpdate: bagofholding\n    });\n    e.exports = j;\n});\n__d(\"ChatSidebarDropdown\", [\"Arbiter\",\"AsyncRequest\",\"Chat\",\"ChatOptions\",\"ChatVisibility\",\"CSS\",\"DOM\",\"JSLogger\",\"PresenceState\",\"Selector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"Chat\"), j = b(\"ChatOptions\"), k = b(\"ChatVisibility\"), l = b(\"CSS\"), m = b(\"DOM\"), n = b(\"JSLogger\"), o = b(\"PresenceState\"), p = b(\"Selector\"), q = b(\"copyProperties\");\n    function r(s) {\n        this._root = s;\n        this._logger = n.create(\"blackbird\");\n        this._displayBrowserNotificationsIfNeeded();\n        p.listen(s, \"select\", this._onSelect.bind(this));\n        p.listen(s, \"toggle\", this._onToggle.bind(this));\n        g.subscribe(\"chat/option-changed\", this._onOptionChanged.bind(this));\n    };\n;\n    q(r.prototype, {\n        changeSetting: function(s, t) {\n            if (this._pendingChange) {\n                return false;\n            }\n        ;\n        ;\n            this._pendingChange = true;\n            var u = {\n            };\n            u[s] = t;\n            j.setSetting(s, t, \"sidebar_menu\");\n            new h(\"/ajax/chat/settings.php\").setHandler(this._onChangeSettingResponse.bind(this, s, t)).setErrorHandler(this._onChangeSettingError.bind(this, s, t)).setFinallyHandler(this._onChangeFinally.bind(this)).setData(u).setAllowCrossPageTransition(true).send();\n        },\n        _displayBrowserNotificationsIfNeeded: function() {\n            if (window.JSBNG__webkitNotifications) {\n                m.scry(JSBNG__document, \"li.sidebar-browser-notif\").forEach(l.show);\n                if (((window.JSBNG__webkitNotifications.checkPermission() !== 0))) {\n                    m.scry(JSBNG__document, \"li.sidebar-browser-notif\").forEach(function(s) {\n                        l.removeClass(s, \"checked\");\n                    });\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        _conditionEnabled: function(s, t) {\n            var u = p.getOption(this._root, s);\n            ((u && p.setOptionEnabled(u, t)));\n        },\n        _onChangeSettingResponse: function(s, t, u) {\n            o.doSync();\n        },\n        _onChangeSettingError: function(s, t, u) {\n            j.setSetting(s, !t, \"sidebar_menu_error\");\n        },\n        _onChangeFinally: function() {\n            this._pendingChange = false;\n        },\n        _onOptionChanged: function(s, t) {\n            var u = t.JSBNG__name, v = t.value;\n            if (((((u === \"sound\")) || ((u === \"browser_notif\"))))) {\n                var w = p.getOption(this._root, u);\n                if (((v !== p.isOptionSelected(w)))) {\n                    p.setSelected(this._root, u, v);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        _onSelect: function(s) {\n            if (this._pendingChange) {\n                return false;\n            }\n        ;\n        ;\n            var t = false, u = false, v = p.getOptionValue(s.option);\n            switch (v) {\n              case \"sidebar\":\n                return this.toggleSidebar();\n              case \"JSBNG__online\":\n                if (!k.isOnline()) {\n                    k.goOnline();\n                }\n                 else u = true;\n            ;\n            ;\n                t = true;\n                break;\n              case \"offline\":\n                if (k.isOnline()) {\n                    k.goOffline();\n                }\n                 else u = true;\n            ;\n            ;\n                t = true;\n                break;\n              case \"advanced_settings\":\n                g.inform(\"chat/advanced-settings-dialog-opened\");\n                t = true;\n                break;\n            };\n        ;\n            if (u) {\n                this._logger.error(\"sidebar_dropdown_visibility_error\", {\n                    action: v\n                });\n            }\n             else this._logger.log(\"sidebar_dropdown_set_visibility\", {\n                action: v\n            });\n        ;\n        ;\n            if (t) {\n                p.toggle(this._root);\n                return false;\n            }\n        ;\n        ;\n        },\n        _onToggle: function(s) {\n            if (this._pendingChange) {\n                return false;\n            }\n        ;\n        ;\n            var t = p.getOptionValue(s.option), u = p.isOptionSelected(s.option);\n            switch (t) {\n              case \"visibility\":\n                if (!k) {\n                    this._jslogger.error(\"JSBNG__on_toggle_visibility_undefined\");\n                    return;\n                }\n            ;\n            ;\n                k.toggleVisibility();\n                this._logger.log(\"sidebar_dropdown_toggle_visibility\", {\n                    available: u\n                });\n                break;\n              case \"browser_notif\":\n                if (((((u && window.JSBNG__webkitNotifications)) && ((window.JSBNG__webkitNotifications.checkPermission() !== 0))))) {\n                    window.JSBNG__webkitNotifications.requestPermission(function() {\n                        this.changeSetting(t, u);\n                    }.bind(this));\n                }\n                 else this.changeSetting(t, u);\n            ;\n            ;\n                break;\n              case \"sound\":\n                this.changeSetting(t, u);\n                break;\n            };\n        ;\n            p.toggle(this._root);\n        },\n        _onVisibilityChanged: function() {\n            var s = k.isOnline(), t = p.getOption(this._root, \"visibility\");\n            if (((s !== p.isOptionSelected(t)))) {\n                p.setSelected(this._root, \"visibility\", s);\n            }\n        ;\n        ;\n        },\n        toggleSidebar: function() {\n            i.toggleSidebar();\n            p.toggle(this._root);\n            return false;\n        }\n    });\n    e.exports = r;\n});\n__d(\"MercuryUnreadState\", [\"Arbiter\",\"copyProperties\",\"MercuryFolders\",\"JSLogger\",\"KeyedCallbackManager\",\"createObjectFrom\",\"MercuryServerRequests\",\"MercuryThreadInformer\",\"MercuryThreads\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"copyProperties\"), i = b(\"MercuryFolders\"), j = b(\"JSLogger\"), k = b(\"KeyedCallbackManager\"), l = b(\"createObjectFrom\"), m = b(\"MercuryServerRequests\"), n = b(\"MercuryThreadInformer\"), o = b(\"MercuryThreads\"), p = c(\"MercuryConstants\"), q = ((i.getSupportedFolders() || [])).filter(function(la) {\n        return ((la != p.MessagingTag.ACTION_ARCHIVED));\n    }), r = {\n    }, s = {\n    }, t = {\n    };\n    q.forEach(function(la) {\n        r[la] = 0;\n        s[la] = false;\n        t[la] = new k();\n    });\n    var u = \"unread_thread_hash\", v = \"unseen_thread_list\", w = p.MercuryThreadlistConstants.MAX_UNREAD_COUNT, x = j.create(\"mercury_unread_state\"), y = {\n        getUnreadCount: function(la) {\n            if (y.exceedsMaxCount(la)) {\n                x.error(\"unguarded_unread_count_fetch\", {\n                });\n                return 0;\n            }\n        ;\n        ;\n            return ca(la);\n        },\n        exceedsMaxCount: function(la) {\n            return ((s[la] || ((ca(la) > w))));\n        },\n        markFolderAsRead: function(la) {\n            if (((s[la] || ((ca(la) > 0))))) {\n                m.markFolderAsRead(la);\n            }\n        ;\n        ;\n        }\n    };\n    function z(la, ma) {\n        t[la].setResource(u, ma);\n        t[la].setResource(v, Object.keys(ma));\n    };\n;\n    function aa(la, ma) {\n        var na = t[la].executeOrEnqueue(u, ma), oa = t[la].getUnavailableResources(na);\n        if (oa.length) {\n            m.fetchUnreadThreadIDs(la);\n        }\n    ;\n    ;\n    };\n;\n    function ba(la) {\n        return t[la].getResource(u);\n    };\n;\n    function ca(la) {\n        var ma = t[la].getResource(v);\n        if (ma) {\n            return ma.length;\n        }\n         else return r[la]\n    ;\n    };\n;\n    function da(la) {\n        var ma;\n        ((la.unread_thread_ids || [])).forEach(function(na) {\n            ma = na.folder;\n            if (!ka(ma)) {\n                return;\n            }\n        ;\n        ;\n            var oa = ia(na.thread_ids);\n            z(ma, l(oa, true));\n            if (((oa.length > w))) {\n                s[ma] = true;\n            }\n        ;\n        ;\n            n.updatedUnreadState();\n        });\n        ((la.message_counts || [])).forEach(function(na) {\n            if (((na.unread_count === undefined))) {\n                return;\n            }\n        ;\n        ;\n            ma = na.folder;\n            if (((na.unread_count > w))) {\n                s[ma] = true;\n                z(ma, {\n                });\n                n.updatedUnreadState();\n            }\n             else {\n                r[ma] = na.unread_count;\n                if (((r[ma] === 0))) {\n                    z(ma, {\n                    });\n                }\n            ;\n            ;\n                n.updatedUnreadState();\n            }\n        ;\n        ;\n        });\n        ((la.actions || [])).forEach(function(na) {\n            if (na.is_forward) {\n                return;\n            }\n        ;\n        ;\n            var oa = p.MercuryActionType, pa = ((na.thread_id ? na.thread_id : na.server_thread_id));\n            if (((na.action_type == oa.DELETE_THREAD))) {\n                q.forEach(function(ra) {\n                    ga(ra, pa);\n                });\n            }\n             else if (((((na.action_type == oa.CHANGE_ARCHIVED_STATUS)) || ((na.action_type == oa.CHANGE_FOLDER))))) {\n                var qa = o.getThreadMetaNow(na.thread_id);\n                ma = i.getFromMeta(qa);\n                if (((ka(ma) && ((qa.unread_count > 0))))) {\n                    fa(ma, pa);\n                }\n            ;\n            ;\n                q.forEach(function(ra) {\n                    if (((ra != ma))) {\n                        ga(ra, pa);\n                    }\n                ;\n                ;\n                });\n            }\n             else {\n                ma = na.folder;\n                if (!ka(ma)) {\n                    return;\n                }\n            ;\n            ;\n                if (((na.action_type == oa.CHANGE_READ_STATUS))) {\n                    ea(ma, pa, na.mark_as_read);\n                }\n                 else if (((((na.action_type == oa.USER_GENERATED_MESSAGE)) || ((na.action_type == oa.LOG_MESSAGE))))) {\n                    if (na.is_unread) {\n                        fa(ma, pa);\n                    }\n                ;\n                }\n                \n            ;\n            ;\n            }\n            \n        ;\n        ;\n        });\n    };\n;\n    function ea(la, ma, na) {\n        if (na) {\n            ga(la, ma);\n        }\n         else fa(la, ma);\n    ;\n    ;\n    };\n;\n    function fa(la, ma) {\n        if (s[la]) {\n            return;\n        }\n    ;\n    ;\n        aa(la, function(na) {\n            if (!na[ma]) {\n                na[ma] = true;\n                z(la, na);\n                n.updatedUnreadState();\n            }\n        ;\n        ;\n        });\n    };\n;\n    function ga(la, ma) {\n        if (s[la]) {\n            return;\n        }\n    ;\n    ;\n        aa(la, function(na) {\n            if (na[ma]) {\n                delete na[ma];\n                z(la, na);\n                n.updatedUnreadState();\n            }\n        ;\n        ;\n        });\n    };\n;\n    function ha(la) {\n        s[la] = false;\n        z(la, {\n        });\n        n.updatedUnreadState();\n    };\n;\n    function ia(la) {\n        return la.map(m.convertThreadIDIfAvailable);\n    };\n;\n    function ja(la) {\n        q.forEach(function(ma) {\n            var na = ba(ma);\n            if (!na) {\n                return;\n            }\n        ;\n        ;\n            for (var oa in la) {\n                var pa = la[oa];\n                if (na[oa]) {\n                    na[pa] = na[oa];\n                    delete na[oa];\n                }\n            ;\n            ;\n            };\n        ;\n            z(ma, na);\n        });\n    };\n;\n    function ka(la) {\n        return q.contains(la);\n    };\n;\n    m.subscribe(\"update-unread\", function(la, ma) {\n        da(ma);\n        var na = ((ma.global_actions || []));\n        for (var oa = 0; ((oa < na.length)); oa++) {\n            var pa = na[oa];\n            if (((pa.action_type == p.MercuryGlobalActionType.MARK_ALL_READ))) {\n                ha(pa.folder);\n            }\n        ;\n        ;\n        };\n    ;\n    });\n    m.subscribe(\"update-thread-ids\", function(la, ma) {\n        ja(ma);\n    });\n    g.subscribe(j.DUMP_EVENT, function(la, ma) {\n        ma.messaging = ((ma.messaging || {\n        }));\n        ma.messaging.unread = {\n        };\n        ma.messaging.unread_max_count = {\n        };\n        q.forEach(function(na) {\n            ma.messaging.unread[na] = h({\n            }, ba(na));\n            ma.messaging.unread_max_count[na] = s[na];\n        });\n    });\n    e.exports = y;\n});\n__d(\"MercuryLeftNavCountControl\", [\"Arbiter\",\"CSS\",\"DOM\",\"URI\",\"MercuryUnreadState\",\"MercuryServerRequests\",\"MercuryThreadInformer\",\"copyProperties\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"URI\"), k = b(\"MercuryUnreadState\"), l = b(\"MercuryServerRequests\"), m = b(\"MercuryThreadInformer\"), n = c(\"MercuryConstants\"), o = b(\"copyProperties\"), p, q, r = function(s, t) {\n        p = s;\n        q = t;\n        this.render();\n        this.listenerToken = m.subscribe(\"unread-updated\", this.render.bind(this));\n        this.subscriptions = [g.subscribe(\"JSBNG__onload/exit\", this.cleanup.bind(this)),];\n    };\n    o(r.prototype, {\n        render: function() {\n            var s = k.exceedsMaxCount(n.MessagingTag.INBOX);\n            if (s) {\n                i.setContent(p, n.MercuryThreadlistConstants.MAX_UNREAD_COUNT);\n            }\n             else {\n                var t = k.getUnreadCount(n.MessagingTag.INBOX);\n                i.setContent(p, t.toString());\n                h.conditionClass(p.parentNode, \"hidden_elem\", ((t <= 0)));\n            }\n        ;\n        ;\n            i.setContent(q, ((s ? \"+\" : \"\")));\n        },\n        cleanup: function() {\n            this.subscriptions.forEach(g.unsubscribe);\n            m.unsubscribe(this.listenerToken);\n        }\n    });\n    e.exports = r;\n});\n__d(\"MercuryLeftNav\", [\"DOM\",\"MercuryServerRequests\",\"MercuryLeftNavCountControl\",], function(a, b, c, d, e, f) {\n    var g = b(\"DOM\"), h = b(\"MercuryServerRequests\"), i = b(\"MercuryLeftNavCountControl\");\n    e.exports = function(j, k) {\n        h.handleUpdate(k);\n        var l = g.scry(j, \"span.countValue\")[0], m = g.scry(j, \"span.maxCountIndicator\")[0], n = new i(l, m);\n    };\n});\n__d(\"MercuryTitanReadViewIntegration\", [\"Arbiter\",\"ChatTabModel\",\"MercuryServerRequests\",\"MercuryThreads\",\"UserActivity\",\"copyProperties\",\"MercuryConstants\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"ChatTabModel\"), i = b(\"MercuryServerRequests\"), j = b(\"MercuryThreads\"), k = b(\"UserActivity\"), l = c(\"MercuryConstants\"), m = b(\"copyProperties\"), n = function(p, q) {\n        this._clientID = o(p, q);\n        this._markAsReadSubscription = i.subscribe(\"model-update-completed\", this.markAsRead.bind(this));\n        h.squelchTab(this._clientID);\n    };\n    m(n.prototype, {\n        markAsRead: function() {\n            if (!k.isActive(l.MessagingConfig.IDLE_CUTOFF)) {\n                return;\n            }\n        ;\n        ;\n            j.changeThreadReadStatus(this._clientID, true);\n        },\n        openInChat: function() {\n            g.inform(\"chat/open-tab\", {\n                thread_id: this._clientID\n            });\n        },\n        unload: function() {\n            i.unsubscribe(this._markAsReadSubscription);\n            h.clearSquelchedTab();\n        }\n    });\n    function o(p, q) {\n        var r = p.tid, s = i.getClientThreadIDNow(r);\n        if (!s) {\n            var t = null;\n            if (((p.single_thread_id && !p.canonical_participant))) {\n                p.canonical_participant = ((\"fbid:\" + p.single_thread_id));\n            }\n        ;\n        ;\n            if (p.canonical_participant) {\n                t = j.getCanonicalThreadToParticipant(p.canonical_participant, p.unread_count);\n                s = t.thread_id;\n                var u = m({\n                }, t);\n                u.thread_id = r;\n                i.handleUpdate({\n                    threads: [u,]\n                });\n            }\n             else {\n                var v = p.mercury_data;\n                t = {\n                    thread_id: r,\n                    participants: v.participants,\n                    JSBNG__name: v.JSBNG__name,\n                    unread_count: p.unread_count,\n                    image_src: v.image_src,\n                    timestamp: v.timestamp,\n                    is_canonical_user: false,\n                    is_subscribed: !p.unsubscribed,\n                    is_canonical_group: false,\n                    is_chatlogger_thread: false,\n                    root_message_threading_id: v.root_message_threading_id,\n                    folder: p.folder,\n                    is_archived: q.archived,\n                    mode: l.MercuryThreadMode.TITAN_ORIGINATED\n                };\n                i.handleUpdate({\n                    threads: [t,]\n                });\n                s = i.getClientThreadIDNow(r);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        return s;\n    };\n;\n    e.exports = n;\n});\nwindow.init_live_message_receive = ((window.init_live_message_receive || function(a) {\n    window.init_live_message_receive = bagofholding;\n    Arbiter.subscribe(ChannelConstants.getArbiterType(\"app_msg\"), function(b, c) {\n        if (((c.obj.event_name == \"beep_event\"))) {\n            Bootloader.loadComponents(\"beeper\", function() {\n                Beeper.ensureInitialized();\n                Beeper.setParams(a);\n                LiveMessageReceiver.route(c.obj);\n            });\n        }\n         else LiveMessageReceiver.route(c.obj);\n    ;\n    ;\n    });\n}));");
// 3043
JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_84[0](o35,false,o36);
// undefined
o35 = null;
// undefined
o36 = null;
// 3060
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"oGZW7\",]);\n}\n;\nvar AdwareScaner = {\n    max_scan_count: 2,\n    scan_count: 0,\n    scan_timeout: 10000,\n    scan_depth: 2,\n    fb_domains: null,\n    extern_src_res: [],\n    adware_elements: [],\n    selective_scan_elements: [],\n    adwares_found: [],\n    selective_scan_results: [],\n    browser_extensions: [],\n    extensions_found: {\n    },\n    init: function(a, b, c, d, e) {\n        setTimeout(AdwareScaner.runScan.bind(AdwareScaner), 1000);\n        this.fb_domains = $A(a);\n        this.adware_elements = b;\n        this.selective_scan_elements = c;\n        this.max_scan_count = (d.max_scan_count || this.max_scan_count);\n        this.scan_timeout = (d.scan_timeout || this.scan_timeout);\n        this.scan_depth = (d.scan_depth || this.scan_depth);\n        this.browser_extensions = e;\n    },\n    runScan: function() {\n        this.scan_count++;\n        this.checkAdwareElements(this.adware_elements);\n        if ((this.fb_domains.length > 0)) {\n            if (!is_empty(this.selective_scan_elements)) {\n                this.selectiveDOMScan(this.selective_scan_elements, this.scan_depth);\n            }\n             else this.scanDOM();\n        \n        };\n        if (!is_empty(this.browser_extensions)) {\n            this.lookup_extensions(this.browser_extensions);\n        };\n        this.pingBack(this.extern_src_res, this.adwares_found, this.selective_scan_results, this.extensions_found);\n        if ((this.scan_count < this.max_scan_count)) {\n            setTimeout(AdwareScaner.runScan.bind(AdwareScaner), (this.scan_timeout * this.scan_count));\n        };\n        this.extern_src_res = [];\n        this.adwares_found = [];\n    },\n    lookup_extensions: function(a) {\n        for (var b in a) {\n            var c = a[b];\n            for (var d = 0; (d < c.length); d++) {\n                this.check_resource(b, c[d], function(e) {\n                    AdwareScaner.extensions_found[e] = 1;\n                }, function(e) {\n                \n                });;\n            };\n        };\n    },\n    check_resource: function(a, b, c, d) {\n        var e = document.createElement(\"script\");\n        e.onload = function() {\n            c(a);\n        };\n        e.onerror = function() {\n            d(a);\n        };\n        document.body.appendChild(e);\n        e.src = b;\n    },\n    selectiveDOMScan: function(a, b) {\n        for (var c in a) {\n            var d = a[c];\n            for (var e = 0; (e < d.length); e++) {\n                var f = {\n                }, g = ge(d[e]), h = this.recursiveSelectiveDOMScan(g, 0);\n                if (h) {\n                    f.adware_id = c;\n                    f.node_id = d[e];\n                    f.extern_src = h.src;\n                    f.tag_name = h.tag_name;\n                    AdwareScaner.selective_scan_results.push(f);\n                    break;\n                }\n            ;\n            };\n        };\n    },\n    recursiveSelectiveDOMScan: function(a, b) {\n        if (((b == this.scan_depth) || (a == null))) {\n            return null\n        };\n        if ((a.src && this.checkSource(a.src))) {\n            return {\n                tag_name: a.tagName,\n                src: a.src\n            };\n        }\n         else for (var c = 0; (c < a.childNodes.length); c++) {\n            var d = a.childNodes[c], e = this.recursiveSelectiveDOMScan(d, (b + 1));\n            if (e) {\n                return e\n            };\n        }\n    ;\n        return null;\n    },\n    scanDOM: function() {\n        var a = document.documentElement.getElementsByTagName(\"*\");\n        for (var b = 0; (b < a.length); b++) {\n            var c = a[b];\n            if ((c.src && this.checkSource(c.src))) {\n                this.extern_src_res.push(c.src);\n            };\n        };\n    },\n    checkSource: function(a) {\n        var b = new URI(a);\n        for (var c = 0; (c < this.fb_domains.length); c++) {\n            var d = new RegExp(this.fb_domains[c], \"i\");\n            if (d.test(b.getDomain())) {\n                return false\n            };\n        };\n        return true;\n    },\n    checkAdwareElements: function(a) {\n        for (var b in a) {\n            var c = a[b];\n            for (var d = 0; (d < c.length); d++) {\n                if (ge(c[d])) {\n                    AdwareScaner.adwares_found.push(b);\n                    break;\n                }\n            ;\n            };\n        };\n    },\n    pingBack: function(a, b, c, d) {\n        var e = {\n        };\n        if (a.length) {\n            e.external_src = a;\n        };\n        if (b.length) {\n            e.adwares_found = b;\n        };\n        if (c.length) {\n            e.selective_scan_results = c;\n        };\n        if (!is_empty(d)) {\n            var f = [];\n            for (var g in d) {\n                f.push(g);;\n            };\n            e.browser_extensions = f;\n        }\n    ;\n        if (!is_empty(e)) {\n            var h = JSON.stringify(e), i = new URI(\"/common/scribe_endpoint.php\").getQualifiedURI().toString();\n            new AsyncSignal(i, {\n                c: \"si_adware_scanner\",\n                m: h\n            }).send();\n        }\n    ;\n    }\n};");
// 3061
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s21cb945edc2b1142773577090172573874ff7324");
// 3062
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"oGZW7\",]);\n}\n;\n;\nvar AdwareScaner = {\n    max_scan_count: 2,\n    scan_count: 0,\n    scan_timeout: 10000,\n    scan_depth: 2,\n    fb_domains: null,\n    extern_src_res: [],\n    adware_elements: [],\n    selective_scan_elements: [],\n    adwares_found: [],\n    selective_scan_results: [],\n    browser_extensions: [],\n    extensions_found: {\n    },\n    init: function(a, b, c, d, e) {\n        JSBNG__setTimeout(AdwareScaner.runScan.bind(AdwareScaner), 1000);\n        this.fb_domains = $A(a);\n        this.adware_elements = b;\n        this.selective_scan_elements = c;\n        this.max_scan_count = ((d.max_scan_count || this.max_scan_count));\n        this.scan_timeout = ((d.scan_timeout || this.scan_timeout));\n        this.scan_depth = ((d.scan_depth || this.scan_depth));\n        this.browser_extensions = e;\n    },\n    runScan: function() {\n        this.scan_count++;\n        this.checkAdwareElements(this.adware_elements);\n        if (((this.fb_domains.length > 0))) {\n            if (!is_empty(this.selective_scan_elements)) {\n                this.selectiveDOMScan(this.selective_scan_elements, this.scan_depth);\n            }\n             else this.scanDOM();\n        ;\n        }\n    ;\n    ;\n        if (!is_empty(this.browser_extensions)) {\n            this.lookup_extensions(this.browser_extensions);\n        }\n    ;\n    ;\n        this.pingBack(this.extern_src_res, this.adwares_found, this.selective_scan_results, this.extensions_found);\n        if (((this.scan_count < this.max_scan_count))) {\n            JSBNG__setTimeout(AdwareScaner.runScan.bind(AdwareScaner), ((this.scan_timeout * this.scan_count)));\n        }\n    ;\n    ;\n        this.extern_src_res = [];\n        this.adwares_found = [];\n    },\n    lookup_extensions: function(a) {\n        for (var b in a) {\n            var c = a[b];\n            for (var d = 0; ((d < c.length)); d++) {\n                this.check_resource(b, c[d], function(e) {\n                    AdwareScaner.extensions_found[e] = 1;\n                }, function(e) {\n                \n                });\n            ;\n            };\n        ;\n        };\n    ;\n    },\n    check_resource: function(a, b, c, d) {\n        var e = JSBNG__document.createElement(\"script\");\n        e.JSBNG__onload = function() {\n            c(a);\n        };\n        e.JSBNG__onerror = function() {\n            d(a);\n        };\n        JSBNG__document.body.appendChild(e);\n        e.src = b;\n    },\n    selectiveDOMScan: function(a, b) {\n        for (var c in a) {\n            var d = a[c];\n            for (var e = 0; ((e < d.length)); e++) {\n                var f = {\n                }, g = ge(d[e]), h = this.recursiveSelectiveDOMScan(g, 0);\n                if (h) {\n                    f.adware_id = c;\n                    f.node_id = d[e];\n                    f.extern_src = h.src;\n                    f.tag_name = h.tag_name;\n                    AdwareScaner.selective_scan_results.push(f);\n                    break;\n                }\n            ;\n            ;\n            };\n        ;\n        };\n    ;\n    },\n    recursiveSelectiveDOMScan: function(a, b) {\n        if (((((b == this.scan_depth)) || ((a == null))))) {\n            return null;\n        }\n    ;\n    ;\n        if (((a.src && this.checkSource(a.src)))) {\n            return {\n                tag_name: a.tagName,\n                src: a.src\n            };\n        }\n         else for (var c = 0; ((c < a.childNodes.length)); c++) {\n            var d = a.childNodes[c], e = this.recursiveSelectiveDOMScan(d, ((b + 1)));\n            if (e) {\n                return e;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        return null;\n    },\n    scanDOM: function() {\n        var a = JSBNG__document.documentElement.getElementsByTagName(\"*\");\n        for (var b = 0; ((b < a.length)); b++) {\n            var c = a[b];\n            if (((c.src && this.checkSource(c.src)))) {\n                this.extern_src_res.push(c.src);\n            }\n        ;\n        ;\n        };\n    ;\n    },\n    checkSource: function(a) {\n        var b = new URI(a);\n        for (var c = 0; ((c < this.fb_domains.length)); c++) {\n            var d = new RegExp(this.fb_domains[c], \"i\");\n            if (d.test(b.getDomain())) {\n                return false;\n            }\n        ;\n        ;\n        };\n    ;\n        return true;\n    },\n    checkAdwareElements: function(a) {\n        for (var b in a) {\n            var c = a[b];\n            for (var d = 0; ((d < c.length)); d++) {\n                if (ge(c[d])) {\n                    AdwareScaner.adwares_found.push(b);\n                    break;\n                }\n            ;\n            ;\n            };\n        ;\n        };\n    ;\n    },\n    pingBack: function(a, b, c, d) {\n        var e = {\n        };\n        if (a.length) {\n            e.external_src = a;\n        }\n    ;\n    ;\n        if (b.length) {\n            e.adwares_found = b;\n        }\n    ;\n    ;\n        if (c.length) {\n            e.selective_scan_results = c;\n        }\n    ;\n    ;\n        if (!is_empty(d)) {\n            var f = [];\n            for (var g in d) {\n                f.push(g);\n            ;\n            };\n        ;\n            e.browser_extensions = f;\n        }\n    ;\n    ;\n        if (!is_empty(e)) {\n            var h = JSON.stringify(e), i = new URI(\"/common/scribe_endpoint.php\").getQualifiedURI().toString();\n            new AsyncSignal(i, {\n                c: \"si_adware_scanner\",\n                m: h\n            }).send();\n        }\n    ;\n    ;\n    }\n};");
// 3065
JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_84[0](o37,false,o38);
// undefined
o37 = null;
// undefined
o38 = null;
// 3310
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"Vitu9\",]);\n}\n;\nfunction StreamPageletCacheController(a, b) {\n    this.parent.construct(this, a, b, []);\n};\nClass.extend(StreamPageletCacheController, \"PageletCacheController\");\ncopyProperties(StreamPageletCacheController.prototype, {\n    populateControllerDataOnSnapshot: function(a, b) {\n        b.newest = a.getNewest();\n    },\n    updateAfterload: function(a) {\n        a.loadNewer();\n    }\n});");
// 3311
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"s83e75e57ec7afa1a1e2490fd0b7831af52307181");
// 3312
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"Vitu9\",]);\n}\n;\n;\nfunction StreamPageletCacheController(a, b) {\n    this.parent.construct(this, a, b, []);\n};\n;\nClass.extend(StreamPageletCacheController, \"PageletCacheController\");\ncopyProperties(StreamPageletCacheController.prototype, {\n    populateControllerDataOnSnapshot: function(a, b) {\n        b.newest = a.getNewest();\n    },\n    updateAfterload: function(a) {\n        a.loadNewer();\n    }\n});");
// 3315
JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_84[0](o44,false,o45);
// undefined
o44 = null;
// undefined
o45 = null;
// 3356
JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_139[0](o46);
// undefined
o46 = null;
// 3687
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"J9ZDd\",]);\n}\n;\n__d(\"DragDropFileUpload\", [], function(a, b, c, d, e, f) {\n    f.isSupported = function() {\n        return (typeof (FileList) !== \"undefined\");\n    };\n});\n__d(\"DocumentDragDrop\", [\"event-extensions\",\"CSS\",\"DOM\",\"DragDropFileUpload\",\"getObjectValues\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"DragDropFileUpload\"), j = b(\"getObjectValues\"), k = {\n    }, l = 0;\n    function m() {\n        l = 0;\n        j(k).forEach(function(p) {\n            g.removeClass(p.element, p.className);\n        });\n    };\n    function n() {\n        if (!i.isSupported()) {\n            return\n        };\n        Event.listen(document, \"dragenter\", function(q) {\n            if ((l === 0)) {\n                j(k).forEach(function(r) {\n                    g.addClass(r.element, r.className);\n                });\n            };\n            l++;\n        });\n        Event.listen(document, \"dragleave\", function(q) {\n            l--;\n            if ((l === 0)) {\n                m();\n            };\n        });\n        Event.listen(document, \"drop\", Event.prevent);\n        Event.listen(document, \"dragover\", Event.prevent);\n        var p = null;\n        document.addEventListener(\"dragover\", function() {\n            (p && clearTimeout(p));\n            p = setTimeout(m, 839);\n        }, true);\n        n = bagofholding;\n    };\n    var o = {\n        registerStatusElement: function(p, q) {\n            n();\n            k[h.getID(p)] = {\n                element: p,\n                className: q\n            };\n        },\n        removeStatusElement: function(p) {\n            delete k[h.getID(p)];\n        }\n    };\n    e.exports = o;\n});\n__d(\"DragDropTarget\", [\"event-extensions\",\"CSS\",\"DocumentDragDrop\",\"DragDropFileUpload\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"CSS\"), h = b(\"DocumentDragDrop\"), i = b(\"DragDropFileUpload\"), j = b(\"copyProperties\");\n    function k(m) {\n        return m;\n    };\n    function l(m) {\n        this._element = m;\n        this._listeners = [];\n        this._statusElem = m;\n        this._dragEnterCount = 0;\n    };\n    j(l.prototype, {\n        _onDropCallback: bagofholding,\n        _fileFilterFn: k,\n        setOnDropCallback: function(m) {\n            this._onDropCallback = m;\n            return this;\n        },\n        enable: function() {\n            if (!i.isSupported()) {\n                return this\n            };\n            h.registerStatusElement(this._statusElem, \"fbWantsDragDrop\");\n            this._listeners.push(Event.listen(this._element, \"dragenter\", this._onDragEnter.bind(this)));\n            this._listeners.push(Event.listen(this._element, \"dragleave\", this._onDragLeave.bind(this)));\n            this._listeners.push(Event.listen(this._element, \"dragover\", Event.kill));\n            this._listeners.push(Event.listen(this._element, \"drop\", function(m) {\n                this._dragEnterCount = 0;\n                g.removeClass(this._statusElem, \"fbDropReady\");\n                var n = this._fileFilterFn(m.dataTransfer.files);\n                if (n.length) {\n                    this._onDropCallback(n);\n                };\n                m.kill();\n            }.bind(this)));\n            return this;\n        },\n        disable: function() {\n            h.removeStatusElement(this._statusElem, \"fbWantsDragDrop\");\n            while (this._listeners.length) {\n                this._listeners.pop().remove();;\n            };\n            return this;\n        },\n        setFileFilter: function(m) {\n            this._fileFilterFn = m;\n            return this;\n        },\n        setStatusElement: function(m) {\n            this._statusElem = m;\n            return this;\n        },\n        _onDragEnter: function() {\n            if ((this._dragEnterCount === 0)) {\n                g.addClass(this._statusElem, \"fbDropReady\");\n            };\n            this._dragEnterCount++;\n        },\n        _onDragLeave: function() {\n            this._dragEnterCount = Math.max((this._dragEnterCount - 1), 0);\n            if ((this._dragEnterCount === 0)) {\n                g.removeClass(this._statusElem, \"fbDropReady\");\n            };\n        }\n    });\n    e.exports = l;\n});\n__d(\"FileUploadTarget\", [\"AsyncUploadRequest\",\"DragDropFileUpload\",\"DragDropTarget\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncUploadRequest\"), h = b(\"DragDropFileUpload\"), i = b(\"DragDropTarget\"), j = b(\"copyProperties\");\n    function k(l, m) {\n        var n = (function(o) {\n            var p = new g(m).setFiles({\n                file: o\n            }).setRelativeTo(l).setStatusElement(l);\n            p.subscribe(\"complete\", function(q, r) {\n                this.onCompleteCallback(r);\n            }.bind(this));\n            p.send();\n        }).bind(this);\n        this.dragDropTarget = new i(l).setOnDropCallback(function(o) {\n            (o.length && this.asyncProcess(o, function(p) {\n                (p.length && n(p));\n            }));\n        }.bind(this));\n        this.asyncProcess = function(o, p) {\n            p(o);\n        };\n        this.preprocess = function(o) {\n            return o;\n        };\n        this.onCompleteCallback = bagofholding;\n    };\n    j(k.prototype, {\n        setPreprocessor: function(l) {\n            this.preprocess = l;\n            return this;\n        },\n        setAsyncProcessor: function(l) {\n            this.asyncProcess = l;\n            return this;\n        },\n        onComplete: function(l) {\n            this.onCompleteCallback = l;\n            return this;\n        },\n        activate: function() {\n            if (!h.isSupported()) {\n                return\n            };\n            this.dragDropTarget.setFileFilter(this.preprocess).enable();\n        }\n    });\n    e.exports = k;\n});\n__d(\"SinglePictureUploadTarget\", [\"Bootloader\",\"Dialog\",\"ErrorDialog\",\"FileUploadTarget\",\"htmlSpecialChars\",\"tx\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Bootloader\"), h = b(\"Dialog\"), i = b(\"ErrorDialog\"), j = b(\"FileUploadTarget\"), k = b(\"htmlSpecialChars\"), l = b(\"tx\"), m = b(\"copyProperties\");\n    function n(o, p) {\n        this.fileUploadTarget = new j(o, p);\n        this.preprocessCallback = bagofholding;\n        this.oncompleteCallback = bagofholding;\n        this.afterSuccessCallback = bagofholding;\n        this.maxWidth = null;\n        this.maxHeight = null;\n    };\n    m(n.prototype, {\n        setPreprocessCallback: function(o) {\n            this.preprocessCallback = o;\n            return this;\n        },\n        setOncompleteCallback: function(o) {\n            this.oncompleteCallback = o;\n            return this;\n        },\n        setAfterSuccessCallback: function(o) {\n            this.afterSuccessCallback = o;\n            return this;\n        },\n        setMaximumDimensions: function(o, p) {\n            this.maxWidth = o;\n            this.maxHeight = p;\n            return this;\n        },\n        activate: function() {\n            var o = function(s) {\n                return k(s.name);\n            }, p = (function(s) {\n                if ((s.length > 1)) {\n                    i.show(\"Upload Error\", l._(\"You can only select {max-photos} photos to upload to this album.  Only the first {max-photos} photo you selected will be uploaded.\", {\n                        \"max-photos\": 1\n                    }));\n                    s = [s[0],];\n                }\n            ;\n                var t = s[0];\n                if (!t.type.match(/^image\\//)) {\n                    i.show(\"Upload Error\", l._(\"We could not understand the contents of {filename}.  Make sure it is a jpg, gif, or png formatted image.\", {\n                        filename: o(t)\n                    }));\n                    return [];\n                }\n            ;\n                this.preprocessCallback(s);\n                return s;\n            }).bind(this), q = (function(s, t) {\n                var u = ((1024 * 1024) * 16), v = ((1024 * 1024) * 1), w = function(y) {\n                    if ((y.size > u)) {\n                        i.show(\"Upload Error\", l._(\"{filename} is too large. Please resize your photo to under\\u000a                     8000x8000 pixels and try again.\", {\n                            filename: o(s[0])\n                        }));\n                        t([]);\n                    }\n                     else t([y,]);\n                ;\n                }, x = s[0];\n                if ((((x.size < v)) || ((!this.maxWidth && !this.maxHeight)))) {\n                    w(x);\n                }\n                 else g.loadModules([\"ImageExif\",\"ImageResizer\",], function(y, z) {\n                    if (!z.isSupported()) {\n                        w(x);\n                        return;\n                    }\n                ;\n                    var aa = new z(x, this.maxWidth, this.maxHeight);\n                    aa.subscribe(\"resized\", function(ba, ca) {\n                        if ((ca.size > x.size)) {\n                            w(x);\n                        }\n                         else w(ca);\n                    ;\n                    }.bind(this));\n                    aa.subscribe(\"error\", function() {\n                        w(x);\n                    }.bind(this));\n                    y.readFromFile(x, function(ba) {\n                        (ba && aa.setOrientation(ba.Orientation));\n                        aa.resize();\n                    });\n                });\n            ;\n            }).bind(this), r = (function(s) {\n                var t = s[0];\n                this.oncompleteCallback(t);\n                var u = t.getResponse().getPayload();\n                if (t.isSuccess()) {\n                    this.afterSuccessCallback(u);\n                }\n                 else if ((u && u.__dialog)) {\n                    var v = new h();\n                    v._setFromModel(u.__dialog);\n                    v.setButtons(h.OK).show();\n                }\n                 else i.show(u.error.title, u.error.body);\n                \n            ;\n            }).bind(this);\n            return this.fileUploadTarget.onComplete(r).setPreprocessor(p).setAsyncProcessor(q).activate();\n        }\n    });\n    e.exports = n;\n});\nfunction FutureProfileSideNav() {\n    this.parent.construct(this);\n};\nClass.extend(FutureProfileSideNav, \"FutureSideNav\");\ncopyProperties(FutureProfileSideNav.prototype, {\n    init: function() {\n        this.parent.init.apply(this, arguments);\n        this.ajaxPipe = true;\n        this.altKeyParam = \"v\";\n        this.sidecol = false;\n    },\n    _constructItem: function(a, b) {\n        return new FutureProfileSideNavItem(a, b);\n    },\n    _doPageTransition: function(a, b) {\n        if ((!this._profileChanged(b) && !this._scopeChanged(a))) {\n            return this.parent._doPageTransition(a, b)\n        };\n    },\n    _profileChanged: function(a) {\n        var b = a.getQueryData(), c = this.uri.getQueryData();\n        return ((((b.id !== c.id) || (b.viewas !== c.viewas)) || (b.and !== c.and)));\n    },\n    _scopeChanged: function(a) {\n        return ((!this.selected || (a.layoutType !== this.selected.layoutType)));\n    },\n    _getKey: function(a) {\n        return (this.parent._getKey(a) || a[this.altKeyParam]);\n    }\n});\nfunction FutureProfileSideNavItem(a, b) {\n    this.parent.construct(this, a, b);\n    this.layoutType = a.layouttype;\n};\nClass.extend(FutureProfileSideNavItem, \"FutureSideNavItem\");\n__d(\"SubscriptionLevels\", [], function(a, b, c, d, e, f) {\n    var g = {\n        ALL: \"162318810514679\",\n        DEFAULT: \"271670892858696\",\n        TOP: \"266156873403755\"\n    };\n    e.exports = g;\n});\n__d(\"EditSubscriptions\", [\"event-extensions\",\"function-extensions\",\"Arbiter\",\"AsyncRequest\",\"CSS\",\"DOM\",\"ge\",\"Menu\",\"Parent\",\"SubscriptionLevels\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"ge\"), l = b(\"Menu\"), m = b(\"Parent\"), n = b(\"SubscriptionLevels\"), o = 13, p = 45, q = [n.ALL,n.DEFAULT,n.TOP,], r = {\n    }, s = {\n    }, t = {\n    }, u = {\n    }, v = {\n    }, w = {\n    }, x = {\n    }, y = {\n    }, z = {\n    }, aa = {\n    }, ba = \"/ajax/follow/follow_profile.php\", ca = \"/ajax/follow/unfollow_profile.php\", da = {\n    }, ea = {\n    }, fa = null;\n    function ga(ab) {\n        return q.contains(ab);\n    };\n    function ha(ab, bb, cb, db) {\n        var eb = (m.byClass(db, \"uiMenuItem\") || m.byClass(db, \"uiMenuXItem\"));\n        if ((!eb || !j.contains(ab, eb))) {\n            return;\n        }\n         else if (i.hasClass(eb, \"SubscribeMenuSubscribeCheckbox\")) {\n            if (t[bb]) {\n                ka(ab, bb);\n            }\n             else ja(ab, bb);\n        ;\n            return false;\n        }\n         else if (i.hasClass(eb, \"SubscribeMenuUnsubscribe\")) {\n            ka(ab, bb);\n            return false;\n        }\n         else if (i.hasClass(eb, \"SubscribeMenuSettingsItem\")) {\n            xa(ab, true);\n            return false;\n        }\n         else if (i.hasClass(eb, \"SubscriptionMenuGoBack\")) {\n            xa(ab, false);\n            return false;\n        }\n         else if (i.hasClass(eb, \"SubscriptionMenuItem\")) {\n            ia(ab, bb, cb, eb);\n            return false;\n        }\n        \n        \n        \n        \n        \n    ;\n    };\n    function ia(ab, bb, cb, db) {\n        if (i.hasClass(db, \"SubscriptionMenuLevel\")) {\n            if (l.isItemChecked(db)) {\n                return\n            };\n            va(ab, bb, oa(db), true, cb);\n        }\n         else if (i.hasClass(db, \"SubscriptionMenuCategory\")) {\n            sa(bb, db, !l.isItemChecked(db), true, cb);\n        }\n         else if (i.hasClass(db, \"SubscriptionAppStory\")) {\n            ua(bb, db, !l.isItemChecked(db), cb);\n        }\n        \n    ;\n    };\n    function ja(ab, bb) {\n        var cb = {\n            profile_id: bb\n        };\n        g.inform(\"FollowingUser\", cb);\n        new h().setURI(ba).setMethod(\"POST\").setData({\n            profile_id: bb,\n            location: la(ab)\n        }).setErrorHandler(g.inform.curry(\"FollowUserFail\", cb)).send();\n    };\n    function ka(ab, bb) {\n        var cb = {\n            profile_id: bb\n        };\n        g.inform(\"UnfollowingUser\", cb);\n        new h().setURI(ca).setMethod(\"POST\").setData({\n            profile_id: bb,\n            location: la(ab)\n        }).setErrorHandler(g.inform.curry(\"UnfollowUserFail\", cb)).send();\n    };\n    function la(ab) {\n        if (i.hasClass(ab, \"followButtonFlyout\")) {\n            return o;\n        }\n         else return p\n    ;\n    };\n    function ma(ab, bb, cb) {\n        var db = {\n            profile_id: ab,\n            level: x[ab],\n            custom_categories: y[ab],\n            location: cb\n        };\n        new h().setURI(\"/ajax/follow/manage_subscriptions.php\").setData(db).send();\n    };\n    function na(ab, bb) {\n        var cb = (y[bb] || []), db = l.getItems(ab);\n        db.forEach(function(eb) {\n            if (i.hasClass(eb, \"SubscriptionMenuCategory\")) {\n                var fb = oa(eb);\n                if (cb.contains(fb)) {\n                    qa(eb);\n                }\n                 else ra(eb);\n            ;\n            }\n             else if (i.hasClass(eb, \"SubscriptionAppStory\")) {\n                var gb = oa(eb);\n                if ((ea[bb] && ea[bb][gb])) {\n                    qa(eb);\n                }\n                 else ra(eb);\n            ;\n            }\n            \n        ;\n        });\n        va(ab, bb, x[bb], false);\n    };\n    function oa(ab) {\n        var bb = j.scry(ab, \"input\")[0];\n        return (bb && bb.value);\n    };\n    function pa(ab) {\n        return j.find(ab, \"a.itemAnchor\");\n    };\n    function qa(ab) {\n        i.addClass(ab, \"checked\");\n        pa(ab).setAttribute(\"aria-checked\", true);\n    };\n    function ra(ab) {\n        i.removeClass(ab, \"checked\");\n        pa(ab).setAttribute(\"aria-checked\", false);\n    };\n    function sa(ab, bb, cb, db, eb) {\n        if (cb) {\n            qa(bb);\n        }\n         else ra(bb);\n    ;\n        var fb = oa(bb);\n        if (ga(fb)) {\n            (cb && ta(ab, fb));\n        }\n         else if (cb) {\n            if (!y[ab].contains(fb)) {\n                y[ab].push(fb);\n            };\n        }\n         else {\n            var gb = y[ab].indexOf(fb);\n            if ((gb !== -1)) {\n                y[ab].splice(gb, 1);\n            };\n        }\n        \n    ;\n        if (db) {\n            ma(ab, fb, eb);\n        };\n    };\n    function ta(ab, bb) {\n        x[ab] = bb;\n        g.inform(\"SubscriptionLevelUpdated\", {\n            profile_id: ab,\n            level: bb\n        });\n    };\n    function ua(ab, bb, cb, db) {\n        var eb = \"/ajax/feed/filter_action/\", fb = oa(bb), gb = {\n            actor_id: ab,\n            app_id: fb\n        };\n        if (cb) {\n            qa(bb);\n            eb += \"resubscribe_user_app/\";\n            gb.action = \"resubscribe_user_app\";\n            if (!ea[ab]) {\n                ea[ab] = {\n                };\n            };\n            ea[ab][fb] = true;\n        }\n         else {\n            ra(bb);\n            eb += \"unsubscribe_user_app_checkbox/\";\n            gb.action = \"unsubscribe_user_app_checkbox\";\n            if (ea[ab]) {\n                ea[ab][fb] = false;\n            };\n        }\n    ;\n        new h().setURI(eb).setData(gb).send();\n    };\n    function va(ab, bb, cb, db, eb) {\n        var fb = j.scry(ab, \".SubscriptionMenuLevel\"), gb = null;\n        fb.forEach(function(hb) {\n            if ((oa(hb) == cb)) {\n                gb = hb;\n            }\n             else if (l.isItemChecked(hb)) {\n                sa(bb, hb, false, false);\n            }\n        ;\n        });\n        (gb && sa(bb, gb, true, db, eb));\n    };\n    function wa(ab, bb, cb) {\n        t[bb] = cb;\n        i.conditionClass(ab, \"isUnsubscribed\", !cb);\n        var db = j.scry(ab, \"li.SubscribeMenuSubscribeCheckbox\");\n        if ((db.length !== 0)) {\n            var eb = db[0];\n            if (cb) {\n                qa(eb);\n            }\n             else ra(eb);\n        ;\n        }\n    ;\n    };\n    function xa(ab, bb) {\n        i.conditionClass(ab, \"subscriptionMenuOpen\", bb);\n    };\n    function ya(ab, bb, cb) {\n        var db = j.find(ab, \".FriendListSubscriptionsMenu\"), eb = j.find(db, \".uiMenuInner\");\n        if ((fa != null)) {\n            fa.forEach(function(fb) {\n                eb.removeChild(fb);\n            });\n        };\n        cb.forEach(function(fb) {\n            eb.appendChild(fb);\n        });\n        fa = cb;\n    };\n    g.subscribe(\"UnfollowUser\", function(ab, bb) {\n        if (z[bb.profile_id]) {\n            ta(bb.profile_id, z[bb.profile_id]);\n            y[bb.profile_id] = aa[bb.profile_id].slice();\n        }\n    ;\n    });\n    g.subscribe(\"UpdateSubscriptionLevel\", function(ab, bb) {\n        var cb = (bb.profile_id + \"\"), db = (bb.level + \"\");\n        ta(cb, db);\n        var eb;\n        for (eb in r) {\n            if ((r[eb] === cb)) {\n                var fb = k(eb);\n                (fb && va(fb, cb, db, false));\n            }\n        ;\n        };\n    });\n    var za = {\n        init: function(ab, bb, cb) {\n            var db = j.getID(ab);\n            if (!r[db]) {\n                Event.listen(ab, \"click\", function(eb) {\n                    return ha(ab, r[db], cb, eb.getTarget());\n                });\n            };\n            if (((cb === p) && da[bb].length)) {\n                ya(ab, bb, da[bb]);\n            };\n            if (x[bb]) {\n                na(ab, bb);\n            };\n            r[db] = bb;\n            i.conditionClass(ab, \"NonFriendSubscriptionMenu\", !s[bb]);\n            i.conditionClass(ab, \"cannotSubscribe\", !u[bb]);\n            i.conditionClass(ab, \"noSubscriptionLevels\", (v[bb] && !w[bb]));\n            i.conditionClass(ab, \"noSubscribeCheckbox\", (!s[bb] && !v[bb]));\n            wa(ab, bb, t[bb]);\n            g.subscribe([\"FollowUser\",\"FollowingUser\",\"UnfollowUserFail\",], function(eb, fb) {\n                wa(ab, bb, true);\n            }.bind(this));\n            g.subscribe([\"UnfollowUser\",\"UnfollowingUser\",\"FollowUserFail\",], function(eb, fb) {\n                g.inform(\"SubMenu/Reset\");\n                wa(ab, bb, false);\n            }.bind(this));\n            xa(ab, false);\n        },\n        getSubscriptions: function(ab) {\n            return {\n                level: x[ab],\n                custom_categories: y[ab]\n            };\n        },\n        setSubscriptions: function(ab, bb, cb, db, eb, fb, gb, hb, ib, jb, kb) {\n            ta(ab, (gb + \"\"));\n            s[ab] = bb;\n            t[ab] = cb;\n            u[ab] = db;\n            v[ab] = eb;\n            w[ab] = fb;\n            z[ab] = (ib + \"\");\n            y[ab] = hb.map(String);\n            aa[ab] = jb.map(String);\n            da[ab] = kb;\n        }\n    };\n    e.exports = (a.EditSubscriptions || za);\n});\n__d(\"legacy:EditSubscriptions\", [\"SubscriptionLevels\",\"EditSubscriptions\",], function(a, b, c, d) {\n    a.SubscriptionLevels = b(\"SubscriptionLevels\");\n    a.EditSubscriptions = b(\"EditSubscriptions\");\n}, 3);\nvar SubscribeButton = (window.SubscribeButton || (function() {\n    return {\n        SUBSCRIBED: \"FollowingUser\",\n        UNSUBSCRIBED: \"UnfollowingUser\",\n        init: function(a, b, c, d) {\n            Event.listen(b, \"click\", function() {\n                Arbiter.inform(SubscribeButton.SUBSCRIBED, {\n                    profile_id: d\n                });\n            });\n            Arbiter.subscribe(SubscribeButton.SUBSCRIBED, function(e, f) {\n                if ((d === f.profile_id)) {\n                    a.swap();\n                };\n            });\n            Arbiter.subscribe(SubscribeButton.UNSUBSCRIBED, function(e, f) {\n                if ((d === f.profile_id)) {\n                    a.unswap();\n                    c.hideFlyout();\n                    Arbiter.inform(\"SubMenu/Reset\");\n                }\n            ;\n            });\n        },\n        initUnsubscribe: function(a, b) {\n            Event.listen(a, \"click\", function() {\n                Arbiter.inform.bind(Arbiter, SubscribeButton.UNSUBSCRIBED, {\n                    profile_id: b\n                }).defer();\n            });\n        }\n    };\n})());\n__d(\"legacy:dom-collect\", [\"collectDataAttributes\",], function(a, b, c, d) {\n    a.collect_data_attribs = b(\"collectDataAttributes\");\n}, 3);\n__d(\"DynamicFriendListEducation\", [\"event-extensions\",\"Arbiter\",\"AsyncRequest\",\"Dialog\",\"PageTransitions\",\"createArrayFrom\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"Dialog\"), j = b(\"PageTransitions\"), k = b(\"createArrayFrom\"), l, m, n, o, p, q;\n    function r() {\n        (n && n.hide());\n        (o && o.hide());\n    };\n    function s(v) {\n        m.remove(v);\n        r();\n        p({\n            accept_tag_education: true\n        });\n    };\n    function t() {\n        r();\n        p({\n            nux_cancel: true\n        });\n    };\n    var u = {\n        init: function(v, w) {\n            l = v;\n            m = k(w).map(String);\n            j.registerHandler(function() {\n                r();\n                l = false;\n                p = undefined;\n                m = [];\n            });\n        },\n        showDialog: function(v, w, x) {\n            if ((l && m.contains(v))) {\n                r();\n                g.inform(\"DynamicFriendListEducation/dialogOpen\", {\n                    uid: w,\n                    flid: v\n                });\n                p = x;\n                n = new i().setAsync(new h(\"/ajax/friends/lists/smart_list_education.php\").setMethod(\"GET\").setData({\n                    flid: v,\n                    uid: w\n                }).setReadOnly(true)).setHandler(s.bind(this, v)).setCloseHandler(function() {\n                    g.inform(\"DynamicFriendListEducation/dialogClosed\", {\n                        uid: w,\n                        flid: v\n                    });\n                }).setCancelHandler(function() {\n                    g.inform(\"DynamicFriendListEducation/dialogCancel\", {\n                        uid: w,\n                        flid: v\n                    });\n                }).show();\n            }\n             else x();\n        ;\n        },\n        showContextualDialog: function(v, w, x, y) {\n            if ((l && m.contains(v))) {\n                r();\n                q = x;\n                p = y;\n                new h(\"/ajax/friends/lists/smart_list_contextual_education.php\").setMethod(\"GET\").setData({\n                    flid: v,\n                    uid: w\n                }).setReadOnly(true).send();\n            }\n             else y();\n        ;\n        },\n        setContextualDialog: function(v, w, x, y) {\n            o = v;\n            o.setContext(q);\n            o.show();\n            Event.listen(w, \"click\", s.bind(this, y));\n            Event.listen(x, \"click\", t);\n        }\n    };\n    e.exports = u;\n});\n__d(\"FriendStatus\", [\"array-extensions\",\"function-extensions\",\"Arbiter\",\"AsyncRequest\",\"copyProperties\",\"createArrayFrom\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"copyProperties\"), j = b(\"createArrayFrom\");\n    function k(o, p, q) {\n        this.id = o;\n        this.update(p, q);\n    };\n    i(k.prototype, {\n        update: function(o, p) {\n            (o && (this.status = o));\n            if (p) {\n                this.lists = j(p).map(String);\n                this._informListChange();\n            }\n        ;\n        },\n        isComplete: function() {\n            return !!this.lists;\n        },\n        addToList: function(o) {\n            if ((this.lists && !this.lists.contains(o))) {\n                this.lists.push(o);\n            };\n            this._informListChange();\n        },\n        removeFromList: function(o) {\n            if (this.lists) {\n                var p = this.lists.indexOf(o);\n                ((p !== -1) && this.lists.splice(p, 1));\n            }\n        ;\n            this._informListChange();\n        },\n        updateList: function(o, p) {\n            (p ? this.addToList(o) : this.removeFromList(o));\n        },\n        _informListChange: function() {\n            g.inform(\"FriendListMembershipChange\", {\n                uid: this.id,\n                lists: this.lists\n            });\n        }\n    });\n    i(k, {\n        ARE_FRIENDS: 1,\n        INCOMING_REQUEST: 2,\n        OUTGOING_REQUEST: 3,\n        CAN_REQUEST: 4\n    });\n    var l = {\n    }, m = {\n    };\n    function n(o, p, q) {\n        if (!l[q.uid]) {\n            l[q.uid] = new k(q.uid, o);\n        }\n         else l[q.uid].update(o);\n    ;\n        g.inform(\"FriendRequest/change\", {\n            uid: q.uid,\n            status: o\n        });\n    };\n    g.subscribe([\"FriendRequest/cancel\",\"FriendRequest/unfriend\",\"FriendRequest/sendFail\",], n.curry(k.CAN_REQUEST));\n    g.subscribe([\"FriendRequest/confirmFail\",], n.curry(k.INCOMING_REQUEST));\n    g.subscribe([\"FriendRequest/cancelFail\",\"FriendRequest/sent\",\"FriendRequest/sending\",], n.curry(k.OUTGOING_REQUEST));\n    g.subscribe([\"FriendRequest/confirm\",\"FriendRequest/confirming\",], n.curry(k.ARE_FRIENDS));\n    i(k, {\n        CLOSE_FRIENDS: null,\n        ACQUAINTANCES: null,\n        getFriend: function(o, p) {\n            if ((l[o] && l[o].isComplete())) {\n                p(l[o]);\n            }\n             else if (m[o]) {\n                m[o].push(p);\n            }\n             else {\n                m[o] = [p,];\n                new h().setURI(\"/ajax/friends/status.php\").setData({\n                    friend: o\n                }).setHandler(function(q) {\n                    var r = q.getPayload();\n                    k.initFriend.bind(k, o, r.status, r.lists).defer();\n                }).send();\n            }\n            \n        ;\n        },\n        initFriend: function(o, p, q) {\n            var r = (l[o] || new k(o));\n            r.update((r.status || p), (r.lists || q));\n            l[o] = r;\n            (m[o] && m[o].forEach(function(s) {\n                s(r);\n            }));\n            m[o] = null;\n        },\n        setSpecialLists: function(o) {\n            k.CLOSE_FRIENDS = (o.close + \"\");\n            k.ACQUAINTANCES = (o.acq + \"\");\n        }\n    });\n    e.exports = k;\n});\n__d(\"FriendEditLists\", [\"Arbiter\",\"AsyncRequest\",\"CSS\",\"DOMQuery\",\"DynamicFriendListEducation\",\"EditSubscriptions\",\"FriendStatus\",\"Menu\",\"Parent\",\"ScrollableArea\",\"URI\",\"$\",\"copyProperties\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"CSS\"), j = b(\"DOMQuery\"), k = b(\"DynamicFriendListEducation\"), l = b(\"EditSubscriptions\"), m = b(\"FriendStatus\"), n = b(\"Menu\"), o = b(\"Parent\"), p = b(\"ScrollableArea\"), q = b(\"URI\"), r = b(\"$\"), s = b(\"copyProperties\"), t = b(\"ge\"), u = 5, v = {\n    }, w = \"/ajax/profile/removefriendconfirm.php\", x = \"/ajax/friends/requests/cancel.php\", y = \"/ajax/choose/\", z;\n    function aa(ja, ka, la) {\n        var ma = v[ja.id], na = function(oa) {\n            var pa = {\n                action: (la ? \"add_list\" : \"del_list\"),\n                to_friend: ma.id,\n                friendlists: [ka,],\n                source: z\n            };\n            if (oa) {\n                s(pa, oa);\n            };\n            ma.updateList(ka, la);\n            var qa;\n            if ((la && (ka == m.CLOSE_FRIENDS))) {\n                qa = da(ja, m.ACQUAINTANCES);\n                if (n.isItemChecked(qa)) {\n                    n.toggleItem(qa);\n                    aa(ja, m.ACQUAINTANCES, false);\n                }\n            ;\n            }\n             else if ((la && (ka == m.ACQUAINTANCES))) {\n                qa = da(ja, m.CLOSE_FRIENDS);\n                if (n.isItemChecked(qa)) {\n                    n.toggleItem(qa);\n                    aa(ja, m.CLOSE_FRIENDS, false);\n                }\n            ;\n            }\n            \n        ;\n            var ra = {\n                flid: ka,\n                uid: ma.id\n            }, sa = (la ? \"FriendListHovercard/add\" : \"FriendListHovercard/remove\");\n            g.inform(sa, ra);\n            new h().setURI(\"/ajax/add_friend/action.php\").setData(pa).send();\n        };\n        if (la) {\n            k.showDialog(ka, ma.id, na);\n        }\n         else na();\n    ;\n    };\n    function ba(ja) {\n        var ka = j.scry(ja, \"input\")[0];\n        return (ka && ka.value);\n    };\n    function ca(ja, ka, la) {\n        var ma = {\n            uid: ka.id\n        };\n        new h().setURI(x).setMethod(\"POST\").setData({\n            friend: ka.id\n        }).setHandler(g.inform.bind(g, \"FriendRequest/cancel\", ma)).setErrorHandler(g.inform.bind(g, \"FriendRequest/cancelFail\", ma)).setStatusElement(la).send();\n    };\n    function da(ja, ka) {\n        var la = n.getItems(ja);\n        for (var ma = 0; (ma < la.length); ma++) {\n            if ((ba(la[ma]) == ka)) {\n                return la[ma]\n            };\n        };\n        return null;\n    };\n    function ea(ja, ka) {\n        var la = n.getItems(ja);\n        la.forEach(function(ma) {\n            var na = ba(ma), oa = ka.lists.contains(na);\n            if ((n.isItemChecked(ma) !== oa)) {\n                n.toggleItem(ma);\n            };\n        });\n    };\n    function fa(ja) {\n        var ka = n.getItems(ja), la = (!i.hasClass(ja, \"followButtonFlyout\") && !i.hasClass(ja, \"likeButtonFlyout\")), ma = [], na = [], oa = 0, pa = 0;\n        ka.forEach(function(ua) {\n            if (i.hasClass(ua, \"neverHide\")) {\n                i.removeClass(ua, \"underShowMore\");\n                oa++;\n            }\n             else if (n.isItemChecked(ua)) {\n                ma.push(ua);\n            }\n             else if (((i.hasClass(ua, \"neverShow\") || i.hasClass(ua, \"FriendListCreateTrigger\")) || ((!la && i.hasClass(ua, \"friendOptionsOnly\"))))) {\n                i.addClass(ua, \"underShowMore\");\n                pa++;\n            }\n             else na.push(ua);\n            \n            \n        ;\n        });\n        var qa = (u - oa), ra = ma.concat(na), sa = pa;\n        ra.forEach(function(ua) {\n            if (i.hasClass(ua, \"ShowMoreItem\")) {\n                qa--;\n                return;\n            }\n        ;\n            if (qa) {\n                i.removeClass(ua, \"underShowMore\");\n                qa--;\n            }\n             else {\n                i.addClass(ua, \"underShowMore\");\n                sa = true;\n            }\n        ;\n        });\n        i.conditionClass(ja, \"hasMoreFriendListItems\", sa);\n        var ta = j.scry(ja, \".FriendListMenuShowMore\");\n        ta.forEach(function(ua) {\n            i.removeClass(ua, \"FriendListMenuShowMore\");\n        });\n    };\n    function ga(ja, ka) {\n        var la = j.scry(ja, \".FriendListUnfriend\")[0], ma = j.scry(ja, \".FriendListCancel\")[0], na = j.scry(ja, \".FriendListSuggestFriends\")[0];\n        if (ma) {\n            i.conditionShow(ma, (ka.status == m.OUTGOING_REQUEST));\n        };\n        if (la) {\n            i.conditionShow(la, (ka.status == m.ARE_FRIENDS));\n            j.find(la, \"a\").setAttribute(\"ajaxify\", q(w).addQueryData({\n                uid: ka.id\n            }).toString());\n        }\n    ;\n        if (na) {\n            j.find(na, \"a\").setAttribute(\"href\", q(y).addQueryData({\n                type: \"suggest_friends\",\n                newcomer: ka.id,\n                ref: \"profile_others_dropdown\"\n            }).toString());\n        };\n    };\n    function ha(ja, ka) {\n        var la = j.scry(ja, \"div.FriendListSubscriptionsMenu\");\n        if ((la.length !== 0)) {\n            l.init(ja, ka, 45);\n        };\n    };\n    g.subscribe(\"FriendRequest/change\", function(ja, ka) {\n        for (var la in v) {\n            var ma = t(la), na = v[la];\n            if (((ma && na) && (na.id == ka.uid))) {\n                ea(ma, na);\n                ga(ma, na);\n                fa(ma);\n            }\n        ;\n        };\n    });\n    n.subscribe(\"select\", function(ja, ka) {\n        if ((i.hasClass(ka.item, \"ShowMoreItem\") && i.hasClass(ka.menu, \"FriendListMenu\"))) {\n            i.addClass(ka.menu, \"FriendListMenuShowMore\");\n            p.poke(ka.item);\n        }\n    ;\n    });\n    var ia = {\n        init: function(ja, ka, la) {\n            ja = r(ja);\n            z = la;\n            if (!v[ja.id]) {\n                n.subscribe(\"select\", function(ma, na) {\n                    if (j.contains(ja, na.item)) {\n                        if (o.byClass(na.item, \"FriendListItem\")) {\n                            n.toggleItem(na.item);\n                            var oa = ba(na.item);\n                            aa(ja, oa, n.isItemChecked(na.item));\n                        }\n                         else if (o.byClass(na.item, \"FriendListCancel\")) {\n                            ca(ja, v[ja.id], na.item);\n                        }\n                         else if (o.byClass(na.item, \"FriendListUnfriend\")) {\n                            g.inform(\"FriendEditLists/unfriend\");\n                        }\n                        \n                    \n                    };\n                });\n            };\n            i.addClass(ja, \"async_saving\");\n            m.getFriend(ka, function(ma) {\n                ea(ja, ma);\n                ga(ja, ma);\n                v[ja.id] = ma;\n                fa(ja);\n                ha(ja, ka);\n                i.removeClass(ja, \"async_saving\");\n            }.bind(this));\n        }\n    };\n    e.exports = (a.FriendEditLists || ia);\n});\n__d(\"FriendListFlyoutController\", [\"event-extensions\",\"Arbiter\",\"AsyncRequest\",\"Button\",\"CSS\",\"DataStore\",\"Dialog\",\"DOM\",\"ContextualLayer\",\"FriendEditLists\",\"FriendStatus\",\"Layer\",\"Parent\",\"ScrollableArea\",\"UserAgent\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"Button\"), j = b(\"CSS\"), k = b(\"DataStore\"), l = b(\"Dialog\"), m = b(\"DOM\"), n = b(\"ContextualLayer\"), o = b(\"FriendEditLists\"), p = b(\"FriendStatus\"), q = b(\"Layer\"), r = b(\"Parent\"), s = b(\"ScrollableArea\"), t = b(\"UserAgent\"), u, v, w = null, x = null, y, z, aa, ba, ca, da, ea = 1500, fa = {\n        init: function(ta) {\n            fa.init = bagofholding;\n            u = ta;\n            u.subscribe(\"mouseenter\", ga);\n            u.subscribe(\"mouseleave\", oa);\n            u.subscribe(\"hide\", ha);\n            if (w) {\n                m.setContent(u.getContent(), [w,x,]);\n            };\n            var ua = function(va) {\n                var wa = r.byClass(va.getTarget(), \"enableFriendListFlyout\");\n                if (wa) {\n                    if ((y === wa)) {\n                        clearTimeout(ba);\n                    }\n                     else {\n                        (v && qa());\n                        na(wa);\n                    }\n                \n                };\n            };\n            Event.listen(document.documentElement, {\n                mouseover: ua,\n                click: ua\n            });\n            g.subscribe(\"FriendEditLists/unfriend\", qa);\n            g.subscribe(\"DynamicFriendListEducation/dialogOpen\", function() {\n                da = true;\n            });\n            g.subscribe(\"DynamicFriendListEducation/dialogClosed\", function() {\n                da = false;\n                oa();\n            });\n        },\n        initContent: function(ta) {\n            m.appendContent(document.body, ta);\n            (function() {\n                if (!w) {\n                    w = ta;\n                    (u && m.setContent(u.getContent(), [w,x,]));\n                    j.show(w);\n                    Event.listen(w, \"click\", ra);\n                    (v && ka(y));\n                }\n                 else {\n                    m.remove(ta);\n                    ta = null;\n                }\n            ;\n            }).defer();\n        },\n        initNux: function(ta) {\n            if (x) {\n                return\n            };\n            x = ta;\n            (u && m.setContent(u.getContent(), [w,x,]));\n        },\n        show: function(ta) {\n            la(ta);\n        },\n        hide: function(ta) {\n            ((ta === false) ? qa() : oa());\n        },\n        setActiveNode: function(ta) {\n            (v && qa());\n            y = ta;\n            z = Event.listen(ta, \"mouseleave\", function() {\n                y = null;\n                (z && z.remove());\n            });\n        },\n        setCloseListener: function(ta, ua) {\n            k.set(ta, \"flfcloselistener\", ua);\n            if ((y != ta)) {\n                k.set(ta, \"flfcloselistenertimeout\", sa.curry(ta).defer(ea));\n            };\n        },\n        setCloseListenerTimeout: function(ta) {\n            ea = ta;\n        }\n    };\n    function ga() {\n        clearTimeout(ba);\n    };\n    function ha() {\n        if (y) {\n            j.removeClass(y, \"selected\");\n            j.removeClass(y, \"uiButtonHover\");\n            if (k.get(y, \"flfcloselistener\")) {\n                var ta = y;\n                k.set(y, \"flfcloselistenertimeout\", sa.curry(ta).defer(ea));\n            }\n        ;\n        }\n    ;\n        v = false;\n        ja();\n        y = null;\n    };\n    function ia(ta) {\n        if ((m.isNodeOfType(ta, \"label\") && j.hasClass(ta, \"uiButton\"))) {\n            ta = i.getInputElement(ta);\n        };\n        return k.get(ta, \"profileid\");\n    };\n    function ja() {\n        (z && z.remove());\n        z = null;\n        (ca && q.unsubscribe(ca));\n        ca = null;\n        (ba && clearTimeout(ba));\n        ba = null;\n    };\n    function ka(ta) {\n        var ua = ia(ta), va = k.get(ta, \"flloc\");\n        o.init(w, ua, va);\n        j.conditionClass(w, \"followButtonFlyout\", j.hasClass(ta, \"profileFollowButton\"));\n        j.conditionClass(w, \"friendButtonFlyout\", ((j.hasClass(ta, \"FriendRequestFriends\") || j.hasClass(ta, \"FriendRequestIncoming\")) || j.hasClass(ta, \"FriendRequestOutgoing\")));\n        j.conditionClass(w, \"likeButtonFlyout\", j.hasClass(ta, \"profileLikeButton\"));\n        var wa = m.scry(w, \"div.uiScrollableArea\")[0];\n        (wa && s.poke(wa));\n    };\n    function la(ta) {\n        if ((!u || v)) {\n            return\n        };\n        u.setContext(ta);\n        u.setCausalElement(ta);\n        ta.setAttribute(\"aria-expanded\", \"true\");\n        j.addClass(ta, \"selected\");\n        j.addClass(ta, \"uiButtonHover\");\n        u.show();\n        y = ta;\n        v = true;\n        if (w) {\n            ka(ta);\n        }\n         else new h().setURI(\"/ajax/friends/lists/flyout_content.php\").setStatusElement(u.getContent()).send();\n    ;\n        ja();\n        z = Event.listen(ta, \"mouseleave\", oa);\n        ca = q.subscribe(\"show\", ma);\n        if (k.get(ta, \"flfcloselistener\")) {\n            clearTimeout(k.remove(ta, \"flfcloselistenertimeout\"));\n        };\n        var ua = ia(ta);\n        p.getFriend(ua, function(va) {\n            if (!x) {\n                return\n            };\n            if ((va.status == p.OUTGOING_REQUEST)) {\n                j.show(x);\n                h.bootstrap(\"/ajax/friends/lists/nux_flyout.php\", null, true);\n            }\n             else j.hide(x);\n        ;\n        });\n    };\n    function ma(ta, ua) {\n        if ((!((ua instanceof n)) || !m.contains(y, ua.getContext()))) {\n            oa();\n        };\n    };\n    function na(ta) {\n        y = ta;\n        aa = la.curry(ta).defer(350);\n        z = Event.listen(ta, \"mouseleave\", function() {\n            clearTimeout(aa);\n            y = null;\n            (z && z.remove());\n        });\n    };\n    function oa() {\n        ba = qa.defer(150);\n    };\n    function pa() {\n        var ta = l.getCurrent(), ua = (ta && ta.getBody());\n        return !!((ua && m.scry(ua, \".friendListDialogTourCarousel\")[0]));\n    };\n    function qa() {\n        if ((da || pa())) {\n            return\n        };\n        ((t.ie() < 8) && document.documentElement.focus());\n        if (u) {\n            u.hide();\n            var ta = u.getCausalElement();\n            (ta && ta.setAttribute(\"aria-expanded\", \"false\"));\n        }\n    ;\n    };\n    function ra(event) {\n        var ta = r.byTag(event.getTarget(), \"a\");\n        if ((ta && j.hasClass(ta, \"FriendListActionItem\"))) {\n            oa();\n        };\n    };\n    function sa(ta) {\n        var ua = k.remove(ta, \"flfcloselistener\");\n        (ua && ua());\n    };\n    e.exports = (a.FriendListFlyoutController || fa);\n});\n__d(\"legacy:FriendListFlyoutController\", [\"FriendListFlyoutController\",], function(a, b, c, d) {\n    a.FriendListFlyoutController = b(\"FriendListFlyoutController\");\n}, 3);\n__d(\"legacy:FriendStatus\", [\"FriendStatus\",], function(a, b, c, d) {\n    a.FriendStatus = b(\"FriendStatus\");\n}, 3);\nvar AddFriendButton = {\n    ERROR_ALREADY_ADDED: 1431005,\n    init: function(a, b, c, d, e, f, g, h, i, j, k) {\n        var l = null, m = DOM.scry(a, \".addButton\")[0], n = DOM.scry(a, \".outgoingButton\")[0], o = DOM.scry(a, \".incomingButton\")[0], p = DOM.scry(a, \".friendButton\")[0];\n        function q(v, w, x) {\n            var y = new URI(m.getAttribute(\"ajaxify\"));\n            link_data = collect_data_attribs(a, [\"ft\",\"gt\",]);\n            new AsyncRequest().setURI(f).setData({\n                to_friend: b,\n                action: v,\n                how_found: d,\n                ref_param: e,\n                link_data: link_data,\n                outgoing_id: n.id,\n                xids: y.getQueryData().xids,\n                logging_location: g,\n                no_flyout_on_click: h,\n                ego_log_data: i,\n                http_referer: k\n            }).setErrorHandler(w).setServerDialogCancelHandler(x).setRelativeTo(n).send();\n        };\n        function r(v, w) {\n            (m && CSS.hide(m));\n            (n && CSS.hide(n));\n            (o && CSS.hide(o));\n            (p && CSS.hide(p));\n            if (v) {\n                CSS.show(v);\n            };\n            if ((((\"Outgoing\" == w) && (l != w)) && j)) {\n                animation(v).from(\"backgroundColor\", \"#FFF8CC\").to(\"backgroundColor\", \"transparent\").from(\"borderColor\", \"#FFE222\").to(\"borderColor\", Style.get(v, \"borderLeftColor\")).duration(2000).go();\n            };\n            (l && CSS.removeClass(a, (\"fStatus\" + l)));\n            l = w;\n            CSS.addClass(a, (\"fStatus\" + w));\n        };\n        function s(v) {\n            if (CSS.hasClass(v, \"enableFriendListFlyout\")) {\n                FriendListFlyoutController.show(v);\n            }\n             else FriendListFlyoutController.hide();\n        ;\n        };\n        var t = Arbiter.subscribe(\"FriendRequest/change\", function(v, w) {\n            if ((w.uid != b)) {\n                return\n            };\n            switch (w.status) {\n              case FriendStatus.ARE_FRIENDS:\n                return r(p, \"Friends\");\n              case FriendStatus.INCOMING_REQUEST:\n                return r(o, \"Incoming\");\n              case FriendStatus.OUTGOING_REQUEST:\n                return r(n, \"Outgoing\");\n              case FriendStatus.CAN_REQUEST:\n                return r(m, \"Requestable\");\n            };\n        }), u;\n        if (c) {\n            u = Arbiter.subscribe(\"FriendRequest/confirm\", function(v, w) {\n                ((w.uid == b) && goURI(c));\n            });\n        };\n        (m && Event.listen(m, \"click\", function() {\n            Arbiter.inform(\"FriendRequest/sending\", {\n                uid: b\n            });\n            if (h) {\n                FriendListFlyoutController.setActiveNode(n);\n            }\n             else s(n);\n        ;\n            q(\"add_friend\", function(v) {\n                var w = ((v.error == AddFriendButton.ERROR_ALREADY_ADDED) ? \"FriendRequest/sent\" : \"FriendRequest/sendFail\");\n                Arbiter.inform(w, {\n                    uid: b\n                });\n                FriendListFlyoutController.hide();\n                AsyncResponse.defaultErrorHandler(v);\n            }, function(v) {\n                Arbiter.inform(\"FriendRequest/sendFail\", {\n                    uid: b\n                });\n                FriendListFlyoutController.hide();\n            });\n        }));\n        PageTransitions.registerHandler(function() {\n            t.unsubscribe();\n            (u && u.unsubscribe());\n        });\n    }\n};\n__d(\"FriendButtonIcon\", [\"Arbiter\",\"FriendStatus\",\"Button\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"FriendStatus\"), i = b(\"Button\");\n    e.exports = {\n        register: function(j, k, l) {\n            g.subscribe(\"FriendListMembershipChange\", function(m, n) {\n                if ((n.uid == l)) {\n                    var o = n.lists.contains(h.CLOSE_FRIENDS), p = n.lists.contains(h.ACQUAINTANCES);\n                    if ((o && !p)) {\n                        i.setIcon(j, k.close);\n                    }\n                     else if ((p && !o)) {\n                        i.setIcon(j, k.acquaintance);\n                    }\n                     else i.setIcon(j, k.friend);\n                    \n                ;\n                }\n            ;\n            });\n        }\n    };\n});\n__d(\"RespondToRequestButton\", [\"event-extensions\",\"Arbiter\",\"CSS\",\"Menu\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"CSS\"), i = b(\"Menu\"), j = {\n        init: function(k, l, m, n) {\n            Event.listen(l, \"click\", function() {\n                h.addClass(l, \"uiButtonConfirm\");\n                h.addClass(l, \"selected\");\n                m.show();\n            });\n            m.subscribe(\"hide\", function() {\n                h.removeClass(l, \"uiButtonConfirm\");\n                h.removeClass(l, \"selected\");\n            });\n            i.subscribe(\"select\", function(o, p) {\n                if (!h.hasClass(p.menu, \"requestResponseMenu\")) {\n                    return\n                };\n                if ((p.item.firstChild.getAttribute(\"data-profileid\") != k)) {\n                    return\n                };\n                if (h.hasClass(p.item, \"reject\")) {\n                    h.hide(l);\n                    h.show(n);\n                }\n            ;\n                m.hide();\n                g.inform(\"FriendRequest/delete\");\n            });\n        }\n    };\n    e.exports = j;\n});\n__d(\"legacy:RespondToRequestButton\", [\"RespondToRequestButton\",], function(a, b, c, d) {\n    a.RespondToRequestButton = b(\"RespondToRequestButton\");\n}, 3);\n__d(\"MessageButton\", [\"event-extensions\",\"Chat\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Chat\"), h = b(\"copyProperties\");\n    function i() {\n    \n    };\n    h(i, {\n        initChat: function(j, k, l) {\n            Event.listen(j, \"click\", function() {\n                g.openTab(k, l, \"friend\");\n                return false;\n            });\n        }\n    });\n    e.exports = i;\n});\n__d(\"StickyController\", [\"event-extensions\",\"CSS\",\"Style\",\"Vector\",\"copyProperties\",\"throttle\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"CSS\"), h = b(\"Style\"), i = b(\"Vector\"), j = b(\"copyProperties\"), k = b(\"throttle\");\n    function l(m, n, o, p) {\n        this._element = m;\n        this._marginTop = n;\n        this._onchange = o;\n        this._proxy = (p || m.parentNode);\n    };\n    j(l.prototype, {\n        handleScroll: function() {\n            var m = (i.getElementPosition(this._proxy, \"viewport\").y <= this._marginTop);\n            if ((this.isFixed() !== m)) {\n                h.set(this._element, \"top\", (m ? (this._marginTop + \"px\") : \"\"));\n                g.conditionClass(this._element, \"fixed_elem\", m);\n                (this._onchange && this._onchange(m));\n            }\n        ;\n        },\n        start: function() {\n            if (this._event) {\n                return\n            };\n            this._event = Event.listen(window, \"scroll\", k(this.handleScroll, 100, this));\n            this.handleScroll.bind(this).defer();\n        },\n        stop: function() {\n            (this._event && this._event.remove());\n            this._event = null;\n        },\n        isFixed: function() {\n            return g.hasClass(this._element, \"fixed_elem\");\n        }\n    });\n    e.exports = l;\n});\n__d(\"requestAnimationFrame\", [], function(a, b, c, d, e, f) {\n    var g = (((((window.requestAnimationFrame || window.webkitRequestAnimationFrame) || window.mozRequestAnimationFrame) || window.oRequestAnimationFrame) || window.msRequestAnimationFrame) || function(h) {\n        window.setTimeout(h, 16);\n    });\n    e.exports = g;\n});\n__d(\"HubsTypeaheadView\", [\"Class\",\"ContextualTypeaheadView\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Class\"), h = b(\"ContextualTypeaheadView\"), i = b(\"copyProperties\");\n    function j(k, l) {\n        this.parent.construct(this, k, l);\n    };\n    g.extend(j, h);\n    i(j.prototype, {\n        render: function(k, l, m) {\n            if ((this.alwaysRender && (k !== \"\"))) {\n                var n = k.toLowerCase().trim(), o = false;\n                for (var p = 0; (p < l.length); p++) {\n                    if ((n == l[p].text.toLowerCase())) {\n                        o = true;\n                        break;\n                    }\n                ;\n                };\n                if (!o) {\n                    l.push({\n                        text: k,\n                        type: \"calltoaction\"\n                    });\n                };\n            }\n        ;\n            return this.parent.render(k, l, m);\n        }\n    });\n    e.exports = j;\n});\n__d(\"BrokenProfilePicLogger\", [\"Run\",\"DOM\",\"JSLogger\",], function(a, b, c, d, e, f) {\n    var g = b(\"Run\"), h = b(\"DOM\"), i = b(\"JSLogger\"), j = i.create(\"entities_profile_pics\"), k = {\n        checkAndLog: function(l) {\n            g.onAfterLoad(function() {\n                var m = h.find(l, \"img\");\n                if ((!m.complete || (((typeof m.naturalWidth != \"undefined\") && (m.naturalWidth === 0))))) {\n                    j.log(\"broken_link\", {\n                        src: m.getAttribute(\"src\")\n                    });\n                };\n            });\n        }\n    };\n    e.exports = k;\n});\n__d(\"TimelineConstants\", [], function(a, b, c, d, e, f) {\n    var g = {\n        DS_HEIGHT: \"timeline-unit-height\",\n        DS_LOADED: \"timeline-capsule-loaded\",\n        DS_SIDEORG: \"timeline-unit-sideorg\",\n        DS_TAILBALANCE: \"timeline-capsule-tailbalance\",\n        DS_COLUMN_HEIGHT_DIFFERENTIAL: \"timeline-column-diff-height\",\n        FIXED_SIDE_LEFT: \"left\",\n        FIXED_SIDE_RIGHT: \"right\",\n        FIXED_SIDE_BOTH: \"both\",\n        SCROLL_TO_OFFSET: 30,\n        SUBSECTION_SCROLL_TO_OFFSET: 90\n    };\n    e.exports = g;\n});\n__d(\"TimelineURI\", [\"URI\",], function(a, b, c, d, e, f) {\n    var g = b(\"URI\"), h = {\n        TIMELINE_KEY: \"timeline\",\n        WALL_KEY: \"wall\",\n        parseURI: function(i) {\n            i = g(i);\n            var j = i.getQueryData(), k = i.getPath(), l = k.split(\"/\").slice(1);\n            if (((l[0] == \"people\") || (l[0] == \"pages\"))) {\n                l = l.slice(2);\n            };\n            var m = ((j.sk || l[1]) || h.TIMELINE_KEY);\n            if ((m == h.WALL_KEY)) {\n                m = h.TIMELINE_KEY;\n            };\n            var n = null, o = null;\n            if ((m == h.TIMELINE_KEY)) {\n                o = (parseInt(l[2], 10) || null);\n                n = (parseInt(l[3], 10) || null);\n            }\n        ;\n            return {\n                path: k,\n                id: (j.id || l[0]),\n                key: m,\n                viewas: (j.viewas ? j.viewas : 0),\n                filter: (j.filter ? j.filter : null),\n                year: o,\n                month: n,\n                friendship: !!j.and\n            };\n        }\n    };\n    e.exports = h;\n});\n__d(\"TimelineController\", [\"event-extensions\",\"Arbiter\",\"CSS\",\"DataStore\",\"DOM\",\"Run\",\"ScrollingPager\",\"Style\",\"TimelineConstants\",\"TimelineURI\",\"Vector\",\"ViewportBounds\",\"$\",\"ge\",\"throttle\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"CSS\"), i = b(\"DataStore\"), j = b(\"DOM\"), k = b(\"Run\"), l = b(\"ScrollingPager\"), m = b(\"Style\"), n = b(\"TimelineConstants\"), o = b(\"TimelineURI\"), p = b(\"Vector\"), q = b(\"ViewportBounds\"), r = b(\"$\"), s = b(\"ge\"), t = b(\"throttle\"), u = 484, v = 48, w = 740, x = 1285, y = null, z = false, aa, ba, ca, da = {\n    }, ea = {\n    }, fa = [], ga = null, ha = 0, ia = false, ja = false, ka = false, la = {\n        allactivity: true,\n        approve: true,\n        games: true,\n        map: true,\n        music: true,\n        video: true\n    };\n    la[o.TIMELINE_KEY] = true;\n    var ma = [], na = false;\n    function oa() {\n        (ga && ga.remove());\n        ga = null;\n    };\n    function pa(ya, za, ab) {\n        ab = (ab || []);\n        if (da[ya]) {\n            return da[ya][za].apply(da[ya], ab)\n        };\n        ea[ya] = (ea[ya] || {\n        });\n        ea[ya][za] = ab;\n        return false;\n    };\n    function qa() {\n        if (!(((ia || ka) || ja))) {\n            oa();\n            return;\n        }\n    ;\n        var ya = p.getScrollPosition();\n        ia = (ia && sa(r(\"rightCol\"), ya, \"paddingTop\", true));\n        ja = (ja && sa(r(\"pagelet_above_header_timeline\"), ya, \"top\"));\n        ka = (ka && sa(r(\"blueBar\"), ya, \"paddingTop\"));\n    };\n    function ra() {\n        var ya = p.getScrollPosition(), za = ((ha === 0) || (ya.y >= ha));\n        pa(xa.STICKY_HEADER, \"toggle\", [za,]);\n        pa(xa.CONTENT, \"checkCurrentSectionChange\");\n    };\n    function sa(ya, za, ab, bb) {\n        if (!ya) {\n            oa();\n            return;\n        }\n    ;\n        if ((za.y <= 0)) {\n            ta(ya, ab);\n            return false;\n        }\n         else {\n            var cb = (bb && xa.getCurrentScrubber());\n            if ((((cb && h.hasClass(cb.getRoot(), \"fixed_elem\"))) || m.isFixed(s(\"pagelet_timeline_friends\")))) {\n                ta(ya, ab);\n                return false;\n            }\n             else {\n                var db = (parseInt(ya.style[ab], 10) || 0);\n                if ((za.y < db)) {\n                    h.addClass(ya, \"timeline_fixed\");\n                    ya.style[ab] = (za.y + \"px\");\n                }\n                 else h.removeClass(ya, \"timeline_fixed\");\n            ;\n            }\n        ;\n        }\n    ;\n        return true;\n    };\n    function ta(ya, za) {\n        ya.style[za] = \"0px\";\n        h.removeClass(ya, \"timeline_fixed\");\n    };\n    function ua() {\n        pa(xa.ADS, \"adjustAdsType\", [xa.shouldShowWideAds(),]);\n        pa(xa.ADS, \"adjustAdsToFit\");\n        pa(xa.CONTENT, \"adjustContentPadding\");\n        pa(xa.STICKY_HEADER_NAV, \"adjustMenuHeights\");\n    };\n    function va(ya, za) {\n        if ((ya == \"sidebar/initialized\")) {\n            na = true;\n        };\n        pa(xa.ADS, \"adjustAdsType\", [xa.shouldShowWideAds(),]);\n    };\n    function wa() {\n        while (fa.length) {\n            fa.pop().remove();;\n        };\n        for (var ya in da) {\n            (da[ya].reset && da[ya].reset());;\n        };\n        oa();\n        ca.unsubscribe();\n        ca = null;\n        y = null;\n        aa = null;\n        da = {\n        };\n        ea = {\n        };\n        ha = 0;\n        ja = false;\n        if (ia) {\n            r(\"rightCol\").style.paddingTop = \"\";\n            h.removeClass(r(\"rightCol\"), \"timeline_fixed\");\n        }\n    ;\n        ia = false;\n        if (ka) {\n            r(\"blueBar\").style.paddingTop = \"\";\n            h.removeClass(r(\"blueBar\"), \"timeline_fixed\");\n        }\n    ;\n        ka = false;\n        ma = [];\n        na = false;\n        z = false;\n        i.purge(n.DS_HEIGHT);\n        i.purge(n.DS_LOADED);\n        i.purge(n.DS_SIDEORG);\n        i.purge(n.DS_TAILBALANCE);\n        i.purge(n.DS_COLUMN_HEIGHT_DIFFERENTIAL);\n    };\n    var xa = {\n        NAV: \"nav\",\n        STICKY_HEADER: \"sticky_header\",\n        STICKY_HEADER_NAV: \"sticky_header_nav\",\n        SCRUBBER: \"scrubber\",\n        CONTENT: \"content\",\n        ADS: \"ads\",\n        COVER: \"cover\",\n        LOGGING: \"logging\",\n        SECTION_LOADING: \"TimelineController/sectionLoading\",\n        SECTION_LOADED: \"TimelineController/sectionLoaded\",\n        SECTION_FULLY_LOADED: \"TimelineController/sectionFullyLoaded\",\n        SECTION_REGISTERED: \"TimelineController/sectionRegistered\",\n        SCRUBBER_DEFAULT_OFFSET: 38,\n        init: function(ya, za, ab) {\n            if (z) {\n                return\n            };\n            if ((za == o.WALL_KEY)) {\n                za = o.TIMELINE_KEY;\n            };\n            z = true;\n            aa = ya;\n            ba = ab.has_fixed_ads;\n            pa(xa.CONTENT, \"adjustContentPadding\");\n            fa.push(Event.listen(window, \"scroll\", t(ra, 100)), Event.listen(window, \"resize\", t(ua, 100)));\n            ca = g.subscribe([\"sidebar/initialized\",\"sidebar/show\",\"sidebar/hide\",], va);\n            k.onLeave(wa);\n            xa.registerCurrentKey(za);\n        },\n        setAdsTracking: function(ya) {\n            pa(xa.ADS, \"start\", [ya,]);\n        },\n        coverHasExpanded: function(ya) {\n            r(\"rightCol\").style.paddingTop = (ya + \"px\");\n            ia = true;\n            var za = r(\"pagelet_above_header_timeline\");\n            if (za.firstChild) {\n                r(\"above_header_timeline_placeholder\").style.height = (za.offsetHeight + \"px\");\n                za.style.top = (ya + \"px\");\n                ja = true;\n            }\n        ;\n            var ab = document.documentElement;\n            ka = ((ab.clientHeight < 400) || (ab.clientWidth < ab.scrollWidth));\n            if (ka) {\n                r(\"blueBar\").style.paddingTop = (ya + \"px\");\n            };\n            ga = Event.listen(window, \"scroll\", qa);\n            g.inform(\"reflow\");\n        },\n        pageHasScrubber: function(ya) {\n            return ((!ya || ya.match(/^(og_)?app_/)) || ((ya in la)));\n        },\n        fixedAds: function() {\n            return ba;\n        },\n        registerCurrentKey: function(ya) {\n            y = ya;\n            var za = (p.getViewportDimensions().y < w);\n            pa(xa.ADS, \"setShortMode\", [za,ya,]);\n            pa(xa.ADS, \"updateCurrentKey\", [ya,]);\n            ha = ((ya == o.TIMELINE_KEY) ? (u - v) : 0);\n        },\n        getCurrentKey: function() {\n            return y;\n        },\n        getSectionKeys: function() {\n            return ma;\n        },\n        getCurrentScrubber: function() {\n            return da[xa.SCRUBBER];\n        },\n        getCurrentStickyHeaderNav: function() {\n            return da[xa.STICKY_HEADER_NAV];\n        },\n        getSection: function(ya) {\n            return pa(xa.CONTENT, \"getSection\", [ya,]);\n        },\n        scrubberHasLoaded: function(ya) {\n            pa(xa.STICKY_HEADER_NAV, \"addTimePeriods\", [ma,]);\n            pa(xa.ADS, \"registerScrubber\", [ya,]);\n        },\n        registerSectionKey: function(ya, za) {\n            if (da[xa.STICKY_HEADER_NAV]) {\n                pa(xa.STICKY_HEADER_NAV, \"addTimePeriod\", [ya,]);\n            }\n             else ma[za] = ya;\n        ;\n        },\n        scrubberHasChangedState: function() {\n            pa(xa.ADS, \"adjustAdsToFit\");\n        },\n        scrubberWasClicked: function(ya) {\n            pa(xa.LOGGING, \"logScrubberClick\", [ya,]);\n        },\n        sectionHasChanged: function(ya, za) {\n            pa(xa.STICKY_HEADER_NAV, \"updateSection\", [ya,za,]);\n            pa(xa.SCRUBBER, \"updateSection\", [ya,za,]);\n            pa(xa.ADS, \"loadAdsIfEnoughTimePassed\");\n            pa(xa.LOGGING, \"logSectionChange\", [ya,za,]);\n        },\n        navigateToSection: function(ya) {\n            pa(xa.CONTENT, \"navigateToSection\", [ya,]);\n        },\n        shouldShowWideAds: function() {\n            if (!na) {\n                return false\n            };\n            var ya = (x + q.getRight());\n            return (p.getViewportDimensions().x >= ya);\n        },\n        sidebarInitialized: function() {\n            return na;\n        },\n        adjustStickyHeaderWidth: function() {\n            pa(xa.STICKY_HEADER, \"adjustWidth\");\n        },\n        register: function(ya, za) {\n            da[ya] = za;\n            if (ea[ya]) {\n                for (var ab in ea[ya]) {\n                    pa(ya, ab, ea[ya][ab]);;\n                };\n                delete ea[ya];\n            }\n        ;\n        },\n        adjustScrollingPagerBuffer: function(ya, za) {\n            var ab = i.get(n.DS_COLUMN_HEIGHT_DIFFERENTIAL, za);\n            if (!ab) {\n                return\n            };\n            var bb = l.getInstance(ya);\n            (bb && bb.setBuffer((bb.getBuffer() + Math.abs(ab))));\n        },\n        runOnceWhenSectionFullyLoaded: function(ya, za, ab) {\n            if (pa(xa.CONTENT, \"getSection\", [za,])) {\n                var bb = false;\n                j.scry(da[xa.CONTENT].getSection(za).node, \"ol.fbTimelineCapsule\").forEach(function(db) {\n                    if ((!bb && (parseInt(i.get(n.DS_LOADED, db.id), 10) >= parseInt(ab, 10)))) {\n                        ya();\n                        bb = true;\n                    }\n                ;\n                });\n                if (bb) {\n                    return\n                };\n            }\n        ;\n            var cb = g.subscribe(xa.SECTION_FULLY_LOADED, function(db, eb) {\n                if (((eb.scrubberKey === za) && (eb.pageIndex === ab))) {\n                    ya();\n                    cb.unsubscribe();\n                }\n            ;\n            });\n        }\n    };\n    e.exports = xa;\n});\n__d(\"TimelineDrag\", [\"event-extensions\",\"ArbiterMixin\",\"Class\",\"Locale\",\"Style\",\"Vector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"Class\"), i = b(\"Locale\"), j = b(\"Style\"), k = b(\"Vector\"), l = b(\"copyProperties\");\n    function m(n, o, p) {\n        p = (p || {\n        });\n        this._listenOn = p.listenOn;\n        this._offsetInput = o;\n        this._defaultOffset = p.default_offset;\n        this._killClicks = p.killClicks;\n        this._vertical = true;\n        this._RTLXSwitch = false;\n        this.setPicture(n, p);\n    };\n    l(m.prototype, g, {\n        setPicture: function(n, o) {\n            if (!n) {\n                return false\n            };\n            o = (o || {\n            });\n            this._picture = n;\n            this._defaultOffset = o.default_offset;\n            if ((o.vertical !== undefined)) {\n                this._vertical = o.vertical;\n            };\n            if (this._vertical) {\n                if (o.height) {\n                    this._containerHeight = o.height;\n                };\n                this._offsetType = \"top\";\n                this._eventCoord = \"y\";\n            }\n             else {\n                if (o.width) {\n                    this._containerWidth = o.width;\n                };\n                this._RTLXSwitch = i.isRTL();\n                this._offsetType = \"left\";\n                this._eventCoord = \"x\";\n            }\n        ;\n            if (this._picture.complete) {\n                this._initialLoad();\n            }\n             else this._loadListener = Event.listen(this._picture, \"load\", function() {\n                this._loadListener.remove();\n                this._initialLoad();\n            }.bind(this));\n        ;\n        },\n        destroy: function() {\n            this._stopDrag();\n            this._saveOffset();\n            (this._mousedown && this._mousedown.remove());\n            (this._onclick && this._onclick.remove());\n            (this._loadListener && this._loadListener.remove());\n        },\n        _initialLoad: function() {\n            var n = (this._listenOn ? this._listenOn : this._picture);\n            (this._mousedown && this._mousedown.remove());\n            this._mousedown = Event.listen(n, \"mousedown\", this._onMouseDown.bind(this));\n            if (this._vertical) {\n                this._maxOffset = (this._containerHeight - this._picture.offsetHeight);\n            }\n             else this._maxOffset = (this._containerWidth - this._picture.width);\n        ;\n            if ((this._defaultOffset !== undefined)) {\n                this._setOffset(this._defaultOffset);\n            };\n            (this._onclick && this._onclick.remove());\n            if (this._killClicks) {\n                this._onclick = Event.listen(n, \"click\", this._onClick.bind(this));\n            };\n            this._saveOffset();\n        },\n        _onClick: function(event) {\n            event.kill();\n        },\n        _onMouseDown: function(event) {\n            var n = (parseInt(j.get(this._picture, this._offsetType), 10) || 0);\n            this._pictureStartDragOffset = (n - k.getEventPosition(event)[this._eventCoord]);\n            this._startDrag();\n            event.kill();\n        },\n        _startDrag: function() {\n            if (!this._dragStarted) {\n                this.inform(\"startdrag\", this);\n                this._dragTokens = [Event.listen(document.documentElement, \"mouseup\", this._onMouseUp.bind(this)),Event.listen(document.documentElement, \"mousemove\", this._onMouseMove.bind(this)),];\n                this._dragStarted = true;\n            }\n        ;\n        },\n        _saveOffset: function() {\n            var n = parseInt(j.get(this._picture, this._offsetType), 10);\n            if (this._RTLXSwitch) {\n                this._offsetInput.value = ((n + this._containerWidth) - this._picture.offsetWidth);\n            }\n             else this._offsetInput.value = n;\n        ;\n        },\n        _stopDrag: function() {\n            if (this._dragStarted) {\n                this.inform(\"stopdrag\", this);\n                this._dragStarted = false;\n                this._dragTokens.forEach(function(n) {\n                    n.remove();\n                });\n                this._saveOffset();\n            }\n        ;\n        },\n        _onMouseUp: function(event) {\n            this._stopDrag();\n            event.kill();\n        },\n        _setOffset: function(n) {\n            if (this._RTLXSwitch) {\n                n = Math.max(0, Math.min(n, -this._maxOffset));\n            }\n             else n = Math.min(0, Math.max(n, this._maxOffset));\n        ;\n            j.set(this._picture, this._offsetType, (n + \"px\"));\n        },\n        _onMouseMove: function(event) {\n            this._setOffset((this._pictureStartDragOffset + k.getEventPosition(event)[this._eventCoord]));\n            event.kill();\n        }\n    });\n    e.exports = m;\n});\n__d(\"TimelineCover\", [\"Button\",\"CSS\",\"DOM\",\"HTML\",\"Parent\",\"DOMScroll\",\"Vector\",\"TimelineController\",\"TimelineDrag\",\"Style\",\"$\",\"copyProperties\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"Button\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"HTML\"), k = b(\"Parent\"), l = b(\"DOMScroll\"), m = b(\"Vector\"), n = b(\"TimelineController\"), o = b(\"TimelineDrag\"), p = b(\"Style\"), q = b(\"$\"), r = b(\"copyProperties\"), s = b(\"ge\");\n    function t(u, v, w) {\n        this.root = q(\"fbProfileCover\");\n        this._parentSection = k.byClass(this.root, \"fbTimelineSection\");\n        this._coverHeight = v;\n        this.cover = i.find(this.root, \".cover\");\n        t.instance = this;\n        this.previewing = w;\n        this.editing = false;\n        if (w) {\n            this.updateCoverImage(w);\n        }\n         else if (this.cover.getAttribute(\"data-collapse\")) {\n            this._expandCover(parseInt(this.cover.getAttribute(\"data-collapse\"), 10));\n        }\n    ;\n        if (this.previewing) {\n            this.editMode();\n        };\n        n.register(n.COVER, this);\n    };\n    t.instance = null;\n    t.getInstance = function() {\n        return t.instance;\n    };\n    r(t.prototype, {\n        showLoadingIndicator: function() {\n            var u = s(\"fbCoverImageContainer\");\n            if (u) {\n                h.addClass(u, \"opaquedLoading\");\n            };\n        },\n        hideLoadingIndicator: function() {\n            var u = s(\"fbCoverImageContainer\");\n            if (u) {\n                h.removeClass(u, \"opaquedLoading\");\n            };\n        },\n        editMode: function() {\n            g.setEnabled(i.find(this.root, \"label.cancelButton\"), true);\n            g.setEnabled(i.find(this.root, \"label.saveButton\"), true);\n            this.hideLoadingIndicator();\n            this._coverImage = i.scry(this.root, \".coverImage\")[0];\n            var u = i.scry(this._coverImage, \".coverWrap\")[0];\n            if (u) {\n                this._originalOffset = p.get(i.find(u, \".coverPhotoImg\"), \"top\");\n            };\n            h.addClass(this._parentSection, \"fbEditCover\");\n            l.scrollTo(this.root);\n            if (this.previewing) {\n                i.remove(this._coverImage);\n                h.show(this._coverImage);\n            }\n        ;\n            var v = i.scry(this._coverImage, \".coverPhotoImg\")[0];\n            if (v) {\n                this._createDragger();\n            };\n            this.editing = true;\n        },\n        _expandCover: function(u) {\n            u -= 1;\n            this.cover.style.marginTop = \"0px\";\n            if ((u != m.getScrollPosition().y)) {\n                window.scrollBy(0, u);\n                n.coverHasExpanded(u);\n            }\n        ;\n        },\n        _exitEditMode: function() {\n            if (this._timelineDrag) {\n                this._timelineDrag.destroy();\n                this._timelineDrag = null;\n            }\n        ;\n            i.find(this.root, \"input.hiddenPhotoID\").value = null;\n            i.find(this.root, \"input.hiddenVideoID\").value = null;\n            g.setEnabled(i.find(this.root, \"label.cancelButton\"), false);\n            g.setEnabled(i.find(this.root, \"label.saveButton\"), false);\n            h.removeClass(this._parentSection, \"fbEditCover\");\n            this.hideLoadingIndicator();\n        },\n        _createDragger: function() {\n            this._timelineDrag = new o(i.find(this.root, \".coverImage .coverPhotoImg\"), i.find(this.root, \"input.photoOffsetInput\"), {\n                height: this._coverHeight,\n                listenOn: this.cover,\n                vertical: true,\n                killClicks: true\n            });\n        },\n        updateCoverImage: function(u, v, w) {\n            this.videoID = w;\n            if (v) {\n                this.editMode();\n            };\n            i.find(this.root, \"input.hiddenPhotoID\").value = u;\n            i.find(this.root, \"input.hiddenVideoID\").value = (w || null);\n            g.setEnabled(i.find(this.root, \"label.saveButton\"), true);\n            if (v) {\n                i.replace(i.find(this.root, \".coverImage\"), j(v));\n            };\n            if (this._timelineDrag) {\n                this._timelineDrag.setPicture(i.find(i.find(this.root, \".coverImage\"), \".coverPhotoImg\"));\n            }\n             else this._createDragger();\n        ;\n        },\n        cancelUpdate: function() {\n            i.remove(i.scry(this.root, \".coverImage\")[0]);\n            i.prependContent(this.cover, this._coverImage);\n            if ((this._originalOffset !== undefined)) {\n                p.set(i.find(this._coverImage, \".coverPhotoImg\"), \"top\", this._originalOffset);\n            };\n            this._exitEditMode();\n        },\n        saveComplete: function() {\n            this._coverImage = i.scry(this.root, \".coverImage\")[0];\n            this._exitEditMode();\n        },\n        isInEditMode: function() {\n            return this.editing;\n        }\n    });\n    e.exports = t;\n});\nfunction TimelineCoverDisclaimer(a, b, c) {\n    if ((TimelineCoverDisclaimer.displayed === undefined)) {\n        TimelineCoverDisclaimer.displayed = true;\n    }\n     else return\n;\n    new Dialog().setModal(true).setTitle(a).setBody(b).setButtonsMessage(c).setButtons(Dialog.OK).show();\n};\nrequireLazy([\"Selector\",], function(a) {\n    add_properties(\"__behaviors\", {\n    });\n    if (__behaviors.TimelineCurationControl) {\n        return\n    };\n    __behaviors.TimelineCurationControl = true;\n    a.subscribe(\"open\", function(b, c) {\n        var d = c.selector, e = (c.clone || d), f = Parent.byClass(e, \"fbTimelineCurationControl\");\n        if (f) {\n            CSS.addClass(f, \"editControlsMenuOpen\");\n            var g = a.subscribe(\"close\", function(h, i) {\n                if ((i.selector == d)) {\n                    a.unsubscribe(g);\n                    CSS.removeClass.curry(f, \"editControlsMenuOpen\").defer();\n                }\n            ;\n            });\n        }\n    ;\n    });\n});\n__d(\"TimelineFriendsNavHovercard\", [\"event-extensions\",\"Hovercard\",\"UserAgent\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Hovercard\"), h = b(\"UserAgent\");\n    function i(event) {\n        var k = event.getTarget();\n        (g.processNode(k) && event.stop());\n    };\n    var j = {\n        init: function(k) {\n            if ((h.ie() < 7)) {\n                return\n            };\n            Event.listen(k, \"mouseover\", i);\n        }\n    };\n    e.exports = j;\n});\n__d(\"TimelinePerfConfig\", [], function(a, b, c, d, e, f) {\n    var g = null, h = function() {\n        if ((g === null)) {\n            return false\n        };\n        return true;\n    }, i = {\n        init: function(j) {\n            g = j;\n        },\n        getDisablePageletThrottle: function() {\n            return (h() && ((g.disablePageletThrottle || g.disableAllThrottle)));\n        },\n        getDisableAllThrottle: function() {\n            return (h() && g.disableAllThrottle);\n        },\n        getDisableSpineHeight: function() {\n            return (h() && g.disableSpineHeight);\n        }\n    };\n    e.exports = i;\n});\n__d(\"legacy:TimelinePerfConfig\", [\"TimelinePerfConfig\",], function(a, b, c, d) {\n    a.TimelinePerfConfig = b(\"TimelinePerfConfig\");\n}, 3);\n__d(\"TimelineProfilePic\", [\"Arbiter\",\"CSS\",\"Dialog\",\"DOM\",\"HTML\",\"Run\",\"$\",\"ge\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"CSS\"), i = b(\"Dialog\"), j = b(\"DOM\"), k = b(\"HTML\"), l = b(\"Run\"), m = b(\"$\"), n = b(\"ge\"), o = b(\"copyProperties\");\n    function p(q, r, s, t) {\n        p.destroyInstance();\n        p._instance = this;\n        this.leavingMessage = r;\n        this.elemID = (s || \"fbProfileCover\");\n        this.elemClass = (t || \".profilePicThumb\");\n        this._arbiterTokens = [g.subscribe(q.LOADING, this.startLoading.bind(this)),g.subscribe(q.SUCCESS, this.onUploadSuccess.bind(this)),];\n        l.onBeforeUnload(this.onBeforeUnload.bind(this));\n        l.onLeave(this.destroy.bind(this));\n    };\n    o(p, {\n        _instance: null,\n        destroyInstance: function() {\n            (this._instance && this._instance.destroy());\n        }\n    });\n    o(p.prototype, {\n        _setLoadingIndicator: function(q) {\n            this._loading = q;\n            h.conditionClass(j.find(m(this.elemID), this.elemClass), \"profilePicLoading\", q);\n        },\n        destroy: function() {\n            this._arbiterTokens.forEach(function(q) {\n                q.unsubscribe();\n            });\n            this._arbiterTokens = [];\n            p._instance = null;\n        },\n        startLoading: function(q, r) {\n            this._setLoadingIndicator(r.isLoading);\n            if (n(\"fbProfilePicSelector\")) {\n                h.removeClass(m(\"fbProfilePicSelector\"), \"fbTimelineNullProfilePicSelector\");\n            };\n        },\n        onUploadSuccess: function(q, r) {\n            this._setLoadingIndicator(false);\n            var s = i.getCurrent();\n            if (s) {\n                s.hide();\n            };\n            j.replace(j.find(m(this.elemID), this.elemClass), k(r.newPic));\n            if (((typeof (r.profileId) !== undefined) && (typeof (r.headerPicURL) !== undefined))) {\n                var t = n((\"profile_pic_header_\" + r.profileId));\n                if (t) {\n                    t.src = r.headerPicURL;\n                };\n            }\n        ;\n        },\n        onBeforeUnload: function() {\n            if (((p._instance === this) && this._loading)) {\n                return this.leavingMessage\n            };\n        }\n    });\n    e.exports = p;\n});\n__d(\"TimelineSmartInsert\", [\"CSS\",\"DOM\",\"Run\",\"UserAgent\",\"Vector\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"Run\"), j = b(\"UserAgent\"), k = b(\"Vector\"), l = false, m = false;\n    function n() {\n        if (m) {\n            return\n        };\n        i.onLeave(o);\n        m = true;\n    };\n    function o() {\n        l = false;\n        m = false;\n    };\n    var p = {\n        BUFFER: 100,\n        run: function(q, r) {\n            n();\n            if ((!l || (j.ie() <= 8))) {\n                r();\n                return;\n            }\n        ;\n            var s = q.offsetHeight;\n            r();\n            var t = q.offsetHeight;\n            if ((((t - s) !== 0) && ((k.getElementPosition(q).y + s) < (k.getScrollPosition().y + p.BUFFER)))) {\n                window.scrollBy(0, (t - s));\n            };\n        },\n        enable: function() {\n            l = true;\n        }\n    };\n    e.exports = p;\n});\n__d(\"TimelineThrottler\", [\"event-extensions\",\"Arbiter\",\"TimelinePerfConfig\",\"copyProperties\",\"debounce\",\"throttle\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"TimelinePerfConfig\"), i = b(\"copyProperties\"), j = b(\"debounce\"), k = b(\"throttle\");\n    function l(m) {\n        this.id = m;\n        this.idle = true;\n        this.keys = {\n        };\n        this.queue = [];\n        this.config = {\n        };\n        this.configure();\n        l.instances[m] = this;\n    };\n    l.getInstance = function(m) {\n        return (l.instances[m] || new l(m));\n    };\n    l.instances = {\n    };\n    l.config = {\n    };\n    l.REQUEUE = \"requeue\";\n    g.subscribe(\"Timeline/throttle\", function(m, n) {\n        l.config = n;\n        for (var o in l.instances) {\n            l.instances[o].configure();;\n        };\n    });\n    i(l.prototype, {\n        configure: function() {\n            if (this._handle) {\n                this._handle.remove();\n            };\n            var m = j(function() {\n                this.idle = true;\n                this._process();\n            }, (l.config.scrollDelay || 400), this), n = k(function() {\n                this.idle = false;\n                m();\n            }, (l.config.scrollThrottle || 100), this);\n            this._handle = Event.listen(window, \"scroll\", n);\n            i(this.config, l.config[this.id]);\n        },\n        cancel: function() {\n            this.idle = true;\n            this.keys = {\n            };\n            this.queue = [];\n            this.config = {\n            };\n            (this._handle && this._handle.remove());\n        },\n        _limit: function(m, n, o) {\n            if (h.getDisableAllThrottle()) {\n                m();\n                return;\n            }\n        ;\n            var p = m;\n            if (n) {\n                if (this.keys[n]) {\n                    if (o) {\n                        this.queue.splice(this.queue.indexOf(this.keys[n]), 1);\n                    }\n                     else return\n                \n                };\n                this.keys[n] = m;\n                p = function() {\n                    delete this.keys[n];\n                    m();\n                }.bind(this);\n            }\n        ;\n            this.queue.push(p);\n            this._process();\n        },\n        throttle: function(m, n) {\n            this._limit(m, n, false);\n        },\n        debounce: function(m, n) {\n            this._limit(m, n, true);\n        },\n        _process: function() {\n            if ((this.idle && this.queue.length)) {\n                var m = this.queue.shift(), n = m();\n                if ((n === l.REQUEUE)) {\n                    this.queue.push(m);\n                };\n                setTimeout(this._process.bind(this), (this.config.delay || 0));\n            }\n        ;\n        }\n    });\n    e.exports = l;\n});\n__d(\"TimelineContentLoader\", [\"event-extensions\",\"function-extensions\",\"Arbiter\",\"CSS\",\"DOM\",\"DOMScroll\",\"OnVisible\",\"ScrollingPager\",\"TimelineConstants\",\"TimelineController\",\"TimelinePerfConfig\",\"TimelineSmartInsert\",\"TimelineThrottler\",\"TimelineURI\",\"UIPagelet\",\"UserAgent\",\"Vector\",\"$\",\"copyProperties\",\"createArrayFrom\",\"debounce\",\"ge\",\"startsWith\",\"tx\",\"userAction\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"DOMScroll\"), k = b(\"OnVisible\"), l = b(\"ScrollingPager\"), m = b(\"TimelineConstants\"), n = b(\"TimelineController\"), o = b(\"TimelinePerfConfig\"), p = b(\"TimelineSmartInsert\"), q = b(\"TimelineThrottler\"), r = b(\"TimelineURI\"), s = b(\"UIPagelet\"), t = b(\"UserAgent\"), u = b(\"Vector\"), v = b(\"$\"), w = b(\"copyProperties\"), x = b(\"createArrayFrom\"), y = b(\"debounce\"), z = b(\"ge\"), aa = b(\"startsWith\"), ba = b(\"tx\"), ca = b(\"userAction\"), da = false, ea = false, fa, ga = {\n    }, ha = null, ia = {\n    }, ja = [], ka = [], la = {\n    }, ma = {\n    }, na = {\n    }, oa = {\n    }, pa = null, qa = null, ra = null, sa = false, ta = null;\n    function ua(fb, gb, hb, ib, jb) {\n        this.node = fb;\n        this.loaded = ib;\n        this.canScrollLoad = true;\n        this.canUnload = (gb != eb.RECENT);\n        this.scrubberKey = gb;\n        this.historicUnitCount = jb;\n        this._pageletLoadData = hb;\n        this._expandPageletLoadData = {\n        };\n    };\n    w(ua.prototype, {\n        load: function(fb) {\n            if (this.loaded) {\n                return\n            };\n            var gb = this._pageletLoadData;\n            g.inform(n.SECTION_LOADING, {\n                data: gb,\n                scrubberKey: this.scrubberKey\n            });\n            this.loaded = true;\n            h.removeClass(this.node, \"fbTimelineTimePeriodUnexpanded\");\n            h.removeClass(this.node, \"fbTimelineTimePeriodSuppressed\");\n            var hb = \"ProfileTimelineSectionPagelet\";\n            if ((this.scrubberKey == eb.WAY_BACK)) {\n                hb = \"ProfileTimelineRemainingYearsPagelet\";\n            };\n            gb.time_cutoff = eb.getTimeCutoff();\n            gb.highlight_unit_data = fb;\n            gb.parent_key = this.parentKey;\n            gb.force_no_friend_activity = sa;\n            h.addClass(this.node, \"fbTimelineSectionLoading\");\n            var ib = null;\n            if ((!fb && !o.getDisablePageletThrottle())) {\n                ib = ya.curry(this.node);\n            };\n            if ((this.canUnload && ea)) {\n                var jb = this.node.firstChild.cloneNode(true);\n                h.hide(jb);\n                i.insertAfter(this.node, jb);\n            }\n             else this.canScrollLoad = false;\n        ;\n            na[this.scrubberKey] = s.loadFromEndpoint(hb, this.node.id, gb, {\n                usePipe: true,\n                jsNonblock: true,\n                constHeight: true,\n                displayCallback: ib\n            });\n            db(this.scrubberKey);\n        },\n        preload: function() {\n            h.addClass(this.node, \"fbTimelineTimePeriodSuppressed\");\n            h.removeClass(this.node, \"fbTimelineTimePeriodUnexpanded\");\n            var fb = i.find(this.node, \"span.sectionLabel\");\n            if (fb.getAttribute(\"data-original-label\")) {\n                i.setContent(fb, fb.getAttribute(\"data-original-label\"));\n                fb.removeAttribute(\"data-original-label\");\n            }\n        ;\n        },\n        unload: function() {\n            if ((!this.loaded || !this.canUnload)) {\n                return\n            };\n            this.loaded = false;\n            (na[this.scrubberKey] && na[this.scrubberKey].cancel());\n            h.addClass(this.node, \"fbTimelineTimePeriodUnexpanded\");\n            h.removeClass(this.node, \"fbTimelineTimePeriodSuppressed\");\n            if ((this.node.nextSibling && h.hasClass(this.node.nextSibling, \"fbTimelineSection\"))) {\n                i.setContent(this.node, this.node.nextSibling);\n                h.show(this.node.firstChild);\n            }\n             else i.empty(this.node);\n        ;\n            this.deactivateScrollLoad();\n        },\n        activateScrollLoad: function() {\n            this.canScrollLoad = true;\n            h.removeClass(this.node, \"fbTimelineTimePeriodSuppressed\");\n            h.addClass(this.node, \"fbTimelineTimePeriodUnexpanded\");\n            (ma[this.scrubberKey] && ma[this.scrubberKey].reset());\n        },\n        deactivateScrollLoad: function() {\n            if (!this.loaded) {\n                this.canScrollLoad = false;\n                h.removeClass(this.node, \"fbTimelineTimePeriodUnexpanded\");\n                h.addClass(this.node, \"fbTimelineTimePeriodSuppressed\");\n                (ma[this.scrubberKey] && ma[this.scrubberKey].remove());\n            }\n        ;\n        },\n        setExpandLoadData: function(fb) {\n            this._expandPageletLoadData = fb;\n            return this;\n        },\n        expandSubSections: function() {\n            if (this.subSections.length) {\n                eb.navigateToSection(this.subSections[0].scrubberKey);\n            };\n        },\n        expand: function(fb) {\n            if (!this.loaded) {\n                return\n            };\n            ra.add_event((\"expand_\" + this.scrubberKey));\n            var gb = i.find(this.node, \".fbTimelineSectionExpander\");\n            h.addClass(gb.firstChild, \"async_saving\");\n            (fb && h.addClass(fb, \"async_saving\"));\n            this._expandPageletLoadData.time_cutoff = eb.getTimeCutoff();\n            eb.navigateToSection(this.scrubberKey);\n            i.scry(this.node, \"ol.fbTimelineCapsule\").forEach(i.remove);\n            this._expandPageletLoadData.new_expand = true;\n            (na[this.scrubberKey] && na[this.scrubberKey].cancel());\n            na[this.scrubberKey] = s.loadFromEndpoint(\"ProfileTimelineSectionPagelet\", gb.id, this._expandPageletLoadData, {\n                usePipe: true,\n                jsNonblock: true,\n                constHeight: true\n            });\n        },\n        isPermalinkPeriod: function() {\n            return this._pageletLoadData.is_permalink_period;\n        }\n    });\n    function va() {\n        if (da) {\n            return\n        };\n        n.register(n.CONTENT, eb);\n        ra = ca(\"scrubber\").set_namespace(\"timeline\").set_ua_id(\"scrubber\");\n        da = true;\n        if ((t.ie() <= 7)) {\n            ea = true;\n        };\n    };\n    var wa = y(function(fb, gb, hb) {\n        var ib = eb.getSection(fb).historicUnitCount;\n        gb -= ib;\n        hb -= 1;\n        if ((((ib == -1) || (hb <= 0)) || (gb < 0))) {\n            return\n        };\n        var jb = eb.getNextSectionKey(fb);\n        if (jb) {\n            eb.getSection(jb).load();\n            wa(jb, gb, hb);\n        }\n    ;\n    }, 500), xa = {\n    };\n    function ya(fb, gb) {\n        pa = q.getInstance(\"displayPagelet\");\n        pa.throttle(function() {\n            var hb = u.getViewportDimensions().y, ib = u.getScrollPosition().y, jb = (ib + hb), kb = (ib + (hb * ((pa.config.fociRatio || 54191)))), lb = u.getElementPosition(fb).y;\n            if ((lb > kb)) {\n                if ((lb < jb)) {\n                    xa[fb.id] = (((xa[fb.id] || 0)) + 1);\n                    if ((xa[fb.id] < ((pa.config.fociPenalty || 3)))) {\n                        return q.REQUEUE\n                    };\n                }\n                 else {\n                    delete xa[fb.id];\n                    return q.REQUEUE;\n                }\n            \n            };\n            delete xa[fb.id];\n            gb();\n        });\n    };\n    function za(fb, gb, hb, ib) {\n        var jb = eb.getNextSectionKey(gb);\n        if (jb) {\n            ma[jb] = new k(fb, ab.curry(jb, fb), false, (hb || 1000));\n        }\n         else if ((gb !== eb.WAY_BACK)) {\n            ib = (ib ? ib : 0);\n            if ((ib > 80)) {\n                return null\n            };\n            za.curry(fb, gb, hb, (ib + 1)).defer(250);\n        }\n        \n    ;\n    };\n    function ab(fb, gb) {\n        if (ga[fb].canScrollLoad) {\n            ra.add_event((\"scroll_load_\" + fb));\n            if (ea) {\n                eb.getSection(fb).preload();\n            }\n             else {\n                eb.getSection(fb).load();\n                if (ta) {\n                    wa(fb, ta.required_units, ta.max_parallelism);\n                };\n            }\n        ;\n            (gb && i.remove(gb));\n        }\n    ;\n    };\n    function bb() {\n        var fb, gb, hb = false;\n        for (var ib = 0; (ib < ja.length); ib++) {\n            var jb = ja[ib];\n            if (!jb) {\n                continue;\n            };\n            var kb = eb.getSection(jb);\n            if ((kb.canScrollLoad || kb.loaded)) {\n                if (!kb.loaded) {\n                    h.removeClass(kb.node, \"fbTimelineTimePeriodSuppressed\");\n                    h.addClass(kb.node, \"fbTimelineTimePeriodUnexpanded\");\n                }\n            ;\n                if ((fb && gb)) {\n                    cb(fb, gb);\n                    if (hb) {\n                        fb.deactivateScrollLoad();\n                    };\n                    hb = true;\n                }\n            ;\n                fb = null;\n                gb = null;\n                continue;\n            }\n             else if (fb) {\n                gb = kb;\n                kb.deactivateScrollLoad();\n            }\n             else {\n                fb = kb;\n                if (hb) {\n                    kb.activateScrollLoad();\n                };\n            }\n            \n        ;\n            h.removeClass(kb.node, \"fbTimelineTimePeriodSuppressed\");\n            h.addClass(kb.node, \"fbTimelineTimePeriodUnexpanded\");\n        };\n    };\n    function cb(fb, gb) {\n        h.removeClass(gb.node, \"fbTimelineTimePeriodUnexpanded\");\n        h.addClass(gb.node, \"fbTimelineTimePeriodSuppressed\");\n        var hb = i.find(fb.node, \"span.sectionLabel\"), ib = i.find(gb.node, \"span.sectionLabel\");\n        if (!ib.getAttribute(\"data-original-label\")) {\n            ib.setAttribute(\"data-original-label\", i.getText(ib));\n        };\n        if (((hb.getAttribute(\"data-month\") && ib.getAttribute(\"data-month\")) && (hb.getAttribute(\"data-year\") == ib.getAttribute(\"data-year\")))) {\n            i.setContent(ib, ba._(\"Show {month1} - {month2} {year}\", {\n                month1: ib.getAttribute(\"data-month\"),\n                month2: hb.getAttribute(\"data-month\"),\n                year: hb.getAttribute(\"data-year\")\n            }));\n        }\n         else if ((hb.getAttribute(\"data-year\") !== ib.getAttribute(\"data-year\"))) {\n            i.setContent(ib, ba._(\"Show {year1} - {year2}\", {\n                year1: ib.getAttribute(\"data-year\"),\n                year2: hb.getAttribute(\"data-year\")\n            }));\n        }\n         else i.setContent(ib, ba._(\"Show {year}\", {\n            year: ib.getAttribute(\"data-year\")\n        }));\n        \n    ;\n    };\n    function db(fb) {\n        if (ea) {\n            for (var gb = 0; (gb < (ja.length - 1)); gb++) {\n                var hb = ja[gb];\n                if (!hb) {\n                    continue;\n                };\n                if ((hb != fb)) {\n                    var ib = ga[hb];\n                    if ((ib.loaded && ib.canUnload)) {\n                        ib.unload();\n                    };\n                }\n            ;\n            }\n        };\n        bb();\n    };\n    var eb = {\n        WAY_BACK: \"way_back\",\n        RECENT: \"recent\",\n        HEADER_SCROLL_CUTOFF: 80,\n        CURRENT_SECTION_OFFSET: 150,\n        FOOTER_HEIGHT: 60,\n        registerTimePeriod: function(fb, gb, hb, ib, jb, kb, lb) {\n            va();\n            if (ka.contains(gb)) {\n                return\n            };\n            var mb = new ua(fb, gb, hb, ib, lb);\n            if (!jb) {\n                ja[kb] = gb;\n                ia[gb] = true;\n            }\n             else {\n                mb.parentKey = jb;\n                ga[jb].subSections = (ga[jb].subSections || []);\n                ga[jb].subSections[kb] = mb;\n            }\n        ;\n            ga[gb] = mb;\n            eb.checkCurrentSectionChange();\n            g.inform(n.SECTION_REGISTERED, {\n                scrubberKey: gb\n            });\n            n.registerSectionKey(gb, kb);\n        },\n        reset: function() {\n            for (var fb in ma) {\n                ma[fb].remove();;\n            };\n            for (var gb in na) {\n                na[gb].cancel();;\n            };\n            for (var hb in oa) {\n                oa[hb].unsubscribe();\n                delete oa[hb];\n            };\n            (fa && fa.unsubscribe());\n            fa = null;\n            (pa && pa.cancel());\n            pa = null;\n            ga = {\n            };\n            ha = null;\n            ia = {\n            };\n            ja = [];\n            ka = [];\n            la = {\n            };\n            ma = {\n            };\n            na = {\n            };\n            qa = null;\n            ra = null;\n            sa = false;\n            da = false;\n        },\n        checkCurrentSectionChange: function() {\n            var fb = eb.getCurrentSection(), gb = (ha && ha.scrubberKey);\n            if (((fb && (fb.scrubberKey !== gb)) && !fb.isPermalinkPeriod())) {\n                ha = fb;\n                var hb = fb.scrubberKey, ib = fb.parentKey;\n                if (!ib) {\n                    ib = hb;\n                    hb = null;\n                }\n            ;\n                n.sectionHasChanged(ib, hb);\n            }\n        ;\n        },\n        setTimeCutoff: function(fb) {\n            qa = fb;\n        },\n        getTimeCutoff: function() {\n            return qa;\n        },\n        setParallelLoadConfig: function(fb) {\n            ta = fb;\n        },\n        getCurrentSection: function() {\n            var fb = {\n            };\n            for (var gb in ga) {\n                var hb = ga[gb];\n                if ((!hb.loaded || la[hb.scrubberKey])) {\n                    continue;\n                };\n                var ib = u.getElementPosition(hb.node, \"viewport\").y;\n                if ((hb.scrubberKey == \"recent\")) {\n                    ib--;\n                };\n                if ((ib < eb.CURRENT_SECTION_OFFSET)) {\n                    fb[ib] = hb;\n                };\n            };\n            var jb = Math.max.apply(null, Object.keys(fb)), kb = (jb == -Infinity);\n            if (!kb) {\n                return fb[jb];\n            }\n             else if (ja[0]) {\n                return ga[ja[0]]\n            }\n        ;\n            return null;\n        },\n        capsuleForCurrentSection: function() {\n            var fb = eb.getCurrentSection();\n            return (fb && i.scry(fb.node, \"ol.fbTimelineCapsule\")[0]);\n        },\n        enableScrollLoad: function(fb, gb, hb, ib) {\n            fb = v(fb);\n            var jb = i.scry(fb.parentNode, \"ol.fbTimelineCapsule\")[0];\n            if (!jb) {\n                return\n            };\n            if ((hb === null)) {\n                za(fb, gb, ib);\n            }\n             else n.runOnceWhenSectionFullyLoaded(za.curry(fb, gb, ib), gb, hb);\n        ;\n        },\n        enableScrollLoadOnClick: function(fb, gb, hb) {\n            fb = v(fb);\n            Event.listen(fb, \"click\", function(ib) {\n                ib.preventDefault();\n                eb.enableScrollLoad(fb, gb, null, hb);\n            });\n        },\n        expandSectionOnClick: function(fb, gb) {\n            Event.listen(fb, \"click\", function(hb) {\n                hb.preventDefault();\n                eb.getSection(gb).expand();\n            });\n        },\n        expandSubSectionsOnClick: function(fb, gb) {\n            Event.listen(fb, \"click\", function(hb) {\n                hb.preventDefault();\n                eb.getSection(gb).expandSubSections();\n            });\n        },\n        getSection: function(fb) {\n            return ga[fb];\n        },\n        getNextSectionKey: function(fb) {\n            for (var gb = 0; (gb < (ja.length - 1)); gb++) {\n                if ((ja[gb] == fb)) {\n                    while (((gb < (ja.length - 1)) && !ja[(gb + 1)])) {\n                        gb++;;\n                    };\n                    return ja[(gb + 1)];\n                }\n            ;\n            };\n            var hb = eb.getSection(fb);\n            if ((!hb || !hb.parentKey)) {\n                return\n            };\n            var ib = eb.getSection(hb.parentKey);\n            if (!ib) {\n                return\n            };\n            for (var jb = 0; (jb < (ib.subSections.length - 1)); jb++) {\n                if ((ib.subSections[jb].scrubberKey == fb)) {\n                    return ib.subSections[(jb + 1)].scrubberKey\n                };\n            };\n        },\n        hideSection: function(fb) {\n            var gb = eb.getSection(fb);\n            (gb && h.hide(gb.node));\n            var hb = n.getCurrentScrubber();\n            if (hb) {\n                var ib = n.getCurrentScrubber().getNav(fb);\n                (ib && h.hide(ib));\n            }\n        ;\n            var jb = n.getCurrentStickyHeaderNav();\n            (jb && jb.removeTimePeriod(fb));\n            la[fb] = true;\n        },\n        loadSectionOnClick: function(fb, gb) {\n            Event.listen(fb, \"click\", function(hb) {\n                hb.preventDefault();\n                eb.getSection(gb).load();\n            });\n        },\n        removeSection: function(fb) {\n            for (var gb in ja) {\n                if ((ja[gb] == fb)) {\n                    ja[gb] = null;\n                    break;\n                }\n            ;\n            };\n            delete ga[fb];\n            delete ia[fb];\n            if ((fb in ma)) {\n                ma[fb].remove();\n                delete ma[fb];\n            }\n        ;\n            var hb = n.getCurrentStickyHeaderNav();\n            (hb && hb.removeTimePeriod(fb));\n            ka.push(fb);\n        },\n        removeSectionParent: function(fb) {\n            i.remove(v(fb).parentNode);\n        },\n        navigateToSection: function(fb, gb, hb) {\n            ra.add_event((\"nav_\" + fb));\n            gb = !!gb;\n            var ib = fb, jb = eb.getSection(fb);\n            if (!jb) {\n                return\n            };\n            if (!jb.loaded) {\n                p.enable();\n            };\n            if (!ia[fb]) {\n                jb.node.style.minHeight = (u.getViewportDimensions().y + \"px\");\n                var kb = g.subscribe(n.SECTION_FULLY_LOADED, function(sb, tb) {\n                    if ((tb.scrubberKey === fb)) {\n                        jb.node.style.minHeight = \"\";\n                        kb.unsubscribe();\n                    }\n                ;\n                });\n                ib = jb.parentKey;\n                var lb = eb.getSection(ib).node;\n                if (!h.hasClass(lb, \"fbTimelineSectionExpanded\")) {\n                    j.scrollTo(lb, 0);\n                    h.addClass(lb, \"fbTimelineSectionExpanded\");\n                    i.scry(lb, \"ol.fbTimelineCapsule\").forEach(i.remove);\n                    i.scry(lb, \"div.fbTimelineSectionExpandPager\").forEach(i.remove);\n                    i.scry(lb, \"div.fbTimelineContentHeader\").forEach(i.remove);\n                }\n            ;\n                var mb = eb.getNextSectionKey(ib);\n                if ((mb && ma[mb])) {\n                    ma[mb].setBuffer(0);\n                };\n            }\n        ;\n            for (var nb = 0; (nb < ja.length); nb++) {\n                var ob = ja[nb];\n                if (!ob) {\n                    continue;\n                };\n                if ((ob == ib)) {\n                    break;\n                };\n                eb.getSection(ob).deactivateScrollLoad();\n                i.scry(v(\"timeline_tab_content\"), \".fbTimelineSectionExpandPager\").forEach(function(sb) {\n                    var tb = l.getInstance(sb.id);\n                    (tb && tb.removeOnVisible());\n                });\n            };\n            eb.adjustContentPadding();\n            jb.load(hb);\n            bb();\n            var pb = u.getScrollPosition().x, qb = u.getElementPosition(jb.node).y;\n            if (!gb) {\n                var rb = (ia[fb] ? m.SCROLL_TO_OFFSET : m.SUBSECTION_SCROLL_TO_OFFSET);\n                j.scrollTo(new u(pb, (qb - rb), \"document\"), true, false, false, function() {\n                    var sb = u.getElementPosition(jb.node).y;\n                    j.scrollTo(new u(pb, (sb - rb), \"document\"), false);\n                    var tb = i.scry(jb.node, \"h3.uiHeaderTitle\")[0];\n                    (tb && tb.focus());\n                });\n            }\n        ;\n        },\n        adjustContentPadding: function() {\n            var fb = z(\"timeline_tab_content\");\n            if (!fb) {\n                return\n            };\n            var gb = (n.getCurrentKey() || r.TIMELINE_KEY);\n            if ((gb !== r.TIMELINE_KEY)) {\n                return\n            };\n            var hb = eb.getSection(eb.WAY_BACK);\n            fb.style.paddingBottom = ((hb && hb.loaded) ? null : ((((u.getViewportDimensions().y - eb.CURRENT_SECTION_OFFSET) - eb.HEADER_SCROLL_CUTOFF) - eb.FOOTER_HEIGHT) + \"px\"));\n        },\n        adjustContentPaddingAfterLoad: function(fb, gb) {\n            n.runOnceWhenSectionFullyLoaded(eb.adjustContentPadding, fb, gb);\n        },\n        appendContentAfterLoad: function(fb, gb, hb) {\n            n.runOnceWhenSectionFullyLoaded(i.appendContent.curry(v(fb), gb), hb, \"0\");\n        },\n        markSectionAsLoaded: function(fb, gb, hb) {\n            n.runOnceWhenSectionFullyLoaded(function() {\n                (z(fb) && h.removeClass(v(fb).parentNode, \"fbTimelineSectionLoading\"));\n            }, gb, hb);\n        },\n        suppressSectionsAbove: function(fb) {\n            var gb, hb;\n            for (var ib = 0; (ib < ja.length); ib++) {\n                var jb = ja[ib];\n                if (!jb) {\n                    continue;\n                };\n                gb = eb.getSection(jb).node;\n                hb = null;\n                if ((x(fb.parentNode.children).indexOf(fb) <= x(gb.parentNode.children).indexOf(gb))) {\n                    hb = jb;\n                    break;\n                }\n            ;\n                eb.getSection(jb).deactivateScrollLoad();\n            };\n            if (hb) {\n                eb.navigateToSection(hb, true);\n            };\n        },\n        forceNoFriendActivity: function() {\n            sa = true;\n        },\n        removeDupes: function(fb) {\n            var gb = z(fb);\n            if (!gb) {\n                return\n            };\n            var hb = i.scry(gb, \"li.fbTimelineUnit\"), ib = {\n            };\n            for (var jb = 0; (jb < hb.length); jb++) {\n                var kb = hb[jb];\n                if ((kb.id && aa(kb.id, \"tl_unit_\"))) {\n                    var lb = kb.id.substring(8, kb.id.length), mb = (((kb.getAttribute(\"data-unit\") == \"ExperienceSummaryUnit\") ? kb.getAttribute(\"data-time\") : 1));\n                    if ((ib.hasOwnProperty(lb) && (ib[lb] == mb))) {\n                        i.remove(kb);\n                    }\n                     else ib[lb] = mb;\n                ;\n                }\n            ;\n            };\n        },\n        removeLoadingState: function(fb) {\n            (z(fb) && h.removeClass(v(fb), \"fbTimelineSectionLoading\"));\n        },\n        setExpandLoadDataForSection: function(fb, gb) {\n            var hb = eb.getSection(fb);\n            (hb && hb.setExpandLoadData(gb));\n        },\n        updatePagerAfterLoad: function(fb, gb, hb, ib) {\n            if (!l.getInstance(fb.firstChild.id)) {\n                oa[fb.firstChild.id] = g.subscribe(l.REGISTERED, function(jb, kb) {\n                    oa[fb.firstChild.id].unsubscribe();\n                    delete oa[fb.firstChild.id];\n                    if ((kb.id === fb.firstChild.id)) {\n                        eb.updatePagerAfterLoad(fb, gb, hb, ib);\n                    };\n                });\n            };\n            n.runOnceWhenSectionFullyLoaded(h.removeClass.curry(fb, \"fbTimelineHiddenPager\"), hb, ib);\n            n.runOnceWhenSectionFullyLoaded(n.adjustScrollingPagerBuffer.curry(fb.firstChild.id, gb), hb, ib);\n        }\n    };\n    e.exports = eb;\n});\n__d(\"TimelineCapsule\", [\"$\",\"Arbiter\",\"createArrayFrom\",\"CSS\",\"DataStore\",\"DOM\",\"DOMQuery\",\"DOMScroll\",\"ge\",\"Hovercard\",\"Parent\",\"TimelineConstants\",\"TimelineContentLoader\",\"TimelineController\",\"TimelineSmartInsert\",\"TimelineThrottler\",\"UserAgent\",\"Vector\",\"isEmpty\",\"requestAnimationFrame\",], function(a, b, c, d, e, f) {\n    var g = b(\"$\"), h = b(\"Arbiter\"), i = b(\"createArrayFrom\"), j = b(\"CSS\"), k = b(\"DataStore\"), l = b(\"DOM\"), m = b(\"DOMQuery\"), n = b(\"DOMScroll\"), o = b(\"ge\"), p = b(\"Hovercard\"), q = b(\"Parent\"), r = b(\"TimelineConstants\"), s = b(\"TimelineContentLoader\"), t = b(\"TimelineController\"), u = b(\"TimelineSmartInsert\"), v = b(\"TimelineThrottler\"), w = b(\"UserAgent\"), x = b(\"Vector\"), y = b(\"isEmpty\"), z = b(\"requestAnimationFrame\"), aa = (function() {\n        var ba = 45, ca = 15, da = \"use\", ea = \"update\", fa = {\n        }, ga = {\n        }, ha = {\n        }, ia = {\n        };\n        function ja(bb) {\n            return j.hasClass(bb, \"fbTimelineBalancer\");\n        };\n        function ka(bb) {\n            return bb.getAttribute(\"data-spine\");\n        };\n        function la(bb) {\n            return j.hasClass(bb, \"placeholderUnit\");\n        };\n        function ma(bb) {\n            return bb.getAttribute(\"data-fixed\");\n        };\n        function na(bb, cb) {\n            if (cb) {\n                return ((k.get(r.DS_SIDEORG, bb.id) || bb.getAttribute(\"data-side\")))\n            };\n            return bb.getAttribute(\"data-side\");\n        };\n        var oa = function(bb, cb) {\n            if ((w.ie() <= 6)) {\n                oa = function(db, eb) {\n                    k.set(r.DS_SIDEORG, db.id, na(db, true));\n                    db.setAttribute(\"data-side\", eb);\n                    j.removeClass(db, \"leftColumn\");\n                    j.removeClass(db, \"rightColumn\");\n                    j.addClass(db, ((eb == \"l\") ? \"leftColumn\" : \"rightColumn\"));\n                };\n            }\n             else oa = function(db, eb) {\n                k.set(r.DS_SIDEORG, db.id, na(db, true));\n                db.setAttribute(\"data-side\", eb);\n            };\n        ;\n            oa(bb, cb);\n        };\n        function pa(bb) {\n            return bb.getAttribute(\"data-size\");\n        };\n        var qa = function(bb, cb) {\n            if (ja(bb)) {\n                return\n            };\n            if (cb) {\n                j.addClass(bb, \"balancingCapsule\");\n            }\n             else j.removeClass(bb, \"balancingCapsule\");\n        ;\n        };\n        function ra(bb) {\n            if (((j.hasClass(bb, \"fbTimelineOneColumn\") && bb.prevSibling) && j.hasClass(bb.prevSibling, \"fbTimelineOneColumn\"))) {\n                return (ca * 2)\n            };\n            if (j.hasClass(bb, \"fbTimelineIndeterminateContent\")) {\n                return 0\n            };\n            return ca;\n        };\n        function sa(bb, cb) {\n            var db = 0;\n            if ((j.shown(bb) && !j.hasClass(bb, \"placeholderUnit\"))) {\n                if ((cb === da)) {\n                    db = k.get(r.DS_HEIGHT, bb.id, null);\n                    if ((db === null)) {\n                        db = bb.getAttribute(\"data-calculatedheight\");\n                    };\n                }\n                 else db = (bb.offsetHeight + ra(bb));\n            \n            };\n            if (((cb === da) && (db === null))) {\n                db = 300;\n            };\n            k.set(r.DS_HEIGHT, bb.id, parseInt(db, 10));\n        };\n        function ta(bb) {\n            var cb = k.get(r.DS_HEIGHT, bb.id, null);\n            return cb;\n        };\n        function ua(bb, cb) {\n            if ((pa(cb) == \"2\")) {\n                return 0;\n            }\n             else if ((na(cb) == \"r\")) {\n                return (bb + ta(cb));\n            }\n             else return (bb - ta(cb))\n            \n        ;\n        };\n        function va(bb) {\n            var cb = bb.parentNode;\n            if (!cb) {\n                return\n            };\n            var db = document.createDocumentFragment(), eb = bb.firstChild;\n            while (eb.firstChild) {\n                db.appendChild(eb.firstChild);;\n            };\n            u.run(cb, l.replace.curry(bb, db));\n        };\n        function wa(bb) {\n            for (var cb = 0; (cb < bb.childNodes.length); cb++) {\n                var db = bb.childNodes[cb];\n                if (!db.getAttribute(\"data-endmarker\")) {\n                    continue;\n                };\n                var eb = db.getAttribute(\"data-endmarker\"), fb = db.getAttribute(\"data-pageindex\"), gb = function() {\n                    k.set(r.DS_LOADED, bb.id, fb);\n                    l.remove(db);\n                    h.inform(t.SECTION_FULLY_LOADED, {\n                        scrubberKey: eb,\n                        pageIndex: fb,\n                        capsuleID: bb.id,\n                        childCount: bb.childNodes.length\n                    });\n                };\n                if (s.getSection(eb)) {\n                    gb();\n                }\n                 else var hb = h.subscribe(t.SECTION_REGISTERED, function(ib, jb) {\n                    if ((jb.scrubberKey === eb)) {\n                        gb();\n                        hb.unsubscribe();\n                    }\n                ;\n                })\n            ;\n                break;\n            };\n            qa(bb, false);\n            h.inform(\"TimelineCapsule/balanced\", {\n                capsule: bb\n            });\n        };\n        function xa(bb, cb, db) {\n            while (cb[0]) {\n                oa(cb.pop(), \"l\");;\n            };\n            while (db[0]) {\n                oa(db.pop(), \"r\");;\n            };\n            if (ja(bb)) {\n                va(bb);\n            };\n            wa(bb);\n        };\n        function ya(bb) {\n            if (y(fa[bb.id])) {\n                return\n            };\n            var cb = (ja(bb) ? bb.firstChild : bb), db = cb.childNodes.length, eb = {\n            }, fb = {\n            }, gb, hb = ca, ib = ca, jb, kb = [];\n            for (var lb = 0; (lb < db); lb++) {\n                gb = cb.childNodes[lb];\n                if (j.hasClass(gb, \"fbTimelineUnit\")) {\n                    jb = m.scry(gb, \"div.timelineUnitContainer\")[0];\n                    if (jb) {\n                        fb[gb.id] = jb.getAttribute(\"data-time\");\n                    };\n                    if ((!la(gb) && j.shown(gb))) {\n                        if ((pa(gb) == \"2\")) {\n                            eb[gb.id] = Math.max(hb, ib);\n                            hb = ib = (eb[gb.id] + ta(gb));\n                        }\n                         else if ((na(gb) == \"r\")) {\n                            eb[gb.id] = ib;\n                            ib += ta(gb);\n                        }\n                         else {\n                            eb[gb.id] = hb;\n                            hb += ta(gb);\n                        }\n                        \n                    ;\n                        if (((na(gb, true) == \"l\") || (pa(gb) == \"2\"))) {\n                            kb.push(gb.id);\n                        };\n                    }\n                ;\n                }\n            ;\n            };\n            for (lb = 0; (lb < (kb.length - 1)); ++lb) {\n                var mb = kb[lb], nb = kb[(lb + 1)], ob = (eb[mb] + ba), pb = eb[nb];\n                for (var qb in fa[bb.id]) {\n                    if ((ob > pb)) {\n                        break;\n                    };\n                    var rb = fa[bb.id][qb];\n                    if (j.shown(rb)) {\n                        continue;\n                    };\n                    if (((fb[qb] <= fb[mb]) && (fb[qb] > fb[nb]))) {\n                        rb.style.top = (ob + \"px\");\n                        ob += ba;\n                        j.show(rb);\n                    }\n                ;\n                };\n            };\n        };\n        function za(bb, cb) {\n            var db = q.byAttribute(bb, \"data-size\");\n            if (db) {\n                if (j.hasClass(bb.parentNode, \"timelineReportContent\")) {\n                    cb(bb);\n                }\n                 else cb(db);\n            ;\n                aa.balanceCapsule(q.byClass(db, \"fbTimelineCapsule\"));\n            }\n        ;\n        };\n        function ab(bb) {\n            var cb = 0;\n            for (var db = 0; (db < bb.childNodes.length); db++) {\n                if (j.hasClass(bb.childNodes[db], \"fbTimelineUnit\")) {\n                    cb++;\n                };\n            };\n            return cb;\n        };\n        return {\n            getUnitsWithTime: function(bb) {\n                return m.scry(bb, \"div.timelineUnitContainer\").filter(function(cb) {\n                    return (((cb.parentNode.parentNode === bb) && cb.getAttribute(\"data-time\")));\n                });\n            },\n            removeUnit: function(bb) {\n                za(bb, function(cb) {\n                    l.remove(cb);\n                });\n            },\n            hideUnit: function(bb) {\n                za(bb, function(cb) {\n                    j.addClass(cb, \"fbTimelineColumnHidden\");\n                });\n            },\n            undoHideUnit: function(bb, cb) {\n                l.remove(q.byClass(cb, \"hiddenText\"));\n                za(bb, function(db) {\n                    j.removeClass(db, \"fbTimelineColumnHidden\");\n                });\n            },\n            unplacehold: function(bb) {\n                var cb = g(bb);\n                cb.style.top = null;\n                j.removeClass(cb, \"visiblePlaceholder\");\n                j.removeClass(cb, \"placeholder\");\n                var db = q.byClass(cb, \"fbTimelineCapsule\");\n                delete fa[db.id][bb];\n                aa.balanceCapsule(db);\n            },\n            scrollToCapsule: function(bb) {\n                if (!ia.hasOwnProperty(bb.id)) {\n                    var cb = x.getElementPosition(bb.parentNode);\n                    n.scrollTo(new x(x.getScrollPosition().x, (cb.y - r.SUBSECTION_SCROLL_TO_OFFSET), \"document\"));\n                    ia[bb.id] = true;\n                }\n            ;\n            },\n            setFirstUnit: function(bb) {\n                var cb = true, db = bb.childNodes.length;\n                for (var eb = 0; (eb < db); eb++) {\n                    var fb = bb.childNodes[eb];\n                    if ((fb.id.indexOf(\"tl_unit_\") === 0)) {\n                        if (cb) {\n                            cb = false;\n                            j.addClass(fb, \"firstUnit\");\n                        }\n                         else {\n                            j.removeClass(fb, \"firstUnit\");\n                            break;\n                        }\n                    \n                    };\n                };\n            },\n            balanceCapsule: function(bb, cb) {\n                if (!bb) {\n                    return\n                };\n                if ((bb.getAttribute(\"data-layout\") == \"fixed\")) {\n                    v.getInstance(\"balanceCapsuleFixed\").debounce(aa.balanceFixed.curry(bb, cb), bb.id);\n                }\n                 else v.getInstance(\"balanceCapsule\").throttle(aa.balance.curry(bb, 0), bb.id);\n            ;\n            },\n            balanceCapsuleFromChild: function(bb, cb) {\n                aa.balanceCapsule(q.byClass(bb, \"fbTimelineCapsule\"), cb);\n            },\n            balanceFixed: function(bb, cb) {\n                if (!bb) {\n                    return\n                };\n                var db = 0, eb, fb = document.createDocumentFragment(), gb = [], hb = [], ib = [], jb = false, kb = (cb && cb.heights_action);\n                if (((kb !== ea) && ((w.chrome() || w.safari())))) {\n                    j.toggleClass(bb, \"webkitFix\");\n                };\n                for (var lb = 0; (lb < bb.childNodes.length); lb++) {\n                    eb = bb.childNodes[lb];\n                    if (ka(eb)) {\n                        continue;\n                    }\n                     else if (ja(eb)) {\n                        i(eb.firstChild.childNodes).forEach(function(sb) {\n                            sa(sb, kb);\n                        });\n                        continue;\n                    }\n                    \n                ;\n                    sa(eb, kb);\n                    if ((na(eb, true) == \"r\")) {\n                        hb.push(eb);\n                    }\n                     else gb.push(eb);\n                ;\n                    ib.push(eb);\n                    if ((pa(eb) != \"2\")) {\n                        if (((((db > 0) && (na(eb) == \"r\"))) || (((db < 0) && (na(eb) == \"l\"))))) {\n                            jb = true;\n                        }\n                    };\n                    db = ua(db, eb);\n                };\n                var mb = [], nb = [], ob = [];\n                m.scry(bb, \"li.fbTimelineBalancer\").forEach(function(sb) {\n                    var tb = i(sb.firstChild.childNodes);\n                    if (sb.getAttribute(\"data-nonunits\")) {\n                        ob = ob.concat(tb);\n                    }\n                     else if ((na(sb) == \"left\")) {\n                        mb = mb.concat(tb);\n                    }\n                     else if ((na(sb) == \"right\")) {\n                        nb = nb.concat(tb);\n                    }\n                    \n                ;\n                });\n                if (jb) {\n                    bb.style.minHeight = bb.offsetHeight;\n                    gb.forEach(function(sb) {\n                        if ((pa(sb) != \"2\")) {\n                            oa(sb, \"l\");\n                        };\n                    });\n                    hb.forEach(function(sb) {\n                        if ((pa(sb) != \"2\")) {\n                            oa(sb, \"r\");\n                        };\n                    });\n                    var pb = l.create(\"li\", {\n                        className: \"fbTimelineBalancer\"\n                    }, l.create(\"ol\", null, gb));\n                    pb.setAttribute(\"data-side\", \"left\");\n                    l.prependContent(bb, pb);\n                    mb = gb.concat(mb);\n                    var qb = l.create(\"li\", {\n                        className: \"fbTimelineBalancer\"\n                    }, l.create(\"ol\", null, hb));\n                    qb.setAttribute(\"data-side\", \"right\");\n                    l.prependContent(bb, qb);\n                    nb = hb.concat(nb);\n                    db = 0;\n                }\n            ;\n                while (((((db >= 0) && mb.length)) || (((db < 0) && nb.length)))) {\n                    if ((db >= 0)) {\n                        eb = mb.shift();\n                    }\n                     else eb = nb.shift();\n                ;\n                    fb.appendChild(eb);\n                    db = ua(db, eb);\n                };\n                while (ob.length) {\n                    fb.appendChild(ob.shift());;\n                };\n                bb.appendChild(fb);\n                m.scry(bb, \"li.fbTimelineBalancer\").forEach(function(sb) {\n                    if (!sb.firstChild.childNodes.length) {\n                        l.remove(sb);\n                    };\n                });\n                var rb;\n                if ((cb && cb.tail_balance)) {\n                    rb = cb.tail_balance;\n                }\n                 else if (k.get(r.DS_TAILBALANCE, bb.id)) {\n                    rb = r.FIXED_SIDE_BOTH;\n                }\n            ;\n                if (rb) {\n                    db = aa.tailBalance(bb, db, rb);\n                };\n                if (jb) {\n                    ib.forEach(function(sb) {\n                        if ((sb.parentNode !== bb)) {\n                            bb.appendChild(sb);\n                            db = ua(db, sb);\n                        }\n                    ;\n                    });\n                    bb.style.minHeight = null;\n                }\n            ;\n                k.set(r.DS_COLUMN_HEIGHT_DIFFERENTIAL, q.byClass(bb, \"fbTimelineSection\").id, db);\n                fa[bb.id] = {\n                };\n                m.scry(bb, \"li.placeholderUnit\").forEach(function(sb) {\n                    fa[bb.id][sb.id] = sb;\n                });\n                ya(bb);\n                wa(bb);\n                if ((kb === da)) {\n                    cb.heights_action = ea;\n                    z(function() {\n                        z(aa.balanceCapsule.curry(bb, cb));\n                    });\n                }\n            ;\n            },\n            tailBalance: function(bb, cb, db) {\n                if (!bb) {\n                    return cb\n                };\n                var eb = [], fb = [], gb = [], hb = [];\n                m.scry(bb, \"li.fbTimelineBalancer\").forEach(function(jb) {\n                    var kb = i(jb.firstChild.childNodes);\n                    if (jb.getAttribute(\"data-nonunits\")) {\n                        hb = hb.concat(kb);\n                    }\n                     else if ((na(jb) == \"left\")) {\n                        fb = fb.concat(kb);\n                    }\n                     else if ((na(jb) == \"right\")) {\n                        gb = gb.concat(kb);\n                    }\n                    \n                ;\n                    eb = eb.concat(kb);\n                });\n                if (((((db == r.FIXED_SIDE_RIGHT) && fb.length)) || (((db == r.FIXED_SIDE_LEFT) && gb.length)))) {\n                    return cb\n                };\n                var ib = document.createDocumentFragment();\n                if (eb) {\n                    while (eb.length) {\n                        if ((pa(eb[0]) != \"2\")) {\n                            if ((cb >= 0)) {\n                                oa(eb[0], \"l\");\n                            }\n                             else oa(eb[0], \"r\");\n                        \n                        };\n                        cb = ua(cb, eb[0]);\n                        ib.appendChild(eb.shift());\n                    }\n                };\n                bb.appendChild(ib);\n                m.scry(bb, \"li.fbTimelineBalancer\").forEach(function(jb) {\n                    if (!jb.firstChild.childNodes.length) {\n                        l.remove(jb);\n                    };\n                });\n                k.set(r.DS_TAILBALANCE, bb.id, true);\n                return cb;\n            },\n            balance: function(bb, cb, db) {\n                if (!bb) {\n                    return\n                };\n                if (!fa[bb.id]) {\n                    fa[bb.id] = {\n                    };\n                };\n                var eb = (ja(bb) ? bb.firstChild : bb), fb = eb.childNodes.length, gb = [], hb = [];\n                if ((w.chrome() || w.safari())) {\n                    j.toggleClass(bb, \"webkitFix\");\n                };\n                for (var ib = 0; (ib < fb); ib++) {\n                    sa(eb.childNodes[ib]);;\n                };\n                var jb = false;\n                for (ib = 0; (ib < fb); ib++) {\n                    var kb = eb.childNodes[ib];\n                    if (ka(kb)) {\n                        continue;\n                    };\n                    var lb = ((cb >= 0)), mb = kb.nextSibling;\n                    if (ma(kb)) {\n                        if ((na(kb) == \"r\")) {\n                            if ((cb > 0)) {\n                                if ((mb && (pa(mb) != \"2\"))) {\n                                    var nb = [kb,];\n                                    while (((mb && ma(mb)) && (na(mb) == \"r\"))) {\n                                        nb.push(mb);\n                                        mb = mb.nextSibling;\n                                    };\n                                    if (mb) {\n                                        if (ja(mb)) {\n                                            var ob = mb.firstChild;\n                                            l.prependContent(ob, nb);\n                                            sa(ob);\n                                            fb -= nb.length;\n                                        }\n                                         else l.insertBefore(kb, mb);\n                                    ;\n                                        ib--;\n                                    }\n                                ;\n                                    continue;\n                                }\n                            \n                            };\n                            cb += ta(kb);\n                        }\n                         else cb -= ta(kb);\n                    ;\n                    }\n                     else if ((kb.id && ((fa[bb.id][kb.id] || la(kb))))) {\n                        fa[bb.id][kb.id] = kb;\n                        continue;\n                    }\n                     else if (ja(kb)) {\n                        cb = aa.balance(kb, cb);\n                    }\n                     else if ((pa(kb) == \"2\")) {\n                        if ((((mb && ma(mb)) && (na(mb) == \"r\")) && (cb <= 0))) {\n                            l.insertBefore(kb, mb);\n                            ib--;\n                        }\n                         else {\n                            lb = true;\n                            cb = 0;\n                        }\n                    ;\n                    }\n                     else if (lb) {\n                        gb.push(kb);\n                        cb -= ta(kb);\n                    }\n                     else {\n                        var pb = false;\n                        if (!jb) {\n                            while ((mb && ((!ma(mb) || (na(mb) != \"r\"))))) {\n                                mb = mb.nextSibling;;\n                            };\n                            if (mb) {\n                                l.insertBefore(kb, mb);\n                                ib--;\n                                pb = true;\n                            }\n                             else jb = true;\n                        ;\n                        }\n                    ;\n                        if (!pb) {\n                            hb.push(kb);\n                            cb += ta(kb);\n                        }\n                    ;\n                    }\n                    \n                    \n                    \n                    \n                ;\n                };\n                qa(bb, true);\n                if ((db && db.nothrottle)) {\n                    xa(bb, gb, hb);\n                    ya(bb);\n                }\n                 else {\n                    clearTimeout(ha[bb.id]);\n                    ha[bb.id] = setTimeout(function() {\n                        v.getInstance(\"positionUnits\").debounce(xa.curry(bb, gb, hb), bb.id);\n                        delete ha[bb.id];\n                    }, 50);\n                    clearTimeout(ga[bb.id]);\n                    ga[bb.id] = setTimeout(function() {\n                        v.getInstance(\"adjustPlaceholders\").debounce(ya.curry(bb), bb.id);\n                        delete ga[bb.id];\n                    }, 150);\n                }\n            ;\n                return cb;\n            }\n        };\n    })();\n    e.exports = (a.TimelineCapsule || aa);\n});\n__d(\"TimelineComposerUtilities\", [\"event-extensions\",\"Arbiter\",\"Bootloader\",\"CSS\",\"DOM\",\"Parent\",\"TimelineCapsule\",\"Vector\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"Bootloader\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"Parent\"), l = b(\"TimelineCapsule\"), m = b(\"Vector\"), n = (86400 * 31), o = 86400000, p = {\n        listenToSetEstimatedDate: function(q, r) {\n            return g.subscribe(\"TimelineBackdatedComposerTagger/initialized\", function(event, s) {\n                if ((s.composer === q)) {\n                    s.date_picker.subscribe(\"initialized\", function(t, u) {\n                        p.setEstimatedDate(u, r());\n                    });\n                };\n            });\n        },\n        listenToPublish: function(q, r) {\n            return g.subscribe(\"composer/publish\", function(event, s) {\n                if ((s.composer === q)) {\n                    h.loadModules([\"TimelineStoryPublisher\",], function(t) {\n                        t.publish(s);\n                        (r && r());\n                    });\n                };\n            });\n        },\n        listenToAnotherComposerOpen: function(q, r) {\n            return g.subscribe(\"composer/mutate\", function(s, t) {\n                if ((t !== q)) {\n                    r();\n                };\n            });\n        },\n        listenToCancel: function(q, r) {\n            return Event.listen(q, \"click\", function(event) {\n                (k.byClass(event.getTarget(), \"cancelBtn\") && r());\n            });\n        },\n        hidePlaceIfAttachmentsTooTall: function(q) {\n            var r = j.find(q, \"ul.fbTimelineComposerAttachments\"), s = m.getElementDimensions(r).y;\n            if ((s > 50)) {\n                var t = k.byTag(j.scry(r, \"span.placeAttachment\")[0], \"li\");\n                (t && i.hide(t));\n            }\n        ;\n        },\n        setEstimatedDate: function(q, r) {\n            var s, t;\n            if ((r && i.hasClass(r, \"fbTimelineCapsule\"))) {\n                s = r.getAttribute(\"data-start\");\n                t = r.getAttribute(\"data-end\");\n                if ((s && t)) {\n                    var u = new Date((t * 1000));\n                    if (((t - s) > (2 * n))) {\n                        q.setDate(u.getFullYear());\n                    }\n                     else q.setDate(u.getFullYear(), (u.getMonth() + 1));\n                ;\n                }\n            ;\n                return;\n            }\n        ;\n            var v = k.byClass(r, \"fbTimelineCapsule\");\n            if (v) {\n                s = v.getAttribute(\"data-start\");\n                t = v.getAttribute(\"data-end\");\n                var w = m.getElementPosition(r).y, x = [t,null,], y = [s,null,], z = l.getUnitsWithTime(v);\n                for (var aa = 0; (aa < z.length); aa++) {\n                    var ba = z[aa], ca = j.scry(ba.parentNode, \".spinePointer\")[0];\n                    if (!ca) {\n                        continue;\n                    };\n                    var da = m.getElementPosition(ca).y;\n                    if ((da <= w)) {\n                        if ((!x[1] || (da > x[1]))) {\n                            x = [ba.getAttribute(\"data-time\"),da,];\n                        };\n                    }\n                     else if ((!y[1] || (da < y[1]))) {\n                        y = [ba.getAttribute(\"data-time\"),da,];\n                    }\n                ;\n                };\n                if (((x[0] !== null) && (y[0] !== null))) {\n                    var ea = (Math.round((((parseInt(x[0], 10) + parseInt(y[0], 10))) / 2)) * 1000);\n                    ea = Math.min((new Date() - o), ea);\n                    q.setDateWithTimestamp(ea);\n                }\n            ;\n            }\n        ;\n        }\n    };\n    e.exports = p;\n});\n__d(\"TimelineNavigation\", [\"event-extensions\",\"Arbiter\",\"DOM\",\"CSS\",\"PageTransitions\",\"Parent\",\"TimelineController\",\"TimelineURI\",\"URI\",\"$\",\"createArrayFrom\",\"ge\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"DOM\"), i = b(\"CSS\"), j = b(\"PageTransitions\"), k = b(\"Parent\"), l = b(\"TimelineController\"), m = b(\"TimelineURI\"), n = b(\"URI\"), o = b(\"$\"), p = b(\"createArrayFrom\"), q = b(\"ge\"), r = 4, s = 110, t = 20, u = 119, v = 328, w = 10, x = 3, y = false, z = 21, aa, ba, ca, da = [], ea = [], fa, ga = 0, ha, ia = 0, ja = 0, ka, la = r, ma = false, na = false, oa = null, pa, qa = false, ra, sa, ta = false;\n    function ua(ib, jb, kb) {\n        if (!jb.firstChild) {\n            h.remove(jb);\n            return;\n        }\n    ;\n        ea.push(jb);\n        xa(kb.recent);\n        i.removeClass(k.byTag(jb, \"li\"), \"empty\");\n        if ((fa && (((ia > r) || (ja > 0))))) {\n            i.removeClass(fa, \"notready\");\n        };\n        wa();\n        if (kb.async) {\n            bb();\n            db();\n        }\n    ;\n    };\n    function va(ib, jb, kb) {\n        h.remove(k.byTag(jb, \"li\"));\n        if (!kb.async) {\n            ka++;\n        }\n         else {\n            ia--;\n            bb();\n            db();\n        }\n    ;\n        wa();\n    };\n    function wa() {\n        var ib = (fa ? 0 : z);\n        if ((ia <= r)) {\n            var jb = ((v + (u * Math.max(0, (r - ia)))) + ib);\n            ha.style.width = (jb + \"px\");\n            la = ia;\n            ya();\n        }\n    ;\n    };\n    function xa(ib) {\n        if (ib) {\n            ja++;\n        }\n         else ia++;\n    ;\n        ya();\n    };\n    function ya() {\n        if (!ra) {\n            return\n        };\n        var ib = (Math.max(0, (ia - r)) + ja);\n        if ((ga && fa)) {\n            h.setContent(ga, ((ib === 0) ? \" \" : ib));\n            i.conditionClass(fa, \"fbTimelineMoreButtonZero\", (ib === 0));\n            if (!ma) {\n                i.conditionShow(fa, (ib > 0));\n            };\n        }\n    ;\n    };\n    function za() {\n        var ib = h.scry(o(\"fbTimelineNavTopRow\"), \"li.tile\"), jb = 0, kb = 0, lb = Math.max(0, (r - la)), mb = false;\n        for (var nb = 0; (nb < ib.length); nb++) {\n            if (((ib[nb] == ha) || (ib[nb] == fa))) {\n                continue;\n            };\n            mb = (((((jb + lb)) \u0025 r) === 0));\n            i.conditionClass(ib[nb], \"leftMost\", (((jb !== 0) && mb)));\n            if (!i.hasClass(ib[nb], \"empty\")) {\n                kb = jb;\n            };\n            jb++;\n        };\n        mb = ((((((kb + 1) + lb)) \u0025 r) === 0));\n        var ob = ((ib.length - 1) - lb);\n        if (mb) {\n            if ((ma && (((((kb + 1) + lb)) / r) < x))) {\n                ob = Math.min(ob, (kb + r));\n                na = true;\n            }\n             else ob = kb;\n        ;\n        }\n         else {\n            var pb = (((((kb + 1) + lb)) \u0025 r));\n            ob = (kb + ((r - pb)));\n            na = false;\n        }\n    ;\n        nb = 0;\n        for (nb = 0; (nb <= ob); nb++) {\n            if ((ib[nb] && (((ib[nb] == ha) || (ib[nb] == fa))))) {\n                ob++;\n            }\n             else ((ib[nb] && i.hasClass(ib[nb], \"empty\")) && i.removeClass(ib[nb], \"hidden_elem\"));\n        ;\n        };\n    };\n    function ab(ib, jb, kb) {\n        var lb = h.scry(ib, \"li.tile\");\n        if (!jb) {\n            jb = 0;\n        };\n        var mb = false;\n        for (var nb = jb; (nb < lb.length); nb++) {\n            mb = (((((nb - kb)) \u0025 r) === 0));\n            var ob = lb[nb];\n            i.conditionClass(ob, \"leftMost\", mb);\n            if (i.hasClass(ob, \"empty\")) {\n                i.removeClass(ob, \"hidden_elem\");\n            };\n        };\n    };\n    function bb() {\n        za();\n        var ib = q(\"fbTimelineNavSecondaryRow\");\n        (ib && ab(ib, 0, 0));\n    };\n    function cb() {\n        if (!fa) {\n            return\n        };\n        if (i.hasClass(fa, \"notready\")) {\n            return\n        };\n        i.toggleClass(fa, \"fbTimelineMoreButtonOpen\");\n        var ib = q(\"fbRecentAppTitle\");\n        (ib && i.conditionClass(ib, \"hidden_elem\", (ja === 0)));\n        if (i.hasClass(fa, \"fbTimelineMoreButtonOpen\")) {\n            bb();\n        }\n         else ya();\n    ;\n        db();\n    };\n    function db() {\n        if ((fa && !i.hasClass(fa, \"fbTimelineMoreButtonOpen\"))) {\n            aa.style.height = \"\";\n            i.removeClass(aa, \"expanded\");\n        }\n         else {\n            var ib = (ia + ((r - la))), jb = ((((((((ja > 0)) ? w : 0)) + (s * (Math.ceil((ja / r))))) + (s * (Math.ceil((ib / r))))) + (s * ((na ? 1 : 0)))) + t);\n            i.addClass(aa, \"expanded\");\n            aa.style.height = (jb + \"px\");\n        }\n    ;\n    };\n    function eb(ib) {\n        var jb = ((ib == m.TIMELINE_KEY) || (ib == m.WALL_KEY)), kb = k.byClass(aa, \"fbTimelineTopSectionBase\"), lb = q(\"timeline_tour_toolbar\");\n        if (fa) {\n            i.removeClass(fa, \"fbTimelineMoreButtonOpen\");\n            db();\n        }\n    ;\n        (lb && i.conditionShow(lb, jb));\n        if (kb) {\n            i.conditionClass(kb, \"collapsedHead\", !jb);\n        };\n    };\n    function fb(event) {\n        if (ta) {\n            return true\n        };\n        if (!k.byTag(event.getTarget(), \"a\")) {\n            var ib = h.find(ha, \"a.title\");\n            j.go(ib.href);\n        }\n    ;\n    };\n    function gb() {\n        if (fa) {\n            (function() {\n                fa.removeAttribute(\"ajaxify\");\n                fa.removeAttribute(\"rel\");\n            }).defer();\n        };\n        (oa && oa.remove());\n    };\n    var hb = {\n        UPDATE_PAGE: \"TimelineNavigation/updatePage\",\n        init: function(ib, jb, kb, lb) {\n            if (y) {\n                return\n            };\n            y = true;\n            aa = ib;\n            fa = jb;\n            ba = n.getRequestURI();\n            ha = h.find(aa, \"li.about\");\n            eb(l.getCurrentKey());\n            ma = lb;\n            g.inform(hb.UPDATE_PAGE);\n            if (fa) {\n                ga = h.find(fa, \"div.text\");\n                oa = Event.listen(fa, \"click\", gb);\n            }\n        ;\n            pa = o(\"fbTimelineNavigationLoadContainer\");\n            h.appendContent(o(\"content\"), pa);\n            sa = Event.listen(ha, \"click\", fb);\n            da.forEach(function(nb) {\n                if (!nb[2].remove) {\n                    ua.apply(this, nb);\n                }\n                 else va.apply(this, nb);\n            ;\n            });\n            da = [];\n            var mb = k.byClass(ib, \"fbTimelineSection\");\n            if (mb) {\n                h.scry(mb, \"ul.uiButtonGroup\").forEach(function(nb) {\n                    p(nb.childNodes).forEach(function(ob) {\n                        (ob.childNodes.length || h.remove(ob));\n                    });\n                    if (nb.firstChild) {\n                        i.addClass(nb.firstChild, \"firstItem\");\n                    }\n                     else h.remove(nb);\n                ;\n                });\n            };\n            l.register(l.NAV, hb);\n        },\n        reset: function() {\n            (sa && sa.remove());\n            sa = null;\n            (ra && ra.remove());\n            ra = null;\n            y = false;\n            aa = null;\n            ca = null;\n            ea = [];\n            fa = null;\n            ga = null;\n            ha = null;\n            ia = 0;\n            ja = 0;\n            ka = 0;\n            la = r;\n            ma = false;\n            na = false;\n            pa = null;\n            qa = false;\n            ta = false;\n        },\n        initializeMorePager: function() {\n            if (ra) {\n                return\n            };\n            if (fa) {\n                ra = Event.listen(fa, \"click\", cb);\n            };\n        },\n        registerNav: function(ib, jb, kb) {\n            (y ? ((kb.remove ? va.apply(this, arguments) : ua.apply(this, arguments))) : da.push(arguments));\n        },\n        redraw: function() {\n            bb();\n            db();\n        },\n        setEditMode: function(ib) {\n            ta = ib;\n        }\n    };\n    e.exports = hb;\n});\n__d(\"TimelineBackdatedComposer\", [\"Arbiter\",\"Bootloader\",\"CSS\",\"DOM\",\"LayerHideOnBlur\",\"Run\",\"TimelineComposerUtilities\",\"TimelineNavigation\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"Bootloader\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"LayerHideOnBlur\"), l = b(\"Run\"), m = b(\"TimelineComposerUtilities\"), n = b(\"TimelineNavigation\"), o;\n    function p() {\n        q();\n        r();\n    };\n    function q() {\n        o.hide();\n    };\n    function r() {\n        h.loadModules([\"TimelineMLE\",], function(t) {\n            var u = t.getFlyout();\n            if ((u && i.hasClass(u.getContext(), \"backdatedDot\"))) {\n                t.hideFlyout();\n            };\n        });\n    };\n    var s = {\n        init: function(t, u) {\n            o = u;\n            var v = [m.listenToPublish(t, p),m.listenToAnotherComposerOpen(t, p),m.listenToSetEstimatedDate(t, o.getContext.bind(o)),t.subscribeToMutate(function() {\n                var x = (!j.scry(t.root, \".cancelBtn\")[0] || j.scry(t.root, \".attachmentLifeEvents\")[0]);\n                if (x) {\n                    o.enableBehavior(k);\n                }\n                 else o.disableBehavior(k);\n            ;\n            }),g.subscribe(\"TimelineMLE/mleFlyoutShown\", function(x, y) {\n                if (i.hasClass(y.getContext(), \"backdatedDot\")) {\n                    q();\n                }\n                 else p();\n            ;\n            }),g.subscribe(n.UPDATE_PAGE, p),], w = m.listenToCancel(o.getContent(), p);\n            l.onLeave(function() {\n                v.forEach(g.unsubscribe.bind(g));\n                v = [];\n                w.remove();\n                w = null;\n            });\n            g.inform(\"TimelineBackdatedComposer/initialized\");\n        },\n        getFlyout: function() {\n            return o;\n        }\n    };\n    e.exports = (a.TimelineBackdatedComposer || s);\n});\n__d(\"TimelineSpine\", [\"array-extensions\",\"event-extensions\",\"Arbiter\",\"AsyncRequest\",\"Bootloader\",\"ContextualDialogX\",\"Composer\",\"CSS\",\"DOM\",\"Layer\",\"LayerHideOnBlur\",\"Parent\",\"Run\",\"TimelineBackdatedComposer\",\"TimelineComposerUtilities\",\"TimelinePerfConfig\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"Bootloader\"), j = b(\"ContextualDialogX\"), k = b(\"Composer\"), l = b(\"CSS\"), m = b(\"DOM\"), n = b(\"Layer\"), o = b(\"LayerHideOnBlur\"), p = b(\"Parent\"), q = b(\"Run\"), r = b(\"TimelineBackdatedComposer\"), s = b(\"TimelineComposerUtilities\"), t = b(\"TimelinePerfConfig\"), u = b(\"copyProperties\");\n    function v() {\n    \n    };\n    u(v, {\n        OFFSET_Y: 12,\n        composerFlyout: null,\n        mleFlyout: null,\n        dot: null,\n        loadComposerFlyoutCalled: false,\n        showComposerFlyout: function(w) {\n            var x = v.composerFlyout;\n            if (!x) {\n                v.loadComposerFlyout(w);\n                v.showComposerFlyoutOnLoad = true;\n                return;\n            }\n        ;\n            var y = m.find(x.getContent(), \"div.fbTimelineBackdatedComposer\"), z = k.getInstance(y);\n            if (z) {\n                z.reset();\n                l.removeClass(z.root, \"uiComposerOpen\");\n            }\n        ;\n            x.enableBehavior(o).setContext(v.dot).updatePosition();\n            x.show();\n            s.hidePlaceIfAttachmentsTooTall(y);\n        },\n        loadComposerFlyout: function(w) {\n            if ((v.loadComposerFlyoutCalled || v.composerFlyout)) {\n                return\n            };\n            v.loadComposerFlyoutCalled = true;\n            q.onLeave(function() {\n                v.loadComposerFlyoutCalled = false;\n                v.composerFlyout = null;\n            }.bind(this));\n            new h().setURI(\"/ajax/timeline/backdated_composer.php\").setData({\n                targetid: w\n            }).setRelativeTo((v.dot || document.body)).send();\n            var x = g.subscribe(\"TimelineBackdatedComposer/initialized\", function() {\n                v.composerFlyout = r.getFlyout();\n                if (v.showComposerFlyoutOnLoad) {\n                    v.showComposerFlyout(w);\n                };\n                v._handleComposerFlyoutDismissed();\n                x.unsubscribe();\n            });\n        },\n        showMLEFlyout: function(w) {\n            v.mleFlyout = w;\n            w.setContext(v.dot).show();\n            v.composerFlyout.hide();\n        },\n        _handleComposerFlyoutDismissed: function() {\n            var w = n.subscribe(\"hide\", function(x, y) {\n                if ((v.dot && y.getContext)) {\n                    if (((y.getContext() === v.dot) && !v.mleFlyout)) {\n                        v._hideDot();\n                    }\n                     else if ((y === v.mleFlyout)) {\n                        v.mleFlyout = null;\n                        v._hideDot();\n                    }\n                    \n                \n                };\n            });\n            q.onLeave(function() {\n                n.unsubscribe(w);\n            }.bind(this));\n        },\n        _hideDot: function() {\n            m.remove(v.dot);\n            v.dot = null;\n        }\n    });\n    u(v.prototype, {\n        init: function(w, x) {\n            this._spine = w;\n            if (!t.getDisableSpineHeight()) {\n                this._spineHeight = w.offsetHeight;\n            };\n            this._plus = m.find(w, \".spineHoverPlus\");\n            this._capsule = p.byClass(w, \"fbTimelineCapsule\");\n            this._targetid = x;\n            var y = [Event.listen(w, \"mouseenter\", function(event) {\n                v.loadComposerFlyout(this._targetid);\n                this._spineHeight = w.offsetHeight;\n            }.bind(this)),Event.listen(w, \"mousemove\", this._mouseMoved.bind(this)),Event.listen(w, \"click\", this._spineClicked.bind(this)),];\n            l.addClass(this._plus, \"spineHoverPlusActive\");\n            q.onLeave(function() {\n                while (y.length) {\n                    y.pop().remove();;\n                };\n            }.bind(this));\n        },\n        _mouseMoved: function(event) {\n            var w = (event.offsetY || event.layerY), x = event.getTarget();\n            if ((x !== this._spine)) {\n                w = (x.offsetTop + w);\n            };\n            w = Math.min(Math.max((w - v.OFFSET_Y), 0), this._spineHeight);\n            this._plus.style.top = (w + \"px\");\n        },\n        _spineClicked: function(event) {\n            if (v.mleFlyout) {\n                i.loadModules([\"TimelineMLE\",], function(w) {\n                    w.hideFlyout();\n                });\n                return;\n            }\n        ;\n            (v.dot && m.remove(v.dot));\n            v.dot = m.create(\"i\", {\n                className: \"backdatedDot\"\n            });\n            v.dot.style.top = (((this._plus.offsetTop - 1)) + \"px\");\n            m.appendContent(this._spine, v.dot);\n            event.stop();\n            v.showComposerFlyout(this._targetid);\n        }\n    });\n    e.exports = (a.TimelineSpine || v);\n});\n__d(\"legacy:TimelineSpine\", [\"TimelineSpine\",], function(a, b, c, d) {\n    a.TimelineSpine = b(\"TimelineSpine\");\n}, 3);\n__d(\"timeline-cover-dragdrop-edit\", [\"SinglePictureUploadTarget\",\"TimelineCover\",], function(a, b, c, d, e, f) {\n    var g = b(\"SinglePictureUploadTarget\"), h = b(\"TimelineCover\"), i = function() {\n        var m = h.getInstance();\n        m.hideLoadingIndicator();\n    }, j = function(m) {\n        var n = h.getInstance(), o = m.id, p = m.photo_html;\n        n.updateCoverImage(o, p);\n    }, k = function(m) {\n        h.getInstance().showLoadingIndicator();\n    }, l = function(m, n, o, p) {\n        new g(m, n).setMaximumDimensions(o, p).setPreprocessCallback(k).setOncompleteCallback(i).setAfterSuccessCallback(j).activate();\n    };\n    f.initialize_timeline_cover_drop_target = l;\n});\n__d(\"TimelineComposer\", [\"Arbiter\",\"Bootloader\",\"CSS\",\"DOM\",\"Parent\",\"Run\",\"TimelineCapsule\",\"TimelineComposerUtilities\",\"$\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"Bootloader\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"Parent\"), l = b(\"Run\"), m = b(\"TimelineCapsule\"), n = b(\"TimelineComposerUtilities\"), o = b(\"$\"), p;\n    function q(v) {\n        if ((v.isScheduledPost || v.isOGPost)) {\n            return\n        };\n        if (!v.streamStory) {\n            window.location.reload();\n            return;\n        }\n    ;\n        if (v.backdatedTime) {\n            h.loadModules([\"TimelineStoryPublisher\",], function(z) {\n                z.publish(v);\n            });\n            return;\n        }\n    ;\n        var w = k.byClass(p, \"fbTimelineCapsule\");\n        if (!w) {\n            return\n        };\n        var x = k.byClass(p, \"timelineUnitContainer\").parentNode;\n        if (x.nextSibling.getAttribute(\"data-spine\")) {\n            x = x.nextSibling;\n        };\n        var y = j.insertAfter(x, v.streamStory)[0];\n        h.loadModules([\"Animation\",], function(z) {\n            z(y.firstChild).from(\"backgroundColor\", \"#fff8dd\").to(\"backgroundColor\", \"#fff\").duration(2000).ease(z.ease.both).go();\n        });\n        m.setFirstUnit(w);\n        m.balanceCapsule(w);\n    };\n    function r() {\n        var v = k.byClass(p, \"fbTimelineTwoColumn\");\n        return j.find(v, \".spinePointer\");\n    };\n    function s(v) {\n        var w = t();\n        i.show(w);\n        var x = v.subscribe(\"hide\", function() {\n            i.hide(w);\n            v.unsubscribe(x);\n        });\n    };\n    function t() {\n        var v = k.byClass(p, \"fbTimelineTwoColumn\"), w = j.scry(v, \"div.composerVeil\");\n        if ((w.length !== 1)) {\n            w = j.appendContent(v, j.create(\"div\", {\n                className: \"composerVeil hidden_elem\"\n            }));\n        };\n        return w[0];\n    };\n    var u = {\n        init: function(v) {\n            p = o(v);\n            var w = g.subscribe(\"composer/publish\", function(event, x) {\n                if ((x.composer.root === p)) {\n                    q(x);\n                };\n            });\n            l.onLeave(function() {\n                w.unsubscribe();\n            });\n            n.hidePlaceIfAttachmentsTooTall(p);\n        },\n        initComposerX: function(v) {\n            p = o(v);\n            var w = g.subscribe(\"composer/publish\", function(event, x) {\n                if ((x.composer_id === v)) {\n                    q(x);\n                };\n            });\n            l.onLeave(function() {\n                w.unsubscribe();\n            });\n        },\n        showMLEFlyout: function(v) {\n            v.setContext(r()).show();\n            s(v);\n        }\n    };\n    e.exports = (a.TimelineComposer || u);\n});\n__d(\"TimelineLogging\", [\"TimelineController\",\"reportData\",], function(a, b, c, d, e, f) {\n    var g = b(\"TimelineController\"), h = b(\"reportData\"), i = false, j = 0, k = null, l = {\n        init: function(m) {\n            if (i) {\n                return\n            };\n            j = m;\n            g.register(g.LOGGING, this);\n        },\n        reset: function() {\n            i = false;\n            j = 0;\n            k = null;\n        },\n        log: function(m, n) {\n            n.profile_id = j;\n            h(m, {\n                gt: n\n            });\n        },\n        logSectionChange: function(m, n) {\n            var o = {\n                timeline_section_change: 1,\n                key: m\n            };\n            if ((k && (m == k))) {\n                o.timeline_scrubber = 1;\n                k = null;\n            }\n        ;\n            l.log(\"timeline\", o);\n        },\n        logScrubberClick: function(m) {\n            k = m;\n        }\n    };\n    e.exports = l;\n});\n__d(\"TimelineSideAds\", [\"event-extensions\",\"function-extensions\",\"Arbiter\",\"cx\",\"csx\",\"CSS\",\"DOM\",\"StickyController\",\"TimelineController\",\"UIPagelet\",\"URI\",\"Vector\",\"debounce\",\"ge\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"cx\"), i = b(\"csx\"), j = b(\"CSS\"), k = b(\"DOM\"), l = b(\"StickyController\"), m = b(\"TimelineController\"), n = b(\"UIPagelet\"), o = b(\"URI\"), p = b(\"Vector\"), q = b(\"debounce\"), r = b(\"ge\"), s = 2, t = 3, u = 75, v = \"data-height\", w = 310, x = 45, y = 30000, z = 0, aa = false, ba, ca, da, ea, fa = [], ga, ha = false, ia, ja = Infinity, ka = 5, la = false, ma, na, oa, pa, qa, ra = false, sa = [], ta;\n    function ua(mb, nb, ob) {\n        var pb = 0;\n        if (r(\"pagelet_timeline_friends\")) {\n            pb += w;\n        };\n        if (nb) {\n            pb += nb.getHeight();\n        };\n        if ((!m.fixedAds() && !pb)) {\n            return\n        };\n        mb -= pb;\n        var qb = 0;\n        for (var rb = 0; (rb < ob); rb++) {\n            qb += eb(rb);;\n        };\n        if (nb) {\n            if ((mb < qb)) {\n                mb += nb.fold((qb - mb));\n            }\n             else if ((mb > qb)) {\n                mb -= nb.unfold((mb - qb));\n            }\n        \n        };\n        return mb;\n    };\n    function va() {\n        var mb = ca.cloneNode(true);\n        mb.id = \"\";\n        var nb = true;\n        k.scry(mb, \"div.ego_unit\").forEach(function(ob) {\n            if (nb) {\n                nb = false;\n            }\n             else k.remove(ob);\n        ;\n        });\n        j.addClass(mb, \"fixed_elem\");\n        return mb;\n    };\n    function wa() {\n        if (!m.pageHasScrubber(ga)) {\n            ab(ka);\n            cb();\n        }\n         else if (na) {\n            bb(ca, false);\n            var mb = oa;\n            (oa && k.remove(oa));\n            oa = va();\n            if (mb) {\n                jb();\n            };\n            ab(((m.sidebarInitialized() && ha) ? t : s));\n            cb();\n            if (!ia) {\n                var nb = m.getCurrentScrubber();\n                if (nb) {\n                    ib(nb.getRoot(), nb.getOffset());\n                }\n                 else {\n                    var ob = r(\"timeline_side_friends\");\n                    if (ob) {\n                        ib(ob, x);\n                    };\n                }\n            ;\n            }\n        ;\n            (ia && ia.start());\n        }\n         else lb.adjustAdsToFit();\n        \n    ;\n    };\n    function xa() {\n        var mb = r(\"pagelet_timeline_friends\");\n        if (mb) {\n            j.conditionClass(mb, \"fixed_elem\", !na);\n        };\n    };\n    function ya() {\n        if (oa) {\n            k.remove(oa);\n            oa = null;\n        }\n    ;\n        if (ia) {\n            ia.stop();\n            ia = null;\n        }\n    ;\n        if (m.fixedAds()) {\n            j.conditionClass(ca, \"fixed_elem\", !na);\n            j.conditionClass(ca, \"-cx-PRIVATE-fbTimelineStyleAds__topAligned\", !m.pageHasScrubber(ga));\n        }\n         else j.conditionClass(ca, \"fixed_elem\", (!na && m.pageHasScrubber(ga)));\n    ;\n        xa();\n    };\n    function za(mb) {\n        var nb = p.getViewportDimensions().y, ob = m.getCurrentScrubber(), pb = (ob ? ob.getOffset() : m.SCRUBBER_DEFAULT_OFFSET), qb = ((nb - pb) - u);\n        if (((ob || m.fixedAds()) || r(\"pagelet_timeline_friends\"))) {\n            return ua(qb, ob, mb)\n        };\n    };\n    function ab(mb) {\n        ea = Math.min(mb, fa.length);\n        for (var nb = 0; (nb < fa.length); nb++) {\n            bb(fa[nb], (nb >= ea));;\n        };\n        bb(ca, (ea === 0));\n    };\n    function bb(mb, nb) {\n        j.conditionClass(mb, \"-cx-PRIVATE-fbTimelineStyleAds__offScreen\", nb);\n        mb.setAttribute(\"aria-hidden\", (nb ? \"true\" : \"false\"));\n    };\n    function cb() {\n        if (!pa) {\n            return\n        };\n        for (var mb = (ea - 1); (mb >= 0); --mb) {\n            if (((ia && ia.isFixed()) && ((((mb !== 0)) || ((oa && !j.shown(oa))))))) {\n                continue;\n            };\n            var nb = k.find(fa[mb], \"div.-cx-PRIVATE-fbAdUnit__root\"), ob = nb.getAttribute(\"data-ad\"), pb = JSON.parse(ob).adid;\n            if (!pa[pb]) {\n                return\n            };\n            var qb = k.create(\"iframe\", {\n                src: o(\"/ai.php\").addQueryData({\n                    aed: pa[pb]\n                }),\n                width: 0,\n                height: 0,\n                frameborder: 0,\n                scrolling: \"no\",\n                className: \"fbEmuTracking\"\n            });\n            qb.setAttribute(\"aria-hidden\", \"true\");\n            k.appendContent(ca, qb);\n            delete pa[pb];\n        };\n    };\n    function db(mb) {\n        var nb = 0;\n        while (((mb > 0) && (nb < ka))) {\n            mb -= eb(nb);\n            if ((mb >= 0)) {\n                nb++;\n            };\n        };\n        return nb;\n    };\n    function eb(mb) {\n        var nb = fa[mb];\n        if (!nb) {\n            return 0\n        };\n        if (!nb.getAttribute(v)) {\n            fb(nb);\n        };\n        return parseInt(nb.getAttribute(v), 10);\n    };\n    function fb(mb) {\n        mb.setAttribute(v, mb.offsetHeight);\n    };\n    function gb() {\n        for (var mb = 0; (mb < fa.length); mb++) {\n            var nb = fa[mb];\n            if (!nb) {\n                continue;\n            };\n            fb(nb);\n        };\n    };\n    function hb() {\n        fa = k.scry(ca, \"div.ego_unit\");\n        var mb = fa.length;\n        if (!mb) {\n            return\n        };\n        la = mb;\n        wa();\n        var nb = function(ob) {\n            fb(ob);\n            la = --mb;\n            lb.adjustAdsToFit();\n            if (!la) {\n                ja = Date.now();\n            };\n        };\n        fa.forEach(function(ob) {\n            function pb() {\n                nb.curry(ob).defer();\n            };\n            var qb = k.scry(ob, \"img.img\")[0];\n            if (qb.complete) {\n                pb();\n            }\n             else Event.listen(qb, {\n                load: pb,\n                error: pb,\n                abort: pb\n            });\n        ;\n        });\n    };\n    function ib(mb, nb) {\n        ia = new l(mb, nb, function(ob) {\n            if (ob) {\n                jb();\n            }\n             else {\n                k.remove(oa);\n                cb();\n            }\n        ;\n        });\n        if (oa) {\n            ia.start();\n        };\n    };\n    function jb() {\n        k.insertAfter(ca, oa);\n        kb();\n    };\n    function kb() {\n        j.conditionShow(oa, ((eb(0) <= za(1)) && !j.hasClass(document.documentElement, \"tinyViewport\")));\n    };\n    var lb = {\n        init: function(mb, nb, ob) {\n            if (aa) {\n                return\n            };\n            ka = ob.max_ads;\n            ba = ob.refresh_delay;\n            y = ob.refresh_threshold;\n            aa = true;\n            da = nb;\n            ca = mb;\n            lb.adjustAdsType(m.shouldShowWideAds());\n            qa = g.subscribe([\"UFI/CommentAddedActive\",\"UFI/CommentDeletedActive\",\"UFI/LikeActive\",\"Curation/Action\",\"ProfileBrowser/LoadMoreContent\",], lb.loadAdsIfEnoughTimePassed);\n            ta = q(lb.loadAdsIfEnoughTimePassed, ba, this, true);\n            if (ob.mouse_move) {\n                sa.push(Event.listen(window, \"mousemove\", ta));\n                sa.push(Event.listen(window, \"scroll\", ta));\n                sa.push(Event.listen(window, \"resize\", ta));\n            }\n        ;\n            m.register(m.ADS, lb);\n        },\n        setShortMode: function(mb, nb) {\n            na = (((nb !== \"map\") && mb) && m.pageHasScrubber(nb));\n        },\n        start: function(mb) {\n            pa = mb;\n            ma = null;\n            hb();\n        },\n        updateCurrentKey: function(mb) {\n            if ((mb == ga)) {\n                return\n            };\n            ga = mb;\n            ya();\n        },\n        loadAds: function(mb) {\n            if ((la || ma)) {\n                return\n            };\n            ja = Infinity;\n            ma = n.loadFromEndpoint(\"WebEgoPane\", ca.id, {\n                pid: 33,\n                data: [da,false,(\"timeline_\" + mb),(na ? t : ka),++z,]\n            }, {\n                crossPage: true,\n                bundle: false\n            });\n        },\n        registerScrubber: function(mb) {\n            j.conditionClass(mb.getRoot(), \"fixed_elem\", !na);\n            xa();\n            if (na) {\n                ib(mb.getRoot(), mb.getOffset());\n            };\n            (!ma && lb.adjustAdsToFit());\n        },\n        loadAdsIfEnoughTimePassed: function() {\n            if (((((((Date.now() - ja) >= y)) && !j.hasClass(document.documentElement, \"tinyViewport\")) && ((!ia || ia.isFixed()))) && ((!pa || !pa[fa[0]])))) {\n                lb.loadAds(ga);\n            };\n            lb.adjustAdsToFit();\n        },\n        adjustAdsType: function(mb) {\n            if ((mb != ha)) {\n                j.conditionClass(ca, \"-cx-PRIVATE-fbTimelineStyleAds__vertical\", !mb);\n                (oa && j.conditionClass(oa, \"-cx-PRIVATE-fbTimelineStyleAds__vertical\", !mb));\n                ha = mb;\n                gb();\n                lb.adjustAdsToFit();\n                var nb = r(\"timeline_side_friends\");\n                if (nb) {\n                    j.conditionClass(nb, \"fbTimelineVerticalSideFriends\", !mb);\n                };\n                var ob = r(\"rightColContent\");\n                if (ob) {\n                    j.conditionClass(ob, \"fbTimelineWideRightCol\", mb);\n                };\n            }\n        ;\n        },\n        adjustAdsToFit: function() {\n            if ((!ca || ra)) {\n                return\n            };\n            ra = true;\n            var mb = (ha ? t : s);\n            if (na) {\n                if ((ia && oa)) {\n                    ia.handleScroll();\n                    if (ia.isFixed()) {\n                        j.conditionShow(oa, ((eb(0) <= za(1)) && !j.hasClass(document.documentElement, \"tinyViewport\")));\n                    }\n                     else ab(mb);\n                ;\n                    cb();\n                }\n            ;\n            }\n             else {\n                var nb = za(mb);\n                if ((typeof nb !== \"undefined\")) {\n                    ab(db(nb));\n                    if (!la) {\n                        cb();\n                    };\n                }\n            ;\n            }\n        ;\n            ra = false;\n        },\n        reset: function() {\n            (ia && ia.stop());\n            (ma && ma.cancel());\n            fa = [];\n            ha = false;\n            ca = null;\n            ia = null;\n            ma = null;\n            z = 0;\n            la = null;\n            na = null;\n            oa = null;\n            ga = null;\n            ja = Infinity;\n            aa = false;\n            (qa && g.unsubscribe(qa));\n            qa = null;\n            sa.forEach(function(mb) {\n                mb.remove();\n            });\n            sa = [];\n            (ta && ta.reset());\n        }\n    };\n    e.exports = (a.TimelineSideAds || lb);\n});\n__d(\"TimelineStar\", [\"event-extensions\",\"Button\",\"CSS\",\"DOM\",\"Parent\",\"TimelineCapsule\",\"Tooltip\",\"URI\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Button\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"Parent\"), k = b(\"TimelineCapsule\"), l = b(\"Tooltip\"), m = b(\"URI\"), n = {\n        STAR_CSS_ONLY: 1,\n        STAR_ASYNC_REQUIRED: 2,\n        ACTION_STAR: 7,\n        ACTION_UNSTAR: 8,\n        starUnitFromButton: function(o, p, q) {\n            var r = j.byClass(o, \"timelineUnitContainer\");\n            n.starUnit(r, p, q);\n        },\n        starUnit: function(o, p, q) {\n            var r = o.parentNode;\n            if (!q) {\n                i.setContent(r, p);\n            };\n            h.removeClass(r, \"fbTimelineTwoColumn\");\n            h.addClass(r, \"fbTimelineOneColumn\");\n            r.removeAttribute(\"data-side\");\n            r.setAttribute(\"data-size\", \"2\");\n            l.hide();\n            k.balanceCapsule.curry(r.parentNode).defer();\n        },\n        unstarUnitFromButton: function(o, p, q) {\n            var r = j.byClass(o, \"timelineUnitContainer\");\n            n.unstarUnit(r, p, q);\n        },\n        unstarUnit: function(o, p, q) {\n            var r = o.parentNode;\n            if (!q) {\n                i.setContent(r, p);\n            };\n            h.removeClass(r, \"fbTimelineOneColumn\");\n            h.addClass(r, \"fbTimelineTwoColumn\");\n            r.setAttribute(\"data-side\", \"l\");\n            r.setAttribute(\"data-size\", \"1\");\n            l.hide();\n            k.balanceCapsule.curry(r.parentNode).defer();\n        },\n        listenToButton: function(o, p) {\n            if (!o) {\n                return\n            };\n            switch (p) {\n              case n.STAR_CSS_ONLY:\n                Event.listen(o, \"click\", function(event) {\n                    g.setEnabled.curry(o, false).defer();\n                    var r = j.byClass(o, \"timelineUnitContainer\"), s = n.unstarUnit;\n                    h.toggleClass(o, \"fbTimelineStarButtonSelected\");\n                    h.toggleClass(o, \"selected\");\n                    if ((r.parentNode.getAttribute(\"data-size\") == \"1\")) {\n                        s = n.starUnit;\n                    };\n                    s(r, null, true);\n                    var t = new m(o.getAttribute(\"ajaxify\")), u = ((t.getQueryData().customize_action == n.ACTION_STAR) ? n.ACTION_UNSTAR : n.ACTION_STAR);\n                    t.addQueryData({\n                        customize_action: u\n                    });\n                    o.setAttribute.bind(o, \"ajaxify\", t).defer();\n                });\n                var q = j.byClass(o, \"stat_elem\");\n                (q && h.removeClass(q, \"stat_elem\"));\n                break;\n              case n.STAR_ASYNC_REQUIRED:\n                break;\n            };\n        }\n    };\n    e.exports = n;\n});\n__d(\"TimelineStickyHeader\", [\"Arbiter\",\"CSS\",\"DOM\",\"TimelineController\",\"ViewportBounds\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"TimelineController\"), k = b(\"ViewportBounds\"), l = false, m = false, n, o, p, q, r = {\n        VISIBLE: \"TimelineStickyHeader/visible\",\n        ADJUST_WIDTH: \"TimelineStickyHeader/adjustWidth\",\n        init: function(s) {\n            if (l) {\n                return\n            };\n            l = true;\n            n = s;\n            o = i.find(s, \"div.name\");\n            p = i.find(s, \"div.actions\");\n            m = h.hasClass(s, \"fbTimelineStickyHeaderVisible\");\n            q = k.addTop(function() {\n                return (m ? (s.offsetTop + s.scrollHeight) : 0);\n            });\n            j.register(j.STICKY_HEADER, r);\n        },\n        reset: function() {\n            l = false;\n            m = false;\n            n = null;\n            o = null;\n            p = null;\n            q.remove();\n            q = null;\n        },\n        toggle: function(s) {\n            h.conditionClass(n, \"fbTimelineStickyHeaderHidden\", !s);\n            if ((s !== m)) {\n                m = s;\n                g.inform(r.VISIBLE, s);\n            }\n        ;\n        },\n        adjustWidth: function() {\n            g.inform(r.ADJUST_WIDTH, o, g.BEHAVIOR_STATE);\n        },\n        getRoot: function() {\n            return n;\n        },\n        setActions: function(s) {\n            if ((l && s)) {\n                i.setContent(p, s);\n                p = s;\n            }\n        ;\n        }\n    };\n    e.exports = (a.TimelineStickyHeader || r);\n});\n__d(\"TimelineStickyHeaderComposer\", [\"event-extensions\",\"Arbiter\",\"Bootloader\",\"Composer\",\"CSS\",\"DOMQuery\",\"Parent\",\"Run\",\"TimelineComposerUtilities\",\"TimelineContentLoader\",\"TimelineStickyHeader\",\"Vector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"Bootloader\"), i = b(\"Composer\"), j = b(\"CSS\"), k = b(\"DOMQuery\"), l = b(\"Parent\"), m = b(\"Run\"), n = b(\"TimelineComposerUtilities\"), o = b(\"TimelineContentLoader\"), p = b(\"TimelineStickyHeader\"), q = b(\"Vector\"), r = b(\"copyProperties\");\n    function s(t) {\n        this._container = l.byClass(t, \"fbTimelineStickyHeaderComposer\");\n        var u = (\"xhpc/construct/\" + t.id);\n        this._tokens = [];\n        g.subscribe(u, function(v, w) {\n            this._composer = w;\n            this._tokens = [n.listenToPublish(this._composer, this._close.bind(this)),n.listenToAnotherComposerOpen(this._composer, this._close.bind(this)),n.listenToSetEstimatedDate(this._composer, o.capsuleForCurrentSection),g.subscribe(\"PhotoSnowlift.OPEN\", this._close.bind(this)),g.subscribe(\"TimelineMLE/mleFlyoutShown\", function(x, y) {\n                if ((i.getInstance(y.getContext()) === this._composer)) {\n                    this._closeComposerAttachment();\n                }\n                 else this._close();\n            ;\n            }.bind(this)),g.subscribe(\"TimelineMLE/mleFlyoutHidden\", function(x, y) {\n                if (((y.context && !y.new_flyout) && (i.getInstance(y.context) === this._composer))) {\n                    this._close();\n                };\n            }.bind(this)),this._composer.subscribeToMutate(this._closeMLE.bind(this)),this._composer.subscribeToMutate(this._registerClickToDismiss.bind(this)),g.subscribe(p.ADJUST_WIDTH, this._toggleNarrowMode.bind(this)),];\n        }.bind(this));\n        this._clickCancelToken = n.listenToCancel(t, this._close.bind(this));\n        m.onLeave(function() {\n            this._tokens.forEach(g.unsubscribe.bind(g));\n            this._tokens = [];\n            this._clickCancelToken.remove();\n            this._clickCancelToken = null;\n            this._clearClickDismissToken();\n        }.bind(this));\n    };\n    r(s.prototype, {\n        _toggleNarrowMode: function(event, t) {\n            h.loadModules([\"Tooltip\",], function(u) {\n                var v = (q.getElementDimensions(t).x > 400), w = k.scry(this._composer.root, \"a.attachmentLink\");\n                j.conditionClass(this._composer.root.parentNode, \"narrowStickyHeaderComposer\", v);\n                for (var x = 0; (x < w.length); x++) {\n                    var y = w[x], z = k.getText(y);\n                    if (v) {\n                        u.set(y, z);\n                    }\n                     else u.remove(y);\n                ;\n                };\n            }.bind(this));\n            return false;\n        },\n        _registerClickToDismiss: function() {\n            var t = k.find(this._composer.root, \"span.lifeEventAttachment\");\n            if (!j.hasClass(t, \"uiComposerAttachmentSelected\")) {\n                this._clearClickDismissToken();\n                return;\n            }\n        ;\n            this._clickDismissToken = Event.listen(document.body, \"click\", function(event) {\n                var u = event.getTarget();\n                if (!l.byClass(u, \"fbTimelineStickyHeaderComposer\")) {\n                    this._close();\n                    this._clearClickDismissToken();\n                }\n            ;\n            }.bind(this));\n        },\n        _clearClickDismissToken: function() {\n            if (this._clickDismissToken) {\n                this._clickDismissToken.remove();\n                this._clickDismissToken = null;\n            }\n        ;\n        },\n        _close: function() {\n            this._closeComposerAttachment();\n            this._closeMLE();\n        },\n        _closeComposerAttachment: function() {\n            this._clearClickDismissToken();\n            this._composer.reset();\n            j.removeClass(this._composer.root, \"uiComposerOpen\");\n        },\n        _closeMLE: function() {\n            h.loadModules([\"TimelineMLE\",], function(t) {\n                var u = t.getFlyout();\n                if ((u && (i.getInstance(u.getContext()) === this._composer))) {\n                    t.hideFlyout();\n                };\n            }.bind(this));\n        }\n    });\n    e.exports = s;\n});\n__d(\"TimelineStickyHeaderNav\", [\"array-extensions\",\"event-extensions\",\"function-extensions\",\"Arbiter\",\"ButtonGroup\",\"CSS\",\"DOM\",\"Parent\",\"Selector\",\"Style\",\"TimelineController\",\"URI\",\"UserAgent\",\"Vector\",\"ge\",\"tx\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ButtonGroup\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"Parent\"), l = b(\"Selector\"), m = b(\"Style\"), n = b(\"TimelineController\"), o = b(\"URI\"), p = b(\"UserAgent\"), q = b(\"Vector\"), r = b(\"ge\"), s = b(\"tx\"), t = false, u, v, w, x, y, z, aa, ba, ca, da, ea, fa = {\n    }, ga = {\n    }, ha = [], ia = false, ja = [], ka = [], la = [], ma = [], na = [], oa = [\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\",];\n    function pa(event) {\n        var eb = k.byTag(event.getTarget(), \"a\");\n        if (eb) {\n            n.navigateToSection(eb.getAttribute(\"data-key\"));\n            event.prevent();\n        }\n    ;\n    };\n    function qa(eb, fb) {\n        var gb = l.getValue(fb);\n        if ((gb === \"allStories\")) {\n            n.getSection(eb).expandSubSections();\n        };\n        if ((gb !== \"activityLog\")) {\n            ra(fb);\n        };\n    };\n    function ra(eb) {\n        bb(eb, \"highlights\");\n        bb(eb, \"allStories\");\n        var fb = j.find(eb, \"li.separator\");\n        i.conditionShow(fb, fb.previousSibling);\n    };\n    function sa(eb) {\n        if ((ca[eb] && !v.custom_subsection_menu)) {\n            ya(eb);\n        }\n         else va();\n    ;\n        n.adjustStickyHeaderWidth();\n    };\n    function ta(eb, fb) {\n        var gb = fb.key;\n        if (da[gb]) {\n            za(gb);\n            sa(gb);\n        }\n    ;\n    };\n    function ua(eb, fb) {\n        var gb = fb.scrubberKey;\n        za(gb);\n        if ((w === gb)) {\n            sa(gb);\n        };\n    };\n    function va() {\n        x.hideItem(aa);\n    };\n    function wa(eb) {\n        var fb = eb.split(\"_\");\n        return oa[(fb.pop() - 1)];\n    };\n    function xa(eb) {\n        var fb = ba[eb], gb = ca[eb];\n        if ((!fb && gb)) {\n            fb = ba[eb] = aa.cloneNode(true);\n            var hb = j.scry(fb, \"li.activityLog a\")[0];\n            if (hb) {\n                hb.href = o(hb.href).addQueryData({\n                    key: eb\n                });\n            };\n            var ib = n.getCurrentScrubber();\n            if (gb.length) {\n                i.show(j.find(fb, \"li.separator\"));\n            };\n            for (var jb = 0; (jb < gb.length); jb++) {\n                var kb = gb[jb].scrubberKey, lb = (ib ? ib.getLabelForSubnav(gb[jb].parentKey, kb) : lb = wa(kb));\n                if (lb) {\n                    ab(fb, {\n                        key: kb,\n                        label: lb\n                    });\n                };\n            };\n            if (cb()) {\n                ra(fb);\n                l.setSelected(fb, j.scry(fb, \"option\")[1].value, true);\n            }\n        ;\n            na.push(l.listen(fb, \"change\", qa.curry(eb, fb)));\n            la.push(Event.listen(fb, \"click\", pa));\n        }\n    ;\n        return fb;\n    };\n    function ya(eb) {\n        var fb = xa(eb);\n        j.insertAfter(aa, fb);\n        i.hide(aa);\n        for (var gb in ba) {\n            var hb = ba[gb];\n            i.conditionShow(hb, (hb === fb));\n        };\n        x.showItem(aa);\n    };\n    function za(eb) {\n        ca[eb] = n.getSection(eb).subSections;\n    };\n    function ab(eb, fb) {\n        var gb = j.create(\"a\", {\n            href: \"#\",\n            rel: \"ignore\",\n            className: \"itemAnchor\",\n            tabIndex: 0\n        }, j.create(\"span\", {\n            className: \"itemLabel fsm\"\n        }, fb.label));\n        gb.setAttribute(\"data-key\", fb.key);\n        gb.setAttribute(\"aria-checked\", false);\n        var hb = j.create(\"li\", {\n            className: \"uiMenuItem uiMenuItemRadio uiSelectorOption\"\n        }, gb);\n        hb.setAttribute(\"data-label\", fb.label);\n        var ib = j.find(eb, \"ul.uiMenuInner\"), jb = j.create(\"option\", {\n            value: fb.key\n        }, fb.label), kb = j.find(eb, \"select\");\n        if ((fb.key === \"recent\")) {\n            j.prependContent(ib, hb);\n            j.insertAfter(kb.options[0], jb);\n        }\n         else {\n            j.appendContent(ib, hb);\n            j.appendContent(kb, jb);\n        }\n    ;\n    };\n    function bb(eb, fb) {\n        var gb = j.scry(eb, \"li.uiMenuItem\");\n        if (!gb) {\n            return\n        };\n        for (var hb = 0; (hb < gb.length); hb++) {\n            var ib = gb[hb];\n            if ((i.hasClass(ib, fb) || (ib.firstChild.getAttribute(\"data-key\") == fb))) {\n                j.remove(ib);\n                break;\n            }\n        ;\n        };\n        var jb = j.find(eb, \"select\"), kb = j.scry(jb, \"option\");\n        for (hb = 0; (hb < kb.length); hb++) {\n            if ((kb[hb].value === fb)) {\n                j.remove(kb[hb]);\n                return;\n            }\n        ;\n        };\n    };\n    function cb() {\n        return ((n.getCurrentKey() === \"allactivity\") || (n.getCurrentKey() === \"approve\"));\n    };\n    var db = {\n        init: function(eb, fb) {\n            if (t) {\n                return\n            };\n            t = true;\n            u = eb;\n            v = (fb || {\n            });\n            y = j.find(u, \"div.pageMenu\");\n            z = j.find(u, \"div.sectionMenu\");\n            aa = j.find(u, \"div.subsectionMenu\");\n            ea = j.find(y, \"li.uiMenuSeparator\");\n            x = h.getInstance(y);\n            ba = {\n            };\n            ca = {\n            };\n            da = {\n            };\n            db.adjustMenuHeights();\n            n.register(n.STICKY_HEADER_NAV, db);\n            if (r(\"pagelet_timeline_friends\")) {\n                db.addTimePeriods(n.getSectionKeys());\n            };\n            ka.forEach(function(gb) {\n                gb();\n            });\n        },\n        reset: function() {\n            t = false;\n            v = {\n            };\n            ha = [];\n            fa = {\n            };\n            ga = {\n            };\n            ia = false;\n            ja = [];\n            u = null;\n            y = null;\n            z = null;\n            aa = null;\n            ea = null;\n            ba = {\n            };\n            ca = {\n            };\n            da = {\n            };\n            while (la.length) {\n                la.pop().remove();;\n            };\n            ma.forEach(g.unsubscribe);\n            na.forEach(l.unsubscribe.bind(l));\n        },\n        addTimePeriods: function(eb) {\n            if (!eb.length) {\n                return\n            };\n            if (v.pull_from_scrubber) {\n                j.setContent(j.find(z, \"ul.uiMenuInner\"), \"\");\n                j.remove(j.find(z, \"select\").children[1]);\n                while (eb.length) {\n                    var fb = eb.shift();\n                    (fb && db.addTimePeriod(fb));\n                };\n                x.showItem(z);\n            }\n        ;\n            var gb = l.getSelectorMenu(z);\n            la.push(Event.listen(gb, \"click\", pa));\n            var hb = (cb() ? n.SECTION_REGISTERED : n.SECTION_LOADED), ib = (cb() ? ua : ta);\n            ma.push(g.subscribe(hb, ib));\n        },\n        addTimePeriod: function(eb) {\n            var fb = n.getCurrentScrubber();\n            if (!fb) {\n                return\n            };\n            var gb = fb.getLabelForNav(eb);\n            if (!gb) {\n                return\n            };\n            ab(z, {\n                key: eb,\n                label: gb\n            });\n            var hb = j.find(z, \"ul.uiMenuInner\");\n            if (((eb === \"recent\") || (hb.children.length < 2))) {\n                l.setSelected(z, eb, true);\n            };\n        },\n        updateSection: function(eb, fb) {\n            if (fb) {\n                var gb = xa(eb);\n                if (gb) {\n                    l.setSelected(gb, fb);\n                    ra(gb);\n                }\n                 else w = eb;\n            ;\n            }\n             else {\n                da[eb] = true;\n                za(eb);\n            }\n        ;\n            l.setSelected(z, eb, true);\n            sa(eb);\n        },\n        adjustMenuHeights: function() {\n            if ((p.ie() <= 7)) {\n                return\n            };\n            [y,z,].forEach(function(eb) {\n                var fb = \"\";\n                if (!i.hasClass(document.documentElement, \"tinyViewport\")) {\n                    fb = ((q.getViewportDimensions().y - q.getElementDimensions(r(\"blueBar\")).y) - 80);\n                    fb += \"px\";\n                }\n            ;\n                m.set(j.find(eb, \"ul.uiMenuInner\"), \"maxHeight\", fb);\n            });\n        },\n        initPageMenu: function(eb, fb) {\n            if (!t) {\n                ka.push(db.initPageMenu.curry(eb, fb));\n                return;\n            }\n        ;\n            function gb(hb, ib) {\n                hb.forEach(function(jb) {\n                    var kb = ga[jb] = j.create(\"li\");\n                    i.hide(kb);\n                    (ib ? j.insertBefore(ea, kb) : j.appendContent(j.find(y, \"ul.uiMenuInner\"), kb));\n                });\n            };\n            gb(eb, true);\n            gb(fb, false);\n            fa.info = j.scry(y, \"li\")[0];\n            ha = fb;\n            ia = true;\n            if (ja.length) {\n                ja.forEach(function(hb) {\n                    db.registerPageMenuItem(hb.key, hb.item);\n                });\n            };\n        },\n        registerPageMenuItem: function(eb, fb) {\n            if (!ia) {\n                ja.push({\n                    key: eb,\n                    item: fb\n                });\n                return;\n            }\n        ;\n            if (ga[eb]) {\n                j.replace(ga[eb], fb);\n                fa[eb] = fb;\n                delete ga[eb];\n                if ((ha.indexOf(eb) >= 0)) {\n                    i.show(ea);\n                };\n            }\n        ;\n        },\n        removeTimePeriod: function(eb) {\n            bb(z, eb);\n        }\n    };\n    e.exports = db;\n});\n__d(\"TimelineViewportTracking\", [\"event-extensions\",\"Class\",\"DOM\",\"ViewportTracking\",\"$\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Class\"), h = b(\"DOM\"), i = b(\"ViewportTracking\"), j = b(\"$\"), k = b(\"copyProperties\"), l = 55;\n    function m() {\n        this.parent.construct(this);\n    };\n    g.extend(m, i);\n    k(m.prototype, {\n        getDataFromConfig: function(n) {\n            this.timeout = n.record_delay;\n        },\n        getTimeout: function() {\n            return this.timeout;\n        },\n        getAllStories: function() {\n            return h.scry(j(\"timeline_tab_content\"), \".timelineUnitContainer\");\n        },\n        getStoryID: function(n) {\n            var o = JSON.parse(n.getAttribute(\"data-gt\"));\n            return (o && o.contentid);\n        },\n        getDataToLog: function(n) {\n            var o = {\n                evt: l,\n                timelineviewporttracking: true\n            };\n            return {\n                gt: o\n            };\n        }\n    });\n    e.exports.init = function(n) {\n        (new m()).init(n);\n    };\n});\n__d(\"TimelineScrubber\", [\"event-extensions\",\"CSS\",\"DOM\",\"Parent\",\"TimelineController\",\"Vector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"Parent\"), j = b(\"TimelineController\"), k = b(\"Vector\"), l = b(\"copyProperties\");\n    function m(n) {\n        this._root = n;\n        this._navKeys = {\n        };\n        this._subNavKeys = {\n        };\n        this._rollups = {\n        };\n        this._rolledup = {\n        };\n        var o = n.childNodes;\n        this._currentNav = o[0];\n        for (var p = 0; (p < o.length); p++) {\n            var q = o[p].getAttribute(\"data-key\");\n            this._navKeys[q] = o[p];\n            var r = h.scry(o[p], \"ul\");\n            this._subNavKeys[q] = {\n            };\n            if (r.length) {\n                var s = r[0].childNodes;\n                for (var t = 0; (t < s.length); t++) {\n                    this._subNavKeys[q][s[t].getAttribute(\"data-key\")] = s[t];;\n                };\n            }\n        ;\n            var u = o[p].getAttribute(\"data-rollup\");\n            if (u) {\n                this._rollups[u] = (this._rollups[u] || []);\n                this._rollups[u].push(o[p]);\n            }\n        ;\n        };\n        this._clickListener = Event.listen(this._root, \"click\", this._handleScrub.bind(this));\n        g.show(this._root);\n        var v = (k.getViewportDimensions().y - this.SCRUBBER_NO_ADS_VERTICAL_BUFFER), w = this.getHeight();\n        if ((w > v)) {\n            this.fold((w - v));\n        };\n        j.register(j.SCRUBBER, this);\n        j.scrubberHasLoaded(this);\n    };\n    l(m.prototype, {\n        KEY_HEIGHT: 23,\n        SUBKEY_HEIGHT: 16,\n        OFFSET: 38,\n        SCRUBBER_NO_ADS_VERTICAL_BUFFER: 125,\n        reset: function() {\n            this._root = null;\n            this._navKeys = {\n            };\n            this._subNavKeys = {\n            };\n            this._rollups = {\n            };\n            this._rolledup = {\n            };\n        },\n        getRoot: function() {\n            return this._root;\n        },\n        getNav: function(n) {\n            return this._navKeys[n];\n        },\n        getSubnav: function(n, o) {\n            return this._subNavKeys[n][o];\n        },\n        getHeight: function() {\n            return this._root.offsetHeight;\n        },\n        getLabelForNav: function(n) {\n            var o = this.getNav(n);\n            return (o && h.getText(h.scry(o, \"a\")[0]));\n        },\n        getLabelForSubnav: function(n, o) {\n            var p = this.getSubnav(n, o);\n            return (p && h.getText(h.scry(p, \"a\")[0]));\n        },\n        fold: function(n) {\n            return this._adjustFolding(n, true);\n        },\n        unfold: function(n) {\n            return this._adjustFolding(n, false);\n        },\n        getOffset: function() {\n            return ((this.OFFSET + ((g.hasClass(document.body, \"hasVoiceBar\") ? 26 : 0))) + ((g.hasClass(\"rightColContent\", \"pagesTimelineRightColumn\") ? 34 : 0)));\n        },\n        updateSection: function(n, o) {\n            var p = this._navKeys[n].getAttribute(\"data-rollup\");\n            if ((this._currentRollup && (this._currentRollup != p))) {\n                g.removeClass(this._currentRollup, \"selected\");\n                g.removeClass(h.scry(this._currentRollup, \"ul\")[0], \"loaded\");\n                delete this._currentRollup;\n            }\n        ;\n            if ((p && this._rolledup[p])) {\n                var q = this._rolledup[p];\n                if (q.getAttribute(\"data-rollup\")) {\n                    this._currentRollup = q;\n                    g.addClass(this._currentRollup, \"selected\");\n                    g.addClass(h.scry(this._currentRollup, \"ul\")[0], \"loaded\");\n                }\n            ;\n            }\n        ;\n            (this._currentNav && g.removeClass(this._currentNav, \"selected\"));\n            (this._currentSubNav && g.removeClass(this._currentSubNav, \"selected\"));\n            this._currentNav = null;\n            this._currentSubNav = null;\n            if (this._navKeys[n]) {\n                this._currentNav = this._navKeys[n];\n                g.addClass(this._currentNav, \"selected\");\n                if ((this.decadesAreSelectable && this._navKeys[o])) {\n                    this._currentSubNav = this._navKeys[o];\n                    g.addClass(this._currentSubNav, \"selected\");\n                }\n                 else if ((o && this._subNavKeys[n][o])) {\n                    this._currentSubNav = this._subNavKeys[n][o];\n                    g.addClass(this._currentSubNav, \"selected\");\n                }\n                \n            ;\n            }\n        ;\n        },\n        _getRollupSize: function(n) {\n            var o = this._currentNav, p = (o && o.getAttribute(\"data-rollup\")), q = (this.KEY_HEIGHT * ((this._rollups[n].length - 1)));\n            if ((n == p)) {\n                q += (this.SUBKEY_HEIGHT * h.scry(o, \"li\").length);\n                q -= (this.SUBKEY_HEIGHT * ((this._rollups[n].length - 1)));\n            }\n        ;\n            return q;\n        },\n        _adjustFolding: function(n, o) {\n            var p = n, q = Object.keys(this._rollups);\n            while (((n > 0) && q.length)) {\n                var r = q[(o ? \"pop\" : \"shift\")]();\n                if ((!o == !this._rolledup[r])) {\n                    continue;\n                };\n                var s = this._getRollupSize(r);\n                if ((s <= 0)) {\n                    continue;\n                };\n                if ((!o && (s > n))) {\n                    break;\n                };\n                this[(o ? \"_collapseRollup\" : \"_expandRollup\")](r);\n                n -= s;\n            };\n            return (p - n);\n        },\n        _collapseRollup: function(n) {\n            var o = this._rollups[n];\n            if (((!o || (o.length < 2)) || this._rolledup[n])) {\n                return\n            };\n            var p = o[0].previousSibling, q = o[0], r = h.create(\"a\", {\n                href: q.firstChild.href,\n                rel: \"ignore\"\n            }, [n,]), s = h.create(\"ul\", {\n                className: \"clearfix\"\n            });\n            for (var t = 0; (t < o.length); t++) {\n                s.appendChild(o[t]);;\n            };\n            var u = h.create(\"li\", null, [r,s,]);\n            if (this.decadesAreSelectable) {\n                var v = o[(o.length - 1)], w = (q.getAttribute(\"data-key\") + v.getAttribute(\"data-key\"));\n                u.setAttribute(\"data-start\", v.getAttribute(\"data-start\"));\n                u.setAttribute(\"data-end\", q.getAttribute(\"data-end\"));\n                u.setAttribute(\"data-key\", w);\n                this._navKeys[w] = u;\n            }\n             else u.setAttribute(\"data-key\", q.getAttribute(\"data-key\"));\n        ;\n            u.setAttribute(\"data-rollup\", n);\n            if (p) {\n                h.insertAfter(p, u);\n            }\n             else h.prependContent(this._root, u);\n        ;\n            this._rolledup[n] = u;\n            this._checkSelection();\n        },\n        _expandRollup: function(n) {\n            if (!this._rolledup[n]) {\n                return\n            };\n            var o = this._rolledup[n], p = h.scry(o, \"ul\")[0], q = document.createDocumentFragment();\n            while (p.childNodes.length) {\n                q.appendChild(p.firstChild);;\n            };\n            h.replace(o, q);\n            this._rolledup[n] = false;\n            this._checkSelection();\n        },\n        _checkSelection: function() {\n            if (this._currentNav) {\n                var n = (this._currentSubNav && this._currentSubNav.getAttribute(\"data-key\"));\n                this.updateSection(this._currentNav.getAttribute(\"data-key\"), n);\n            }\n        ;\n        },\n        _handleScrub: function(event) {\n            var n = event.getModifiers();\n            if (((event.isMiddleClick() || n.access) || n.meta)) {\n                return true\n            };\n            var o = i.byTag(event.getTarget(), \"a\"), p = (o && i.byAttribute(o, \"data-key\"));\n            if (p) {\n                j.scrubberWasClicked(p.getAttribute(\"data-key\"));\n                j.navigateToSection(p.getAttribute(\"data-key\"));\n                return event.prevent();\n            }\n        ;\n        }\n    });\n    e.exports = m;\n});\n__d(\"TimelineMainScrubber\", [\"Arbiter\",\"Class\",\"CSS\",\"DOMQuery\",\"TimelineController\",\"TimelineScrubber\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"Class\"), i = b(\"CSS\"), j = b(\"DOMQuery\"), k = b(\"TimelineController\"), l = b(\"TimelineScrubber\"), m = b(\"copyProperties\");\n    function n(o) {\n        this.parent.construct(this, o);\n        this._subscribe = g.subscribe(k.SECTION_LOADED, function(p, q) {\n            var r = this._navKeys[q.key], s = (r && j.scry(r, \"ul\")[0]);\n            if (s) {\n                i.addClass(s, \"loaded\");\n                k.scrubberHasChangedState();\n                if (q.hideSubSections) {\n                    i.hide(s);\n                };\n            }\n        ;\n        }.bind(this));\n    };\n    h.extend(n, l);\n    m(n.prototype, {\n        reset: function() {\n            this.parent.reset();\n            (this._subscribe && this._subscribe.unsubscribe());\n        }\n    });\n    e.exports = n;\n});\n__d(\"profile-pic-dragdrop-edit\", [\"Arbiter\",\"SinglePictureUploadTarget\",\"TimelineProfilePic\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"SinglePictureUploadTarget\"), i = b(\"TimelineProfilePic\");\n    f.initialize_profile_pic_drop_target = function(j, k, l, m) {\n        new i(l, m);\n        new h(j, k).setPreprocessCallback(function(n) {\n            g.inform(l.LOADING, {\n                isLoading: 1\n            }, g.BEHAVIOR_STATE);\n        }).setOncompleteCallback(function() {\n            g.inform(l.LOADING, {\n                isLoading: 0\n            }, g.BEHAVIOR_STATE);\n        }).setAfterSuccessCallback(function(n) {\n            g.inform(l.SUCCESS, {\n                newPic: n.photo_html\n            }, g.BEHAVIOR_STATE);\n        }).activate();\n    };\n});\n__d(\"legacy:TimelineCover\", [\"TimelineCover\",], function(a, b, c, d) {\n    a.TimelineCover = b(\"TimelineCover\");\n}, 3);\n__d(\"OnlyMeUI\", [\"AudienceSelector\",\"Arbiter\",\"CSS\",\"DOM\",\"Parent\",\"PrivacyConst\",\"Selector\",\"$\",\"tx\",], function(a, b, c, d, e, f) {\n    var g = b(\"AudienceSelector\"), h = b(\"Arbiter\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"Parent\"), l = b(\"PrivacyConst\"), m = b(\"Selector\"), n = b(\"$\"), o = b(\"tx\");\n    function p() {\n        return [j.create(\"div\", {\n            className: \"onlyMeBorder\"\n        }),j.create(\"div\", {\n            className: \"onlyMeBorder onlyMeBorderBottom\"\n        }),];\n    };\n    function q() {\n        return j.create(\"img\", {\n            alt: \" \",\n            className: \"onlyMePrivacyCorner\",\n            height: 34,\n            src: \"/images/profile/timeline/privacy_corner.png\",\n            width: 34\n        });\n    };\n    function r(x) {\n        var y = j.scry(x, \".photoUnit a.photo\");\n        return y.filter(function(z) {\n            return !j.scry(z, \".onlyMePrivacyCorner\").length;\n        });\n    };\n    function s(x, y) {\n        if (g.hasTags(u(y))) {\n            return\n        };\n        i.addClass(x, \"storyOnlyMe\");\n        if (!i.hasClass(x, \"timelineRecentActivityStory\")) {\n            j.setContent(j.find(y, \"span.uiButtonText\"), \"Only Me\");\n        };\n        if (!i.hasClass(x, \"storyContent\")) {\n            var z = r(x);\n            for (var aa = 0, ba = z.length; (aa < ba); ++aa) {\n                j.appendContent(z[aa], q());;\n            };\n        }\n    ;\n        if (!j.scry(x, \"div.onlyMeBorder\").length) {\n            var ca = p();\n            j.prependContent(x, ca[0]);\n            j.appendContent(x, ca[1]);\n        }\n    ;\n    };\n    function t(x) {\n        if (!x) {\n            return\n        };\n        var y = (((k.byClass(x, \"storyContent\") || k.byClass(x, \"timelineRecentActivityStory\")) || k.byClass(x, \"timelineUnitContainer\")) || k.byClass(x, \"fbTimelineTwoColumn\"));\n        if (!y) {\n            y = j.scry(x, \"^.permalink_stream .storyContent\");\n            y = (y.length && y[0]);\n        }\n         else if (i.hasClass(y, \"fbTimelineComposerUnit\")) {\n            return null\n        }\n    ;\n        return y;\n    };\n    function u(x) {\n        var y = j.scry(x, \"*[data-oid]\");\n        if ((y.length === 0)) {\n            return \"\"\n        };\n        return y[0].getAttribute(\"data-oid\");\n    };\n    var v = false, w = {\n        init: function() {\n            if (v) {\n                return\n            };\n            v = true;\n            h.subscribe(\"AudienceSelector/changed\", function(x, y) {\n                var z = (t(y.selector) || t(y.clone));\n                if (!z) {\n                    return\n                };\n                if ((m.getOptionValue(y.option) == l.BaseValue.SELF)) {\n                    s(z, y.selector);\n                }\n                 else i.removeClass(z, \"storyOnlyMe\");\n            ;\n            });\n        },\n        setOnlyMe: function(x) {\n            if (v) {\n                return\n            };\n            w.init();\n            x = j.find(k.byClass(n(x), \"uiSelector\"), \"a.uiSelectorButton\");\n            var y = t(x);\n            (y && s(y, x));\n        }\n    };\n    e.exports = w;\n});\nfunction StreamProfileComposer() {\n\n};\ncopyProperties(StreamProfileComposer.prototype, {\n    init: function(a) {\n        var b = $(a);\n        Arbiter.subscribe(\"composer/publish\", function(event, c) {\n            if (c.streamStory) {\n                animation.prependInsert(b, c.streamStory);\n            };\n        });\n    }\n});\n__d(\"SwapButton\", [\"event-extensions\",\"copyProperties\",\"CSS\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"copyProperties\"), h = b(\"CSS\");\n    function i(j, k, l) {\n        this._swapperButton = j;\n        this._swappeeButton = k;\n        Event.listen(j, \"click\", this.swap.bind(this));\n        if (l) {\n            Event.listen(k, \"click\", this.unswap.bind(this));\n        };\n    };\n    g(i.prototype, {\n        _swapperButton: null,\n        _swappeeButton: null,\n        swap: function() {\n            h.hide(this._swapperButton);\n            h.show(this._swappeeButton);\n        },\n        unswap: function() {\n            h.show(this._swapperButton);\n            h.hide(this._swappeeButton);\n        },\n        toggle: function() {\n            h.toggle(this._swapperButton);\n            h.toggle(this._swappeeButton);\n        }\n    });\n    e.exports = i;\n});\n__d(\"CountButtonCount\", [\"ArbiterMixin\",\"copyProperties\",\"DOM\",], function(a, b, c, d, e, f) {\n    var g = b(\"ArbiterMixin\"), h = b(\"copyProperties\"), i = b(\"DOM\");\n    function j(k, l, m) {\n        this._root = k;\n        this._count = l;\n        this._max = m;\n    };\n    h(j.prototype, g, {\n        getCount: function() {\n            return this._count;\n        },\n        setCount: function(k) {\n            this._count = k;\n            var l = this.getDisplayedValue();\n            i.setContent(this._root, l);\n            this.inform(\"change\", {\n                value: this._count,\n                display: l\n            });\n            return this;\n        },\n        addCount: function(k) {\n            this.setCount((this.getCount() + k));\n            return this;\n        },\n        getDisplayedValue: function() {\n            return Math.max(0, Math.min(this._count, this._max));\n        }\n    });\n    e.exports = j;\n});\n__d(\"CountButton\", [\"copyProperties\",\"CSS\",\"cx\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\"), h = b(\"CSS\"), i = b(\"cx\"), j = {\n        large: \"-cx-PRIVATE-uiCountButton__counterLarge\",\n        small: \"-cx-PRIVATE-uiCountButton__counterSmall\",\n        hidden: \"-cx-PRIVATE-uiCountButton__counterHidden\"\n    };\n    function k(l, m) {\n        this._root = l;\n        this._counter = m;\n        this._initEvents();\n    };\n    g(k.prototype, {\n        _initEvents: function() {\n            this._counter.subscribe(\"change\", this._counterChange.bind(this));\n        },\n        _counterChange: function(l, m) {\n            h.removeClass(this._root, j.large);\n            h.removeClass(this._root, j.small);\n            h.removeClass(this._root, j.hidden);\n            if ((m.value > 9)) {\n                h.addClass(this._root, j.large);\n            }\n             else if ((m.value > 0)) {\n                h.addClass(this._root, j.small);\n            }\n             else h.addClass(this._root, j.hidden);\n            \n        ;\n        },\n        getCounter: function() {\n            return this._counter;\n        }\n    });\n    e.exports = k;\n});\n__d(\"HoverButton\", [\"AsyncRequest\",\"CSS\",\"DOM\",\"URI\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncRequest\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"URI\"), k = b(\"copyProperties\");\n    function l(m, n, o, p) {\n        this._button = m;\n        this._flyout = n;\n        this._flyoutAjaxify = p;\n        this._flyoutContent = o;\n        n.subscribe(\"show\", this._onShow.bind(this));\n        n.subscribe(\"hide\", this._onHide.bind(this));\n    };\n    k(l.prototype, {\n        _button: null,\n        _flyout: null,\n        _flyoutAjaxify: null,\n        _flyoutContent: null,\n        showFlyoutBriefly: function() {\n            this.showFlyout();\n            this._flyout.hideFlyoutDelayed(5000);\n        },\n        showFlyout: function() {\n            this._flyout.showFlyout(this._button, true);\n            this._flyout.inform(\"show\", this._button);\n        },\n        hideFlyout: function() {\n            this._flyout.hideFlyout(true);\n            this._flyout.inform(\"hide\", this._button);\n        },\n        _onShow: function(m, n) {\n            h.addClass(n, \"uiHoverButtonSelected\");\n            h.addClass(n, \"selected\");\n            if (this._flyoutAjaxify) {\n                h.addClass(this._flyoutContent, \"async_saving\");\n                new g().setURI(new j(this._flyoutAjaxify)).setHandler(function(o) {\n                    h.removeClass(this._flyoutContent, \"async_saving\");\n                    i.setContent(this._flyoutContent, o.payload);\n                }.bind(this)).send();\n                this._flyoutAjaxify = null;\n            }\n        ;\n        },\n        _onHide: function(m, n) {\n            h.removeClass(n, \"uiHoverButtonSelected\");\n            h.removeClass(n, \"selected\");\n        },\n        destroy: function() {\n            this.hideFlyout();\n            this._flyout.destroy();\n        }\n    });\n    e.exports = l;\n});\n__d(\"legacy:TooltipLink\", [\"TooltipLink\",], function(a, b, c, d) {\n    a.TooltipLink = b(\"TooltipLink\");\n}, 3);\n__d(\"HoverFlyout\", [\"event-extensions\",\"ArbiterMixin\",\"Class\",\"DataStore\",\"LayerDestroyOnHide\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"Class\"), i = b(\"DataStore\"), j = b(\"LayerDestroyOnHide\"), k = b(\"copyProperties\");\n    function l(m, n, o, p) {\n        if (m) {\n            this._showDelay = o;\n            this._hideDelay = p;\n            this.init(m);\n            if (n) {\n                this.initNode(n);\n            };\n        }\n    ;\n    };\n    k(l.prototype, g, {\n        init: function(m) {\n            this._flyout = m;\n            this._showDelay = (this._showDelay || 0);\n            this._hideDelay = (this._hideDelay || 100);\n            this._showTimeout = null;\n            this._hideTimeout = null;\n            this._flyoutSubscriptions = [this._flyout.subscribe(\"mouseenter\", this._onFlyoutMouseEnter.bind(this)),this._flyout.subscribe(\"mouseleave\", this.hideFlyout.shield(this)),];\n            this._nodes = [];\n            this._dataStoreUnique = ((\"HoverFlyout_\" + Date.now()) + \"_listeners\");\n            this._flyout.disableBehavior(j);\n            return this;\n        },\n        initNode: function(m) {\n            if (this._nodes.contains(m)) {\n                return this\n            };\n            this._nodes.push(m);\n            i.set(m, this._dataStoreUnique, [Event.listen(m, \"mouseenter\", this._onNodeMouseEnter.bind(this, m)),Event.listen(m, \"mouseleave\", this.hideFlyout.shield(this)),]);\n            return this;\n        },\n        deactivateNode: function(m) {\n            var n = i.get(m, this._dataStoreUnique);\n            if (n) {\n                while (n.length) {\n                    n.pop().remove();;\n                }\n            };\n            this._nodes.remove(m);\n        },\n        setShowDelay: function(m) {\n            this._showDelay = m;\n            return this;\n        },\n        setHideDelay: function(m) {\n            this._hideDelay = m;\n            return this;\n        },\n        showFlyout: function(m, n) {\n            this.setActiveNode(m);\n            if (n) {\n                this._flyout.setContext(m).show();\n                this.inform(\"show\", m);\n            }\n             else this._showTimeout = this.showFlyout.bind(this, m, true).defer(this._showDelay);\n        ;\n            return this;\n        },\n        hideFlyout: function(m) {\n            clearTimeout(this._showTimeout);\n            if (m) {\n                this._flyout.hide();\n                (this._activeNode && this.inform(\"hide\", this._activeNode));\n                this._activeNode = null;\n            }\n             else this._hideTimeout = this.hideFlyout.bind(this, true).defer(this._hideDelay);\n        ;\n        },\n        hideFlyoutDelayed: function(m) {\n            clearTimeout(this._showTimeout);\n            clearTimeout(this._hideTimeout);\n            this._hideTimeout = this.hideFlyout.bind(this, true).defer(m);\n        },\n        getActiveNode: function() {\n            return this._activeNode;\n        },\n        setActiveNode: function(m) {\n            clearTimeout(this._hideTimeout);\n            if ((this._activeNode && (this._activeNode !== m))) {\n                this.hideFlyout(true);\n            };\n            this._activeNode = m;\n            return this;\n        },\n        clearNodes: function() {\n            for (var m = this._nodes.length; (m > 0); m--) {\n                this.deactivateNode(this._nodes[(m - 1)]);;\n            };\n        },\n        destroy: function() {\n            while (this._flyoutSubscriptions.length) {\n                this._flyout.unsubscribe(this._flyoutSubscriptions.pop());;\n            };\n            this.clearNodes();\n        },\n        _onNodeMouseEnter: function(m) {\n            if ((this._activeNode === m)) {\n                clearTimeout(this._hideTimeout);\n            }\n             else this.showFlyout(m);\n        ;\n        },\n        _onFlyoutMouseEnter: function() {\n            clearTimeout(this._hideTimeout);\n        }\n    });\n    e.exports = (a.HoverFlyout || l);\n});\n__d(\"TypeaheadSetPhotoOnSelect\", [\"event-extensions\",\"function-extensions\",\"CSS\",\"DOM\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"copyProperties\");\n    function j(k) {\n        this._typeahead = k;\n    };\n    i(j.prototype, {\n        _eventListener: null,\n        _subscription: null,\n        enable: function() {\n            var k = h.scry(this._typeahead.getElement(), \".photo\")[0];\n            if (k) {\n                if (!h.isNodeOfType(k, \"img\")) {\n                    var l = h.create(\"img\", {\n                        className: k.className\n                    });\n                    h.replace(k, l);\n                    k = l;\n                }\n            ;\n                var m = g.hide.curry(k), n = g.show.curry(k);\n                this._eventListener = Event.listen(k, {\n                    load: n,\n                    error: m,\n                    abort: m\n                });\n                this._subscription = this._typeahead.subscribe(\"select\", function(o, p) {\n                    var q = (p.selected.photo || this._typeahead.view.fallbackPhoto);\n                    (q ? k.setAttribute(\"src\", q) : m());\n                }.bind(this));\n            }\n        ;\n        },\n        disable: function() {\n            this._eventListener.remove();\n            this._eventListener = null;\n            this._typeahead.unsubscribe(this._subscription);\n            this._subscription = null;\n        }\n    });\n    e.exports = j;\n});\n__d(\"legacy:SetPhotoOnSelectTypeaheadBehavior\", [\"TypeaheadSetPhotoOnSelect\",], function(a, b, c, d) {\n    var e = b(\"TypeaheadSetPhotoOnSelect\");\n    if (!a.TypeaheadBehaviors) {\n        a.TypeaheadBehaviors = {\n        };\n    };\n    a.TypeaheadBehaviors.setPhotoOnSelect = function(f) {\n        f.enableBehavior(e);\n    };\n}, 3);");
// 3688
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"sdab5f952481327a6d573c7c4a67920609bcd7798");
// 3689
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"J9ZDd\",]);\n}\n;\n;\n__d(\"DragDropFileUpload\", [], function(a, b, c, d, e, f) {\n    f.isSupported = function() {\n        return ((typeof (JSBNG__FileList) !== \"undefined\"));\n    };\n});\n__d(\"DocumentDragDrop\", [\"event-extensions\",\"CSS\",\"DOM\",\"DragDropFileUpload\",\"getObjectValues\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"DragDropFileUpload\"), j = b(\"getObjectValues\"), k = {\n    }, l = 0;\n    function m() {\n        l = 0;\n        j(k).forEach(function(p) {\n            g.removeClass(p.element, p.className);\n        });\n    };\n;\n    function n() {\n        if (!i.isSupported()) {\n            return;\n        }\n    ;\n    ;\n        JSBNG__Event.listen(JSBNG__document, \"dragenter\", function(q) {\n            if (((l === 0))) {\n                j(k).forEach(function(r) {\n                    g.addClass(r.element, r.className);\n                });\n            }\n        ;\n        ;\n            l++;\n        });\n        JSBNG__Event.listen(JSBNG__document, \"dragleave\", function(q) {\n            l--;\n            if (((l === 0))) {\n                m();\n            }\n        ;\n        ;\n        });\n        JSBNG__Event.listen(JSBNG__document, \"drop\", JSBNG__Event.prevent);\n        JSBNG__Event.listen(JSBNG__document, \"dragover\", JSBNG__Event.prevent);\n        var p = null;\n        JSBNG__document.JSBNG__addEventListener(\"dragover\", function() {\n            ((p && JSBNG__clearTimeout(p)));\n            p = JSBNG__setTimeout(m, 839);\n        }, true);\n        n = bagofholding;\n    };\n;\n    var o = {\n        registerStatusElement: function(p, q) {\n            n();\n            k[h.getID(p)] = {\n                element: p,\n                className: q\n            };\n        },\n        removeStatusElement: function(p) {\n            delete k[h.getID(p)];\n        }\n    };\n    e.exports = o;\n});\n__d(\"DragDropTarget\", [\"event-extensions\",\"CSS\",\"DocumentDragDrop\",\"DragDropFileUpload\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"CSS\"), h = b(\"DocumentDragDrop\"), i = b(\"DragDropFileUpload\"), j = b(\"copyProperties\");\n    function k(m) {\n        return m;\n    };\n;\n    function l(m) {\n        this._element = m;\n        this._listeners = [];\n        this._statusElem = m;\n        this._dragEnterCount = 0;\n    };\n;\n    j(l.prototype, {\n        _onDropCallback: bagofholding,\n        _fileFilterFn: k,\n        setOnDropCallback: function(m) {\n            this._onDropCallback = m;\n            return this;\n        },\n        enable: function() {\n            if (!i.isSupported()) {\n                return this;\n            }\n        ;\n        ;\n            h.registerStatusElement(this._statusElem, \"fbWantsDragDrop\");\n            this._listeners.push(JSBNG__Event.listen(this._element, \"dragenter\", this._onDragEnter.bind(this)));\n            this._listeners.push(JSBNG__Event.listen(this._element, \"dragleave\", this._onDragLeave.bind(this)));\n            this._listeners.push(JSBNG__Event.listen(this._element, \"dragover\", JSBNG__Event.kill));\n            this._listeners.push(JSBNG__Event.listen(this._element, \"drop\", function(m) {\n                this._dragEnterCount = 0;\n                g.removeClass(this._statusElem, \"fbDropReady\");\n                var n = this._fileFilterFn(m.dataTransfer.files);\n                if (n.length) {\n                    this._onDropCallback(n);\n                }\n            ;\n            ;\n                m.kill();\n            }.bind(this)));\n            return this;\n        },\n        disable: function() {\n            h.removeStatusElement(this._statusElem, \"fbWantsDragDrop\");\n            while (this._listeners.length) {\n                this._listeners.pop().remove();\n            ;\n            };\n        ;\n            return this;\n        },\n        setFileFilter: function(m) {\n            this._fileFilterFn = m;\n            return this;\n        },\n        setStatusElement: function(m) {\n            this._statusElem = m;\n            return this;\n        },\n        _onDragEnter: function() {\n            if (((this._dragEnterCount === 0))) {\n                g.addClass(this._statusElem, \"fbDropReady\");\n            }\n        ;\n        ;\n            this._dragEnterCount++;\n        },\n        _onDragLeave: function() {\n            this._dragEnterCount = Math.max(((this._dragEnterCount - 1)), 0);\n            if (((this._dragEnterCount === 0))) {\n                g.removeClass(this._statusElem, \"fbDropReady\");\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = l;\n});\n__d(\"FileUploadTarget\", [\"AsyncUploadRequest\",\"DragDropFileUpload\",\"DragDropTarget\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncUploadRequest\"), h = b(\"DragDropFileUpload\"), i = b(\"DragDropTarget\"), j = b(\"copyProperties\");\n    function k(l, m) {\n        var n = (function(o) {\n            var p = new g(m).setFiles({\n                file: o\n            }).setRelativeTo(l).setStatusElement(l);\n            p.subscribe(\"complete\", function(q, r) {\n                this.JSBNG__onCompleteCallback(r);\n            }.bind(this));\n            p.send();\n        }).bind(this);\n        this.dragDropTarget = new i(l).setOnDropCallback(function(o) {\n            ((o.length && this.asyncProcess(o, function(p) {\n                ((p.length && n(p)));\n            })));\n        }.bind(this));\n        this.asyncProcess = function(o, p) {\n            p(o);\n        };\n        this.preprocess = function(o) {\n            return o;\n        };\n        this.JSBNG__onCompleteCallback = bagofholding;\n    };\n;\n    j(k.prototype, {\n        setPreprocessor: function(l) {\n            this.preprocess = l;\n            return this;\n        },\n        setAsyncProcessor: function(l) {\n            this.asyncProcess = l;\n            return this;\n        },\n        JSBNG__onComplete: function(l) {\n            this.JSBNG__onCompleteCallback = l;\n            return this;\n        },\n        activate: function() {\n            if (!h.isSupported()) {\n                return;\n            }\n        ;\n        ;\n            this.dragDropTarget.setFileFilter(this.preprocess).enable();\n        }\n    });\n    e.exports = k;\n});\n__d(\"SinglePictureUploadTarget\", [\"Bootloader\",\"Dialog\",\"ErrorDialog\",\"FileUploadTarget\",\"htmlSpecialChars\",\"tx\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Bootloader\"), h = b(\"Dialog\"), i = b(\"ErrorDialog\"), j = b(\"FileUploadTarget\"), k = b(\"htmlSpecialChars\"), l = b(\"tx\"), m = b(\"copyProperties\");\n    function n(o, p) {\n        this.fileUploadTarget = new j(o, p);\n        this.preprocessCallback = bagofholding;\n        this.JSBNG__oncompleteCallback = bagofholding;\n        this.afterSuccessCallback = bagofholding;\n        this.maxWidth = null;\n        this.maxHeight = null;\n    };\n;\n    m(n.prototype, {\n        setPreprocessCallback: function(o) {\n            this.preprocessCallback = o;\n            return this;\n        },\n        setOncompleteCallback: function(o) {\n            this.JSBNG__oncompleteCallback = o;\n            return this;\n        },\n        setAfterSuccessCallback: function(o) {\n            this.afterSuccessCallback = o;\n            return this;\n        },\n        setMaximumDimensions: function(o, p) {\n            this.maxWidth = o;\n            this.maxHeight = p;\n            return this;\n        },\n        activate: function() {\n            var o = function(s) {\n                return k(s.JSBNG__name);\n            }, p = (function(s) {\n                if (((s.length > 1))) {\n                    i.show(\"Upload Error\", l._(\"You can only select {max-photos} photos to upload to this album.  Only the first {max-photos} photo you selected will be uploaded.\", {\n                        \"max-photos\": 1\n                    }));\n                    s = [s[0],];\n                }\n            ;\n            ;\n                var t = s[0];\n                if (!t.type.match(/^image\\//)) {\n                    i.show(\"Upload Error\", l._(\"We could not understand the contents of {filename}.  Make sure it is a jpg, gif, or png formatted image.\", {\n                        filename: o(t)\n                    }));\n                    return [];\n                }\n            ;\n            ;\n                this.preprocessCallback(s);\n                return s;\n            }).bind(this), q = (function(s, t) {\n                var u = ((((1024 * 1024)) * 16)), v = ((((1024 * 1024)) * 1)), w = function(y) {\n                    if (((y.size > u))) {\n                        i.show(\"Upload Error\", l._(\"{filename} is too large. Please resize your photo to under\\u000a                     8000x8000 pixels and try again.\", {\n                            filename: o(s[0])\n                        }));\n                        t([]);\n                    }\n                     else t([y,]);\n                ;\n                ;\n                }, x = s[0];\n                if (((((x.size < v)) || ((!this.maxWidth && !this.maxHeight))))) {\n                    w(x);\n                }\n                 else g.loadModules([\"ImageExif\",\"ImageResizer\",], function(y, z) {\n                    if (!z.isSupported()) {\n                        w(x);\n                        return;\n                    }\n                ;\n                ;\n                    var aa = new z(x, this.maxWidth, this.maxHeight);\n                    aa.subscribe(\"resized\", function(ba, ca) {\n                        if (((ca.size > x.size))) {\n                            w(x);\n                        }\n                         else w(ca);\n                    ;\n                    ;\n                    }.bind(this));\n                    aa.subscribe(\"error\", function() {\n                        w(x);\n                    }.bind(this));\n                    y.readFromFile(x, function(ba) {\n                        ((ba && aa.setOrientation(ba.Orientation)));\n                        aa.resize();\n                    });\n                });\n            ;\n            ;\n            }).bind(this), r = (function(s) {\n                var t = s[0];\n                this.JSBNG__oncompleteCallback(t);\n                var u = t.getResponse().getPayload();\n                if (t.isSuccess()) {\n                    this.afterSuccessCallback(u);\n                }\n                 else if (((u && u.__dialog))) {\n                    var v = new h();\n                    v._setFromModel(u.__dialog);\n                    v.setButtons(h.OK).show();\n                }\n                 else i.show(u.error.title, u.error.body);\n                \n            ;\n            ;\n            }).bind(this);\n            return this.fileUploadTarget.JSBNG__onComplete(r).setPreprocessor(p).setAsyncProcessor(q).activate();\n        }\n    });\n    e.exports = n;\n});\nfunction FutureProfileSideNav() {\n    this.parent.construct(this);\n};\n;\nClass.extend(FutureProfileSideNav, \"FutureSideNav\");\ncopyProperties(FutureProfileSideNav.prototype, {\n    init: function() {\n        this.parent.init.apply(this, arguments);\n        this.ajaxPipe = true;\n        this.altKeyParam = \"v\";\n        this.sidecol = false;\n    },\n    _constructItem: function(a, b) {\n        return new FutureProfileSideNavItem(a, b);\n    },\n    _doPageTransition: function(a, b) {\n        if (((!this._profileChanged(b) && !this._scopeChanged(a)))) {\n            return this.parent._doPageTransition(a, b);\n        }\n    ;\n    ;\n    },\n    _profileChanged: function(a) {\n        var b = a.getQueryData(), c = this.uri.getQueryData();\n        return ((((((b.id !== c.id)) || ((b.viewas !== c.viewas)))) || ((b.and !== c.and))));\n    },\n    _scopeChanged: function(a) {\n        return ((!this.selected || ((a.layoutType !== this.selected.layoutType))));\n    },\n    _getKey: function(a) {\n        return ((this.parent._getKey(a) || a[this.altKeyParam]));\n    }\n});\nfunction FutureProfileSideNavItem(a, b) {\n    this.parent.construct(this, a, b);\n    this.layoutType = a.layouttype;\n};\n;\nClass.extend(FutureProfileSideNavItem, \"FutureSideNavItem\");\n__d(\"SubscriptionLevels\", [], function(a, b, c, d, e, f) {\n    var g = {\n        ALL: \"162318810514679\",\n        DEFAULT: \"271670892858696\",\n        TOP: \"266156873403755\"\n    };\n    e.exports = g;\n});\n__d(\"EditSubscriptions\", [\"event-extensions\",\"function-extensions\",\"Arbiter\",\"AsyncRequest\",\"CSS\",\"DOM\",\"ge\",\"Menu\",\"Parent\",\"SubscriptionLevels\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"ge\"), l = b(\"Menu\"), m = b(\"Parent\"), n = b(\"SubscriptionLevels\"), o = 13, p = 45, q = [n.ALL,n.DEFAULT,n.TOP,], r = {\n    }, s = {\n    }, t = {\n    }, u = {\n    }, v = {\n    }, w = {\n    }, x = {\n    }, y = {\n    }, z = {\n    }, aa = {\n    }, ba = \"/ajax/follow/follow_profile.php\", ca = \"/ajax/follow/unfollow_profile.php\", da = {\n    }, ea = {\n    }, fa = null;\n    function ga(ab) {\n        return q.contains(ab);\n    };\n;\n    function ha(ab, bb, cb, db) {\n        var eb = ((m.byClass(db, \"uiMenuItem\") || m.byClass(db, \"uiMenuXItem\")));\n        if (((!eb || !j.contains(ab, eb)))) {\n            return;\n        }\n         else if (i.hasClass(eb, \"SubscribeMenuSubscribeCheckbox\")) {\n            if (t[bb]) {\n                ka(ab, bb);\n            }\n             else ja(ab, bb);\n        ;\n        ;\n            return false;\n        }\n         else if (i.hasClass(eb, \"SubscribeMenuUnsubscribe\")) {\n            ka(ab, bb);\n            return false;\n        }\n         else if (i.hasClass(eb, \"SubscribeMenuSettingsItem\")) {\n            xa(ab, true);\n            return false;\n        }\n         else if (i.hasClass(eb, \"SubscriptionMenuGoBack\")) {\n            xa(ab, false);\n            return false;\n        }\n         else if (i.hasClass(eb, \"SubscriptionMenuItem\")) {\n            ia(ab, bb, cb, eb);\n            return false;\n        }\n        \n        \n        \n        \n        \n    ;\n    ;\n    };\n;\n    function ia(ab, bb, cb, db) {\n        if (i.hasClass(db, \"SubscriptionMenuLevel\")) {\n            if (l.isItemChecked(db)) {\n                return;\n            }\n        ;\n        ;\n            va(ab, bb, oa(db), true, cb);\n        }\n         else if (i.hasClass(db, \"SubscriptionMenuCategory\")) {\n            sa(bb, db, !l.isItemChecked(db), true, cb);\n        }\n         else if (i.hasClass(db, \"SubscriptionAppStory\")) {\n            ua(bb, db, !l.isItemChecked(db), cb);\n        }\n        \n        \n    ;\n    ;\n    };\n;\n    function ja(ab, bb) {\n        var cb = {\n            profile_id: bb\n        };\n        g.inform(\"FollowingUser\", cb);\n        new h().setURI(ba).setMethod(\"POST\").setData({\n            profile_id: bb,\n            JSBNG__location: la(ab)\n        }).setErrorHandler(g.inform.curry(\"FollowUserFail\", cb)).send();\n    };\n;\n    function ka(ab, bb) {\n        var cb = {\n            profile_id: bb\n        };\n        g.inform(\"UnfollowingUser\", cb);\n        new h().setURI(ca).setMethod(\"POST\").setData({\n            profile_id: bb,\n            JSBNG__location: la(ab)\n        }).setErrorHandler(g.inform.curry(\"UnfollowUserFail\", cb)).send();\n    };\n;\n    function la(ab) {\n        if (i.hasClass(ab, \"followButtonFlyout\")) {\n            return o;\n        }\n         else return p\n    ;\n    };\n;\n    function ma(ab, bb, cb) {\n        var db = {\n            profile_id: ab,\n            level: x[ab],\n            custom_categories: y[ab],\n            JSBNG__location: cb\n        };\n        new h().setURI(\"/ajax/follow/manage_subscriptions.php\").setData(db).send();\n    };\n;\n    function na(ab, bb) {\n        var cb = ((y[bb] || [])), db = l.getItems(ab);\n        db.forEach(function(eb) {\n            if (i.hasClass(eb, \"SubscriptionMenuCategory\")) {\n                var fb = oa(eb);\n                if (cb.contains(fb)) {\n                    qa(eb);\n                }\n                 else ra(eb);\n            ;\n            ;\n            }\n             else if (i.hasClass(eb, \"SubscriptionAppStory\")) {\n                var gb = oa(eb);\n                if (((ea[bb] && ea[bb][gb]))) {\n                    qa(eb);\n                }\n                 else ra(eb);\n            ;\n            ;\n            }\n            \n        ;\n        ;\n        });\n        va(ab, bb, x[bb], false);\n    };\n;\n    function oa(ab) {\n        var bb = j.scry(ab, \"input\")[0];\n        return ((bb && bb.value));\n    };\n;\n    function pa(ab) {\n        return j.JSBNG__find(ab, \"a.itemAnchor\");\n    };\n;\n    function qa(ab) {\n        i.addClass(ab, \"checked\");\n        pa(ab).setAttribute(\"aria-checked\", true);\n    };\n;\n    function ra(ab) {\n        i.removeClass(ab, \"checked\");\n        pa(ab).setAttribute(\"aria-checked\", false);\n    };\n;\n    function sa(ab, bb, cb, db, eb) {\n        if (cb) {\n            qa(bb);\n        }\n         else ra(bb);\n    ;\n    ;\n        var fb = oa(bb);\n        if (ga(fb)) {\n            ((cb && ta(ab, fb)));\n        }\n         else if (cb) {\n            if (!y[ab].contains(fb)) {\n                y[ab].push(fb);\n            }\n        ;\n        ;\n        }\n         else {\n            var gb = y[ab].indexOf(fb);\n            if (((gb !== -1))) {\n                y[ab].splice(gb, 1);\n            }\n        ;\n        ;\n        }\n        \n    ;\n    ;\n        if (db) {\n            ma(ab, fb, eb);\n        }\n    ;\n    ;\n    };\n;\n    function ta(ab, bb) {\n        x[ab] = bb;\n        g.inform(\"SubscriptionLevelUpdated\", {\n            profile_id: ab,\n            level: bb\n        });\n    };\n;\n    function ua(ab, bb, cb, db) {\n        var eb = \"/ajax/feed/filter_action/\", fb = oa(bb), gb = {\n            actor_id: ab,\n            app_id: fb\n        };\n        if (cb) {\n            qa(bb);\n            eb += \"resubscribe_user_app/\";\n            gb.action = \"resubscribe_user_app\";\n            if (!ea[ab]) {\n                ea[ab] = {\n                };\n            }\n        ;\n        ;\n            ea[ab][fb] = true;\n        }\n         else {\n            ra(bb);\n            eb += \"unsubscribe_user_app_checkbox/\";\n            gb.action = \"unsubscribe_user_app_checkbox\";\n            if (ea[ab]) {\n                ea[ab][fb] = false;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        new h().setURI(eb).setData(gb).send();\n    };\n;\n    function va(ab, bb, cb, db, eb) {\n        var fb = j.scry(ab, \".SubscriptionMenuLevel\"), gb = null;\n        fb.forEach(function(hb) {\n            if (((oa(hb) == cb))) {\n                gb = hb;\n            }\n             else if (l.isItemChecked(hb)) {\n                sa(bb, hb, false, false);\n            }\n            \n        ;\n        ;\n        });\n        ((gb && sa(bb, gb, true, db, eb)));\n    };\n;\n    function wa(ab, bb, cb) {\n        t[bb] = cb;\n        i.conditionClass(ab, \"isUnsubscribed\", !cb);\n        var db = j.scry(ab, \"li.SubscribeMenuSubscribeCheckbox\");\n        if (((db.length !== 0))) {\n            var eb = db[0];\n            if (cb) {\n                qa(eb);\n            }\n             else ra(eb);\n        ;\n        ;\n        }\n    ;\n    ;\n    };\n;\n    function xa(ab, bb) {\n        i.conditionClass(ab, \"subscriptionMenuOpen\", bb);\n    };\n;\n    function ya(ab, bb, cb) {\n        var db = j.JSBNG__find(ab, \".FriendListSubscriptionsMenu\"), eb = j.JSBNG__find(db, \".uiMenuInner\");\n        if (((fa != null))) {\n            fa.forEach(function(fb) {\n                eb.removeChild(fb);\n            });\n        }\n    ;\n    ;\n        cb.forEach(function(fb) {\n            eb.appendChild(fb);\n        });\n        fa = cb;\n    };\n;\n    g.subscribe(\"UnfollowUser\", function(ab, bb) {\n        if (z[bb.profile_id]) {\n            ta(bb.profile_id, z[bb.profile_id]);\n            y[bb.profile_id] = aa[bb.profile_id].slice();\n        }\n    ;\n    ;\n    });\n    g.subscribe(\"UpdateSubscriptionLevel\", function(ab, bb) {\n        var cb = ((bb.profile_id + \"\")), db = ((bb.level + \"\"));\n        ta(cb, db);\n        var eb;\n        for (eb in r) {\n            if (((r[eb] === cb))) {\n                var fb = k(eb);\n                ((fb && va(fb, cb, db, false)));\n            }\n        ;\n        ;\n        };\n    ;\n    });\n    var za = {\n        init: function(ab, bb, cb) {\n            var db = j.getID(ab);\n            if (!r[db]) {\n                JSBNG__Event.listen(ab, \"click\", function(eb) {\n                    return ha(ab, r[db], cb, eb.getTarget());\n                });\n            }\n        ;\n        ;\n            if (((((cb === p)) && da[bb].length))) {\n                ya(ab, bb, da[bb]);\n            }\n        ;\n        ;\n            if (x[bb]) {\n                na(ab, bb);\n            }\n        ;\n        ;\n            r[db] = bb;\n            i.conditionClass(ab, \"NonFriendSubscriptionMenu\", !s[bb]);\n            i.conditionClass(ab, \"cannotSubscribe\", !u[bb]);\n            i.conditionClass(ab, \"noSubscriptionLevels\", ((v[bb] && !w[bb])));\n            i.conditionClass(ab, \"noSubscribeCheckbox\", ((!s[bb] && !v[bb])));\n            wa(ab, bb, t[bb]);\n            g.subscribe([\"FollowUser\",\"FollowingUser\",\"UnfollowUserFail\",], function(eb, fb) {\n                wa(ab, bb, true);\n            }.bind(this));\n            g.subscribe([\"UnfollowUser\",\"UnfollowingUser\",\"FollowUserFail\",], function(eb, fb) {\n                g.inform(\"SubMenu/Reset\");\n                wa(ab, bb, false);\n            }.bind(this));\n            xa(ab, false);\n        },\n        getSubscriptions: function(ab) {\n            return {\n                level: x[ab],\n                custom_categories: y[ab]\n            };\n        },\n        setSubscriptions: function(ab, bb, cb, db, eb, fb, gb, hb, ib, jb, kb) {\n            ta(ab, ((gb + \"\")));\n            s[ab] = bb;\n            t[ab] = cb;\n            u[ab] = db;\n            v[ab] = eb;\n            w[ab] = fb;\n            z[ab] = ((ib + \"\"));\n            y[ab] = hb.map(String);\n            aa[ab] = jb.map(String);\n            da[ab] = kb;\n        }\n    };\n    e.exports = ((a.EditSubscriptions || za));\n});\n__d(\"legacy:EditSubscriptions\", [\"SubscriptionLevels\",\"EditSubscriptions\",], function(a, b, c, d) {\n    a.SubscriptionLevels = b(\"SubscriptionLevels\");\n    a.EditSubscriptions = b(\"EditSubscriptions\");\n}, 3);\nvar SubscribeButton = ((window.SubscribeButton || (function() {\n    return {\n        SUBSCRIBED: \"FollowingUser\",\n        UNSUBSCRIBED: \"UnfollowingUser\",\n        init: function(a, b, c, d) {\n            JSBNG__Event.listen(b, \"click\", function() {\n                Arbiter.inform(SubscribeButton.SUBSCRIBED, {\n                    profile_id: d\n                });\n            });\n            Arbiter.subscribe(SubscribeButton.SUBSCRIBED, function(e, f) {\n                if (((d === f.profile_id))) {\n                    a.swap();\n                }\n            ;\n            ;\n            });\n            Arbiter.subscribe(SubscribeButton.UNSUBSCRIBED, function(e, f) {\n                if (((d === f.profile_id))) {\n                    a.unswap();\n                    c.hideFlyout();\n                    Arbiter.inform(\"SubMenu/Reset\");\n                }\n            ;\n            ;\n            });\n        },\n        initUnsubscribe: function(a, b) {\n            JSBNG__Event.listen(a, \"click\", function() {\n                Arbiter.inform.bind(Arbiter, SubscribeButton.UNSUBSCRIBED, {\n                    profile_id: b\n                }).defer();\n            });\n        }\n    };\n})()));\n__d(\"legacy:dom-collect\", [\"collectDataAttributes\",], function(a, b, c, d) {\n    a.collect_data_attribs = b(\"collectDataAttributes\");\n}, 3);\n__d(\"DynamicFriendListEducation\", [\"event-extensions\",\"Arbiter\",\"AsyncRequest\",\"Dialog\",\"PageTransitions\",\"createArrayFrom\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"Dialog\"), j = b(\"PageTransitions\"), k = b(\"createArrayFrom\"), l, m, n, o, p, q;\n    function r() {\n        ((n && n.hide()));\n        ((o && o.hide()));\n    };\n;\n    function s(v) {\n        m.remove(v);\n        r();\n        p({\n            accept_tag_education: true\n        });\n    };\n;\n    function t() {\n        r();\n        p({\n            nux_cancel: true\n        });\n    };\n;\n    var u = {\n        init: function(v, w) {\n            l = v;\n            m = k(w).map(String);\n            j.registerHandler(function() {\n                r();\n                l = false;\n                p = undefined;\n                m = [];\n            });\n        },\n        showDialog: function(v, w, x) {\n            if (((l && m.contains(v)))) {\n                r();\n                g.inform(\"DynamicFriendListEducation/dialogOpen\", {\n                    uid: w,\n                    flid: v\n                });\n                p = x;\n                n = new i().setAsync(new h(\"/ajax/friends/lists/smart_list_education.php\").setMethod(\"GET\").setData({\n                    flid: v,\n                    uid: w\n                }).setReadOnly(true)).setHandler(s.bind(this, v)).setCloseHandler(function() {\n                    g.inform(\"DynamicFriendListEducation/dialogClosed\", {\n                        uid: w,\n                        flid: v\n                    });\n                }).setCancelHandler(function() {\n                    g.inform(\"DynamicFriendListEducation/dialogCancel\", {\n                        uid: w,\n                        flid: v\n                    });\n                }).show();\n            }\n             else x();\n        ;\n        ;\n        },\n        showContextualDialog: function(v, w, x, y) {\n            if (((l && m.contains(v)))) {\n                r();\n                q = x;\n                p = y;\n                new h(\"/ajax/friends/lists/smart_list_contextual_education.php\").setMethod(\"GET\").setData({\n                    flid: v,\n                    uid: w\n                }).setReadOnly(true).send();\n            }\n             else y();\n        ;\n        ;\n        },\n        setContextualDialog: function(v, w, x, y) {\n            o = v;\n            o.setContext(q);\n            o.show();\n            JSBNG__Event.listen(w, \"click\", s.bind(this, y));\n            JSBNG__Event.listen(x, \"click\", t);\n        }\n    };\n    e.exports = u;\n});\n__d(\"FriendStatus\", [\"array-extensions\",\"function-extensions\",\"Arbiter\",\"AsyncRequest\",\"copyProperties\",\"createArrayFrom\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"copyProperties\"), j = b(\"createArrayFrom\");\n    function k(o, p, q) {\n        this.id = o;\n        this.update(p, q);\n    };\n;\n    i(k.prototype, {\n        update: function(o, p) {\n            ((o && (this.JSBNG__status = o)));\n            if (p) {\n                this.lists = j(p).map(String);\n                this._informListChange();\n            }\n        ;\n        ;\n        },\n        isComplete: function() {\n            return !!this.lists;\n        },\n        addToList: function(o) {\n            if (((this.lists && !this.lists.contains(o)))) {\n                this.lists.push(o);\n            }\n        ;\n        ;\n            this._informListChange();\n        },\n        removeFromList: function(o) {\n            if (this.lists) {\n                var p = this.lists.indexOf(o);\n                ((((p !== -1)) && this.lists.splice(p, 1)));\n            }\n        ;\n        ;\n            this._informListChange();\n        },\n        updateList: function(o, p) {\n            ((p ? this.addToList(o) : this.removeFromList(o)));\n        },\n        _informListChange: function() {\n            g.inform(\"FriendListMembershipChange\", {\n                uid: this.id,\n                lists: this.lists\n            });\n        }\n    });\n    i(k, {\n        ARE_FRIENDS: 1,\n        INCOMING_REQUEST: 2,\n        OUTGOING_REQUEST: 3,\n        CAN_REQUEST: 4\n    });\n    var l = {\n    }, m = {\n    };\n    function n(o, p, q) {\n        if (!l[q.uid]) {\n            l[q.uid] = new k(q.uid, o);\n        }\n         else l[q.uid].update(o);\n    ;\n    ;\n        g.inform(\"FriendRequest/change\", {\n            uid: q.uid,\n            JSBNG__status: o\n        });\n    };\n;\n    g.subscribe([\"FriendRequest/cancel\",\"FriendRequest/unfriend\",\"FriendRequest/sendFail\",], n.curry(k.CAN_REQUEST));\n    g.subscribe([\"FriendRequest/confirmFail\",], n.curry(k.INCOMING_REQUEST));\n    g.subscribe([\"FriendRequest/cancelFail\",\"FriendRequest/sent\",\"FriendRequest/sending\",], n.curry(k.OUTGOING_REQUEST));\n    g.subscribe([\"FriendRequest/confirm\",\"FriendRequest/confirming\",], n.curry(k.ARE_FRIENDS));\n    i(k, {\n        CLOSE_FRIENDS: null,\n        ACQUAINTANCES: null,\n        getFriend: function(o, p) {\n            if (((l[o] && l[o].isComplete()))) {\n                p(l[o]);\n            }\n             else if (m[o]) {\n                m[o].push(p);\n            }\n             else {\n                m[o] = [p,];\n                new h().setURI(\"/ajax/friends/status.php\").setData({\n                    friend: o\n                }).setHandler(function(q) {\n                    var r = q.getPayload();\n                    k.initFriend.bind(k, o, r.JSBNG__status, r.lists).defer();\n                }).send();\n            }\n            \n        ;\n        ;\n        },\n        initFriend: function(o, p, q) {\n            var r = ((l[o] || new k(o)));\n            r.update(((r.JSBNG__status || p)), ((r.lists || q)));\n            l[o] = r;\n            ((m[o] && m[o].forEach(function(s) {\n                s(r);\n            })));\n            m[o] = null;\n        },\n        setSpecialLists: function(o) {\n            k.CLOSE_FRIENDS = ((o.close + \"\"));\n            k.ACQUAINTANCES = ((o.acq + \"\"));\n        }\n    });\n    e.exports = k;\n});\n__d(\"FriendEditLists\", [\"Arbiter\",\"AsyncRequest\",\"CSS\",\"DOMQuery\",\"DynamicFriendListEducation\",\"EditSubscriptions\",\"FriendStatus\",\"Menu\",\"Parent\",\"ScrollableArea\",\"URI\",\"$\",\"copyProperties\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"CSS\"), j = b(\"DOMQuery\"), k = b(\"DynamicFriendListEducation\"), l = b(\"EditSubscriptions\"), m = b(\"FriendStatus\"), n = b(\"Menu\"), o = b(\"Parent\"), p = b(\"ScrollableArea\"), q = b(\"URI\"), r = b(\"$\"), s = b(\"copyProperties\"), t = b(\"ge\"), u = 5, v = {\n    }, w = \"/ajax/profile/removefriendconfirm.php\", x = \"/ajax/friends/requests/cancel.php\", y = \"/ajax/choose/\", z;\n    function aa(ja, ka, la) {\n        var ma = v[ja.id], na = function(oa) {\n            var pa = {\n                action: ((la ? \"add_list\" : \"del_list\")),\n                to_friend: ma.id,\n                friendlists: [ka,],\n                source: z\n            };\n            if (oa) {\n                s(pa, oa);\n            }\n        ;\n        ;\n            ma.updateList(ka, la);\n            var qa;\n            if (((la && ((ka == m.CLOSE_FRIENDS))))) {\n                qa = da(ja, m.ACQUAINTANCES);\n                if (n.isItemChecked(qa)) {\n                    n.toggleItem(qa);\n                    aa(ja, m.ACQUAINTANCES, false);\n                }\n            ;\n            ;\n            }\n             else if (((la && ((ka == m.ACQUAINTANCES))))) {\n                qa = da(ja, m.CLOSE_FRIENDS);\n                if (n.isItemChecked(qa)) {\n                    n.toggleItem(qa);\n                    aa(ja, m.CLOSE_FRIENDS, false);\n                }\n            ;\n            ;\n            }\n            \n        ;\n        ;\n            var ra = {\n                flid: ka,\n                uid: ma.id\n            }, sa = ((la ? \"FriendListHovercard/add\" : \"FriendListHovercard/remove\"));\n            g.inform(sa, ra);\n            new h().setURI(\"/ajax/add_friend/action.php\").setData(pa).send();\n        };\n        if (la) {\n            k.showDialog(ka, ma.id, na);\n        }\n         else na();\n    ;\n    ;\n    };\n;\n    function ba(ja) {\n        var ka = j.scry(ja, \"input\")[0];\n        return ((ka && ka.value));\n    };\n;\n    function ca(ja, ka, la) {\n        var ma = {\n            uid: ka.id\n        };\n        new h().setURI(x).setMethod(\"POST\").setData({\n            friend: ka.id\n        }).setHandler(g.inform.bind(g, \"FriendRequest/cancel\", ma)).setErrorHandler(g.inform.bind(g, \"FriendRequest/cancelFail\", ma)).setStatusElement(la).send();\n    };\n;\n    function da(ja, ka) {\n        var la = n.getItems(ja);\n        for (var ma = 0; ((ma < la.length)); ma++) {\n            if (((ba(la[ma]) == ka))) {\n                return la[ma];\n            }\n        ;\n        ;\n        };\n    ;\n        return null;\n    };\n;\n    function ea(ja, ka) {\n        var la = n.getItems(ja);\n        la.forEach(function(ma) {\n            var na = ba(ma), oa = ka.lists.contains(na);\n            if (((n.isItemChecked(ma) !== oa))) {\n                n.toggleItem(ma);\n            }\n        ;\n        ;\n        });\n    };\n;\n    function fa(ja) {\n        var ka = n.getItems(ja), la = ((!i.hasClass(ja, \"followButtonFlyout\") && !i.hasClass(ja, \"likeButtonFlyout\"))), ma = [], na = [], oa = 0, pa = 0;\n        ka.forEach(function(ua) {\n            if (i.hasClass(ua, \"neverHide\")) {\n                i.removeClass(ua, \"underShowMore\");\n                oa++;\n            }\n             else if (n.isItemChecked(ua)) {\n                ma.push(ua);\n            }\n             else if (((((i.hasClass(ua, \"neverShow\") || i.hasClass(ua, \"FriendListCreateTrigger\"))) || ((!la && i.hasClass(ua, \"friendOptionsOnly\")))))) {\n                i.addClass(ua, \"underShowMore\");\n                pa++;\n            }\n             else na.push(ua);\n            \n            \n        ;\n        ;\n        });\n        var qa = ((u - oa)), ra = ma.concat(na), sa = pa;\n        ra.forEach(function(ua) {\n            if (i.hasClass(ua, \"ShowMoreItem\")) {\n                qa--;\n                return;\n            }\n        ;\n        ;\n            if (qa) {\n                i.removeClass(ua, \"underShowMore\");\n                qa--;\n            }\n             else {\n                i.addClass(ua, \"underShowMore\");\n                sa = true;\n            }\n        ;\n        ;\n        });\n        i.conditionClass(ja, \"hasMoreFriendListItems\", sa);\n        var ta = j.scry(ja, \".FriendListMenuShowMore\");\n        ta.forEach(function(ua) {\n            i.removeClass(ua, \"FriendListMenuShowMore\");\n        });\n    };\n;\n    function ga(ja, ka) {\n        var la = j.scry(ja, \".FriendListUnfriend\")[0], ma = j.scry(ja, \".FriendListCancel\")[0], na = j.scry(ja, \".FriendListSuggestFriends\")[0];\n        if (ma) {\n            i.conditionShow(ma, ((ka.JSBNG__status == m.OUTGOING_REQUEST)));\n        }\n    ;\n    ;\n        if (la) {\n            i.conditionShow(la, ((ka.JSBNG__status == m.ARE_FRIENDS)));\n            j.JSBNG__find(la, \"a\").setAttribute(\"ajaxify\", q(w).addQueryData({\n                uid: ka.id\n            }).toString());\n        }\n    ;\n    ;\n        if (na) {\n            j.JSBNG__find(na, \"a\").setAttribute(\"href\", q(y).addQueryData({\n                type: \"suggest_friends\",\n                newcomer: ka.id,\n                ref: \"profile_others_dropdown\"\n            }).toString());\n        }\n    ;\n    ;\n    };\n;\n    function ha(ja, ka) {\n        var la = j.scry(ja, \"div.FriendListSubscriptionsMenu\");\n        if (((la.length !== 0))) {\n            l.init(ja, ka, 45);\n        }\n    ;\n    ;\n    };\n;\n    g.subscribe(\"FriendRequest/change\", function(ja, ka) {\n        for (var la in v) {\n            var ma = t(la), na = v[la];\n            if (((((ma && na)) && ((na.id == ka.uid))))) {\n                ea(ma, na);\n                ga(ma, na);\n                fa(ma);\n            }\n        ;\n        ;\n        };\n    ;\n    });\n    n.subscribe(\"select\", function(ja, ka) {\n        if (((i.hasClass(ka.item, \"ShowMoreItem\") && i.hasClass(ka.menu, \"FriendListMenu\")))) {\n            i.addClass(ka.menu, \"FriendListMenuShowMore\");\n            p.poke(ka.item);\n        }\n    ;\n    ;\n    });\n    var ia = {\n        init: function(ja, ka, la) {\n            ja = r(ja);\n            z = la;\n            if (!v[ja.id]) {\n                n.subscribe(\"select\", function(ma, na) {\n                    if (j.contains(ja, na.item)) {\n                        if (o.byClass(na.item, \"FriendListItem\")) {\n                            n.toggleItem(na.item);\n                            var oa = ba(na.item);\n                            aa(ja, oa, n.isItemChecked(na.item));\n                        }\n                         else if (o.byClass(na.item, \"FriendListCancel\")) {\n                            ca(ja, v[ja.id], na.item);\n                        }\n                         else if (o.byClass(na.item, \"FriendListUnfriend\")) {\n                            g.inform(\"FriendEditLists/unfriend\");\n                        }\n                        \n                        \n                    ;\n                    }\n                ;\n                ;\n                });\n            }\n        ;\n        ;\n            i.addClass(ja, \"async_saving\");\n            m.getFriend(ka, function(ma) {\n                ea(ja, ma);\n                ga(ja, ma);\n                v[ja.id] = ma;\n                fa(ja);\n                ha(ja, ka);\n                i.removeClass(ja, \"async_saving\");\n            }.bind(this));\n        }\n    };\n    e.exports = ((a.FriendEditLists || ia));\n});\n__d(\"FriendListFlyoutController\", [\"event-extensions\",\"Arbiter\",\"AsyncRequest\",\"Button\",\"CSS\",\"DataStore\",\"Dialog\",\"DOM\",\"ContextualLayer\",\"FriendEditLists\",\"FriendStatus\",\"Layer\",\"Parent\",\"ScrollableArea\",\"UserAgent\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"Button\"), j = b(\"CSS\"), k = b(\"DataStore\"), l = b(\"Dialog\"), m = b(\"DOM\"), n = b(\"ContextualLayer\"), o = b(\"FriendEditLists\"), p = b(\"FriendStatus\"), q = b(\"Layer\"), r = b(\"Parent\"), s = b(\"ScrollableArea\"), t = b(\"UserAgent\"), u, v, w = null, x = null, y, z, aa, ba, ca, da, ea = 1500, fa = {\n        init: function(ta) {\n            fa.init = bagofholding;\n            u = ta;\n            u.subscribe(\"mouseenter\", ga);\n            u.subscribe(\"mouseleave\", oa);\n            u.subscribe(\"hide\", ha);\n            if (w) {\n                m.setContent(u.getContent(), [w,x,]);\n            }\n        ;\n        ;\n            var ua = function(va) {\n                var wa = r.byClass(va.getTarget(), \"enableFriendListFlyout\");\n                if (wa) {\n                    if (((y === wa))) {\n                        JSBNG__clearTimeout(ba);\n                    }\n                     else {\n                        ((v && qa()));\n                        na(wa);\n                    }\n                ;\n                }\n            ;\n            ;\n            };\n            JSBNG__Event.listen(JSBNG__document.documentElement, {\n                mouseover: ua,\n                click: ua\n            });\n            g.subscribe(\"FriendEditLists/unfriend\", qa);\n            g.subscribe(\"DynamicFriendListEducation/dialogOpen\", function() {\n                da = true;\n            });\n            g.subscribe(\"DynamicFriendListEducation/dialogClosed\", function() {\n                da = false;\n                oa();\n            });\n        },\n        initContent: function(ta) {\n            m.appendContent(JSBNG__document.body, ta);\n            (function() {\n                if (!w) {\n                    w = ta;\n                    ((u && m.setContent(u.getContent(), [w,x,])));\n                    j.show(w);\n                    JSBNG__Event.listen(w, \"click\", ra);\n                    ((v && ka(y)));\n                }\n                 else {\n                    m.remove(ta);\n                    ta = null;\n                }\n            ;\n            ;\n            }).defer();\n        },\n        initNux: function(ta) {\n            if (x) {\n                return;\n            }\n        ;\n        ;\n            x = ta;\n            ((u && m.setContent(u.getContent(), [w,x,])));\n        },\n        show: function(ta) {\n            la(ta);\n        },\n        hide: function(ta) {\n            ((((ta === false)) ? qa() : oa()));\n        },\n        setActiveNode: function(ta) {\n            ((v && qa()));\n            y = ta;\n            z = JSBNG__Event.listen(ta, \"mouseleave\", function() {\n                y = null;\n                ((z && z.remove()));\n            });\n        },\n        setCloseListener: function(ta, ua) {\n            k.set(ta, \"flfcloselistener\", ua);\n            if (((y != ta))) {\n                k.set(ta, \"flfcloselistenertimeout\", sa.curry(ta).defer(ea));\n            }\n        ;\n        ;\n        },\n        setCloseListenerTimeout: function(ta) {\n            ea = ta;\n        }\n    };\n    function ga() {\n        JSBNG__clearTimeout(ba);\n    };\n;\n    function ha() {\n        if (y) {\n            j.removeClass(y, \"selected\");\n            j.removeClass(y, \"uiButtonHover\");\n            if (k.get(y, \"flfcloselistener\")) {\n                var ta = y;\n                k.set(y, \"flfcloselistenertimeout\", sa.curry(ta).defer(ea));\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        v = false;\n        ja();\n        y = null;\n    };\n;\n    function ia(ta) {\n        if (((m.isNodeOfType(ta, \"label\") && j.hasClass(ta, \"uiButton\")))) {\n            ta = i.getInputElement(ta);\n        }\n    ;\n    ;\n        return k.get(ta, \"profileid\");\n    };\n;\n    function ja() {\n        ((z && z.remove()));\n        z = null;\n        ((ca && q.unsubscribe(ca)));\n        ca = null;\n        ((ba && JSBNG__clearTimeout(ba)));\n        ba = null;\n    };\n;\n    function ka(ta) {\n        var ua = ia(ta), va = k.get(ta, \"flloc\");\n        o.init(w, ua, va);\n        j.conditionClass(w, \"followButtonFlyout\", j.hasClass(ta, \"profileFollowButton\"));\n        j.conditionClass(w, \"friendButtonFlyout\", ((((j.hasClass(ta, \"FriendRequestFriends\") || j.hasClass(ta, \"FriendRequestIncoming\"))) || j.hasClass(ta, \"FriendRequestOutgoing\"))));\n        j.conditionClass(w, \"likeButtonFlyout\", j.hasClass(ta, \"profileLikeButton\"));\n        var wa = m.scry(w, \"div.uiScrollableArea\")[0];\n        ((wa && s.poke(wa)));\n    };\n;\n    function la(ta) {\n        if (((!u || v))) {\n            return;\n        }\n    ;\n    ;\n        u.setContext(ta);\n        u.setCausalElement(ta);\n        ta.setAttribute(\"aria-expanded\", \"true\");\n        j.addClass(ta, \"selected\");\n        j.addClass(ta, \"uiButtonHover\");\n        u.show();\n        y = ta;\n        v = true;\n        if (w) {\n            ka(ta);\n        }\n         else new h().setURI(\"/ajax/friends/lists/flyout_content.php\").setStatusElement(u.getContent()).send();\n    ;\n    ;\n        ja();\n        z = JSBNG__Event.listen(ta, \"mouseleave\", oa);\n        ca = q.subscribe(\"show\", ma);\n        if (k.get(ta, \"flfcloselistener\")) {\n            JSBNG__clearTimeout(k.remove(ta, \"flfcloselistenertimeout\"));\n        }\n    ;\n    ;\n        var ua = ia(ta);\n        p.getFriend(ua, function(va) {\n            if (!x) {\n                return;\n            }\n        ;\n        ;\n            if (((va.JSBNG__status == p.OUTGOING_REQUEST))) {\n                j.show(x);\n                h.bootstrap(\"/ajax/friends/lists/nux_flyout.php\", null, true);\n            }\n             else j.hide(x);\n        ;\n        ;\n        });\n    };\n;\n    function ma(ta, ua) {\n        if (((!((ua instanceof n)) || !m.contains(y, ua.getContext())))) {\n            oa();\n        }\n    ;\n    ;\n    };\n;\n    function na(ta) {\n        y = ta;\n        aa = la.curry(ta).defer(350);\n        z = JSBNG__Event.listen(ta, \"mouseleave\", function() {\n            JSBNG__clearTimeout(aa);\n            y = null;\n            ((z && z.remove()));\n        });\n    };\n;\n    function oa() {\n        ba = qa.defer(150);\n    };\n;\n    function pa() {\n        var ta = l.getCurrent(), ua = ((ta && ta.getBody()));\n        return !!((ua && m.scry(ua, \".friendListDialogTourCarousel\")[0]));\n    };\n;\n    function qa() {\n        if (((da || pa()))) {\n            return;\n        }\n    ;\n    ;\n        ((((t.ie() < 8)) && JSBNG__document.documentElement.JSBNG__focus()));\n        if (u) {\n            u.hide();\n            var ta = u.getCausalElement();\n            ((ta && ta.setAttribute(\"aria-expanded\", \"false\")));\n        }\n    ;\n    ;\n    };\n;\n    function ra(JSBNG__event) {\n        var ta = r.byTag(JSBNG__event.getTarget(), \"a\");\n        if (((ta && j.hasClass(ta, \"FriendListActionItem\")))) {\n            oa();\n        }\n    ;\n    ;\n    };\n;\n    function sa(ta) {\n        var ua = k.remove(ta, \"flfcloselistener\");\n        ((ua && ua()));\n    };\n;\n    e.exports = ((a.FriendListFlyoutController || fa));\n});\n__d(\"legacy:FriendListFlyoutController\", [\"FriendListFlyoutController\",], function(a, b, c, d) {\n    a.FriendListFlyoutController = b(\"FriendListFlyoutController\");\n}, 3);\n__d(\"legacy:FriendStatus\", [\"FriendStatus\",], function(a, b, c, d) {\n    a.FriendStatus = b(\"FriendStatus\");\n}, 3);\nvar AddFriendButton = {\n    ERROR_ALREADY_ADDED: 1431005,\n    init: function(a, b, c, d, e, f, g, h, i, j, k) {\n        var l = null, m = DOM.scry(a, \".addButton\")[0], n = DOM.scry(a, \".outgoingButton\")[0], o = DOM.scry(a, \".incomingButton\")[0], p = DOM.scry(a, \".friendButton\")[0];\n        function q(v, w, x) {\n            var y = new URI(m.getAttribute(\"ajaxify\"));\n            link_data = collect_data_attribs(a, [\"ft\",\"gt\",]);\n            new AsyncRequest().setURI(f).setData({\n                to_friend: b,\n                action: v,\n                how_found: d,\n                ref_param: e,\n                link_data: link_data,\n                outgoing_id: n.id,\n                xids: y.getQueryData().xids,\n                logging_location: g,\n                no_flyout_on_click: h,\n                ego_log_data: i,\n                http_referer: k\n            }).setErrorHandler(w).setServerDialogCancelHandler(x).setRelativeTo(n).send();\n        };\n    ;\n        function r(v, w) {\n            ((m && CSS.hide(m)));\n            ((n && CSS.hide(n)));\n            ((o && CSS.hide(o)));\n            ((p && CSS.hide(p)));\n            if (v) {\n                CSS.show(v);\n            }\n        ;\n        ;\n            if (((((((\"Outgoing\" == w)) && ((l != w)))) && j))) {\n                animation(v).from(\"backgroundColor\", \"#FFF8CC\").to(\"backgroundColor\", \"transparent\").from(\"borderColor\", \"#FFE222\").to(\"borderColor\", Style.get(v, \"borderLeftColor\")).duration(2000).go();\n            }\n        ;\n        ;\n            ((l && CSS.removeClass(a, ((\"fStatus\" + l)))));\n            l = w;\n            CSS.addClass(a, ((\"fStatus\" + w)));\n        };\n    ;\n        function s(v) {\n            if (CSS.hasClass(v, \"enableFriendListFlyout\")) {\n                FriendListFlyoutController.show(v);\n            }\n             else FriendListFlyoutController.hide();\n        ;\n        ;\n        };\n    ;\n        var t = Arbiter.subscribe(\"FriendRequest/change\", function(v, w) {\n            if (((w.uid != b))) {\n                return;\n            }\n        ;\n        ;\n            switch (w.JSBNG__status) {\n              case FriendStatus.ARE_FRIENDS:\n                return r(p, \"Friends\");\n              case FriendStatus.INCOMING_REQUEST:\n                return r(o, \"Incoming\");\n              case FriendStatus.OUTGOING_REQUEST:\n                return r(n, \"Outgoing\");\n              case FriendStatus.CAN_REQUEST:\n                return r(m, \"Requestable\");\n            };\n        ;\n        }), u;\n        if (c) {\n            u = Arbiter.subscribe(\"FriendRequest/confirm\", function(v, w) {\n                ((((w.uid == b)) && goURI(c)));\n            });\n        }\n    ;\n    ;\n        ((m && JSBNG__Event.listen(m, \"click\", function() {\n            Arbiter.inform(\"FriendRequest/sending\", {\n                uid: b\n            });\n            if (h) {\n                FriendListFlyoutController.setActiveNode(n);\n            }\n             else s(n);\n        ;\n        ;\n            q(\"add_friend\", function(v) {\n                var w = ((((v.error == AddFriendButton.ERROR_ALREADY_ADDED)) ? \"FriendRequest/sent\" : \"FriendRequest/sendFail\"));\n                Arbiter.inform(w, {\n                    uid: b\n                });\n                FriendListFlyoutController.hide();\n                AsyncResponse.defaultErrorHandler(v);\n            }, function(v) {\n                Arbiter.inform(\"FriendRequest/sendFail\", {\n                    uid: b\n                });\n                FriendListFlyoutController.hide();\n            });\n        })));\n        PageTransitions.registerHandler(function() {\n            t.unsubscribe();\n            ((u && u.unsubscribe()));\n        });\n    }\n};\n__d(\"FriendButtonIcon\", [\"Arbiter\",\"FriendStatus\",\"Button\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"FriendStatus\"), i = b(\"Button\");\n    e.exports = {\n        register: function(j, k, l) {\n            g.subscribe(\"FriendListMembershipChange\", function(m, n) {\n                if (((n.uid == l))) {\n                    var o = n.lists.contains(h.CLOSE_FRIENDS), p = n.lists.contains(h.ACQUAINTANCES);\n                    if (((o && !p))) {\n                        i.setIcon(j, k.close);\n                    }\n                     else if (((p && !o))) {\n                        i.setIcon(j, k.acquaintance);\n                    }\n                     else i.setIcon(j, k.friend);\n                    \n                ;\n                ;\n                }\n            ;\n            ;\n            });\n        }\n    };\n});\n__d(\"RespondToRequestButton\", [\"event-extensions\",\"Arbiter\",\"CSS\",\"Menu\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"CSS\"), i = b(\"Menu\"), j = {\n        init: function(k, l, m, n) {\n            JSBNG__Event.listen(l, \"click\", function() {\n                h.addClass(l, \"uiButtonConfirm\");\n                h.addClass(l, \"selected\");\n                m.show();\n            });\n            m.subscribe(\"hide\", function() {\n                h.removeClass(l, \"uiButtonConfirm\");\n                h.removeClass(l, \"selected\");\n            });\n            i.subscribe(\"select\", function(o, p) {\n                if (!h.hasClass(p.menu, \"requestResponseMenu\")) {\n                    return;\n                }\n            ;\n            ;\n                if (((p.item.firstChild.getAttribute(\"data-profileid\") != k))) {\n                    return;\n                }\n            ;\n            ;\n                if (h.hasClass(p.item, \"reject\")) {\n                    h.hide(l);\n                    h.show(n);\n                }\n            ;\n            ;\n                m.hide();\n                g.inform(\"FriendRequest/delete\");\n            });\n        }\n    };\n    e.exports = j;\n});\n__d(\"legacy:RespondToRequestButton\", [\"RespondToRequestButton\",], function(a, b, c, d) {\n    a.RespondToRequestButton = b(\"RespondToRequestButton\");\n}, 3);\n__d(\"MessageButton\", [\"event-extensions\",\"Chat\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Chat\"), h = b(\"copyProperties\");\n    function i() {\n    \n    };\n;\n    h(i, {\n        initChat: function(j, k, l) {\n            JSBNG__Event.listen(j, \"click\", function() {\n                g.openTab(k, l, \"friend\");\n                return false;\n            });\n        }\n    });\n    e.exports = i;\n});\n__d(\"StickyController\", [\"event-extensions\",\"CSS\",\"Style\",\"Vector\",\"copyProperties\",\"throttle\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"CSS\"), h = b(\"Style\"), i = b(\"Vector\"), j = b(\"copyProperties\"), k = b(\"throttle\");\n    function l(m, n, o, p) {\n        this._element = m;\n        this._marginTop = n;\n        this._onchange = o;\n        this._proxy = ((p || m.parentNode));\n    };\n;\n    j(l.prototype, {\n        handleScroll: function() {\n            var m = ((i.getElementPosition(this._proxy, \"viewport\").y <= this._marginTop));\n            if (((this.isFixed() !== m))) {\n                h.set(this._element, \"JSBNG__top\", ((m ? ((this._marginTop + \"px\")) : \"\")));\n                g.conditionClass(this._element, \"fixed_elem\", m);\n                ((this._onchange && this._onchange(m)));\n            }\n        ;\n        ;\n        },\n        start: function() {\n            if (this._event) {\n                return;\n            }\n        ;\n        ;\n            this._event = JSBNG__Event.listen(window, \"JSBNG__scroll\", k(this.handleScroll, 100, this));\n            this.handleScroll.bind(this).defer();\n        },\n        JSBNG__stop: function() {\n            ((this._event && this._event.remove()));\n            this._event = null;\n        },\n        isFixed: function() {\n            return g.hasClass(this._element, \"fixed_elem\");\n        }\n    });\n    e.exports = l;\n});\n__d(\"requestAnimationFrame\", [], function(a, b, c, d, e, f) {\n    var g = ((((((((((window.requestAnimationFrame || window.JSBNG__webkitRequestAnimationFrame)) || window.JSBNG__mozRequestAnimationFrame)) || window.oRequestAnimationFrame)) || window.msRequestAnimationFrame)) || function(h) {\n        window.JSBNG__setTimeout(h, 16);\n    }));\n    e.exports = g;\n});\n__d(\"HubsTypeaheadView\", [\"Class\",\"ContextualTypeaheadView\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Class\"), h = b(\"ContextualTypeaheadView\"), i = b(\"copyProperties\");\n    function j(k, l) {\n        this.parent.construct(this, k, l);\n    };\n;\n    g.extend(j, h);\n    i(j.prototype, {\n        render: function(k, l, m) {\n            if (((this.alwaysRender && ((k !== \"\"))))) {\n                var n = k.toLowerCase().trim(), o = false;\n                for (var p = 0; ((p < l.length)); p++) {\n                    if (((n == l[p].text.toLowerCase()))) {\n                        o = true;\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n                if (!o) {\n                    l.push({\n                        text: k,\n                        type: \"calltoaction\"\n                    });\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            return this.parent.render(k, l, m);\n        }\n    });\n    e.exports = j;\n});\n__d(\"BrokenProfilePicLogger\", [\"Run\",\"DOM\",\"JSLogger\",], function(a, b, c, d, e, f) {\n    var g = b(\"Run\"), h = b(\"DOM\"), i = b(\"JSLogger\"), j = i.create(\"entities_profile_pics\"), k = {\n        checkAndLog: function(l) {\n            g.JSBNG__onAfterLoad(function() {\n                var m = h.JSBNG__find(l, \"img\");\n                if (((!m.complete || ((((typeof m.naturalWidth != \"undefined\")) && ((m.naturalWidth === 0))))))) {\n                    j.log(\"broken_link\", {\n                        src: m.getAttribute(\"src\")\n                    });\n                }\n            ;\n            ;\n            });\n        }\n    };\n    e.exports = k;\n});\n__d(\"TimelineConstants\", [], function(a, b, c, d, e, f) {\n    var g = {\n        DS_HEIGHT: \"timeline-unit-height\",\n        DS_LOADED: \"timeline-capsule-loaded\",\n        DS_SIDEORG: \"timeline-unit-sideorg\",\n        DS_TAILBALANCE: \"timeline-capsule-tailbalance\",\n        DS_COLUMN_HEIGHT_DIFFERENTIAL: \"timeline-column-diff-height\",\n        FIXED_SIDE_LEFT: \"left\",\n        FIXED_SIDE_RIGHT: \"right\",\n        FIXED_SIDE_BOTH: \"both\",\n        SCROLL_TO_OFFSET: 30,\n        SUBSECTION_SCROLL_TO_OFFSET: 90\n    };\n    e.exports = g;\n});\n__d(\"TimelineURI\", [\"URI\",], function(a, b, c, d, e, f) {\n    var g = b(\"URI\"), h = {\n        TIMELINE_KEY: \"timeline\",\n        WALL_KEY: \"wall\",\n        parseURI: function(i) {\n            i = g(i);\n            var j = i.getQueryData(), k = i.getPath(), l = k.split(\"/\").slice(1);\n            if (((((l[0] == \"people\")) || ((l[0] == \"pages\"))))) {\n                l = l.slice(2);\n            }\n        ;\n        ;\n            var m = ((((j.sk || l[1])) || h.TIMELINE_KEY));\n            if (((m == h.WALL_KEY))) {\n                m = h.TIMELINE_KEY;\n            }\n        ;\n        ;\n            var n = null, o = null;\n            if (((m == h.TIMELINE_KEY))) {\n                o = ((parseInt(l[2], 10) || null));\n                n = ((parseInt(l[3], 10) || null));\n            }\n        ;\n        ;\n            return {\n                path: k,\n                id: ((j.id || l[0])),\n                key: m,\n                viewas: ((j.viewas ? j.viewas : 0)),\n                filter: ((j.filter ? j.filter : null)),\n                year: o,\n                month: n,\n                friendship: !!j.and\n            };\n        }\n    };\n    e.exports = h;\n});\n__d(\"TimelineController\", [\"event-extensions\",\"Arbiter\",\"CSS\",\"DataStore\",\"DOM\",\"Run\",\"ScrollingPager\",\"Style\",\"TimelineConstants\",\"TimelineURI\",\"Vector\",\"ViewportBounds\",\"$\",\"ge\",\"throttle\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"CSS\"), i = b(\"DataStore\"), j = b(\"DOM\"), k = b(\"Run\"), l = b(\"ScrollingPager\"), m = b(\"Style\"), n = b(\"TimelineConstants\"), o = b(\"TimelineURI\"), p = b(\"Vector\"), q = b(\"ViewportBounds\"), r = b(\"$\"), s = b(\"ge\"), t = b(\"throttle\"), u = 484, v = 48, w = 740, x = 1285, y = null, z = false, aa, ba, ca, da = {\n    }, ea = {\n    }, fa = [], ga = null, ha = 0, ia = false, ja = false, ka = false, la = {\n        allactivity: true,\n        approve: true,\n        games: true,\n        map: true,\n        music: true,\n        video: true\n    };\n    la[o.TIMELINE_KEY] = true;\n    var ma = [], na = false;\n    function oa() {\n        ((ga && ga.remove()));\n        ga = null;\n    };\n;\n    function pa(ya, za, ab) {\n        ab = ((ab || []));\n        if (da[ya]) {\n            return da[ya][za].apply(da[ya], ab);\n        }\n    ;\n    ;\n        ea[ya] = ((ea[ya] || {\n        }));\n        ea[ya][za] = ab;\n        return false;\n    };\n;\n    function qa() {\n        if (!((((ia || ka)) || ja))) {\n            oa();\n            return;\n        }\n    ;\n    ;\n        var ya = p.getScrollPosition();\n        ia = ((ia && sa(r(\"rightCol\"), ya, \"paddingTop\", true)));\n        ja = ((ja && sa(r(\"pagelet_above_header_timeline\"), ya, \"JSBNG__top\")));\n        ka = ((ka && sa(r(\"blueBar\"), ya, \"paddingTop\")));\n    };\n;\n    function ra() {\n        var ya = p.getScrollPosition(), za = ((((ha === 0)) || ((ya.y >= ha))));\n        pa(xa.STICKY_HEADER, \"toggle\", [za,]);\n        pa(xa.CONTENT, \"checkCurrentSectionChange\");\n    };\n;\n    function sa(ya, za, ab, bb) {\n        if (!ya) {\n            oa();\n            return;\n        }\n    ;\n    ;\n        if (((za.y <= 0))) {\n            ta(ya, ab);\n            return false;\n        }\n         else {\n            var cb = ((bb && xa.getCurrentScrubber()));\n            if (((((cb && h.hasClass(cb.getRoot(), \"fixed_elem\"))) || m.isFixed(s(\"pagelet_timeline_friends\"))))) {\n                ta(ya, ab);\n                return false;\n            }\n             else {\n                var db = ((parseInt(ya.style[ab], 10) || 0));\n                if (((za.y < db))) {\n                    h.addClass(ya, \"timeline_fixed\");\n                    ya.style[ab] = ((za.y + \"px\"));\n                }\n                 else h.removeClass(ya, \"timeline_fixed\");\n            ;\n            ;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        return true;\n    };\n;\n    function ta(ya, za) {\n        ya.style[za] = \"0px\";\n        h.removeClass(ya, \"timeline_fixed\");\n    };\n;\n    function ua() {\n        pa(xa.ADS, \"adjustAdsType\", [xa.shouldShowWideAds(),]);\n        pa(xa.ADS, \"adjustAdsToFit\");\n        pa(xa.CONTENT, \"adjustContentPadding\");\n        pa(xa.STICKY_HEADER_NAV, \"adjustMenuHeights\");\n    };\n;\n    function va(ya, za) {\n        if (((ya == \"sidebar/initialized\"))) {\n            na = true;\n        }\n    ;\n    ;\n        pa(xa.ADS, \"adjustAdsType\", [xa.shouldShowWideAds(),]);\n    };\n;\n    function wa() {\n        while (fa.length) {\n            fa.pop().remove();\n        ;\n        };\n    ;\n        for (var ya in da) {\n            ((da[ya].reset && da[ya].reset()));\n        ;\n        };\n    ;\n        oa();\n        ca.unsubscribe();\n        ca = null;\n        y = null;\n        aa = null;\n        da = {\n        };\n        ea = {\n        };\n        ha = 0;\n        ja = false;\n        if (ia) {\n            r(\"rightCol\").style.paddingTop = \"\";\n            h.removeClass(r(\"rightCol\"), \"timeline_fixed\");\n        }\n    ;\n    ;\n        ia = false;\n        if (ka) {\n            r(\"blueBar\").style.paddingTop = \"\";\n            h.removeClass(r(\"blueBar\"), \"timeline_fixed\");\n        }\n    ;\n    ;\n        ka = false;\n        ma = [];\n        na = false;\n        z = false;\n        i.purge(n.DS_HEIGHT);\n        i.purge(n.DS_LOADED);\n        i.purge(n.DS_SIDEORG);\n        i.purge(n.DS_TAILBALANCE);\n        i.purge(n.DS_COLUMN_HEIGHT_DIFFERENTIAL);\n    };\n;\n    var xa = {\n        NAV: \"nav\",\n        STICKY_HEADER: \"sticky_header\",\n        STICKY_HEADER_NAV: \"sticky_header_nav\",\n        SCRUBBER: \"scrubber\",\n        CONTENT: \"JSBNG__content\",\n        ADS: \"ads\",\n        COVER: \"cover\",\n        LOGGING: \"logging\",\n        SECTION_LOADING: \"TimelineController/sectionLoading\",\n        SECTION_LOADED: \"TimelineController/sectionLoaded\",\n        SECTION_FULLY_LOADED: \"TimelineController/sectionFullyLoaded\",\n        SECTION_REGISTERED: \"TimelineController/sectionRegistered\",\n        SCRUBBER_DEFAULT_OFFSET: 38,\n        init: function(ya, za, ab) {\n            if (z) {\n                return;\n            }\n        ;\n        ;\n            if (((za == o.WALL_KEY))) {\n                za = o.TIMELINE_KEY;\n            }\n        ;\n        ;\n            z = true;\n            aa = ya;\n            ba = ab.has_fixed_ads;\n            pa(xa.CONTENT, \"adjustContentPadding\");\n            fa.push(JSBNG__Event.listen(window, \"JSBNG__scroll\", t(ra, 100)), JSBNG__Event.listen(window, \"resize\", t(ua, 100)));\n            ca = g.subscribe([\"sidebar/initialized\",\"sidebar/show\",\"sidebar/hide\",], va);\n            k.JSBNG__onLeave(wa);\n            xa.registerCurrentKey(za);\n        },\n        setAdsTracking: function(ya) {\n            pa(xa.ADS, \"start\", [ya,]);\n        },\n        coverHasExpanded: function(ya) {\n            r(\"rightCol\").style.paddingTop = ((ya + \"px\"));\n            ia = true;\n            var za = r(\"pagelet_above_header_timeline\");\n            if (za.firstChild) {\n                r(\"above_header_timeline_placeholder\").style.height = ((za.offsetHeight + \"px\"));\n                za.style.JSBNG__top = ((ya + \"px\"));\n                ja = true;\n            }\n        ;\n        ;\n            var ab = JSBNG__document.documentElement;\n            ka = ((((ab.clientHeight < 400)) || ((ab.clientWidth < ab.scrollWidth))));\n            if (ka) {\n                r(\"blueBar\").style.paddingTop = ((ya + \"px\"));\n            }\n        ;\n        ;\n            ga = JSBNG__Event.listen(window, \"JSBNG__scroll\", qa);\n            g.inform(\"reflow\");\n        },\n        pageHasScrubber: function(ya) {\n            return ((((!ya || ya.match(/^(og_)?app_/))) || ((ya in la))));\n        },\n        fixedAds: function() {\n            return ba;\n        },\n        registerCurrentKey: function(ya) {\n            y = ya;\n            var za = ((p.getViewportDimensions().y < w));\n            pa(xa.ADS, \"setShortMode\", [za,ya,]);\n            pa(xa.ADS, \"updateCurrentKey\", [ya,]);\n            ha = ((((ya == o.TIMELINE_KEY)) ? ((u - v)) : 0));\n        },\n        getCurrentKey: function() {\n            return y;\n        },\n        getSectionKeys: function() {\n            return ma;\n        },\n        getCurrentScrubber: function() {\n            return da[xa.SCRUBBER];\n        },\n        getCurrentStickyHeaderNav: function() {\n            return da[xa.STICKY_HEADER_NAV];\n        },\n        getSection: function(ya) {\n            return pa(xa.CONTENT, \"getSection\", [ya,]);\n        },\n        scrubberHasLoaded: function(ya) {\n            pa(xa.STICKY_HEADER_NAV, \"addTimePeriods\", [ma,]);\n            pa(xa.ADS, \"registerScrubber\", [ya,]);\n        },\n        registerSectionKey: function(ya, za) {\n            if (da[xa.STICKY_HEADER_NAV]) {\n                pa(xa.STICKY_HEADER_NAV, \"addTimePeriod\", [ya,]);\n            }\n             else ma[za] = ya;\n        ;\n        ;\n        },\n        scrubberHasChangedState: function() {\n            pa(xa.ADS, \"adjustAdsToFit\");\n        },\n        scrubberWasClicked: function(ya) {\n            pa(xa.LOGGING, \"logScrubberClick\", [ya,]);\n        },\n        sectionHasChanged: function(ya, za) {\n            pa(xa.STICKY_HEADER_NAV, \"updateSection\", [ya,za,]);\n            pa(xa.SCRUBBER, \"updateSection\", [ya,za,]);\n            pa(xa.ADS, \"loadAdsIfEnoughTimePassed\");\n            pa(xa.LOGGING, \"logSectionChange\", [ya,za,]);\n        },\n        navigateToSection: function(ya) {\n            pa(xa.CONTENT, \"navigateToSection\", [ya,]);\n        },\n        shouldShowWideAds: function() {\n            if (!na) {\n                return false;\n            }\n        ;\n        ;\n            var ya = ((x + q.getRight()));\n            return ((p.getViewportDimensions().x >= ya));\n        },\n        sidebarInitialized: function() {\n            return na;\n        },\n        adjustStickyHeaderWidth: function() {\n            pa(xa.STICKY_HEADER, \"adjustWidth\");\n        },\n        register: function(ya, za) {\n            da[ya] = za;\n            if (ea[ya]) {\n                for (var ab in ea[ya]) {\n                    pa(ya, ab, ea[ya][ab]);\n                ;\n                };\n            ;\n                delete ea[ya];\n            }\n        ;\n        ;\n        },\n        adjustScrollingPagerBuffer: function(ya, za) {\n            var ab = i.get(n.DS_COLUMN_HEIGHT_DIFFERENTIAL, za);\n            if (!ab) {\n                return;\n            }\n        ;\n        ;\n            var bb = l.getInstance(ya);\n            ((bb && bb.setBuffer(((bb.getBuffer() + Math.abs(ab))))));\n        },\n        runOnceWhenSectionFullyLoaded: function(ya, za, ab) {\n            if (pa(xa.CONTENT, \"getSection\", [za,])) {\n                var bb = false;\n                j.scry(da[xa.CONTENT].getSection(za).node, \"ol.fbTimelineCapsule\").forEach(function(db) {\n                    if (((!bb && ((parseInt(i.get(n.DS_LOADED, db.id), 10) >= parseInt(ab, 10)))))) {\n                        ya();\n                        bb = true;\n                    }\n                ;\n                ;\n                });\n                if (bb) {\n                    return;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            var cb = g.subscribe(xa.SECTION_FULLY_LOADED, function(db, eb) {\n                if (((((eb.scrubberKey === za)) && ((eb.pageIndex === ab))))) {\n                    ya();\n                    cb.unsubscribe();\n                }\n            ;\n            ;\n            });\n        }\n    };\n    e.exports = xa;\n});\n__d(\"TimelineDrag\", [\"event-extensions\",\"ArbiterMixin\",\"Class\",\"Locale\",\"Style\",\"Vector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"Class\"), i = b(\"Locale\"), j = b(\"Style\"), k = b(\"Vector\"), l = b(\"copyProperties\");\n    function m(n, o, p) {\n        p = ((p || {\n        }));\n        this._listenOn = p.listenOn;\n        this._offsetInput = o;\n        this._defaultOffset = p.default_offset;\n        this._killClicks = p.killClicks;\n        this._vertical = true;\n        this._RTLXSwitch = false;\n        this.setPicture(n, p);\n    };\n;\n    l(m.prototype, g, {\n        setPicture: function(n, o) {\n            if (!n) {\n                return false;\n            }\n        ;\n        ;\n            o = ((o || {\n            }));\n            this._picture = n;\n            this._defaultOffset = o.default_offset;\n            if (((o.vertical !== undefined))) {\n                this._vertical = o.vertical;\n            }\n        ;\n        ;\n            if (this._vertical) {\n                if (o.height) {\n                    this._containerHeight = o.height;\n                }\n            ;\n            ;\n                this._offsetType = \"JSBNG__top\";\n                this._eventCoord = \"y\";\n            }\n             else {\n                if (o.width) {\n                    this._containerWidth = o.width;\n                }\n            ;\n            ;\n                this._RTLXSwitch = i.isRTL();\n                this._offsetType = \"left\";\n                this._eventCoord = \"x\";\n            }\n        ;\n        ;\n            if (this._picture.complete) {\n                this._initialLoad();\n            }\n             else this._loadListener = JSBNG__Event.listen(this._picture, \"load\", function() {\n                this._loadListener.remove();\n                this._initialLoad();\n            }.bind(this));\n        ;\n        ;\n        },\n        destroy: function() {\n            this._stopDrag();\n            this._saveOffset();\n            ((this._mousedown && this._mousedown.remove()));\n            ((this._onclick && this._onclick.remove()));\n            ((this._loadListener && this._loadListener.remove()));\n        },\n        _initialLoad: function() {\n            var n = ((this._listenOn ? this._listenOn : this._picture));\n            ((this._mousedown && this._mousedown.remove()));\n            this._mousedown = JSBNG__Event.listen(n, \"mousedown\", this._onMouseDown.bind(this));\n            if (this._vertical) {\n                this._maxOffset = ((this._containerHeight - this._picture.offsetHeight));\n            }\n             else this._maxOffset = ((this._containerWidth - this._picture.width));\n        ;\n        ;\n            if (((this._defaultOffset !== undefined))) {\n                this._setOffset(this._defaultOffset);\n            }\n        ;\n        ;\n            ((this._onclick && this._onclick.remove()));\n            if (this._killClicks) {\n                this._onclick = JSBNG__Event.listen(n, \"click\", this._onClick.bind(this));\n            }\n        ;\n        ;\n            this._saveOffset();\n        },\n        _onClick: function(JSBNG__event) {\n            JSBNG__event.kill();\n        },\n        _onMouseDown: function(JSBNG__event) {\n            var n = ((parseInt(j.get(this._picture, this._offsetType), 10) || 0));\n            this._pictureStartDragOffset = ((n - k.getEventPosition(JSBNG__event)[this._eventCoord]));\n            this._startDrag();\n            JSBNG__event.kill();\n        },\n        _startDrag: function() {\n            if (!this._dragStarted) {\n                this.inform(\"startdrag\", this);\n                this._dragTokens = [JSBNG__Event.listen(JSBNG__document.documentElement, \"mouseup\", this._onMouseUp.bind(this)),JSBNG__Event.listen(JSBNG__document.documentElement, \"mousemove\", this._onMouseMove.bind(this)),];\n                this._dragStarted = true;\n            }\n        ;\n        ;\n        },\n        _saveOffset: function() {\n            var n = parseInt(j.get(this._picture, this._offsetType), 10);\n            if (this._RTLXSwitch) {\n                this._offsetInput.value = ((((n + this._containerWidth)) - this._picture.offsetWidth));\n            }\n             else this._offsetInput.value = n;\n        ;\n        ;\n        },\n        _stopDrag: function() {\n            if (this._dragStarted) {\n                this.inform(\"stopdrag\", this);\n                this._dragStarted = false;\n                this._dragTokens.forEach(function(n) {\n                    n.remove();\n                });\n                this._saveOffset();\n            }\n        ;\n        ;\n        },\n        _onMouseUp: function(JSBNG__event) {\n            this._stopDrag();\n            JSBNG__event.kill();\n        },\n        _setOffset: function(n) {\n            if (this._RTLXSwitch) {\n                n = Math.max(0, Math.min(n, -this._maxOffset));\n            }\n             else n = Math.min(0, Math.max(n, this._maxOffset));\n        ;\n        ;\n            j.set(this._picture, this._offsetType, ((n + \"px\")));\n        },\n        _onMouseMove: function(JSBNG__event) {\n            this._setOffset(((this._pictureStartDragOffset + k.getEventPosition(JSBNG__event)[this._eventCoord])));\n            JSBNG__event.kill();\n        }\n    });\n    e.exports = m;\n});\n__d(\"TimelineCover\", [\"Button\",\"CSS\",\"DOM\",\"HTML\",\"Parent\",\"DOMScroll\",\"Vector\",\"TimelineController\",\"TimelineDrag\",\"Style\",\"$\",\"copyProperties\",\"ge\",], function(a, b, c, d, e, f) {\n    var g = b(\"Button\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"HTML\"), k = b(\"Parent\"), l = b(\"DOMScroll\"), m = b(\"Vector\"), n = b(\"TimelineController\"), o = b(\"TimelineDrag\"), p = b(\"Style\"), q = b(\"$\"), r = b(\"copyProperties\"), s = b(\"ge\");\n    function t(u, v, w) {\n        this.root = q(\"fbProfileCover\");\n        this._parentSection = k.byClass(this.root, \"fbTimelineSection\");\n        this._coverHeight = v;\n        this.cover = i.JSBNG__find(this.root, \".cover\");\n        t.instance = this;\n        this.previewing = w;\n        this.editing = false;\n        if (w) {\n            this.updateCoverImage(w);\n        }\n         else if (this.cover.getAttribute(\"data-collapse\")) {\n            this._expandCover(parseInt(this.cover.getAttribute(\"data-collapse\"), 10));\n        }\n        \n    ;\n    ;\n        if (this.previewing) {\n            this.editMode();\n        }\n    ;\n    ;\n        n.register(n.COVER, this);\n    };\n;\n    t.instance = null;\n    t.getInstance = function() {\n        return t.instance;\n    };\n    r(t.prototype, {\n        showLoadingIndicator: function() {\n            var u = s(\"fbCoverImageContainer\");\n            if (u) {\n                h.addClass(u, \"opaquedLoading\");\n            }\n        ;\n        ;\n        },\n        hideLoadingIndicator: function() {\n            var u = s(\"fbCoverImageContainer\");\n            if (u) {\n                h.removeClass(u, \"opaquedLoading\");\n            }\n        ;\n        ;\n        },\n        editMode: function() {\n            g.setEnabled(i.JSBNG__find(this.root, \"label.cancelButton\"), true);\n            g.setEnabled(i.JSBNG__find(this.root, \"label.saveButton\"), true);\n            this.hideLoadingIndicator();\n            this._coverImage = i.scry(this.root, \".coverImage\")[0];\n            var u = i.scry(this._coverImage, \".coverWrap\")[0];\n            if (u) {\n                this._originalOffset = p.get(i.JSBNG__find(u, \".coverPhotoImg\"), \"JSBNG__top\");\n            }\n        ;\n        ;\n            h.addClass(this._parentSection, \"fbEditCover\");\n            l.JSBNG__scrollTo(this.root);\n            if (this.previewing) {\n                i.remove(this._coverImage);\n                h.show(this._coverImage);\n            }\n        ;\n        ;\n            var v = i.scry(this._coverImage, \".coverPhotoImg\")[0];\n            if (v) {\n                this._createDragger();\n            }\n        ;\n        ;\n            this.editing = true;\n        },\n        _expandCover: function(u) {\n            u -= 1;\n            this.cover.style.marginTop = \"0px\";\n            if (((u != m.getScrollPosition().y))) {\n                window.JSBNG__scrollBy(0, u);\n                n.coverHasExpanded(u);\n            }\n        ;\n        ;\n        },\n        _exitEditMode: function() {\n            if (this._timelineDrag) {\n                this._timelineDrag.destroy();\n                this._timelineDrag = null;\n            }\n        ;\n        ;\n            i.JSBNG__find(this.root, \"input.hiddenPhotoID\").value = null;\n            i.JSBNG__find(this.root, \"input.hiddenVideoID\").value = null;\n            g.setEnabled(i.JSBNG__find(this.root, \"label.cancelButton\"), false);\n            g.setEnabled(i.JSBNG__find(this.root, \"label.saveButton\"), false);\n            h.removeClass(this._parentSection, \"fbEditCover\");\n            this.hideLoadingIndicator();\n        },\n        _createDragger: function() {\n            this._timelineDrag = new o(i.JSBNG__find(this.root, \".coverImage .coverPhotoImg\"), i.JSBNG__find(this.root, \"input.photoOffsetInput\"), {\n                height: this._coverHeight,\n                listenOn: this.cover,\n                vertical: true,\n                killClicks: true\n            });\n        },\n        updateCoverImage: function(u, v, w) {\n            this.videoID = w;\n            if (v) {\n                this.editMode();\n            }\n        ;\n        ;\n            i.JSBNG__find(this.root, \"input.hiddenPhotoID\").value = u;\n            i.JSBNG__find(this.root, \"input.hiddenVideoID\").value = ((w || null));\n            g.setEnabled(i.JSBNG__find(this.root, \"label.saveButton\"), true);\n            if (v) {\n                i.replace(i.JSBNG__find(this.root, \".coverImage\"), j(v));\n            }\n        ;\n        ;\n            if (this._timelineDrag) {\n                this._timelineDrag.setPicture(i.JSBNG__find(i.JSBNG__find(this.root, \".coverImage\"), \".coverPhotoImg\"));\n            }\n             else this._createDragger();\n        ;\n        ;\n        },\n        cancelUpdate: function() {\n            i.remove(i.scry(this.root, \".coverImage\")[0]);\n            i.prependContent(this.cover, this._coverImage);\n            if (((this._originalOffset !== undefined))) {\n                p.set(i.JSBNG__find(this._coverImage, \".coverPhotoImg\"), \"JSBNG__top\", this._originalOffset);\n            }\n        ;\n        ;\n            this._exitEditMode();\n        },\n        saveComplete: function() {\n            this._coverImage = i.scry(this.root, \".coverImage\")[0];\n            this._exitEditMode();\n        },\n        isInEditMode: function() {\n            return this.editing;\n        }\n    });\n    e.exports = t;\n});\nfunction TimelineCoverDisclaimer(a, b, c) {\n    if (((TimelineCoverDisclaimer.displayed === undefined))) {\n        TimelineCoverDisclaimer.displayed = true;\n    }\n     else return\n;\n    new Dialog().setModal(true).setTitle(a).setBody(b).setButtonsMessage(c).setButtons(Dialog.OK).show();\n};\n;\nrequireLazy([\"Selector\",], function(a) {\n    add_properties(\"__behaviors\", {\n    });\n    if (__behaviors.TimelineCurationControl) {\n        return;\n    }\n;\n;\n    __behaviors.TimelineCurationControl = true;\n    a.subscribe(\"open\", function(b, c) {\n        var d = c.selector, e = ((c.clone || d)), f = Parent.byClass(e, \"fbTimelineCurationControl\");\n        if (f) {\n            CSS.addClass(f, \"editControlsMenuOpen\");\n            var g = a.subscribe(\"close\", function(h, i) {\n                if (((i.selector == d))) {\n                    a.unsubscribe(g);\n                    CSS.removeClass.curry(f, \"editControlsMenuOpen\").defer();\n                }\n            ;\n            ;\n            });\n        }\n    ;\n    ;\n    });\n});\n__d(\"TimelineFriendsNavHovercard\", [\"event-extensions\",\"Hovercard\",\"UserAgent\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Hovercard\"), h = b(\"UserAgent\");\n    function i(JSBNG__event) {\n        var k = JSBNG__event.getTarget();\n        ((g.processNode(k) && JSBNG__event.JSBNG__stop()));\n    };\n;\n    var j = {\n        init: function(k) {\n            if (((h.ie() < 7))) {\n                return;\n            }\n        ;\n        ;\n            JSBNG__Event.listen(k, \"mouseover\", i);\n        }\n    };\n    e.exports = j;\n});\n__d(\"TimelinePerfConfig\", [], function(a, b, c, d, e, f) {\n    var g = null, h = function() {\n        if (((g === null))) {\n            return false;\n        }\n    ;\n    ;\n        return true;\n    }, i = {\n        init: function(j) {\n            g = j;\n        },\n        getDisablePageletThrottle: function() {\n            return ((h() && ((g.disablePageletThrottle || g.disableAllThrottle))));\n        },\n        getDisableAllThrottle: function() {\n            return ((h() && g.disableAllThrottle));\n        },\n        getDisableSpineHeight: function() {\n            return ((h() && g.disableSpineHeight));\n        }\n    };\n    e.exports = i;\n});\n__d(\"legacy:TimelinePerfConfig\", [\"TimelinePerfConfig\",], function(a, b, c, d) {\n    a.TimelinePerfConfig = b(\"TimelinePerfConfig\");\n}, 3);\n__d(\"TimelineProfilePic\", [\"Arbiter\",\"CSS\",\"Dialog\",\"DOM\",\"HTML\",\"Run\",\"$\",\"ge\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"CSS\"), i = b(\"Dialog\"), j = b(\"DOM\"), k = b(\"HTML\"), l = b(\"Run\"), m = b(\"$\"), n = b(\"ge\"), o = b(\"copyProperties\");\n    function p(q, r, s, t) {\n        p.destroyInstance();\n        p._instance = this;\n        this.leavingMessage = r;\n        this.elemID = ((s || \"fbProfileCover\"));\n        this.elemClass = ((t || \".profilePicThumb\"));\n        this._arbiterTokens = [g.subscribe(q.LOADING, this.startLoading.bind(this)),g.subscribe(q.SUCCESS, this.JSBNG__onUploadSuccess.bind(this)),];\n        l.JSBNG__onBeforeUnload(this.JSBNG__onBeforeUnload.bind(this));\n        l.JSBNG__onLeave(this.destroy.bind(this));\n    };\n;\n    o(p, {\n        _instance: null,\n        destroyInstance: function() {\n            ((this._instance && this._instance.destroy()));\n        }\n    });\n    o(p.prototype, {\n        _setLoadingIndicator: function(q) {\n            this._loading = q;\n            h.conditionClass(j.JSBNG__find(m(this.elemID), this.elemClass), \"profilePicLoading\", q);\n        },\n        destroy: function() {\n            this._arbiterTokens.forEach(function(q) {\n                q.unsubscribe();\n            });\n            this._arbiterTokens = [];\n            p._instance = null;\n        },\n        startLoading: function(q, r) {\n            this._setLoadingIndicator(r.isLoading);\n            if (n(\"fbProfilePicSelector\")) {\n                h.removeClass(m(\"fbProfilePicSelector\"), \"fbTimelineNullProfilePicSelector\");\n            }\n        ;\n        ;\n        },\n        JSBNG__onUploadSuccess: function(q, r) {\n            this._setLoadingIndicator(false);\n            var s = i.getCurrent();\n            if (s) {\n                s.hide();\n            }\n        ;\n        ;\n            j.replace(j.JSBNG__find(m(this.elemID), this.elemClass), k(r.newPic));\n            if (((((typeof (r.profileId) !== undefined)) && ((typeof (r.headerPicURL) !== undefined))))) {\n                var t = n(((\"profile_pic_header_\" + r.profileId)));\n                if (t) {\n                    t.src = r.headerPicURL;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        JSBNG__onBeforeUnload: function() {\n            if (((((p._instance === this)) && this._loading))) {\n                return this.leavingMessage;\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = p;\n});\n__d(\"TimelineSmartInsert\", [\"CSS\",\"DOM\",\"Run\",\"UserAgent\",\"Vector\",], function(a, b, c, d, e, f) {\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"Run\"), j = b(\"UserAgent\"), k = b(\"Vector\"), l = false, m = false;\n    function n() {\n        if (m) {\n            return;\n        }\n    ;\n    ;\n        i.JSBNG__onLeave(o);\n        m = true;\n    };\n;\n    function o() {\n        l = false;\n        m = false;\n    };\n;\n    var p = {\n        BUFFER: 100,\n        run: function(q, r) {\n            n();\n            if (((!l || ((j.ie() <= 8))))) {\n                r();\n                return;\n            }\n        ;\n        ;\n            var s = q.offsetHeight;\n            r();\n            var t = q.offsetHeight;\n            if (((((((t - s)) !== 0)) && ((((k.getElementPosition(q).y + s)) < ((k.getScrollPosition().y + p.BUFFER))))))) {\n                window.JSBNG__scrollBy(0, ((t - s)));\n            }\n        ;\n        ;\n        },\n        enable: function() {\n            l = true;\n        }\n    };\n    e.exports = p;\n});\n__d(\"TimelineThrottler\", [\"event-extensions\",\"Arbiter\",\"TimelinePerfConfig\",\"copyProperties\",\"debounce\",\"throttle\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"TimelinePerfConfig\"), i = b(\"copyProperties\"), j = b(\"debounce\"), k = b(\"throttle\");\n    function l(m) {\n        this.id = m;\n        this.idle = true;\n        this.keys = {\n        };\n        this.queue = [];\n        this.config = {\n        };\n        this.configure();\n        l.instances[m] = this;\n    };\n;\n    l.getInstance = function(m) {\n        return ((l.instances[m] || new l(m)));\n    };\n    l.instances = {\n    };\n    l.config = {\n    };\n    l.REQUEUE = \"requeue\";\n    g.subscribe(\"Timeline/throttle\", function(m, n) {\n        l.config = n;\n        for (var o in l.instances) {\n            l.instances[o].configure();\n        ;\n        };\n    ;\n    });\n    i(l.prototype, {\n        configure: function() {\n            if (this._handle) {\n                this._handle.remove();\n            }\n        ;\n        ;\n            var m = j(function() {\n                this.idle = true;\n                this._process();\n            }, ((l.config.scrollDelay || 400)), this), n = k(function() {\n                this.idle = false;\n                m();\n            }, ((l.config.scrollThrottle || 100)), this);\n            this._handle = JSBNG__Event.listen(window, \"JSBNG__scroll\", n);\n            i(this.config, l.config[this.id]);\n        },\n        cancel: function() {\n            this.idle = true;\n            this.keys = {\n            };\n            this.queue = [];\n            this.config = {\n            };\n            ((this._handle && this._handle.remove()));\n        },\n        _limit: function(m, n, o) {\n            if (h.getDisableAllThrottle()) {\n                m();\n                return;\n            }\n        ;\n        ;\n            var p = m;\n            if (n) {\n                if (this.keys[n]) {\n                    if (o) {\n                        this.queue.splice(this.queue.indexOf(this.keys[n]), 1);\n                    }\n                     else return\n                ;\n                }\n            ;\n            ;\n                this.keys[n] = m;\n                p = function() {\n                    delete this.keys[n];\n                    m();\n                }.bind(this);\n            }\n        ;\n        ;\n            this.queue.push(p);\n            this._process();\n        },\n        throttle: function(m, n) {\n            this._limit(m, n, false);\n        },\n        debounce: function(m, n) {\n            this._limit(m, n, true);\n        },\n        _process: function() {\n            if (((this.idle && this.queue.length))) {\n                var m = this.queue.shift(), n = m();\n                if (((n === l.REQUEUE))) {\n                    this.queue.push(m);\n                }\n            ;\n            ;\n                JSBNG__setTimeout(this._process.bind(this), ((this.config.delay || 0)));\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = l;\n});\n__d(\"TimelineContentLoader\", [\"event-extensions\",\"function-extensions\",\"Arbiter\",\"CSS\",\"DOM\",\"DOMScroll\",\"OnVisible\",\"ScrollingPager\",\"TimelineConstants\",\"TimelineController\",\"TimelinePerfConfig\",\"TimelineSmartInsert\",\"TimelineThrottler\",\"TimelineURI\",\"UIPagelet\",\"UserAgent\",\"Vector\",\"$\",\"copyProperties\",\"createArrayFrom\",\"debounce\",\"ge\",\"startsWith\",\"tx\",\"userAction\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"DOMScroll\"), k = b(\"OnVisible\"), l = b(\"ScrollingPager\"), m = b(\"TimelineConstants\"), n = b(\"TimelineController\"), o = b(\"TimelinePerfConfig\"), p = b(\"TimelineSmartInsert\"), q = b(\"TimelineThrottler\"), r = b(\"TimelineURI\"), s = b(\"UIPagelet\"), t = b(\"UserAgent\"), u = b(\"Vector\"), v = b(\"$\"), w = b(\"copyProperties\"), x = b(\"createArrayFrom\"), y = b(\"debounce\"), z = b(\"ge\"), aa = b(\"startsWith\"), ba = b(\"tx\"), ca = b(\"userAction\"), da = false, ea = false, fa, ga = {\n    }, ha = null, ia = {\n    }, ja = [], ka = [], la = {\n    }, ma = {\n    }, na = {\n    }, oa = {\n    }, pa = null, qa = null, ra = null, sa = false, ta = null;\n    function ua(fb, gb, hb, ib, jb) {\n        this.node = fb;\n        this.loaded = ib;\n        this.canScrollLoad = true;\n        this.canUnload = ((gb != eb.RECENT));\n        this.scrubberKey = gb;\n        this.historicUnitCount = jb;\n        this._pageletLoadData = hb;\n        this._expandPageletLoadData = {\n        };\n    };\n;\n    w(ua.prototype, {\n        load: function(fb) {\n            if (this.loaded) {\n                return;\n            }\n        ;\n        ;\n            var gb = this._pageletLoadData;\n            g.inform(n.SECTION_LOADING, {\n                data: gb,\n                scrubberKey: this.scrubberKey\n            });\n            this.loaded = true;\n            h.removeClass(this.node, \"fbTimelineTimePeriodUnexpanded\");\n            h.removeClass(this.node, \"fbTimelineTimePeriodSuppressed\");\n            var hb = \"ProfileTimelineSectionPagelet\";\n            if (((this.scrubberKey == eb.WAY_BACK))) {\n                hb = \"ProfileTimelineRemainingYearsPagelet\";\n            }\n        ;\n        ;\n            gb.time_cutoff = eb.getTimeCutoff();\n            gb.highlight_unit_data = fb;\n            gb.parent_key = this.parentKey;\n            gb.force_no_friend_activity = sa;\n            h.addClass(this.node, \"fbTimelineSectionLoading\");\n            var ib = null;\n            if (((!fb && !o.getDisablePageletThrottle()))) {\n                ib = ya.curry(this.node);\n            }\n        ;\n        ;\n            if (((this.canUnload && ea))) {\n                var jb = this.node.firstChild.cloneNode(true);\n                h.hide(jb);\n                i.insertAfter(this.node, jb);\n            }\n             else this.canScrollLoad = false;\n        ;\n        ;\n            na[this.scrubberKey] = s.loadFromEndpoint(hb, this.node.id, gb, {\n                usePipe: true,\n                jsNonblock: true,\n                constHeight: true,\n                displayCallback: ib\n            });\n            db(this.scrubberKey);\n        },\n        preload: function() {\n            h.addClass(this.node, \"fbTimelineTimePeriodSuppressed\");\n            h.removeClass(this.node, \"fbTimelineTimePeriodUnexpanded\");\n            var fb = i.JSBNG__find(this.node, \"span.sectionLabel\");\n            if (fb.getAttribute(\"data-original-label\")) {\n                i.setContent(fb, fb.getAttribute(\"data-original-label\"));\n                fb.removeAttribute(\"data-original-label\");\n            }\n        ;\n        ;\n        },\n        unload: function() {\n            if (((!this.loaded || !this.canUnload))) {\n                return;\n            }\n        ;\n        ;\n            this.loaded = false;\n            ((na[this.scrubberKey] && na[this.scrubberKey].cancel()));\n            h.addClass(this.node, \"fbTimelineTimePeriodUnexpanded\");\n            h.removeClass(this.node, \"fbTimelineTimePeriodSuppressed\");\n            if (((this.node.nextSibling && h.hasClass(this.node.nextSibling, \"fbTimelineSection\")))) {\n                i.setContent(this.node, this.node.nextSibling);\n                h.show(this.node.firstChild);\n            }\n             else i.empty(this.node);\n        ;\n        ;\n            this.deactivateScrollLoad();\n        },\n        activateScrollLoad: function() {\n            this.canScrollLoad = true;\n            h.removeClass(this.node, \"fbTimelineTimePeriodSuppressed\");\n            h.addClass(this.node, \"fbTimelineTimePeriodUnexpanded\");\n            ((ma[this.scrubberKey] && ma[this.scrubberKey].reset()));\n        },\n        deactivateScrollLoad: function() {\n            if (!this.loaded) {\n                this.canScrollLoad = false;\n                h.removeClass(this.node, \"fbTimelineTimePeriodUnexpanded\");\n                h.addClass(this.node, \"fbTimelineTimePeriodSuppressed\");\n                ((ma[this.scrubberKey] && ma[this.scrubberKey].remove()));\n            }\n        ;\n        ;\n        },\n        setExpandLoadData: function(fb) {\n            this._expandPageletLoadData = fb;\n            return this;\n        },\n        expandSubSections: function() {\n            if (this.subSections.length) {\n                eb.navigateToSection(this.subSections[0].scrubberKey);\n            }\n        ;\n        ;\n        },\n        expand: function(fb) {\n            if (!this.loaded) {\n                return;\n            }\n        ;\n        ;\n            ra.add_event(((\"expand_\" + this.scrubberKey)));\n            var gb = i.JSBNG__find(this.node, \".fbTimelineSectionExpander\");\n            h.addClass(gb.firstChild, \"async_saving\");\n            ((fb && h.addClass(fb, \"async_saving\")));\n            this._expandPageletLoadData.time_cutoff = eb.getTimeCutoff();\n            eb.navigateToSection(this.scrubberKey);\n            i.scry(this.node, \"ol.fbTimelineCapsule\").forEach(i.remove);\n            this._expandPageletLoadData.new_expand = true;\n            ((na[this.scrubberKey] && na[this.scrubberKey].cancel()));\n            na[this.scrubberKey] = s.loadFromEndpoint(\"ProfileTimelineSectionPagelet\", gb.id, this._expandPageletLoadData, {\n                usePipe: true,\n                jsNonblock: true,\n                constHeight: true\n            });\n        },\n        isPermalinkPeriod: function() {\n            return this._pageletLoadData.is_permalink_period;\n        }\n    });\n    function va() {\n        if (da) {\n            return;\n        }\n    ;\n    ;\n        n.register(n.CONTENT, eb);\n        ra = ca(\"scrubber\").set_namespace(\"timeline\").set_ua_id(\"scrubber\");\n        da = true;\n        if (((t.ie() <= 7))) {\n            ea = true;\n        }\n    ;\n    ;\n    };\n;\n    var wa = y(function(fb, gb, hb) {\n        var ib = eb.getSection(fb).historicUnitCount;\n        gb -= ib;\n        hb -= 1;\n        if (((((((ib == -1)) || ((hb <= 0)))) || ((gb < 0))))) {\n            return;\n        }\n    ;\n    ;\n        var jb = eb.getNextSectionKey(fb);\n        if (jb) {\n            eb.getSection(jb).load();\n            wa(jb, gb, hb);\n        }\n    ;\n    ;\n    }, 500), xa = {\n    };\n    function ya(fb, gb) {\n        pa = q.getInstance(\"displayPagelet\");\n        pa.throttle(function() {\n            var hb = u.getViewportDimensions().y, ib = u.getScrollPosition().y, jb = ((ib + hb)), kb = ((ib + ((hb * ((pa.config.fociRatio || 54191)))))), lb = u.getElementPosition(fb).y;\n            if (((lb > kb))) {\n                if (((lb < jb))) {\n                    xa[fb.id] = ((((xa[fb.id] || 0)) + 1));\n                    if (((xa[fb.id] < ((pa.config.fociPenalty || 3))))) {\n                        return q.REQUEUE;\n                    }\n                ;\n                ;\n                }\n                 else {\n                    delete xa[fb.id];\n                    return q.REQUEUE;\n                }\n            ;\n            }\n        ;\n        ;\n            delete xa[fb.id];\n            gb();\n        });\n    };\n;\n    function za(fb, gb, hb, ib) {\n        var jb = eb.getNextSectionKey(gb);\n        if (jb) {\n            ma[jb] = new k(fb, ab.curry(jb, fb), false, ((hb || 1000)));\n        }\n         else if (((gb !== eb.WAY_BACK))) {\n            ib = ((ib ? ib : 0));\n            if (((ib > 80))) {\n                return null;\n            }\n        ;\n        ;\n            za.curry(fb, gb, hb, ((ib + 1))).defer(250);\n        }\n        \n    ;\n    ;\n    };\n;\n    function ab(fb, gb) {\n        if (ga[fb].canScrollLoad) {\n            ra.add_event(((\"scroll_load_\" + fb)));\n            if (ea) {\n                eb.getSection(fb).preload();\n            }\n             else {\n                eb.getSection(fb).load();\n                if (ta) {\n                    wa(fb, ta.required_units, ta.max_parallelism);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            ((gb && i.remove(gb)));\n        }\n    ;\n    ;\n    };\n;\n    function bb() {\n        var fb, gb, hb = false;\n        for (var ib = 0; ((ib < ja.length)); ib++) {\n            var jb = ja[ib];\n            if (!jb) {\n                continue;\n            }\n        ;\n        ;\n            var kb = eb.getSection(jb);\n            if (((kb.canScrollLoad || kb.loaded))) {\n                if (!kb.loaded) {\n                    h.removeClass(kb.node, \"fbTimelineTimePeriodSuppressed\");\n                    h.addClass(kb.node, \"fbTimelineTimePeriodUnexpanded\");\n                }\n            ;\n            ;\n                if (((fb && gb))) {\n                    cb(fb, gb);\n                    if (hb) {\n                        fb.deactivateScrollLoad();\n                    }\n                ;\n                ;\n                    hb = true;\n                }\n            ;\n            ;\n                fb = null;\n                gb = null;\n                continue;\n            }\n             else if (fb) {\n                gb = kb;\n                kb.deactivateScrollLoad();\n            }\n             else {\n                fb = kb;\n                if (hb) {\n                    kb.activateScrollLoad();\n                }\n            ;\n            ;\n            }\n            \n        ;\n        ;\n            h.removeClass(kb.node, \"fbTimelineTimePeriodSuppressed\");\n            h.addClass(kb.node, \"fbTimelineTimePeriodUnexpanded\");\n        };\n    ;\n    };\n;\n    function cb(fb, gb) {\n        h.removeClass(gb.node, \"fbTimelineTimePeriodUnexpanded\");\n        h.addClass(gb.node, \"fbTimelineTimePeriodSuppressed\");\n        var hb = i.JSBNG__find(fb.node, \"span.sectionLabel\"), ib = i.JSBNG__find(gb.node, \"span.sectionLabel\");\n        if (!ib.getAttribute(\"data-original-label\")) {\n            ib.setAttribute(\"data-original-label\", i.getText(ib));\n        }\n    ;\n    ;\n        if (((((hb.getAttribute(\"data-month\") && ib.getAttribute(\"data-month\"))) && ((hb.getAttribute(\"data-year\") == ib.getAttribute(\"data-year\")))))) {\n            i.setContent(ib, ba._(\"Show {month1} - {month2} {year}\", {\n                month1: ib.getAttribute(\"data-month\"),\n                month2: hb.getAttribute(\"data-month\"),\n                year: hb.getAttribute(\"data-year\")\n            }));\n        }\n         else if (((hb.getAttribute(\"data-year\") !== ib.getAttribute(\"data-year\")))) {\n            i.setContent(ib, ba._(\"Show {year1} - {year2}\", {\n                year1: ib.getAttribute(\"data-year\"),\n                year2: hb.getAttribute(\"data-year\")\n            }));\n        }\n         else i.setContent(ib, ba._(\"Show {year}\", {\n            year: ib.getAttribute(\"data-year\")\n        }));\n        \n    ;\n    ;\n    };\n;\n    function db(fb) {\n        if (ea) {\n            for (var gb = 0; ((gb < ((ja.length - 1)))); gb++) {\n                var hb = ja[gb];\n                if (!hb) {\n                    continue;\n                }\n            ;\n            ;\n                if (((hb != fb))) {\n                    var ib = ga[hb];\n                    if (((ib.loaded && ib.canUnload))) {\n                        ib.unload();\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            };\n        }\n    ;\n    ;\n        bb();\n    };\n;\n    var eb = {\n        WAY_BACK: \"way_back\",\n        RECENT: \"recent\",\n        HEADER_SCROLL_CUTOFF: 80,\n        CURRENT_SECTION_OFFSET: 150,\n        FOOTER_HEIGHT: 60,\n        registerTimePeriod: function(fb, gb, hb, ib, jb, kb, lb) {\n            va();\n            if (ka.contains(gb)) {\n                return;\n            }\n        ;\n        ;\n            var mb = new ua(fb, gb, hb, ib, lb);\n            if (!jb) {\n                ja[kb] = gb;\n                ia[gb] = true;\n            }\n             else {\n                mb.parentKey = jb;\n                ga[jb].subSections = ((ga[jb].subSections || []));\n                ga[jb].subSections[kb] = mb;\n            }\n        ;\n        ;\n            ga[gb] = mb;\n            eb.checkCurrentSectionChange();\n            g.inform(n.SECTION_REGISTERED, {\n                scrubberKey: gb\n            });\n            n.registerSectionKey(gb, kb);\n        },\n        reset: function() {\n            for (var fb in ma) {\n                ma[fb].remove();\n            ;\n            };\n        ;\n            for (var gb in na) {\n                na[gb].cancel();\n            ;\n            };\n        ;\n            for (var hb in oa) {\n                oa[hb].unsubscribe();\n                delete oa[hb];\n            };\n        ;\n            ((fa && fa.unsubscribe()));\n            fa = null;\n            ((pa && pa.cancel()));\n            pa = null;\n            ga = {\n            };\n            ha = null;\n            ia = {\n            };\n            ja = [];\n            ka = [];\n            la = {\n            };\n            ma = {\n            };\n            na = {\n            };\n            qa = null;\n            ra = null;\n            sa = false;\n            da = false;\n        },\n        checkCurrentSectionChange: function() {\n            var fb = eb.getCurrentSection(), gb = ((ha && ha.scrubberKey));\n            if (((((fb && ((fb.scrubberKey !== gb)))) && !fb.isPermalinkPeriod()))) {\n                ha = fb;\n                var hb = fb.scrubberKey, ib = fb.parentKey;\n                if (!ib) {\n                    ib = hb;\n                    hb = null;\n                }\n            ;\n            ;\n                n.sectionHasChanged(ib, hb);\n            }\n        ;\n        ;\n        },\n        setTimeCutoff: function(fb) {\n            qa = fb;\n        },\n        getTimeCutoff: function() {\n            return qa;\n        },\n        setParallelLoadConfig: function(fb) {\n            ta = fb;\n        },\n        getCurrentSection: function() {\n            var fb = {\n            };\n            for (var gb in ga) {\n                var hb = ga[gb];\n                if (((!hb.loaded || la[hb.scrubberKey]))) {\n                    continue;\n                }\n            ;\n            ;\n                var ib = u.getElementPosition(hb.node, \"viewport\").y;\n                if (((hb.scrubberKey == \"recent\"))) {\n                    ib--;\n                }\n            ;\n            ;\n                if (((ib < eb.CURRENT_SECTION_OFFSET))) {\n                    fb[ib] = hb;\n                }\n            ;\n            ;\n            };\n        ;\n            var jb = Math.max.apply(null, Object.keys(fb)), kb = ((jb == -Infinity));\n            if (!kb) {\n                return fb[jb];\n            }\n             else if (ja[0]) {\n                return ga[ja[0]];\n            }\n            \n        ;\n        ;\n            return null;\n        },\n        capsuleForCurrentSection: function() {\n            var fb = eb.getCurrentSection();\n            return ((fb && i.scry(fb.node, \"ol.fbTimelineCapsule\")[0]));\n        },\n        enableScrollLoad: function(fb, gb, hb, ib) {\n            fb = v(fb);\n            var jb = i.scry(fb.parentNode, \"ol.fbTimelineCapsule\")[0];\n            if (!jb) {\n                return;\n            }\n        ;\n        ;\n            if (((hb === null))) {\n                za(fb, gb, ib);\n            }\n             else n.runOnceWhenSectionFullyLoaded(za.curry(fb, gb, ib), gb, hb);\n        ;\n        ;\n        },\n        enableScrollLoadOnClick: function(fb, gb, hb) {\n            fb = v(fb);\n            JSBNG__Event.listen(fb, \"click\", function(ib) {\n                ib.preventDefault();\n                eb.enableScrollLoad(fb, gb, null, hb);\n            });\n        },\n        expandSectionOnClick: function(fb, gb) {\n            JSBNG__Event.listen(fb, \"click\", function(hb) {\n                hb.preventDefault();\n                eb.getSection(gb).expand();\n            });\n        },\n        expandSubSectionsOnClick: function(fb, gb) {\n            JSBNG__Event.listen(fb, \"click\", function(hb) {\n                hb.preventDefault();\n                eb.getSection(gb).expandSubSections();\n            });\n        },\n        getSection: function(fb) {\n            return ga[fb];\n        },\n        getNextSectionKey: function(fb) {\n            for (var gb = 0; ((gb < ((ja.length - 1)))); gb++) {\n                if (((ja[gb] == fb))) {\n                    while (((((gb < ((ja.length - 1)))) && !ja[((gb + 1))]))) {\n                        gb++;\n                    ;\n                    };\n                ;\n                    return ja[((gb + 1))];\n                }\n            ;\n            ;\n            };\n        ;\n            var hb = eb.getSection(fb);\n            if (((!hb || !hb.parentKey))) {\n                return;\n            }\n        ;\n        ;\n            var ib = eb.getSection(hb.parentKey);\n            if (!ib) {\n                return;\n            }\n        ;\n        ;\n            for (var jb = 0; ((jb < ((ib.subSections.length - 1)))); jb++) {\n                if (((ib.subSections[jb].scrubberKey == fb))) {\n                    return ib.subSections[((jb + 1))].scrubberKey;\n                }\n            ;\n            ;\n            };\n        ;\n        },\n        hideSection: function(fb) {\n            var gb = eb.getSection(fb);\n            ((gb && h.hide(gb.node)));\n            var hb = n.getCurrentScrubber();\n            if (hb) {\n                var ib = n.getCurrentScrubber().getNav(fb);\n                ((ib && h.hide(ib)));\n            }\n        ;\n        ;\n            var jb = n.getCurrentStickyHeaderNav();\n            ((jb && jb.removeTimePeriod(fb)));\n            la[fb] = true;\n        },\n        loadSectionOnClick: function(fb, gb) {\n            JSBNG__Event.listen(fb, \"click\", function(hb) {\n                hb.preventDefault();\n                eb.getSection(gb).load();\n            });\n        },\n        removeSection: function(fb) {\n            for (var gb in ja) {\n                if (((ja[gb] == fb))) {\n                    ja[gb] = null;\n                    break;\n                }\n            ;\n            ;\n            };\n        ;\n            delete ga[fb];\n            delete ia[fb];\n            if (((fb in ma))) {\n                ma[fb].remove();\n                delete ma[fb];\n            }\n        ;\n        ;\n            var hb = n.getCurrentStickyHeaderNav();\n            ((hb && hb.removeTimePeriod(fb)));\n            ka.push(fb);\n        },\n        removeSectionParent: function(fb) {\n            i.remove(v(fb).parentNode);\n        },\n        navigateToSection: function(fb, gb, hb) {\n            ra.add_event(((\"nav_\" + fb)));\n            gb = !!gb;\n            var ib = fb, jb = eb.getSection(fb);\n            if (!jb) {\n                return;\n            }\n        ;\n        ;\n            if (!jb.loaded) {\n                p.enable();\n            }\n        ;\n        ;\n            if (!ia[fb]) {\n                jb.node.style.minHeight = ((u.getViewportDimensions().y + \"px\"));\n                var kb = g.subscribe(n.SECTION_FULLY_LOADED, function(sb, tb) {\n                    if (((tb.scrubberKey === fb))) {\n                        jb.node.style.minHeight = \"\";\n                        kb.unsubscribe();\n                    }\n                ;\n                ;\n                });\n                ib = jb.parentKey;\n                var lb = eb.getSection(ib).node;\n                if (!h.hasClass(lb, \"fbTimelineSectionExpanded\")) {\n                    j.JSBNG__scrollTo(lb, 0);\n                    h.addClass(lb, \"fbTimelineSectionExpanded\");\n                    i.scry(lb, \"ol.fbTimelineCapsule\").forEach(i.remove);\n                    i.scry(lb, \"div.fbTimelineSectionExpandPager\").forEach(i.remove);\n                    i.scry(lb, \"div.fbTimelineContentHeader\").forEach(i.remove);\n                }\n            ;\n            ;\n                var mb = eb.getNextSectionKey(ib);\n                if (((mb && ma[mb]))) {\n                    ma[mb].setBuffer(0);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            for (var nb = 0; ((nb < ja.length)); nb++) {\n                var ob = ja[nb];\n                if (!ob) {\n                    continue;\n                }\n            ;\n            ;\n                if (((ob == ib))) {\n                    break;\n                }\n            ;\n            ;\n                eb.getSection(ob).deactivateScrollLoad();\n                i.scry(v(\"timeline_tab_content\"), \".fbTimelineSectionExpandPager\").forEach(function(sb) {\n                    var tb = l.getInstance(sb.id);\n                    ((tb && tb.removeOnVisible()));\n                });\n            };\n        ;\n            eb.adjustContentPadding();\n            jb.load(hb);\n            bb();\n            var pb = u.getScrollPosition().x, qb = u.getElementPosition(jb.node).y;\n            if (!gb) {\n                var rb = ((ia[fb] ? m.SCROLL_TO_OFFSET : m.SUBSECTION_SCROLL_TO_OFFSET));\n                j.JSBNG__scrollTo(new u(pb, ((qb - rb)), \"JSBNG__document\"), true, false, false, function() {\n                    var sb = u.getElementPosition(jb.node).y;\n                    j.JSBNG__scrollTo(new u(pb, ((sb - rb)), \"JSBNG__document\"), false);\n                    var tb = i.scry(jb.node, \"h3.uiHeaderTitle\")[0];\n                    ((tb && tb.JSBNG__focus()));\n                });\n            }\n        ;\n        ;\n        },\n        adjustContentPadding: function() {\n            var fb = z(\"timeline_tab_content\");\n            if (!fb) {\n                return;\n            }\n        ;\n        ;\n            var gb = ((n.getCurrentKey() || r.TIMELINE_KEY));\n            if (((gb !== r.TIMELINE_KEY))) {\n                return;\n            }\n        ;\n        ;\n            var hb = eb.getSection(eb.WAY_BACK);\n            fb.style.paddingBottom = ((((hb && hb.loaded)) ? null : ((((((((u.getViewportDimensions().y - eb.CURRENT_SECTION_OFFSET)) - eb.HEADER_SCROLL_CUTOFF)) - eb.FOOTER_HEIGHT)) + \"px\"))));\n        },\n        adjustContentPaddingAfterLoad: function(fb, gb) {\n            n.runOnceWhenSectionFullyLoaded(eb.adjustContentPadding, fb, gb);\n        },\n        appendContentAfterLoad: function(fb, gb, hb) {\n            n.runOnceWhenSectionFullyLoaded(i.appendContent.curry(v(fb), gb), hb, \"0\");\n        },\n        markSectionAsLoaded: function(fb, gb, hb) {\n            n.runOnceWhenSectionFullyLoaded(function() {\n                ((z(fb) && h.removeClass(v(fb).parentNode, \"fbTimelineSectionLoading\")));\n            }, gb, hb);\n        },\n        suppressSectionsAbove: function(fb) {\n            var gb, hb;\n            for (var ib = 0; ((ib < ja.length)); ib++) {\n                var jb = ja[ib];\n                if (!jb) {\n                    continue;\n                }\n            ;\n            ;\n                gb = eb.getSection(jb).node;\n                hb = null;\n                if (((x(fb.parentNode.children).indexOf(fb) <= x(gb.parentNode.children).indexOf(gb)))) {\n                    hb = jb;\n                    break;\n                }\n            ;\n            ;\n                eb.getSection(jb).deactivateScrollLoad();\n            };\n        ;\n            if (hb) {\n                eb.navigateToSection(hb, true);\n            }\n        ;\n        ;\n        },\n        forceNoFriendActivity: function() {\n            sa = true;\n        },\n        removeDupes: function(fb) {\n            var gb = z(fb);\n            if (!gb) {\n                return;\n            }\n        ;\n        ;\n            var hb = i.scry(gb, \"li.fbTimelineUnit\"), ib = {\n            };\n            for (var jb = 0; ((jb < hb.length)); jb++) {\n                var kb = hb[jb];\n                if (((kb.id && aa(kb.id, \"tl_unit_\")))) {\n                    var lb = kb.id.substring(8, kb.id.length), mb = ((((kb.getAttribute(\"data-unit\") == \"ExperienceSummaryUnit\")) ? kb.getAttribute(\"data-time\") : 1));\n                    if (((ib.hasOwnProperty(lb) && ((ib[lb] == mb))))) {\n                        i.remove(kb);\n                    }\n                     else ib[lb] = mb;\n                ;\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n        },\n        removeLoadingState: function(fb) {\n            ((z(fb) && h.removeClass(v(fb), \"fbTimelineSectionLoading\")));\n        },\n        setExpandLoadDataForSection: function(fb, gb) {\n            var hb = eb.getSection(fb);\n            ((hb && hb.setExpandLoadData(gb)));\n        },\n        updatePagerAfterLoad: function(fb, gb, hb, ib) {\n            if (!l.getInstance(fb.firstChild.id)) {\n                oa[fb.firstChild.id] = g.subscribe(l.REGISTERED, function(jb, kb) {\n                    oa[fb.firstChild.id].unsubscribe();\n                    delete oa[fb.firstChild.id];\n                    if (((kb.id === fb.firstChild.id))) {\n                        eb.updatePagerAfterLoad(fb, gb, hb, ib);\n                    }\n                ;\n                ;\n                });\n            }\n        ;\n        ;\n            n.runOnceWhenSectionFullyLoaded(h.removeClass.curry(fb, \"fbTimelineHiddenPager\"), hb, ib);\n            n.runOnceWhenSectionFullyLoaded(n.adjustScrollingPagerBuffer.curry(fb.firstChild.id, gb), hb, ib);\n        }\n    };\n    e.exports = eb;\n});\n__d(\"TimelineCapsule\", [\"$\",\"Arbiter\",\"createArrayFrom\",\"CSS\",\"DataStore\",\"DOM\",\"DOMQuery\",\"DOMScroll\",\"ge\",\"Hovercard\",\"Parent\",\"TimelineConstants\",\"TimelineContentLoader\",\"TimelineController\",\"TimelineSmartInsert\",\"TimelineThrottler\",\"UserAgent\",\"Vector\",\"isEmpty\",\"requestAnimationFrame\",], function(a, b, c, d, e, f) {\n    var g = b(\"$\"), h = b(\"Arbiter\"), i = b(\"createArrayFrom\"), j = b(\"CSS\"), k = b(\"DataStore\"), l = b(\"DOM\"), m = b(\"DOMQuery\"), n = b(\"DOMScroll\"), o = b(\"ge\"), p = b(\"Hovercard\"), q = b(\"Parent\"), r = b(\"TimelineConstants\"), s = b(\"TimelineContentLoader\"), t = b(\"TimelineController\"), u = b(\"TimelineSmartInsert\"), v = b(\"TimelineThrottler\"), w = b(\"UserAgent\"), x = b(\"Vector\"), y = b(\"isEmpty\"), z = b(\"requestAnimationFrame\"), aa = (function() {\n        var ba = 45, ca = 15, da = \"use\", ea = \"update\", fa = {\n        }, ga = {\n        }, ha = {\n        }, ia = {\n        };\n        function ja(bb) {\n            return j.hasClass(bb, \"fbTimelineBalancer\");\n        };\n    ;\n        function ka(bb) {\n            return bb.getAttribute(\"data-spine\");\n        };\n    ;\n        function la(bb) {\n            return j.hasClass(bb, \"placeholderUnit\");\n        };\n    ;\n        function ma(bb) {\n            return bb.getAttribute(\"data-fixed\");\n        };\n    ;\n        function na(bb, cb) {\n            if (cb) {\n                return ((k.get(r.DS_SIDEORG, bb.id) || bb.getAttribute(\"data-side\")));\n            }\n        ;\n        ;\n            return bb.getAttribute(\"data-side\");\n        };\n    ;\n        var oa = function(bb, cb) {\n            if (((w.ie() <= 6))) {\n                oa = function(db, eb) {\n                    k.set(r.DS_SIDEORG, db.id, na(db, true));\n                    db.setAttribute(\"data-side\", eb);\n                    j.removeClass(db, \"leftColumn\");\n                    j.removeClass(db, \"rightColumn\");\n                    j.addClass(db, ((((eb == \"l\")) ? \"leftColumn\" : \"rightColumn\")));\n                };\n            }\n             else oa = function(db, eb) {\n                k.set(r.DS_SIDEORG, db.id, na(db, true));\n                db.setAttribute(\"data-side\", eb);\n            };\n        ;\n        ;\n            oa(bb, cb);\n        };\n        function pa(bb) {\n            return bb.getAttribute(\"data-size\");\n        };\n    ;\n        var qa = function(bb, cb) {\n            if (ja(bb)) {\n                return;\n            }\n        ;\n        ;\n            if (cb) {\n                j.addClass(bb, \"balancingCapsule\");\n            }\n             else j.removeClass(bb, \"balancingCapsule\");\n        ;\n        ;\n        };\n        function ra(bb) {\n            if (((((j.hasClass(bb, \"fbTimelineOneColumn\") && bb.prevSibling)) && j.hasClass(bb.prevSibling, \"fbTimelineOneColumn\")))) {\n                return ((ca * 2));\n            }\n        ;\n        ;\n            if (j.hasClass(bb, \"fbTimelineIndeterminateContent\")) {\n                return 0;\n            }\n        ;\n        ;\n            return ca;\n        };\n    ;\n        function sa(bb, cb) {\n            var db = 0;\n            if (((j.shown(bb) && !j.hasClass(bb, \"placeholderUnit\")))) {\n                if (((cb === da))) {\n                    db = k.get(r.DS_HEIGHT, bb.id, null);\n                    if (((db === null))) {\n                        db = bb.getAttribute(\"data-calculatedheight\");\n                    }\n                ;\n                ;\n                }\n                 else db = ((bb.offsetHeight + ra(bb)));\n            ;\n            }\n        ;\n        ;\n            if (((((cb === da)) && ((db === null))))) {\n                db = 300;\n            }\n        ;\n        ;\n            k.set(r.DS_HEIGHT, bb.id, parseInt(db, 10));\n        };\n    ;\n        function ta(bb) {\n            var cb = k.get(r.DS_HEIGHT, bb.id, null);\n            return cb;\n        };\n    ;\n        function ua(bb, cb) {\n            if (((pa(cb) == \"2\"))) {\n                return 0;\n            }\n             else if (((na(cb) == \"r\"))) {\n                return ((bb + ta(cb)));\n            }\n             else return ((bb - ta(cb)))\n            \n        ;\n        };\n    ;\n        function va(bb) {\n            var cb = bb.parentNode;\n            if (!cb) {\n                return;\n            }\n        ;\n        ;\n            var db = JSBNG__document.createDocumentFragment(), eb = bb.firstChild;\n            while (eb.firstChild) {\n                db.appendChild(eb.firstChild);\n            ;\n            };\n        ;\n            u.run(cb, l.replace.curry(bb, db));\n        };\n    ;\n        function wa(bb) {\n            for (var cb = 0; ((cb < bb.childNodes.length)); cb++) {\n                var db = bb.childNodes[cb];\n                if (!db.getAttribute(\"data-endmarker\")) {\n                    continue;\n                }\n            ;\n            ;\n                var eb = db.getAttribute(\"data-endmarker\"), fb = db.getAttribute(\"data-pageindex\"), gb = function() {\n                    k.set(r.DS_LOADED, bb.id, fb);\n                    l.remove(db);\n                    h.inform(t.SECTION_FULLY_LOADED, {\n                        scrubberKey: eb,\n                        pageIndex: fb,\n                        capsuleID: bb.id,\n                        childCount: bb.childNodes.length\n                    });\n                };\n                if (s.getSection(eb)) {\n                    gb();\n                }\n                 else var hb = h.subscribe(t.SECTION_REGISTERED, function(ib, jb) {\n                    if (((jb.scrubberKey === eb))) {\n                        gb();\n                        hb.unsubscribe();\n                    }\n                ;\n                ;\n                })\n            ;\n                break;\n            };\n        ;\n            qa(bb, false);\n            h.inform(\"TimelineCapsule/balanced\", {\n                capsule: bb\n            });\n        };\n    ;\n        function xa(bb, cb, db) {\n            while (cb[0]) {\n                oa(cb.pop(), \"l\");\n            ;\n            };\n        ;\n            while (db[0]) {\n                oa(db.pop(), \"r\");\n            ;\n            };\n        ;\n            if (ja(bb)) {\n                va(bb);\n            }\n        ;\n        ;\n            wa(bb);\n        };\n    ;\n        function ya(bb) {\n            if (y(fa[bb.id])) {\n                return;\n            }\n        ;\n        ;\n            var cb = ((ja(bb) ? bb.firstChild : bb)), db = cb.childNodes.length, eb = {\n            }, fb = {\n            }, gb, hb = ca, ib = ca, jb, kb = [];\n            for (var lb = 0; ((lb < db)); lb++) {\n                gb = cb.childNodes[lb];\n                if (j.hasClass(gb, \"fbTimelineUnit\")) {\n                    jb = m.scry(gb, \"div.timelineUnitContainer\")[0];\n                    if (jb) {\n                        fb[gb.id] = jb.getAttribute(\"data-time\");\n                    }\n                ;\n                ;\n                    if (((!la(gb) && j.shown(gb)))) {\n                        if (((pa(gb) == \"2\"))) {\n                            eb[gb.id] = Math.max(hb, ib);\n                            hb = ib = ((eb[gb.id] + ta(gb)));\n                        }\n                         else if (((na(gb) == \"r\"))) {\n                            eb[gb.id] = ib;\n                            ib += ta(gb);\n                        }\n                         else {\n                            eb[gb.id] = hb;\n                            hb += ta(gb);\n                        }\n                        \n                    ;\n                    ;\n                        if (((((na(gb, true) == \"l\")) || ((pa(gb) == \"2\"))))) {\n                            kb.push(gb.id);\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            for (lb = 0; ((lb < ((kb.length - 1)))); ++lb) {\n                var mb = kb[lb], nb = kb[((lb + 1))], ob = ((eb[mb] + ba)), pb = eb[nb];\n                for (var qb in fa[bb.id]) {\n                    if (((ob > pb))) {\n                        break;\n                    }\n                ;\n                ;\n                    var rb = fa[bb.id][qb];\n                    if (j.shown(rb)) {\n                        continue;\n                    }\n                ;\n                ;\n                    if (((((fb[qb] <= fb[mb])) && ((fb[qb] > fb[nb]))))) {\n                        rb.style.JSBNG__top = ((ob + \"px\"));\n                        ob += ba;\n                        j.show(rb);\n                    }\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n        };\n    ;\n        function za(bb, cb) {\n            var db = q.byAttribute(bb, \"data-size\");\n            if (db) {\n                if (j.hasClass(bb.parentNode, \"timelineReportContent\")) {\n                    cb(bb);\n                }\n                 else cb(db);\n            ;\n            ;\n                aa.balanceCapsule(q.byClass(db, \"fbTimelineCapsule\"));\n            }\n        ;\n        ;\n        };\n    ;\n        function ab(bb) {\n            var cb = 0;\n            for (var db = 0; ((db < bb.childNodes.length)); db++) {\n                if (j.hasClass(bb.childNodes[db], \"fbTimelineUnit\")) {\n                    cb++;\n                }\n            ;\n            ;\n            };\n        ;\n            return cb;\n        };\n    ;\n        return {\n            getUnitsWithTime: function(bb) {\n                return m.scry(bb, \"div.timelineUnitContainer\").filter(function(cb) {\n                    return ((((cb.parentNode.parentNode === bb)) && cb.getAttribute(\"data-time\")));\n                });\n            },\n            removeUnit: function(bb) {\n                za(bb, function(cb) {\n                    l.remove(cb);\n                });\n            },\n            hideUnit: function(bb) {\n                za(bb, function(cb) {\n                    j.addClass(cb, \"fbTimelineColumnHidden\");\n                });\n            },\n            undoHideUnit: function(bb, cb) {\n                l.remove(q.byClass(cb, \"hiddenText\"));\n                za(bb, function(db) {\n                    j.removeClass(db, \"fbTimelineColumnHidden\");\n                });\n            },\n            unplacehold: function(bb) {\n                var cb = g(bb);\n                cb.style.JSBNG__top = null;\n                j.removeClass(cb, \"visiblePlaceholder\");\n                j.removeClass(cb, \"placeholder\");\n                var db = q.byClass(cb, \"fbTimelineCapsule\");\n                delete fa[db.id][bb];\n                aa.balanceCapsule(db);\n            },\n            scrollToCapsule: function(bb) {\n                if (!ia.hasOwnProperty(bb.id)) {\n                    var cb = x.getElementPosition(bb.parentNode);\n                    n.JSBNG__scrollTo(new x(x.getScrollPosition().x, ((cb.y - r.SUBSECTION_SCROLL_TO_OFFSET)), \"JSBNG__document\"));\n                    ia[bb.id] = true;\n                }\n            ;\n            ;\n            },\n            setFirstUnit: function(bb) {\n                var cb = true, db = bb.childNodes.length;\n                for (var eb = 0; ((eb < db)); eb++) {\n                    var fb = bb.childNodes[eb];\n                    if (((fb.id.indexOf(\"tl_unit_\") === 0))) {\n                        if (cb) {\n                            cb = false;\n                            j.addClass(fb, \"firstUnit\");\n                        }\n                         else {\n                            j.removeClass(fb, \"firstUnit\");\n                            break;\n                        }\n                    ;\n                    }\n                ;\n                ;\n                };\n            ;\n            },\n            balanceCapsule: function(bb, cb) {\n                if (!bb) {\n                    return;\n                }\n            ;\n            ;\n                if (((bb.getAttribute(\"data-layout\") == \"fixed\"))) {\n                    v.getInstance(\"balanceCapsuleFixed\").debounce(aa.balanceFixed.curry(bb, cb), bb.id);\n                }\n                 else v.getInstance(\"balanceCapsule\").throttle(aa.balance.curry(bb, 0), bb.id);\n            ;\n            ;\n            },\n            balanceCapsuleFromChild: function(bb, cb) {\n                aa.balanceCapsule(q.byClass(bb, \"fbTimelineCapsule\"), cb);\n            },\n            balanceFixed: function(bb, cb) {\n                if (!bb) {\n                    return;\n                }\n            ;\n            ;\n                var db = 0, eb, fb = JSBNG__document.createDocumentFragment(), gb = [], hb = [], ib = [], jb = false, kb = ((cb && cb.heights_action));\n                if (((((kb !== ea)) && ((w.JSBNG__chrome() || w.safari()))))) {\n                    j.toggleClass(bb, \"webkitFix\");\n                }\n            ;\n            ;\n                for (var lb = 0; ((lb < bb.childNodes.length)); lb++) {\n                    eb = bb.childNodes[lb];\n                    if (ka(eb)) {\n                        continue;\n                    }\n                     else if (ja(eb)) {\n                        i(eb.firstChild.childNodes).forEach(function(sb) {\n                            sa(sb, kb);\n                        });\n                        continue;\n                    }\n                    \n                ;\n                ;\n                    sa(eb, kb);\n                    if (((na(eb, true) == \"r\"))) {\n                        hb.push(eb);\n                    }\n                     else gb.push(eb);\n                ;\n                ;\n                    ib.push(eb);\n                    if (((pa(eb) != \"2\"))) {\n                        if (((((((db > 0)) && ((na(eb) == \"r\")))) || ((((db < 0)) && ((na(eb) == \"l\"))))))) {\n                            jb = true;\n                        }\n                    ;\n                    }\n                ;\n                ;\n                    db = ua(db, eb);\n                };\n            ;\n                var mb = [], nb = [], ob = [];\n                m.scry(bb, \"li.fbTimelineBalancer\").forEach(function(sb) {\n                    var tb = i(sb.firstChild.childNodes);\n                    if (sb.getAttribute(\"data-nonunits\")) {\n                        ob = ob.concat(tb);\n                    }\n                     else if (((na(sb) == \"left\"))) {\n                        mb = mb.concat(tb);\n                    }\n                     else if (((na(sb) == \"right\"))) {\n                        nb = nb.concat(tb);\n                    }\n                    \n                    \n                ;\n                ;\n                });\n                if (jb) {\n                    bb.style.minHeight = bb.offsetHeight;\n                    gb.forEach(function(sb) {\n                        if (((pa(sb) != \"2\"))) {\n                            oa(sb, \"l\");\n                        }\n                    ;\n                    ;\n                    });\n                    hb.forEach(function(sb) {\n                        if (((pa(sb) != \"2\"))) {\n                            oa(sb, \"r\");\n                        }\n                    ;\n                    ;\n                    });\n                    var pb = l.create(\"li\", {\n                        className: \"fbTimelineBalancer\"\n                    }, l.create(\"ol\", null, gb));\n                    pb.setAttribute(\"data-side\", \"left\");\n                    l.prependContent(bb, pb);\n                    mb = gb.concat(mb);\n                    var qb = l.create(\"li\", {\n                        className: \"fbTimelineBalancer\"\n                    }, l.create(\"ol\", null, hb));\n                    qb.setAttribute(\"data-side\", \"right\");\n                    l.prependContent(bb, qb);\n                    nb = hb.concat(nb);\n                    db = 0;\n                }\n            ;\n            ;\n                while (((((((db >= 0)) && mb.length)) || ((((db < 0)) && nb.length))))) {\n                    if (((db >= 0))) {\n                        eb = mb.shift();\n                    }\n                     else eb = nb.shift();\n                ;\n                ;\n                    fb.appendChild(eb);\n                    db = ua(db, eb);\n                };\n            ;\n                while (ob.length) {\n                    fb.appendChild(ob.shift());\n                ;\n                };\n            ;\n                bb.appendChild(fb);\n                m.scry(bb, \"li.fbTimelineBalancer\").forEach(function(sb) {\n                    if (!sb.firstChild.childNodes.length) {\n                        l.remove(sb);\n                    }\n                ;\n                ;\n                });\n                var rb;\n                if (((cb && cb.tail_balance))) {\n                    rb = cb.tail_balance;\n                }\n                 else if (k.get(r.DS_TAILBALANCE, bb.id)) {\n                    rb = r.FIXED_SIDE_BOTH;\n                }\n                \n            ;\n            ;\n                if (rb) {\n                    db = aa.tailBalance(bb, db, rb);\n                }\n            ;\n            ;\n                if (jb) {\n                    ib.forEach(function(sb) {\n                        if (((sb.parentNode !== bb))) {\n                            bb.appendChild(sb);\n                            db = ua(db, sb);\n                        }\n                    ;\n                    ;\n                    });\n                    bb.style.minHeight = null;\n                }\n            ;\n            ;\n                k.set(r.DS_COLUMN_HEIGHT_DIFFERENTIAL, q.byClass(bb, \"fbTimelineSection\").id, db);\n                fa[bb.id] = {\n                };\n                m.scry(bb, \"li.placeholderUnit\").forEach(function(sb) {\n                    fa[bb.id][sb.id] = sb;\n                });\n                ya(bb);\n                wa(bb);\n                if (((kb === da))) {\n                    cb.heights_action = ea;\n                    z(function() {\n                        z(aa.balanceCapsule.curry(bb, cb));\n                    });\n                }\n            ;\n            ;\n            },\n            tailBalance: function(bb, cb, db) {\n                if (!bb) {\n                    return cb;\n                }\n            ;\n            ;\n                var eb = [], fb = [], gb = [], hb = [];\n                m.scry(bb, \"li.fbTimelineBalancer\").forEach(function(jb) {\n                    var kb = i(jb.firstChild.childNodes);\n                    if (jb.getAttribute(\"data-nonunits\")) {\n                        hb = hb.concat(kb);\n                    }\n                     else if (((na(jb) == \"left\"))) {\n                        fb = fb.concat(kb);\n                    }\n                     else if (((na(jb) == \"right\"))) {\n                        gb = gb.concat(kb);\n                    }\n                    \n                    \n                ;\n                ;\n                    eb = eb.concat(kb);\n                });\n                if (((((((db == r.FIXED_SIDE_RIGHT)) && fb.length)) || ((((db == r.FIXED_SIDE_LEFT)) && gb.length))))) {\n                    return cb;\n                }\n            ;\n            ;\n                var ib = JSBNG__document.createDocumentFragment();\n                if (eb) {\n                    while (eb.length) {\n                        if (((pa(eb[0]) != \"2\"))) {\n                            if (((cb >= 0))) {\n                                oa(eb[0], \"l\");\n                            }\n                             else oa(eb[0], \"r\");\n                        ;\n                        }\n                    ;\n                    ;\n                        cb = ua(cb, eb[0]);\n                        ib.appendChild(eb.shift());\n                    };\n                }\n            ;\n            ;\n                bb.appendChild(ib);\n                m.scry(bb, \"li.fbTimelineBalancer\").forEach(function(jb) {\n                    if (!jb.firstChild.childNodes.length) {\n                        l.remove(jb);\n                    }\n                ;\n                ;\n                });\n                k.set(r.DS_TAILBALANCE, bb.id, true);\n                return cb;\n            },\n            balance: function(bb, cb, db) {\n                if (!bb) {\n                    return;\n                }\n            ;\n            ;\n                if (!fa[bb.id]) {\n                    fa[bb.id] = {\n                    };\n                }\n            ;\n            ;\n                var eb = ((ja(bb) ? bb.firstChild : bb)), fb = eb.childNodes.length, gb = [], hb = [];\n                if (((w.JSBNG__chrome() || w.safari()))) {\n                    j.toggleClass(bb, \"webkitFix\");\n                }\n            ;\n            ;\n                for (var ib = 0; ((ib < fb)); ib++) {\n                    sa(eb.childNodes[ib]);\n                ;\n                };\n            ;\n                var jb = false;\n                for (ib = 0; ((ib < fb)); ib++) {\n                    var kb = eb.childNodes[ib];\n                    if (ka(kb)) {\n                        continue;\n                    }\n                ;\n                ;\n                    var lb = ((cb >= 0)), mb = kb.nextSibling;\n                    if (ma(kb)) {\n                        if (((na(kb) == \"r\"))) {\n                            if (((cb > 0))) {\n                                if (((mb && ((pa(mb) != \"2\"))))) {\n                                    var nb = [kb,];\n                                    while (((((mb && ma(mb))) && ((na(mb) == \"r\"))))) {\n                                        nb.push(mb);\n                                        mb = mb.nextSibling;\n                                    };\n                                ;\n                                    if (mb) {\n                                        if (ja(mb)) {\n                                            var ob = mb.firstChild;\n                                            l.prependContent(ob, nb);\n                                            sa(ob);\n                                            fb -= nb.length;\n                                        }\n                                         else l.insertBefore(kb, mb);\n                                    ;\n                                    ;\n                                        ib--;\n                                    }\n                                ;\n                                ;\n                                    continue;\n                                }\n                            ;\n                            }\n                        ;\n                        ;\n                            cb += ta(kb);\n                        }\n                         else cb -= ta(kb);\n                    ;\n                    ;\n                    }\n                     else if (((kb.id && ((fa[bb.id][kb.id] || la(kb)))))) {\n                        fa[bb.id][kb.id] = kb;\n                        continue;\n                    }\n                     else if (ja(kb)) {\n                        cb = aa.balance(kb, cb);\n                    }\n                     else if (((pa(kb) == \"2\"))) {\n                        if (((((((mb && ma(mb))) && ((na(mb) == \"r\")))) && ((cb <= 0))))) {\n                            l.insertBefore(kb, mb);\n                            ib--;\n                        }\n                         else {\n                            lb = true;\n                            cb = 0;\n                        }\n                    ;\n                    ;\n                    }\n                     else if (lb) {\n                        gb.push(kb);\n                        cb -= ta(kb);\n                    }\n                     else {\n                        var pb = false;\n                        if (!jb) {\n                            while (((mb && ((!ma(mb) || ((na(mb) != \"r\"))))))) {\n                                mb = mb.nextSibling;\n                            ;\n                            };\n                        ;\n                            if (mb) {\n                                l.insertBefore(kb, mb);\n                                ib--;\n                                pb = true;\n                            }\n                             else jb = true;\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                        if (!pb) {\n                            hb.push(kb);\n                            cb += ta(kb);\n                        }\n                    ;\n                    ;\n                    }\n                    \n                    \n                    \n                    \n                ;\n                ;\n                };\n            ;\n                qa(bb, true);\n                if (((db && db.nothrottle))) {\n                    xa(bb, gb, hb);\n                    ya(bb);\n                }\n                 else {\n                    JSBNG__clearTimeout(ha[bb.id]);\n                    ha[bb.id] = JSBNG__setTimeout(function() {\n                        v.getInstance(\"positionUnits\").debounce(xa.curry(bb, gb, hb), bb.id);\n                        delete ha[bb.id];\n                    }, 50);\n                    JSBNG__clearTimeout(ga[bb.id]);\n                    ga[bb.id] = JSBNG__setTimeout(function() {\n                        v.getInstance(\"adjustPlaceholders\").debounce(ya.curry(bb), bb.id);\n                        delete ga[bb.id];\n                    }, 150);\n                }\n            ;\n            ;\n                return cb;\n            }\n        };\n    })();\n    e.exports = ((a.TimelineCapsule || aa));\n});\n__d(\"TimelineComposerUtilities\", [\"event-extensions\",\"Arbiter\",\"Bootloader\",\"CSS\",\"DOM\",\"Parent\",\"TimelineCapsule\",\"Vector\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"Bootloader\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"Parent\"), l = b(\"TimelineCapsule\"), m = b(\"Vector\"), n = ((86400 * 31)), o = 86400000, p = {\n        listenToSetEstimatedDate: function(q, r) {\n            return g.subscribe(\"TimelineBackdatedComposerTagger/initialized\", function(JSBNG__event, s) {\n                if (((s.composer === q))) {\n                    s.date_picker.subscribe(\"initialized\", function(t, u) {\n                        p.setEstimatedDate(u, r());\n                    });\n                }\n            ;\n            ;\n            });\n        },\n        listenToPublish: function(q, r) {\n            return g.subscribe(\"composer/publish\", function(JSBNG__event, s) {\n                if (((s.composer === q))) {\n                    h.loadModules([\"TimelineStoryPublisher\",], function(t) {\n                        t.publish(s);\n                        ((r && r()));\n                    });\n                }\n            ;\n            ;\n            });\n        },\n        listenToAnotherComposerOpen: function(q, r) {\n            return g.subscribe(\"composer/mutate\", function(s, t) {\n                if (((t !== q))) {\n                    r();\n                }\n            ;\n            ;\n            });\n        },\n        listenToCancel: function(q, r) {\n            return JSBNG__Event.listen(q, \"click\", function(JSBNG__event) {\n                ((k.byClass(JSBNG__event.getTarget(), \"cancelBtn\") && r()));\n            });\n        },\n        hidePlaceIfAttachmentsTooTall: function(q) {\n            var r = j.JSBNG__find(q, \"ul.fbTimelineComposerAttachments\"), s = m.getElementDimensions(r).y;\n            if (((s > 50))) {\n                var t = k.byTag(j.scry(r, \"span.placeAttachment\")[0], \"li\");\n                ((t && i.hide(t)));\n            }\n        ;\n        ;\n        },\n        setEstimatedDate: function(q, r) {\n            var s, t;\n            if (((r && i.hasClass(r, \"fbTimelineCapsule\")))) {\n                s = r.getAttribute(\"data-start\");\n                t = r.getAttribute(\"data-end\");\n                if (((s && t))) {\n                    var u = new JSBNG__Date(((t * 1000)));\n                    if (((((t - s)) > ((2 * n))))) {\n                        q.setDate(u.getFullYear());\n                    }\n                     else q.setDate(u.getFullYear(), ((u.getMonth() + 1)));\n                ;\n                ;\n                }\n            ;\n            ;\n                return;\n            }\n        ;\n        ;\n            var v = k.byClass(r, \"fbTimelineCapsule\");\n            if (v) {\n                s = v.getAttribute(\"data-start\");\n                t = v.getAttribute(\"data-end\");\n                var w = m.getElementPosition(r).y, x = [t,null,], y = [s,null,], z = l.getUnitsWithTime(v);\n                for (var aa = 0; ((aa < z.length)); aa++) {\n                    var ba = z[aa], ca = j.scry(ba.parentNode, \".spinePointer\")[0];\n                    if (!ca) {\n                        continue;\n                    }\n                ;\n                ;\n                    var da = m.getElementPosition(ca).y;\n                    if (((da <= w))) {\n                        if (((!x[1] || ((da > x[1]))))) {\n                            x = [ba.getAttribute(\"data-time\"),da,];\n                        }\n                    ;\n                    ;\n                    }\n                     else if (((!y[1] || ((da < y[1]))))) {\n                        y = [ba.getAttribute(\"data-time\"),da,];\n                    }\n                    \n                ;\n                ;\n                };\n            ;\n                if (((((x[0] !== null)) && ((y[0] !== null))))) {\n                    var ea = ((Math.round(((((parseInt(x[0], 10) + parseInt(y[0], 10))) / 2))) * 1000));\n                    ea = Math.min(((new JSBNG__Date() - o)), ea);\n                    q.setDateWithTimestamp(ea);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        }\n    };\n    e.exports = p;\n});\n__d(\"TimelineNavigation\", [\"event-extensions\",\"Arbiter\",\"DOM\",\"CSS\",\"PageTransitions\",\"Parent\",\"TimelineController\",\"TimelineURI\",\"URI\",\"$\",\"createArrayFrom\",\"ge\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"DOM\"), i = b(\"CSS\"), j = b(\"PageTransitions\"), k = b(\"Parent\"), l = b(\"TimelineController\"), m = b(\"TimelineURI\"), n = b(\"URI\"), o = b(\"$\"), p = b(\"createArrayFrom\"), q = b(\"ge\"), r = 4, s = 110, t = 20, u = 119, v = 328, w = 10, x = 3, y = false, z = 21, aa, ba, ca, da = [], ea = [], fa, ga = 0, ha, ia = 0, ja = 0, ka, la = r, ma = false, na = false, oa = null, pa, qa = false, ra, sa, ta = false;\n    function ua(ib, jb, kb) {\n        if (!jb.firstChild) {\n            h.remove(jb);\n            return;\n        }\n    ;\n    ;\n        ea.push(jb);\n        xa(kb.recent);\n        i.removeClass(k.byTag(jb, \"li\"), \"empty\");\n        if (((fa && ((((ia > r)) || ((ja > 0))))))) {\n            i.removeClass(fa, \"notready\");\n        }\n    ;\n    ;\n        wa();\n        if (kb.async) {\n            bb();\n            db();\n        }\n    ;\n    ;\n    };\n;\n    function va(ib, jb, kb) {\n        h.remove(k.byTag(jb, \"li\"));\n        if (!kb.async) {\n            ka++;\n        }\n         else {\n            ia--;\n            bb();\n            db();\n        }\n    ;\n    ;\n        wa();\n    };\n;\n    function wa() {\n        var ib = ((fa ? 0 : z));\n        if (((ia <= r))) {\n            var jb = ((((v + ((u * Math.max(0, ((r - ia))))))) + ib));\n            ha.style.width = ((jb + \"px\"));\n            la = ia;\n            ya();\n        }\n    ;\n    ;\n    };\n;\n    function xa(ib) {\n        if (ib) {\n            ja++;\n        }\n         else ia++;\n    ;\n    ;\n        ya();\n    };\n;\n    function ya() {\n        if (!ra) {\n            return;\n        }\n    ;\n    ;\n        var ib = ((Math.max(0, ((ia - r))) + ja));\n        if (((ga && fa))) {\n            h.setContent(ga, ((((ib === 0)) ? \" \" : ib)));\n            i.conditionClass(fa, \"fbTimelineMoreButtonZero\", ((ib === 0)));\n            if (!ma) {\n                i.conditionShow(fa, ((ib > 0)));\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    };\n;\n    function za() {\n        var ib = h.scry(o(\"fbTimelineNavTopRow\"), \"li.tile\"), jb = 0, kb = 0, lb = Math.max(0, ((r - la))), mb = false;\n        for (var nb = 0; ((nb < ib.length)); nb++) {\n            if (((((ib[nb] == ha)) || ((ib[nb] == fa))))) {\n                continue;\n            }\n        ;\n        ;\n            mb = ((((((jb + lb)) % r)) === 0));\n            i.conditionClass(ib[nb], \"leftMost\", ((((jb !== 0)) && mb)));\n            if (!i.hasClass(ib[nb], \"empty\")) {\n                kb = jb;\n            }\n        ;\n        ;\n            jb++;\n        };\n    ;\n        mb = ((((((((kb + 1)) + lb)) % r)) === 0));\n        var ob = ((((ib.length - 1)) - lb));\n        if (mb) {\n            if (((ma && ((((((((kb + 1)) + lb)) / r)) < x))))) {\n                ob = Math.min(ob, ((kb + r)));\n                na = true;\n            }\n             else ob = kb;\n        ;\n        ;\n        }\n         else {\n            var pb = ((((((kb + 1)) + lb)) % r));\n            ob = ((kb + ((r - pb))));\n            na = false;\n        }\n    ;\n    ;\n        nb = 0;\n        for (nb = 0; ((nb <= ob)); nb++) {\n            if (((ib[nb] && ((((ib[nb] == ha)) || ((ib[nb] == fa))))))) {\n                ob++;\n            }\n             else ((((ib[nb] && i.hasClass(ib[nb], \"empty\"))) && i.removeClass(ib[nb], \"hidden_elem\")));\n        ;\n        ;\n        };\n    ;\n    };\n;\n    function ab(ib, jb, kb) {\n        var lb = h.scry(ib, \"li.tile\");\n        if (!jb) {\n            jb = 0;\n        }\n    ;\n    ;\n        var mb = false;\n        for (var nb = jb; ((nb < lb.length)); nb++) {\n            mb = ((((((nb - kb)) % r)) === 0));\n            var ob = lb[nb];\n            i.conditionClass(ob, \"leftMost\", mb);\n            if (i.hasClass(ob, \"empty\")) {\n                i.removeClass(ob, \"hidden_elem\");\n            }\n        ;\n        ;\n        };\n    ;\n    };\n;\n    function bb() {\n        za();\n        var ib = q(\"fbTimelineNavSecondaryRow\");\n        ((ib && ab(ib, 0, 0)));\n    };\n;\n    function cb() {\n        if (!fa) {\n            return;\n        }\n    ;\n    ;\n        if (i.hasClass(fa, \"notready\")) {\n            return;\n        }\n    ;\n    ;\n        i.toggleClass(fa, \"fbTimelineMoreButtonOpen\");\n        var ib = q(\"fbRecentAppTitle\");\n        ((ib && i.conditionClass(ib, \"hidden_elem\", ((ja === 0)))));\n        if (i.hasClass(fa, \"fbTimelineMoreButtonOpen\")) {\n            bb();\n        }\n         else ya();\n    ;\n    ;\n        db();\n    };\n;\n    function db() {\n        if (((fa && !i.hasClass(fa, \"fbTimelineMoreButtonOpen\")))) {\n            aa.style.height = \"\";\n            i.removeClass(aa, \"expanded\");\n        }\n         else {\n            var ib = ((ia + ((r - la)))), jb = ((((((((((((ja > 0)) ? w : 0)) + ((s * (Math.ceil(((ja / r)))))))) + ((s * (Math.ceil(((ib / r)))))))) + ((s * ((na ? 1 : 0)))))) + t));\n            i.addClass(aa, \"expanded\");\n            aa.style.height = ((jb + \"px\"));\n        }\n    ;\n    ;\n    };\n;\n    function eb(ib) {\n        var jb = ((((ib == m.TIMELINE_KEY)) || ((ib == m.WALL_KEY)))), kb = k.byClass(aa, \"fbTimelineTopSectionBase\"), lb = q(\"timeline_tour_toolbar\");\n        if (fa) {\n            i.removeClass(fa, \"fbTimelineMoreButtonOpen\");\n            db();\n        }\n    ;\n    ;\n        ((lb && i.conditionShow(lb, jb)));\n        if (kb) {\n            i.conditionClass(kb, \"collapsedHead\", !jb);\n        }\n    ;\n    ;\n    };\n;\n    function fb(JSBNG__event) {\n        if (ta) {\n            return true;\n        }\n    ;\n    ;\n        if (!k.byTag(JSBNG__event.getTarget(), \"a\")) {\n            var ib = h.JSBNG__find(ha, \"a.title\");\n            j.go(ib.href);\n        }\n    ;\n    ;\n    };\n;\n    function gb() {\n        if (fa) {\n            (function() {\n                fa.removeAttribute(\"ajaxify\");\n                fa.removeAttribute(\"rel\");\n            }).defer();\n        }\n    ;\n    ;\n        ((oa && oa.remove()));\n    };\n;\n    var hb = {\n        UPDATE_PAGE: \"TimelineNavigation/updatePage\",\n        init: function(ib, jb, kb, lb) {\n            if (y) {\n                return;\n            }\n        ;\n        ;\n            y = true;\n            aa = ib;\n            fa = jb;\n            ba = n.getRequestURI();\n            ha = h.JSBNG__find(aa, \"li.about\");\n            eb(l.getCurrentKey());\n            ma = lb;\n            g.inform(hb.UPDATE_PAGE);\n            if (fa) {\n                ga = h.JSBNG__find(fa, \"div.text\");\n                oa = JSBNG__Event.listen(fa, \"click\", gb);\n            }\n        ;\n        ;\n            pa = o(\"fbTimelineNavigationLoadContainer\");\n            h.appendContent(o(\"JSBNG__content\"), pa);\n            sa = JSBNG__Event.listen(ha, \"click\", fb);\n            da.forEach(function(nb) {\n                if (!nb[2].remove) {\n                    ua.apply(this, nb);\n                }\n                 else va.apply(this, nb);\n            ;\n            ;\n            });\n            da = [];\n            var mb = k.byClass(ib, \"fbTimelineSection\");\n            if (mb) {\n                h.scry(mb, \"ul.uiButtonGroup\").forEach(function(nb) {\n                    p(nb.childNodes).forEach(function(ob) {\n                        ((ob.childNodes.length || h.remove(ob)));\n                    });\n                    if (nb.firstChild) {\n                        i.addClass(nb.firstChild, \"firstItem\");\n                    }\n                     else h.remove(nb);\n                ;\n                ;\n                });\n            }\n        ;\n        ;\n            l.register(l.NAV, hb);\n        },\n        reset: function() {\n            ((sa && sa.remove()));\n            sa = null;\n            ((ra && ra.remove()));\n            ra = null;\n            y = false;\n            aa = null;\n            ca = null;\n            ea = [];\n            fa = null;\n            ga = null;\n            ha = null;\n            ia = 0;\n            ja = 0;\n            ka = 0;\n            la = r;\n            ma = false;\n            na = false;\n            pa = null;\n            qa = false;\n            ta = false;\n        },\n        initializeMorePager: function() {\n            if (ra) {\n                return;\n            }\n        ;\n        ;\n            if (fa) {\n                ra = JSBNG__Event.listen(fa, \"click\", cb);\n            }\n        ;\n        ;\n        },\n        registerNav: function(ib, jb, kb) {\n            ((y ? ((kb.remove ? va.apply(this, arguments) : ua.apply(this, arguments))) : da.push(arguments)));\n        },\n        redraw: function() {\n            bb();\n            db();\n        },\n        setEditMode: function(ib) {\n            ta = ib;\n        }\n    };\n    e.exports = hb;\n});\n__d(\"TimelineBackdatedComposer\", [\"Arbiter\",\"Bootloader\",\"CSS\",\"DOM\",\"LayerHideOnBlur\",\"Run\",\"TimelineComposerUtilities\",\"TimelineNavigation\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"Bootloader\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"LayerHideOnBlur\"), l = b(\"Run\"), m = b(\"TimelineComposerUtilities\"), n = b(\"TimelineNavigation\"), o;\n    function p() {\n        q();\n        r();\n    };\n;\n    function q() {\n        o.hide();\n    };\n;\n    function r() {\n        h.loadModules([\"TimelineMLE\",], function(t) {\n            var u = t.getFlyout();\n            if (((u && i.hasClass(u.getContext(), \"backdatedDot\")))) {\n                t.hideFlyout();\n            }\n        ;\n        ;\n        });\n    };\n;\n    var s = {\n        init: function(t, u) {\n            o = u;\n            var v = [m.listenToPublish(t, p),m.listenToAnotherComposerOpen(t, p),m.listenToSetEstimatedDate(t, o.getContext.bind(o)),t.subscribeToMutate(function() {\n                var x = ((!j.scry(t.root, \".cancelBtn\")[0] || j.scry(t.root, \".attachmentLifeEvents\")[0]));\n                if (x) {\n                    o.enableBehavior(k);\n                }\n                 else o.disableBehavior(k);\n            ;\n            ;\n            }),g.subscribe(\"TimelineMLE/mleFlyoutShown\", function(x, y) {\n                if (i.hasClass(y.getContext(), \"backdatedDot\")) {\n                    q();\n                }\n                 else p();\n            ;\n            ;\n            }),g.subscribe(n.UPDATE_PAGE, p),], w = m.listenToCancel(o.getContent(), p);\n            l.JSBNG__onLeave(function() {\n                v.forEach(g.unsubscribe.bind(g));\n                v = [];\n                w.remove();\n                w = null;\n            });\n            g.inform(\"TimelineBackdatedComposer/initialized\");\n        },\n        getFlyout: function() {\n            return o;\n        }\n    };\n    e.exports = ((a.TimelineBackdatedComposer || s));\n});\n__d(\"TimelineSpine\", [\"array-extensions\",\"event-extensions\",\"Arbiter\",\"AsyncRequest\",\"Bootloader\",\"ContextualDialogX\",\"Composer\",\"CSS\",\"DOM\",\"Layer\",\"LayerHideOnBlur\",\"Parent\",\"Run\",\"TimelineBackdatedComposer\",\"TimelineComposerUtilities\",\"TimelinePerfConfig\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"Bootloader\"), j = b(\"ContextualDialogX\"), k = b(\"Composer\"), l = b(\"CSS\"), m = b(\"DOM\"), n = b(\"Layer\"), o = b(\"LayerHideOnBlur\"), p = b(\"Parent\"), q = b(\"Run\"), r = b(\"TimelineBackdatedComposer\"), s = b(\"TimelineComposerUtilities\"), t = b(\"TimelinePerfConfig\"), u = b(\"copyProperties\");\n    function v() {\n    \n    };\n;\n    u(v, {\n        OFFSET_Y: 12,\n        composerFlyout: null,\n        mleFlyout: null,\n        dot: null,\n        loadComposerFlyoutCalled: false,\n        showComposerFlyout: function(w) {\n            var x = v.composerFlyout;\n            if (!x) {\n                v.loadComposerFlyout(w);\n                v.showComposerFlyoutOnLoad = true;\n                return;\n            }\n        ;\n        ;\n            var y = m.JSBNG__find(x.getContent(), \"div.fbTimelineBackdatedComposer\"), z = k.getInstance(y);\n            if (z) {\n                z.reset();\n                l.removeClass(z.root, \"uiComposerOpen\");\n            }\n        ;\n        ;\n            x.enableBehavior(o).setContext(v.dot).updatePosition();\n            x.show();\n            s.hidePlaceIfAttachmentsTooTall(y);\n        },\n        loadComposerFlyout: function(w) {\n            if (((v.loadComposerFlyoutCalled || v.composerFlyout))) {\n                return;\n            }\n        ;\n        ;\n            v.loadComposerFlyoutCalled = true;\n            q.JSBNG__onLeave(function() {\n                v.loadComposerFlyoutCalled = false;\n                v.composerFlyout = null;\n            }.bind(this));\n            new h().setURI(\"/ajax/timeline/backdated_composer.php\").setData({\n                targetid: w\n            }).setRelativeTo(((v.dot || JSBNG__document.body))).send();\n            var x = g.subscribe(\"TimelineBackdatedComposer/initialized\", function() {\n                v.composerFlyout = r.getFlyout();\n                if (v.showComposerFlyoutOnLoad) {\n                    v.showComposerFlyout(w);\n                }\n            ;\n            ;\n                v._handleComposerFlyoutDismissed();\n                x.unsubscribe();\n            });\n        },\n        showMLEFlyout: function(w) {\n            v.mleFlyout = w;\n            w.setContext(v.dot).show();\n            v.composerFlyout.hide();\n        },\n        _handleComposerFlyoutDismissed: function() {\n            var w = n.subscribe(\"hide\", function(x, y) {\n                if (((v.dot && y.getContext))) {\n                    if (((((y.getContext() === v.dot)) && !v.mleFlyout))) {\n                        v._hideDot();\n                    }\n                     else if (((y === v.mleFlyout))) {\n                        v.mleFlyout = null;\n                        v._hideDot();\n                    }\n                    \n                ;\n                }\n            ;\n            ;\n            });\n            q.JSBNG__onLeave(function() {\n                n.unsubscribe(w);\n            }.bind(this));\n        },\n        _hideDot: function() {\n            m.remove(v.dot);\n            v.dot = null;\n        }\n    });\n    u(v.prototype, {\n        init: function(w, x) {\n            this._spine = w;\n            if (!t.getDisableSpineHeight()) {\n                this._spineHeight = w.offsetHeight;\n            }\n        ;\n        ;\n            this._plus = m.JSBNG__find(w, \".spineHoverPlus\");\n            this._capsule = p.byClass(w, \"fbTimelineCapsule\");\n            this._targetid = x;\n            var y = [JSBNG__Event.listen(w, \"mouseenter\", function(JSBNG__event) {\n                v.loadComposerFlyout(this._targetid);\n                this._spineHeight = w.offsetHeight;\n            }.bind(this)),JSBNG__Event.listen(w, \"mousemove\", this._mouseMoved.bind(this)),JSBNG__Event.listen(w, \"click\", this._spineClicked.bind(this)),];\n            l.addClass(this._plus, \"spineHoverPlusActive\");\n            q.JSBNG__onLeave(function() {\n                while (y.length) {\n                    y.pop().remove();\n                ;\n                };\n            ;\n            }.bind(this));\n        },\n        _mouseMoved: function(JSBNG__event) {\n            var w = ((JSBNG__event.offsetY || JSBNG__event.layerY)), x = JSBNG__event.getTarget();\n            if (((x !== this._spine))) {\n                w = ((x.offsetTop + w));\n            }\n        ;\n        ;\n            w = Math.min(Math.max(((w - v.OFFSET_Y)), 0), this._spineHeight);\n            this._plus.style.JSBNG__top = ((w + \"px\"));\n        },\n        _spineClicked: function(JSBNG__event) {\n            if (v.mleFlyout) {\n                i.loadModules([\"TimelineMLE\",], function(w) {\n                    w.hideFlyout();\n                });\n                return;\n            }\n        ;\n        ;\n            ((v.dot && m.remove(v.dot)));\n            v.dot = m.create(\"i\", {\n                className: \"backdatedDot\"\n            });\n            v.dot.style.JSBNG__top = ((((this._plus.offsetTop - 1)) + \"px\"));\n            m.appendContent(this._spine, v.dot);\n            JSBNG__event.JSBNG__stop();\n            v.showComposerFlyout(this._targetid);\n        }\n    });\n    e.exports = ((a.TimelineSpine || v));\n});\n__d(\"legacy:TimelineSpine\", [\"TimelineSpine\",], function(a, b, c, d) {\n    a.TimelineSpine = b(\"TimelineSpine\");\n}, 3);\n__d(\"timeline-cover-dragdrop-edit\", [\"SinglePictureUploadTarget\",\"TimelineCover\",], function(a, b, c, d, e, f) {\n    var g = b(\"SinglePictureUploadTarget\"), h = b(\"TimelineCover\"), i = function() {\n        var m = h.getInstance();\n        m.hideLoadingIndicator();\n    }, j = function(m) {\n        var n = h.getInstance(), o = m.id, p = m.photo_html;\n        n.updateCoverImage(o, p);\n    }, k = function(m) {\n        h.getInstance().showLoadingIndicator();\n    }, l = function(m, n, o, p) {\n        new g(m, n).setMaximumDimensions(o, p).setPreprocessCallback(k).setOncompleteCallback(i).setAfterSuccessCallback(j).activate();\n    };\n    f.initialize_timeline_cover_drop_target = l;\n});\n__d(\"TimelineComposer\", [\"Arbiter\",\"Bootloader\",\"CSS\",\"DOM\",\"Parent\",\"Run\",\"TimelineCapsule\",\"TimelineComposerUtilities\",\"$\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"Bootloader\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"Parent\"), l = b(\"Run\"), m = b(\"TimelineCapsule\"), n = b(\"TimelineComposerUtilities\"), o = b(\"$\"), p;\n    function q(v) {\n        if (((v.isScheduledPost || v.isOGPost))) {\n            return;\n        }\n    ;\n    ;\n        if (!v.streamStory) {\n            window.JSBNG__location.reload();\n            return;\n        }\n    ;\n    ;\n        if (v.backdatedTime) {\n            h.loadModules([\"TimelineStoryPublisher\",], function(z) {\n                z.publish(v);\n            });\n            return;\n        }\n    ;\n    ;\n        var w = k.byClass(p, \"fbTimelineCapsule\");\n        if (!w) {\n            return;\n        }\n    ;\n    ;\n        var x = k.byClass(p, \"timelineUnitContainer\").parentNode;\n        if (x.nextSibling.getAttribute(\"data-spine\")) {\n            x = x.nextSibling;\n        }\n    ;\n    ;\n        var y = j.insertAfter(x, v.streamStory)[0];\n        h.loadModules([\"Animation\",], function(z) {\n            z(y.firstChild).from(\"backgroundColor\", \"#fff8dd\").to(\"backgroundColor\", \"#fff\").duration(2000).ease(z.ease.both).go();\n        });\n        m.setFirstUnit(w);\n        m.balanceCapsule(w);\n    };\n;\n    function r() {\n        var v = k.byClass(p, \"fbTimelineTwoColumn\");\n        return j.JSBNG__find(v, \".spinePointer\");\n    };\n;\n    function s(v) {\n        var w = t();\n        i.show(w);\n        var x = v.subscribe(\"hide\", function() {\n            i.hide(w);\n            v.unsubscribe(x);\n        });\n    };\n;\n    function t() {\n        var v = k.byClass(p, \"fbTimelineTwoColumn\"), w = j.scry(v, \"div.composerVeil\");\n        if (((w.length !== 1))) {\n            w = j.appendContent(v, j.create(\"div\", {\n                className: \"composerVeil hidden_elem\"\n            }));\n        }\n    ;\n    ;\n        return w[0];\n    };\n;\n    var u = {\n        init: function(v) {\n            p = o(v);\n            var w = g.subscribe(\"composer/publish\", function(JSBNG__event, x) {\n                if (((x.composer.root === p))) {\n                    q(x);\n                }\n            ;\n            ;\n            });\n            l.JSBNG__onLeave(function() {\n                w.unsubscribe();\n            });\n            n.hidePlaceIfAttachmentsTooTall(p);\n        },\n        initComposerX: function(v) {\n            p = o(v);\n            var w = g.subscribe(\"composer/publish\", function(JSBNG__event, x) {\n                if (((x.composer_id === v))) {\n                    q(x);\n                }\n            ;\n            ;\n            });\n            l.JSBNG__onLeave(function() {\n                w.unsubscribe();\n            });\n        },\n        showMLEFlyout: function(v) {\n            v.setContext(r()).show();\n            s(v);\n        }\n    };\n    e.exports = ((a.TimelineComposer || u));\n});\n__d(\"TimelineLogging\", [\"TimelineController\",\"reportData\",], function(a, b, c, d, e, f) {\n    var g = b(\"TimelineController\"), h = b(\"reportData\"), i = false, j = 0, k = null, l = {\n        init: function(m) {\n            if (i) {\n                return;\n            }\n        ;\n        ;\n            j = m;\n            g.register(g.LOGGING, this);\n        },\n        reset: function() {\n            i = false;\n            j = 0;\n            k = null;\n        },\n        log: function(m, n) {\n            n.profile_id = j;\n            h(m, {\n                gt: n\n            });\n        },\n        logSectionChange: function(m, n) {\n            var o = {\n                timeline_section_change: 1,\n                key: m\n            };\n            if (((k && ((m == k))))) {\n                o.timeline_scrubber = 1;\n                k = null;\n            }\n        ;\n        ;\n            l.log(\"timeline\", o);\n        },\n        logScrubberClick: function(m) {\n            k = m;\n        }\n    };\n    e.exports = l;\n});\n__d(\"TimelineSideAds\", [\"event-extensions\",\"function-extensions\",\"Arbiter\",\"cx\",\"csx\",\"CSS\",\"DOM\",\"StickyController\",\"TimelineController\",\"UIPagelet\",\"URI\",\"Vector\",\"debounce\",\"ge\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"cx\"), i = b(\"csx\"), j = b(\"CSS\"), k = b(\"DOM\"), l = b(\"StickyController\"), m = b(\"TimelineController\"), n = b(\"UIPagelet\"), o = b(\"URI\"), p = b(\"Vector\"), q = b(\"debounce\"), r = b(\"ge\"), s = 2, t = 3, u = 75, v = \"data-height\", w = 310, x = 45, y = 30000, z = 0, aa = false, ba, ca, da, ea, fa = [], ga, ha = false, ia, ja = Infinity, ka = 5, la = false, ma, na, oa, pa, qa, ra = false, sa = [], ta;\n    function ua(mb, nb, ob) {\n        var pb = 0;\n        if (r(\"pagelet_timeline_friends\")) {\n            pb += w;\n        }\n    ;\n    ;\n        if (nb) {\n            pb += nb.getHeight();\n        }\n    ;\n    ;\n        if (((!m.fixedAds() && !pb))) {\n            return;\n        }\n    ;\n    ;\n        mb -= pb;\n        var qb = 0;\n        for (var rb = 0; ((rb < ob)); rb++) {\n            qb += eb(rb);\n        ;\n        };\n    ;\n        if (nb) {\n            if (((mb < qb))) {\n                mb += nb.fold(((qb - mb)));\n            }\n             else if (((mb > qb))) {\n                mb -= nb.unfold(((mb - qb)));\n            }\n            \n        ;\n        }\n    ;\n    ;\n        return mb;\n    };\n;\n    function va() {\n        var mb = ca.cloneNode(true);\n        mb.id = \"\";\n        var nb = true;\n        k.scry(mb, \"div.ego_unit\").forEach(function(ob) {\n            if (nb) {\n                nb = false;\n            }\n             else k.remove(ob);\n        ;\n        ;\n        });\n        j.addClass(mb, \"fixed_elem\");\n        return mb;\n    };\n;\n    function wa() {\n        if (!m.pageHasScrubber(ga)) {\n            ab(ka);\n            cb();\n        }\n         else if (na) {\n            bb(ca, false);\n            var mb = oa;\n            ((oa && k.remove(oa)));\n            oa = va();\n            if (mb) {\n                jb();\n            }\n        ;\n        ;\n            ab(((((m.sidebarInitialized() && ha)) ? t : s)));\n            cb();\n            if (!ia) {\n                var nb = m.getCurrentScrubber();\n                if (nb) {\n                    ib(nb.getRoot(), nb.getOffset());\n                }\n                 else {\n                    var ob = r(\"timeline_side_friends\");\n                    if (ob) {\n                        ib(ob, x);\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            ((ia && ia.start()));\n        }\n         else lb.adjustAdsToFit();\n        \n    ;\n    ;\n    };\n;\n    function xa() {\n        var mb = r(\"pagelet_timeline_friends\");\n        if (mb) {\n            j.conditionClass(mb, \"fixed_elem\", !na);\n        }\n    ;\n    ;\n    };\n;\n    function ya() {\n        if (oa) {\n            k.remove(oa);\n            oa = null;\n        }\n    ;\n    ;\n        if (ia) {\n            ia.JSBNG__stop();\n            ia = null;\n        }\n    ;\n    ;\n        if (m.fixedAds()) {\n            j.conditionClass(ca, \"fixed_elem\", !na);\n            j.conditionClass(ca, \"-cx-PRIVATE-fbTimelineStyleAds__topAligned\", !m.pageHasScrubber(ga));\n        }\n         else j.conditionClass(ca, \"fixed_elem\", ((!na && m.pageHasScrubber(ga))));\n    ;\n    ;\n        xa();\n    };\n;\n    function za(mb) {\n        var nb = p.getViewportDimensions().y, ob = m.getCurrentScrubber(), pb = ((ob ? ob.getOffset() : m.SCRUBBER_DEFAULT_OFFSET)), qb = ((((nb - pb)) - u));\n        if (((((ob || m.fixedAds())) || r(\"pagelet_timeline_friends\")))) {\n            return ua(qb, ob, mb);\n        }\n    ;\n    ;\n    };\n;\n    function ab(mb) {\n        ea = Math.min(mb, fa.length);\n        for (var nb = 0; ((nb < fa.length)); nb++) {\n            bb(fa[nb], ((nb >= ea)));\n        ;\n        };\n    ;\n        bb(ca, ((ea === 0)));\n    };\n;\n    function bb(mb, nb) {\n        j.conditionClass(mb, \"-cx-PRIVATE-fbTimelineStyleAds__offScreen\", nb);\n        mb.setAttribute(\"aria-hidden\", ((nb ? \"true\" : \"false\")));\n    };\n;\n    function cb() {\n        if (!pa) {\n            return;\n        }\n    ;\n    ;\n        for (var mb = ((ea - 1)); ((mb >= 0)); --mb) {\n            if (((((ia && ia.isFixed())) && ((((mb !== 0)) || ((oa && !j.shown(oa)))))))) {\n                continue;\n            }\n        ;\n        ;\n            var nb = k.JSBNG__find(fa[mb], \"div.-cx-PRIVATE-fbAdUnit__root\"), ob = nb.getAttribute(\"data-ad\"), pb = JSON.parse(ob).adid;\n            if (!pa[pb]) {\n                return;\n            }\n        ;\n        ;\n            var qb = k.create(\"div\", {\n                src: o(\"/ai.php\").addQueryData({\n                    aed: pa[pb]\n                }),\n                width: 0,\n                height: 0,\n                frameborder: 0,\n                scrolling: \"no\",\n                className: \"fbEmuTracking\"\n            });\n            qb.setAttribute(\"aria-hidden\", \"true\");\n            k.appendContent(ca, qb);\n            delete pa[pb];\n        };\n    ;\n    };\n;\n    function db(mb) {\n        var nb = 0;\n        while (((((mb > 0)) && ((nb < ka))))) {\n            mb -= eb(nb);\n            if (((mb >= 0))) {\n                nb++;\n            }\n        ;\n        ;\n        };\n    ;\n        return nb;\n    };\n;\n    function eb(mb) {\n        var nb = fa[mb];\n        if (!nb) {\n            return 0;\n        }\n    ;\n    ;\n        if (!nb.getAttribute(v)) {\n            fb(nb);\n        }\n    ;\n    ;\n        return parseInt(nb.getAttribute(v), 10);\n    };\n;\n    function fb(mb) {\n        mb.setAttribute(v, mb.offsetHeight);\n    };\n;\n    function gb() {\n        for (var mb = 0; ((mb < fa.length)); mb++) {\n            var nb = fa[mb];\n            if (!nb) {\n                continue;\n            }\n        ;\n        ;\n            fb(nb);\n        };\n    ;\n    };\n;\n    function hb() {\n        fa = k.scry(ca, \"div.ego_unit\");\n        var mb = fa.length;\n        if (!mb) {\n            return;\n        }\n    ;\n    ;\n        la = mb;\n        wa();\n        var nb = function(ob) {\n            fb(ob);\n            la = --mb;\n            lb.adjustAdsToFit();\n            if (!la) {\n                ja = JSBNG__Date.now();\n            }\n        ;\n        ;\n        };\n        fa.forEach(function(ob) {\n            function pb() {\n                nb.curry(ob).defer();\n            };\n        ;\n            var qb = k.scry(ob, \"img.img\")[0];\n            if (qb.complete) {\n                pb();\n            }\n             else JSBNG__Event.listen(qb, {\n                load: pb,\n                error: pb,\n                abort: pb\n            });\n        ;\n        ;\n        });\n    };\n;\n    function ib(mb, nb) {\n        ia = new l(mb, nb, function(ob) {\n            if (ob) {\n                jb();\n            }\n             else {\n                k.remove(oa);\n                cb();\n            }\n        ;\n        ;\n        });\n        if (oa) {\n            ia.start();\n        }\n    ;\n    ;\n    };\n;\n    function jb() {\n        k.insertAfter(ca, oa);\n        kb();\n    };\n;\n    function kb() {\n        j.conditionShow(oa, ((((eb(0) <= za(1))) && !j.hasClass(JSBNG__document.documentElement, \"tinyViewport\"))));\n    };\n;\n    var lb = {\n        init: function(mb, nb, ob) {\n            if (aa) {\n                return;\n            }\n        ;\n        ;\n            ka = ob.max_ads;\n            ba = ob.refresh_delay;\n            y = ob.refresh_threshold;\n            aa = true;\n            da = nb;\n            ca = mb;\n            lb.adjustAdsType(m.shouldShowWideAds());\n            qa = g.subscribe([\"UFI/CommentAddedActive\",\"UFI/CommentDeletedActive\",\"UFI/LikeActive\",\"Curation/Action\",\"ProfileBrowser/LoadMoreContent\",], lb.loadAdsIfEnoughTimePassed);\n            ta = q(lb.loadAdsIfEnoughTimePassed, ba, this, true);\n            if (ob.mouse_move) {\n                sa.push(JSBNG__Event.listen(window, \"mousemove\", ta));\n                sa.push(JSBNG__Event.listen(window, \"JSBNG__scroll\", ta));\n                sa.push(JSBNG__Event.listen(window, \"resize\", ta));\n            }\n        ;\n        ;\n            m.register(m.ADS, lb);\n        },\n        setShortMode: function(mb, nb) {\n            na = ((((((nb !== \"map\")) && mb)) && m.pageHasScrubber(nb)));\n        },\n        start: function(mb) {\n            pa = mb;\n            ma = null;\n            hb();\n        },\n        updateCurrentKey: function(mb) {\n            if (((mb == ga))) {\n                return;\n            }\n        ;\n        ;\n            ga = mb;\n            ya();\n        },\n        loadAds: function(mb) {\n            if (((la || ma))) {\n                return;\n            }\n        ;\n        ;\n            ja = Infinity;\n            ma = n.loadFromEndpoint(\"WebEgoPane\", ca.id, {\n                pid: 33,\n                data: [da,false,((\"timeline_\" + mb)),((na ? t : ka)),++z,]\n            }, {\n                crossPage: true,\n                bundle: false\n            });\n        },\n        registerScrubber: function(mb) {\n            j.conditionClass(mb.getRoot(), \"fixed_elem\", !na);\n            xa();\n            if (na) {\n                ib(mb.getRoot(), mb.getOffset());\n            }\n        ;\n        ;\n            ((!ma && lb.adjustAdsToFit()));\n        },\n        loadAdsIfEnoughTimePassed: function() {\n            if (((((((((((JSBNG__Date.now() - ja)) >= y)) && !j.hasClass(JSBNG__document.documentElement, \"tinyViewport\"))) && ((!ia || ia.isFixed())))) && ((!pa || !pa[fa[0]]))))) {\n                lb.loadAds(ga);\n            }\n        ;\n        ;\n            lb.adjustAdsToFit();\n        },\n        adjustAdsType: function(mb) {\n            if (((mb != ha))) {\n                j.conditionClass(ca, \"-cx-PRIVATE-fbTimelineStyleAds__vertical\", !mb);\n                ((oa && j.conditionClass(oa, \"-cx-PRIVATE-fbTimelineStyleAds__vertical\", !mb)));\n                ha = mb;\n                gb();\n                lb.adjustAdsToFit();\n                var nb = r(\"timeline_side_friends\");\n                if (nb) {\n                    j.conditionClass(nb, \"fbTimelineVerticalSideFriends\", !mb);\n                }\n            ;\n            ;\n                var ob = r(\"rightColContent\");\n                if (ob) {\n                    j.conditionClass(ob, \"fbTimelineWideRightCol\", mb);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        adjustAdsToFit: function() {\n            if (((!ca || ra))) {\n                return;\n            }\n        ;\n        ;\n            ra = true;\n            var mb = ((ha ? t : s));\n            if (na) {\n                if (((ia && oa))) {\n                    ia.handleScroll();\n                    if (ia.isFixed()) {\n                        j.conditionShow(oa, ((((eb(0) <= za(1))) && !j.hasClass(JSBNG__document.documentElement, \"tinyViewport\"))));\n                    }\n                     else ab(mb);\n                ;\n                ;\n                    cb();\n                }\n            ;\n            ;\n            }\n             else {\n                var nb = za(mb);\n                if (((typeof nb !== \"undefined\"))) {\n                    ab(db(nb));\n                    if (!la) {\n                        cb();\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            ra = false;\n        },\n        reset: function() {\n            ((ia && ia.JSBNG__stop()));\n            ((ma && ma.cancel()));\n            fa = [];\n            ha = false;\n            ca = null;\n            ia = null;\n            ma = null;\n            z = 0;\n            la = null;\n            na = null;\n            oa = null;\n            ga = null;\n            ja = Infinity;\n            aa = false;\n            ((qa && g.unsubscribe(qa)));\n            qa = null;\n            sa.forEach(function(mb) {\n                mb.remove();\n            });\n            sa = [];\n            ((ta && ta.reset()));\n        }\n    };\n    e.exports = ((a.TimelineSideAds || lb));\n});\n__d(\"TimelineStar\", [\"event-extensions\",\"Button\",\"CSS\",\"DOM\",\"Parent\",\"TimelineCapsule\",\"Tooltip\",\"URI\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Button\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"Parent\"), k = b(\"TimelineCapsule\"), l = b(\"Tooltip\"), m = b(\"URI\"), n = {\n        STAR_CSS_ONLY: 1,\n        STAR_ASYNC_REQUIRED: 2,\n        ACTION_STAR: 7,\n        ACTION_UNSTAR: 8,\n        starUnitFromButton: function(o, p, q) {\n            var r = j.byClass(o, \"timelineUnitContainer\");\n            n.starUnit(r, p, q);\n        },\n        starUnit: function(o, p, q) {\n            var r = o.parentNode;\n            if (!q) {\n                i.setContent(r, p);\n            }\n        ;\n        ;\n            h.removeClass(r, \"fbTimelineTwoColumn\");\n            h.addClass(r, \"fbTimelineOneColumn\");\n            r.removeAttribute(\"data-side\");\n            r.setAttribute(\"data-size\", \"2\");\n            l.hide();\n            k.balanceCapsule.curry(r.parentNode).defer();\n        },\n        unstarUnitFromButton: function(o, p, q) {\n            var r = j.byClass(o, \"timelineUnitContainer\");\n            n.unstarUnit(r, p, q);\n        },\n        unstarUnit: function(o, p, q) {\n            var r = o.parentNode;\n            if (!q) {\n                i.setContent(r, p);\n            }\n        ;\n        ;\n            h.removeClass(r, \"fbTimelineOneColumn\");\n            h.addClass(r, \"fbTimelineTwoColumn\");\n            r.setAttribute(\"data-side\", \"l\");\n            r.setAttribute(\"data-size\", \"1\");\n            l.hide();\n            k.balanceCapsule.curry(r.parentNode).defer();\n        },\n        listenToButton: function(o, p) {\n            if (!o) {\n                return;\n            }\n        ;\n        ;\n            switch (p) {\n              case n.STAR_CSS_ONLY:\n                JSBNG__Event.listen(o, \"click\", function(JSBNG__event) {\n                    g.setEnabled.curry(o, false).defer();\n                    var r = j.byClass(o, \"timelineUnitContainer\"), s = n.unstarUnit;\n                    h.toggleClass(o, \"fbTimelineStarButtonSelected\");\n                    h.toggleClass(o, \"selected\");\n                    if (((r.parentNode.getAttribute(\"data-size\") == \"1\"))) {\n                        s = n.starUnit;\n                    }\n                ;\n                ;\n                    s(r, null, true);\n                    var t = new m(o.getAttribute(\"ajaxify\")), u = ((((t.getQueryData().customize_action == n.ACTION_STAR)) ? n.ACTION_UNSTAR : n.ACTION_STAR));\n                    t.addQueryData({\n                        customize_action: u\n                    });\n                    o.setAttribute.bind(o, \"ajaxify\", t).defer();\n                });\n                var q = j.byClass(o, \"stat_elem\");\n                ((q && h.removeClass(q, \"stat_elem\")));\n                break;\n              case n.STAR_ASYNC_REQUIRED:\n                break;\n            };\n        ;\n        }\n    };\n    e.exports = n;\n});\n__d(\"TimelineStickyHeader\", [\"Arbiter\",\"CSS\",\"DOM\",\"TimelineController\",\"ViewportBounds\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"TimelineController\"), k = b(\"ViewportBounds\"), l = false, m = false, n, o, p, q, r = {\n        VISIBLE: \"TimelineStickyHeader/visible\",\n        ADJUST_WIDTH: \"TimelineStickyHeader/adjustWidth\",\n        init: function(s) {\n            if (l) {\n                return;\n            }\n        ;\n        ;\n            l = true;\n            n = s;\n            o = i.JSBNG__find(s, \"div.JSBNG__name\");\n            p = i.JSBNG__find(s, \"div.actions\");\n            m = h.hasClass(s, \"fbTimelineStickyHeaderVisible\");\n            q = k.addTop(function() {\n                return ((m ? ((s.offsetTop + s.scrollHeight)) : 0));\n            });\n            j.register(j.STICKY_HEADER, r);\n        },\n        reset: function() {\n            l = false;\n            m = false;\n            n = null;\n            o = null;\n            p = null;\n            q.remove();\n            q = null;\n        },\n        toggle: function(s) {\n            h.conditionClass(n, \"fbTimelineStickyHeaderHidden\", !s);\n            if (((s !== m))) {\n                m = s;\n                g.inform(r.VISIBLE, s);\n            }\n        ;\n        ;\n        },\n        adjustWidth: function() {\n            g.inform(r.ADJUST_WIDTH, o, g.BEHAVIOR_STATE);\n        },\n        getRoot: function() {\n            return n;\n        },\n        setActions: function(s) {\n            if (((l && s))) {\n                i.setContent(p, s);\n                p = s;\n            }\n        ;\n        ;\n        }\n    };\n    e.exports = ((a.TimelineStickyHeader || r));\n});\n__d(\"TimelineStickyHeaderComposer\", [\"event-extensions\",\"Arbiter\",\"Bootloader\",\"Composer\",\"CSS\",\"DOMQuery\",\"Parent\",\"Run\",\"TimelineComposerUtilities\",\"TimelineContentLoader\",\"TimelineStickyHeader\",\"Vector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"Bootloader\"), i = b(\"Composer\"), j = b(\"CSS\"), k = b(\"DOMQuery\"), l = b(\"Parent\"), m = b(\"Run\"), n = b(\"TimelineComposerUtilities\"), o = b(\"TimelineContentLoader\"), p = b(\"TimelineStickyHeader\"), q = b(\"Vector\"), r = b(\"copyProperties\");\n    function s(t) {\n        this._container = l.byClass(t, \"fbTimelineStickyHeaderComposer\");\n        var u = ((\"xhpc/construct/\" + t.id));\n        this._tokens = [];\n        g.subscribe(u, function(v, w) {\n            this._composer = w;\n            this._tokens = [n.listenToPublish(this._composer, this._close.bind(this)),n.listenToAnotherComposerOpen(this._composer, this._close.bind(this)),n.listenToSetEstimatedDate(this._composer, o.capsuleForCurrentSection),g.subscribe(\"PhotoSnowlift.OPEN\", this._close.bind(this)),g.subscribe(\"TimelineMLE/mleFlyoutShown\", function(x, y) {\n                if (((i.getInstance(y.getContext()) === this._composer))) {\n                    this._closeComposerAttachment();\n                }\n                 else this._close();\n            ;\n            ;\n            }.bind(this)),g.subscribe(\"TimelineMLE/mleFlyoutHidden\", function(x, y) {\n                if (((((y.context && !y.new_flyout)) && ((i.getInstance(y.context) === this._composer))))) {\n                    this._close();\n                }\n            ;\n            ;\n            }.bind(this)),this._composer.subscribeToMutate(this._closeMLE.bind(this)),this._composer.subscribeToMutate(this._registerClickToDismiss.bind(this)),g.subscribe(p.ADJUST_WIDTH, this._toggleNarrowMode.bind(this)),];\n        }.bind(this));\n        this._clickCancelToken = n.listenToCancel(t, this._close.bind(this));\n        m.JSBNG__onLeave(function() {\n            this._tokens.forEach(g.unsubscribe.bind(g));\n            this._tokens = [];\n            this._clickCancelToken.remove();\n            this._clickCancelToken = null;\n            this._clearClickDismissToken();\n        }.bind(this));\n    };\n;\n    r(s.prototype, {\n        _toggleNarrowMode: function(JSBNG__event, t) {\n            h.loadModules([\"Tooltip\",], function(u) {\n                var v = ((q.getElementDimensions(t).x > 400)), w = k.scry(this._composer.root, \"a.attachmentLink\");\n                j.conditionClass(this._composer.root.parentNode, \"narrowStickyHeaderComposer\", v);\n                for (var x = 0; ((x < w.length)); x++) {\n                    var y = w[x], z = k.getText(y);\n                    if (v) {\n                        u.set(y, z);\n                    }\n                     else u.remove(y);\n                ;\n                ;\n                };\n            ;\n            }.bind(this));\n            return false;\n        },\n        _registerClickToDismiss: function() {\n            var t = k.JSBNG__find(this._composer.root, \"span.lifeEventAttachment\");\n            if (!j.hasClass(t, \"uiComposerAttachmentSelected\")) {\n                this._clearClickDismissToken();\n                return;\n            }\n        ;\n        ;\n            this._clickDismissToken = JSBNG__Event.listen(JSBNG__document.body, \"click\", function(JSBNG__event) {\n                var u = JSBNG__event.getTarget();\n                if (!l.byClass(u, \"fbTimelineStickyHeaderComposer\")) {\n                    this._close();\n                    this._clearClickDismissToken();\n                }\n            ;\n            ;\n            }.bind(this));\n        },\n        _clearClickDismissToken: function() {\n            if (this._clickDismissToken) {\n                this._clickDismissToken.remove();\n                this._clickDismissToken = null;\n            }\n        ;\n        ;\n        },\n        _close: function() {\n            this._closeComposerAttachment();\n            this._closeMLE();\n        },\n        _closeComposerAttachment: function() {\n            this._clearClickDismissToken();\n            this._composer.reset();\n            j.removeClass(this._composer.root, \"uiComposerOpen\");\n        },\n        _closeMLE: function() {\n            h.loadModules([\"TimelineMLE\",], function(t) {\n                var u = t.getFlyout();\n                if (((u && ((i.getInstance(u.getContext()) === this._composer))))) {\n                    t.hideFlyout();\n                }\n            ;\n            ;\n            }.bind(this));\n        }\n    });\n    e.exports = s;\n});\n__d(\"TimelineStickyHeaderNav\", [\"array-extensions\",\"event-extensions\",\"function-extensions\",\"Arbiter\",\"ButtonGroup\",\"CSS\",\"DOM\",\"Parent\",\"Selector\",\"Style\",\"TimelineController\",\"URI\",\"UserAgent\",\"Vector\",\"ge\",\"tx\",], function(a, b, c, d, e, f) {\n    b(\"array-extensions\");\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"ButtonGroup\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"Parent\"), l = b(\"Selector\"), m = b(\"Style\"), n = b(\"TimelineController\"), o = b(\"URI\"), p = b(\"UserAgent\"), q = b(\"Vector\"), r = b(\"ge\"), s = b(\"tx\"), t = false, u, v, w, x, y, z, aa, ba, ca, da, ea, fa = {\n    }, ga = {\n    }, ha = [], ia = false, ja = [], ka = [], la = [], ma = [], na = [], oa = [\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\",];\n    function pa(JSBNG__event) {\n        var eb = k.byTag(JSBNG__event.getTarget(), \"a\");\n        if (eb) {\n            n.navigateToSection(eb.getAttribute(\"data-key\"));\n            JSBNG__event.prevent();\n        }\n    ;\n    ;\n    };\n;\n    function qa(eb, fb) {\n        var gb = l.getValue(fb);\n        if (((gb === \"allStories\"))) {\n            n.getSection(eb).expandSubSections();\n        }\n    ;\n    ;\n        if (((gb !== \"activityLog\"))) {\n            ra(fb);\n        }\n    ;\n    ;\n    };\n;\n    function ra(eb) {\n        bb(eb, \"highlights\");\n        bb(eb, \"allStories\");\n        var fb = j.JSBNG__find(eb, \"li.separator\");\n        i.conditionShow(fb, fb.previousSibling);\n    };\n;\n    function sa(eb) {\n        if (((ca[eb] && !v.custom_subsection_menu))) {\n            ya(eb);\n        }\n         else va();\n    ;\n    ;\n        n.adjustStickyHeaderWidth();\n    };\n;\n    function ta(eb, fb) {\n        var gb = fb.key;\n        if (da[gb]) {\n            za(gb);\n            sa(gb);\n        }\n    ;\n    ;\n    };\n;\n    function ua(eb, fb) {\n        var gb = fb.scrubberKey;\n        za(gb);\n        if (((w === gb))) {\n            sa(gb);\n        }\n    ;\n    ;\n    };\n;\n    function va() {\n        x.hideItem(aa);\n    };\n;\n    function wa(eb) {\n        var fb = eb.split(\"_\");\n        return oa[((fb.pop() - 1))];\n    };\n;\n    function xa(eb) {\n        var fb = ba[eb], gb = ca[eb];\n        if (((!fb && gb))) {\n            fb = ba[eb] = aa.cloneNode(true);\n            var hb = j.scry(fb, \"li.activityLog a\")[0];\n            if (hb) {\n                hb.href = o(hb.href).addQueryData({\n                    key: eb\n                });\n            }\n        ;\n        ;\n            var ib = n.getCurrentScrubber();\n            if (gb.length) {\n                i.show(j.JSBNG__find(fb, \"li.separator\"));\n            }\n        ;\n        ;\n            for (var jb = 0; ((jb < gb.length)); jb++) {\n                var kb = gb[jb].scrubberKey, lb = ((ib ? ib.getLabelForSubnav(gb[jb].parentKey, kb) : lb = wa(kb)));\n                if (lb) {\n                    ab(fb, {\n                        key: kb,\n                        label: lb\n                    });\n                }\n            ;\n            ;\n            };\n        ;\n            if (cb()) {\n                ra(fb);\n                l.setSelected(fb, j.scry(fb, \"option\")[1].value, true);\n            }\n        ;\n        ;\n            na.push(l.listen(fb, \"change\", qa.curry(eb, fb)));\n            la.push(JSBNG__Event.listen(fb, \"click\", pa));\n        }\n    ;\n    ;\n        return fb;\n    };\n;\n    function ya(eb) {\n        var fb = xa(eb);\n        j.insertAfter(aa, fb);\n        i.hide(aa);\n        for (var gb in ba) {\n            var hb = ba[gb];\n            i.conditionShow(hb, ((hb === fb)));\n        };\n    ;\n        x.showItem(aa);\n    };\n;\n    function za(eb) {\n        ca[eb] = n.getSection(eb).subSections;\n    };\n;\n    function ab(eb, fb) {\n        var gb = j.create(\"a\", {\n            href: \"#\",\n            rel: \"ignore\",\n            className: \"itemAnchor\",\n            tabIndex: 0\n        }, j.create(\"span\", {\n            className: \"itemLabel fsm\"\n        }, fb.label));\n        gb.setAttribute(\"data-key\", fb.key);\n        gb.setAttribute(\"aria-checked\", false);\n        var hb = j.create(\"li\", {\n            className: \"uiMenuItem uiMenuItemRadio uiSelectorOption\"\n        }, gb);\n        hb.setAttribute(\"data-label\", fb.label);\n        var ib = j.JSBNG__find(eb, \"ul.uiMenuInner\"), jb = j.create(\"option\", {\n            value: fb.key\n        }, fb.label), kb = j.JSBNG__find(eb, \"select\");\n        if (((fb.key === \"recent\"))) {\n            j.prependContent(ib, hb);\n            j.insertAfter(kb.options[0], jb);\n        }\n         else {\n            j.appendContent(ib, hb);\n            j.appendContent(kb, jb);\n        }\n    ;\n    ;\n    };\n;\n    function bb(eb, fb) {\n        var gb = j.scry(eb, \"li.uiMenuItem\");\n        if (!gb) {\n            return;\n        }\n    ;\n    ;\n        for (var hb = 0; ((hb < gb.length)); hb++) {\n            var ib = gb[hb];\n            if (((i.hasClass(ib, fb) || ((ib.firstChild.getAttribute(\"data-key\") == fb))))) {\n                j.remove(ib);\n                break;\n            }\n        ;\n        ;\n        };\n    ;\n        var jb = j.JSBNG__find(eb, \"select\"), kb = j.scry(jb, \"option\");\n        for (hb = 0; ((hb < kb.length)); hb++) {\n            if (((kb[hb].value === fb))) {\n                j.remove(kb[hb]);\n                return;\n            }\n        ;\n        ;\n        };\n    ;\n    };\n;\n    function cb() {\n        return ((((n.getCurrentKey() === \"allactivity\")) || ((n.getCurrentKey() === \"approve\"))));\n    };\n;\n    var db = {\n        init: function(eb, fb) {\n            if (t) {\n                return;\n            }\n        ;\n        ;\n            t = true;\n            u = eb;\n            v = ((fb || {\n            }));\n            y = j.JSBNG__find(u, \"div.pageMenu\");\n            z = j.JSBNG__find(u, \"div.sectionMenu\");\n            aa = j.JSBNG__find(u, \"div.subsectionMenu\");\n            ea = j.JSBNG__find(y, \"li.uiMenuSeparator\");\n            x = h.getInstance(y);\n            ba = {\n            };\n            ca = {\n            };\n            da = {\n            };\n            db.adjustMenuHeights();\n            n.register(n.STICKY_HEADER_NAV, db);\n            if (r(\"pagelet_timeline_friends\")) {\n                db.addTimePeriods(n.getSectionKeys());\n            }\n        ;\n        ;\n            ka.forEach(function(gb) {\n                gb();\n            });\n        },\n        reset: function() {\n            t = false;\n            v = {\n            };\n            ha = [];\n            fa = {\n            };\n            ga = {\n            };\n            ia = false;\n            ja = [];\n            u = null;\n            y = null;\n            z = null;\n            aa = null;\n            ea = null;\n            ba = {\n            };\n            ca = {\n            };\n            da = {\n            };\n            while (la.length) {\n                la.pop().remove();\n            ;\n            };\n        ;\n            ma.forEach(g.unsubscribe);\n            na.forEach(l.unsubscribe.bind(l));\n        },\n        addTimePeriods: function(eb) {\n            if (!eb.length) {\n                return;\n            }\n        ;\n        ;\n            if (v.pull_from_scrubber) {\n                j.setContent(j.JSBNG__find(z, \"ul.uiMenuInner\"), \"\");\n                j.remove(j.JSBNG__find(z, \"select\").children[1]);\n                while (eb.length) {\n                    var fb = eb.shift();\n                    ((fb && db.addTimePeriod(fb)));\n                };\n            ;\n                x.showItem(z);\n            }\n        ;\n        ;\n            var gb = l.getSelectorMenu(z);\n            la.push(JSBNG__Event.listen(gb, \"click\", pa));\n            var hb = ((cb() ? n.SECTION_REGISTERED : n.SECTION_LOADED)), ib = ((cb() ? ua : ta));\n            ma.push(g.subscribe(hb, ib));\n        },\n        addTimePeriod: function(eb) {\n            var fb = n.getCurrentScrubber();\n            if (!fb) {\n                return;\n            }\n        ;\n        ;\n            var gb = fb.getLabelForNav(eb);\n            if (!gb) {\n                return;\n            }\n        ;\n        ;\n            ab(z, {\n                key: eb,\n                label: gb\n            });\n            var hb = j.JSBNG__find(z, \"ul.uiMenuInner\");\n            if (((((eb === \"recent\")) || ((hb.children.length < 2))))) {\n                l.setSelected(z, eb, true);\n            }\n        ;\n        ;\n        },\n        updateSection: function(eb, fb) {\n            if (fb) {\n                var gb = xa(eb);\n                if (gb) {\n                    l.setSelected(gb, fb);\n                    ra(gb);\n                }\n                 else w = eb;\n            ;\n            ;\n            }\n             else {\n                da[eb] = true;\n                za(eb);\n            }\n        ;\n        ;\n            l.setSelected(z, eb, true);\n            sa(eb);\n        },\n        adjustMenuHeights: function() {\n            if (((p.ie() <= 7))) {\n                return;\n            }\n        ;\n        ;\n            [y,z,].forEach(function(eb) {\n                var fb = \"\";\n                if (!i.hasClass(JSBNG__document.documentElement, \"tinyViewport\")) {\n                    fb = ((((q.getViewportDimensions().y - q.getElementDimensions(r(\"blueBar\")).y)) - 80));\n                    fb += \"px\";\n                }\n            ;\n            ;\n                m.set(j.JSBNG__find(eb, \"ul.uiMenuInner\"), \"maxHeight\", fb);\n            });\n        },\n        initPageMenu: function(eb, fb) {\n            if (!t) {\n                ka.push(db.initPageMenu.curry(eb, fb));\n                return;\n            }\n        ;\n        ;\n            function gb(hb, ib) {\n                hb.forEach(function(jb) {\n                    var kb = ga[jb] = j.create(\"li\");\n                    i.hide(kb);\n                    ((ib ? j.insertBefore(ea, kb) : j.appendContent(j.JSBNG__find(y, \"ul.uiMenuInner\"), kb)));\n                });\n            };\n        ;\n            gb(eb, true);\n            gb(fb, false);\n            fa.info = j.scry(y, \"li\")[0];\n            ha = fb;\n            ia = true;\n            if (ja.length) {\n                ja.forEach(function(hb) {\n                    db.registerPageMenuItem(hb.key, hb.item);\n                });\n            }\n        ;\n        ;\n        },\n        registerPageMenuItem: function(eb, fb) {\n            if (!ia) {\n                ja.push({\n                    key: eb,\n                    item: fb\n                });\n                return;\n            }\n        ;\n        ;\n            if (ga[eb]) {\n                j.replace(ga[eb], fb);\n                fa[eb] = fb;\n                delete ga[eb];\n                if (((ha.indexOf(eb) >= 0))) {\n                    i.show(ea);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        removeTimePeriod: function(eb) {\n            bb(z, eb);\n        }\n    };\n    e.exports = db;\n});\n__d(\"TimelineViewportTracking\", [\"event-extensions\",\"Class\",\"DOM\",\"ViewportTracking\",\"$\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Class\"), h = b(\"DOM\"), i = b(\"ViewportTracking\"), j = b(\"$\"), k = b(\"copyProperties\"), l = 55;\n    function m() {\n        this.parent.construct(this);\n    };\n;\n    g.extend(m, i);\n    k(m.prototype, {\n        getDataFromConfig: function(n) {\n            this.timeout = n.record_delay;\n        },\n        getTimeout: function() {\n            return this.timeout;\n        },\n        getAllStories: function() {\n            return h.scry(j(\"timeline_tab_content\"), \".timelineUnitContainer\");\n        },\n        getStoryID: function(n) {\n            var o = JSON.parse(n.getAttribute(\"data-gt\"));\n            return ((o && o.contentid));\n        },\n        getDataToLog: function(n) {\n            var o = {\n                evt: l,\n                timelineviewporttracking: true\n            };\n            return {\n                gt: o\n            };\n        }\n    });\n    e.exports.init = function(n) {\n        (new m()).init(n);\n    };\n});\n__d(\"TimelineScrubber\", [\"event-extensions\",\"CSS\",\"DOM\",\"Parent\",\"TimelineController\",\"Vector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"Parent\"), j = b(\"TimelineController\"), k = b(\"Vector\"), l = b(\"copyProperties\");\n    function m(n) {\n        this._root = n;\n        this._navKeys = {\n        };\n        this._subNavKeys = {\n        };\n        this._rollups = {\n        };\n        this._rolledup = {\n        };\n        var o = n.childNodes;\n        this._currentNav = o[0];\n        for (var p = 0; ((p < o.length)); p++) {\n            var q = o[p].getAttribute(\"data-key\");\n            this._navKeys[q] = o[p];\n            var r = h.scry(o[p], \"ul\");\n            this._subNavKeys[q] = {\n            };\n            if (r.length) {\n                var s = r[0].childNodes;\n                for (var t = 0; ((t < s.length)); t++) {\n                    this._subNavKeys[q][s[t].getAttribute(\"data-key\")] = s[t];\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            var u = o[p].getAttribute(\"data-rollup\");\n            if (u) {\n                this._rollups[u] = ((this._rollups[u] || []));\n                this._rollups[u].push(o[p]);\n            }\n        ;\n        ;\n        };\n    ;\n        this._clickListener = JSBNG__Event.listen(this._root, \"click\", this._handleScrub.bind(this));\n        g.show(this._root);\n        var v = ((k.getViewportDimensions().y - this.SCRUBBER_NO_ADS_VERTICAL_BUFFER)), w = this.getHeight();\n        if (((w > v))) {\n            this.fold(((w - v)));\n        }\n    ;\n    ;\n        j.register(j.SCRUBBER, this);\n        j.scrubberHasLoaded(this);\n    };\n;\n    l(m.prototype, {\n        KEY_HEIGHT: 23,\n        SUBKEY_HEIGHT: 16,\n        OFFSET: 38,\n        SCRUBBER_NO_ADS_VERTICAL_BUFFER: 125,\n        reset: function() {\n            this._root = null;\n            this._navKeys = {\n            };\n            this._subNavKeys = {\n            };\n            this._rollups = {\n            };\n            this._rolledup = {\n            };\n        },\n        getRoot: function() {\n            return this._root;\n        },\n        getNav: function(n) {\n            return this._navKeys[n];\n        },\n        getSubnav: function(n, o) {\n            return this._subNavKeys[n][o];\n        },\n        getHeight: function() {\n            return this._root.offsetHeight;\n        },\n        getLabelForNav: function(n) {\n            var o = this.getNav(n);\n            return ((o && h.getText(h.scry(o, \"a\")[0])));\n        },\n        getLabelForSubnav: function(n, o) {\n            var p = this.getSubnav(n, o);\n            return ((p && h.getText(h.scry(p, \"a\")[0])));\n        },\n        fold: function(n) {\n            return this._adjustFolding(n, true);\n        },\n        unfold: function(n) {\n            return this._adjustFolding(n, false);\n        },\n        getOffset: function() {\n            return ((((this.OFFSET + ((g.hasClass(JSBNG__document.body, \"hasVoiceBar\") ? 26 : 0)))) + ((g.hasClass(\"rightColContent\", \"pagesTimelineRightColumn\") ? 34 : 0))));\n        },\n        updateSection: function(n, o) {\n            var p = this._navKeys[n].getAttribute(\"data-rollup\");\n            if (((this._currentRollup && ((this._currentRollup != p))))) {\n                g.removeClass(this._currentRollup, \"selected\");\n                g.removeClass(h.scry(this._currentRollup, \"ul\")[0], \"loaded\");\n                delete this._currentRollup;\n            }\n        ;\n        ;\n            if (((p && this._rolledup[p]))) {\n                var q = this._rolledup[p];\n                if (q.getAttribute(\"data-rollup\")) {\n                    this._currentRollup = q;\n                    g.addClass(this._currentRollup, \"selected\");\n                    g.addClass(h.scry(this._currentRollup, \"ul\")[0], \"loaded\");\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            ((this._currentNav && g.removeClass(this._currentNav, \"selected\")));\n            ((this._currentSubNav && g.removeClass(this._currentSubNav, \"selected\")));\n            this._currentNav = null;\n            this._currentSubNav = null;\n            if (this._navKeys[n]) {\n                this._currentNav = this._navKeys[n];\n                g.addClass(this._currentNav, \"selected\");\n                if (((this.decadesAreSelectable && this._navKeys[o]))) {\n                    this._currentSubNav = this._navKeys[o];\n                    g.addClass(this._currentSubNav, \"selected\");\n                }\n                 else if (((o && this._subNavKeys[n][o]))) {\n                    this._currentSubNav = this._subNavKeys[n][o];\n                    g.addClass(this._currentSubNav, \"selected\");\n                }\n                \n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        _getRollupSize: function(n) {\n            var o = this._currentNav, p = ((o && o.getAttribute(\"data-rollup\"))), q = ((this.KEY_HEIGHT * ((this._rollups[n].length - 1))));\n            if (((n == p))) {\n                q += ((this.SUBKEY_HEIGHT * h.scry(o, \"li\").length));\n                q -= ((this.SUBKEY_HEIGHT * ((this._rollups[n].length - 1))));\n            }\n        ;\n        ;\n            return q;\n        },\n        _adjustFolding: function(n, o) {\n            var p = n, q = Object.keys(this._rollups);\n            while (((((n > 0)) && q.length))) {\n                var r = q[((o ? \"pop\" : \"shift\"))]();\n                if (((!o == !this._rolledup[r]))) {\n                    continue;\n                }\n            ;\n            ;\n                var s = this._getRollupSize(r);\n                if (((s <= 0))) {\n                    continue;\n                }\n            ;\n            ;\n                if (((!o && ((s > n))))) {\n                    break;\n                }\n            ;\n            ;\n                this[((o ? \"_collapseRollup\" : \"_expandRollup\"))](r);\n                n -= s;\n            };\n        ;\n            return ((p - n));\n        },\n        _collapseRollup: function(n) {\n            var o = this._rollups[n];\n            if (((((!o || ((o.length < 2)))) || this._rolledup[n]))) {\n                return;\n            }\n        ;\n        ;\n            var p = o[0].previousSibling, q = o[0], r = h.create(\"a\", {\n                href: q.firstChild.href,\n                rel: \"ignore\"\n            }, [n,]), s = h.create(\"ul\", {\n                className: \"clearfix\"\n            });\n            for (var t = 0; ((t < o.length)); t++) {\n                s.appendChild(o[t]);\n            ;\n            };\n        ;\n            var u = h.create(\"li\", null, [r,s,]);\n            if (this.decadesAreSelectable) {\n                var v = o[((o.length - 1))], w = ((q.getAttribute(\"data-key\") + v.getAttribute(\"data-key\")));\n                u.setAttribute(\"data-start\", v.getAttribute(\"data-start\"));\n                u.setAttribute(\"data-end\", q.getAttribute(\"data-end\"));\n                u.setAttribute(\"data-key\", w);\n                this._navKeys[w] = u;\n            }\n             else u.setAttribute(\"data-key\", q.getAttribute(\"data-key\"));\n        ;\n        ;\n            u.setAttribute(\"data-rollup\", n);\n            if (p) {\n                h.insertAfter(p, u);\n            }\n             else h.prependContent(this._root, u);\n        ;\n        ;\n            this._rolledup[n] = u;\n            this._checkSelection();\n        },\n        _expandRollup: function(n) {\n            if (!this._rolledup[n]) {\n                return;\n            }\n        ;\n        ;\n            var o = this._rolledup[n], p = h.scry(o, \"ul\")[0], q = JSBNG__document.createDocumentFragment();\n            while (p.childNodes.length) {\n                q.appendChild(p.firstChild);\n            ;\n            };\n        ;\n            h.replace(o, q);\n            this._rolledup[n] = false;\n            this._checkSelection();\n        },\n        _checkSelection: function() {\n            if (this._currentNav) {\n                var n = ((this._currentSubNav && this._currentSubNav.getAttribute(\"data-key\")));\n                this.updateSection(this._currentNav.getAttribute(\"data-key\"), n);\n            }\n        ;\n        ;\n        },\n        _handleScrub: function(JSBNG__event) {\n            var n = JSBNG__event.getModifiers();\n            if (((((JSBNG__event.isMiddleClick() || n.access)) || n.meta))) {\n                return true;\n            }\n        ;\n        ;\n            var o = i.byTag(JSBNG__event.getTarget(), \"a\"), p = ((o && i.byAttribute(o, \"data-key\")));\n            if (p) {\n                j.scrubberWasClicked(p.getAttribute(\"data-key\"));\n                j.navigateToSection(p.getAttribute(\"data-key\"));\n                return JSBNG__event.prevent();\n            }\n        ;\n        ;\n        }\n    });\n    e.exports = m;\n});\n__d(\"TimelineMainScrubber\", [\"Arbiter\",\"Class\",\"CSS\",\"DOMQuery\",\"TimelineController\",\"TimelineScrubber\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"Class\"), i = b(\"CSS\"), j = b(\"DOMQuery\"), k = b(\"TimelineController\"), l = b(\"TimelineScrubber\"), m = b(\"copyProperties\");\n    function n(o) {\n        this.parent.construct(this, o);\n        this._subscribe = g.subscribe(k.SECTION_LOADED, function(p, q) {\n            var r = this._navKeys[q.key], s = ((r && j.scry(r, \"ul\")[0]));\n            if (s) {\n                i.addClass(s, \"loaded\");\n                k.scrubberHasChangedState();\n                if (q.hideSubSections) {\n                    i.hide(s);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        }.bind(this));\n    };\n;\n    h.extend(n, l);\n    m(n.prototype, {\n        reset: function() {\n            this.parent.reset();\n            ((this._subscribe && this._subscribe.unsubscribe()));\n        }\n    });\n    e.exports = n;\n});\n__d(\"profile-pic-dragdrop-edit\", [\"Arbiter\",\"SinglePictureUploadTarget\",\"TimelineProfilePic\",], function(a, b, c, d, e, f) {\n    var g = b(\"Arbiter\"), h = b(\"SinglePictureUploadTarget\"), i = b(\"TimelineProfilePic\");\n    f.initialize_profile_pic_drop_target = function(j, k, l, m) {\n        new i(l, m);\n        new h(j, k).setPreprocessCallback(function(n) {\n            g.inform(l.LOADING, {\n                isLoading: 1\n            }, g.BEHAVIOR_STATE);\n        }).setOncompleteCallback(function() {\n            g.inform(l.LOADING, {\n                isLoading: 0\n            }, g.BEHAVIOR_STATE);\n        }).setAfterSuccessCallback(function(n) {\n            g.inform(l.SUCCESS, {\n                newPic: n.photo_html\n            }, g.BEHAVIOR_STATE);\n        }).activate();\n    };\n});\n__d(\"legacy:TimelineCover\", [\"TimelineCover\",], function(a, b, c, d) {\n    a.TimelineCover = b(\"TimelineCover\");\n}, 3);\n__d(\"OnlyMeUI\", [\"AudienceSelector\",\"Arbiter\",\"CSS\",\"DOM\",\"Parent\",\"PrivacyConst\",\"Selector\",\"$\",\"tx\",], function(a, b, c, d, e, f) {\n    var g = b(\"AudienceSelector\"), h = b(\"Arbiter\"), i = b(\"CSS\"), j = b(\"DOM\"), k = b(\"Parent\"), l = b(\"PrivacyConst\"), m = b(\"Selector\"), n = b(\"$\"), o = b(\"tx\");\n    function p() {\n        return [j.create(\"div\", {\n            className: \"JSBNG__onlyMeBorder\"\n        }),j.create(\"div\", {\n            className: \"JSBNG__onlyMeBorder onlyMeBorderBottom\"\n        }),];\n    };\n;\n    function q() {\n        return j.create(\"img\", {\n            alt: \" \",\n            className: \"JSBNG__onlyMePrivacyCorner\",\n            height: 34,\n            src: \"/images/profile/timeline/privacy_corner.png\",\n            width: 34\n        });\n    };\n;\n    function r(x) {\n        var y = j.scry(x, \".photoUnit a.photo\");\n        return y.filter(function(z) {\n            return !j.scry(z, \".JSBNG__onlyMePrivacyCorner\").length;\n        });\n    };\n;\n    function s(x, y) {\n        if (g.hasTags(u(y))) {\n            return;\n        }\n    ;\n    ;\n        i.addClass(x, \"storyOnlyMe\");\n        if (!i.hasClass(x, \"timelineRecentActivityStory\")) {\n            j.setContent(j.JSBNG__find(y, \"span.uiButtonText\"), \"Only Me\");\n        }\n    ;\n    ;\n        if (!i.hasClass(x, \"storyContent\")) {\n            var z = r(x);\n            for (var aa = 0, ba = z.length; ((aa < ba)); ++aa) {\n                j.appendContent(z[aa], q());\n            ;\n            };\n        ;\n        }\n    ;\n    ;\n        if (!j.scry(x, \"div.JSBNG__onlyMeBorder\").length) {\n            var ca = p();\n            j.prependContent(x, ca[0]);\n            j.appendContent(x, ca[1]);\n        }\n    ;\n    ;\n    };\n;\n    function t(x) {\n        if (!x) {\n            return;\n        }\n    ;\n    ;\n        var y = ((((((k.byClass(x, \"storyContent\") || k.byClass(x, \"timelineRecentActivityStory\"))) || k.byClass(x, \"timelineUnitContainer\"))) || k.byClass(x, \"fbTimelineTwoColumn\")));\n        if (!y) {\n            y = j.scry(x, \"^.permalink_stream .storyContent\");\n            y = ((y.length && y[0]));\n        }\n         else if (i.hasClass(y, \"fbTimelineComposerUnit\")) {\n            return null;\n        }\n        \n    ;\n    ;\n        return y;\n    };\n;\n    function u(x) {\n        var y = j.scry(x, \"*[data-oid]\");\n        if (((y.length === 0))) {\n            return \"\";\n        }\n    ;\n    ;\n        return y[0].getAttribute(\"data-oid\");\n    };\n;\n    var v = false, w = {\n        init: function() {\n            if (v) {\n                return;\n            }\n        ;\n        ;\n            v = true;\n            h.subscribe(\"AudienceSelector/changed\", function(x, y) {\n                var z = ((t(y.selector) || t(y.clone)));\n                if (!z) {\n                    return;\n                }\n            ;\n            ;\n                if (((m.getOptionValue(y.option) == l.BaseValue.SELF))) {\n                    s(z, y.selector);\n                }\n                 else i.removeClass(z, \"storyOnlyMe\");\n            ;\n            ;\n            });\n        },\n        setOnlyMe: function(x) {\n            if (v) {\n                return;\n            }\n        ;\n        ;\n            w.init();\n            x = j.JSBNG__find(k.byClass(n(x), \"uiSelector\"), \"a.uiSelectorButton\");\n            var y = t(x);\n            ((y && s(y, x)));\n        }\n    };\n    e.exports = w;\n});\nfunction StreamProfileComposer() {\n\n};\n;\ncopyProperties(StreamProfileComposer.prototype, {\n    init: function(a) {\n        var b = $(a);\n        Arbiter.subscribe(\"composer/publish\", function(JSBNG__event, c) {\n            if (c.streamStory) {\n                animation.prependInsert(b, c.streamStory);\n            }\n        ;\n        ;\n        });\n    }\n});\n__d(\"SwapButton\", [\"event-extensions\",\"copyProperties\",\"CSS\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"copyProperties\"), h = b(\"CSS\");\n    function i(j, k, l) {\n        this._swapperButton = j;\n        this._swappeeButton = k;\n        JSBNG__Event.listen(j, \"click\", this.swap.bind(this));\n        if (l) {\n            JSBNG__Event.listen(k, \"click\", this.unswap.bind(this));\n        }\n    ;\n    ;\n    };\n;\n    g(i.prototype, {\n        _swapperButton: null,\n        _swappeeButton: null,\n        swap: function() {\n            h.hide(this._swapperButton);\n            h.show(this._swappeeButton);\n        },\n        unswap: function() {\n            h.show(this._swapperButton);\n            h.hide(this._swappeeButton);\n        },\n        toggle: function() {\n            h.toggle(this._swapperButton);\n            h.toggle(this._swappeeButton);\n        }\n    });\n    e.exports = i;\n});\n__d(\"CountButtonCount\", [\"ArbiterMixin\",\"copyProperties\",\"DOM\",], function(a, b, c, d, e, f) {\n    var g = b(\"ArbiterMixin\"), h = b(\"copyProperties\"), i = b(\"DOM\");\n    function j(k, l, m) {\n        this._root = k;\n        this._count = l;\n        this._max = m;\n    };\n;\n    h(j.prototype, g, {\n        getCount: function() {\n            return this._count;\n        },\n        setCount: function(k) {\n            this._count = k;\n            var l = this.getDisplayedValue();\n            i.setContent(this._root, l);\n            this.inform(\"change\", {\n                value: this._count,\n                display: l\n            });\n            return this;\n        },\n        addCount: function(k) {\n            this.setCount(((this.getCount() + k)));\n            return this;\n        },\n        getDisplayedValue: function() {\n            return Math.max(0, Math.min(this._count, this._max));\n        }\n    });\n    e.exports = j;\n});\n__d(\"CountButton\", [\"copyProperties\",\"CSS\",\"cx\",], function(a, b, c, d, e, f) {\n    var g = b(\"copyProperties\"), h = b(\"CSS\"), i = b(\"cx\"), j = {\n        large: \"-cx-PRIVATE-uiCountButton__counterLarge\",\n        small: \"-cx-PRIVATE-uiCountButton__counterSmall\",\n        hidden: \"-cx-PRIVATE-uiCountButton__counterHidden\"\n    };\n    function k(l, m) {\n        this._root = l;\n        this._counter = m;\n        this._initEvents();\n    };\n;\n    g(k.prototype, {\n        _initEvents: function() {\n            this._counter.subscribe(\"change\", this._counterChange.bind(this));\n        },\n        _counterChange: function(l, m) {\n            h.removeClass(this._root, j.large);\n            h.removeClass(this._root, j.small);\n            h.removeClass(this._root, j.hidden);\n            if (((m.value > 9))) {\n                h.addClass(this._root, j.large);\n            }\n             else if (((m.value > 0))) {\n                h.addClass(this._root, j.small);\n            }\n             else h.addClass(this._root, j.hidden);\n            \n        ;\n        ;\n        },\n        getCounter: function() {\n            return this._counter;\n        }\n    });\n    e.exports = k;\n});\n__d(\"HoverButton\", [\"AsyncRequest\",\"CSS\",\"DOM\",\"URI\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    var g = b(\"AsyncRequest\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"URI\"), k = b(\"copyProperties\");\n    function l(m, n, o, p) {\n        this._button = m;\n        this._flyout = n;\n        this._flyoutAjaxify = p;\n        this._flyoutContent = o;\n        n.subscribe(\"show\", this._onShow.bind(this));\n        n.subscribe(\"hide\", this._onHide.bind(this));\n    };\n;\n    k(l.prototype, {\n        _button: null,\n        _flyout: null,\n        _flyoutAjaxify: null,\n        _flyoutContent: null,\n        showFlyoutBriefly: function() {\n            this.showFlyout();\n            this._flyout.hideFlyoutDelayed(5000);\n        },\n        showFlyout: function() {\n            this._flyout.showFlyout(this._button, true);\n            this._flyout.inform(\"show\", this._button);\n        },\n        hideFlyout: function() {\n            this._flyout.hideFlyout(true);\n            this._flyout.inform(\"hide\", this._button);\n        },\n        _onShow: function(m, n) {\n            h.addClass(n, \"uiHoverButtonSelected\");\n            h.addClass(n, \"selected\");\n            if (this._flyoutAjaxify) {\n                h.addClass(this._flyoutContent, \"async_saving\");\n                new g().setURI(new j(this._flyoutAjaxify)).setHandler(function(o) {\n                    h.removeClass(this._flyoutContent, \"async_saving\");\n                    i.setContent(this._flyoutContent, o.payload);\n                }.bind(this)).send();\n                this._flyoutAjaxify = null;\n            }\n        ;\n        ;\n        },\n        _onHide: function(m, n) {\n            h.removeClass(n, \"uiHoverButtonSelected\");\n            h.removeClass(n, \"selected\");\n        },\n        destroy: function() {\n            this.hideFlyout();\n            this._flyout.destroy();\n        }\n    });\n    e.exports = l;\n});\n__d(\"legacy:TooltipLink\", [\"TooltipLink\",], function(a, b, c, d) {\n    a.TooltipLink = b(\"TooltipLink\");\n}, 3);\n__d(\"HoverFlyout\", [\"event-extensions\",\"ArbiterMixin\",\"Class\",\"DataStore\",\"LayerDestroyOnHide\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"ArbiterMixin\"), h = b(\"Class\"), i = b(\"DataStore\"), j = b(\"LayerDestroyOnHide\"), k = b(\"copyProperties\");\n    function l(m, n, o, p) {\n        if (m) {\n            this._showDelay = o;\n            this._hideDelay = p;\n            this.init(m);\n            if (n) {\n                this.initNode(n);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    };\n;\n    k(l.prototype, g, {\n        init: function(m) {\n            this._flyout = m;\n            this._showDelay = ((this._showDelay || 0));\n            this._hideDelay = ((this._hideDelay || 100));\n            this._showTimeout = null;\n            this._hideTimeout = null;\n            this._flyoutSubscriptions = [this._flyout.subscribe(\"mouseenter\", this._onFlyoutMouseEnter.bind(this)),this._flyout.subscribe(\"mouseleave\", this.hideFlyout.shield(this)),];\n            this._nodes = [];\n            this._dataStoreUnique = ((((\"HoverFlyout_\" + JSBNG__Date.now())) + \"_listeners\"));\n            this._flyout.disableBehavior(j);\n            return this;\n        },\n        initNode: function(m) {\n            if (this._nodes.contains(m)) {\n                return this;\n            }\n        ;\n        ;\n            this._nodes.push(m);\n            i.set(m, this._dataStoreUnique, [JSBNG__Event.listen(m, \"mouseenter\", this._onNodeMouseEnter.bind(this, m)),JSBNG__Event.listen(m, \"mouseleave\", this.hideFlyout.shield(this)),]);\n            return this;\n        },\n        deactivateNode: function(m) {\n            var n = i.get(m, this._dataStoreUnique);\n            if (n) {\n                while (n.length) {\n                    n.pop().remove();\n                ;\n                };\n            }\n        ;\n        ;\n            this._nodes.remove(m);\n        },\n        setShowDelay: function(m) {\n            this._showDelay = m;\n            return this;\n        },\n        setHideDelay: function(m) {\n            this._hideDelay = m;\n            return this;\n        },\n        showFlyout: function(m, n) {\n            this.setActiveNode(m);\n            if (n) {\n                this._flyout.setContext(m).show();\n                this.inform(\"show\", m);\n            }\n             else this._showTimeout = this.showFlyout.bind(this, m, true).defer(this._showDelay);\n        ;\n        ;\n            return this;\n        },\n        hideFlyout: function(m) {\n            JSBNG__clearTimeout(this._showTimeout);\n            if (m) {\n                this._flyout.hide();\n                ((this._activeNode && this.inform(\"hide\", this._activeNode)));\n                this._activeNode = null;\n            }\n             else this._hideTimeout = this.hideFlyout.bind(this, true).defer(this._hideDelay);\n        ;\n        ;\n        },\n        hideFlyoutDelayed: function(m) {\n            JSBNG__clearTimeout(this._showTimeout);\n            JSBNG__clearTimeout(this._hideTimeout);\n            this._hideTimeout = this.hideFlyout.bind(this, true).defer(m);\n        },\n        getActiveNode: function() {\n            return this._activeNode;\n        },\n        setActiveNode: function(m) {\n            JSBNG__clearTimeout(this._hideTimeout);\n            if (((this._activeNode && ((this._activeNode !== m))))) {\n                this.hideFlyout(true);\n            }\n        ;\n        ;\n            this._activeNode = m;\n            return this;\n        },\n        clearNodes: function() {\n            for (var m = this._nodes.length; ((m > 0)); m--) {\n                this.deactivateNode(this._nodes[((m - 1))]);\n            ;\n            };\n        ;\n        },\n        destroy: function() {\n            while (this._flyoutSubscriptions.length) {\n                this._flyout.unsubscribe(this._flyoutSubscriptions.pop());\n            ;\n            };\n        ;\n            this.clearNodes();\n        },\n        _onNodeMouseEnter: function(m) {\n            if (((this._activeNode === m))) {\n                JSBNG__clearTimeout(this._hideTimeout);\n            }\n             else this.showFlyout(m);\n        ;\n        ;\n        },\n        _onFlyoutMouseEnter: function() {\n            JSBNG__clearTimeout(this._hideTimeout);\n        }\n    });\n    e.exports = ((a.HoverFlyout || l));\n});\n__d(\"TypeaheadSetPhotoOnSelect\", [\"event-extensions\",\"function-extensions\",\"CSS\",\"DOM\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    b(\"function-extensions\");\n    var g = b(\"CSS\"), h = b(\"DOM\"), i = b(\"copyProperties\");\n    function j(k) {\n        this._typeahead = k;\n    };\n;\n    i(j.prototype, {\n        _eventListener: null,\n        _subscription: null,\n        enable: function() {\n            var k = h.scry(this._typeahead.getElement(), \".photo\")[0];\n            if (k) {\n                if (!h.isNodeOfType(k, \"img\")) {\n                    var l = h.create(\"img\", {\n                        className: k.className\n                    });\n                    h.replace(k, l);\n                    k = l;\n                }\n            ;\n            ;\n                var m = g.hide.curry(k), n = g.show.curry(k);\n                this._eventListener = JSBNG__Event.listen(k, {\n                    load: n,\n                    error: m,\n                    abort: m\n                });\n                this._subscription = this._typeahead.subscribe(\"select\", function(o, p) {\n                    var q = ((p.selected.photo || this._typeahead.view.fallbackPhoto));\n                    ((q ? k.setAttribute(\"src\", q) : m()));\n                }.bind(this));\n            }\n        ;\n        ;\n        },\n        disable: function() {\n            this._eventListener.remove();\n            this._eventListener = null;\n            this._typeahead.unsubscribe(this._subscription);\n            this._subscription = null;\n        }\n    });\n    e.exports = j;\n});\n__d(\"legacy:SetPhotoOnSelectTypeaheadBehavior\", [\"TypeaheadSetPhotoOnSelect\",], function(a, b, c, d) {\n    var e = b(\"TypeaheadSetPhotoOnSelect\");\n    if (!a.TypeaheadBehaviors) {\n        a.TypeaheadBehaviors = {\n        };\n    }\n;\n;\n    a.TypeaheadBehaviors.setPhotoOnSelect = function(f) {\n        f.enableBehavior(e);\n    };\n}, 3);");
// 3692
JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_84[0](o4,false,o16);
// undefined
o4 = null;
// undefined
o16 = null;
// 4348
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"1vNpf\",]);\n}\n;\n__d(\"legacy:XHPTemplate\", [\"XHPTemplate\",], function(a, b, c, d) {\n    a.XHPTemplate = b(\"XHPTemplate\");\n}, 3);\nfunction DynamicFacepile() {\n\n};\ncopyProperties(DynamicFacepile.prototype, {\n    init: function(a, b, c, d) {\n        this._facepile = c;\n        this._maxFacepileSize = b;\n        this._memberIDs = a;\n        this._facepileItemMap = {\n        };\n        var e = DOM.scry(this._facepile, \"li\");\n        for (var f = 0, g = a.length; (f < g); ++f) {\n            this._facepileItemMap[a[f]] = e[f];;\n        };\n        this._template = d;\n    },\n    containsID: function(a) {\n        return this._facepileItemMap[a];\n    },\n    removeFacepileItem: function(a) {\n        var b = this._facepileItemMap[a.uid];\n        if (!b) {\n            return\n        };\n        delete this._facepileItemMap[a.uid];\n        this._memberIDs.splice(this._memberIDs.indexOf(a.uid), 1);\n        DOM.remove(b);\n    },\n    addFacepileItem: function(a) {\n        var b = this._template.render(), c = XHPTemplate.getNode(b, \"img\");\n        c.src = a.photo;\n        var d = XHPTemplate.getNode(b, \"anchor\");\n        d.href = URI(\"/profile.php\").addQueryData({\n            id: a.uid\n        });\n        TooltipLink.setTooltipText(d, a.name);\n        DOM.prependContent(this._facepile, b);\n        this._facepileItemMap[a.uid] = b;\n        this._memberIDs.unshift(a.uid);\n        if ((this._memberIDs.length > this._maxFacepileSize)) {\n            var e = this._memberIDs.pop(), f = this._facepileItemMap[e];\n            DOM.remove(f);\n            delete this._facepileItemMap[e];\n        }\n    ;\n    }\n});\nvar FriendsDashSideCol = {\n    init: function(a) {\n        this._flid = a;\n        var b = \"listeditor/friend_lists_changed\", c = Arbiter.subscribe(b, function(d, e) {\n            if (((d == b) && (e.list_info.list_id == this._flid))) {\n                if (e.refresh_member_box) {\n                    new AsyncRequest(\"/ajax/friends/lists/list_modified.php\").setMethod(\"GET\").setReadOnly(true).setData({\n                        list_id: this._flid\n                    }).send();\n                };\n                if (e.removed_uid) {\n                    DOM.scry($(\"home_stream\"), (\".aid_\" + e.removed_uid)).forEach(CSS.hide);\n                }\n                 else if ((e.undo_remove && e.added_uid)) {\n                    DOM.scry($(\"home_stream\"), (\".aid_\" + e.added_uid)).forEach(CSS.show);\n                }\n                 else Arbiter.inform(UIIntentionalStreamMessage.REFRESH_STREAM, {\n                    filter: (\"fl_\" + this._flid),\n                    noScroll: 1\n                });\n                \n            ;\n            }\n        ;\n        }.bind(this), Arbiter.SUBSCRIBE_NEW);\n        PageTransitions.registerHandler(Arbiter.unsubscribe.curry(c));\n    }\n};\n__d(\"FriendListHeader\", [\"event-extensions\",\"AsyncRequest\",\"CSS\",\"DOM\",\"Input\",\"Menu\",\"PageTransitions\",\"Parent\",\"Selector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"AsyncRequest\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"Input\"), k = b(\"Menu\"), l = b(\"PageTransitions\"), m = b(\"Parent\"), n = b(\"Selector\"), o = b(\"copyProperties\");\n    function p() {\n    \n    };\n    o(p.prototype, {\n        init: function(q, r) {\n            var s = i.find(q, \".nameInput\"), t = i.find(q, \".staticName .name\"), u = k.subscribe(\"select\", function(w, x) {\n                if (!m.byClass(x.menu, \"friendListManage\")) {\n                    return\n                };\n                var y = x.item;\n                if (h.hasClass(y, \"editName\")) {\n                    h.addClass(q, \"friendListHeaderEditMode\");\n                    j.setValue(s, \"\");\n                    j.focus(s);\n                }\n                 else if (h.hasClass(y, \"chooseUpdateTypes\")) {\n                    h.addClass(x.menu, \"updateTypesExpanded\");\n                    return false;\n                }\n                \n            ;\n            }), v = n.subscribe(\"select\", function(w, x) {\n                if (!h.hasClass(x.selector, \"friendListManage\")) {\n                    return\n                };\n                if (h.hasClass(x.option, \"updateType\")) {\n                    k.toggleItem(x.option);\n                    var y = [];\n                    n.getSelectedOptions(x.selector).forEach(function(z) {\n                        y.push(n.getOptionValue(z));\n                    });\n                    new g().setURI(\"/ajax/friends/lists/subscriptions.php\").setData({\n                        subs: y,\n                        flid: r\n                    }).send();\n                    return false;\n                }\n            ;\n            });\n            Event.listen(q, \"click\", function(w) {\n                if (m.byClass(w.getTarget(), \"cancel\")) {\n                    h.removeClass(q, \"friendListHeaderEditMode\");\n                    return;\n                }\n            ;\n                if ((m.byClass(w.getTarget(), \"saveButton\") && j.isEmpty(s))) {\n                    j.focus(s);\n                    w.preventDefault();\n                }\n            ;\n            });\n            l.registerHandler(function() {\n                k.unsubscribe(u);\n                n.unsubscribe(v);\n            });\n        }\n    });\n    e.exports = p;\n});\n__d(\"legacy:FriendListHeader\", [\"FriendListHeader\",], function(a, b, c, d) {\n    a.FriendListHeader = b(\"FriendListHeader\");\n}, 3);\nfunction FriendListMembersBox() {\n\n};\ncopyProperties(FriendListMembersBox.prototype, {\n    init: function(a, b, c, d, e, f, g) {\n        this._root = a;\n        this._flid = b;\n        this._listSize = d;\n        this._headerTitle = DOM.find(this._root, \".uiHeaderTitle\");\n        this._headerActions = DOM.find(this._root, \".uiHeaderActions a\");\n        this._facepile = new DynamicFacepile();\n        this._facepile.init(c, e, f.firstChild, g);\n        var h = [Arbiter.subscribe([\"FriendListSuggestions/add\",\"FriendListMemberTypeahead/add\",\"FriendListHovercard/add\",], this.handleAddEvent.bind(this)),Arbiter.subscribe(\"FriendListHovercard/remove\", this.handleRemoveEvent.bind(this)),];\n        PageTransitions.registerHandler(function() {\n            h.forEach(Arbiter.unsubscribe);\n        });\n    },\n    handleAddEvent: function(a, b) {\n        if (((b.flid !== this._flid) || !b.uid)) {\n            return\n        };\n        if (this._facepile.containsID(b.uid)) {\n            return\n        };\n        if ((!b.photo || !b.name)) {\n            requireLazy([\"ShortProfiles\",], function(c) {\n                c.get(b.uid, function(d, e) {\n                    if (e.exist) {\n                        d.flid = this._flid;\n                        d.photo = e.thumbSrc;\n                        d.name = e.firstName;\n                        this._facepile.addFacepileItem(d);\n                    }\n                ;\n                }.bind(this, b));\n            }.bind(this));\n        }\n         else this._facepile.addFacepileItem(b);\n    ;\n        CSS.removeClass(this._root, \"empty\");\n        CSS.show(this._headerActions);\n        this._listSize++;\n        this.updateListSize();\n    },\n    handleRemoveEvent: function(a, b) {\n        if (((b.flid !== this._flid) || !b.uid)) {\n            return\n        };\n        this._listSize--;\n        this.updateListSize();\n        this._facepile.removeFacepileItem(b);\n    },\n    updateListSize: function() {\n        DOM.setContent(this._headerTitle, tx._(\"On This List ({num_members})\", {\n            num_members: this._listSize\n        }));\n    }\n});\n__d(\"FriendListSuggestions\", [\"event-extensions\",\"Arbiter\",\"AsyncRequest\",\"AsyncSignal\",\"Bootloader\",\"CSS\",\"DOM\",\"DynamicFriendListEducation\",\"PageTransitions\",\"Parent\",\"UserAgent\",\"copyProperties\",\"csx\",\"ge\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"AsyncSignal\"), j = b(\"Bootloader\"), k = b(\"CSS\"), l = b(\"DOM\"), m = b(\"DynamicFriendListEducation\"), n = b(\"PageTransitions\"), o = b(\"Parent\"), p = b(\"UserAgent\"), q = b(\"copyProperties\"), r = b(\"csx\"), s = b(\"ge\");\n    function t() {\n    \n    };\n    q(t.prototype, {\n        init: function(u, v, w, x, y) {\n            this._container = u;\n            this._flid = v;\n            this._shouldSave = w;\n            this._context = x;\n            this._source = y;\n            var z = Event.listen(u, \"click\", function(ba) {\n                var ca = ba.getTarget();\n                (o.byClass(ca, \"addLink\") && this._handleAdd(ca));\n                (o.byClass(ca, \"declineButton\") && this._handleDecline(ca));\n            }.bind(this));\n            if ((p.ie() < 7)) {\n                j.loadModules([\"ExplicitHover\",], function(ba) {\n                    this._explicitHover = new ba(this._container, \"friendListSuggestion\");\n                }.bind(this));\n            };\n            var aa = g.subscribe(\"FriendListMemberTypeahead/add\", function(ba, ca) {\n                var da = s((\"suggestion_\" + ca.uid));\n                (da && this._swap(da));\n            }.bind(this));\n            n.registerHandler(function() {\n                z.remove();\n                aa.unsubscribe();\n                (this._explicitHover && this._explicitHover.uninstall());\n            }.bind(this));\n        },\n        _handleDecline: function(u) {\n            var v = o.byTag(u, \"li\");\n            this._swap(v);\n        },\n        _handleAdd: function(u) {\n            var v = o.byTag(u, \"li\"), w = this._getUIDFromItem(v), x = function(y) {\n                if ((y && y.nux_cancel)) {\n                    return\n                };\n                this._swap(v);\n                if (this._shouldSave) {\n                    this._save(w, y);\n                };\n                var z = l.scry(v, \"img.-cx-PRIVATE-uiSquareImage__root\")[0], aa = l.find(v, \"td.userSuggestionName\");\n                g.inform(\"FriendListSuggestions/add\", {\n                    flid: this._flid,\n                    uid: w,\n                    name: l.getText(aa),\n                    photo: z.src\n                });\n            }.bind(this);\n            m.showContextualDialog(this._flid, w, u, x);\n        },\n        _getUIDFromItem: function(u) {\n            return (\"\" + u.id.split(\"_\")[1]);\n        },\n        _swap: function(u) {\n            l.remove(u);\n            var v = l.scry(this._container, \"li.hidden_elem\")[0];\n            if (!v) {\n                return\n            };\n            k.show(v);\n            var w = this._getUIDFromItem(v), x = (\"\" + v.getAttribute(\"data-coeff-key\")), y = {\n                tids: [w,],\n                key: x\n            };\n            new i(\"/friends/ajax/log_data.php\", y).send();\n        },\n        _save: function(u, v) {\n            var w = {\n                flid: this._flid,\n                id: u,\n                add: 1,\n                source: this._source\n            };\n            w[this.context] = 1;\n            if (v) {\n                q(w, v);\n            };\n            new h().setURI(\"/friends/ajax/lists.php\").setData(w).send();\n        }\n    });\n    e.exports = t;\n});\n__d(\"legacy:FriendListSuggestions\", [\"FriendListSuggestions\",], function(a, b, c, d) {\n    a.FriendListSuggestions = b(\"FriendListSuggestions\");\n}, 3);\n__d(\"UnicodeByteMaxLength\", [\"event-extensions\",\"DataStore\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"DataStore\");\n    function h(i) {\n        var j = 0;\n        for (var k = 0; (k < i.length); k++) {\n            var l = i.charCodeAt(k);\n            if ((l <= 127)) {\n                j += 1;\n            }\n             else if ((l <= 2047)) {\n                j += 2;\n            }\n             else if ((l <= 55193)) {\n                j += 3;\n            }\n             else if (((l >= 55296) && (l < 57344))) {\n                j += 4;\n                k++;\n            }\n             else if ((l < 65535)) {\n                j += 3;\n            }\n            \n            \n            \n        ;\n        };\n        return j;\n    };\n    Event.listen(document, \"keypress\", function(i) {\n        var j = i.getTarget(), k = g.get(j, \"maxlen\");\n        if (k) {\n            return (h(j.value) < k)\n        };\n    });\n});\n__d(\"legacy:UIIntentionalStreamRefresh\", [\"UIIntentionalStreamRefresh\",], function(a, b, c, d) {\n    a.UIIntentionalStreamRefresh = b(\"UIIntentionalStreamRefresh\");\n}, 3);");
// 4349
fpc.call(JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_1[0], o2,"sa457fded3147c97efe50a521aef6f7f48d3eb84c");
// undefined
o2 = null;
// 4350
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"1vNpf\",]);\n}\n;\n;\n__d(\"legacy:XHPTemplate\", [\"XHPTemplate\",], function(a, b, c, d) {\n    a.XHPTemplate = b(\"XHPTemplate\");\n}, 3);\nfunction DynamicFacepile() {\n\n};\n;\ncopyProperties(DynamicFacepile.prototype, {\n    init: function(a, b, c, d) {\n        this._facepile = c;\n        this._maxFacepileSize = b;\n        this._memberIDs = a;\n        this._facepileItemMap = {\n        };\n        var e = DOM.scry(this._facepile, \"li\");\n        for (var f = 0, g = a.length; ((f < g)); ++f) {\n            this._facepileItemMap[a[f]] = e[f];\n        ;\n        };\n    ;\n        this._template = d;\n    },\n    containsID: function(a) {\n        return this._facepileItemMap[a];\n    },\n    removeFacepileItem: function(a) {\n        var b = this._facepileItemMap[a.uid];\n        if (!b) {\n            return;\n        }\n    ;\n    ;\n        delete this._facepileItemMap[a.uid];\n        this._memberIDs.splice(this._memberIDs.indexOf(a.uid), 1);\n        DOM.remove(b);\n    },\n    addFacepileItem: function(a) {\n        var b = this._template.render(), c = XHPTemplate.getNode(b, \"img\");\n        c.src = a.photo;\n        var d = XHPTemplate.getNode(b, \"anchor\");\n        d.href = URI(\"/profile.php\").addQueryData({\n            id: a.uid\n        });\n        TooltipLink.setTooltipText(d, a.JSBNG__name);\n        DOM.prependContent(this._facepile, b);\n        this._facepileItemMap[a.uid] = b;\n        this._memberIDs.unshift(a.uid);\n        if (((this._memberIDs.length > this._maxFacepileSize))) {\n            var e = this._memberIDs.pop(), f = this._facepileItemMap[e];\n            DOM.remove(f);\n            delete this._facepileItemMap[e];\n        }\n    ;\n    ;\n    }\n});\nvar FriendsDashSideCol = {\n    init: function(a) {\n        this._flid = a;\n        var b = \"listeditor/friend_lists_changed\", c = Arbiter.subscribe(b, function(d, e) {\n            if (((((d == b)) && ((e.list_info.list_id == this._flid))))) {\n                if (e.refresh_member_box) {\n                    new AsyncRequest(\"/ajax/friends/lists/list_modified.php\").setMethod(\"GET\").setReadOnly(true).setData({\n                        list_id: this._flid\n                    }).send();\n                }\n            ;\n            ;\n                if (e.removed_uid) {\n                    DOM.scry($(\"home_stream\"), ((\".aid_\" + e.removed_uid))).forEach(CSS.hide);\n                }\n                 else if (((e.undo_remove && e.added_uid))) {\n                    DOM.scry($(\"home_stream\"), ((\".aid_\" + e.added_uid))).forEach(CSS.show);\n                }\n                 else Arbiter.inform(UIIntentionalStreamMessage.REFRESH_STREAM, {\n                    filter: ((\"fl_\" + this._flid)),\n                    noScroll: 1\n                });\n                \n            ;\n            ;\n            }\n        ;\n        ;\n        }.bind(this), Arbiter.SUBSCRIBE_NEW);\n        PageTransitions.registerHandler(Arbiter.unsubscribe.curry(c));\n    }\n};\n__d(\"FriendListHeader\", [\"event-extensions\",\"AsyncRequest\",\"CSS\",\"DOM\",\"Input\",\"Menu\",\"PageTransitions\",\"Parent\",\"Selector\",\"copyProperties\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"AsyncRequest\"), h = b(\"CSS\"), i = b(\"DOM\"), j = b(\"Input\"), k = b(\"Menu\"), l = b(\"PageTransitions\"), m = b(\"Parent\"), n = b(\"Selector\"), o = b(\"copyProperties\");\n    function p() {\n    \n    };\n;\n    o(p.prototype, {\n        init: function(q, r) {\n            var s = i.JSBNG__find(q, \".nameInput\"), t = i.JSBNG__find(q, \".staticName .JSBNG__name\"), u = k.subscribe(\"select\", function(w, x) {\n                if (!m.byClass(x.menu, \"friendListManage\")) {\n                    return;\n                }\n            ;\n            ;\n                var y = x.item;\n                if (h.hasClass(y, \"editName\")) {\n                    h.addClass(q, \"friendListHeaderEditMode\");\n                    j.setValue(s, \"\");\n                    j.JSBNG__focus(s);\n                }\n                 else if (h.hasClass(y, \"chooseUpdateTypes\")) {\n                    h.addClass(x.menu, \"updateTypesExpanded\");\n                    return false;\n                }\n                \n            ;\n            ;\n            }), v = n.subscribe(\"select\", function(w, x) {\n                if (!h.hasClass(x.selector, \"friendListManage\")) {\n                    return;\n                }\n            ;\n            ;\n                if (h.hasClass(x.option, \"updateType\")) {\n                    k.toggleItem(x.option);\n                    var y = [];\n                    n.getSelectedOptions(x.selector).forEach(function(z) {\n                        y.push(n.getOptionValue(z));\n                    });\n                    new g().setURI(\"/ajax/friends/lists/subscriptions.php\").setData({\n                        subs: y,\n                        flid: r\n                    }).send();\n                    return false;\n                }\n            ;\n            ;\n            });\n            JSBNG__Event.listen(q, \"click\", function(w) {\n                if (m.byClass(w.getTarget(), \"cancel\")) {\n                    h.removeClass(q, \"friendListHeaderEditMode\");\n                    return;\n                }\n            ;\n            ;\n                if (((m.byClass(w.getTarget(), \"saveButton\") && j.isEmpty(s)))) {\n                    j.JSBNG__focus(s);\n                    w.preventDefault();\n                }\n            ;\n            ;\n            });\n            l.registerHandler(function() {\n                k.unsubscribe(u);\n                n.unsubscribe(v);\n            });\n        }\n    });\n    e.exports = p;\n});\n__d(\"legacy:FriendListHeader\", [\"FriendListHeader\",], function(a, b, c, d) {\n    a.FriendListHeader = b(\"FriendListHeader\");\n}, 3);\nfunction FriendListMembersBox() {\n\n};\n;\ncopyProperties(FriendListMembersBox.prototype, {\n    init: function(a, b, c, d, e, f, g) {\n        this._root = a;\n        this._flid = b;\n        this._listSize = d;\n        this._headerTitle = DOM.JSBNG__find(this._root, \".uiHeaderTitle\");\n        this._headerActions = DOM.JSBNG__find(this._root, \".uiHeaderActions a\");\n        this._facepile = new DynamicFacepile();\n        this._facepile.init(c, e, f.firstChild, g);\n        var h = [Arbiter.subscribe([\"FriendListSuggestions/add\",\"FriendListMemberTypeahead/add\",\"FriendListHovercard/add\",], this.handleAddEvent.bind(this)),Arbiter.subscribe(\"FriendListHovercard/remove\", this.handleRemoveEvent.bind(this)),];\n        PageTransitions.registerHandler(function() {\n            h.forEach(Arbiter.unsubscribe);\n        });\n    },\n    handleAddEvent: function(a, b) {\n        if (((((b.flid !== this._flid)) || !b.uid))) {\n            return;\n        }\n    ;\n    ;\n        if (this._facepile.containsID(b.uid)) {\n            return;\n        }\n    ;\n    ;\n        if (((!b.photo || !b.JSBNG__name))) {\n            requireLazy([\"ShortProfiles\",], function(c) {\n                c.get(b.uid, function(d, e) {\n                    if (e.exist) {\n                        d.flid = this._flid;\n                        d.photo = e.thumbSrc;\n                        d.JSBNG__name = e.firstName;\n                        this._facepile.addFacepileItem(d);\n                    }\n                ;\n                ;\n                }.bind(this, b));\n            }.bind(this));\n        }\n         else this._facepile.addFacepileItem(b);\n    ;\n    ;\n        CSS.removeClass(this._root, \"empty\");\n        CSS.show(this._headerActions);\n        this._listSize++;\n        this.updateListSize();\n    },\n    handleRemoveEvent: function(a, b) {\n        if (((((b.flid !== this._flid)) || !b.uid))) {\n            return;\n        }\n    ;\n    ;\n        this._listSize--;\n        this.updateListSize();\n        this._facepile.removeFacepileItem(b);\n    },\n    updateListSize: function() {\n        DOM.setContent(this._headerTitle, tx._(\"On This List ({num_members})\", {\n            num_members: this._listSize\n        }));\n    }\n});\n__d(\"FriendListSuggestions\", [\"event-extensions\",\"Arbiter\",\"AsyncRequest\",\"AsyncSignal\",\"Bootloader\",\"CSS\",\"DOM\",\"DynamicFriendListEducation\",\"PageTransitions\",\"Parent\",\"UserAgent\",\"copyProperties\",\"csx\",\"ge\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"Arbiter\"), h = b(\"AsyncRequest\"), i = b(\"AsyncSignal\"), j = b(\"Bootloader\"), k = b(\"CSS\"), l = b(\"DOM\"), m = b(\"DynamicFriendListEducation\"), n = b(\"PageTransitions\"), o = b(\"Parent\"), p = b(\"UserAgent\"), q = b(\"copyProperties\"), r = b(\"csx\"), s = b(\"ge\");\n    function t() {\n    \n    };\n;\n    q(t.prototype, {\n        init: function(u, v, w, x, y) {\n            this._container = u;\n            this._flid = v;\n            this._shouldSave = w;\n            this._context = x;\n            this._source = y;\n            var z = JSBNG__Event.listen(u, \"click\", function(ba) {\n                var ca = ba.getTarget();\n                ((o.byClass(ca, \"addLink\") && this._handleAdd(ca)));\n                ((o.byClass(ca, \"declineButton\") && this._handleDecline(ca)));\n            }.bind(this));\n            if (((p.ie() < 7))) {\n                j.loadModules([\"ExplicitHover\",], function(ba) {\n                    this._explicitHover = new ba(this._container, \"friendListSuggestion\");\n                }.bind(this));\n            }\n        ;\n        ;\n            var aa = g.subscribe(\"FriendListMemberTypeahead/add\", function(ba, ca) {\n                var da = s(((\"suggestion_\" + ca.uid)));\n                ((da && this._swap(da)));\n            }.bind(this));\n            n.registerHandler(function() {\n                z.remove();\n                aa.unsubscribe();\n                ((this._explicitHover && this._explicitHover.uninstall()));\n            }.bind(this));\n        },\n        _handleDecline: function(u) {\n            var v = o.byTag(u, \"li\");\n            this._swap(v);\n        },\n        _handleAdd: function(u) {\n            var v = o.byTag(u, \"li\"), w = this._getUIDFromItem(v), x = function(y) {\n                if (((y && y.nux_cancel))) {\n                    return;\n                }\n            ;\n            ;\n                this._swap(v);\n                if (this._shouldSave) {\n                    this._save(w, y);\n                }\n            ;\n            ;\n                var z = l.scry(v, \"img.-cx-PRIVATE-uiSquareImage__root\")[0], aa = l.JSBNG__find(v, \"td.userSuggestionName\");\n                g.inform(\"FriendListSuggestions/add\", {\n                    flid: this._flid,\n                    uid: w,\n                    JSBNG__name: l.getText(aa),\n                    photo: z.src\n                });\n            }.bind(this);\n            m.showContextualDialog(this._flid, w, u, x);\n        },\n        _getUIDFromItem: function(u) {\n            return ((\"\" + u.id.split(\"_\")[1]));\n        },\n        _swap: function(u) {\n            l.remove(u);\n            var v = l.scry(this._container, \"li.hidden_elem\")[0];\n            if (!v) {\n                return;\n            }\n        ;\n        ;\n            k.show(v);\n            var w = this._getUIDFromItem(v), x = ((\"\" + v.getAttribute(\"data-coeff-key\"))), y = {\n                tids: [w,],\n                key: x\n            };\n            new i(\"/friends/ajax/log_data.php\", y).send();\n        },\n        _save: function(u, v) {\n            var w = {\n                flid: this._flid,\n                id: u,\n                add: 1,\n                source: this._source\n            };\n            w[this.context] = 1;\n            if (v) {\n                q(w, v);\n            }\n        ;\n        ;\n            new h().setURI(\"/friends/ajax/lists.php\").setData(w).send();\n        }\n    });\n    e.exports = t;\n});\n__d(\"legacy:FriendListSuggestions\", [\"FriendListSuggestions\",], function(a, b, c, d) {\n    a.FriendListSuggestions = b(\"FriendListSuggestions\");\n}, 3);\n__d(\"UnicodeByteMaxLength\", [\"event-extensions\",\"DataStore\",], function(a, b, c, d, e, f) {\n    b(\"event-extensions\");\n    var g = b(\"DataStore\");\n    function h(i) {\n        var j = 0;\n        for (var k = 0; ((k < i.length)); k++) {\n            var l = i.charCodeAt(k);\n            if (((l <= 127))) {\n                j += 1;\n            }\n             else if (((l <= 2047))) {\n                j += 2;\n            }\n             else if (((l <= 55193))) {\n                j += 3;\n            }\n             else if (((((l >= 55296)) && ((l < 57344))))) {\n                j += 4;\n                k++;\n            }\n             else if (((l < 65535))) {\n                j += 3;\n            }\n            \n            \n            \n            \n        ;\n        ;\n        };\n    ;\n        return j;\n    };\n;\n    JSBNG__Event.listen(JSBNG__document, \"keypress\", function(i) {\n        var j = i.getTarget(), k = g.get(j, \"maxlen\");\n        if (k) {\n            return ((h(j.value) < k));\n        }\n    ;\n    ;\n    });\n});\n__d(\"legacy:UIIntentionalStreamRefresh\", [\"UIIntentionalStreamRefresh\",], function(a, b, c, d) {\n    a.UIIntentionalStreamRefresh = b(\"UIIntentionalStreamRefresh\");\n}, 3);");
// 4353
JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_84[0](o6,false,o9);
// undefined
o6 = null;
// undefined
o9 = null;
// 4371
JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_14[0]();
// 4378
JSBNG_Replay.sec3f7c0a188503295a66a797eaa3892a5e54bc0e_273[0]();
// 5681
JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_28[0]("Uncaught TypeError: Cannot read property 'length' of null","http://www.facebook.com/JSBENCH_NG_RECORD.js",737);
// 6945
JSBNG_Replay.seb9c4ec101e2122bc8027bac073064b6a755179c_140[0](o1);
// undefined
o1 = null;
// 6948
cb(); return null; }
finalize(); })();
