/*
 * In a generated replay, this file is partially common, boilerplate code
 * included in every replay, and partially generated replay code. The following
 * header applies to the boilerplate code. A comment indicating "Auto-generated
 * below this comment" marks the separation between these two parts.
 *
 * Copyright (C) 2011, 2012 Purdue University
 * Written by Gregor Richards
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

(function() {
    // global eval alias
    var geval = eval;

    // detect if we're in a browser or not
    var inbrowser = false;
    var inharness = false;
    if (typeof window !== "undefined" && "document" in window) {
        inbrowser = true;
        if (window.parent && "JSBNG_handleResult" in window.parent) {
            inharness = true;
        }
    } else if (typeof global !== "undefined") {
        window = global;
        window.top = window;
    } else {
        window = (function() { return this; })();
        window.top = window;
    }

    if ("console" in window) {
        window.JSBNG_Console = window.console;
    }

    var callpath = [];

    // global state
    var JSBNG_Replay = window.top.JSBNG_Replay = {
        push: function(arr, fun) {
            arr.push(fun);
            return fun;
        },

        path: function(str) {
            verifyPath(str);
        }
    };

    // the actual replay runner
    function onload() {
        try {
            delete window.onload;
        } catch (ex) {}

        var jr = JSBNG_Replay$;
        var cb = function() {
            var end = new Date().getTime();

            var msg = "Time: " + (end - st) + "ms";
    
            if (inharness) {
                window.parent.JSBNG_handleResult({error:false, time:(end - st)});
            } else if (inbrowser) {
                var res = document.createElement("div");
    
                res.style.position = "fixed";
                res.style.left = "1em";
                res.style.top = "1em";
                res.style.width = "35em";
                res.style.height = "5em";
                res.style.padding = "1em";
                res.style.backgroundColor = "white";
                res.style.color = "black";
                res.appendChild(document.createTextNode(msg));
    
                document.body.appendChild(res);
            } else if (typeof console !== "undefined") {
                console.log(msg);
            } else if (typeof print !== "undefined") {
                // hopefully not the browser print() function :)
                print(msg);
            }
        };

        // force it to JIT
        jr(false);

        // then time it
        var st = new Date().getTime();
        while (jr !== null) {
            jr = jr(true, cb);
        }
    }

    // add a frame at replay time
    function iframe(pageid) {
        var iw;
        if (inbrowser) {
            // represent the iframe as an iframe (of course)
            var iframe = document.createElement("iframe");
            iframe.style.display = "none";
            document.body.appendChild(iframe);
            iw = iframe.contentWindow;
            iw.document.write("<script type=\"text/javascript\">Function.prototype.bind = null; var JSBNG_Replay_geval = eval;</script>");
            iw.document.close();
        } else {
            // no general way, just lie and do horrible things
            var topwin = window;
            (function() {
                var window = {};
                window.window = window;
                window.top = topwin;
                window.JSBNG_Replay_geval = function(str) {
                    eval(str);
                }
                iw = window;
            })();
        }
        return iw;
    }

    // called at the end of the replay stuff
    function finalize() {
        if (inbrowser) {
            setTimeout(onload, 0);
        } else {
            onload();
        }
    }

    // verify this recorded value and this replayed value are close enough
    function verify(rep, rec) {
        if (rec !== rep &&
            (rep === rep || rec === rec) /* NaN test */) {
            if (typeof rec !== "object" || rec === null ||
                !(("__JSBNG_unknown_" + typeof(rep)) in rec)) {
                return false;
            }
        }
        return true;
    }

    // general message
    var firstMessage = true;
    function replayMessage(msg) {
        if (inbrowser) {
            if (firstMessage)
                document.open();
            firstMessage = false;
            document.write(msg);
        } else {
            console.log(msg);
        }
    }

    // complain when there's an error
    function verificationError(msg) {
        if (inharness) {
            window.parent.JSBNG_handleResult({error:true, msg: msg});
        } else replayMessage(msg);
        throw new Error();
    }

    // to verify a set
    function verifySet(objstr, obj, prop, gvalstr, gval) {
        if (/^on/.test(prop)) {
            // these aren't instrumented compatibly
            return;
        }

        if (!verify(obj[prop], gval)) {
            var bval = obj[prop];
            var msg = "Verification failure! " + objstr + "." + prop + " is not " + gvalstr + ", it's " + bval + "!";
            verificationError(msg);
        }
    }

    // to verify a call or new
    function verifyCall(iscall, func, cthis, cargs) {
        var ok = true;
        var callArgs = func.callArgs[func.inst];
        iscall = iscall ? 1 : 0;
        if (cargs.length !== callArgs.length - 1) {
            ok = false;
        } else {
            if (iscall && !verify(cthis, callArgs[0])) ok = false;
            for (var i = 0; i < cargs.length; i++) {
                if (!verify(cargs[i], callArgs[i+1])) ok = false;
            }
        }
        if (!ok) {
            var msg = "Call verification failure!";
            verificationError(msg);
        }

        return func.returns[func.inst++];
    }

    // to verify the callpath
    function verifyPath(func) {
        var real = callpath.shift();
        if (real !== func) {
            var msg = "Call path verification failure! Expected " + real + ", found " + func;
            verificationError(msg);
        }
    }

    // figure out how to define getters
    var defineGetter;
    if (Object.defineProperty) {
        var odp = Object.defineProperty;
        defineGetter = function(obj, prop, getter) {
            odp(obj, prop, {"enumerable": true, "get": getter, "set": function(){}});
        };
    } else if (Object.prototype.__defineGetter__) {
        var opdg = Object.prototype.__defineGetter__;
        var opds = Object.prototype.__defineSetter__;
        defineGetter = function(obj, prop, getter) {
            opdg.call(obj, prop, getter);
            opds.call(obj, prop, function(){});
        };
    } else {
        defineGetter = function() {
            verificationError("This replay requires getters for correct behavior, and your JS engine appears to be incapable of defining getters. Sorry!");
        };
    }

    // for calling events
    var fpc = Function.prototype.call;

// resist the urge, don't put a })(); here!
/******************************************************************************
 * Auto-generated below this comment
 *****************************************************************************/
var ow885589709 = window;
var ow283489458 = iframe("283489458");
var f283489458_0;
var o0;
var f283489458_17;
var o1;
var o2;
var f283489458_64;
var f283489458_368;
var o3;
var f283489458_370;
var f283489458_371;
var o4;
var fo283489458_373_className;
var f283489458_375;
var o5;
var o6;
var o7;
var f283489458_388;
var f283489458_390;
var o8;
var o9;
var o10;
var o11;
var o12;
var o13;
var o14;
var o15;
var o16;
var o17;
var o18;
var f283489458_445;
var f283489458_450;
var f283489458_451;
var f283489458_454;
var f283489458_457;
var f283489458_459;
var f283489458_460;
var f283489458_463;
var f283489458_464;
var f283489458_482;
var f283489458_484;
JSBNG_Replay.sb5d8a5a82713b77123eb5ce3609b274e45633210_74 = [];
// 1
// record generated by JSBench c8b048872b28 at 2012-08-21T15:32:20.527Z
// 2
// 19
ow885589709.JSBNG__top = ow885589709;
// 28
ow885589709.JSBNG__scrollX = 0;
// 29
ow885589709.JSBNG__scrollY = 0;
// 60
ow885589709.JSBNG__frames = ow885589709;
// 63
ow885589709.JSBNG__self = ow885589709;
// 70
ow885589709.JSBNG__content = ow885589709;
// 81
ow885589709.JSBNG__closed = false;
// 84
ow885589709.JSBNG__pkcs11 = null;
// 87
ow885589709.JSBNG__opener = null;
// 88
ow885589709.JSBNG__defaultStatus = "";
// 91
ow885589709.JSBNG__innerWidth = 1280;
// 92
ow885589709.JSBNG__innerHeight = 666;
// 93
ow885589709.JSBNG__outerWidth = 1280;
// 94
ow885589709.JSBNG__outerHeight = 749;
// 95
ow885589709.JSBNG__screenX = 0;
// 96
ow885589709.JSBNG__screenY = 0;
// 97
ow885589709.JSBNG__mozInnerScreenX = 0;
// 98
ow885589709.JSBNG__mozInnerScreenY = 0;
// 99
ow885589709.JSBNG__pageXOffset = 0;
// 100
ow885589709.JSBNG__pageYOffset = 0;
// 101
ow885589709.JSBNG__scrollMaxX = 0;
// 102
ow885589709.JSBNG__scrollMaxY = 0;
// 103
ow885589709.JSBNG__fullScreen = false;
// 136
ow885589709.JSBNG__frameElement = null;
// 141
ow885589709.JSBNG__mozPaintCount = 0;
// 144
ow885589709.JSBNG__mozAnimationStartTime = 1345563151650;
// 165
ow885589709.JSBNG__name = "";
// 172
ow885589709.JSBNG__status = "";
// 769
// 770
// 771
// 772
f283489458_0 = function() { return f283489458_0.returns[f283489458_0.inst++]; };
f283489458_0.returns = [];
f283489458_0.inst = 0;
// 773
ow283489458.JSBNG__Date = f283489458_0;
// 774
o0 = {};
// 775
ow283489458.JSBNG__document = o0;
// 788
ow283489458.JSBNG__top = ow283489458;
// 797
ow283489458.JSBNG__scrollX = 0;
// 798
ow283489458.JSBNG__scrollY = 0;
// 809
f283489458_17 = function() { return f283489458_17.returns[f283489458_17.inst++]; };
f283489458_17.returns = [];
f283489458_17.inst = 0;
// 810
ow283489458.JSBNG__setInterval = f283489458_17;
// 829
ow283489458.JSBNG__frames = ow283489458;
// 832
ow283489458.JSBNG__self = ow283489458;
// 833
o1 = {};
// 834
ow283489458.JSBNG__navigator = o1;
// 839
ow283489458.JSBNG__content = ow283489458;
// 850
ow283489458.JSBNG__closed = false;
// 853
ow283489458.JSBNG__pkcs11 = null;
// 856
ow283489458.JSBNG__opener = null;
// 857
ow283489458.JSBNG__defaultStatus = "";
// 858
o2 = {};
// 859
ow283489458.JSBNG__location = o2;
// 860
ow283489458.JSBNG__innerWidth = 1280;
// 861
ow283489458.JSBNG__innerHeight = 666;
// 862
ow283489458.JSBNG__outerWidth = 1280;
// 863
ow283489458.JSBNG__outerHeight = 749;
// 864
ow283489458.JSBNG__screenX = 0;
// 865
ow283489458.JSBNG__screenY = 0;
// 866
ow283489458.JSBNG__mozInnerScreenX = 0;
// 867
ow283489458.JSBNG__mozInnerScreenY = 0;
// 868
ow283489458.JSBNG__pageXOffset = 0;
// 869
ow283489458.JSBNG__pageYOffset = 0;
// 870
ow283489458.JSBNG__scrollMaxX = 0;
// 871
ow283489458.JSBNG__scrollMaxY = 0;
// 872
ow283489458.JSBNG__fullScreen = false;
// 905
ow283489458.JSBNG__frameElement = null;
// 910
ow283489458.JSBNG__mozPaintCount = 0;
// 913
ow283489458.JSBNG__mozAnimationStartTime = 1345563151928;
// 926
f283489458_64 = function() { return f283489458_64.returns[f283489458_64.inst++]; };
f283489458_64.returns = [];
f283489458_64.inst = 0;
// 927
ow283489458.JSBNG__XMLHttpRequest = f283489458_64;
// 934
ow283489458.JSBNG__name = "";
// 941
ow283489458.JSBNG__status = "";
// 1536
f283489458_368 = function() { return f283489458_368.returns[f283489458_368.inst++]; };
f283489458_368.returns = [];
f283489458_368.inst = 0;
// 1537
ow283489458.Math.JSBNG__random = f283489458_368;
// 1538
// 1540
// 1541
o3 = {};
// 1542
f283489458_0.returns.push(o3);
// 1543
f283489458_370 = function() { return f283489458_370.returns[f283489458_370.inst++]; };
f283489458_370.returns = [];
f283489458_370.inst = 0;
// 1544
o3.getTime = f283489458_370;
// undefined
o3 = null;
// 1545
f283489458_370.returns.push(1345563151985);
// 1546
// 1547
o2.pathname = "/";
// 1548
o2.hash = "#!/search/javascript?q=javascript";
// 1554
f283489458_371 = function() { return f283489458_371.returns[f283489458_371.inst++]; };
f283489458_371.returns = [];
f283489458_371.inst = 0;
// 1555
o0.getElementsByTagName = f283489458_371;
// 1556
o3 = {};
// 1557
f283489458_371.returns.push(o3);
// 1558
o4 = {};
// 1559
o3["0"] = o4;
// undefined
o3 = null;
// undefined
fo283489458_373_className = function() { return fo283489458_373_className.returns[fo283489458_373_className.inst++]; };
fo283489458_373_className.returns = [];
fo283489458_373_className.inst = 0;
defineGetter(o4, "className", fo283489458_373_className);
// undefined
fo283489458_373_className.returns.push("");
// 1565
ow283489458.JSBNG__attachEvent = undefined;
// 1567
o3 = {};
// 1568
f283489458_371.returns.push(o3);
// 1569
f283489458_375 = function() { return f283489458_375.returns[f283489458_375.inst++]; };
f283489458_375.returns = [];
f283489458_375.inst = 0;
// 1570
o0.createElement = f283489458_375;
// 1571
o5 = {};
// 1572
f283489458_375.returns.push(o5);
// 1573
o6 = {};
// 1574
o3["0"] = o6;
// 1575
o6.src = "http://twitter.com/JSBENCH_NG_RECORD_OBJECTS.js";
// 1576
o7 = {};
// 1577
o3["1"] = o7;
// 1578
o7.src = "http://twitter.com/JSBENCH_NG_RECORD.js";
// undefined
o7 = null;
// 1579
o7 = {};
// 1580
o3["2"] = o7;
// 1581
o7.src = "";
// undefined
o7 = null;
// 1582
o7 = {};
// 1583
o3["3"] = o7;
// 1584
o7.src = "";
// undefined
o7 = null;
// 1585
o7 = {};
// 1586
o3["4"] = o7;
// 1587
o7.src = "";
// undefined
o7 = null;
// 1588
o7 = {};
// 1589
o3["5"] = o7;
// 1590
o7.src = "";
// undefined
o7 = null;
// 1591
o7 = {};
// 1592
o3["6"] = o7;
// 1593
o7.src = "";
// undefined
o7 = null;
// 1594
o7 = {};
// 1595
o3["7"] = o7;
// 1596
o7.src = "";
// undefined
o7 = null;
// 1597
o7 = {};
// 1598
o3["8"] = o7;
// 1599
o7.src = "";
// undefined
o7 = null;
// 1600
o7 = {};
// 1601
o3["9"] = o7;
// 1602
o7.src = "";
// undefined
o7 = null;
// 1603
o3["10"] = void 0;
// undefined
o3 = null;
// 1606
o3 = {};
// 1607
o0.body = o3;
// 1608
f283489458_388 = function() { return f283489458_388.returns[f283489458_388.inst++]; };
f283489458_388.returns = [];
f283489458_388.inst = 0;
// 1609
o0.getElementById = f283489458_388;
// 1610
o7 = {};
// 1611
f283489458_388.returns.push(o7);
// 1612
o2.href = "http://twitter.com/#!/search/javascript?q=javascript";
// 1614
o7.tagName = "DIV";
// 1615
f283489458_390 = function() { return f283489458_390.returns[f283489458_390.inst++]; };
f283489458_390.returns = [];
f283489458_390.inst = 0;
// 1616
o7.getElementsByTagName = f283489458_390;
// undefined
o7 = null;
// 1617
o7 = {};
// 1618
f283489458_390.returns.push(o7);
// 1619
o7.length = 27;
// 1620
o8 = {};
// 1621
o7["26"] = o8;
// 1622
o8.className = "new-js-banners";
// undefined
o8 = null;
// 1623
o8 = {};
// 1624
o7["25"] = o8;
// 1625
o8.className = "wrapper";
// 1626
o9 = {};
// 1627
o7["24"] = o9;
// 1628
o9.className = "footer inline-list";
// undefined
o9 = null;
// 1629
o9 = {};
// 1630
o7["23"] = o9;
// 1631
o9.className = "placeholding-input";
// 1633
o9.tagName = "DIV";
// 1634
o9.getElementsByTagName = f283489458_390;
// undefined
o9 = null;
// 1635
o9 = {};
// 1636
f283489458_390.returns.push(o9);
// 1637
o10 = {};
// 1638
o9["0"] = o10;
// undefined
o9 = null;
// 1641
o9 = {};
// 1642
f283489458_390.returns.push(o9);
// 1643
o11 = {};
// 1644
o9["0"] = o11;
// undefined
o9 = null;
// 1645
// undefined
o11 = null;
// 1646
// 1647
// 1648
o9 = {};
// 1649
o7["22"] = o9;
// 1650
o9.className = "placeholding-input";
// 1652
o9.tagName = "DIV";
// 1653
o9.getElementsByTagName = f283489458_390;
// undefined
o9 = null;
// 1654
o9 = {};
// 1655
f283489458_390.returns.push(o9);
// 1656
o11 = {};
// 1657
o9["0"] = o11;
// undefined
o9 = null;
// 1660
o9 = {};
// 1661
f283489458_390.returns.push(o9);
// 1662
o12 = {};
// 1663
o9["0"] = o12;
// undefined
o9 = null;
// 1664
// undefined
o12 = null;
// 1665
// 1666
// 1667
o9 = {};
// 1668
o7["21"] = o9;
// 1669
o9.className = "placeholding-input";
// 1671
o9.tagName = "DIV";
// 1672
o9.getElementsByTagName = f283489458_390;
// undefined
o9 = null;
// 1673
o9 = {};
// 1674
f283489458_390.returns.push(o9);
// 1675
o12 = {};
// 1676
o9["0"] = o12;
// undefined
o9 = null;
// 1679
o9 = {};
// 1680
f283489458_390.returns.push(o9);
// 1681
o13 = {};
// 1682
o9["0"] = o13;
// undefined
o9 = null;
// 1683
// undefined
o13 = null;
// 1684
// 1685
// 1686
o9 = {};
// 1687
o7["20"] = o9;
// 1688
o9.className = "front-signup js-front-signup";
// 1689
o13 = {};
// 1690
o7["19"] = o13;
// 1691
o13.className = "remember-forgot";
// undefined
o13 = null;
// 1692
o13 = {};
// 1693
o7["18"] = o13;
// 1694
o13.className = "placeholding-input password flex-table-form";
// 1696
o13.tagName = "DIV";
// 1697
o13.getElementsByTagName = f283489458_390;
// undefined
o13 = null;
// 1698
o13 = {};
// 1699
f283489458_390.returns.push(o13);
// 1700
o14 = {};
// 1701
o13["0"] = o14;
// undefined
o13 = null;
// 1704
o13 = {};
// 1705
f283489458_390.returns.push(o13);
// 1706
o15 = {};
// 1707
o13["0"] = o15;
// undefined
o13 = null;
// 1708
// undefined
o15 = null;
// 1709
// 1710
// 1711
o13 = {};
// 1712
o7["17"] = o13;
// 1713
o13.className = "placeholding-input username";
// 1715
o13.tagName = "DIV";
// 1716
o13.getElementsByTagName = f283489458_390;
// undefined
o13 = null;
// 1717
o13 = {};
// 1718
f283489458_390.returns.push(o13);
// 1719
o15 = {};
// 1720
o13["0"] = o15;
// undefined
o13 = null;
// 1723
o13 = {};
// 1724
f283489458_390.returns.push(o13);
// 1725
o16 = {};
// 1726
o13["0"] = o16;
// undefined
o13 = null;
// 1727
// undefined
o16 = null;
// 1728
// 1729
// 1730
o13 = {};
// 1731
o7["16"] = o13;
// 1732
o13.className = "front-signin js-front-signin";
// 1733
o16 = {};
// 1734
o7["15"] = o16;
// 1735
o16.className = "front-welcome-text";
// undefined
o16 = null;
// 1736
o16 = {};
// 1737
o7["14"] = o16;
// 1738
o16.className = "front-welcome";
// undefined
o16 = null;
// 1739
o16 = {};
// 1740
o7["13"] = o16;
// 1741
o16.className = "front-card";
// undefined
o16 = null;
// 1742
o16 = {};
// 1743
o7["12"] = o16;
// 1744
o16.className = "front-warning";
// undefined
o16 = null;
// 1745
o16 = {};
// 1746
o7["11"] = o16;
// 1747
o16.className = "front-container   ";
// undefined
o16 = null;
// 1748
o16 = {};
// 1749
o7["10"] = o16;
// 1750
o16.className = "";
// 1751
o17 = {};
// 1752
o7["9"] = o17;
// 1753
o17.className = "alert-messages ";
// undefined
o17 = null;
// 1754
o17 = {};
// 1755
o7["8"] = o17;
// 1756
o17.className = "pull-right";
// undefined
o17 = null;
// 1757
o17 = {};
// 1758
o7["7"] = o17;
// 1759
o17.className = "js-front-language";
// 1760
o18 = {};
// 1761
o7["6"] = o18;
// 1762
o18.className = "divider";
// undefined
o18 = null;
// 1763
o18 = {};
// 1764
o7["5"] = o18;
// 1765
o18.className = "container";
// undefined
o18 = null;
// 1766
o18 = {};
// 1767
o7["4"] = o18;
// 1768
o18.className = "global-nav-inner";
// undefined
o18 = null;
// 1769
o18 = {};
// 1770
o7["3"] = o18;
// 1771
o18.className = "global-nav";
// undefined
o18 = null;
// 1772
o18 = {};
// 1773
o7["2"] = o18;
// 1774
o18.className = "js-banners";
// undefined
o18 = null;
// 1775
o18 = {};
// 1776
o7["1"] = o18;
// 1777
o18.className = "topbar js-topbar";
// undefined
o18 = null;
// 1778
o18 = {};
// 1779
o7["0"] = o18;
// undefined
o7 = null;
// 1780
o18.className = "push-loader";
// undefined
o18 = null;
// 1781
f283489458_17.returns.push(2);
// 1798
o9.tagName = "DIV";
// 1799
o9.getElementsByTagName = f283489458_390;
// undefined
o9 = null;
// 1800
o7 = {};
// 1801
f283489458_390.returns.push(o7);
// 1802
o9 = {};
// 1803
o7["0"] = o9;
// undefined
o7 = null;
// 1805
// undefined
o9 = null;
// 1815
o13.tagName = "DIV";
// 1816
o13.getElementsByTagName = f283489458_390;
// undefined
o13 = null;
// 1817
o7 = {};
// 1818
f283489458_390.returns.push(o7);
// 1819
o9 = {};
// 1820
o7["0"] = o9;
// undefined
o7 = null;
// 1822
// undefined
o9 = null;
// 1842
o17.tagName = "DIV";
// 1843
o17.getElementsByTagName = f283489458_390;
// undefined
o17 = null;
// 1844
o7 = {};
// 1845
f283489458_390.returns.push(o7);
// 1846
o9 = {};
// 1847
o7["0"] = o9;
// undefined
o7 = null;
// 1849
// undefined
o9 = null;
// 1864
o1.cookieEnabled = "true";
// 1866
o1.appName = "Netscape";
// 1868
f283489458_388.returns.push(null);
// 1869
o0.cookie = "k=10.35.59.127.1345563150295841; guest_id=v1%3A134556315030635910";
// 1870
f283489458_445 = function() { return f283489458_445.returns[f283489458_445.inst++]; };
f283489458_445.returns = [];
f283489458_445.inst = 0;
// 1871
o0.getElementsByName = f283489458_445;
// 1872
o7 = {};
// 1873
f283489458_445.returns.push(o7);
// 1874
o7.length = 2;
// 1875
o9 = {};
// 1876
o7["0"] = o9;
// 1877
// undefined
o9 = null;
// 1879
o9 = {};
// 1880
o7["1"] = o9;
// undefined
o7 = null;
// 1881
// undefined
o9 = null;
// 1886
o7 = {};
// 1887
f283489458_371.returns.push(o7);
// 1888
o7["0"] = o4;
// undefined
o7 = null;
// undefined
fo283489458_373_className.returns.push(" remove-prerendered-content");
// undefined
fo283489458_373_className.returns.push(" remove-prerendered-content");
// 1892
f283489458_388.returns.push(o16);
// 1894
f283489458_388.returns.push(o16);
// 1896
// undefined
o16 = null;
// 1898
f283489458_388.returns.push(o8);
// 1900
// 1901
// undefined
o8 = null;
// undefined
fo283489458_373_className.returns.push(" remove-prerendered-content");
// 1904
f283489458_450 = function() { return f283489458_450.returns[f283489458_450.inst++]; };
f283489458_450.returns = [];
f283489458_450.inst = 0;
// 1905
o4.getAttribute = f283489458_450;
// 1906
f283489458_450.returns.push("highlight-global-nav-home");
// undefined
fo283489458_373_className.returns.push(" ");
// 1909
f283489458_450.returns.push("highlight-global-nav-home");
// 1911
f283489458_451 = function() { return f283489458_451.returns[f283489458_451.inst++]; };
f283489458_451.returns = [];
f283489458_451.inst = 0;
// 1912
o4.removeAttribute = f283489458_451;
// 1913
f283489458_451.returns.push(undefined);
// 1915
f283489458_368.returns.push(0.3353369189918699);
// 1916
o2.hostname = "twitter.com";
// 1918
f283489458_388.returns.push(null);
// 1919
o2.protocol = "http:";
// 1920
o7 = {};
// 1921
f283489458_0.returns.push(o7);
// undefined
o7 = null;
// 1922
o7 = {};
// 1923
f283489458_0.returns.push(o7);
// undefined
o7 = null;
// 1924
f283489458_454 = function() { return f283489458_454.returns[f283489458_454.inst++]; };
f283489458_454.returns = [];
f283489458_454.inst = 0;
// 1925
o5.cloneNode = f283489458_454;
// undefined
o5 = null;
// 1926
o5 = {};
// 1927
f283489458_454.returns.push(o5);
// 1928
// 1929
// 1930
// 1931
// 1932
// 1933
// 1934
// 1936
o7 = {};
// 1937
o6.parentNode = o7;
// undefined
o6 = null;
// 1938
f283489458_457 = function() { return f283489458_457.returns[f283489458_457.inst++]; };
f283489458_457.returns = [];
f283489458_457.inst = 0;
// 1939
o7.insertBefore = f283489458_457;
// undefined
o7 = null;
// 1941
f283489458_457.returns.push(o5);
// 1943
o2.search = "";
// undefined
o2 = null;
// 1945
f283489458_368.returns.push(0.4683779077336425);
// 1946
o2 = {};
// 1947
f283489458_64.returns.push(o2);
// 1948
// 1949
f283489458_459 = function() { return f283489458_459.returns[f283489458_459.inst++]; };
f283489458_459.returns = [];
f283489458_459.inst = 0;
// 1950
o2.open = f283489458_459;
// 1951
f283489458_459.returns.push(undefined);
// 1952
f283489458_460 = function() { return f283489458_460.returns[f283489458_460.inst++]; };
f283489458_460.returns = [];
f283489458_460.inst = 0;
// 1953
o2.send = f283489458_460;
// 1954
f283489458_460.returns.push(undefined);
// 1956
o6 = {};
// 1957
f283489458_375.returns.push(o6);
// 1958
// 1959
o7 = {};
// 1960
o6.firstChild = o7;
// undefined
o6 = null;
// 1961
f283489458_463 = function() { return f283489458_463.returns[f283489458_463.inst++]; };
f283489458_463.returns = [];
f283489458_463.inst = 0;
// 1962
o7.JSBNG__addEventListener = f283489458_463;
// 1964
f283489458_463.returns.push(undefined);
// 1966
f283489458_464 = function() { return f283489458_464.returns[f283489458_464.inst++]; };
f283489458_464.returns = [];
f283489458_464.inst = 0;
// 1967
o3.insertBefore = f283489458_464;
// 1969
o6 = {};
// 1970
o3.firstChild = o6;
// undefined
o3 = null;
// undefined
o6 = null;
// 1971
f283489458_464.returns.push(o7);
// undefined
o7 = null;
// 1972
o3 = {};
// 1974
o2.readyState = 1;
// 1975
o6 = {};
// 1979
o7 = {};
// 1982
o8 = {};
// 1985
o9 = {};
// 1988
o2.responseText = "{\"requestCacheSeedData\":[],\"userProperties\":{},\"countryCode\":\"us\",\"twttr\":{\"pageLocale\":\"en\",\"doNotTrack\":false,\"payload\":{\"profiling\":false,\"conditionalTemplates\":{}},\"languages\":[{\"name_en\":\"Arabic\",\"name\":\"\\u0627\\u0644\\u0639\\u0631\\u0628\\u064a\\u0629\",\"css_classes\":\"ar rtl\",\"code\":\"ar\",\"current\":false,\"localized_name\":\"Arabic\"},{\"name_en\":\"Basque\",\"name\":\"Euskara\",\"css_classes\":\"eu western\",\"code\":\"eu\",\"current\":false,\"localized_name\":\"Basque\"},{\"name_en\":\"Catalan\",\"name\":\"catal\\u00e0\",\"css_classes\":\"ca western\",\"code\":\"ca\",\"current\":false,\"localized_name\":\"Catalan\"},{\"name_en\":\"Czech\",\"name\":\"\\u010ce\\u0161tina\",\"css_classes\":\"cs western\",\"code\":\"cs\",\"current\":false,\"localized_name\":\"Czech\"},{\"name_en\":\"Danish\",\"name\":\"Dansk\",\"css_classes\":\"western da\",\"code\":\"da\",\"current\":false,\"localized_name\":\"Danish\"},{\"name_en\":\"Dutch\",\"name\":\"Nederlands\",\"css_classes\":\"western nl\",\"code\":\"nl\",\"current\":false,\"localized_name\":\"Dutch\"},{\"name_en\":\"English\",\"name\":\"English\",\"css_classes\":null,\"code\":\"en\",\"current\":true,\"localized_name\":\"English\"},{\"name_en\":\"Farsi\",\"name\":\"\\u0641\\u0627\\u0631\\u0633\\u06cc\",\"css_classes\":\"fa rtl\",\"code\":\"fa\",\"current\":false,\"localized_name\":\"Farsi\"},{\"name_en\":\"Filipino\",\"name\":\"Filipino\",\"css_classes\":\"western fil\",\"code\":\"fil\",\"current\":false,\"localized_name\":\"Filipino\"},{\"name_en\":\"Finnish\",\"name\":\"Suomi\",\"css_classes\":\"western fi\",\"code\":\"fi\",\"current\":false,\"localized_name\":\"Finnish\"},{\"name_en\":\"French\",\"name\":\"fran\\u00e7ais\",\"css_classes\":\"western fr\",\"code\":\"fr\",\"current\":false,\"localized_name\":\"French\"},{\"name_en\":\"German\",\"name\":\"Deutsch\",\"css_classes\":\"western de\",\"code\":\"de\",\"current\":false,\"localized_name\":\"German\"},{\"name_en\":\"Greek\",\"name\":\"\\u0395\\u03bb\\u03bb\\u03b7\\u03bd\\u03b9\\u03ba\\u03ac\",\"css_classes\":\"\",\"code\":\"el\",\"current\":false,\"localized_name\":\"Greek\"},{\"name_en\":\"Hebrew\",\"name\":\"\\u05e2\\u05b4\\u05d1\\u05b0\\u05e8\\u05b4\\u05d9\\u05ea\",\"css_classes\":\"he rtl\",\"code\":\"he\",\"current\":false,\"localized_name\":\"Hebrew\"},{\"name_en\":\"Hindi\",\"name\":\"\\u0939\\u093f\\u0928\\u094d\\u0926\\u0940\",\"css_classes\":\"asian hi\",\"code\":\"hi\",\"current\":false,\"localized_name\":\"Hindi\"},{\"name_en\":\"Hungarian\",\"name\":\"Magyar\",\"css_classes\":\"western hu\",\"code\":\"hu\",\"current\":false,\"localized_name\":\"Hungarian\"},{\"name_en\":\"Indonesian\",\"name\":\"Bahasa Indonesia\",\"css_classes\":\"western id\",\"code\":\"id\",\"current\":false,\"localized_name\":\"Indonesian\"},{\"name_en\":\"Italian\",\"name\":\"Italiano\",\"css_classes\":\"western it\",\"code\":\"it\",\"current\":false,\"localized_name\":\"Italian\"},{\"name_en\":\"Japanese\",\"name\":\"\\u65e5\\u672c\\u8a9e\",\"css_classes\":\"asian ja\",\"code\":\"ja\",\"current\":false,\"localized_name\":\"Japanese\"},{\"name_en\":\"Korean\",\"name\":\"\\ud55c\\uad6d\\uc5b4\",\"css_classes\":\"asian ko\",\"code\":\"ko\",\"current\":false,\"localized_name\":\"Korean\"},{\"name_en\":\"Malay\",\"name\":\"Bahasa Melayu\",\"css_classes\":\"western msa\",\"code\":\"msa\",\"current\":false,\"localized_name\":\"Malay\"},{\"name_en\":\"Norwegian\",\"name\":\"Norsk\",\"css_classes\":\"western no\",\"code\":\"no\",\"current\":false,\"localized_name\":\"Norwegian\"},{\"name_en\":\"Polish\",\"name\":\"Polski\",\"css_classes\":\"western pl\",\"code\":\"pl\",\"current\":false,\"localized_name\":\"Polish\"},{\"name_en\":\"Portuguese\",\"name\":\"Portugu\\u00eas\",\"css_classes\":\"western pt\",\"code\":\"pt\",\"current\":false,\"localized_name\":\"Portuguese\"},{\"name_en\":\"Russian\",\"name\":\"\\u0420\\u0443\\u0441\\u0441\\u043a\\u0438\\u0439\",\"css_classes\":\"western ru\",\"code\":\"ru\",\"current\":false,\"localized_name\":\"Russian\"},{\"name_en\":\"Simplified Chinese\",\"name\":\"\\u7b80\\u4f53\\u4e2d\\u6587\",\"css_classes\":\"asian zh-cn\",\"code\":\"zh-cn\",\"current\":false,\"localized_name\":\"Simplified Chinese\"},{\"name_en\":\"Spanish\",\"name\":\"Espa\\u00f1ol\",\"css_classes\":\"western es\",\"code\":\"es\",\"current\":false,\"localized_name\":\"Spanish\"},{\"name_en\":\"Swedish\",\"name\":\"Svenska\",\"css_classes\":\"western sv\",\"code\":\"sv\",\"current\":false,\"localized_name\":\"Swedish\"},{\"name_en\":\"Thai\",\"name\":\"\\u0e20\\u0e32\\u0e29\\u0e32\\u0e44\\u0e17\\u0e22\",\"css_classes\":\"th asian\",\"code\":\"th\",\"current\":false,\"localized_name\":\"Thai\"},{\"name_en\":\"Traditional Chinese\",\"name\":\"\\u7e41\\u9ad4\\u4e2d\\u6587\",\"css_classes\":\"asian zh-tw\",\"code\":\"zh-tw\",\"current\":false,\"localized_name\":\"Traditional Chinese\"},{\"name_en\":\"Turkish\",\"name\":\"T\\u00fcrk\\u00e7e\",\"css_classes\":\"western tr\",\"code\":\"tr\",\"current\":false,\"localized_name\":\"Turkish\"},{\"name_en\":\"Ukrainian\",\"name\":\"\\u0423\\u043a\\u0440\\u0430\\u0457\\u043d\\u0441\\u044c\\u043a\\u0430 \\u043c\\u043e\\u0432\\u0430\",\"css_classes\":\"uk western\",\"code\":\"uk\",\"current\":false,\"localized_name\":\"Ukrainian\"},{\"name_en\":\"Urdu\",\"name\":\"\\u0627\\u0631\\u062f\\u0648\",\"css_classes\":\"ur rtl\",\"code\":\"ur\",\"current\":false,\"localized_name\":\"Urdu\"}],\"cdnBase\":{\"unversioned\":{\"ssl_akamai\":[\"https:\\/\\/twimg0-a.akamaihd.net\"],\"http\":[\"http:\\/\\/a0.twimg.com\"],\"ssl\":[\"https:\\/\\/si0.twimg.com\"]},\"versioned\":{\"ssl_akamai\":[\"https:\\/\\/twimg0-a.akamaihd.net\\/a\\/1345479106\"],\"http\":[\"http:\\/\\/a0.twimg.com\\/a\\/1345479106\"],\"ssl\":[\"https:\\/\\/si0.twimg.com\\/a\\/1345479106\"]},\"hashed\":{\"ssl_akamai\":[\"https:\\/\\/twimg0-a.akamaihd.net\\/c\"],\"http\":[\"http:\\/\\/a0.twimg.com\\/c\"],\"ssl\":[\"https:\\/\\/si0.twimg.com\\/c\"]}},\"inEU\":false,\"globalConfig\":{\"max_media_per_upload\":1,\"short_url_length\":20,\"photo_size_limit\":3145728,\"characters_reserved_per_media\":21,\"short_url_length_https\":21,\"photo_sizes\":{\"large\":{\"h\":2048,\"resize\":\"fit\",\"w\":1024},\"medium\":{\"h\":1200,\"resize\":\"fit\",\"w\":600},\"thumb\":{\"h\":150,\"resize\":\"crop\",\"w\":150},\"small\":{\"h\":480,\"resize\":\"fit\",\"w\":340}},\"non_username_paths\":[\"about\",\"account\",\"accounts\",\"activity\",\"all\",\"announcements\",\"anywhere\",\"api_rules\",\"api_terms\",\"apirules\",\"apps\",\"auth\",\"badges\",\"blog\",\"business\",\"buttons\",\"contacts\",\"devices\",\"direct_messages\",\"download\",\"downloads\",\"edit_announcements\",\"faq\",\"favorites\",\"find_sources\",\"find_users\",\"followers\",\"following\",\"friend_request\",\"friendrequest\",\"friends\",\"goodies\",\"help\",\"home\",\"im_account\",\"inbox\",\"invitations\",\"invite\",\"jobs\",\"list\",\"login\",\"logo\",\"logout\",\"me\",\"mentions\",\"messages\",\"mockview\",\"newtwitter\",\"notifications\",\"nudge\",\"oauth\",\"phoenix_search\",\"positions\",\"privacy\",\"public_timeline\",\"related_tweets\",\"replies\",\"retweeted_of_mine\",\"retweets\",\"retweets_by_others\",\"rules\",\"saved_searches\",\"search\",\"sent\",\"settings\",\"share\",\"signup\",\"signin\",\"similar_to\",\"statistics\",\"terms\",\"tos\",\"translate\",\"trends\",\"tweetbutton\",\"twttr\",\"update_discoverability\",\"users\",\"welcome\",\"who_to_follow\",\"widgets\",\"zendesk_auth\",\"media_signup\"]},\"scribeBufferSize\":10,\"isPreflight\":false},\"countries\":[{\"name\":\"Worldwide\",\"code\":\"xx\"},{\"name\":\"Afghanistan\",\"code\":\"af\"},{\"name\":\"Algeria\",\"code\":\"dz\"},{\"name\":\"Argentina\",\"code\":\"ar\"},{\"name\":\"Australia\",\"code\":\"au\"},{\"name\":\"Bangladesh\",\"code\":\"bd\"},{\"name\":\"Brazil\",\"code\":\"br\"},{\"name\":\"Cameroon\",\"code\":\"cm\"},{\"name\":\"Canada\",\"code\":\"ca\"},{\"name\":\"Colombia\",\"code\":\"co\"},{\"name\":\"Denmark\",\"code\":\"dk\"},{\"name\":\"Egypt\",\"code\":\"eg\"},{\"name\":\"Ethiopia\",\"code\":\"et\"},{\"name\":\"France\",\"code\":\"fr\"},{\"name\":\"Germany\",\"code\":\"de\"},{\"name\":\"Ghana\",\"code\":\"gh\"},{\"name\":\"Greece\",\"code\":\"gr\"},{\"name\":\"India\",\"code\":\"in\"},{\"name\":\"Indonesia\",\"code\":\"id\"},{\"name\":\"Iraq\",\"code\":\"iq\"},{\"name\":\"Ireland\",\"code\":\"ie\"},{\"name\":\"Israel\",\"code\":\"il\"},{\"name\":\"Italy\",\"code\":\"it\"},{\"name\":\"Japan\",\"code\":\"jp\"},{\"name\":\"Kenya\",\"code\":\"ke\"},{\"name\":\"Madagascar\",\"code\":\"mg\"},{\"name\":\"Malaysia\",\"code\":\"my\"},{\"name\":\"Mexico\",\"code\":\"mx\"},{\"name\":\"Morocco\",\"code\":\"ma\"},{\"name\":\"Mozambique\",\"code\":\"mz\"},{\"name\":\"Nepal\",\"code\":\"np\"},{\"name\":\"Netherlands\",\"code\":\"nl\"},{\"name\":\"New Zealand\",\"code\":\"nz\"},{\"name\":\"Nigeria\",\"code\":\"ni\"},{\"name\":\"Pakistan\",\"code\":\"pk\"},{\"name\":\"Peru\",\"code\":\"pe\"},{\"name\":\"Philippines\",\"code\":\"ph\"},{\"name\":\"Poland\",\"code\":\"pl\"},{\"name\":\"Republic of Korea\",\"code\":\"kr\"},{\"name\":\"Romania\",\"code\":\"ro\"},{\"name\":\"Russia\",\"code\":\"ru\"},{\"name\":\"Saudi Arabia\",\"code\":\"sa\"},{\"name\":\"Singapore\",\"code\":\"sg\"},{\"name\":\"South Africa\",\"code\":\"za\"},{\"name\":\"Spain\",\"code\":\"es\"},{\"name\":\"Sri Lanka\",\"code\":\"lk\"},{\"name\":\"Sweden\",\"code\":\"se\"},{\"name\":\"Switzerland\",\"code\":\"ch\"},{\"name\":\"Taiwan\",\"code\":\"tw\"},{\"name\":\"Tanzania\",\"code\":\"tz\"},{\"name\":\"Thailand\",\"code\":\"th\"},{\"name\":\"Turkey\",\"code\":\"tr\"},{\"name\":\"Uganda\",\"code\":\"ug\"},{\"name\":\"Ukraine\",\"code\":\"ua\"},{\"name\":\"United Kingdom\",\"code\":\"gb\"},{\"name\":\"United States\",\"code\":\"us\"},{\"name\":\"Uzbekistan\",\"code\":\"uz\"},{\"name\":\"Venezuela\",\"code\":\"ve\"},{\"name\":\"Vietnam\",\"code\":\"vn\"},{\"name\":\"Yemen\",\"code\":\"ye\"}],\"postAuthenticityToken\":\"ab563baf48a09bd8bcac3133ef3717340b74024c\",\"deciderFeatures\":{\"phoenix_turkey_permalink\":1,\"tweet_stream_retweets_by_you_polling\":1,\"suggestion_categories_streams\":1,\"i18n_new_translation_center\":1,\"people_stream_followers\":1,\"phoenix_pepsi_details\":1,\"geo_more_places\":1,\"trends_component\":1,\"tweet_stream_following_polling\":1,\"linkify_cashtags\":1,\"phoenix_scribe\":1,\"email_device_settings\":1,\"phoenix_user_media_gallery\":1,\"list_stream_subscriptions\":1,\"html5Routing\":1,\"bananaquit_show_opt_out\":1,\"conversations\":1,\"tweet_stream_your_tweets_retweeted_polling\":1,\"onebox\":1,\"phoenix_flickr_details\":1,\"people_stream_people_search\":1,\"contact_import\":1,\"phoenix_apple_itunes_more\":1,\"tweet_stream_profile_polling\":1,\"photo_copy_paste_inception\":1,\"geo_ui\":1,\"typeahead\":1,\"front_full_signup\":1,\"t1d_tweet_img\":1,\"people_stream_friends\":1,\"dashboard_activity_followers\":1,\"list_stream_own_lists\":1,\"phoenix_wordpress_details\":1,\"empty_timeline_recommendations\":1,\"phoenix_aol_video\":1,\"ptw_reinjection\":1,\"swift_typeahead\":1,\"phoenix_url_resolver\":1,\"avatar_upload\":1,\"tweet_stream_profile\":1,\"swift_login\":1,\"typeahead_saved_searches\":1,\"embed_code_dialog\":1,\"phoenix_turkey_html5_resize\":1,\"phoenix_tweetbox_talon\":1,\"phoenix_facets_videos\":1,\"logged_out_people_search\":1,\"tweet_stream_user\":1,\"more_lists_component\":1,\"swift_discover\":1,\"phoenix_facets\":1,\"phoenix_search_relevance_logged_out\":1,\"personalization_settings\":1,\"phoenix_facets_images\":1,\"sports_onebox\":1,\"activity_read\":1,\"tweet_stream_favorites\":1,\"japanese_ad_component\":1,\"tweet_stream_user_polling\":1,\"phoenix_pctd\":1,\"mobile_download_gallery\":1,\"place_people_component\":1,\"tweet_stream_mentions_polling\":1,\"people_stream_follower_requests\":1,\"place_users_stream\":1,\"swift_permalink\":1,\"swift_events\":1,\"advanced_search\":1,\"swift_action_queue\":1,\"list_streams\":1,\"t1_dm_poll\":1,\"personalization_preview\":1,\"tweet_stream_retweets_by_you\":1,\"wtf_signup_suggestions\":1,\"promptbird_phoenix\":1,\"phoenix_amazon_details\":1,\"contact_import_stream\":1,\"welcome_ad_track\":1,\"welcome_profile\":1,\"swift_mentions\":1,\"user_shuffler\":1,\"bananaquit_dnt_scribe\":1,\"whotofollow_similarities\":1,\"t1d_topic_img\":1,\"flock\":1,\"place_tweets_component\":1,\"swift_facebook_token\":1,\"message_stream\":1,\"people_stream_fresh\":1,\"disable_gallery_grid\":1,\"api_per_country_takedown\":1,\"wtf_home_timeline_show_links\":1,\"phoenix_search_dropdown\":1,\"profile_image_latency\":1,\"whotofollow_random_sample\":1,\"tweet_stream_home\":1,\"personalized_trends\":1,\"in_reply_to_component\":1,\"promo_component\":1,\"add_authenticity_token_via_js\":1,\"geo_location\":1,\"phoenix_first_time\":1,\"phoenix_local_foursquare\":1,\"scribe_client_event\":1,\"escape_ampersands_in_search_highlighter\":1,\"people_stream_list_members\":1,\"media_flagging\":1,\"mt_tweet_backend_bing\":1,\"t1d_tweet_vid\":1,\"tweet_stream_list_polling\":1,\"typeahead_global_nav\":1,\"phoenix_autocomplete\":1,\"welcome_warm_signup\":1,\"scribe_image_failures\":1,\"people_stream_list_followers\":1,\"platform_coerce_native_media_to_cards\":1,\"phoenix_local_gowalla\":1,\"inline_media_component\":1,\"geo_show_similar_places\":1,\"turkey\":1,\"list_stream_memberships\":1,\"use_scribe_post\":1,\"scribe_form_piggyback\":1,\"tweet_stream_your_tweets_retweeted\":1,\"swift_events_reroute\":1,\"phoenix_turkey_flash\":1,\"tweet_stream_retweets_by_others_polling\":1,\"big_photo_permalink\":1,\"dashboard_activity_following\":1,\"sports_onebox_polling\":1,\"tweet_stream_favorites_polling\":1,\"people_streams\":1,\"phoenix_apple_itunes\":1,\"profile_pane_fresh\":1,\"profile_tweetbox\":1,\"whotofollow_recommendations\":1,\"tweet_stream_mentions\":1,\"old_webclient_events\":1,\"tweet_stream_list\":1,\"newest_list_members_component\":1,\"swift_impression_cookie\":1,\"news_onebox\":1,\"blender_search_timeline\":1,\"social_context\":1,\"search_assistance\":1,\"swift_interactions\":1,\"phoenix_instagram_and_friends\":1,\"phoenix_facets_logged_out\":1,\"phoenix_whosay_details\":1,\"tweet_stream_search_polling\":1,\"phoenix_local_plancast\":1,\"tweet_streams_polling\":1,\"infinite_scroll\":1,\"geo_allow_set_location_manually\":1,\"phoenix_search_relevance\":1,\"local_trends\":1,\"tweet_stream_home_polling\":1,\"swift_events_search\":1,\"tweet_stream_retweets_by_others\":1,\"disable_gallery_thumbs\":1,\"mobile_download_gallery_logged_out\":1,\"swift_profile\":1,\"activity_modal\":1,\"fake_loggedout_decider\":1,\"geo_place_creation\":1,\"promoted_accounts_in_whotofollow_viewall\":1,\"tweet_streams\":1,\"phoenix_preload_twimgs\":1,\"eurl_dwell_time_store\":1,\"typeahead_local_queries\":1,\"tweet_geo_component\":1,\"geo_ui_dropdown_available\":1,\"tweet_stream_following\":1,\"user_onebox\":1,\"activity_status_summary\":1,\"phoenix_local_meetup\":1,\"recent_tweets_component\":1,\"phoenix_facebook_details\":1,\"onebox_user_search\":1,\"tweet_stream_search\":1,\"japanese_new_ad_provider\":1,\"profile_combined_api\":1,\"trends_component_polling\":1,\"t1d_topic_vid\":1},\"abBuckets\":{\"mobile_signupbutton_validation_fix_315\":{\"bucket\":\"always_enabled\",\"version\":4,\"experiment_key\":\"mobile_signupbutton_validation_fix_315\",\"bucket_names\":[\"control\",\"always_enabled\",\"better_enabling\"]},\"tweet_permalink_logged_out_action_330\":{\"bucket\":\"current\",\"version\":3,\"experiment_key\":\"tweet_permalink_logged_out_action_330\",\"bucket_names\":[\"control\",\"current\"]},\"signup_mailto_on_welcome_312\":{\"bucket\":\"usual\",\"version\":4,\"experiment_key\":\"signup_mailto_on_welcome_312\",\"bucket_names\":[\"control\",\"usual\"]}}}";
// 2001
o13 = {};
// 2002
f283489458_390.returns.push(o13);
// 2003
o13["0"] = o10;
// undefined
o13 = null;
// 2004
o10.value = "";
// 2010
o13 = {};
// 2011
f283489458_390.returns.push(o13);
// 2012
o13["0"] = o11;
// undefined
o13 = null;
// 2013
o11.value = "";
// 2019
o13 = {};
// 2020
f283489458_390.returns.push(o13);
// 2021
o13["0"] = o12;
// undefined
o13 = null;
// 2022
o12.value = "";
// 2032
o13 = {};
// 2033
f283489458_390.returns.push(o13);
// 2034
o13["0"] = o14;
// undefined
o13 = null;
// 2035
o14.value = "";
// 2041
o13 = {};
// 2042
f283489458_390.returns.push(o13);
// 2043
o13["0"] = o15;
// undefined
o13 = null;
// 2044
o15.value = "";
// 2091
o13 = {};
// 2092
f283489458_390.returns.push(o13);
// 2093
o13["0"] = o10;
// undefined
o13 = null;
// 2100
o13 = {};
// 2101
f283489458_390.returns.push(o13);
// 2102
o13["0"] = o11;
// undefined
o13 = null;
// 2109
o13 = {};
// 2110
f283489458_390.returns.push(o13);
// 2111
o13["0"] = o12;
// undefined
o13 = null;
// 2122
o13 = {};
// 2123
f283489458_390.returns.push(o13);
// 2124
o13["0"] = o14;
// undefined
o13 = null;
// 2131
o13 = {};
// 2132
f283489458_390.returns.push(o13);
// 2133
o13["0"] = o15;
// undefined
o13 = null;
// 2170
o13 = {};
// 2171
ow283489458.JSBNG__event = undefined;
// 2172
o13.type = "load";
// undefined
o13 = null;
// 2173
// undefined
o5 = null;
// 2174
o1.userAgent = "Mozilla/5.0 (X11; Linux i686 on x86_64; rv:14.0) Gecko/20100101 Firefox/14.0.1";
// undefined
o1 = null;
// 2175
o0.nodeType = 9;
// 2176
f283489458_482 = function() { return f283489458_482.returns[f283489458_482.inst++]; };
f283489458_482.returns = [];
f283489458_482.inst = 0;
// 2177
o0.JSBNG__addEventListener = f283489458_482;
// 2179
o1 = {};
// 2180
f283489458_375.returns.push(o1);
// 2181
o0.documentElement = o4;
// undefined
o0 = null;
// undefined
o4 = null;
// 2182
f283489458_484 = function() { return f283489458_484.returns[f283489458_484.inst++]; };
f283489458_484.returns = [];
f283489458_484.inst = 0;
// 2183
o1.setAttribute = f283489458_484;
// 2184
f283489458_484.returns.push(undefined);
// 2185
// 2186
o1.getElementsByTagName = f283489458_390;
// undefined
o1 = null;
// 2187
o0 = {};
// 2188
f283489458_390.returns.push(o0);
// 2190
o1 = {};
// 2191
f283489458_390.returns.push(o1);
// 2192
o4 = {};
// 2193
o1["0"] = o4;
// undefined
o1 = null;
// undefined
o4 = null;
// 2194
o0.length = 4;
// undefined
o0 = null;
// 2196
o0 = {};
// 2197
f283489458_375.returns.push(o0);
// 2198
o0.appendChild = void 0;
// undefined
o0 = null;
// 2200
o0 = {};
// 2201
f283489458_375.returns.push(o0);
// undefined
o0 = null;
// 2214
o0 = {};
// 2215
f283489458_390.returns.push(o0);
// 2216
o0["0"] = o10;
// undefined
o0 = null;
// 2223
o0 = {};
// 2224
f283489458_390.returns.push(o0);
// 2225
o0["0"] = o11;
// undefined
o0 = null;
// 2232
o0 = {};
// 2233
f283489458_390.returns.push(o0);
// 2234
o0["0"] = o12;
// undefined
o0 = null;
// 2245
o0 = {};
// 2246
f283489458_390.returns.push(o0);
// 2247
o0["0"] = o14;
// undefined
o0 = null;
// 2254
o0 = {};
// 2255
f283489458_390.returns.push(o0);
// 2256
o0["0"] = o15;
// undefined
o0 = null;
// 2304
o0 = {};
// 2305
f283489458_390.returns.push(o0);
// 2306
o0["0"] = o10;
// undefined
o0 = null;
// 2313
o0 = {};
// 2314
f283489458_390.returns.push(o0);
// 2315
o0["0"] = o11;
// undefined
o0 = null;
// 2322
o0 = {};
// 2323
f283489458_390.returns.push(o0);
// 2324
o0["0"] = o12;
// undefined
o0 = null;
// 2335
o0 = {};
// 2336
f283489458_390.returns.push(o0);
// 2337
o0["0"] = o14;
// undefined
o0 = null;
// 2344
o0 = {};
// 2345
f283489458_390.returns.push(o0);
// 2346
o0["0"] = o15;
// undefined
o0 = null;
// 2394
o0 = {};
// 2395
f283489458_390.returns.push(o0);
// 2396
o0["0"] = o10;
// undefined
o0 = null;
// 2403
o0 = {};
// 2404
f283489458_390.returns.push(o0);
// 2405
o0["0"] = o11;
// undefined
o0 = null;
// 2412
o0 = {};
// 2413
f283489458_390.returns.push(o0);
// 2414
o0["0"] = o12;
// undefined
o0 = null;
// 2425
o0 = {};
// 2426
f283489458_390.returns.push(o0);
// 2427
o0["0"] = o14;
// undefined
o0 = null;
// 2434
o0 = {};
// 2435
f283489458_390.returns.push(o0);
// 2436
o0["0"] = o15;
// undefined
o0 = null;
// 2484
o0 = {};
// 2485
f283489458_390.returns.push(o0);
// 2486
o0["0"] = o10;
// undefined
o0 = null;
// 2493
o0 = {};
// 2494
f283489458_390.returns.push(o0);
// 2495
o0["0"] = o11;
// undefined
o0 = null;
// 2502
o0 = {};
// 2503
f283489458_390.returns.push(o0);
// 2504
o0["0"] = o12;
// undefined
o0 = null;
// 2515
o0 = {};
// 2516
f283489458_390.returns.push(o0);
// 2517
o0["0"] = o14;
// undefined
o0 = null;
// 2524
o0 = {};
// 2525
f283489458_390.returns.push(o0);
// 2526
o0["0"] = o15;
// undefined
o0 = null;
// 2574
o0 = {};
// 2575
f283489458_390.returns.push(o0);
// 2576
o0["0"] = o10;
// undefined
o0 = null;
// 2583
o0 = {};
// 2584
f283489458_390.returns.push(o0);
// 2585
o0["0"] = o11;
// undefined
o0 = null;
// 2592
o0 = {};
// 2593
f283489458_390.returns.push(o0);
// 2594
o0["0"] = o12;
// undefined
o0 = null;
// 2605
o0 = {};
// 2606
f283489458_390.returns.push(o0);
// 2607
o0["0"] = o14;
// undefined
o0 = null;
// 2614
o0 = {};
// 2615
f283489458_390.returns.push(o0);
// 2616
o0["0"] = o15;
// undefined
o0 = null;
// 2664
o0 = {};
// 2665
f283489458_390.returns.push(o0);
// 2666
o0["0"] = o10;
// undefined
o0 = null;
// 2673
o0 = {};
// 2674
f283489458_390.returns.push(o0);
// 2675
o0["0"] = o11;
// undefined
o0 = null;
// 2682
o0 = {};
// 2683
f283489458_390.returns.push(o0);
// 2684
o0["0"] = o12;
// undefined
o0 = null;
// 2695
o0 = {};
// 2696
f283489458_390.returns.push(o0);
// 2697
o0["0"] = o14;
// undefined
o0 = null;
// 2704
o0 = {};
// 2705
f283489458_390.returns.push(o0);
// 2706
o0["0"] = o15;
// undefined
o0 = null;
// 2754
o0 = {};
// 2755
f283489458_390.returns.push(o0);
// 2756
o0["0"] = o10;
// undefined
o0 = null;
// 2763
o0 = {};
// 2764
f283489458_390.returns.push(o0);
// 2765
o0["0"] = o11;
// undefined
o0 = null;
// 2772
o0 = {};
// 2773
f283489458_390.returns.push(o0);
// 2774
o0["0"] = o12;
// undefined
o0 = null;
// 2785
o0 = {};
// 2786
f283489458_390.returns.push(o0);
// 2787
o0["0"] = o14;
// undefined
o0 = null;
// 2794
o0 = {};
// 2795
f283489458_390.returns.push(o0);
// 2796
o0["0"] = o15;
// undefined
o0 = null;
// 2844
o0 = {};
// 2845
f283489458_390.returns.push(o0);
// 2846
o0["0"] = o10;
// undefined
o0 = null;
// 2853
o0 = {};
// 2854
f283489458_390.returns.push(o0);
// 2855
o0["0"] = o11;
// undefined
o0 = null;
// 2862
o0 = {};
// 2863
f283489458_390.returns.push(o0);
// 2864
o0["0"] = o12;
// undefined
o0 = null;
// 2875
o0 = {};
// 2876
f283489458_390.returns.push(o0);
// 2877
o0["0"] = o14;
// undefined
o0 = null;
// 2884
o0 = {};
// 2885
f283489458_390.returns.push(o0);
// 2886
o0["0"] = o15;
// undefined
o0 = null;
// 2934
o0 = {};
// 2935
f283489458_390.returns.push(o0);
// 2936
o0["0"] = o10;
// undefined
o0 = null;
// 2943
o0 = {};
// 2944
f283489458_390.returns.push(o0);
// 2945
o0["0"] = o11;
// undefined
o0 = null;
// 2952
o0 = {};
// 2953
f283489458_390.returns.push(o0);
// 2954
o0["0"] = o12;
// undefined
o0 = null;
// 2965
o0 = {};
// 2966
f283489458_390.returns.push(o0);
// 2967
o0["0"] = o14;
// undefined
o0 = null;
// 2974
o0 = {};
// 2975
f283489458_390.returns.push(o0);
// 2976
o0["0"] = o15;
// undefined
o0 = null;
// 3024
o0 = {};
// 3025
f283489458_390.returns.push(o0);
// 3026
o0["0"] = o10;
// undefined
o0 = null;
// 3033
o0 = {};
// 3034
f283489458_390.returns.push(o0);
// 3035
o0["0"] = o11;
// undefined
o0 = null;
// 3042
o0 = {};
// 3043
f283489458_390.returns.push(o0);
// 3044
o0["0"] = o12;
// undefined
o0 = null;
// 3055
o0 = {};
// 3056
f283489458_390.returns.push(o0);
// 3057
o0["0"] = o14;
// undefined
o0 = null;
// 3064
o0 = {};
// 3065
f283489458_390.returns.push(o0);
// 3066
o0["0"] = o15;
// undefined
o0 = null;
// 3114
o0 = {};
// 3115
f283489458_390.returns.push(o0);
// 3116
o0["0"] = o10;
// undefined
o0 = null;
// 3123
o0 = {};
// 3124
f283489458_390.returns.push(o0);
// 3125
o0["0"] = o11;
// undefined
o0 = null;
// 3132
o0 = {};
// 3133
f283489458_390.returns.push(o0);
// 3134
o0["0"] = o12;
// undefined
o0 = null;
// 3145
o0 = {};
// 3146
f283489458_390.returns.push(o0);
// 3147
o0["0"] = o14;
// undefined
o0 = null;
// 3154
o0 = {};
// 3155
f283489458_390.returns.push(o0);
// 3156
o0["0"] = o15;
// undefined
o0 = null;
// 3204
o0 = {};
// 3205
f283489458_390.returns.push(o0);
// 3206
o0["0"] = o10;
// undefined
o0 = null;
// 3213
o0 = {};
// 3214
f283489458_390.returns.push(o0);
// 3215
o0["0"] = o11;
// undefined
o0 = null;
// 3222
o0 = {};
// 3223
f283489458_390.returns.push(o0);
// 3224
o0["0"] = o12;
// undefined
o0 = null;
// 3235
o0 = {};
// 3236
f283489458_390.returns.push(o0);
// 3237
o0["0"] = o14;
// undefined
o0 = null;
// 3244
o0 = {};
// 3245
f283489458_390.returns.push(o0);
// 3246
o0["0"] = o15;
// undefined
o0 = null;
// 3294
o0 = {};
// 3295
f283489458_390.returns.push(o0);
// 3296
o0["0"] = o10;
// undefined
o0 = null;
// 3303
o0 = {};
// 3304
f283489458_390.returns.push(o0);
// 3305
o0["0"] = o11;
// undefined
o0 = null;
// 3312
o0 = {};
// 3313
f283489458_390.returns.push(o0);
// 3314
o0["0"] = o12;
// undefined
o0 = null;
// 3325
o0 = {};
// 3326
f283489458_390.returns.push(o0);
// 3327
o0["0"] = o14;
// undefined
o0 = null;
// 3334
o0 = {};
// 3335
f283489458_390.returns.push(o0);
// 3336
o0["0"] = o15;
// undefined
o0 = null;
// 3384
o0 = {};
// 3385
f283489458_390.returns.push(o0);
// 3386
o0["0"] = o10;
// undefined
o0 = null;
// 3393
o0 = {};
// 3394
f283489458_390.returns.push(o0);
// 3395
o0["0"] = o11;
// undefined
o0 = null;
// 3402
o0 = {};
// 3403
f283489458_390.returns.push(o0);
// 3404
o0["0"] = o12;
// undefined
o0 = null;
// 3415
o0 = {};
// 3416
f283489458_390.returns.push(o0);
// 3417
o0["0"] = o14;
// undefined
o0 = null;
// 3424
o0 = {};
// 3425
f283489458_390.returns.push(o0);
// 3426
o0["0"] = o15;
// undefined
o0 = null;
// 3474
o0 = {};
// 3475
f283489458_390.returns.push(o0);
// 3476
o0["0"] = o10;
// undefined
o0 = null;
// 3483
o0 = {};
// 3484
f283489458_390.returns.push(o0);
// 3485
o0["0"] = o11;
// undefined
o0 = null;
// 3492
o0 = {};
// 3493
f283489458_390.returns.push(o0);
// 3494
o0["0"] = o12;
// undefined
o0 = null;
// 3505
o0 = {};
// 3506
f283489458_390.returns.push(o0);
// 3507
o0["0"] = o14;
// undefined
o0 = null;
// 3514
o0 = {};
// 3515
f283489458_390.returns.push(o0);
// 3516
o0["0"] = o15;
// undefined
o0 = null;
// 3564
o0 = {};
// 3565
f283489458_390.returns.push(o0);
// 3566
o0["0"] = o10;
// undefined
o0 = null;
// 3573
o0 = {};
// 3574
f283489458_390.returns.push(o0);
// 3575
o0["0"] = o11;
// undefined
o0 = null;
// 3582
o0 = {};
// 3583
f283489458_390.returns.push(o0);
// 3584
o0["0"] = o12;
// undefined
o0 = null;
// 3595
o0 = {};
// 3596
f283489458_390.returns.push(o0);
// 3597
o0["0"] = o14;
// undefined
o0 = null;
// 3604
o0 = {};
// 3605
f283489458_390.returns.push(o0);
// 3606
o0["0"] = o15;
// undefined
o0 = null;
// 3654
o0 = {};
// 3655
f283489458_390.returns.push(o0);
// 3656
o0["0"] = o10;
// undefined
o0 = null;
// 3663
o0 = {};
// 3664
f283489458_390.returns.push(o0);
// 3665
o0["0"] = o11;
// undefined
o0 = null;
// 3672
o0 = {};
// 3673
f283489458_390.returns.push(o0);
// 3674
o0["0"] = o12;
// undefined
o0 = null;
// 3685
o0 = {};
// 3686
f283489458_390.returns.push(o0);
// 3687
o0["0"] = o14;
// undefined
o0 = null;
// 3694
o0 = {};
// 3695
f283489458_390.returns.push(o0);
// 3696
o0["0"] = o15;
// undefined
o0 = null;
// 3744
o0 = {};
// 3745
f283489458_390.returns.push(o0);
// 3746
o0["0"] = o10;
// undefined
o0 = null;
// 3753
o0 = {};
// 3754
f283489458_390.returns.push(o0);
// 3755
o0["0"] = o11;
// undefined
o0 = null;
// 3762
o0 = {};
// 3763
f283489458_390.returns.push(o0);
// 3764
o0["0"] = o12;
// undefined
o0 = null;
// 3775
o0 = {};
// 3776
f283489458_390.returns.push(o0);
// 3777
o0["0"] = o14;
// undefined
o0 = null;
// 3784
o0 = {};
// 3785
f283489458_390.returns.push(o0);
// 3786
o0["0"] = o15;
// undefined
o0 = null;
// 3834
o0 = {};
// 3835
f283489458_390.returns.push(o0);
// 3836
o0["0"] = o10;
// undefined
o0 = null;
// 3843
o0 = {};
// 3844
f283489458_390.returns.push(o0);
// 3845
o0["0"] = o11;
// undefined
o0 = null;
// 3852
o0 = {};
// 3853
f283489458_390.returns.push(o0);
// 3854
o0["0"] = o12;
// undefined
o0 = null;
// 3865
o0 = {};
// 3866
f283489458_390.returns.push(o0);
// 3867
o0["0"] = o14;
// undefined
o0 = null;
// 3874
o0 = {};
// 3875
f283489458_390.returns.push(o0);
// 3876
o0["0"] = o15;
// undefined
o0 = null;
// 3924
o0 = {};
// 3925
f283489458_390.returns.push(o0);
// 3926
o0["0"] = o10;
// undefined
o0 = null;
// 3933
o0 = {};
// 3934
f283489458_390.returns.push(o0);
// 3935
o0["0"] = o11;
// undefined
o0 = null;
// 3942
o0 = {};
// 3943
f283489458_390.returns.push(o0);
// 3944
o0["0"] = o12;
// undefined
o0 = null;
// 3955
o0 = {};
// 3956
f283489458_390.returns.push(o0);
// 3957
o0["0"] = o14;
// undefined
o0 = null;
// 3964
o0 = {};
// 3965
f283489458_390.returns.push(o0);
// 3966
o0["0"] = o15;
// undefined
o0 = null;
// 4014
o0 = {};
// 4015
f283489458_390.returns.push(o0);
// 4016
o0["0"] = o10;
// undefined
o0 = null;
// 4023
o0 = {};
// 4024
f283489458_390.returns.push(o0);
// 4025
o0["0"] = o11;
// undefined
o0 = null;
// 4032
o0 = {};
// 4033
f283489458_390.returns.push(o0);
// 4034
o0["0"] = o12;
// undefined
o0 = null;
// 4045
o0 = {};
// 4046
f283489458_390.returns.push(o0);
// 4047
o0["0"] = o14;
// undefined
o0 = null;
// 4054
o0 = {};
// 4055
f283489458_390.returns.push(o0);
// 4056
o0["0"] = o15;
// undefined
o0 = null;
// 4104
o0 = {};
// 4105
f283489458_390.returns.push(o0);
// 4106
o0["0"] = o10;
// undefined
o0 = null;
// 4113
o0 = {};
// 4114
f283489458_390.returns.push(o0);
// 4115
o0["0"] = o11;
// undefined
o0 = null;
// 4122
o0 = {};
// 4123
f283489458_390.returns.push(o0);
// 4124
o0["0"] = o12;
// undefined
o0 = null;
// 4135
o0 = {};
// 4136
f283489458_390.returns.push(o0);
// 4137
o0["0"] = o14;
// undefined
o0 = null;
// 4144
o0 = {};
// 4145
f283489458_390.returns.push(o0);
// 4146
o0["0"] = o15;
// undefined
o0 = null;
// 4194
o0 = {};
// 4195
f283489458_390.returns.push(o0);
// 4196
o0["0"] = o10;
// undefined
o0 = null;
// 4203
o0 = {};
// 4204
f283489458_390.returns.push(o0);
// 4205
o0["0"] = o11;
// undefined
o0 = null;
// 4212
o0 = {};
// 4213
f283489458_390.returns.push(o0);
// 4214
o0["0"] = o12;
// undefined
o0 = null;
// 4225
o0 = {};
// 4226
f283489458_390.returns.push(o0);
// 4227
o0["0"] = o14;
// undefined
o0 = null;
// 4234
o0 = {};
// 4235
f283489458_390.returns.push(o0);
// 4236
o0["0"] = o15;
// undefined
o0 = null;
// 4284
o0 = {};
// 4285
f283489458_390.returns.push(o0);
// 4286
o0["0"] = o10;
// undefined
o0 = null;
// 4293
o0 = {};
// 4294
f283489458_390.returns.push(o0);
// 4295
o0["0"] = o11;
// undefined
o0 = null;
// 4302
o0 = {};
// 4303
f283489458_390.returns.push(o0);
// 4304
o0["0"] = o12;
// undefined
o0 = null;
// 4315
o0 = {};
// 4316
f283489458_390.returns.push(o0);
// 4317
o0["0"] = o14;
// undefined
o0 = null;
// 4324
o0 = {};
// 4325
f283489458_390.returns.push(o0);
// 4326
o0["0"] = o15;
// undefined
o0 = null;
// 4374
o0 = {};
// 4375
f283489458_390.returns.push(o0);
// 4376
o0["0"] = o10;
// undefined
o0 = null;
// 4383
o0 = {};
// 4384
f283489458_390.returns.push(o0);
// 4385
o0["0"] = o11;
// undefined
o0 = null;
// 4392
o0 = {};
// 4393
f283489458_390.returns.push(o0);
// 4394
o0["0"] = o12;
// undefined
o0 = null;
// 4405
o0 = {};
// 4406
f283489458_390.returns.push(o0);
// 4407
o0["0"] = o14;
// undefined
o0 = null;
// 4414
o0 = {};
// 4415
f283489458_390.returns.push(o0);
// 4416
o0["0"] = o15;
// undefined
o0 = null;
// 4464
o0 = {};
// 4465
f283489458_390.returns.push(o0);
// 4466
o0["0"] = o10;
// undefined
o0 = null;
// 4473
o0 = {};
// 4474
f283489458_390.returns.push(o0);
// 4475
o0["0"] = o11;
// undefined
o0 = null;
// 4482
o0 = {};
// 4483
f283489458_390.returns.push(o0);
// 4484
o0["0"] = o12;
// undefined
o0 = null;
// 4495
o0 = {};
// 4496
f283489458_390.returns.push(o0);
// 4497
o0["0"] = o14;
// undefined
o0 = null;
// 4504
o0 = {};
// 4505
f283489458_390.returns.push(o0);
// 4506
o0["0"] = o15;
// undefined
o0 = null;
// 4554
o0 = {};
// 4555
f283489458_390.returns.push(o0);
// 4556
o0["0"] = o10;
// undefined
o0 = null;
// 4563
o0 = {};
// 4564
f283489458_390.returns.push(o0);
// 4565
o0["0"] = o11;
// undefined
o0 = null;
// 4572
o0 = {};
// 4573
f283489458_390.returns.push(o0);
// 4574
o0["0"] = o12;
// undefined
o0 = null;
// 4585
o0 = {};
// 4586
f283489458_390.returns.push(o0);
// 4587
o0["0"] = o14;
// undefined
o0 = null;
// 4594
o0 = {};
// 4595
f283489458_390.returns.push(o0);
// 4596
o0["0"] = o15;
// undefined
o0 = null;
// 4644
o0 = {};
// 4645
f283489458_390.returns.push(o0);
// 4646
o0["0"] = o10;
// undefined
o0 = null;
// 4653
o0 = {};
// 4654
f283489458_390.returns.push(o0);
// 4655
o0["0"] = o11;
// undefined
o0 = null;
// 4662
o0 = {};
// 4663
f283489458_390.returns.push(o0);
// 4664
o0["0"] = o12;
// undefined
o0 = null;
// 4675
o0 = {};
// 4676
f283489458_390.returns.push(o0);
// 4677
o0["0"] = o14;
// undefined
o0 = null;
// 4684
o0 = {};
// 4685
f283489458_390.returns.push(o0);
// 4686
o0["0"] = o15;
// undefined
o0 = null;
// 4734
o0 = {};
// 4735
f283489458_390.returns.push(o0);
// 4736
o0["0"] = o10;
// undefined
o0 = null;
// 4743
o0 = {};
// 4744
f283489458_390.returns.push(o0);
// 4745
o0["0"] = o11;
// undefined
o0 = null;
// 4752
o0 = {};
// 4753
f283489458_390.returns.push(o0);
// 4754
o0["0"] = o12;
// undefined
o0 = null;
// 4765
o0 = {};
// 4766
f283489458_390.returns.push(o0);
// 4767
o0["0"] = o14;
// undefined
o0 = null;
// 4774
o0 = {};
// 4775
f283489458_390.returns.push(o0);
// 4776
o0["0"] = o15;
// undefined
o0 = null;
// 4824
o0 = {};
// 4825
f283489458_390.returns.push(o0);
// 4826
o0["0"] = o10;
// undefined
o0 = null;
// 4833
o0 = {};
// 4834
f283489458_390.returns.push(o0);
// 4835
o0["0"] = o11;
// undefined
o0 = null;
// 4842
o0 = {};
// 4843
f283489458_390.returns.push(o0);
// 4844
o0["0"] = o12;
// undefined
o0 = null;
// 4855
o0 = {};
// 4856
f283489458_390.returns.push(o0);
// 4857
o0["0"] = o14;
// undefined
o0 = null;
// 4864
o0 = {};
// 4865
f283489458_390.returns.push(o0);
// 4866
o0["0"] = o15;
// undefined
o0 = null;
// 4914
o0 = {};
// 4915
f283489458_390.returns.push(o0);
// 4916
o0["0"] = o10;
// undefined
o0 = null;
// 4923
o0 = {};
// 4924
f283489458_390.returns.push(o0);
// 4925
o0["0"] = o11;
// undefined
o0 = null;
// 4932
o0 = {};
// 4933
f283489458_390.returns.push(o0);
// 4934
o0["0"] = o12;
// undefined
o0 = null;
// 4945
o0 = {};
// 4946
f283489458_390.returns.push(o0);
// 4947
o0["0"] = o14;
// undefined
o0 = null;
// 4954
o0 = {};
// 4955
f283489458_390.returns.push(o0);
// 4956
o0["0"] = o15;
// undefined
o0 = null;
// 5004
o0 = {};
// 5005
f283489458_390.returns.push(o0);
// 5006
o0["0"] = o10;
// undefined
o0 = null;
// 5013
o0 = {};
// 5014
f283489458_390.returns.push(o0);
// 5015
o0["0"] = o11;
// undefined
o0 = null;
// 5022
o0 = {};
// 5023
f283489458_390.returns.push(o0);
// 5024
o0["0"] = o12;
// undefined
o0 = null;
// 5035
o0 = {};
// 5036
f283489458_390.returns.push(o0);
// 5037
o0["0"] = o14;
// undefined
o0 = null;
// 5044
o0 = {};
// 5045
f283489458_390.returns.push(o0);
// 5046
o0["0"] = o15;
// undefined
o0 = null;
// 5094
o0 = {};
// 5095
f283489458_390.returns.push(o0);
// 5096
o0["0"] = o10;
// undefined
o0 = null;
// 5103
o0 = {};
// 5104
f283489458_390.returns.push(o0);
// 5105
o0["0"] = o11;
// undefined
o0 = null;
// 5112
o0 = {};
// 5113
f283489458_390.returns.push(o0);
// 5114
o0["0"] = o12;
// undefined
o0 = null;
// 5125
o0 = {};
// 5126
f283489458_390.returns.push(o0);
// 5127
o0["0"] = o14;
// undefined
o0 = null;
// 5134
o0 = {};
// 5135
f283489458_390.returns.push(o0);
// 5136
o0["0"] = o15;
// undefined
o0 = null;
// 5184
o0 = {};
// 5185
f283489458_390.returns.push(o0);
// 5186
o0["0"] = o10;
// undefined
o0 = null;
// 5193
o0 = {};
// 5194
f283489458_390.returns.push(o0);
// 5195
o0["0"] = o11;
// undefined
o0 = null;
// 5202
o0 = {};
// 5203
f283489458_390.returns.push(o0);
// 5204
o0["0"] = o12;
// undefined
o0 = null;
// 5215
o0 = {};
// 5216
f283489458_390.returns.push(o0);
// 5217
o0["0"] = o14;
// undefined
o0 = null;
// 5224
o0 = {};
// 5225
f283489458_390.returns.push(o0);
// 5226
o0["0"] = o15;
// undefined
o0 = null;
// 5274
o0 = {};
// 5275
f283489458_390.returns.push(o0);
// 5276
o0["0"] = o10;
// undefined
o0 = null;
// 5283
o0 = {};
// 5284
f283489458_390.returns.push(o0);
// 5285
o0["0"] = o11;
// undefined
o0 = null;
// 5292
o0 = {};
// 5293
f283489458_390.returns.push(o0);
// 5294
o0["0"] = o12;
// undefined
o0 = null;
// 5305
o0 = {};
// 5306
f283489458_390.returns.push(o0);
// 5307
o0["0"] = o14;
// undefined
o0 = null;
// 5314
o0 = {};
// 5315
f283489458_390.returns.push(o0);
// 5316
o0["0"] = o15;
// undefined
o0 = null;
// 5364
o0 = {};
// 5365
f283489458_390.returns.push(o0);
// 5366
o0["0"] = o10;
// undefined
o0 = null;
// 5373
o0 = {};
// 5374
f283489458_390.returns.push(o0);
// 5375
o0["0"] = o11;
// undefined
o0 = null;
// 5382
o0 = {};
// 5383
f283489458_390.returns.push(o0);
// 5384
o0["0"] = o12;
// undefined
o0 = null;
// 5395
o0 = {};
// 5396
f283489458_390.returns.push(o0);
// 5397
o0["0"] = o14;
// undefined
o0 = null;
// 5404
o0 = {};
// 5405
f283489458_390.returns.push(o0);
// 5406
o0["0"] = o15;
// undefined
o0 = null;
// 5454
o0 = {};
// 5455
f283489458_390.returns.push(o0);
// 5456
o0["0"] = o10;
// undefined
o0 = null;
// 5463
o0 = {};
// 5464
f283489458_390.returns.push(o0);
// 5465
o0["0"] = o11;
// undefined
o0 = null;
// 5472
o0 = {};
// 5473
f283489458_390.returns.push(o0);
// 5474
o0["0"] = o12;
// undefined
o0 = null;
// 5485
o0 = {};
// 5486
f283489458_390.returns.push(o0);
// 5487
o0["0"] = o14;
// undefined
o0 = null;
// 5494
o0 = {};
// 5495
f283489458_390.returns.push(o0);
// 5496
o0["0"] = o15;
// undefined
o0 = null;
// 5544
o0 = {};
// 5545
f283489458_390.returns.push(o0);
// 5546
o0["0"] = o10;
// undefined
o0 = null;
// 5553
o0 = {};
// 5554
f283489458_390.returns.push(o0);
// 5555
o0["0"] = o11;
// undefined
o0 = null;
// 5562
o0 = {};
// 5563
f283489458_390.returns.push(o0);
// 5564
o0["0"] = o12;
// undefined
o0 = null;
// 5575
o0 = {};
// 5576
f283489458_390.returns.push(o0);
// 5577
o0["0"] = o14;
// undefined
o0 = null;
// 5584
o0 = {};
// 5585
f283489458_390.returns.push(o0);
// 5586
o0["0"] = o15;
// undefined
o0 = null;
// 5634
o0 = {};
// 5635
f283489458_390.returns.push(o0);
// 5636
o0["0"] = o10;
// undefined
o0 = null;
// 5643
o0 = {};
// 5644
f283489458_390.returns.push(o0);
// 5645
o0["0"] = o11;
// undefined
o0 = null;
// 5652
o0 = {};
// 5653
f283489458_390.returns.push(o0);
// 5654
o0["0"] = o12;
// undefined
o0 = null;
// 5665
o0 = {};
// 5666
f283489458_390.returns.push(o0);
// 5667
o0["0"] = o14;
// undefined
o0 = null;
// 5674
o0 = {};
// 5675
f283489458_390.returns.push(o0);
// 5676
o0["0"] = o15;
// undefined
o0 = null;
// 5724
o0 = {};
// 5725
f283489458_390.returns.push(o0);
// 5726
o0["0"] = o10;
// undefined
o0 = null;
// 5733
o0 = {};
// 5734
f283489458_390.returns.push(o0);
// 5735
o0["0"] = o11;
// undefined
o0 = null;
// 5742
o0 = {};
// 5743
f283489458_390.returns.push(o0);
// 5744
o0["0"] = o12;
// undefined
o0 = null;
// 5755
o0 = {};
// 5756
f283489458_390.returns.push(o0);
// 5757
o0["0"] = o14;
// undefined
o0 = null;
// 5764
o0 = {};
// 5765
f283489458_390.returns.push(o0);
// 5766
o0["0"] = o15;
// undefined
o0 = null;
// 5814
o0 = {};
// 5815
f283489458_390.returns.push(o0);
// 5816
o0["0"] = o10;
// undefined
o0 = null;
// 5823
o0 = {};
// 5824
f283489458_390.returns.push(o0);
// 5825
o0["0"] = o11;
// undefined
o0 = null;
// 5832
o0 = {};
// 5833
f283489458_390.returns.push(o0);
// 5834
o0["0"] = o12;
// undefined
o0 = null;
// 5845
o0 = {};
// 5846
f283489458_390.returns.push(o0);
// 5847
o0["0"] = o14;
// undefined
o0 = null;
// 5854
o0 = {};
// 5855
f283489458_390.returns.push(o0);
// 5856
o0["0"] = o15;
// undefined
o0 = null;
// 5904
o0 = {};
// 5905
f283489458_390.returns.push(o0);
// 5906
o0["0"] = o10;
// undefined
o0 = null;
// 5913
o0 = {};
// 5914
f283489458_390.returns.push(o0);
// 5915
o0["0"] = o11;
// undefined
o0 = null;
// 5922
o0 = {};
// 5923
f283489458_390.returns.push(o0);
// 5924
o0["0"] = o12;
// undefined
o0 = null;
// 5935
o0 = {};
// 5936
f283489458_390.returns.push(o0);
// 5937
o0["0"] = o14;
// undefined
o0 = null;
// 5944
o0 = {};
// 5945
f283489458_390.returns.push(o0);
// 5946
o0["0"] = o15;
// undefined
o0 = null;
// 5994
o0 = {};
// 5995
f283489458_390.returns.push(o0);
// 5996
o0["0"] = o10;
// undefined
o0 = null;
// 6003
o0 = {};
// 6004
f283489458_390.returns.push(o0);
// 6005
o0["0"] = o11;
// undefined
o0 = null;
// 6012
o0 = {};
// 6013
f283489458_390.returns.push(o0);
// 6014
o0["0"] = o12;
// undefined
o0 = null;
// 6025
o0 = {};
// 6026
f283489458_390.returns.push(o0);
// 6027
o0["0"] = o14;
// undefined
o0 = null;
// 6034
o0 = {};
// 6035
f283489458_390.returns.push(o0);
// 6036
o0["0"] = o15;
// undefined
o0 = null;
// 6084
o0 = {};
// 6085
f283489458_390.returns.push(o0);
// 6086
o0["0"] = o10;
// undefined
o0 = null;
// 6093
o0 = {};
// 6094
f283489458_390.returns.push(o0);
// 6095
o0["0"] = o11;
// undefined
o0 = null;
// 6102
o0 = {};
// 6103
f283489458_390.returns.push(o0);
// 6104
o0["0"] = o12;
// undefined
o0 = null;
// 6115
o0 = {};
// 6116
f283489458_390.returns.push(o0);
// 6117
o0["0"] = o14;
// undefined
o0 = null;
// 6124
o0 = {};
// 6125
f283489458_390.returns.push(o0);
// 6126
o0["0"] = o15;
// undefined
o0 = null;
// 6174
o0 = {};
// 6175
f283489458_390.returns.push(o0);
// 6176
o0["0"] = o10;
// undefined
o0 = null;
// 6183
o0 = {};
// 6184
f283489458_390.returns.push(o0);
// 6185
o0["0"] = o11;
// undefined
o0 = null;
// 6192
o0 = {};
// 6193
f283489458_390.returns.push(o0);
// 6194
o0["0"] = o12;
// undefined
o0 = null;
// 6205
o0 = {};
// 6206
f283489458_390.returns.push(o0);
// 6207
o0["0"] = o14;
// undefined
o0 = null;
// 6214
o0 = {};
// 6215
f283489458_390.returns.push(o0);
// 6216
o0["0"] = o15;
// undefined
o0 = null;
// 6264
o0 = {};
// 6265
f283489458_390.returns.push(o0);
// 6266
o0["0"] = o10;
// undefined
o0 = null;
// 6273
o0 = {};
// 6274
f283489458_390.returns.push(o0);
// 6275
o0["0"] = o11;
// undefined
o0 = null;
// 6282
o0 = {};
// 6283
f283489458_390.returns.push(o0);
// 6284
o0["0"] = o12;
// undefined
o0 = null;
// 6295
o0 = {};
// 6296
f283489458_390.returns.push(o0);
// 6297
o0["0"] = o14;
// undefined
o0 = null;
// 6304
o0 = {};
// 6305
f283489458_390.returns.push(o0);
// 6306
o0["0"] = o15;
// undefined
o0 = null;
// 6354
o0 = {};
// 6355
f283489458_390.returns.push(o0);
// 6356
o0["0"] = o10;
// undefined
o0 = null;
// 6363
o0 = {};
// 6364
f283489458_390.returns.push(o0);
// 6365
o0["0"] = o11;
// undefined
o0 = null;
// 6372
o0 = {};
// 6373
f283489458_390.returns.push(o0);
// 6374
o0["0"] = o12;
// undefined
o0 = null;
// 6385
o0 = {};
// 6386
f283489458_390.returns.push(o0);
// 6387
o0["0"] = o14;
// undefined
o0 = null;
// 6394
o0 = {};
// 6395
f283489458_390.returns.push(o0);
// 6396
o0["0"] = o15;
// undefined
o0 = null;
// 6444
o0 = {};
// 6445
f283489458_390.returns.push(o0);
// 6446
o0["0"] = o10;
// undefined
o0 = null;
// 6453
o0 = {};
// 6454
f283489458_390.returns.push(o0);
// 6455
o0["0"] = o11;
// undefined
o0 = null;
// 6462
o0 = {};
// 6463
f283489458_390.returns.push(o0);
// 6464
o0["0"] = o12;
// undefined
o0 = null;
// 6475
o0 = {};
// 6476
f283489458_390.returns.push(o0);
// 6477
o0["0"] = o14;
// undefined
o0 = null;
// 6484
o0 = {};
// 6485
f283489458_390.returns.push(o0);
// 6486
o0["0"] = o15;
// undefined
o0 = null;
// 6534
o0 = {};
// 6535
f283489458_390.returns.push(o0);
// 6536
o0["0"] = o10;
// undefined
o0 = null;
// 6543
o0 = {};
// 6544
f283489458_390.returns.push(o0);
// 6545
o0["0"] = o11;
// undefined
o0 = null;
// 6552
o0 = {};
// 6553
f283489458_390.returns.push(o0);
// 6554
o0["0"] = o12;
// undefined
o0 = null;
// 6565
o0 = {};
// 6566
f283489458_390.returns.push(o0);
// 6567
o0["0"] = o14;
// undefined
o0 = null;
// 6574
o0 = {};
// 6575
f283489458_390.returns.push(o0);
// 6576
o0["0"] = o15;
// undefined
o0 = null;
// 6624
o0 = {};
// 6625
f283489458_390.returns.push(o0);
// 6626
o0["0"] = o10;
// undefined
o0 = null;
// 6633
o0 = {};
// 6634
f283489458_390.returns.push(o0);
// 6635
o0["0"] = o11;
// undefined
o0 = null;
// 6642
o0 = {};
// 6643
f283489458_390.returns.push(o0);
// 6644
o0["0"] = o12;
// undefined
o0 = null;
// 6655
o0 = {};
// 6656
f283489458_390.returns.push(o0);
// 6657
o0["0"] = o14;
// undefined
o0 = null;
// 6664
o0 = {};
// 6665
f283489458_390.returns.push(o0);
// 6666
o0["0"] = o15;
// undefined
o0 = null;
// 6714
o0 = {};
// 6715
f283489458_390.returns.push(o0);
// 6716
o0["0"] = o10;
// undefined
o0 = null;
// 6723
o0 = {};
// 6724
f283489458_390.returns.push(o0);
// 6725
o0["0"] = o11;
// undefined
o0 = null;
// 6732
o0 = {};
// 6733
f283489458_390.returns.push(o0);
// 6734
o0["0"] = o12;
// undefined
o0 = null;
// 6745
o0 = {};
// 6746
f283489458_390.returns.push(o0);
// 6747
o0["0"] = o14;
// undefined
o0 = null;
// 6754
o0 = {};
// 6755
f283489458_390.returns.push(o0);
// 6756
o0["0"] = o15;
// undefined
o0 = null;
// 6804
o0 = {};
// 6805
f283489458_390.returns.push(o0);
// 6806
o0["0"] = o10;
// undefined
o0 = null;
// 6813
o0 = {};
// 6814
f283489458_390.returns.push(o0);
// 6815
o0["0"] = o11;
// undefined
o0 = null;
// 6822
o0 = {};
// 6823
f283489458_390.returns.push(o0);
// 6824
o0["0"] = o12;
// undefined
o0 = null;
// 6835
o0 = {};
// 6836
f283489458_390.returns.push(o0);
// 6837
o0["0"] = o14;
// undefined
o0 = null;
// 6844
o0 = {};
// 6845
f283489458_390.returns.push(o0);
// 6846
o0["0"] = o15;
// undefined
o0 = null;
// 6894
o0 = {};
// 6895
f283489458_390.returns.push(o0);
// 6896
o0["0"] = o10;
// undefined
o0 = null;
// 6903
o0 = {};
// 6904
f283489458_390.returns.push(o0);
// 6905
o0["0"] = o11;
// undefined
o0 = null;
// 6912
o0 = {};
// 6913
f283489458_390.returns.push(o0);
// 6914
o0["0"] = o12;
// undefined
o0 = null;
// 6925
o0 = {};
// 6926
f283489458_390.returns.push(o0);
// 6927
o0["0"] = o14;
// undefined
o0 = null;
// 6934
o0 = {};
// 6935
f283489458_390.returns.push(o0);
// 6936
o0["0"] = o15;
// undefined
o0 = null;
// 6984
o0 = {};
// 6985
f283489458_390.returns.push(o0);
// 6986
o0["0"] = o10;
// undefined
o0 = null;
// 6993
o0 = {};
// 6994
f283489458_390.returns.push(o0);
// 6995
o0["0"] = o11;
// undefined
o0 = null;
// 7002
o0 = {};
// 7003
f283489458_390.returns.push(o0);
// 7004
o0["0"] = o12;
// undefined
o0 = null;
// 7015
o0 = {};
// 7016
f283489458_390.returns.push(o0);
// 7017
o0["0"] = o14;
// undefined
o0 = null;
// 7024
o0 = {};
// 7025
f283489458_390.returns.push(o0);
// 7026
o0["0"] = o15;
// undefined
o0 = null;
// 7074
o0 = {};
// 7075
f283489458_390.returns.push(o0);
// 7076
o0["0"] = o10;
// undefined
o0 = null;
// 7083
o0 = {};
// 7084
f283489458_390.returns.push(o0);
// 7085
o0["0"] = o11;
// undefined
o0 = null;
// 7092
o0 = {};
// 7093
f283489458_390.returns.push(o0);
// 7094
o0["0"] = o12;
// undefined
o0 = null;
// 7105
o0 = {};
// 7106
f283489458_390.returns.push(o0);
// 7107
o0["0"] = o14;
// undefined
o0 = null;
// 7114
o0 = {};
// 7115
f283489458_390.returns.push(o0);
// 7116
o0["0"] = o15;
// undefined
o0 = null;
// 7164
o0 = {};
// 7165
f283489458_390.returns.push(o0);
// 7166
o0["0"] = o10;
// undefined
o0 = null;
// 7173
o0 = {};
// 7174
f283489458_390.returns.push(o0);
// 7175
o0["0"] = o11;
// undefined
o0 = null;
// 7182
o0 = {};
// 7183
f283489458_390.returns.push(o0);
// 7184
o0["0"] = o12;
// undefined
o0 = null;
// 7195
o0 = {};
// 7196
f283489458_390.returns.push(o0);
// 7197
o0["0"] = o14;
// undefined
o0 = null;
// 7204
o0 = {};
// 7205
f283489458_390.returns.push(o0);
// 7206
o0["0"] = o15;
// undefined
o0 = null;
// 7254
o0 = {};
// 7255
f283489458_390.returns.push(o0);
// 7256
o0["0"] = o10;
// undefined
o0 = null;
// 7263
o0 = {};
// 7264
f283489458_390.returns.push(o0);
// 7265
o0["0"] = o11;
// undefined
o0 = null;
// 7272
o0 = {};
// 7273
f283489458_390.returns.push(o0);
// 7274
o0["0"] = o12;
// undefined
o0 = null;
// 7285
o0 = {};
// 7286
f283489458_390.returns.push(o0);
// 7287
o0["0"] = o14;
// undefined
o0 = null;
// 7294
o0 = {};
// 7295
f283489458_390.returns.push(o0);
// 7296
o0["0"] = o15;
// undefined
o0 = null;
// 7344
o0 = {};
// 7345
f283489458_390.returns.push(o0);
// 7346
o0["0"] = o10;
// undefined
o0 = null;
// 7353
o0 = {};
// 7354
f283489458_390.returns.push(o0);
// 7355
o0["0"] = o11;
// undefined
o0 = null;
// 7362
o0 = {};
// 7363
f283489458_390.returns.push(o0);
// 7364
o0["0"] = o12;
// undefined
o0 = null;
// 7375
o0 = {};
// 7376
f283489458_390.returns.push(o0);
// 7377
o0["0"] = o14;
// undefined
o0 = null;
// 7384
o0 = {};
// 7385
f283489458_390.returns.push(o0);
// 7386
o0["0"] = o15;
// undefined
o0 = null;
// 7434
o0 = {};
// 7435
f283489458_390.returns.push(o0);
// 7436
o0["0"] = o10;
// undefined
o0 = null;
// 7443
o0 = {};
// 7444
f283489458_390.returns.push(o0);
// 7445
o0["0"] = o11;
// undefined
o0 = null;
// 7452
o0 = {};
// 7453
f283489458_390.returns.push(o0);
// 7454
o0["0"] = o12;
// undefined
o0 = null;
// 7465
o0 = {};
// 7466
f283489458_390.returns.push(o0);
// 7467
o0["0"] = o14;
// undefined
o0 = null;
// 7474
o0 = {};
// 7475
f283489458_390.returns.push(o0);
// 7476
o0["0"] = o15;
// undefined
o0 = null;
// 7524
o0 = {};
// 7525
f283489458_390.returns.push(o0);
// 7526
o0["0"] = o10;
// undefined
o0 = null;
// undefined
o10 = null;
// 7533
o0 = {};
// 7534
f283489458_390.returns.push(o0);
// 7535
o0["0"] = o11;
// undefined
o0 = null;
// undefined
o11 = null;
// 7542
o0 = {};
// 7543
f283489458_390.returns.push(o0);
// 7544
o0["0"] = o12;
// undefined
o0 = null;
// undefined
o12 = null;
// 7555
o0 = {};
// 7556
f283489458_390.returns.push(o0);
// 7557
o0["0"] = o14;
// undefined
o0 = null;
// undefined
o14 = null;
// 7564
o0 = {};
// 7565
f283489458_390.returns.push(o0);
// 7566
o0["0"] = o15;
// undefined
o0 = null;
// undefined
o15 = null;
// 7602
// 0
JSBNG_Replay$ = function(real, cb) { if (!real) return;
// 1539
ow283489458.JSBNG_Replay_geval("JSBNG__document.domain = \"twitter.com\";\nJSBNG__document.startTime = new JSBNG__Date().getTime();\nvar twttr = {\n};\ntwttr.versionName = \"phoenix\";\ntwttr.isT1 = true;\ntwttr.didPingKeynote = false;\ntwttr.keynoteTTFTPing = function() {\n    if (((!twttr.didPingKeynote && ((window.JSBNG__location.href.indexOf(\"keynoteTest\") > 0))))) {\n        var image = JSBNG__document.createElement(\"img\");\n        image.src = \"/images/keynote.gif\";\n        twttr.didPingKeynote = true;\n    }\n;\n;\n};\n((window.JSBNG__console || function() {\n    var a = [\"log\",\"debug\",\"info\",\"warn\",\"error\",\"assert\",\"dir\",\"dirxml\",\"group\",\"groupEnd\",\"time\",\"timeEnd\",\"count\",\"trace\",\"profile\",\"profileEnd\",];\n    window.JSBNG__console = {\n    };\n    for (var b = 0; ((b < a.length)); ++b) {\n        window.JSBNG__console[a[b]] = function() {\n        \n        };\n    ;\n    };\n;\n}()));\ntwttr.griffin = {\n    current: [\"euro2012\",\"olympics\",\"nascar\",]\n};\ntwttr.griffin.euroTerms = [];\n((twttr.griffin || (twttr.griffin = {\n    current: []\n}))), twttr.griffin.isEvent = function(a) {\n    if (!a) {\n        return !1;\n    }\n;\n;\n    a = a.replace(/^#|\\/$/g, \"\").toLowerCase();\n    for (var b = 0; ((b < twttr.griffin.current.length)); b++) {\n        if (((a == twttr.griffin.current[b]))) {\n            return a;\n        }\n    ;\n    ;\n    };\n;\n    return !1;\n}, twttr.griffin.redirectIfEvent = function(a, b) {\n    var a = twttr.griffin.isEvent(a);\n    if (a) {\n        var c = ((JSBNG__document.referrer || \"none\")), d = [\"ev_\",b,\"_\",a,\"=\",c,\"; path=/\",].join(\"\");\n        return JSBNG__document.cookie = d, window.JSBNG__location.replace(((\"/hashtag/\" + a))), !0;\n    }\n;\n;\n    return !1;\n}, twttr.griffin.isEuroSearchTakeover = function(a) {\n    if (((!twttr.griffin.euroTerms || !a))) {\n        return !1;\n    }\n;\n;\n    ((((a && ((a.substr(0, 1) == \"#\")))) && (a = a.substr(1)))), a = a.toLowerCase();\n    for (var b = 0; ((b < twttr.griffin.euroTerms.length)); b++) {\n        if (((a == twttr.griffin.euroTerms[b]))) {\n            return !0;\n        }\n    ;\n    ;\n    };\n;\n    return !1;\n}, twttr.griffin.redirectOnSearch = function(a) {\n    return (($.cookie(((\"noReroute_\" + a))) ? !1 : twttr.griffin.redirectIfEvent(a, \"takeover\")));\n}, twttr.griffin.setNoRedirectOnSearch = function(a, b) {\n    if (!twttr.griffin.isEvent(a)) {\n        return;\n    }\n;\n;\n    var c = ((b ? !0 : null));\n    $.cookie(((\"noReroute_\" + a)), c);\n};\nif (((((window.JSBNG__location.pathname == \"/\")) && ((window.JSBNG__location.hash != \"\"))))) {\n    var hash = window.JSBNG__location.hash.substr(1).toLowerCase();\n    twttr.griffin.redirectIfEvent(hash, \"redir\");\n}\n;\n;\n;");
// 1550
ow283489458.JSBNG_Replay_geval("(function() {\n    window.JSBNG__setTimeout = window.JSBNG__setTimeout, window.JSBNG__setInterval = window.JSBNG__setInterval, window.WATCH = function(a, b) {\n        ((((typeof b == \"undefined\")) && (b = a, a = undefined))), ((((typeof a == \"string\")) && (WATCH._didExecute[a] = !0))), WATCH._attempt(this, b);\n    }, WATCH._didExecute = {\n    }, WATCH._reportCount = 0, WATCH._reportLimit = 25, WATCH._reportInterval = 60000, WATCH._active = !1, WATCH.activate = function(a) {\n        ((((typeof a == \"undefined\")) && (a = !0))), WATCH._active = a, extend(WATCH, ((WATCH._active ? WATCH.actives : WATCH.inactives)));\n    }, WATCH.actives = {\n    }, WATCH.inactives = {\n    };\n    var extend = function(a, b) {\n        for (var c in b) {\n            a[c] = b[c];\n        ;\n        };\n    ;\n    }, noop = function() {\n    \n    };\n    WATCH._attempt = function(a, b) {\n        ((((arguments.length < 2)) && (b = a, a = window)));\n        if (WATCH._active) {\n            try {\n                b.apply(a);\n            } catch (c) {\n                WATCH._triggerError(c);\n            };\n        }\n         else {\n            b.apply(a);\n        }\n    ;\n    ;\n    }, WATCH.inactives.end = noop, WATCH.actives.end = function(a) {\n        if (((typeof a == \"undefined\"))) {\n            throw new Error(\"WATCH.end() requires a label\");\n        }\n    ;\n    ;\n        ((WATCH._didExecute[a] ? WATCH._didExecute[a] = !1 : ((WATCH._active && WATCH._triggerError(new Error(((((((((\"WATCH.end(\\\"\" + a)) + \"\\\") called without successful call to WATCH(\\\"\")) + a)) + \"\\\", fn(){...}) - a SyntaxError probably just happened\")))))))), WATCH._didExecute[a] = !1;\n    }, WATCH.inactives.callback = function(a, b) {\n        return ((((typeof b == \"undefined\")) ? a : b));\n    }, WATCH.actives.callback = function(that, callback) {\n        ((((arguments.length === 1)) && (callback = that, that = this))), ((((typeof callback == \"string\")) && (callback = function(stringVersion) {\n            return function() {\n                eval(stringVersion);\n            };\n        }(callback))));\n        var watchedCallback = function() {\n            var a = this, b = arguments, c;\n            return WATCH._attempt(function() {\n                c = callback.apply(a, b);\n            }), c;\n        };\n        return watchedCallback.isWatched = !0, watchedCallback;\n    }, WATCH._onErrorCallbacks = {\n    }, WATCH.inactives._addOnError = noop, WATCH.actives._addOnError = function(a) {\n        var b = WATCH._unique();\n        return WATCH._onErrorCallbacks[b] = a, b;\n    }, WATCH.inactives._removeOnError = noop, WATCH.actives._removeOnError = function(a) {\n        delete WATCH._onErrorCallbacks[a];\n    }, WATCH._lastUnique = -1, WATCH._unique = function() {\n        return ++WATCH._lastUnique;\n    }, WATCH.inactives.jQuery = noop, WATCH.actives.jQuery = function() {\n        WATCH._originalJQueryEventAdd = ((WATCH._originalJQueryEventAdd || jQuery.JSBNG__event.add)), jQuery.JSBNG__event.add = function() {\n            var a = Array.prototype.slice.call(arguments);\n            return ((((typeof a[2] == \"function\")) ? a[2] = WATCH.callback(a[2]) : ((((((a && ((typeof a[2] == \"object\")))) && a[2].handler)) && (a[2].handler = WATCH.callback(a[2].handler)))))), WATCH._originalJQueryEventAdd.apply(this, a);\n        }, WATCH._originalJQueryAjax = ((WATCH._originalJQueryAjax || jQuery.ajax)), jQuery.ajax = function(a) {\n            return jQuery.each([\"complete\",\"error\",\"success\",], function(b, c) {\n                if (!a[c]) {\n                    return;\n                }\n            ;\n            ;\n                a[c] = WATCH.callback(a[c]);\n            }), WATCH._originalJQueryAjax.apply(this, arguments);\n        };\n    }, WATCH.inactives.undoJQuery = noop, WATCH.actives.undoJQuery = function() {\n        jQuery.JSBNG__event.add = WATCH._originalJQueryEventAdd, jQuery.ajax = WATCH._originalJQueryAjax;\n    }, WATCH._previousErrors = {\n    };\n    var escapeDoubleQuotes = function(a) {\n        return a.toString().replace(\"\\\"\", \"\\\\\\\"\");\n    }, stringifyLite = function(a) {\n        var b = \"{\", c = !1;\n        for (var d in a) {\n            if (((((typeof a[d] == \"undefined\")) || ((a[d] === null))))) {\n                continue;\n            }\n        ;\n        ;\n            b += ((((((((((c ? \",\\\"\" : \"\\\"\")) + escapeDoubleQuotes(d))) + \"\\\":\\\"\")) + escapeDoubleQuotes(a[d]))) + \"\\\"\")), c = !0;\n        };\n    ;\n        return ((b + \"}\"));\n    };\n    WATCH._scribeError = function(a) {\n        if (((WATCH._previousErrors[a.error] && ((((new JSBNG__Date - WATCH._previousErrors[a.error])) < WATCH._reportInterval))))) {\n            return !1;\n        }\n    ;\n    ;\n        if (((WATCH.reportLimit <= WATCH.reportCount))) {\n            return;\n        }\n    ;\n    ;\n        WATCH.reportCount++;\n        if (!JSBNG__document.JSBNG__location.hostname.match(/(^(www|api)\\.)?twitter\\.com$/)) {\n            return;\n        }\n    ;\n    ;\n        WATCH._previousErrors[a.error] = new JSBNG__Date, a.product_name = \"webclient\", a.type = \"js_error\", a.url = window.JSBNG__location.href, a.event_name = \"test\";\n        var b = ((JSBNG__document.JSBNG__location.hostname.match(/(^(www|api|staging\\d+.local)\\.)twitter\\.com$/) != null)), c = ((b ? \"scribe.twitter.com\" : window.JSBNG__location.host)), d = ((((((window.JSBNG__location.protocol.match(/s\\:$/) ? \"https\" : \"http\")) + \"://\")) + c));\n        d += ((b ? \"/\" : \"/scribe\")), d += ((((((\"?category=client_watch_error&log=\" + encodeURIComponent(stringifyLite(a)))) + \"&ts=\")) + (new JSBNG__Date).getTime())), (new JSBNG__Image).src = d;\n    }, WATCH._triggerError = function(a) {\n        var b = !0, c = {\n            error: a\n        };\n        for (var d in WATCH._onErrorCallbacks) {\n            try {\n                ((((WATCH._onErrorCallbacks[d](c) === !1)) && (b = !1)));\n            } catch (e) {\n                c.callbackFailure = !0;\n            };\n        ;\n        };\n    ;\n        WATCH._scribeError(c);\n        if (b) {\n            throw a;\n        }\n    ;\n    ;\n    }, WATCH.inactives.natives = noop, WATCH.actives.natives = function() {\n        window.JSBNG__setInterval = WATCH._watchedSetInterval, window.JSBNG__setTimeout = WATCH._watchedSetTimeout;\n    }, WATCH.inactives.undoNatives = noop, WATCH.actives.undoNatives = function() {\n        window.JSBNG__setInterval = WATCH._originalSetInterval, window.JSBNG__setTimeout = WATCH._originalSetTimeout;\n    }, WATCH._originalSetInterval = window.JSBNG__setInterval, WATCH._originalSetTimeout = window.JSBNG__setTimeout, WATCH._watchedSetInterval = function(a, b) {\n        var c = WATCH._originalSetInterval;\n        return c(WATCH.callback(a), b);\n    }, WATCH._watchedSetTimeout = function(a, b) {\n        var c = WATCH._originalSetTimeout;\n        return c(WATCH.callback(a), b);\n    }, WATCH.activate(!1);\n})();");
// 1551
ow283489458.JSBNG_Replay_geval("");
// 1552
ow283489458.JSBNG_Replay_geval("function bust() {\n    JSBNG__document.write = \"\";\n    window.JSBNG__top.JSBNG__location = window.JSBNG__self.JSBNG__location;\n    JSBNG__setTimeout(function() {\n        JSBNG__document.body.innerHTML = \"\";\n    }, 0);\n    window.JSBNG__self.JSBNG__onload = function(evt) {\n        JSBNG__document.body.innerHTML = \"\";\n    };\n};\n;\nif (((window.JSBNG__top !== window.JSBNG__self))) {\n    try {\n        if (window.JSBNG__top.JSBNG__location.host) {\n        \n        }\n         else {\n            bust();\n        }\n    ;\n    ;\n    } catch (ex) {\n        bust();\n    };\n;\n}\n;\n;");
// 1553
ow283489458.JSBNG_Replay_geval("(function() {\n    var a = JSBNG__document.getElementsByTagName(\"html\")[0], b = window.JSBNG__location.hash.split(\"?\")[0], c = ((b.match(/#/) && ((b.replace(/#[!]?[\\/]?/, \"\") !== \"\"))));\n    ((c ? a.className += \" remove-prerendered-content\" : (a.className += \" use-prerendered-content\", ((a.getAttribute(\"data-nav-highlight-class-name\") && (a.className += ((\" \" + a.getAttribute(\"data-nav-highlight-class-name\")))))))));\n})();");
// 1563
ow283489458.JSBNG_Replay_geval("var _gaq = ((_gaq || []));\n_gaq.push([\"_setAccount\",\"UA-30775-6\",], [\"_trackPageview\",], [\"_setDomainName\",\"twitter.com\",]), twttr.didInsertGA = !1, twttr.insertGAScriptElement = function() {\n    if (!twttr.didInsertGA) {\n        var a = JSBNG__document.getElementsByTagName(\"script\")[0], b = JSBNG__document.createElement(\"script\");\n        b.async = !0, b.src = ((((((JSBNG__document.JSBNG__location.protocol == \"https:\")) ? \"http://jsbngssl.ssl\" : \"http://www\")) + \".google-analytics.com/ga.js\")), a.parentNode.insertBefore(b, a), twttr.didInsertGA = !0;\n    }\n;\n;\n}, twttr.trackPageView = function(a) {\n    var b = [\"_trackPageview\",];\n    ((a && b.push(a))), _gaq.push(b);\n};");
// 1564
ow283489458.JSBNG_Replay_geval("WATCH(\"loadrunner\", function() {\n    (function(a, b) {\n        function u(a) {\n            for (var b = 1, c; c = arguments[b]; b++) {\n                for (var d in c) {\n                    a[d] = c[d];\n                ;\n                };\n            ;\n            };\n        ;\n            return a;\n        };\n    ;\n        function v(a) {\n            return Array.prototype.slice.call(a);\n        };\n    ;\n        function x(a, b) {\n            for (var c = 0, d; d = a[c]; c++) {\n                if (((b == d))) {\n                    return c;\n                }\n            ;\n            ;\n            };\n        ;\n            return -1;\n        };\n    ;\n        function y() {\n            var a = v(arguments), b = [];\n            for (var c = 0, d = a.length; ((c < d)); c++) {\n                ((((a[c].length > 0)) && b.push(a[c].replace(/\\/$/, \"\"))));\n            ;\n            };\n        ;\n            return b.join(\"/\");\n        };\n    ;\n        function z(a, b, c) {\n            var d = b.split(\"/\"), e = a;\n            while (((d.length > 1))) {\n                var f = d.shift();\n                e = e[f] = ((e[f] || {\n                }));\n            };\n        ;\n            e[d[0]] = c;\n        };\n    ;\n        function A() {\n        \n        };\n    ;\n        function B(a, b) {\n            ((a && (this.id = this.path = this.resolvePath(a)))), this.force = !!b;\n        };\n    ;\n        function C(a, b) {\n            this.id = a, this.body = b, ((((typeof b == \"undefined\")) && (this.path = this.resolvePath(a))));\n        };\n    ;\n        function D(a) {\n            var b = [];\n            for (var c = 0, d; d = a[c]; c++) {\n                ((((d instanceof F)) ? b = b.concat(D(d.deps)) : ((((d instanceof C)) && b.push(d)))));\n            ;\n            };\n        ;\n            return b;\n        };\n    ;\n        function E(a) {\n            this.deps = a, ((((this.deps.length == 0)) && this.complete()));\n        };\n    ;\n        function F(a) {\n            this.deps = a;\n        };\n    ;\n        function G() {\n            for (var a in d) {\n                if (((d[a].readyState == \"interactive\"))) {\n                    return m[d[a].id];\n                }\n            ;\n            ;\n            };\n        ;\n        };\n    ;\n        function H(a, b) {\n            var d;\n            return ((((!a && c)) && (d = ((l || G()))))), ((d ? (delete m[d.scriptId], d.body = b, d.execute()) : (k = d = new C(a, b), j[d.id] = d))), d;\n        };\n    ;\n        function I() {\n            var a = v(arguments), b, c;\n            return ((((typeof a[0] == \"string\")) && (b = a.shift()))), c = a.shift(), H(b, c);\n        };\n    ;\n        function J(a, b) {\n            var c = ((b.id || \"\")), d = c.split(\"/\");\n            d.pop();\n            var e = d.join(\"/\");\n            return a.replace(/^\\./, e);\n        };\n    ;\n        function K(a, b) {\n            function d(a) {\n                return C.exports[J(a, b)];\n            };\n        ;\n            var c = [];\n            for (var e = 0, f = a.length; ((e < f)); e++) {\n                if (((a[e] == \"require\"))) {\n                    c.push(d);\n                    continue;\n                }\n            ;\n            ;\n                if (((a[e] == \"exports\"))) {\n                    b.exports = ((b.exports || {\n                    })), c.push(b.exports);\n                    continue;\n                }\n            ;\n            ;\n                c.push(d(a[e]));\n            };\n        ;\n            return c;\n        };\n    ;\n        function L() {\n            var a = v(arguments), b = [], c, d;\n            ((((typeof a[0] == \"string\")) && (c = a.shift()))), ((w(a[0]) && (b = a.shift()))), d = a.shift();\n            var e = H(c, function(a) {\n                function f() {\n                    var c = K(v(b), e), f;\n                    ((((typeof d == \"function\")) ? f = d.apply(e, c) : f = d)), ((((typeof f == \"undefined\")) && (f = e.exports))), a(f);\n                };\n            ;\n                var c = [];\n                for (var g = 0, i = b.length; ((g < i)); g++) {\n                    var j = b[g];\n                    ((((x([\"require\",\"exports\",], j) == -1)) && c.push(J(j, e))));\n                };\n            ;\n                ((((c.length > 0)) ? M.apply(this, c.concat(f)) : f()));\n            });\n            return e;\n        };\n    ;\n        function M() {\n            var a = v(arguments), b;\n            ((((typeof a[((a.length - 1))] == \"function\")) && (b = a.pop())));\n            var c = new E(N(a));\n            return ((b && c.then(b))), c;\n        };\n    ;\n        function N(a) {\n            var b = [];\n            for (var c = 0, d; d = a[c]; c++) {\n                ((((typeof d == \"string\")) && (d = O(d)))), ((w(d) && (d = new F(N(d))))), b.push(d);\n            ;\n            };\n        ;\n            return b;\n        };\n    ;\n        function O(a) {\n            var b, c;\n            for (var d = 0, e; e = M.matchers[d]; d++) {\n                var f = e[0], g = e[1];\n                if (b = a.match(f)) {\n                    return g(a);\n                }\n            ;\n            ;\n            };\n        ;\n            throw new Error(((a + \" was not recognised by loader\")));\n        };\n    ;\n        function Q() {\n            return a.using = n, a.provide = o, a.define = p, a.loadrunner = q, P;\n        };\n    ;\n        function S(a) {\n            if (((typeof R[a] != \"undefined\"))) {\n                return R[a];\n            }\n        ;\n        ;\n            for (var b = 0; ((b < M.bundles.length)); b++) {\n                for (var c in M.bundles[b]) {\n                    if (((((c != a)) && ((x(M.bundles[b][c], a) > -1))))) {\n                        return R[a] = c, c;\n                    }\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n            return R[a] = a, a;\n        };\n    ;\n        var c = ((a.JSBNG__attachEvent && !a.JSBNG__opera)), d = b.getElementsByTagName(\"script\"), e = 0, f, g = b.createElement(\"script\"), i = {\n        }, j = {\n        }, k, l, m = {\n        }, n = a.using, o = a.provide, p = a.define, q = a.loadrunner, r = {\n        };\n        for (var s = 0, t; t = d[s]; s++) {\n            if (t.src.match(/loadrunner\\.js(\\?|#|$)/)) {\n                f = t;\n                break;\n            }\n        ;\n        ;\n        };\n    ;\n        var w = ((Array.isArray || function(a) {\n            return ((a.constructor == Array));\n        }));\n        A.prototype.then = function(b) {\n            var c = this;\n            return ((this.started || (this.started = !0, this.start()))), ((this.completed ? b.apply(a, this.results) : (this.callbacks = ((this.callbacks || [])), this.callbacks.push(b)))), this;\n        }, A.prototype.start = function() {\n        \n        }, A.prototype.complete = function() {\n            if (!this.completed) {\n                this.results = v(arguments), this.completed = !0;\n                if (this.callbacks) {\n                    for (var b = 0, c; c = this.callbacks[b]; b++) {\n                        c.apply(a, this.results);\n                    ;\n                    };\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        }, B.loaded = [], B.times = {\n        }, B.prototype = new A, B.prototype.resolvePath = function(a) {\n            return S(a);\n        }, B.prototype.start = function() {\n            var a = this, b, c;\n            return (((c = j[this.id]) ? (c.then(function() {\n                a.complete();\n            }), this) : ((((b = i[this.id]) ? b.then(function() {\n                a.loaded();\n            }) : ((((!this.force && ((x(B.loaded, this.id) > -1)))) ? this.loaded() : this.load())))), this)));\n        }, B.prototype.createScriptTag = function() {\n            var b = this, c;\n            i[this.id] = b, (((c = r[this.path]) && b.then(function() {\n                for (var a = 0, b; b = c[a]; a++) {\n                    b.complete.apply(b, arguments);\n                ;\n                };\n            ;\n            }))), this.times = {\n                start: new JSBNG__Date\n            };\n            var f = g.cloneNode(!1);\n            this.scriptId = f.id = ((\"LR\" + ++e)), f.type = \"text/javascript\", f.async = !0, f.JSBNG__onerror = function() {\n                throw new Error(((b.path + \" not loaded\")));\n            }, f.JSBNG__onreadystatechange = f.JSBNG__onload = function(c) {\n                c = ((a.JSBNG__event || c));\n                if (((((c.type == \"load\")) || ((x([\"loaded\",\"complete\",], this.readyState) > -1))))) {\n                    this.JSBNG__onreadystatechange = null, b.loaded();\n                }\n            ;\n            ;\n            }, f.src = this.path, l = this, d[0].parentNode.insertBefore(f, d[0]), l = null, m[f.id] = this;\n        }, B.prototype.queueScript = function() {\n            r[this.path] = ((r[this.path] || [])), r[this.path].push(this);\n        }, B.prototype.load = function(a) {\n            return ((((M.autoLoad || a)) ? this.createScriptTag() : this.queueScript())), this;\n        }, B.prototype.loaded = function() {\n            this.complete();\n        }, B.prototype.complete = function() {\n            ((((x(B.loaded, this.id) == -1)) && B.loaded.push(this.id))), ((this.times && (B.times[this.id] = u(this.times, {\n                end: new JSBNG__Date\n            })))), delete i[this.id], A.prototype.complete.apply(this, arguments);\n        }, C.exports = {\n        }, C.prototype = new B, C.prototype.resolvePath = function(a) {\n            return ((((S(a) != a)) ? S(a) : y(M.path, ((a + \".js\")))));\n        }, C.prototype.start = function() {\n            var a, b, c = this, d;\n            ((this.body ? this.execute() : (((a = C.exports[this.id]) ? this.exp(a) : (((b = j[this.id]) ? b.then(function(a) {\n                c.exp(a);\n            }) : (j[this.id] = this, this.load())))))));\n        }, C.prototype.loaded = function() {\n            var a, b, d = this;\n            ((c ? (((b = C.exports[this.id]) ? this.exp(b) : (((a = j[this.id]) && a.then(function(a) {\n                d.exp(a);\n            }))))) : (a = k, k = null, a.id = ((a.id || this.id)), a.then(function(a) {\n                d.exp(a);\n            }))));\n        }, C.prototype.complete = function() {\n            delete j[this.id], B.prototype.complete.apply(this, arguments);\n        }, C.prototype.execute = function() {\n            var a = this;\n            ((((typeof this.body == \"object\")) ? this.exp(this.body) : ((((typeof this.body == \"function\")) && this.body.apply(window, [function(b) {\n                a.exp(b);\n            },])))));\n        }, C.prototype.exp = function(a) {\n            ((this.times && u(this.times, {\n                eval: new JSBNG__Date\n            }))), this.complete(this.exports = C.exports[this.id] = ((a || {\n            })));\n        }, E.prototype = new A, E.prototype.start = function() {\n            function b() {\n                var b = [];\n                for (var c = 0, d; d = a.deps[c]; c++) {\n                    if (!d.completed) {\n                        return;\n                    }\n                ;\n                ;\n                    ((((d.results.length > 0)) && (b = b.concat(d.results))));\n                };\n            ;\n                a.complete.apply(a, b);\n            };\n        ;\n            var a = this;\n            for (var c = 0, d; d = this.deps[c]; c++) {\n                d.then(b);\n            ;\n            };\n        ;\n            return this;\n        }, E.prototype.load = function() {\n            for (var a = 0, b; b = this.deps[a]; a++) {\n                ((b.load && b.load(!0)));\n            ;\n            };\n        ;\n            return this;\n        }, E.prototype.as = function(a) {\n            var b = this;\n            return this.then(function() {\n                var c = D(b.deps), d = {\n                };\n                for (var e = 0, f; f = c[e]; e++) {\n                    z(d, f.id, arguments[e]);\n                ;\n                };\n            ;\n                a.apply(this, [d,].concat(v(arguments)));\n            });\n        }, F.prototype = new A, F.prototype.start = function() {\n            var a = this, b = 0, c = [];\n            return function d() {\n                var e = a.deps[b++];\n                ((e ? e.then(function(a) {\n                    ((((e.results.length > 0)) && (c = c.concat(e.results)))), d();\n                }) : a.complete.apply(a, c)));\n            }(), this;\n        }, F.prototype.load = function() {\n            var a = this, b = 0;\n            return function c() {\n                var d = a.deps[b++];\n                ((((d && d.load)) && d.load(!0).then(function() {\n                    c();\n                })));\n            }(), this;\n        }, L.amd = {\n        };\n        var P = function(a) {\n            return a(M, I, P, L);\n        };\n        P.Script = B, P.Module = C, P.Collection = E, P.Sequence = F, P.Dependency = A, P.noConflict = Q, a.loadrunner = P, a.using = M, a.provide = I, a.define = L, M.path = \"\", M.autoLoad = !0, M.bundles = [];\n        var R = {\n        };\n        M.matchers = [], M.matchers.add = function(a, b) {\n            this.unshift([a,b,]);\n        }, M.matchers.add(/(^script!|\\.js$)/, function(a) {\n            var b = new B(a.replace(/^\\$/, ((M.path.replace(/\\/$/, \"\") + \"/\"))).replace(/^script!/, \"\"), !1);\n            return b.id = a, b;\n        }), M.matchers.add(/^[a-zA-Z0-9_\\-\\/]+$/, function(a) {\n            return new C(a);\n        }), ((f && (M.path = ((((f.getAttribute(\"data-path\") || f.src.split(/loadrunner\\.js/)[0])) || \"\")), (((main = f.getAttribute(\"data-main\")) && M.apply(a, main.split(/\\s*,\\s*/)).then(function() {\n        \n        }))))));\n    })(this, JSBNG__document);\n    loadrunner(function(a, b, c, d) {\n        function e(a) {\n            this.id = this.path = a;\n        };\n    ;\n        e.inProgress = [], e.done = [], e.prototype = new c.Dependency, e.prototype.start = function() {\n            var a = this, b;\n            (((b = e.done[this.id]) ? this.complete(b.result) : (((b = e.inProgress[this.id]) ? b.then(function() {\n                a.complete(b.result);\n            }) : (e.inProgress[this.id] = this, this.load())))));\n        }, e.prototype.load = function() {\n            var a, b = this;\n            if (window.JSBNG__XMLHttpRequest) {\n                a = new window.JSBNG__XMLHttpRequest;\n            }\n             else {\n                try {\n                    a = new window.ActiveXObject(\"Microsoft.XMLHTTP\");\n                } catch (c) {\n                    return new Error(\"XHR not found.\");\n                };\n            }\n        ;\n        ;\n            a.JSBNG__onreadystatechange = ((window.top.JSBNG_Replay.push)((window.top.JSBNG_Replay.sb5d8a5a82713b77123eb5ce3609b274e45633210_74), function() {\n                ((((a.readyState == 4)) && (b.result = a.responseText, e.done[b.id] = b, delete e.inProgress[b.id], b.complete(b.result))));\n            })), a.open(\"GET\", this.path, !0), a.send(null);\n        }, a.matchers.add(/^json!/, function(a) {\n            return new e(a.substring(5));\n        });\n    });\n    loadrunner(function(a, b, c, d) {\n        function e(a) {\n            this.id = this.path = a;\n        };\n    ;\n        e.inProgress = [], e.done = [], e.prototype = new c.Dependency, e.prototype.start = function() {\n            var a = this, b;\n            (((b = e.done[this.id]) ? this.complete(b.result) : (((b = e.inProgress[this.id]) ? b.then(function() {\n                a.complete(b.result);\n            }) : (e.inProgress[this.id] = this, this.load())))));\n        }, e.prototype.load = function() {\n            var b = this;\n            a(\"lib/lazyload\", function(a) {\n                function c() {\n                    e.done[b.id] = b, delete e.inProgress[b.id], b.complete();\n                };\n            ;\n                (((($(((((\"link[href='\" + b.path)) + \"']\"))).length > 0)) ? c() : a.css(b.path, c)));\n            });\n        }, a.matchers.add(/^css!/, function(b) {\n            var c;\n            return b = b.replace(/^css!/, \"\"), c = /^(https?:)?\\/\\//.test(b), new e(b.replace(/^\\//, ((((((!c && a.cssPath)) || \"\")).replace(/\\/$/, \"\") + \"/\"))));\n        });\n    });\n    loadrunner(function(a, b, c, d) {\n        function e(a, b) {\n            for (var c = 0, d; d = a[c]; c++) {\n                if (((b == d))) {\n                    return c;\n                }\n            ;\n            ;\n            };\n        ;\n            return -1;\n        };\n    ;\n        function f(a) {\n            var b;\n            ((((a.charAt(0) == \"\\u003E\")) && (a = a.substring(1))));\n            if (b = g.inProgress[a]) {\n                b.complete(), delete g.inProgress[a];\n            }\n        ;\n        ;\n            g.done.push(a);\n        };\n    ;\n        var g = function(a) {\n            this.id = a;\n        };\n        g.inProgress = [], g.done = [], g.prototype = new c.Dependency, g.prototype.start = function() {\n            var a, b = this;\n            ((((e(g.done, this.id) != -1)) ? this.complete() : (((a = g.inProgress[this.id]) ? a.then(function() {\n                b.complete();\n            }) : g.inProgress[this.id] = this))));\n        }, a.matchers.add(/^>/, function(a) {\n            return new g(a.substring(1));\n        }), window.signal = f;\n    });\n});");
// 1604
ow283489458.JSBNG_Replay_geval("WATCH.end(\"loadrunner\");");
// 1605
ow283489458.JSBNG_Replay_geval("WATCH(\"javascript_logged_out\", function() {\n    function miniScribe(eName, more, cat) {\n        var log = [], cat = ((cat || \"client_event\")), more = ((more || {\n        }));\n        more.event_name = eName;\n        for (var k in more) {\n            log.push(((((((((\"\\\"\" + k)) + \"\\\":\\\"\")) + more[k])) + \"\\\"\")));\n        };\n    ;\n    ;\n        (new JSBNG__Image()).src = ((((((((((\"//scribe.twitter.com/scribe?category=\" + encodeURIComponent(cat))) + \"&log=\")) + encodeURIComponent(((((\"{\" + log.join(\",\"))) + \"}\"))))) + \"&ts=\")) + (+new JSBNG__Date)));\n    };\n;\n    (function() {\n        function a(a, b) {\n            var c = ((a.tagName ? a : JSBNG__document.getElementById(a)));\n            return ((b ? c.getElementsByTagName(b) : c));\n        };\n    ;\n        function b(a, b, c) {\n            for (var d = ((a.length - 1)); ((d >= 0)); d--) {\n                var e = a[d].className, f = ((e && e.match(b)));\n                ((f && c.call(a[d], f[1])));\n            };\n        ;\n        };\n    ;\n        function c(a, b) {\n            return a.className = a.className.replace(((\" \" + b)), \"\");\n        };\n    ;\n        function d(a, b) {\n            return a.className = ((((c(a, b) + \" \")) + b));\n        };\n    ;\n        function l() {\n            var a = !!JSBNG__navigator.cookieEnabled;\n            if (((((typeof JSBNG__navigator.cookieEnabled == \"undefined\")) || ((JSBNG__navigator.appName == \"Microsoft Internet Explorer\"))))) {\n                JSBNG__document.cookie = \"cookies_enabled\", a = ((JSBNG__document.cookie.indexOf(\"cookies_enabled\") != -1));\n            }\n        ;\n        ;\n            return a;\n        };\n    ;\n        function m(a) {\n            var b, c, d, e = JSBNG__document.cookie.split(\";\");\n            for (b = 0; ((b < e.length)); b++) {\n                c = e[b].substr(0, e[b].indexOf(\"=\")), d = e[b].substr(((e[b].indexOf(\"=\") + 1))), c = c.replace(/^\\s+|\\s+$/g, \"\");\n                if (((c == a))) {\n                    return unescape(d);\n                }\n            ;\n            ;\n            };\n        ;\n            return null;\n        };\n    ;\n        var e = JSBNG__document.body, f = JSBNG__document.getElementById(\"doc\"), g;\n        ((JSBNG__location.href.match(/#!\\/./) ? (((g = JSBNG__location.href.match(/#!?\\/(login|download)(\\/|$)/)) && d(f, ((\"route-\" + g[1]))))) : (c(e, \"user-style-twttr loading-body\"), d(e, \"front-page\"), ((JSBNG__document.body.className.match(/front-image-nascar/) ? miniScribe(\"web:front:::impression\", {\n            context: \"olympics\"\n        }) : miniScribe(\"web:front:::impression\", {\n            context: \"front\"\n        }))), window._scribedFrontImpression = !0)));\n        var i = a(f, \"div\"), j = \"hasome\";\n        b(i, /holding/, function() {\n            var b = this, e = a(b, \"input\")[0], f = a(b, \"span\")[0];\n            ((((e && f)) && (f.JSBNG__onclick = function() {\n                e.JSBNG__focus();\n            }, e.JSBNG__onblur = function() {\n                ((e.value.length || c(b, j)));\n            }, e.JSBNG__onkeydown = function(a) {\n                JSBNG__setTimeout(function() {\n                    ((((((a && ((a.keyCode === 8)))) || e.value.length)) ? d(b, j) : c(b, j)));\n                }, 0);\n            })));\n        }), window.JSBNG__setInterval(function() {\n            b(i, /holding/, function() {\n                var b = a(this, \"input\")[0];\n                ((((b && b.value.length)) && d(this, j)));\n            });\n        }, 1111);\n        var k = {\n            signin: \"web:front:login_callout:form:login_click\",\n            signup: \"web:front:signup_callout:form:signup_click\",\n            search: \"web:front:main:search_field:search\",\n            language: \"web:front:footer:language_selector:select\"\n        };\n        b(i, /js-front-(signin|signup|search|language)/, function(b) {\n            var c = a(this, \"form\"), d = k[b];\n            ((((c && c[0])) && (c[0].JSBNG__onsubmit = function() {\n                ((a(f).className.match(\"route-front\") || miniScribe(d)));\n            })));\n        }), ((l() || (JSBNG__document.getElementById(\"front-no-cookies-warn\").style.display = \"block\")));\n        var n = !!JSBNG__document.getElementById(\"remember_default_checked\"), o = m(\"remember_checked\"), p = ((((o == \"1\")) || ((((o == null)) && n)))), q, r = JSBNG__document.getElementsByName(\"remember_me\");\n        for (q = 0; ((q < r.length)); q++) {\n            r[q].checked = p;\n        ;\n        };\n    ;\n    })();\n});");
// 1883
ow283489458.JSBNG_Replay_geval("WATCH.end(\"javascript_logged_out\");");
// 1884
ow283489458.JSBNG_Replay_geval("WATCH(\"boot\", function() {\n    using.cssPath = \"http://a0.twimg.com/a/1345479106/\";\n    using.path = \"http://a0.twimg.com/a/1345479106/phoenix/js\";\n    using.autoLoad = false;\n    provide(\"boot/init\", function(a) {\n        function c(a) {\n            for (var b in a) {\n                ((a.hasOwnProperty(b) && (twttr[b] = a[b])));\n            ;\n            };\n        ;\n        };\n    ;\n        function d(a) {\n            ((twttr.bootTimings && twttr.bootTimings.add(\"bootstrap_data process start\"))), c(a.twttr), signal(\"\\u003Epayload\"), ((a.boomr && using(a.boomr.js).load().then(function() {\n                delete BOOMR.plugins.RT, BOOMR.init({\n                    allow_ssl: !0,\n                    autorun: !1,\n                    user_ip: twttr.remoteIP,\n                    BW: {\n                        base_url: a.boomr.base_url\n                    }\n                }), using(\"\\u003EsetupComplete\", \"util\").as(function(b) {\n                    JSBNG__setTimeout(BOOMR.page_ready, 10000), BOOMR.subscribe(\"before_beacon\", function(c) {\n                        if (!c.bw) {\n                            return;\n                        }\n                    ;\n                    ;\n                        var d = parseInt(((c.bw / 1024)), 10), e = parseInt(((((c.bw_err * 100)) / c.bw)), 10), f = parseInt(((((c.lat_err * 100)) / c.lat)), 10);\n                        scribble(\"measurement\", {\n                            load_time_ms: c.t_done,\n                            bandwidth_kbytes: d,\n                            bandwidth_error_percent: e,\n                            latency_ms: c.lat,\n                            latency_error_percent: f,\n                            product: \"webclient\",\n                            base_url: a.boomr.base_url\n                        }, \"boomerang\"), ((b.util.params().boomr && twttr.showMessage(((((((((((((((\"Bandwidth: \" + b.util.addCommas(d))) + \" KB/s &plusmn; \")) + e)) + \"%\\u003Cbr /\\u003ELatency: \")) + c.lat)) + \" ms &plusmn; \")) + c.lat_err)), !0)));\n                    });\n                });\n            }))), ((a.countryCode && (twttr.countryCode = a.countryCode)));\n            if (a.countries) {\n                twttr.countries = a.countries;\n                if (twttr.countryCode) {\n                    for (var b = 0, d = twttr.countries.length; ((b < d)); b++) {\n                        ((((twttr.countries[b].code == twttr.countryCode)) && (twttr.countries[b].selected = !0)));\n                    ;\n                    };\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            ((a.pageLocaleJS ? (((twttr.bootTimings && twttr.bootTimings.add(\"i18n fetch start\"))), using(a.pageLocaleJS).load().then(function() {\n                ((twttr.bootTimings && twttr.bootTimings.add(\"i18n fetch finish\"))), signal(\"\\u003ElanguageData\");\n            })) : signal(\"\\u003ElanguageData\"))), using(\"\\u003EdefaultViews\", twttr.bundleMore, function() {\n                ((a.showWelcomeBanner && (new twttr.views.WelcomeToPhoenixBanner).render($(\"#banners\"), \"append\"))), ((a.flashNotice && twttr.showMessage(a.flashNotice, !0)));\n            }), using(\"\\u003Edecider\", function() {\n                twttr.decider._updateFeatures(a.deciderFeatures, !0), signal(\"\\u003EdeciderFeaturesFromBootstrap\");\n            }), using(\"\\u003Eab_decider\", function() {\n                twttr.abdecider._updateExperiments(a.abBuckets, !0);\n            }), using(\"\\u003Eapi_ready\", function() {\n                twttr.API.setConfig({\n                    postAuthenticityToken: a.postAuthenticityToken\n                }), $(\"input.authenticity_token\").val(a.postAuthenticityToken), ((twttr.decider.isAvailable(\"add_authenticity_token_via_js\") && $(\"input[name=authenticity_token]\").val(a.postAuthenticityToken)));\n                var b = a.requestCacheSeedData;\n                for (var c = 0, d = b.length; ((c < d)); ++c) {\n                    var e = b[c];\n                    twttr.API._requestCache.inject(e.api_request_name, e.options, e.json, 1);\n                };\n            ;\n                signal(\"\\u003Erequest_cache_seeded\"), ((a.homeTimelineFetchSize && (twttr.API.homeTimelineFetchSize = a.homeTimelineFetchSize)));\n            }), ((twttr.bootTimings && twttr.bootTimings.add(\"bootstrap_data process finish\")));\n        };\n    ;\n        function e() {\n            ((twttr.loggedIn ? (((twttr.bootTimings && twttr.bootTimings.add(\"initCurrentUser start\"))), using(\"boot/bootstrap_data\", \"\\u003Erequest_cache_seeded\", function(a) {\n                twttr.API.User.current({\n                    error: function() {\n                        window.JSBNG__location.reload(!0);\n                    },\n                    success: function(b) {\n                        twttr.currentUser = b;\n                        for (var c in a.userProperties) {\n                            twttr.currentUser.sync(c, ((a.userProperties[c] || !1)));\n                        ;\n                        };\n                    ;\n                        twttr.API.User.bind(\"update\", function(a, b) {\n                            if (((twttr.currentUser.id == b.id))) {\n                                var c = [\"JSBNG__name\",\"url\",\"JSBNG__location\",\"description\",];\n                                for (var d = 0; ((d < c.length)); ++d) {\n                                    twttr.currentUser.sync(c[d], b[c[d]]);\n                                ;\n                                };\n                            ;\n                            }\n                        ;\n                        ;\n                        }), ((twttr.bootTimings && twttr.bootTimings.add(\"initCurrentUser finish\"))), signal(\"\\u003EallCurrentUserDataLoaded\");\n                    }\n                });\n            })) : signal(\"\\u003EallCurrentUserDataLoaded\")));\n        };\n    ;\n        function f(a) {\n            var b = new JSBNG__Date;\n            using(a).load().then(function() {\n                var a = new JSBNG__Date;\n                using(\"boot/bootstrap_data\", function() {\n                    twttr.Profiler.logPreviousEvent(\"twttr.bundles fetched\", b, a);\n                });\n            });\n        };\n    ;\n        function g(a) {\n            function c() {\n                ((b || JSBNG__setTimeout(function() {\n                    twttr.keynoteTTFTPing(), b = !0, a();\n                }, 0)));\n            };\n        ;\n            function d() {\n                JSBNG__setTimeout(c, 0);\n            };\n        ;\n            function f() {\n                e.JSBNG__onresize = null, d();\n            };\n        ;\n            var b = !1, e = JSBNG__document.getElementById(\"stream-items-id\");\n            if (!e) {\n                a();\n                return;\n            }\n        ;\n        ;\n            if (((e.clientHeight > 0))) {\n                d();\n                return;\n            }\n        ;\n        ;\n            e.JSBNG__onresize = f;\n        };\n    ;\n        function i(a) {\n            for (var b in a) {\n                return !1;\n            };\n        ;\n            return !0;\n        };\n    ;\n        function j(a) {\n            function d() {\n                JSBNG__clearTimeout(c), $(b).remove(), twttr.app.recalculatePadding();\n            };\n        ;\n            function e() {\n                b.style.display = \"block\", JSBNG__setTimeout(function() {\n                    b.style.height = \"46px\";\n                });\n            };\n        ;\n            if (!a) {\n                return;\n            }\n        ;\n        ;\n            var b = JSBNG__document.getElementById(\"slow-load-banner\");\n            if (!b) {\n                return;\n            }\n        ;\n        ;\n            var c;\n            c = JSBNG__setTimeout(e, a), ((twttr.bundleCore && using(twttr.bundleCore, d)));\n        };\n    ;\n        var b = {\n            add: function(a, b) {\n                ((b || (b = new JSBNG__Date))), twttr.bootTimings.data.push({\n                    JSBNG__name: a,\n                    timestamp: b\n                });\n            },\n            data: [],\n            done: function() {\n                twttr.bootTimings.add = twttr.bootTimings.done = $.noop, $.each(loadrunner.Script.times, function(a, b) {\n                    $.each(b, function(b, c) {\n                        twttr.bootTimings.data.push({\n                            JSBNG__name: [\"bundle\",a,b,].join(\" \"),\n                            timestamp: c\n                        });\n                    });\n                }), twttr.Profiler.logDataSet(\"Boot\", twttr.appStartTime, twttr.bootTimings.data), twttr.bootTimings = null;\n            }\n        };\n        a({\n            init: function(a) {\n                if (a.renderedOnServer) {\n                    var k = JSBNG__document.getElementsByTagName(\"html\")[0], l = k.className.match(/highlight-global-nav-([a-z]+)/);\n                    if (((a.twttr.loggedIn && l))) {\n                        var m = ((\"global-nav-\" + l[1]));\n                        JSBNG__document.getElementById(m).className += \" active\";\n                    }\n                     else if (k.className.match(/remove-prerendered-content/)) {\n                        JSBNG__document.getElementById(\"page-outer\").className = JSBNG__document.getElementById(\"page-outer\").className.replace(\"flush-to-top\", \"\");\n                        var n = JSBNG__document.getElementById(\"page-container\");\n                        n.className = n.className.replace(\"home-container\", \"\"), n.innerHTML = \"\", signal(\"\\u003EwokeUp\"), a.renderedOnServer = !1;\n                    }\n                    \n                ;\n                ;\n                    k.className = k.className.replace(\"use-prerendered-content\", \"\").replace(\"remove-prerendered-content\", \"\"), ((k.getAttribute(\"data-nav-highlight-class-name\") && (k.className = k.className.replace(k.getAttribute(\"data-nav-highlight-class-name\"), \"\"), k.removeAttribute(\"data-nav-highlight-class-name\"))));\n                }\n            ;\n            ;\n                if (a.disablePhoenix) {\n                    j(a.loadTimeoutInterval);\n                    return;\n                }\n            ;\n            ;\n                c(a.twttr), twttr.appStartTime = JSBNG__document.startTime, twttr.geo = ((twttr.geo || {\n                })), twttr.session = ((twttr.session || {\n                })), twttr.session.impressionId = ((twttr.appStartTime + Math.JSBNG__random())), twttr.isLocalhost = JSBNG__location.hostname.match(/localhost\\.twitter\\.com/);\n                if (twttr.allScribeEvents) {\n                    try {\n                        twttr.allScribeEvents = ((JSON.parse(JSBNG__localStorage.twttrAllScribeEvents) || []));\n                    } catch (o) {\n                        twttr.allScribeEvents = [];\n                    };\n                }\n            ;\n            ;\n                twttr.bootTimings = ((a.profiling ? b : null));\n                for (var p = 0; ((p < a.loadrunnerAssets.length)); p++) {\n                    using.bundles.push(a.loadrunnerAssets[p]);\n                ;\n                };\n            ;\n                ((((((a.loadrunnerAssets.length == 1)) && i(a.loadrunnerAssets[0]))) && (using.autoLoad = !0))), j(a.loadTimeoutInterval), twttr.proto = window.JSBNG__location.protocol.replace(\":\", \"\"), twttr.isSSL = function() {\n                    return ((twttr.proto === \"https\"));\n                }, twttr.createIframe = function(a, b) {\n                    var c = JSBNG__document.createElement(\"div\");\n                    c.innerHTML = ((((\"\\u003Cdiv tabindex=\\\"-1\\\" role=\\\"presentation\\\" style=\\\"position:absolute;top:-9999px;\\\" src=\\\"\" + a)) + \"\\\"\\u003E\\u003C/div\\u003E\"));\n                    var d = c.firstChild, e = function() {\n                        b.apply(d, arguments);\n                    };\n                    return ((d.JSBNG__addEventListener ? d.JSBNG__addEventListener(\"load\", e, !1) : d.JSBNG__attachEvent(\"JSBNG__onload\", e))), JSBNG__document.body.insertBefore(d, JSBNG__document.body.firstChild), d;\n                }, ((a.inline_bootstrap_data || provide(\"boot/bootstrap_data\", function(a) {\n                    var b = [];\n                    b.push(((((((((\"json!/account/bootstrap_data\" + window.JSBNG__location.search)) + ((window.JSBNG__location.search ? \"&\" : \"?\")))) + \"r=\")) + Math.JSBNG__random()))), ((((typeof JSON == \"undefined\")) && b.push(twttr.bundleCore))), ((twttr.bootTimings && twttr.bootTimings.add(\"bootstrap_data fetch start\"))), using(b, function(b) {\n                        ((twttr.bootTimings && twttr.bootTimings.add(\"bootstrap_data fetch finish\")));\n                        var c = JSON.parse(b);\n                        a(c);\n                    });\n                }))), f(a.assets), using(twttr.bundleCore, function() {\n                    twttr.anywhere.remote = {\n                    }, using(\"bluejs/api\", function(a) {\n                        twttr.API = a, twttr.API.setConfig({\n                            cacheObjects: !0,\n                            includeEntities: !0\n                        }), twttr.extendAPI(), signal(\"\\u003Eapi_ready\"), using(\"\\u003Erequest_cache_seeded\", function() {\n                            e();\n                        });\n                    });\n                }), using(a.setupDependencies, function() {\n                    ((twttr.bootTimings && twttr.bootTimings.add(\"setup start\"))), jQuery.ready(), jQuery.fx.interval = 50, twttr.setup(a.renderedOnServer), ((twttr.bootTimings && twttr.bootTimings.add(\"setup finish\"))), signal(\"\\u003EsetupComplete\");\n                    var b = function() {\n                        using(twttr.bundleMore).load();\n                    };\n                    (((($.browser.msie && ((parseInt($.browser.version, 10) <= 8)))) ? g(b) : b()));\n                }), using(twttr.bundleMore, function() {\n                    signal(\"\\u003EallCodeLoaded\");\n                }), using(\"boot/bootstrap_data\", d), twttr.createIframe(a.pReceiverURL, function() {\n                    var a = this;\n                    using(twttr.bundleCore, function() {\n                        twttr.anywhere.remote.server = a, twttr.anywhere.api.util.RemoteRequest.flush();\n                    });\n                });\n            }\n        });\n    });\n    using(\"boot/init\", function(boot) {\n        var data = {\n            assets: [\"bundle/t1-core\",],\n            sandboxes: {\n                jsonp: \"http://a0.twimg.com/a/1345479106/jsonp_sandbox.html\",\n                detailsPaneContent: \"http://a0.twimg.com/a/1345479106/details_pane_content_sandbox.html\"\n            },\n            renderedOnServer: true,\n            loadrunnerAssets: [{\n                \"http://a0.twimg.com/c/phoenix/en/bundle/sandbox.46298132d415b0168f1b1626bc148c99a6496dcc.js\": [\"bundle/sandbox\",],\n                \"http://a0.twimg.com/c/phoenix/en/bundle/t1-hogan-core.da31cb481a235c68052dc0329e13f6a1aef9c31e.js\": [\"bundle/t1-hogan-core\",],\n                \"http://a0.twimg.com/c/phoenix/en/bundle/t1-more.7152802a7d535e74c7338f5254308d61bce6e545.js\": [\"bundle/t1-more\",],\n                \"http://a0.twimg.com/c/phoenix/en/bundle/t1-core.cff52d0363daa50776332252b9ef769a2fbda0a4.js\": [\"bundle/t1-core\",],\n                \"http://a0.twimg.com/c/phoenix/en/bundle/ie6.d71f8de82c7cddee6a11aa7aa093031396c8e9bf.js\": [\"bundle/ie6\",],\n                \"http://a0.twimg.com/c/phoenix/en/bundle/signup.193171e43f7c3caa12329ea028e723413019576b.js\": [\"bundle/signup\",],\n                \"http://a0.twimg.com/c/phoenix/en/bundle/t1-hogan-more.864d58ff5bd506f67e89f2afc518ea78c42aa0b1.js\": [\"bundle/t1-hogan-more\",]\n            },],\n            twttr: {\n                loggedIn: false,\n                expando: false,\n                isT1: true,\n                placeDataPrefix: \"http://geo.l3.twitter.com/places/autocomplete_places-\",\n                hasHoversInCss: true,\n                remoteIP: \"50.16.240.131\",\n                isRTL: false,\n                requestFullCity: \"us,va,ashburn\",\n                bundleCore: \"bundle/t1-core\",\n                deciderOverrides: {\n                },\n                domains: {\n                    local: \"twitter.com\",\n                    upload: \"upload.twitter.com\",\n                    remote: \"api.twitter.com\"\n                },\n                bundleMore: \"bundle/t1-more\",\n                hosts: {\n                    local: \"http://twitter.com\",\n                    upload: \"http://upload.twitter.com\",\n                    remote: \"http://api.twitter.com\"\n                }\n            },\n            pReceiverURL: \"http://api.twitter.com/receiver.html\",\n            setupDependencies: [\"\\u003EallCurrentUserDataLoaded\",\"\\u003Erequest_cache_seeded\",\"bundle/t1-core\",\"\\u003ElanguageData\",],\n            profiling: false,\n            inline_bootstrap_data: false,\n            disablePhoenix: false,\n            loadTimeoutInterval: 10000\n        };\n        boot.init(data);\n    });\n});");
// 1973
fpc.call(JSBNG_Replay.sb5d8a5a82713b77123eb5ce3609b274e45633210_74[0], o2,o3);
// undefined
o3 = null;
// 1976
fpc.call(JSBNG_Replay.sb5d8a5a82713b77123eb5ce3609b274e45633210_74[0], o2,o6);
// undefined
o6 = null;
// 1978
ow283489458.JSBNG_Replay_geval("WATCH.end(\"boot\");");
// 1981
o2.readyState = 2;
// 1980
fpc.call(JSBNG_Replay.sb5d8a5a82713b77123eb5ce3609b274e45633210_74[0], o2,o7);
// undefined
o7 = null;
// 1984
o2.readyState = 3;
// 1983
fpc.call(JSBNG_Replay.sb5d8a5a82713b77123eb5ce3609b274e45633210_74[0], o2,o8);
// undefined
o8 = null;
// 1987
o2.readyState = 4;
// 1986
fpc.call(JSBNG_Replay.sb5d8a5a82713b77123eb5ce3609b274e45633210_74[0], o2,o9);
// undefined
o2 = null;
// undefined
o9 = null;
// 2169
ow283489458.JSBNG_Replay_geval("provide(\"/account/templates_t1_core.js\", function(exports) {\n    if (!twttr.isMockview) {\n        var __hogan_opts = {\n            sectionTags: [{\n                o: \"_i\",\n                c: \"i\"\n            },],\n            disableLambda: true\n        };\n        twttr.provide(\"twttr.templates\", {\n            activity_modal: \"\\u003Cdiv id='activity-modal' style='display: none'\\u003E\\u000a  \\u003Cdiv class='left-pointer'\\u003E\\u003C/div\\u003E\\u000a  \\u003Ca class='dismiss' title=\\\"Hide\\\"\\u003E&times;\\u003C/a\\u003E\\u000a  \\u003Cp class='header'\\u003E\\u003Cspan class='new'\\u003ENew!\\u003C/span\\u003E Activity and @{{current_user_screen_name}}\\u003C/p\\u003E\\u000a  \\u003Cp class='desc'\\u003E\\u000a      View favorites, follows, retweets and more by people you follow in \\u003Cstrong\\u003EActivity\\u003C/strong\\u003E.\\u000a  \\u003C/p\\u003E\\u000a  \\u003Cp class='extra-blurb desc'\\u003E\\u000a    View your mentions, tweets that were retweeted and more in \\u003Cstrong\\u003E@{{current_user_screen_name}}\\u003C/strong\\u003E.\\u000a  \\u003C/p\\u003E\\u000a\\u003C/div\\u003E\",\n            bg_img_css: \"\\u000a\\u003Cstyle id=\\\"user-style-{{screen_name}}-bg-img\\\" class=\\\"js-user-style-bg-img\\\"\\u003E\\u000a  body.user-style-{{screen_name}} {\\u000a    {{#is_vit_layout}}\\u000a      {{^is_mobile}}\\u000a      background-color: #3c8fc9;\\u000a      {{/is_mobile}}\\u000a      {{#is_mobile}}\\u000a      background-color: #e2e2e2;\\u000a      {{/is_mobile}}\\u000a    {{/is_vit_layout}}\\u000a    {{^is_vit_layout}}\\u000a      {{#profile_use_background_image}}\\u000a        {{#profile_background_image_url}}\\u000a          background-image: url({{profile_background_image_url}});\\u000a        {{/profile_background_image_url}}\\u000a      {{/profile_use_background_image}}\\u000a    {{/is_vit_layout}}\\u000a  }\\u000a\\u003C/style\\u003E\\u000a\",\n            details_pane: \"\\u003Cdiv class=\\\"inner-pane\\\"\\u003E\\u000a  \\u003Cdiv class='pane-toolbar pane-built-in'\\u003E\\u000a    {{#popable}}\\u000a      \\u003Ca class='pane-back toolbar-control' href='#'\\u003E\\u003Cspan\\u003E&larr;\\u003C/span\\u003E {{back_label}}\\u003C/a\\u003E\\u000a    {{/popable}}\\u000a    {{#closable}}\\u000a      \\u003Ca class='pane-close toolbar-control' href='#'\\u003Eclose \\u003Cspan\\u003E&times;\\u003C/span\\u003E\\u003C/a\\u003E\\u000a    {{/closable}}\\u000a    \\u003Cbr style='clear: both' /\\u003E\\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"pane-components\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"pane-components-inner\\\"\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            details_pane_container: \"\\u003Cdiv id=\\\"details-pane-outer\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"details-pane-shell\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"details-pane\\\"\\u003E\\u000a      {{{pane}}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            home_page: \"\\u003Cdiv class=\\\"main-content\\\"\\u003E\\u000a  {{#render_page_content}}\\u000a    \\u003Cdiv class=\\\"page-header home-header\\\"\\u003E\\u000a      \\u003Cdiv id=\\\"main-tweet-box\\\"\\u003E\\u000a        {{\\u003Eposting_tweet_box}}\\u000a      \\u003C/div\\u003E\\u000a      \\u003Cul class=\\\"stream-tabs\\\"\\u003E\\u000a        \\u003Cli class=\\\"stream-tab stream-tab-home {{#active_tab_home}}active{{/active_tab_home}}\\\"\\u003E\\u000a          \\u003Ca class=\\\"tab-text\\\" title='All you follow' href=\\\"{{index_path}}\\\"\\u003ETimeline\\u003C/a\\u003E\\u000a        \\u003C/li\\u003E\\u000a\\u000a        {{#decider_activity_read}}\\u000a          \\u003Cli class=\\\"stream-tab stream-tab-your_activity {{#active_tab_your_activity}}active{{/active_tab_your_activity}}\\\"\\u003E\\u000a            \\u003Ca class=\\\"tab-text\\\" title='@{{current_user_screen_name}}' href=\\\"{{your_activity_path}}\\\"\\u003E@{{current_user_screen_name}}\\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a          \\u003Cli class=\\\"stream-tab stream-tab-activity {{#active_tab_activity}}active{{/active_tab_activity}}\\\"\\u003E\\u000a            \\u003Ca class=\\\"tab-text\\\" title='Activity' href=\\\"{{activity_path}}\\\"\\u003EActivity\\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a        {{/decider_activity_read}}\\u000a\\u000a        {{^decider_activity_read}}\\u000a          \\u003Cli class=\\\"stream-tab stream-tab-mentions {{#active_tab_mentions}}active{{/active_tab_mentions}}\\\"\\u003E\\u000a            \\u003Ca class=\\\"tab-text\\\" title='Mentions' href=\\\"{{mentions_path}}\\\"\\u003E@Mentions\\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a          \\u003Cli class=\\\"stream-tab stream-tab-retweets dropdown-link {{#active_tab_retweets}}active{{/active_tab_retweets}}\\\"\\u003E\\u000a            \\u003Ca class=\\\"tab-text\\\" href=\\\"#\\\"\\u003ERetweets\\u003Ci\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a        {{/decider_activity_read}}\\u000a\\u000a        \\u003Cli class=\\\"stream-tab stream-tab-searches dropdown-link {{#active_tab_searches}}active{{/active_tab_searches}}\\\"\\u003E\\u000a          \\u003Ca class=\\\"tab-text\\\" href=\\\"#\\\"\\u003ESearches\\u003Ci\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a        \\u003C/li\\u003E\\u000a\\u000a        \\u003Cli class=\\\"stream-tab stream-tab-lists dropdown-link {{#active_tab_lists}}active{{/active_tab_lists}}\\\"\\u003E\\u000a          \\u003Ca class=\\\"tab-text\\\" href=\\\"#\\\"\\u003ELists\\u003Ci\\u003E\\u003C/i\\u003E\\u003C/a\\u003E\\u000a        \\u003C/li\\u003E\\u000a        {{#decider_network_discovery}}\\u000a          \\u003Cli class=\\\"stream-tab stream-tab-discovery activity-subtabs {{#active_tab_network_discovery}}active{{/active_tab_network_discovery}}\\\"\\u003E\\u000a            \\u003Ca class=\\\"tab-text\\\" title='Discover' href=\\\"{{discovery_path}}\\\"\\u003EDiscover\\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a        {{/decider_network_discovery}}\\u000a      \\u003C/ul\\u003E\\u000a    \\u003C/div\\u003E\\u000a    {{#decider_activity_read}}\\u000a      {{#activity_subtabs}}\\u000a        \\u003Cul class=\\\"stream-subtabs stream-subtabs-activity {{#active_tab_activity}}active{{/active_tab_activity}}\\\"\\u003E\\u000a          \\u003Cli class=\\\"stream-tab stream-subtab-your_activity {{#active_subtab_your_activity}}active{{/active_subtab_your_activity}}\\\"\\u003E\\u000a            \\u003Ca class=\\\"tab-text\\\" href=\\\"{{your_activity_path}}\\\"\\u003Eabout you\\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a          \\u003Cli class=\\\"stream-tab stream-tab-separator\\\"\\u003E&middot;\\u003C/li\\u003E\\u000a          \\u003Cli class=\\\"stream-tab stream-subtab-activity {{#active_subtab_activity}}active{{/active_subtab_activity}}\\\"\\u003E\\u000a            \\u003Ca class=\\\"tab-text\\\" href=\\\"{{activity_path}}\\\"\\u003Eby people you follow\\u003C/a\\u003E\\u000a          \\u003C/li\\u003E\\u000a        \\u003C/ul\\u003E\\u000a      {{/activity_subtabs}}\\u000a    {{/decider_activity_read}}\\u000a    {{\\u003Estream_manager}}\\u000a    {{#rendering_on_server}}\\u003Cscript\\u003Etwttr.tweetsVisibleTime = new Date();if (window.ttft) window.ttft.serverRendered('home');twttr.keynoteTTFTPing();\\u003C/script\\u003E{{/rendering_on_server}}\\u000a  {{/render_page_content}}\\u000a\\u003C/div\\u003E\\u000a\\u003Cdiv class=\\\"dashboard\\\"\\u003E\\u000a  {{#render_page_content}}\\u000a    {{#current_user}}\\u000a      {{\\u003Ehome_dashboard}}\\u000a    {{/current_user}}\\u000a  {{/render_page_content}}\\u000a\\u003C/div\\u003E\\u000a\\u000a{{\\u003Edetails_pane_container}}\\u000a\",\n            message_drawer: \"\\u003Cdiv class=\\\"message {{^rendering_on_server}}{{type}}{{/rendering_on_server}}\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"message-inside\\\"\\u003E\\u000a    \\u003Cspan class=\\\"message-text\\\"\\u003E{{{text}}}\\u003C/span\\u000a    \\u003E{{#close_button}}\\u003Ca class=\\\"dismiss\\\" href=\\\"#\\\"\\u003E&times;\\u003C/a\\u003E{{/close_button}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            message_notification: \"{{#message}}\\u000a\\u003Cdiv data-sender-id='{{sender_screen_name}}' data-message-id=\\\"{{id}}\\\" class='notification'\\u003E\\u000a  \\u003Ca class='dismiss' href='#'\\u003E&times;\\u003C/a\\u003E\\u000a  \\u003Ch1\\u003ENew Message from {{{sender_screen_name}}}\\u003C/h1\\u003E\\u000a  \\u003Cdiv class='message-text'\\u003E{{{text}}}\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"message-notification-reply-box\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"message-notification-reply-editor\\\"\\u003E\\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"message-notification-reply-button button\\\"\\u003ESend\\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a{{/message}}\",\n            more_button: \"\\u003Cdiv class=\\\"stream-item\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"more-button-container\\\"\\u003E\\u000a    \\u003Ca class=\\\"more-button btn\\\"\\u003Emore\\u003C/a\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            new_tweets_bar: \"\\u003Cdiv class=\\\"stream-item\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"new-tweets-bar js-new-tweets-bar\\\" data-item-count=\\\"{{count}}\\\"\\u003E\\u000a    \\u000a    {{#tweets_count_phrase}}\\u000a      {{tweets_count_phrase}}\\u000a    {{/tweets_count_phrase}}\\u000a    {{^tweets_count_phrase}}\\u000a      {{#is_tweet}}\\u000a        {{#count_one}}{{count}} new Tweet{{/count_one}}{{#count_other}}{{count}} new Tweets{{/count_other}}\\u000a      {{/is_tweet}}\\u000a      {{^is_tweet}}\\u000a        {{#count_one}}{{count}} new Interaction{{/count_one}}{{#count_other}}{{count}} new Interactions{{/count_other}}\\u000a      {{/is_tweet}}\\u000a    {{/tweets_count_phrase}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            pill_css: \"\\u000a.profile-style-{{screen_name}} a {\\u000a  {{#profile_link_color}}\\u000a    color: #{{profile_link_color}} !important;\\u000a  {{/profile_link_color}}\\u000a}\\u000a\\u000aa:hover .geo-pin, body.user-style-{{screen_name}} .stream-item:hover .geo-pin {\\u000a  background-color: #{{profile_link_color}};\\u000a}\",\n            posting_tweet_box: \"\\u003Cform method=\\\"post\\\" action=\\\"/status/update\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"tweet-box condensed\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"tweet-box-title\\\"\\u003E\\u000a      \\u003Ch2\\u003EWhat\\u2019s happening?\\u003C/h2\\u003E\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"text-area\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"text-area-editor twttr-editor\\\"\\u003E\\u000a        \\u003Ctextarea class=\\\"twitter-anywhere-tweet-box-editor\\\" name=\\\"status\\\" style=\\\"width: 482px; height: 36px;\\\"\\u003E\\u003C/textarea\\u003E\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/form\\u003E\\u000a\",\n            stream: \"\\u003Cdiv class=\\\"stream\\\"\\u003E\\u000a  \\u000a  \\u003Cdiv class=\\\"js-stream-items stream-items\\\" id=\\\"stream-items-id\\\"\\u003E\\u003C/div\\u003E\\u000a\\u003C/div\\u003E\",\n            stream_activity: \"\\u003Cspan class='stream-activity-line'\\u003E\\u003Ci\\u003E\\u003C/i\\u003E{{{sentence}}}\\u003C/span\\u003E\",\n            stream_item: \"\\u003Cdiv class=\\\"js-stream-item stream-item {{item_class}}\\\" data-item-id=\\\"{{item_id}}\\\" data-item-type=\\\"{{item_type}}\\\"{{#rendering_on_server}} id=\\\"stream-item-{{item_type}}-{{item_id}}\\\"{{/rendering_on_server}}\\u003E\\u000a  {{{item_html}}}\\u000a\\u003C/div\\u003E\\u000a\",\n            stream_loading: \"\\u003Cdiv class=\\\"stream-loading\\\"\\u003E\\u000a  \\u003Cdiv class=\\\"stream-end-inner\\\"\\u003E\\u000a    \\u003Cspan class=\\\"spinner\\\" title=\\\"Loading...\\\"\\u003E\\u003C/span\\u003E\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            stream_manager: \"\\u003Cdiv class=\\\"stream-manager js-stream-manager-container\\\"{{#page_name_underscore}} id=\\\"{{page_name_underscore}}-stream-manager\\\"{{/page_name_underscore}}\\u003E\\u000a  {{#tweets}}\\u000a    \\u003Cdiv class=\\\"stream-title\\\"\\u003E\\u003C/div\\u003E\\u000a    \\u003Cdiv class=\\\"stream-container\\\"\\u003E\\u000a      \\u003Cdiv class=\\\"stream {{#page_name_underscore}}{{page_name_underscore}}-stream{{/page_name_underscore}}\\\"\\u003E\\u000a        \\u000a        \\u003Cdiv class=\\\"js-stream-items stream-items\\\" id=\\\"stream-items-id\\\"\\u003E{{{tweets}}}\\u003C/div\\u003E\\u000a        {{#show_empty_home}}\\u000a          \\u003Cdiv class=\\\"component\\\"\\u003E{{\\u003Eempty_home}}\\u003C/div\\u003E\\u000a        {{/show_empty_home}}\\u000a        {{#include_stream_footer}}\\u000a          \\u003Cdiv class=\\\"component\\\"\\u003E{{\\u003Estream_end}}\\u003C/div\\u003E\\u000a        {{/include_stream_footer}}\\u000a\\u000a      \\u003C/div\\u003E\\u000a    \\u003C/div\\u003E\\u000a  {{/tweets}}\\u000a  {{#rendering_on_server}}\\u000a    {{^tweets}}\\u000a      {{#profile_page}}\\u000a        {{^can_view}}\\u000a          {{\\u003Estream}}\\u000a        {{/can_view}}\\u000a      {{/profile_page}}\\u000a    {{/tweets}}\\u000a  {{/rendering_on_server}}\\u000a\\u003C/div\\u003E\\u000a\",\n            stream_tweet: \"\\u000a\\u000a{{^render_withheld}}\\u000a\\u000a  \\u000a  {{#is_current_user_withheld}}\\u000a    {{\\u003Ewithheld_message}}\\u000a  {{/is_current_user_withheld}}\\u000a\\u000a  \\u003Cdiv class=\\\"tweet original-tweet js-stream-tweet js-actionable-tweet js-hover js-profile-popup-actionable js-original-tweet {{#hidden_by_activity}} sub-stream-item-hidden{{/hidden_by_activity}}{{#embedded_by_activity}} js-activity-tweet{{/embedded_by_activity}}{{#spam_threat}} spam-threat-tweet{{/spam_threat}} {{\\u003Ecommon_tweet_classes}}\\\" {{\\u003Etweet_data}}\\u003E\\u000a\\u000a    \\u000a    \\u003Ci class=\\\"dogear\\\"\\u003E\\u003C/i\\u003E\\u000a\\u000a    \\u000a    \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a\\u000a      \\u000a      \\u003Cdiv class=\\\"stream-item-header\\\"\\u003E\\u000a        {{\\u003Etweet_timestamp}}\\u000a        {{#tweet_spam_experiment_enabled}}\\u000a          {{\\u003Etweet_spam_menu}}\\u000a        {{/tweet_spam_experiment_enabled}}\\u000a        {{\\u003Etweet_user_block}}\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u000a      {{#rendering_on_server}}\\u000a        \\u003Cp class=\\\"js-tweet-text{{#is_rtl_tweet}} tweet-text-rtl{{/is_rtl_tweet}}\\\"\\u003E\\u000a          {{\\u003Elinked_tweet}}\\u000a        \\u003C/p\\u003E\\u000a      {{/rendering_on_server}}\\u000a      {{^rendering_on_server}}\\u000a        \\u003Cp class=\\\"js-tweet-text\\\"\\u003E{{\\u003Elinked_tweet}}\\u003C/p\\u003E\\u000a      {{/rendering_on_server}}\\u000a\\u000a      \\u000a      \\u003Cdiv class=\\\"stream-item-footer\\\"\\u003E\\u000a        \\u000a        {{\\u003Etweet_context}}\\u000a\\u000a        \\u000a        \\u003Ca class=\\\"details with-icn js-details\\\" href=\\\"{{permalink_path}}\\\"\\u003E\\u000a          \\u003Cspan class=\\\"details-icon js-icon-container\\\"{{#place_name}} data-placename=\\\"{{place_name}}\\\"{{/place_name}}\\u003E\\u000a            {{#is_reply}}\\u000a              \\u003Ci class=\\\"sm-chat\\\"\\u003E\\u003C/i\\u003E\\u000a            {{/is_reply}}\\u000a            {{#rendering_on_server}}\\u000a            {{#has_embedded_photo}}\\u000a              \\u003Ci class=\\\"sm-image\\\"\\u003E\\u003C/i\\u003E\\u000a            {{/has_embedded_photo}}\\u000a            {{#has_embedded_summary}}\\u000a              \\u003Ci class=\\\"sm-embed\\\"\\u003E\\u003C/i\\u003E\\u000a            {{/has_embedded_summary}}\\u000a            {{#has_embedded_player}}\\u000a              \\u003Ci class=\\\"sm-video\\\"\\u003E\\u003C/i\\u003E\\u000a            {{/has_embedded_player}}\\u000a            {{#has_strong_geo}}\\u000a              \\u003Ci class=\\\"sm-geo\\\"\\u003E\\u003C/i\\u003E\\u000a            {{/has_strong_geo}}\\u000a            {{/rendering_on_server}}\\u000a          \\u003C/span\\u003E\\u000a          \\u003Cb\\u003E\\u000a            \\u003Cspan class=\\\"expand-stream-item js-view-details\\\"\\u003E\\u000a              {{#rendering_on_server}}\\u000a                {{expand_callout_text}}\\u000a                {{^expand_callout_text}}\\u000a                  \\u003Cspan class=\\\"expand-action-wrapper\\\"\\u003E\\u000a                    Expand\\u000a                  \\u003C/span\\u003E\\u000a                {{/expand_callout_text}}\\u000a              {{/rendering_on_server}}\\u000a              {{^rendering_on_server}}\\u000a                {{#is_reply}}\\u000a                  View conversation\\u000a                {{/is_reply}}\\u000a                {{^is_reply}}\\u000a                  \\u003Cspan class=\\\"expand-action-wrapper\\\"\\u003E\\u000a                    Expand\\u000a                  \\u003C/span\\u003E\\u000a                {{/is_reply}}\\u000a              {{/rendering_on_server}}\\u000a            \\u003C/span\\u003E\\u000a            \\u003Cspan class=\\\"collapse-stream-item js-hide-details\\\"\\u003E\\u000a              {{#rendering_on_server}}\\u000a                {{collapse_callout_text}}\\u000a              {{/rendering_on_server}}\\u000a              {{^rendering_on_server}}\\u000a                {{#is_reply}}\\u000a                  Hide conversation\\u000a                {{/is_reply}}\\u000a                {{^is_reply}}\\u000a                  \\u003Cspan class=\\\"collapse-action-wrapper\\\"\\u003E\\u000a                    Collapse\\u000a                  \\u003C/span\\u003E\\u000a                {{/is_reply}}\\u000a              {{/rendering_on_server}}\\u000a            \\u003C/span\\u003E\\u000a          \\u003C/b\\u003E\\u000a        \\u003C/a\\u003E\\u000a\\u000a        \\u000a        {{\\u003Etweet_actions}}\\u000a      \\u003C/div\\u003E\\u000a\\u000a      \\u000a      {{\\u003Estream_tweet_expansion}}\\u000a\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/div\\u003E\\u000a{{/render_withheld}}\\u000a\\u000a{{#render_withheld}}\\u000a  {{\\u003Estream_tweet_withheld}}\\u000a{{/render_withheld}}\\u000a\",\n            stream_tweet_withheld: \"\\u003Cdiv class=\\\"tweet original-tweet withheld-tweet js-stream-tweet js-actionable-tweet js-profile-popup-actionable js-original-tweet {{#hidden_by_activity}} sub-stream-item-hidden{{/hidden_by_activity}}{{#embedded_by_activity}} js-activity-tweet{{/embedded_by_activity}} {{\\u003Ecommon_tweet_classes}}\\\" {{\\u003Etweet_data}}\\u003E\\u000a  \\u003Ci class=\\\"dogear\\\"\\u003E\\u003C/i\\u003E\\u000a  \\u003Cdiv class=\\\"content\\\"\\u003E\\u000a    \\u003Cdiv class=\\\"stream-item-header\\\"\\u003E\\u000a      \\u003Ca class=\\\"account-group\\\"\\u003E\\u000a        \\u003Cstrong class=\\\"fullname\\\"\\u003ETweet withheld\\u003C/strong\\u003E\\u000a      \\u003C/a\\u003E\\u000a      {{\\u003Etweet_timestamp}}\\u000a    \\u003C/div\\u003E\\u000a    \\u003Cp class=\\\"js-tweet-text\\\"\\u003E{{\\u003Elinked_tweet}}\\u003C/p\\u003E\\u000a    \\u003Cdiv class=\\\"stream-item-footer\\\"\\u003E\\u000a      {{\\u003Etweet_context}}\\u000a    \\u003C/div\\u003E\\u000a    {{\\u003Estream_tweet_expansion}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            tweet_actions: \"\\u000a\\u000a\\u000a \\u003Cul class=\\\"tweet-actions js-actions\\\"\\u003E\\u000a  \\u003Cli class=\\\"action-reply-container\\\"\\u003E\\u000a    \\u000a    {{^change_german_verbs}}\\u000a      \\u003Ca class=\\\"with-icn js-action-reply\\\" data-modal=\\\"tweet-reply\\\" href=\\\"#\\\" title=\\\"Reply\\\"\\u003E\\u000a        \\u003Ci class=\\\"sm-reply\\\"\\u003E\\u003C/i\\u003E\\u000a        \\u003Cb\\u003EReply\\u003C/b\\u003E\\u000a      \\u003C/a\\u003E\\u000a    {{/change_german_verbs}}\\u000a    {{#change_german_verbs}}\\u000a      \\u003Ca class=\\\"with-icn js-action-reply\\\" data-modal=\\\"tweet-reply\\\" href=\\\"#\\\" title=\\\"Kommentieren\\\"\\u003E\\u000a        \\u003Ci class=\\\"sm-reply\\\"\\u003E\\u003C/i\\u003E\\u000a        \\u003Cb\\u003EKommentieren\\u003C/b\\u003E\\u000a      \\u003C/a\\u003E\\u000a    {{/change_german_verbs}}\\u000a  \\u003C/li\\u003E\\u000a  {{#allowed_to_retweet}}\\u000a    \\u003Cli class=\\\"action-rt-container\\\"\\u003E\\u000a      \\u003Ca class=\\\"with-icn js-toggle-rt\\\" data-modal=\\\"tweet-retweet\\\" href=\\\"#\\\"\\u003E\\u000a        \\u003Ci class=\\\"sm-rt\\\"\\u003E\\u003C/i\\u003E\\u000a        \\u000a        \\u000a        {{^change_german_verbs}}\\u000a          \\u003Cb\\u003E\\u003Cspan class=\\\"undo-retweet\\\" title=\\\"Undo retweet\\\"\\u003ERetweeted\\u003C/span\\u003E\\u003Cspan class=\\\"retweet\\\" title=\\\"Retweet\\\"\\u003ERetweet\\u003C/span\\u003E\\u003C/b\\u003E\\u000a        {{/change_german_verbs}}\\u000a        {{#change_german_verbs}}\\u000a          \\u003Cb\\u003E\\u003Cspan class=\\\"undo-retweet\\\" title=\\\"Nicht mehr teilen\\\"\\u003EGeteilt\\u003C/span\\u003E\\u003Cspan class=\\\"retweet\\\" title=\\\"Teilen\\\"\\u003ETeilen\\u003C/span\\u003E\\u003C/b\\u003E\\u000a        {{/change_german_verbs}}\\u000a      \\u003C/a\\u003E\\u000a    \\u003C/li\\u003E\\u000a  {{/allowed_to_retweet}}\\u000a  \\u003Cli class=\\\"action-del-container\\\"\\u003E\\u000a    \\u003Ca class=\\\"with-icn js-action-del\\\" href=\\\"#\\\" title=\\\"Delete\\\"\\u003E\\u000a      \\u003Ci class=\\\"sm-trash\\\"\\u003E\\u003C/i\\u003E\\u000a      \\u003Cb\\u003EDelete\\u003C/b\\u003E\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/li\\u003E\\u000a  \\u003Cli class=\\\"action-fav-container\\\"\\u003E\\u000a    \\u003Ca class=\\\"with-icn js-toggle-fav\\\" href=\\\"#\\\"\\u003E\\u000a      \\u003Ci class=\\\"sm-fav\\\"\\u003E\\u003C/i\\u003E\\u000a      \\u000a      \\u000a      {{^change_german_verbs}}\\u000a        {{^australian_fav_to_like}}{{^australian_fav_to_star}}\\u000a          \\u003Cb\\u003E\\u003Cspan class=\\\"unfavorite\\\" title=\\\"Undo favorite\\\"\\u003EFavorited\\u003C/span\\u003E\\u003Cspan class=\\\"favorite\\\" title=\\\"Favorite\\\"\\u003EFavorite\\u003C/span\\u003E\\u003C/b\\u003E\\u000a        {{/australian_fav_to_star}}{{/australian_fav_to_like}}\\u000a        {{#australian_fav_to_like}}\\u000a          \\u003Cb\\u003E\\u003Cspan class=\\\"unfavorite\\\" title=\\\"Undo like\\\"\\u003ELiked\\u003C/span\\u003E\\u003Cspan class=\\\"favorite\\\" title=\\\"Like\\\"\\u003ELike\\u003C/span\\u003E\\u003C/b\\u003E\\u000a        {{/australian_fav_to_like}}\\u000a        {{#australian_fav_to_star}}\\u000a          \\u003Cb\\u003E\\u003Cspan class=\\\"unfavorite\\\" title=\\\"Undo star\\\"\\u003EStarred\\u003C/span\\u003E\\u003Cspan class=\\\"favorite\\\" title=\\\"Star\\\"\\u003EStar\\u003C/span\\u003E\\u003C/b\\u003E\\u000a        {{/australian_fav_to_star}}\\u000a      {{/change_german_verbs}}\\u000a      {{#change_german_verbs}}\\u000a        \\u003Cb\\u003E\\u003Cspan class=\\\"unfavorite\\\" title=\\\"Gef\\u00e4llt mir nicht\\\"\\u003EGef\\u00e4llt mir jetzt\\u003C/span\\u003E\\u003Cspan class=\\\"favorite\\\" title=\\\"Favorite\\\"\\u003EGef\\u00e4llt mir\\u003C/span\\u003E\\u003C/b\\u003E\\u000a      {{/change_german_verbs}}\\u000a    \\u003C/a\\u003E\\u000a  \\u003C/li\\u003E\\u000a\\u003C/ul\\u003E\",\n            tweet_contributor: \"{{#contributor}}\\u000a  \\u003Cspan class=\\\"tweet-contributors\\\"\\u003Eby \\u003Ca href=\\\"{{profile_path}}\\\" class=\\\"user-profile-link\\\" data-screen-name=\\\"{{screen_name}}\\\"\\u003E{{screen_name}}\\u003C/a\\u003E\\u003C/span\\u003E\\u000a{{/contributor}}\",\n            tweet_dogear: \"\\u003Cdiv class=\\\"tweet-dogear\\\"\\u003E\\u003C/div\\u003E\",\n            tweet_labels: \"{{#is_top_tweet}}\\u000a    \\u003Cspan class=\\\"tweet-context icon-link\\\"\\u003E\\u003Ci class=\\\"badge-tweet badge-tweet-top\\\"\\u003E\\u003C/i\\u003E{{#retweet_count}}Retweeted {{retweet_count}} times{{/retweet_count}}{{^retweet_count}}Top Tweet{{/retweet_count}}\\u003C/span\\u003E\\u000a{{/is_top_tweet}}\\u000a\\u000a{{#is_sponsored}}\\u000a  \\u003Ca href=\\\"{{#retweeting_status}}{{#user}}{{profile_path}}{{/user}}{{/retweeting_status}}{{^retweeting_status}}{{#user}}{{profile_path}}{{/user}}{{/retweeting_status}}\\\" class=\\\"icon-link promoted-arrow tweet-context user-profile-link js-action-profile-promoted\\\" data-user-id=\\\"{{#user}}{{id}}{{/user}}\\\" title=\\\"{{disclosure_text}}\\\"\\u003E\\u003Cspan\\u003E\\u003Ci class=\\\"badge-tweet badge-tweet-{{disclosure_type}}\\\"\\u003E\\u003C/i\\u003E\\u003Cb\\u003EPromoted by {{advertiser_name}}\\u003C/b\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u000a\\u000a  {{#in_home_page}}\\u000a    {{^rendering_on_server}}\\u000a      \\u003Ca class=\\\"icon-link tweet-feedback dismiss-action js-action-dismiss\\\"\\u003E\\u003Ci\\u003E\\u003C/i\\u003E\\u003Cb\\u003EDismiss\\u003C/b\\u003E\\u003C/a\\u003E\\u000a    {{/rendering_on_server}}\\u000a    {{{social_context}}}\\u000a  {{/in_home_page}}\\u000a{{/is_sponsored}}\",\n            tweet_meta: \"\\u003Cdiv class='tweet-meta'\\u003E\\u000a  \\u003Cspan class='icons'\\u003E\\u000a    {{#is_sponsored}}\\u000a      {{#retweet_count}}\\u000a        \\u003Cspan class='retweet-icon'\\u003E\\u003C/span\\u003E \\u003Cem\\u003E{{retweet_count_text}}\\u003C/em\\u003E\\u000a      {{/retweet_count}}\\u000a    {{/is_sponsored}}\\u000a\\u000a    {{^decider_activity_read}}\\u000a      {{^is_sponsored}}\\u000a        {{#was_retweeted}}\\u000a          {{#retweeting_status}}\\u000a            \\u003Cspan class='retweet-icon'\\u003E\\u003C/span\\u003E {{#user}}\\u003Cem\\u003Eby {{screen_name}}\\u003C/em\\u003E{{/user}}\\u000a          {{/retweeting_status}}\\u000a        {{/was_retweeted}}\\u000a      {{/is_sponsored}}\\u000a    {{/decider_activity_read}}\\u000a\\u000a    \\u003Cdiv class=\\\"extra-icons\\\"\\u003E\\u000a      {{^can_expand}}\\u000a        {{#is_reply}}\\u000a          \\u003Cspan class='reply-icon icon js-reply-notice'\\u003E@\\u003C/span\\u003E\\u000a        {{/is_reply}}\\u000a        \\u003Cspan class=\\\"inlinemedia-icons js-icon-container\\\"\\u003E\\u003C/span\\u003E\\u000a        {{#show_geo_icon}}\\u003Cspan class=\\\"geo-pin\\\"\\u003E\\u003C/span\\u003E{{/show_geo_icon}}\\u000a      {{/can_expand}}\\u000a      {{#can_expand}}\\u000a        {{\\u003Etweet_timestamp}}\\u000a      {{/can_expand}}\\u000a    \\u003C/div\\u003E\\u000a  \\u003C/span\\u003E\\u000a\\u003C/div\\u003E\\u000a\\u000a{{#can_expand}}\\u000a  {{\\u003Etweet_actions}}\\u000a{{/can_expand}}\",\n            tweet_source: \"\\u003Cspan class=\\\"tweet-source\\\"\\u003Evia {{{source}}}\\u003C/span\\u003E\",\n            tweet_text: \"\\u003Cdiv class=\\\"tweet-text js-tweet-text\\\"\\u003E\\u000a  {{\\u003Elinked_tweet}}\\u000a\\u003C/div\\u003E\",\n            tweet_timestamp: \"\\u003Csmall class=\\\"time\\\"\\u003E\\u000a    \\u003Ca href=\\\"{{permalink_path}}\\\" class=\\\"tweet-timestamp js-permalink\\\" title=\\\"{{explicit_timestamp}}\\\" {{#impression_cookie}}data-send-impression-cookie{{/impression_cookie}}\\u003E\\u003Cspan class=\\\"_timestamp js-short-timestamp {{#is_relative_timestamp}}js-relative-timestamp{{/is_relative_timestamp}}\\\" data-time=\\\"{{actual_timestamp}}\\\" data-long-form=\\\"true\\\"\\u003E{{short_timestamp}}\\u003C/span\\u003E\\u003C/a\\u003E\\u000a\\u003C/small\\u003E\\u000a\",\n            tweet_user_image_48: \"{{#user}}\\u000a\\u003Cimg height=\\\"48\\\" width=\\\"48\\\" src='{{profile_image_url}}' alt='{{name}}' class='user-profile-link js-action-profile-avatar' data-user-id='{{id}}'/\\u003E\\u000a{{/user}}\\u000a\",\n            tweet_user_name: \"{{#user}}\\u000a\\u003Cspan class='tweet-user-name'\\u003E\\u000a  \\u003Ca class='tweet-screen-name user-profile-link js-action-profile-name' data-user-id='{{id}}' href='{{profile_path}}' title='{{name}}'\\u003E{{screen_name}}\\u003C/a\\u003E\\u000a  \\u003Cspan class='tweet-full-name'\\u003E{{name}}\\u003C/span\\u003E\\u000a  {{#show_follow_action}}\\u000a    {{^is_current_user}}\\u000a    \\u003Cspan class=\\\"tweet-user-follow\\\"\\u003E\\u000a    \\u003C/span\\u003E\\u000a    {{/is_current_user}}\\u000a  {{/show_follow_action}}\\u000a\\u003C/span\\u003E\\u000a{{/user}}\",\n            user_css_p1: \"\\u000a\\u003Cstyle id=\\\"user-style-{{screen_name}}\\\"\\u003E\\u000a  body.user-style-{{screen_name}} {\\u000a    {{#profile_use_background_image}}\\u000a      background-position: left 40px;\\u000a      background-attachment: fixed;\\u000a      {{^profile_background_tile}}\\u000a        background-repeat: no-repeat;\\u000a      {{/profile_background_tile}}\\u000a    {{/profile_use_background_image}}\\u000a    {{#profile_background_color}}\\u000a      background-color: #{{profile_background_color}};\\u000a    {{/profile_background_color}}\\u000a    {{#profile_text_color}}\\u000a      color: #{{profile_text_color}};\\u000a    {{/profile_text_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} a,\\u000a  body.user-style-{{screen_name}} ul.stream-tabs li,\\u000a  body.user-style-{{screen_name}} .component .promo strong,\\u000a  body.user-style-{{screen_name}} .message-thread-preview:hover .message-count,\\u000a  body.user-style-{{screen_name}} .list-membership-container li.create-a-list {\\u000a    {{#profile_link_color}}\\u000a      color: #{{profile_link_color}};\\u000a    {{/profile_link_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .stream-item:hover .tweet-screen-name,\\u000a  body.user-style-{{screen_name}} .stream-item:hover .tweet-timestamp,\\u000a  body.user-style-{{screen_name}} .stream-item:hover .tweet-geo-text,\\u000a  body.user-style-{{screen_name}} .stream-item:hover .user-profile-link,\\u000a  body.user-style-{{screen_name}} span.user-stat-link,\\u000a  body.user-style-{{screen_name}} a.title-link:hover,\\u000a  body.user-style-{{screen_name}} a.user-stats-count:hover span.user-stats-stat,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item:hover a.user-screen-name,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item:hover .user-meta a,\\u000a  body.user-style-{{screen_name}} .user-detailed-list-item:hover a.user-screen-name,\\u000a  body.user-style-{{screen_name}} .tweet-activity:hover a.latest-tweet-timestamp,\\u000a  body.user-style-{{screen_name}} .stream-item:hover a.icon-link,\\u000a  body.user-style-{{screen_name}} .stream-item:hover a.icon-link b,\\u000a  body.user-style-{{screen_name}} .stream-item:hover .tweet-feedback,\\u000a  body.user-style-{{screen_name}} .promoted-tweet:hover .social-context a,\\u000a  body.user-style-{{screen_name}} .dashboard ul.trends li a:hover span.icon-link,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-sentence .dashboard-activity-item-entity,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-sentence .dashboard-activity-item-entity .user,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-sentence .dashboard-activity-item-count,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-link:hover .dashboard-activity-item-sentence,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-link:hover .dashboard-activity-item-sentence span.user,\\u000a  body.user-style-{{screen_name}} .JSBNG__onebox-user-screen-name:hover {\\u000a    {{#profile_link_color}}\\u000a      color: #{{profile_link_color}} !important;\\u000a    {{/profile_link_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .expanding-stream-item:hover .tweet-screen-name {\\u000a    color: #333 !important;\\u000a  }\\u000a  body.user-style-{{screen_name}} .expanding-stream-item:hover .tweet-timestamp {\\u000a    color: #999 !important;\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .hovered-stream-item,\\u000a  body.user-style-{{screen_name}} .stream-item:hover,\\u000a  body.user-style-{{screen_name}} #new-tweets-bar,\\u000a  body.user-style-{{screen_name}} #new-tweets-bar:active {\\u000a    {{#rgba_tweet_background_color}}\\u000a      background-color: {{rgba_tweet_background_color}};\\u000a    {{/rgba_tweet_background_color}}\\u000a    {{#rgba_tweet_border_color}}\\u000a      border-color: {{rgba_tweet_border_color}};\\u000a    {{/rgba_tweet_border_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .expanding-stream-item:hover {\\u000a    border-top-color: transparent;\\u000a    border-bottom-color: #EBEBEB;\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} #new-tweets-bar:hover {\\u000a    {{#rgba_newtweets_background_color}}\\u000a      background-color: {{rgba_newtweets_background_color}};\\u000a    {{/rgba_newtweets_background_color}}\\u000a    {{#rgba_newtweets_border_color}}\\u000a      border-color: {{rgba_newtweets_border_color}};\\u000a    {{/rgba_newtweets_border_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item .user-screen-name,\\u000a  body.user-style-{{screen_name}} .profile-screenname,\\u000a  body.user-style-{{screen_name}} .title-link,\\u000a  body.user-style-{{screen_name}} div.latest-tweet .latest-tweet-timestamp,\\u000a  body.user-style-{{screen_name}} div.truncated-tweet .latest-tweet-timestamp,\\u000a  body.user-style-{{screen_name}} a.user-stats-count span.user-stats-stat,\\u000a  body.user-style-{{screen_name}} .welcome-steps li .active a strong,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-sentence span.user {\\u000a    {{#profile_text_color}}\\u000a      color: #{{profile_text_color}};\\u000a    {{/profile_text_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item .user-full-name,\\u000a  body.user-style-{{screen_name}} span.trend-location,\\u000a  body.user-style-{{screen_name}} .your-activity h3,\\u000a  body.user-style-{{screen_name}} .trends-inner h3,\\u000a  body.user-style-{{screen_name}} .dashboard .user-rec-inner h3,\\u000a  body.user-style-{{screen_name}} .latest-tweet,\\u000a  body.user-style-{{screen_name}} .truncated-tweet,\\u000a  body.user-style-{{screen_name}} .latest-tweet a.latest-tweet-timestamp,\\u000a  body.user-style-{{screen_name}} .truncated-tweet a.latest-tweet-timestamp,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item .user-meta,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item .user-meta a,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item .user-meta a s,\\u000a  body.user-style-{{screen_name}} .social-context div,\\u000a  body.user-style-{{screen_name}} .dashboard .dot,\\u000a  body.user-style-{{screen_name}} .component .promo,\\u000a  body.user-style-{{screen_name}} .component .promo a.definition,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item .dismiss,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item .ellip,\\u000a  body.user-style-{{screen_name}} .facets-media-not-displayed .not-displayed-text,\\u000a  body.user-style-{{screen_name}} .dashboard .copyright,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item a.icon-link,\\u000a  body.user-style-{{screen_name}} .dashboard ul.trends li a span.icon-link,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-link,\\u000a  body.user-style-{{screen_name}} .dashboard-activity-item-sentence {\\u000a    {{#rgba_text_color}}\\u000a      color: {{rgba_text_color}};\\u000a    {{/rgba_text_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} #page-container,\\u000a  body.user-style-{{screen_name}} .user-sidebar-color,\\u000a  body.user-style-{{screen_name}} .expando-container .dashboard {\\u000a    {{#profile_sidebar_fill_color}}\\u000a      \\u000a      background: #{{profile_sidebar_fill_color}};\\u000a    {{/profile_sidebar_fill_color}}\\u000a    {{#rgba_sidebar_color}}\\u000a      \\u000a      background: {{rgba_sidebar_color}};\\u000a    {{/rgba_sidebar_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .activity:hover .stream-item-activity-network .activity-supplement .activity-item-tweet .activity-item-tweet-content,\\u000a  body.user-style-{{screen_name}} .hovered-stream-item .stream-item-activity-network .activity-supplement .activity-item-tweet .activity-item-tweet-content,\\u000a  body.user-style-{{screen_name}} .dashboard .stream-item-activity-network .activity-supplement .activity-item-tweet .activity-item-tweet-content  {\\u000a    {{#rgba_tweet_border_color}}\\u000a      border-color: {{rgba_tweet_border_color}} !important;\\u000a    {{/rgba_tweet_border_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .expanding-stream-item:hover a.twitter-atreply:hover,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item.open a.twitter-atreply,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item.colorful-links a.twitter-atreply,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item:hover a.twitter-hashtag:hover,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item.open a.twitter-hashtag,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item.colorful-links a.twitter-hashtag,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item:hover a.twitter-timeline-link:hover,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item.open a.twitter-timeline-link,\\u000a  body.user-style-{{screen_name}} .expanding-stream-item.colorful-links a.twitter-timeline-link {\\u000a    {{#profile_link_color}}\\u000a      color: #{{profile_link_color}} !important;\\u000a    {{/profile_link_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} s,\\u000a  body.user-style-{{screen_name}} .pretty-link s {\\u000a    {{#profile_pretty_link_color}}\\u000a      color: #{{profile_pretty_link_color}};\\u000a    {{/profile_pretty_link_color}}\\u000a  }\\u000a\\u000a  body.user-style-{{screen_name}} .dashboard s,\\u000a  body.user-style-{{screen_name}} .dashboard .pretty-link s,\\u000a  body.user-style-{{screen_name}} .dashboard .user-small-list-item:hover .user-meta a s {\\u000a    {{#profile_pretty_link_sidebar_color}}\\u000a      color: #{{profile_pretty_link_sidebar_color}};\\u000a    {{/profile_pretty_link_sidebar_color}}\\u000a  }\\u000a\\u000a  {{\\u003Epill_css}}\\u000a\\u003C/style\\u003E\",\n            user_link: \"\\u003Ca class=\\\"pretty-link js-user-profile-link\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u003Cb\\u003E{{name}}\\u003C/b\\u003E\\u003C/a\\u003E\",\n            common_tweet_classes: \"\\u000a{{#is_sponsored}} promoted-tweet{{/is_sponsored}}{{#is_my_tweet}} my-tweet{{/is_my_tweet}}{{#favorited}} favorited{{/favorited}}{{#is_retweeted_by_current_user}} retweeted{{/is_retweeted_by_current_user}}{{#preexpanded}} opened-tweet{{/preexpanded}}\\u000a{{#can_delete_user_tweets}}can-delete{{/can_delete_user_tweets}}\\u000a{{#has_visible_cards}} has-cards{{/has_visible_cards}}\\u000a{{#has_native_media}} has-native-media{{/has_native_media}}\\u000a{{#has_retweet_count}} with-social-proof{{/has_retweet_count}}\\u000a{{^has_retweet_count}}{{#tweet_stats}} with-social-proof{{/tweet_stats}}{{/has_retweet_count}}\\u000a{{#has_preloadable_media}} has-preloadable-media{{/has_preloadable_media}}\",\n            JSBNG__content: \"\\u003Cdiv class=\\\"content-main js-content-main breakable\\\"\\u003E\\u000a  \\u003Cdiv id=\\\"js-promptbird-below-black-bar-hook\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv id=\\\"js-empty-timeline-recommendations-module-hook\\\"\\u003E\\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"content-header js-stream-header\\\"\\u003E\\u000a    {{\\u003Estream_header}} \\u000a  \\u003C/div\\u003E\\u000a  \\u003Cdiv class=\\\"stream js-stream-manager-container\\\"\\u003E\\u000a    {{#rendering_on_server}}\\u000a      {{\\u003Estream_manager}}\\u000a      \\u003Cscript\\u003Eif (window.ttft) window.ttft.serverRendered('{{page_name}}');twttr.keynoteTTFTPing();\\u003C/script\\u003E\\u000a    {{/rendering_on_server}}\\u000a  \\u003C/div\\u003E\\u000a\\u003C/div\\u003E\\u000a\",\n            dashboard: \"\\u003Cdiv class=\\\"dashboard\\\"\\u003E\\u000a  {{#rendering_on_server}}\\u000a    {{\\u003Emini_home_profile}}\\u000a  {{/rendering_on_server}}\\u000a\\u003C/div\\u003E\\u000a\",\n            linked_tweet: \"{{#swift}}\\u000a  {{#render_withheld}}\\u000a    {{text}} \\u003Ca href=\\\"{{withheld_help_path}}\\\" target=\\\"_blank\\\"\\u003ELearn more\\u003C/a\\u003E\\u000a  {{/render_withheld}}\\u000a  {{^render_withheld}}\\u000a    {{#tweet_parts}}{{#entity}}\\u003Ca href=\\\"{{url}}\\\" {{#attributes}}{{name}}=\\\"{{value}}\\\" {{/attributes}}\\u003E{{#complex_link}}\\u003Cspan class=\\\"invisible\\\"\\u003E{{before_display_url}}\\u003C/span\\u003E\\u003Cspan class=\\\"js-display-url\\\"\\u003E{{display_sans_ellipsis}}\\u003C/span\\u003E\\u003Cspan class=\\\"invisible\\\"\\u003E{{after_display_url}}\\u003C/span\\u003E\\u003Cspan class=\\\"tco-ellipsis\\\"\\u003E\\u003Cspan class=\\\"invisible\\\"\\u003E&nbsp;\\u003C/span\\u003E{{following_ellipsis}}\\u003C/span\\u003E{{/complex_link}}{{^complex_link}}{{#prefix}}\\u003Cs\\u003E{{prefix}}\\u003C/s\\u003E\\u003Cb\\u003E{{text}}\\u003C/b\\u003E{{/prefix}}{{^prefix}}{{text}}{{/prefix}}{{/complex_link}}\\u003C/a\\u003E{{/entity}}{{^entity}}{{text}}{{/entity}}{{/tweet_parts}}\\u000a  {{/render_withheld}}\\u000a{{/swift}}\\u000a{{^swift}}\\u000a  {{{linkified_text}}}\\u000a{{/swift}}\\u000a\",\n            page: \"{{\\u003Edashboard}}\\u000a{{\\u003Econtent}}\",\n            promoted_disclosure: \"\\u003Ci class=\\\"{{promoted_badge_class}}\\\"\\u003E\\u003C/i\\u003E\\u000a\\u003Ca href=\\\"{{#user}}{{profile_path}}{{/user}}\\\"\\u000a   class=\\\"js-action-profile-promoted js-user-profile-link js-promoted-badge\\\"\\u000a   data-user-id=\\\"{{#user}}{{id}}{{/user}}\\\"\\u000a   {{#user}}{{#impression_cookie}}data-impression-cookie=\\\"{{impression_cookie}}\\\"{{/impression_cookie}}{{/user}}\\u000a\\u003EPromoted by {{advertiser_name}}\\u003C/a\\u003E\",\n            stream_header: \"\\u003Cdiv class=\\\"header-inner\\\"\\u003E\\u000a  \\u003Ch2\\u003E\\u000a    \\u003Cspan class=\\\"content-header-buttons js-header-button-container\\\"\\u003E\\u003C/span\\u003E\\u000a    \\u000a    \\u000a    \\u003Cspan class=\\\"js-stream-title\\\"\\u003E{{stream_title}}\\u003C/span\\u003E&nbsp;\\u003Csmall class=\\\"view-toggler js-view-toggler\\\"\\u003E\\u003C/small\\u003E\\u000a  \\u003C/h2\\u003E\\u000a  {{#header_help}}\\u003Cp class=\\\"js-header-help subheader\\\"\\u003E{{{header_help}}}\\u003C/p\\u003E{{/header_help}}\\u000a\\u003C/div\\u003E\\u000a\",\n            stream_tweet_expansion: \"\\u003Cdiv class=\\\"expanded-content js-tweet-details-dropdown\\\"\\u003E\\u000a  {{^on_permalink}}\\u000a    {{#preexpanded}}{{\\u003Etweet_details}}{{/preexpanded}}\\u000a  {{/on_permalink}}\\u000a\\u003C/div\\u003E\",\n            tweet_context: \"\\u000a\\u000a\\u000a\\u000a\\u003Cdiv class=\\\"context\\\"\\u003E\\u000a  {{#is_sponsored}}\\u000a    \\u003Cspan class=\\\"metadata with-icn js-disclosure js-tooltip\\\" title=\\\"{{disclosure_text}}\\\"\\u003E\\u000a      {{#was_retweeted}}\\u000a        {{#retweeting_status}}\\u000a          {{\\u003Epromoted_disclosure}}\\u000a        {{/retweeting_status}}\\u000a      {{/was_retweeted}}\\u000a      {{^was_retweeted}}\\u000a        {{\\u003Epromoted_disclosure}}\\u000a      {{/was_retweeted}}\\u000a    \\u003C/span\\u003E\\u000a    {{#in_home_page}}\\u000a      \\u003Cbutton type=\\\"button\\\" class=\\\"btn-link dismiss-promoted js-action-dismiss with-icn\\\"\\u003E\\u003Ci class=\\\"close\\\"\\u003E\\u003C/i\\u003E\\u003Cb\\u003E{{^abtest_dismiss_text_180_any_bucket}}Dismiss{{/abtest_dismiss_text_180_any_bucket}}{{#abtest_dismiss_text_180_dismiss_tweet}}Dismiss Tweet{{/abtest_dismiss_text_180_dismiss_tweet}}{{#abtest_dismiss_text_180_remove_tweet}}Remove Tweet{{/abtest_dismiss_text_180_remove_tweet}}{{#abtest_dismiss_text_180_not_interested}}Not interested{{/abtest_dismiss_text_180_not_interested}}\\u003C/b\\u003E\\u003C/button\\u003E\\u000a      {{#rendering_on_server}}\\u000a        \\u003Cspan class=\\\"social-context\\\"\\u003E{{\\u003Emini_social_proof}}\\u003C/span\\u003E\\u000a      {{/rendering_on_server}}\\u000a      {{^rendering_on_server}}\\u000a        {{{social_context}}}\\u000a      {{/rendering_on_server}}\\u000a    {{/in_home_page}}\\u000a  {{/is_sponsored}}\\u000a  {{#is_top_tweet}}\\u000a    \\u003Cspan class=\\\"metadata with-icn\\\"\\u003E\\u000a      \\u003Ci class=\\\"badge-top\\\"\\u003E\\u003C/i\\u003E{{#retweet_count}}Retweeted {{retweet_count}} times{{/retweet_count}}{{^retweet_count}}Top Tweet{{/retweet_count}}\\u000a    \\u003C/span\\u003E\\u000a  {{/is_top_tweet}}\\u000a  {{^is_sponsored}}\\u000a    {{#was_retweeted}}\\u000a      {{#retweeting_status}}\\u000a        {{#user}}\\u000a          \\u000a          {{^change_german_verbs}}\\u000a            \\u003Cspan class=\\\"with-icn\\\"\\u003E\\u003Ci class=\\\"badge-retweeted\\\"\\u003E\\u003C/i\\u003E\\u003Cspan class=\\\"js-retweet-text\\\"\\u003ERetweeted by \\u003Ca class=\\\"pretty-link js-user-profile-link\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u003Cb\\u003E{{name}}\\u003C/b\\u003E\\u003C/a\\u003E\\u003C/span\\u003E\\u003C/span\\u003E\\u000a          {{/change_german_verbs}}\\u000a          {{#change_german_verbs}}\\u000a            \\u003Cspan class=\\\"with-icn\\\"\\u003E\\u003Ci class=\\\"badge-retweeted\\\"\\u003E\\u003C/i\\u003E\\u003Cspan class=\\\"js-retweet-text\\\"\\u003EVon \\u003Ca class=\\\"pretty-link js-user-profile-link\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u003Cb\\u003E{{name}}\\u003C/b\\u003E\\u003C/a\\u003E geteilt\\u003C/span\\u003E\\u003C/span\\u003E\\u000a          {{/change_german_verbs}}\\u000a        {{/user}}\\u000a      {{/retweeting_status}}\\u000a    {{/was_retweeted}}\\u000a  {{/is_sponsored}}\\u000a\\u003C/div\\u003E\\u000a\",\n            tweet_data: \"\\u000adata-tweet-id=\\\"{{id}}\\\"\\u000a{{{tweet_impression_id}}}\\u000adata-item-id=\\\"{{id}}\\\"\\u000a{{#current_user_retweet}} data-my-retweet-id=\\\"{{id}}\\\"{{/current_user_retweet}}\\u000a{{#was_retweeted}}{{#retweeting_status}} data-retweet-id=\\\"{{id}}\\\"{{/retweeting_status}}{{/was_retweeted}}\\u000a{{#user}} data-screen-name=\\\"{{screen_name}}\\\" data-name=\\\"{{name}}\\\" data-user-id=\\\"{{id}}\\\"{{/user}}\\u000a{{#protected}} data-protected=\\\"true\\\"{{/protected}}\\u000a{{#is_sponsored}} data-promoted=\\\"true\\\"{{/is_sponsored}}\\u000a{{#show_geo_icon}} data-geo=\\\"true\\\"{{/show_geo_icon}}\\u000a{{#cards}} data-card-type=\\\"{{#photos}}photo{{/photos}}{{#summaries}}summary{{/summaries}}{{#players}}player{{/players}}\\\"{{/cards}}\\u000adata-is-reply-to=\\\"{{is_reply}}\\\"\\u000a{{#status_data}} data-status=\\\"{{status_data}}\\\"{{/status_data}}\\u000a{{#rendering_on_server}}{{^preexpanded}}data-expanded-footer=\\\"{{{escaped_tweet_details}}}{{#deprecated_escape_html_for_tweet_details}}{{\\u003Etweet_details}}{{/deprecated_escape_html_for_tweet_details}}\\\"{{/preexpanded}}{{/rendering_on_server}}\\u000a{{#possibly_sensitive}} data-possibly-sensitive=\\\"true\\\"{{/possibly_sensitive}}\\u000a{{#impression_cookie}} data-impression-cookie=\\\"{{impression_cookie}}\\\"{{/impression_cookie}}\\u000a{{#mentioned_screen_names}} data-mentions=\\\"{{mentioned_screen_names}}\\\"{{/mentioned_screen_names}}\\u000a{{#relevance_type}} data-relevance-type=\\\"{{relevance_type}}\\\"{{/relevance_type}}\\u000a\",\n            tweet_geo_text: \"{{#has_geo}}\\u000a  {{^show_geo_map}}\\u000a    \\u003Cdiv\\u003E\\u000a      \\u003Ca class=\\\"js-tweet-geo-text tweet-geo-text\\\" href=\\\"{{place_path}}\\\"\\u003E\\u000a        {{#place_name}}from {{place_name}}{{/place_name}}{{^place_name}}view location{{/place_name}}\\u000a      \\u003C/a\\u003E\\u000a    \\u003C/div\\u003E\\u000a  {{/show_geo_map}}\\u000a{{/has_geo}}\",\n            tweet_user_block: \"{{#user}}\\u000a  \\u003Ca {{#impression_cookie}}data-impression-cookie=\\\"{{impression_cookie}}\\\"{{/impression_cookie}} class=\\\"account-group js-account-group js-action-profile js-user-profile-link\\\" href=\\\"{{profile_path}}\\\" data-user-id=\\\"{{id}}\\\"\\u003E\\u000a    \\u003Cimg class=\\\"avatar js-action-profile-avatar\\\" src=\\\"{{profile_image_url}}\\\" alt=\\\"{{name}}\\\"\\u003E\\u000a    \\u003Cstrong class=\\\"fullname js-action-profile-name show-popup-with-id\\\"\\u003E{{name}}{{#show_verified_badge}}{{#verified}}\\u003Ci class=\\\"verified\\\"\\u003E\\u003Cspan class=\\\"hidden-elements\\\"\\u003EVerified\\u003C/span\\u003E\\u003C/i\\u003E{{/verified}}{{/show_verified_badge}}\\u003C/strong\\u003E\\u000a    \\u003Cspan\\u003E&rlm;\\u003C/span\\u003E\\u003Cspan class=\\\"username js-action-profile-name\\\"\\u003E\\u003Cs\\u003E@\\u003C/s\\u003E\\u003Cb\\u003E{{screen_name}}\\u003C/b\\u003E\\u003C/span\\u003E\\u000a    {{#protected}}\\u000a      \\u003Ci class=\\\"sm-lock\\\"\\u003E\\u003C/i\\u003E\\u000a    {{/protected}}\\u000a  \\u003C/a\\u003E\\u000a{{/user}}\\u000a\",\n            user_css_t1: \"\\u000a\\u003Cstyle id=\\\"user-style-{{style_namespace}}\\\" class=\\\"js-user-style\\\"\\u003E\\u000a\\u000a\\u000a\\u000a\\u000a\\u000a\\u000a\\u000a\\u000a\\u000aa,\\u000a\\u000a\\u000a\\u000a.btn-link,\\u000a\\u000a\\u000a\\u000a\\u000a  \\u000a  \\u000a\\u000a.pretty-link{{colon_hover}} s,\\u000a.pretty-link{{colon_hover}} b,\\u000a/* Account Group */\\u000a.metadata a{{colon_hover}},\\u000a\\u000a.account-group{{colon_hover}} .fullname,\\u000a\\u000a.stats a{{colon_hover}},\\u000a.stats a{{colon_hover}} strong,\\u000a\\u000a.profile-modal-header .fullname a{{colon_hover}},\\u000a.profile-modal-header .username a{{colon_hover}},\\u000a\\u000a.story-article{{colon_hover}} .metadata,\\u000a\\u000a.find-friends-sources li{{colon_hover}} .source,\\u000a\\u000a\\u000a\\u000a\\u000a\\u000a.stream-item a{{colon_hover}} .fullname,\\u000a\\u000a.stream-item .view-all-supplements{{colon_hover}},\\u000a\\u000a.tweet .time a{{colon_hover}},\\u000a.tweet{{colon_hover}} .user-dropdown .mark-as-spam-text,\\u000a.tweet-actions a,\\u000a.tweet .details.with-icn b,\\u000a\\u000a.stream-item{{colon_hover}} .original-tweet .expand-action-wrapper,\\u000a.opened-tweet.original-tweet  .expand-action-wrapper,\\u000a\\u000a.stream-item{{colon_hover}} .original-tweet .details b,\\u000a.stream-item.open .original-tweet .details b,\\u000a\\u000a.simple-tweet{{colon_hover}} .details b,\\u000a.simple-tweet.open .details b,\\u000a.simple-tweet{{colon_hover}} .details .expand-action-wrapper,\\u000a.simple-tweet.open .details .collapse-action-wrapper,\\u000a.simple-tweet{{colon_hover}} .details .simple-details-link,\\u000a\\u000a.client-and-actions a{{colon_hover}},\\u000a\\u000a.dismiss-promoted{{colon_hover}} b,\\u000a\\u000a.tweet .context .pretty-link{{colon_hover}} s,\\u000a.tweet .context .pretty-link{{colon_hover}} b,\\u000a\\u000a.list .username a{{colon_hover}},\\u000a.list-membership-container .create-a-list,\\u000a.list-membership-container .create-a-list{{colon_hover}},\\u000a\\u000a\\u000a\\u000a.story-header{{colon_hover}} .view-tweets,\\u000a.card .list-details a{{colon_hover}},\\u000a.card .card-body{{colon_hover}} .attribution,\\u000a.new-tweets-bar,\\u000a.JSBNG__onebox .soccer ul.ticker a{{colon_hover}},\\u000a\\u000a\\u000a\\u000a.discover-item-actions a,\\u000a\\u000a\\u000a\\u000a.remove-background-btn,\\u000a\\u000a\\u000a\\u000a.stream-item-activity-me .latest-tweet .tweet-row a{{colon_hover}} {\\u000a  {{#profile_link_color}}\\u000a    color: #{{profile_link_color}};\\u000a  {{/profile_link_color}}\\u000a  {{^profile_link_color}}\\u000a    color: #0084B4;\\u000a  {{/profile_link_color}}\\u000a}\\u000a\\u000a\\u000a\\u000a\\u000a\\u000a\\u000as,\\u000a.pretty-link{{colon_hover}} s,\\u000a.stream-item-activity-me .latest-tweet .tweet-row a{{colon_hover}} s {\\u000a  {{#profile_pretty_link_color}}\\u000a    color: #{{profile_pretty_link_color}};\\u000a  {{/profile_pretty_link_color}}\\u000a  {{^profile_pretty_link_color}}\\u000a    color: #66B5D2;\\u000a  {{/profile_pretty_link_color}}\\u000a}\\u000a\\u000a\\u000a\\u000a\\u000a\\u000a.tweet .sm-reply,\\u000a.tweet .sm-rt,\\u000a.tweet .sm-fav,\\u000a.tweet .sm-image,\\u000a.tweet .sm-video,\\u000a.tweet .sm-audio,\\u000a.tweet .sm-geo,\\u000a.tweet .sm-in,\\u000a.tweet .sm-trash,\\u000a.tweet .sm-page,\\u000a.tweet .sm-embed,\\u000a.tweet .sm-summary,\\u000a.tweet .sm-chat,\\u000a\\u000a.tweet .mark-as-spam-flag,\\u000a.tweet .mark-as-spam-silhouette,\\u000a\\u000a.timelines-navigation .active .profile-nav-icon,\\u000a.timelines-navigation .profile-nav-icon{{colon_hover}},\\u000a\\u000a.sm-top-tweet,\\u000a\\u000a\\u000a.discover-item .js-action-card-search{{colon_hover}} .sm-search {\\u000a  {{#profile_link_color}}\\u000a    background-color: #{{profile_link_color}};\\u000a  {{/profile_link_color}}\\u000a  {{^profile_link_color}}\\u000a    background-color: #6684B4;\\u000a  {{/profile_link_color}}\\u000a}\\u000a\\u000abody {\\u000a  {{#profile_use_background_image}}\\u000a    background-position: {{#center_background}}center{{/center_background}}{{^center_background}}left{{/center_background}} 40px;\\u000a    background-attachment: fixed;\\u000a    background-repeat: repeat;\\u000a    {{^profile_background_tile}}\\u000a      background-repeat: no-repeat;\\u000a    {{/profile_background_tile}}\\u000a  {{/profile_use_background_image}}\\u000a  {{#profile_background_color}}\\u000a    background-color: #{{profile_background_color}};\\u000a  {{/profile_background_color}}\\u000a  {{^profile_background_color}}\\u000a    background-color: #c0deed;\\u000a  {{/profile_background_color}}\\u000a}\\u000a\\u003C/style\\u003E\\u000a\",\n            withheld_message: \"\\u003Cdiv class=\\\"withheld-message\\\"\\u003E{{text}}  \\u003Ca href={{#is_withheld_copyright}}\\\"{{withheld_copyright_help_path}}\\\"{{/is_withheld_copyright}}{{^is_withheld_copyright}}\\\"{{withheld_help_path}}\\\"{{/is_withheld_copyright}} target=\\\"_blank\\\"\\u003ELearn more\\u003C/a\\u003E\\u003C/div\\u003E\\u000a\"\n        });\n    }\n;\n;\n    exports();\n});\nprovide(\"$lib/jquery-1.7.1.js\", function(a) {\n    (function(a, b) {\n        function c(a) {\n            var b = M[a] = {\n            }, c, d;\n            a = a.split(/\\s+/);\n            for (c = 0, d = a.length; ((c < d)); c++) {\n                b[a[c]] = !0;\n            ;\n            };\n        ;\n            return b;\n        };\n    ;\n        function d(a, c, d) {\n            if (((((d === b)) && ((a.nodeType === 1))))) {\n                var e = ((\"data-\" + c.replace(P, \"-$1\").toLowerCase()));\n                d = a.getAttribute(e);\n                if (((typeof d == \"string\"))) {\n                    try {\n                        d = ((((d === \"true\")) ? !0 : ((((d === \"false\")) ? !1 : ((((d === \"null\")) ? null : ((L.isNumeric(d) ? parseFloat(d) : ((O.test(d) ? L.parseJSON(d) : d))))))))));\n                    } catch (f) {\n                    \n                    };\n                ;\n                    L.data(a, c, d);\n                }\n                 else d = b;\n            ;\n            ;\n            }\n        ;\n        ;\n            return d;\n        };\n    ;\n        function e(a) {\n            for (var b in a) {\n                if (((((b === \"data\")) && L.isEmptyObject(a[b])))) {\n                    continue;\n                }\n            ;\n            ;\n                if (((b !== \"toJSON\"))) {\n                    return !1;\n                }\n            ;\n            ;\n            };\n        ;\n            return !0;\n        };\n    ;\n        function f(a, b, c) {\n            var d = ((b + \"defer\")), e = ((b + \"queue\")), f = ((b + \"mark\")), g = L._data(a, d);\n            ((((((g && ((((c === \"queue\")) || !L._data(a, e))))) && ((((c === \"mark\")) || !L._data(a, f))))) && JSBNG__setTimeout(function() {\n                ((((!L._data(a, e) && !L._data(a, f))) && (L.removeData(a, d, !0), g.fire())));\n            }, 0)));\n        };\n    ;\n        function g() {\n            return !1;\n        };\n    ;\n        function i() {\n            return !0;\n        };\n    ;\n        function j(a) {\n            return ((((!a || !a.parentNode)) || ((a.parentNode.nodeType === 11))));\n        };\n    ;\n        function k(a, b, c) {\n            b = ((b || 0));\n            if (L.isFunction(b)) {\n                return L.grep(a, function(a, d) {\n                    var e = !!b.call(a, d, a);\n                    return ((e === c));\n                });\n            }\n        ;\n        ;\n            if (b.nodeType) {\n                return L.grep(a, function(a, d) {\n                    return ((((a === b)) === c));\n                });\n            }\n        ;\n        ;\n            if (((typeof b == \"string\"))) {\n                var d = L.grep(a, function(a) {\n                    return ((a.nodeType === 1));\n                });\n                if (ob.test(b)) {\n                    return L.filter(b, d, !c);\n                }\n            ;\n            ;\n                b = L.filter(b, d);\n            }\n        ;\n        ;\n            return L.grep(a, function(a, d) {\n                return ((((L.inArray(a, b) >= 0)) === c));\n            });\n        };\n    ;\n        function l(a) {\n            var b = sb.split(\"|\"), c = a.createDocumentFragment();\n            if (c.createElement) {\n                while (b.length) {\n                    c.createElement(b.pop());\n                ;\n                };\n            }\n        ;\n        ;\n            return c;\n        };\n    ;\n        function m(a, b) {\n            return ((L.nodeName(a, \"table\") ? ((a.getElementsByTagName(\"tbody\")[0] || a.appendChild(a.ownerDocument.createElement(\"tbody\")))) : a));\n        };\n    ;\n        function n(a, b) {\n            if (((((b.nodeType !== 1)) || !L.hasData(a)))) {\n                return;\n            }\n        ;\n        ;\n            var c, d, e, f = L._data(a), g = L._data(b, f), i = f.events;\n            if (i) {\n                delete g.handle, g.events = {\n                };\n                for (c in i) {\n                    for (d = 0, e = i[c].length; ((d < e)); d++) {\n                        L.JSBNG__event.add(b, ((((c + ((i[c][d].namespace ? \".\" : \"\")))) + i[c][d].namespace)), i[c][d], i[c][d].data);\n                    ;\n                    };\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            ((g.data && (g.data = L.extend({\n            }, g.data))));\n        };\n    ;\n        function o(a, b) {\n            var c;\n            if (((b.nodeType !== 1))) {\n                return;\n            }\n        ;\n        ;\n            ((b.clearAttributes && b.clearAttributes())), ((b.mergeAttributes && b.mergeAttributes(a))), c = b.nodeName.toLowerCase();\n            if (((c === \"object\"))) {\n                b.outerHTML = a.outerHTML;\n            }\n             else {\n                if (((((c !== \"input\")) || ((((a.type !== \"checkbox\")) && ((a.type !== \"radio\"))))))) {\n                    if (((c === \"option\"))) {\n                        b.selected = a.defaultSelected;\n                    }\n                     else {\n                        if (((((c === \"input\")) || ((c === \"textarea\"))))) {\n                            b.defaultValue = a.defaultValue;\n                        }\n                    ;\n                    }\n                ;\n                ;\n                }\n                 else ((a.checked && (b.defaultChecked = b.checked = a.checked))), ((((b.value !== a.value)) && (b.value = a.value)));\n            ;\n            }\n        ;\n        ;\n            b.removeAttribute(L.expando);\n        };\n    ;\n        function p(a) {\n            return ((((typeof a.getElementsByTagName != \"undefined\")) ? a.getElementsByTagName(\"*\") : ((((typeof a.querySelectorAll != \"undefined\")) ? a.querySelectorAll(\"*\") : []))));\n        };\n    ;\n        function q(a) {\n            if (((((a.type === \"checkbox\")) || ((a.type === \"radio\"))))) {\n                a.defaultChecked = a.checked;\n            }\n        ;\n        ;\n        };\n    ;\n        function r(a) {\n            var b = ((a.nodeName || \"\")).toLowerCase();\n            ((((b === \"input\")) ? q(a) : ((((((b !== \"script\")) && ((typeof a.getElementsByTagName != \"undefined\")))) && L.grep(a.getElementsByTagName(\"input\"), q)))));\n        };\n    ;\n        function s(a) {\n            var b = I.createElement(\"div\");\n            return Gb.appendChild(b), b.innerHTML = a.outerHTML, b.firstChild;\n        };\n    ;\n        function t(a, b) {\n            ((b.src ? L.ajax({\n                url: b.src,\n                async: !1,\n                dataType: \"script\"\n            }) : L.globalEval(((((((b.text || b.textContent)) || b.innerHTML)) || \"\")).replace(Eb, \"/*$0*/\")))), ((b.parentNode && b.parentNode.removeChild(b)));\n        };\n    ;\n        function u(a, b, c) {\n            var d = ((((b === \"width\")) ? a.offsetWidth : a.offsetHeight)), e = ((((b === \"width\")) ? Ob : Pb)), f = 0, g = e.length;\n            if (((d > 0))) {\n                if (((c !== \"border\"))) {\n                    for (; ((f < g)); f++) {\n                        ((c || (d -= ((parseFloat(L.css(a, ((\"padding\" + e[f])))) || 0))))), ((((c === \"margin\")) ? d += ((parseFloat(L.css(a, ((c + e[f])))) || 0)) : d -= ((parseFloat(L.css(a, ((((\"border\" + e[f])) + \"Width\")))) || 0))));\n                    ;\n                    };\n                }\n            ;\n            ;\n                return ((d + \"px\"));\n            }\n        ;\n        ;\n            d = Qb(a, b, b);\n            if (((((d < 0)) || ((d == null))))) {\n                d = ((a.style[b] || 0));\n            }\n        ;\n        ;\n            d = ((parseFloat(d) || 0));\n            if (c) {\n                for (; ((f < g)); f++) {\n                    d += ((parseFloat(L.css(a, ((\"padding\" + e[f])))) || 0)), ((((c !== \"padding\")) && (d += ((parseFloat(L.css(a, ((((\"border\" + e[f])) + \"Width\")))) || 0))))), ((((c === \"margin\")) && (d += ((parseFloat(L.css(a, ((c + e[f])))) || 0)))));\n                ;\n                };\n            }\n        ;\n        ;\n            return ((d + \"px\"));\n        };\n    ;\n        function v(a) {\n            return function(b, c) {\n                ((((typeof b != \"string\")) && (c = b, b = \"*\")));\n                if (L.isFunction(c)) {\n                    var d = b.toLowerCase().split(dc), e = 0, f = d.length, g, i, j;\n                    for (; ((e < f)); e++) {\n                        g = d[e], j = /^\\+/.test(g), ((j && (g = ((g.substr(1) || \"*\"))))), i = a[g] = ((a[g] || [])), i[((j ? \"unshift\" : \"push\"))](c);\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n            };\n        };\n    ;\n        function w(a, c, d, e, f, g) {\n            f = ((f || c.dataTypes[0])), g = ((g || {\n            })), g[f] = !0;\n            var i = a[f], j = 0, k = ((i ? i.length : 0)), l = ((a === hc)), m;\n            for (; ((((j < k)) && ((l || !m)))); j++) {\n                m = i[j](c, d, e), ((((typeof m == \"string\")) && ((((!l || g[m])) ? m = b : (c.dataTypes.unshift(m), m = w(a, c, d, e, m, g))))));\n            ;\n            };\n        ;\n            return ((((((l || !m)) && !g[\"*\"])) && (m = w(a, c, d, e, \"*\", g)))), m;\n        };\n    ;\n        function x(a, c) {\n            var d, e, f = ((L.ajaxSettings.flatOptions || {\n            }));\n            for (d in c) {\n                ((((c[d] !== b)) && (((f[d] ? a : ((e || (e = {\n                })))))[d] = c[d])));\n            ;\n            };\n        ;\n            ((e && L.extend(!0, a, e)));\n        };\n    ;\n        function y(a, b, c, d) {\n            if (L.isArray(b)) {\n                L.each(b, function(b, e) {\n                    ((((c || Ub.test(a))) ? d(a, e) : y(((((((a + \"[\")) + ((((((typeof e == \"object\")) || L.isArray(e))) ? b : \"\")))) + \"]\")), e, c, d)));\n                });\n            }\n             else {\n                if (((((!c && ((b != null)))) && ((typeof b == \"object\"))))) {\n                    for (var e in b) {\n                        y(((((((a + \"[\")) + e)) + \"]\")), b[e], c, d);\n                    ;\n                    };\n                }\n                 else {\n                    d(a, b);\n                }\n            ;\n            }\n        ;\n        ;\n        };\n    ;\n        function z(a, c, d) {\n            var e = a.contents, f = a.dataTypes, g = a.responseFields, i, j, k, l;\n            for (j in g) {\n                ((((j in d)) && (c[g[j]] = d[j])));\n            ;\n            };\n        ;\n            while (((f[0] === \"*\"))) {\n                f.shift(), ((((i === b)) && (i = ((a.mimeType || c.getResponseHeader(\"content-type\"))))));\n            ;\n            };\n        ;\n            if (i) {\n                for (j in e) {\n                    if (((e[j] && e[j].test(i)))) {\n                        f.unshift(j);\n                        break;\n                    }\n                ;\n                ;\n                };\n            }\n        ;\n        ;\n            if (((f[0] in d))) k = f[0];\n             else {\n                for (j in d) {\n                    if (((!f[0] || a.converters[((((j + \" \")) + f[0]))]))) {\n                        k = j;\n                        break;\n                    }\n                ;\n                ;\n                    ((l || (l = j)));\n                };\n            ;\n                k = ((k || l));\n            }\n        ;\n        ;\n            if (k) {\n                return ((((k !== f[0])) && f.unshift(k))), d[k];\n            }\n        ;\n        ;\n        };\n    ;\n        function A(a, c) {\n            ((a.dataFilter && (c = a.dataFilter(c, a.dataType))));\n            var d = a.dataTypes, e = {\n            }, f, g, i = d.length, j, k = d[0], l, m, n, o, p;\n            for (f = 1; ((f < i)); f++) {\n                if (((f === 1))) {\n                    for (g in a.converters) {\n                        ((((typeof g == \"string\")) && (e[g.toLowerCase()] = a.converters[g])));\n                    ;\n                    };\n                }\n            ;\n            ;\n                l = k, k = d[f];\n                if (((k === \"*\"))) {\n                    k = l;\n                }\n                 else {\n                    if (((((l !== \"*\")) && ((l !== k))))) {\n                        m = ((((l + \" \")) + k)), n = ((e[m] || e[((\"* \" + k))]));\n                        if (!n) {\n                            p = b;\n                            for (o in e) {\n                                j = o.split(\" \");\n                                if (((((j[0] === l)) || ((j[0] === \"*\"))))) {\n                                    p = e[((((j[1] + \" \")) + k))];\n                                    if (p) {\n                                        o = e[o], ((((o === !0)) ? n = p : ((((p === !0)) && (n = o)))));\n                                        break;\n                                    }\n                                ;\n                                ;\n                                }\n                            ;\n                            ;\n                            };\n                        ;\n                        }\n                    ;\n                    ;\n                        ((((!n && !p)) && L.error(((\"No conversion from \" + m.replace(\" \", \" to \")))))), ((((n !== !0)) && (c = ((n ? n(c) : p(o(c)))))));\n                    }\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            return c;\n        };\n    ;\n        function B() {\n            try {\n                return new a.JSBNG__XMLHttpRequest;\n            } catch (b) {\n            \n            };\n        ;\n        };\n    ;\n        function C() {\n            try {\n                return new a.ActiveXObject(\"Microsoft.XMLHTTP\");\n            } catch (b) {\n            \n            };\n        ;\n        };\n    ;\n        function D() {\n            return JSBNG__setTimeout(E, 0), zc = L.now();\n        };\n    ;\n        function E() {\n            zc = b;\n        };\n    ;\n        function F(a, b) {\n            var c = {\n            };\n            return L.each(yc.concat.apply([], yc.slice(0, b)), function() {\n                c[this] = a;\n            }), c;\n        };\n    ;\n        function G(a) {\n            if (!sc[a]) {\n                var b = I.body, c = L(((((\"\\u003C\" + a)) + \"\\u003E\"))).appendTo(b), d = c.css(\"display\");\n                c.remove();\n                if (((((d === \"none\")) || ((d === \"\"))))) {\n                    ((tc || (tc = I.createElement(\"div\"), tc.frameBorder = tc.width = tc.height = 0))), b.appendChild(tc);\n                    if (((!uc || !tc.createElement))) {\n                        uc = ((tc.contentWindow || tc.contentDocument)).JSBNG__document, uc.write(((((((I.compatMode === \"CSS1Compat\")) ? \"\\u003C!doctype html\\u003E\" : \"\")) + \"\\u003Chtml\\u003E\\u003Cbody\\u003E\"))), uc.close();\n                    }\n                ;\n                ;\n                    c = uc.createElement(a), uc.body.appendChild(c), d = L.css(c, \"display\"), b.removeChild(tc);\n                }\n            ;\n            ;\n                sc[a] = d;\n            }\n        ;\n        ;\n            return sc[a];\n        };\n    ;\n        function H(a) {\n            return ((L.isWindow(a) ? a : ((((a.nodeType === 9)) ? ((a.defaultView || a.parentWindow)) : !1))));\n        };\n    ;\n        var I = a.JSBNG__document, J = a.JSBNG__navigator, K = a.JSBNG__location, L = function() {\n            function c() {\n                if (d.isReady) {\n                    return;\n                }\n            ;\n            ;\n                try {\n                    I.documentElement.doScroll(\"left\");\n                } catch (a) {\n                    JSBNG__setTimeout(c, 1);\n                    return;\n                };\n            ;\n                d.ready();\n            };\n        ;\n            var d = function(a, b) {\n                return new d.fn.init(a, b, g);\n            }, e = a.jQuery, f = a.$, g, i = /^(?:[^#<]*(<[\\w\\W]+>)[^>]*$|#([\\w\\-]*)$)/, j = /\\S/, k = /^\\s+/, l = /\\s+$/, m = /^<(\\w+)\\s*\\/?>(?:<\\/\\1>)?$/, n = /^[\\],:{}\\s]*$/, o = /\\\\(?:[\"\\\\\\/bfnrt]|u[0-9a-fA-F]{4})/g, p = /\"[^\"\\\\\\n\\r]*\"|true|false|null|-?\\d+(?:\\.\\d*)?(?:[eE][+\\-]?\\d+)?/g, q = /(?:^|:|,)(?:\\s*\\[)+/g, r = /(webkit)[ \\/]([\\w.]+)/, s = /(opera)(?:.*version)?[ \\/]([\\w.]+)/, t = /(msie) ([\\w.]+)/, u = /(mozilla)(?:.*? rv:([\\w.]+))?/, v = /-([a-z]|[0-9])/gi, w = /^-ms-/, x = function(a, b) {\n                return ((b + \"\")).toUpperCase();\n            }, y = J.userAgent, z, A, B, C = Object.prototype.toString, D = Object.prototype.hasOwnProperty, E = Array.prototype.push, F = Array.prototype.slice, G = String.prototype.trim, H = Array.prototype.indexOf, K = {\n            };\n            return d.fn = d.prototype = {\n                constructor: d,\n                init: function(a, c, e) {\n                    var f, g, j, k;\n                    if (!a) {\n                        return this;\n                    }\n                ;\n                ;\n                    if (a.nodeType) {\n                        return this.context = this[0] = a, this.length = 1, this;\n                    }\n                ;\n                ;\n                    if (((((((a === \"body\")) && !c)) && I.body))) {\n                        return this.context = I, this[0] = I.body, this.selector = a, this.length = 1, this;\n                    }\n                ;\n                ;\n                    if (((typeof a == \"string\"))) {\n                        ((((((((a.charAt(0) === \"\\u003C\")) && ((a.charAt(((a.length - 1))) === \"\\u003E\")))) && ((a.length >= 3)))) ? f = [null,a,null,] : f = i.exec(a)));\n                        if (((f && ((f[1] || !c))))) {\n                            if (f[1]) {\n                                return c = ((((c instanceof d)) ? c[0] : c)), k = ((c ? ((c.ownerDocument || c)) : I)), j = m.exec(a), ((j ? ((d.isPlainObject(c) ? (a = [I.createElement(j[1]),], d.fn.attr.call(a, c, !0)) : a = [k.createElement(j[1]),])) : (j = d.buildFragment([f[1],], [k,]), a = ((j.cacheable ? d.clone(j.fragment) : j.fragment)).childNodes))), d.merge(this, a);\n                            }\n                        ;\n                        ;\n                            g = I.getElementById(f[2]);\n                            if (((g && g.parentNode))) {\n                                if (((g.id !== f[2]))) {\n                                    return e.JSBNG__find(a);\n                                }\n                            ;\n                            ;\n                                this.length = 1, this[0] = g;\n                            }\n                        ;\n                        ;\n                            return this.context = I, this.selector = a, this;\n                        }\n                    ;\n                    ;\n                        return ((((!c || c.jquery)) ? ((c || e)).JSBNG__find(a) : this.constructor(c).JSBNG__find(a)));\n                    }\n                ;\n                ;\n                    return ((d.isFunction(a) ? e.ready(a) : (((((a.selector !== b)) && (this.selector = a.selector, this.context = a.context))), d.makeArray(a, this))));\n                },\n                selector: \"\",\n                jquery: \"1.7.1\",\n                length: 0,\n                size: function() {\n                    return this.length;\n                },\n                toArray: function() {\n                    return F.call(this, 0);\n                },\n                get: function(a) {\n                    return ((((a == null)) ? this.toArray() : ((((a < 0)) ? this[((this.length + a))] : this[a]))));\n                },\n                pushStack: function(a, b, c) {\n                    var e = this.constructor();\n                    return ((d.isArray(a) ? E.apply(e, a) : d.merge(e, a))), e.prevObject = this, e.context = this.context, ((((b === \"JSBNG__find\")) ? e.selector = ((((this.selector + ((this.selector ? \" \" : \"\")))) + c)) : ((b && (e.selector = ((((((((((this.selector + \".\")) + b)) + \"(\")) + c)) + \")\"))))))), e;\n                },\n                each: function(a, b) {\n                    return d.each(this, a, b);\n                },\n                ready: function(a) {\n                    return d.bindReady(), A.add(a), this;\n                },\n                eq: function(a) {\n                    return a = +a, ((((a === -1)) ? this.slice(a) : this.slice(a, ((a + 1)))));\n                },\n                first: function() {\n                    return this.eq(0);\n                },\n                last: function() {\n                    return this.eq(-1);\n                },\n                slice: function() {\n                    return this.pushStack(F.apply(this, arguments), \"slice\", F.call(arguments).join(\",\"));\n                },\n                map: function(a) {\n                    return this.pushStack(d.map(this, function(b, c) {\n                        return a.call(b, c, b);\n                    }));\n                },\n                end: function() {\n                    return ((this.prevObject || this.constructor(null)));\n                },\n                push: E,\n                sort: [].sort,\n                splice: [].splice\n            }, d.fn.init.prototype = d.fn, d.extend = d.fn.extend = function() {\n                var a, c, e, f, g, i, j = ((arguments[0] || {\n                })), k = 1, l = arguments.length, m = !1;\n                ((((typeof j == \"boolean\")) && (m = j, j = ((arguments[1] || {\n                })), k = 2))), ((((((typeof j != \"object\")) && !d.isFunction(j))) && (j = {\n                }))), ((((l === k)) && (j = this, --k)));\n                for (; ((k < l)); k++) {\n                    if ((((a = arguments[k]) != null))) {\n                        for (c in a) {\n                            e = j[c], f = a[c];\n                            if (((j === f))) {\n                                continue;\n                            }\n                        ;\n                        ;\n                            ((((((m && f)) && ((d.isPlainObject(f) || (g = d.isArray(f)))))) ? (((g ? (g = !1, i = ((((e && d.isArray(e))) ? e : []))) : i = ((((e && d.isPlainObject(e))) ? e : {\n                            })))), j[c] = d.extend(m, i, f)) : ((((f !== b)) && (j[c] = f)))));\n                        };\n                    }\n                ;\n                ;\n                };\n            ;\n                return j;\n            }, d.extend({\n                noConflict: function(b) {\n                    return ((((a.$ === d)) && (a.$ = f))), ((((b && ((a.jQuery === d)))) && (a.jQuery = e))), d;\n                },\n                isReady: !1,\n                readyWait: 1,\n                holdReady: function(a) {\n                    ((a ? d.readyWait++ : d.ready(!0)));\n                },\n                ready: function(a) {\n                    if (((((((a === !0)) && !--d.readyWait)) || ((((a !== !0)) && !d.isReady))))) {\n                        if (!I.body) {\n                            return JSBNG__setTimeout(d.ready, 1);\n                        }\n                    ;\n                    ;\n                        d.isReady = !0;\n                        if (((((a !== !0)) && ((--d.readyWait > 0))))) {\n                            return;\n                        }\n                    ;\n                    ;\n                        A.fireWith(I, [d,]), ((d.fn.trigger && d(I).trigger(\"ready\").off(\"ready\")));\n                    }\n                ;\n                ;\n                },\n                bindReady: function() {\n                    if (A) {\n                        return;\n                    }\n                ;\n                ;\n                    A = d.Callbacks(\"JSBNG__once memory\");\n                    if (((I.readyState === \"complete\"))) {\n                        return JSBNG__setTimeout(d.ready, 1);\n                    }\n                ;\n                ;\n                    if (I.JSBNG__addEventListener) {\n                        I.JSBNG__addEventListener(\"DOMContentLoaded\", B, !1), a.JSBNG__addEventListener(\"load\", d.ready, !1);\n                    }\n                     else {\n                        if (I.JSBNG__attachEvent) {\n                            I.JSBNG__attachEvent(\"JSBNG__onreadystatechange\", B), a.JSBNG__attachEvent(\"JSBNG__onload\", d.ready);\n                            var b = !1;\n                            try {\n                                b = ((a.JSBNG__frameElement == null));\n                            } catch (e) {\n                            \n                            };\n                        ;\n                            ((((I.documentElement.doScroll && b)) && c()));\n                        }\n                    ;\n                    }\n                ;\n                ;\n                },\n                isFunction: function(a) {\n                    return ((d.type(a) === \"function\"));\n                },\n                isArray: ((Array.isArray || function(a) {\n                    return ((d.type(a) === \"array\"));\n                })),\n                isWindow: function(a) {\n                    return ((((a && ((typeof a == \"object\")))) && ((\"JSBNG__setInterval\" in a))));\n                },\n                isNumeric: function(a) {\n                    return ((!isNaN(parseFloat(a)) && isFinite(a)));\n                },\n                type: function(a) {\n                    return ((((a == null)) ? String(a) : ((K[C.call(a)] || \"object\"))));\n                },\n                isPlainObject: function(a) {\n                    if (((((((!a || ((d.type(a) !== \"object\")))) || a.nodeType)) || d.isWindow(a)))) {\n                        return !1;\n                    }\n                ;\n                ;\n                    try {\n                        if (((((a.constructor && !D.call(a, \"constructor\"))) && !D.call(a.constructor.prototype, \"isPrototypeOf\")))) {\n                            return !1;\n                        }\n                    ;\n                    ;\n                    } catch (c) {\n                        return !1;\n                    };\n                ;\n                    var e;\n                    for (e in a) {\n                    ;\n                    };\n                ;\n                    return ((((e === b)) || D.call(a, e)));\n                },\n                isEmptyObject: function(a) {\n                    for (var b in a) {\n                        return !1;\n                    };\n                ;\n                    return !0;\n                },\n                error: function(a) {\n                    throw new Error(a);\n                },\n                parseJSON: function(b) {\n                    if (((((typeof b != \"string\")) || !b))) {\n                        return null;\n                    }\n                ;\n                ;\n                    b = d.trim(b);\n                    if (((a.JSON && a.JSON.parse))) {\n                        return a.JSON.parse(b);\n                    }\n                ;\n                ;\n                    if (n.test(b.replace(o, \"@\").replace(p, \"]\").replace(q, \"\"))) {\n                        return (new Function(((\"return \" + b))))();\n                    }\n                ;\n                ;\n                    d.error(((\"Invalid JSON: \" + b)));\n                },\n                parseXML: function(c) {\n                    var e, f;\n                    try {\n                        ((a.JSBNG__DOMParser ? (f = new JSBNG__DOMParser, e = f.parseFromString(c, \"text/xml\")) : (e = new ActiveXObject(\"Microsoft.XMLDOM\"), e.async = \"false\", e.loadXML(c))));\n                    } catch (g) {\n                        e = b;\n                    };\n                ;\n                    return ((((((!e || !e.documentElement)) || e.getElementsByTagName(\"parsererror\").length)) && d.error(((\"Invalid XML: \" + c))))), e;\n                },\n                noop: function() {\n                \n                },\n                globalEval: function(b) {\n                    ((((b && j.test(b))) && ((a.execScript || function(b) {\n                        a.eval.call(a, b);\n                    }))(b)));\n                },\n                camelCase: function(a) {\n                    return a.replace(w, \"ms-\").replace(v, x);\n                },\n                nodeName: function(a, b) {\n                    return ((a.nodeName && ((a.nodeName.toUpperCase() === b.toUpperCase()))));\n                },\n                each: function(a, c, e) {\n                    var f, g = 0, i = a.length, j = ((((i === b)) || d.isFunction(a)));\n                    if (e) {\n                        if (j) {\n                            for (f in a) {\n                                if (((c.apply(a[f], e) === !1))) {\n                                    break;\n                                }\n                            ;\n                            ;\n                            };\n                        ;\n                        }\n                         else for (; ((g < i)); ) {\n                            if (((c.apply(a[g++], e) === !1))) {\n                                break;\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                    }\n                     else if (j) {\n                        for (f in a) {\n                            if (((c.call(a[f], f, a[f]) === !1))) {\n                                break;\n                            }\n                        ;\n                        ;\n                        };\n                    ;\n                    }\n                     else for (; ((g < i)); ) {\n                        if (((c.call(a[g], g, a[g++]) === !1))) {\n                            break;\n                        }\n                    ;\n                    ;\n                    }\n                    \n                ;\n                ;\n                    return a;\n                },\n                trim: ((G ? function(a) {\n                    return ((((a == null)) ? \"\" : G.call(a)));\n                } : function(a) {\n                    return ((((a == null)) ? \"\" : a.toString().replace(k, \"\").replace(l, \"\")));\n                })),\n                makeArray: function(a, b) {\n                    var c = ((b || []));\n                    if (((a != null))) {\n                        var e = d.type(a);\n                        ((((((((((((a.length == null)) || ((e === \"string\")))) || ((e === \"function\")))) || ((e === \"regexp\")))) || d.isWindow(a))) ? E.call(c, a) : d.merge(c, a)));\n                    }\n                ;\n                ;\n                    return c;\n                },\n                inArray: function(a, b, c) {\n                    var d;\n                    if (b) {\n                        if (H) {\n                            return H.call(b, a, c);\n                        }\n                    ;\n                    ;\n                        d = b.length, c = ((c ? ((((c < 0)) ? Math.max(0, ((d + c))) : c)) : 0));\n                        for (; ((c < d)); c++) {\n                            if (((((c in b)) && ((b[c] === a))))) {\n                                return c;\n                            }\n                        ;\n                        ;\n                        };\n                    ;\n                    }\n                ;\n                ;\n                    return -1;\n                },\n                merge: function(a, c) {\n                    var d = a.length, e = 0;\n                    if (((typeof c.length == \"number\"))) {\n                        for (var f = c.length; ((e < f)); e++) {\n                            a[d++] = c[e];\n                        ;\n                        };\n                    }\n                     else {\n                        while (((c[e] !== b))) {\n                            a[d++] = c[e++];\n                        ;\n                        };\n                    }\n                ;\n                ;\n                    return a.length = d, a;\n                },\n                grep: function(a, b, c) {\n                    var d = [], e;\n                    c = !!c;\n                    for (var f = 0, g = a.length; ((f < g)); f++) {\n                        e = !!b(a[f], f), ((((c !== e)) && d.push(a[f])));\n                    ;\n                    };\n                ;\n                    return d;\n                },\n                map: function(a, c, e) {\n                    var f, g, i = [], j = 0, k = a.length, l = ((((a instanceof d)) || ((((((k !== b)) && ((typeof k == \"number\")))) && ((((((((((k > 0)) && a[0])) && a[((k - 1))])) || ((k === 0)))) || d.isArray(a)))))));\n                    if (l) {\n                        for (; ((j < k)); j++) {\n                            f = c(a[j], j, e), ((((f != null)) && (i[i.length] = f)));\n                        ;\n                        };\n                    }\n                     else {\n                        for (g in a) {\n                            f = c(a[g], g, e), ((((f != null)) && (i[i.length] = f)));\n                        ;\n                        };\n                    }\n                ;\n                ;\n                    return i.concat.apply([], i);\n                },\n                guid: 1,\n                proxy: function(a, c) {\n                    if (((typeof c == \"string\"))) {\n                        var e = a[c];\n                        c = a, a = e;\n                    }\n                ;\n                ;\n                    if (!d.isFunction(a)) {\n                        return b;\n                    }\n                ;\n                ;\n                    var f = F.call(arguments, 2), g = function() {\n                        return a.apply(c, f.concat(F.call(arguments)));\n                    };\n                    return g.guid = a.guid = ((((a.guid || g.guid)) || d.guid++)), g;\n                },\n                access: function(a, c, e, f, g, i) {\n                    var j = a.length;\n                    if (((typeof c == \"object\"))) {\n                        for (var k in c) {\n                            d.access(a, k, c[k], f, g, e);\n                        ;\n                        };\n                    ;\n                        return a;\n                    }\n                ;\n                ;\n                    if (((e !== b))) {\n                        f = ((((!i && f)) && d.isFunction(e)));\n                        for (var l = 0; ((l < j)); l++) {\n                            g(a[l], c, ((f ? e.call(a[l], l, g(a[l], c)) : e)), i);\n                        ;\n                        };\n                    ;\n                        return a;\n                    }\n                ;\n                ;\n                    return ((j ? g(a[0], c) : b));\n                },\n                now: function() {\n                    return (new JSBNG__Date).getTime();\n                },\n                uaMatch: function(a) {\n                    a = a.toLowerCase();\n                    var b = ((((((((r.exec(a) || s.exec(a))) || t.exec(a))) || ((((a.indexOf(\"compatible\") < 0)) && u.exec(a))))) || []));\n                    return {\n                        browser: ((b[1] || \"\")),\n                        version: ((b[2] || \"0\"))\n                    };\n                },\n                sub: function() {\n                    function a(b, c) {\n                        return new a.fn.init(b, c);\n                    };\n                ;\n                    d.extend(!0, a, this), a.superclass = this, a.fn = a.prototype = this(), a.fn.constructor = a, a.sub = this.sub, a.fn.init = function(c, e) {\n                        return ((((((e && ((e instanceof d)))) && !((e instanceof a)))) && (e = a(e)))), d.fn.init.call(this, c, e, b);\n                    }, a.fn.init.prototype = a.fn;\n                    var b = a(I);\n                    return a;\n                },\n                browser: {\n                }\n            }), d.each(\"Boolean Number String Function Array Date RegExp Object\".split(\" \"), function(a, b) {\n                K[((((\"[object \" + b)) + \"]\"))] = b.toLowerCase();\n            }), z = d.uaMatch(y), ((z.browser && (d.browser[z.browser] = !0, d.browser.version = z.version))), ((d.browser.webkit && (d.browser.safari = !0))), ((j.test(\"\\u00a0\") && (k = /^[\\s\\xA0]+/, l = /[\\s\\xA0]+$/))), g = d(I), ((I.JSBNG__addEventListener ? B = function() {\n                I.JSBNG__removeEventListener(\"DOMContentLoaded\", B, !1), d.ready();\n            } : ((I.JSBNG__attachEvent && (B = function() {\n                ((((I.readyState === \"complete\")) && (I.JSBNG__detachEvent(\"JSBNG__onreadystatechange\", B), d.ready())));\n            }))))), d;\n        }(), M = {\n        };\n        L.Callbacks = function(a) {\n            a = ((a ? ((M[a] || c(a))) : {\n            }));\n            var d = [], e = [], f, g, i, j, k, l = function(b) {\n                var c, e, f, g, i;\n                for (c = 0, e = b.length; ((c < e)); c++) {\n                    f = b[c], g = L.type(f), ((((g === \"array\")) ? l(f) : ((((((g === \"function\")) && ((!a.unique || !n.has(f))))) && d.push(f)))));\n                ;\n                };\n            ;\n            }, m = function(b, c) {\n                c = ((c || [])), f = ((!a.memory || [b,c,])), g = !0, k = ((i || 0)), i = 0, j = d.length;\n                for (; ((d && ((k < j)))); k++) {\n                    if (((((d[k].apply(b, c) === !1)) && a.stopOnFalse))) {\n                        f = !0;\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n                g = !1, ((d && ((a.JSBNG__once ? ((((f === !0)) ? n.disable() : d = [])) : ((((e && e.length)) && (f = e.shift(), n.fireWith(f[0], f[1]))))))));\n            }, n = {\n                add: function() {\n                    if (d) {\n                        var a = d.length;\n                        l(arguments), ((g ? j = d.length : ((((f && ((f !== !0)))) && (i = a, m(f[0], f[1]))))));\n                    }\n                ;\n                ;\n                    return this;\n                },\n                remove: function() {\n                    if (d) {\n                        var b = arguments, c = 0, e = b.length;\n                        for (; ((c < e)); c++) {\n                            for (var f = 0; ((f < d.length)); f++) {\n                                if (((b[c] === d[f]))) {\n                                    ((((g && ((f <= j)))) && (j--, ((((f <= k)) && k--))))), d.splice(f--, 1);\n                                    if (a.unique) {\n                                        break;\n                                    }\n                                ;\n                                ;\n                                }\n                            ;\n                            ;\n                            };\n                        ;\n                        };\n                    ;\n                    }\n                ;\n                ;\n                    return this;\n                },\n                has: function(a) {\n                    if (d) {\n                        var b = 0, c = d.length;\n                        for (; ((b < c)); b++) {\n                            if (((a === d[b]))) {\n                                return !0;\n                            }\n                        ;\n                        ;\n                        };\n                    ;\n                    }\n                ;\n                ;\n                    return !1;\n                },\n                empty: function() {\n                    return d = [], this;\n                },\n                disable: function() {\n                    return d = e = f = b, this;\n                },\n                disabled: function() {\n                    return !d;\n                },\n                lock: function() {\n                    return e = b, ((((!f || ((f === !0)))) && n.disable())), this;\n                },\n                locked: function() {\n                    return !e;\n                },\n                fireWith: function(b, c) {\n                    return ((e && ((g ? ((a.JSBNG__once || e.push([b,c,]))) : ((((!a.JSBNG__once || !f)) && m(b, c))))))), this;\n                },\n                fire: function() {\n                    return n.fireWith(this, arguments), this;\n                },\n                fired: function() {\n                    return !!f;\n                }\n            };\n            return n;\n        };\n        var N = [].slice;\n        L.extend({\n            Deferred: function(a) {\n                var b = L.Callbacks(\"JSBNG__once memory\"), c = L.Callbacks(\"JSBNG__once memory\"), d = L.Callbacks(\"memory\"), e = \"pending\", f = {\n                    resolve: b,\n                    reject: c,\n                    notify: d\n                }, g = {\n                    done: b.add,\n                    fail: c.add,\n                    progress: d.add,\n                    state: function() {\n                        return e;\n                    },\n                    isResolved: b.fired,\n                    isRejected: c.fired,\n                    then: function(a, b, c) {\n                        return i.done(a).fail(b).progress(c), this;\n                    },\n                    always: function() {\n                        return i.done.apply(i, arguments).fail.apply(i, arguments), this;\n                    },\n                    pipe: function(a, b, c) {\n                        return L.Deferred(function(d) {\n                            L.each({\n                                done: [a,\"resolve\",],\n                                fail: [b,\"reject\",],\n                                progress: [c,\"notify\",]\n                            }, function(a, b) {\n                                var c = b[0], e = b[1], f;\n                                ((L.isFunction(c) ? i[a](function() {\n                                    f = c.apply(this, arguments), ((((f && L.isFunction(f.promise))) ? f.promise().then(d.resolve, d.reject, d.notify) : d[((e + \"With\"))](((((this === i)) ? d : this)), [f,])));\n                                }) : i[a](d[e])));\n                            });\n                        }).promise();\n                    },\n                    promise: function(a) {\n                        if (((a == null))) {\n                            a = g;\n                        }\n                         else {\n                            for (var b in g) {\n                                a[b] = g[b];\n                            ;\n                            };\n                        }\n                    ;\n                    ;\n                        return a;\n                    }\n                }, i = g.promise({\n                }), j;\n                for (j in f) {\n                    i[j] = f[j].fire, i[((j + \"With\"))] = f[j].fireWith;\n                ;\n                };\n            ;\n                return i.done(function() {\n                    e = \"resolved\";\n                }, c.disable, d.lock).fail(function() {\n                    e = \"rejected\";\n                }, b.disable, d.lock), ((a && a.call(i, i))), i;\n            },\n            when: function(a) {\n                function b(a) {\n                    return function(b) {\n                        d[a] = ((((arguments.length > 1)) ? N.call(arguments, 0) : b)), ((--i || k.resolveWith(k, d)));\n                    };\n                };\n            ;\n                function c(a) {\n                    return function(b) {\n                        g[a] = ((((arguments.length > 1)) ? N.call(arguments, 0) : b)), k.notifyWith(l, g);\n                    };\n                };\n            ;\n                var d = N.call(arguments, 0), e = 0, f = d.length, g = new Array(f), i = f, j = f, k = ((((((((f <= 1)) && a)) && L.isFunction(a.promise))) ? a : L.Deferred())), l = k.promise();\n                if (((f > 1))) {\n                    for (; ((e < f)); e++) {\n                        ((((((d[e] && d[e].promise)) && L.isFunction(d[e].promise))) ? d[e].promise().then(b(e), k.reject, c(e)) : --i));\n                    ;\n                    };\n                ;\n                    ((i || k.resolveWith(k, d)));\n                }\n                 else ((((k !== a)) && k.resolveWith(k, ((f ? [a,] : [])))));\n            ;\n            ;\n                return l;\n            }\n        }), L.support = function() {\n            var b, c, d, e, f, g, i, j, k, l, m, n, o, p = I.createElement(\"div\"), q = I.documentElement;\n            p.setAttribute(\"className\", \"t\"), p.innerHTML = \"   \\u003Clink/\\u003E\\u003Ctable\\u003E\\u003C/table\\u003E\\u003Ca href='/a' style='top:1px;float:left;opacity:.55;'\\u003Ea\\u003C/a\\u003E\\u003Cinput type='checkbox'/\\u003E\", c = p.getElementsByTagName(\"*\"), d = p.getElementsByTagName(\"a\")[0];\n            if (((((!c || !c.length)) || !d))) {\n                return {\n                };\n            }\n        ;\n        ;\n            e = I.createElement(\"select\"), f = e.appendChild(I.createElement(\"option\")), g = p.getElementsByTagName(\"input\")[0], b = {\n                leadingWhitespace: ((p.firstChild.nodeType === 3)),\n                tbody: !p.getElementsByTagName(\"tbody\").length,\n                htmlSerialize: !!p.getElementsByTagName(\"link\").length,\n                style: /top/.test(d.getAttribute(\"style\")),\n                hrefNormalized: ((d.getAttribute(\"href\") === \"/a\")),\n                opacity: /^0.55/.test(d.style.opacity),\n                cssFloat: !!d.style.cssFloat,\n                checkOn: ((g.value === \"JSBNG__on\")),\n                optSelected: f.selected,\n                getSetAttribute: ((p.className !== \"t\")),\n                enctype: !!I.createElement(\"form\").enctype,\n                html5Clone: ((I.createElement(\"nav\").cloneNode(!0).outerHTML !== \"\\u003C:nav\\u003E\\u003C/:nav\\u003E\")),\n                submitBubbles: !0,\n                changeBubbles: !0,\n                focusinBubbles: !1,\n                deleteExpando: !0,\n                noCloneEvent: !0,\n                inlineBlockNeedsLayout: !1,\n                shrinkWrapBlocks: !1,\n                reliableMarginRight: !0\n            }, g.checked = !0, b.noCloneChecked = g.cloneNode(!0).checked, e.disabled = !0, b.optDisabled = !f.disabled;\n            try {\n                delete p.test;\n            } catch (r) {\n                b.deleteExpando = !1;\n            };\n        ;\n            ((((((!p.JSBNG__addEventListener && p.JSBNG__attachEvent)) && p.fireEvent)) && (p.JSBNG__attachEvent(\"JSBNG__onclick\", function() {\n                b.noCloneEvent = !1;\n            }), p.cloneNode(!0).fireEvent(\"JSBNG__onclick\")))), g = I.createElement(\"input\"), g.value = \"t\", g.setAttribute(\"type\", \"radio\"), b.radioValue = ((g.value === \"t\")), g.setAttribute(\"checked\", \"checked\"), p.appendChild(g), j = I.createDocumentFragment(), j.appendChild(p.lastChild), b.checkClone = j.cloneNode(!0).cloneNode(!0).lastChild.checked, b.appendChecked = g.checked, j.removeChild(g), j.appendChild(p), p.innerHTML = \"\", ((a.JSBNG__getComputedStyle && (i = I.createElement(\"div\"), i.style.width = \"0\", i.style.marginRight = \"0\", p.style.width = \"2px\", p.appendChild(i), b.reliableMarginRight = ((((parseInt(((a.JSBNG__getComputedStyle(i, null) || {\n                marginRight: 0\n            })).marginRight, 10) || 0)) === 0)))));\n            if (p.JSBNG__attachEvent) {\n                for (n in {\n                    submit: 1,\n                    change: 1,\n                    focusin: 1\n                }) {\n                    m = ((\"JSBNG__on\" + n)), o = ((m in p)), ((o || (p.setAttribute(m, \"return;\"), o = ((typeof p[m] == \"function\"))))), b[((n + \"Bubbles\"))] = o;\n                ;\n                };\n            }\n        ;\n        ;\n            return j.removeChild(p), j = e = f = i = p = g = null, L(function() {\n                var a, c, d, e, f, g, i, j, l, m, n, q = I.getElementsByTagName(\"body\")[0];\n                if (!q) {\n                    return;\n                }\n            ;\n            ;\n                i = 1, j = \"position:absolute;top:0;left:0;width:1px;height:1px;margin:0;\", l = \"visibility:hidden;border:0;\", m = ((((\"style='\" + j)) + \"border:5px solid #000;padding:0;'\")), n = ((((((((((((\"\\u003Cdiv \" + m)) + \"\\u003E\\u003Cdiv\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\")) + \"\\u003Ctable \")) + m)) + \" cellpadding='0' cellspacing='0'\\u003E\")) + \"\\u003Ctr\\u003E\\u003Ctd\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/table\\u003E\")), a = I.createElement(\"div\"), a.style.cssText = ((((((l + \"width:0;height:0;position:static;top:0;margin-top:\")) + i)) + \"px\")), q.insertBefore(a, q.firstChild), p = I.createElement(\"div\"), a.appendChild(p), p.innerHTML = \"\\u003Ctable\\u003E\\u003Ctr\\u003E\\u003Ctd style='padding:0;border:0;display:none'\\u003E\\u003C/td\\u003E\\u003Ctd\\u003Et\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/table\\u003E\", k = p.getElementsByTagName(\"td\"), o = ((k[0].offsetHeight === 0)), k[0].style.display = \"\", k[1].style.display = \"none\", b.reliableHiddenOffsets = ((o && ((k[0].offsetHeight === 0)))), p.innerHTML = \"\", p.style.width = p.style.paddingLeft = \"1px\", L.boxModel = b.boxModel = ((p.offsetWidth === 2)), ((((typeof p.style.zoom != \"undefined\")) && (p.style.display = \"inline\", p.style.zoom = 1, b.inlineBlockNeedsLayout = ((p.offsetWidth === 2)), p.style.display = \"\", p.innerHTML = \"\\u003Cdiv style='width:4px;'\\u003E\\u003C/div\\u003E\", b.shrinkWrapBlocks = ((p.offsetWidth !== 2))))), p.style.cssText = ((j + l)), p.innerHTML = n, c = p.firstChild, d = c.firstChild, f = c.nextSibling.firstChild.firstChild, g = {\n                    doesNotAddBorder: ((d.offsetTop !== 5)),\n                    doesAddBorderForTableAndCells: ((f.offsetTop === 5))\n                }, d.style.position = \"fixed\", d.style.JSBNG__top = \"20px\", g.fixedPosition = ((((d.offsetTop === 20)) || ((d.offsetTop === 15)))), d.style.position = d.style.JSBNG__top = \"\", c.style.overflow = \"hidden\", c.style.position = \"relative\", g.subtractsBorderForOverflowNotVisible = ((d.offsetTop === -5)), g.doesNotIncludeMarginInBodyOffset = ((q.offsetTop !== i)), q.removeChild(a), p = a = null, L.extend(b, g);\n            }), b;\n        }();\n        var O = /^(?:\\{.*\\}|\\[.*\\])$/, P = /([A-Z])/g;\n        L.extend({\n            cache: {\n            },\n            uuid: 0,\n            expando: ((\"jQuery\" + ((L.fn.jquery + Math.JSBNG__random())).replace(/\\D/g, \"\"))),\n            noData: {\n                embed: !0,\n                object: \"clsid:D27CDB6E-AE6D-11cf-96B8-444553540000\",\n                applet: !0\n            },\n            hasData: function(a) {\n                return a = ((a.nodeType ? L.cache[a[L.expando]] : a[L.expando])), ((!!a && !e(a)));\n            },\n            data: function(a, c, d, e) {\n                if (!L.acceptData(a)) {\n                    return;\n                }\n            ;\n            ;\n                var f, g, i, j = L.expando, k = ((typeof c == \"string\")), l = a.nodeType, m = ((l ? L.cache : a)), n = ((l ? a[j] : ((a[j] && j)))), o = ((c === \"events\"));\n                if (((((((((!n || !m[n])) || ((((!o && !e)) && !m[n].data)))) && k)) && ((d === b))))) {\n                    return;\n                }\n            ;\n            ;\n                ((n || ((l ? a[j] = n = ++L.uuid : n = j)))), ((m[n] || (m[n] = {\n                }, ((l || (m[n].toJSON = L.noop))))));\n                if (((((typeof c == \"object\")) || ((typeof c == \"function\"))))) {\n                    ((e ? m[n] = L.extend(m[n], c) : m[n].data = L.extend(m[n].data, c)));\n                }\n            ;\n            ;\n                return f = g = m[n], ((e || (((g.data || (g.data = {\n                }))), g = g.data))), ((((d !== b)) && (g[L.camelCase(c)] = d))), ((((o && !g[c])) ? f.events : (((k ? (i = g[c], ((((i == null)) && (i = g[L.camelCase(c)])))) : i = g)), i)));\n            },\n            removeData: function(a, b, c) {\n                if (!L.acceptData(a)) {\n                    return;\n                }\n            ;\n            ;\n                var d, f, g, i = L.expando, j = a.nodeType, k = ((j ? L.cache : a)), l = ((j ? a[i] : i));\n                if (!k[l]) {\n                    return;\n                }\n            ;\n            ;\n                if (b) {\n                    d = ((c ? k[l] : k[l].data));\n                    if (d) {\n                        ((L.isArray(b) || ((((b in d)) ? b = [b,] : (b = L.camelCase(b), ((((b in d)) ? b = [b,] : b = b.split(\" \"))))))));\n                        for (f = 0, g = b.length; ((f < g)); f++) {\n                            delete d[b[f]];\n                        ;\n                        };\n                    ;\n                        if (!((c ? e : L.isEmptyObject))(d)) {\n                            return;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                if (!c) {\n                    delete k[l].data;\n                    if (!e(k[l])) {\n                        return;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                ((((L.support.deleteExpando || !k.JSBNG__setInterval)) ? delete k[l] : k[l] = null)), ((j && ((L.support.deleteExpando ? delete a[i] : ((a.removeAttribute ? a.removeAttribute(i) : a[i] = null))))));\n            },\n            _data: function(a, b, c) {\n                return L.data(a, b, c, !0);\n            },\n            acceptData: function(a) {\n                if (a.nodeName) {\n                    var b = L.noData[a.nodeName.toLowerCase()];\n                    if (b) {\n                        return ((((b !== !0)) && ((a.getAttribute(\"classid\") === b))));\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                return !0;\n            }\n        }), L.fn.extend({\n            data: function(a, c) {\n                var e, f, g, i = null;\n                if (((typeof a == \"undefined\"))) {\n                    if (this.length) {\n                        i = L.data(this[0]);\n                        if (((((this[0].nodeType === 1)) && !L._data(this[0], \"parsedAttrs\")))) {\n                            f = this[0].attributes;\n                            for (var j = 0, k = f.length; ((j < k)); j++) {\n                                g = f[j].JSBNG__name, ((((g.indexOf(\"data-\") === 0)) && (g = L.camelCase(g.substring(5)), d(this[0], g, i[g]))));\n                            ;\n                            };\n                        ;\n                            L._data(this[0], \"parsedAttrs\", !0);\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    return i;\n                }\n            ;\n            ;\n                return ((((typeof a == \"object\")) ? this.each(function() {\n                    L.data(this, a);\n                }) : (e = a.split(\".\"), e[1] = ((e[1] ? ((\".\" + e[1])) : \"\")), ((((c === b)) ? (i = this.triggerHandler(((((\"getData\" + e[1])) + \"!\")), [e[0],]), ((((((i === b)) && this.length)) && (i = L.data(this[0], a), i = d(this[0], a, i)))), ((((((i === b)) && e[1])) ? this.data(e[0]) : i))) : this.each(function() {\n                    var b = L(this), d = [e[0],c,];\n                    b.triggerHandler(((((\"setData\" + e[1])) + \"!\")), d), L.data(this, a, c), b.triggerHandler(((((\"changeData\" + e[1])) + \"!\")), d);\n                }))))));\n            },\n            removeData: function(a) {\n                return this.each(function() {\n                    L.removeData(this, a);\n                });\n            }\n        }), L.extend({\n            _mark: function(a, b) {\n                ((a && (b = ((((b || \"fx\")) + \"mark\")), L._data(a, b, ((((L._data(a, b) || 0)) + 1))))));\n            },\n            _unmark: function(a, b, c) {\n                ((((a !== !0)) && (c = b, b = a, a = !1)));\n                if (b) {\n                    c = ((c || \"fx\"));\n                    var d = ((c + \"mark\")), e = ((a ? 0 : ((((L._data(b, d) || 1)) - 1))));\n                    ((e ? L._data(b, d, e) : (L.removeData(b, d, !0), f(b, c, \"mark\"))));\n                }\n            ;\n            ;\n            },\n            queue: function(a, b, c) {\n                var d;\n                if (a) {\n                    return b = ((((b || \"fx\")) + \"queue\")), d = L._data(a, b), ((c && ((((!d || L.isArray(c))) ? d = L._data(a, b, L.makeArray(c)) : d.push(c))))), ((d || []));\n                }\n            ;\n            ;\n            },\n            dequeue: function(a, b) {\n                b = ((b || \"fx\"));\n                var c = L.queue(a, b), d = c.shift(), e = {\n                };\n                ((((d === \"inprogress\")) && (d = c.shift()))), ((d && (((((b === \"fx\")) && c.unshift(\"inprogress\"))), L._data(a, ((b + \".run\")), e), d.call(a, function() {\n                    L.dequeue(a, b);\n                }, e)))), ((c.length || (L.removeData(a, ((((((b + \"queue \")) + b)) + \".run\")), !0), f(a, b, \"queue\"))));\n            }\n        }), L.fn.extend({\n            queue: function(a, c) {\n                return ((((typeof a != \"string\")) && (c = a, a = \"fx\"))), ((((c === b)) ? L.queue(this[0], a) : this.each(function() {\n                    var b = L.queue(this, a, c);\n                    ((((((a === \"fx\")) && ((b[0] !== \"inprogress\")))) && L.dequeue(this, a)));\n                })));\n            },\n            dequeue: function(a) {\n                return this.each(function() {\n                    L.dequeue(this, a);\n                });\n            },\n            delay: function(a, b) {\n                return a = ((L.fx ? ((L.fx.speeds[a] || a)) : a)), b = ((b || \"fx\")), this.queue(b, function(b, c) {\n                    var d = JSBNG__setTimeout(b, a);\n                    c.JSBNG__stop = function() {\n                        JSBNG__clearTimeout(d);\n                    };\n                });\n            },\n            clearQueue: function(a) {\n                return this.queue(((a || \"fx\")), []);\n            },\n            promise: function(a, c) {\n                function d() {\n                    ((--i || e.resolveWith(f, [f,])));\n                };\n            ;\n                ((((typeof a != \"string\")) && (c = a, a = b))), a = ((a || \"fx\"));\n                var e = L.Deferred(), f = this, g = f.length, i = 1, j = ((a + \"defer\")), k = ((a + \"queue\")), l = ((a + \"mark\")), m;\n                while (g--) {\n                    if (m = ((L.data(f[g], j, b, !0) || ((((L.data(f[g], k, b, !0) || L.data(f[g], l, b, !0))) && L.data(f[g], j, L.Callbacks(\"JSBNG__once memory\"), !0)))))) {\n                        i++, m.add(d);\n                    }\n                ;\n                ;\n                };\n            ;\n                return d(), e.promise();\n            }\n        });\n        var Q = /[\\n\\t\\r]/g, R = /\\s+/, S = /\\r/g, T = /^(?:button|input)$/i, U = /^(?:button|input|object|select|textarea)$/i, V = /^a(?:rea)?$/i, W = /^(?:autofocus|autoplay|async|checked|controls|defer|disabled|hidden|loop|multiple|open|readonly|required|scoped|selected)$/i, X = L.support.getSetAttribute, Y, Z, ab;\n        L.fn.extend({\n            attr: function(a, b) {\n                return L.access(this, a, b, !0, L.attr);\n            },\n            removeAttr: function(a) {\n                return this.each(function() {\n                    L.removeAttr(this, a);\n                });\n            },\n            prop: function(a, b) {\n                return L.access(this, a, b, !0, L.prop);\n            },\n            removeProp: function(a) {\n                return a = ((L.propFix[a] || a)), this.each(function() {\n                    try {\n                        this[a] = b, delete this[a];\n                    } catch (c) {\n                    \n                    };\n                ;\n                });\n            },\n            addClass: function(a) {\n                var b, c, d, e, f, g, i;\n                if (L.isFunction(a)) {\n                    return this.each(function(b) {\n                        L(this).addClass(a.call(this, b, this.className));\n                    });\n                }\n            ;\n            ;\n                if (((a && ((typeof a == \"string\"))))) {\n                    b = a.split(R);\n                    for (c = 0, d = this.length; ((c < d)); c++) {\n                        e = this[c];\n                        if (((e.nodeType === 1))) {\n                            if (((!e.className && ((b.length === 1))))) e.className = a;\n                             else {\n                                f = ((((\" \" + e.className)) + \" \"));\n                                for (g = 0, i = b.length; ((g < i)); g++) {\n                                    ((~f.indexOf(((((\" \" + b[g])) + \" \"))) || (f += ((b[g] + \" \")))));\n                                ;\n                                };\n                            ;\n                                e.className = L.trim(f);\n                            }\n                        ;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n                return this;\n            },\n            removeClass: function(a) {\n                var c, d, e, f, g, i, j;\n                if (L.isFunction(a)) {\n                    return this.each(function(b) {\n                        L(this).removeClass(a.call(this, b, this.className));\n                    });\n                }\n            ;\n            ;\n                if (((((a && ((typeof a == \"string\")))) || ((a === b))))) {\n                    c = ((a || \"\")).split(R);\n                    for (d = 0, e = this.length; ((d < e)); d++) {\n                        f = this[d];\n                        if (((((f.nodeType === 1)) && f.className))) {\n                            if (a) {\n                                g = ((((\" \" + f.className)) + \" \")).replace(Q, \" \");\n                                for (i = 0, j = c.length; ((i < j)); i++) {\n                                    g = g.replace(((((\" \" + c[i])) + \" \")), \" \");\n                                ;\n                                };\n                            ;\n                                f.className = L.trim(g);\n                            }\n                             else f.className = \"\";\n                        ;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n                return this;\n            },\n            toggleClass: function(a, b) {\n                var c = typeof a, d = ((typeof b == \"boolean\"));\n                return ((L.isFunction(a) ? this.each(function(c) {\n                    L(this).toggleClass(a.call(this, c, this.className, b), b);\n                }) : this.each(function() {\n                    if (((c === \"string\"))) {\n                        var e, f = 0, g = L(this), i = b, j = a.split(R);\n                        while (e = j[f++]) {\n                            i = ((d ? i : !g.hasClass(e))), g[((i ? \"addClass\" : \"removeClass\"))](e);\n                        ;\n                        };\n                    ;\n                    }\n                     else if (((((c === \"undefined\")) || ((c === \"boolean\"))))) {\n                        ((this.className && L._data(this, \"__className__\", this.className))), this.className = ((((this.className || ((a === !1)))) ? \"\" : ((L._data(this, \"__className__\") || \"\"))));\n                    }\n                    \n                ;\n                ;\n                })));\n            },\n            hasClass: function(a) {\n                var b = ((((\" \" + a)) + \" \")), c = 0, d = this.length;\n                for (; ((c < d)); c++) {\n                    if (((((this[c].nodeType === 1)) && ((((((\" \" + this[c].className)) + \" \")).replace(Q, \" \").indexOf(b) > -1))))) {\n                        return !0;\n                    }\n                ;\n                ;\n                };\n            ;\n                return !1;\n            },\n            val: function(a) {\n                var c, d, e, f = this[0];\n                if (!arguments.length) {\n                    if (f) {\n                        return c = ((L.valHooks[f.nodeName.toLowerCase()] || L.valHooks[f.type])), ((((((c && ((\"get\" in c)))) && (((d = c.get(f, \"value\")) !== b)))) ? d : (d = f.value, ((((typeof d == \"string\")) ? d.replace(S, \"\") : ((((d == null)) ? \"\" : d)))))));\n                    }\n                ;\n                ;\n                    return;\n                }\n            ;\n            ;\n                return e = L.isFunction(a), this.each(function(d) {\n                    var f = L(this), g;\n                    if (((this.nodeType !== 1))) {\n                        return;\n                    }\n                ;\n                ;\n                    ((e ? g = a.call(this, d, f.val()) : g = a)), ((((g == null)) ? g = \"\" : ((((typeof g == \"number\")) ? g += \"\" : ((L.isArray(g) && (g = L.map(g, function(a) {\n                        return ((((a == null)) ? \"\" : ((a + \"\"))));\n                    })))))))), c = ((L.valHooks[this.nodeName.toLowerCase()] || L.valHooks[this.type]));\n                    if (((((!c || !((\"set\" in c)))) || ((c.set(this, g, \"value\") === b))))) {\n                        this.value = g;\n                    }\n                ;\n                ;\n                });\n            }\n        }), L.extend({\n            valHooks: {\n                option: {\n                    get: function(a) {\n                        var b = a.attributes.value;\n                        return ((((!b || b.specified)) ? a.value : a.text));\n                    }\n                },\n                select: {\n                    get: function(a) {\n                        var b, c, d, e, f = a.selectedIndex, g = [], i = a.options, j = ((a.type === \"select-one\"));\n                        if (((f < 0))) {\n                            return null;\n                        }\n                    ;\n                    ;\n                        c = ((j ? f : 0)), d = ((j ? ((f + 1)) : i.length));\n                        for (; ((c < d)); c++) {\n                            e = i[c];\n                            if (((((e.selected && ((L.support.optDisabled ? !e.disabled : ((e.getAttribute(\"disabled\") === null)))))) && ((!e.parentNode.disabled || !L.nodeName(e.parentNode, \"optgroup\")))))) {\n                                b = L(e).val();\n                                if (j) {\n                                    return b;\n                                }\n                            ;\n                            ;\n                                g.push(b);\n                            }\n                        ;\n                        ;\n                        };\n                    ;\n                        return ((((((j && !g.length)) && i.length)) ? L(i[f]).val() : g));\n                    },\n                    set: function(a, b) {\n                        var c = L.makeArray(b);\n                        return L(a).JSBNG__find(\"option\").each(function() {\n                            this.selected = ((L.inArray(L(this).val(), c) >= 0));\n                        }), ((c.length || (a.selectedIndex = -1))), c;\n                    }\n                }\n            },\n            attrFn: {\n                val: !0,\n                css: !0,\n                html: !0,\n                text: !0,\n                data: !0,\n                width: !0,\n                height: !0,\n                offset: !0\n            },\n            attr: function(a, c, d, e) {\n                var f, g, i, j = a.nodeType;\n                if (((((((!a || ((j === 3)))) || ((j === 8)))) || ((j === 2))))) {\n                    return;\n                }\n            ;\n            ;\n                if (((e && ((c in L.attrFn))))) {\n                    return L(a)[c](d);\n                }\n            ;\n            ;\n                if (((typeof a.getAttribute == \"undefined\"))) {\n                    return L.prop(a, c, d);\n                }\n            ;\n            ;\n                i = ((((j !== 1)) || !L.isXMLDoc(a))), ((i && (c = c.toLowerCase(), g = ((L.attrHooks[c] || ((W.test(c) ? Z : Y)))))));\n                if (((d !== b))) {\n                    if (((d === null))) {\n                        L.removeAttr(a, c);\n                        return;\n                    }\n                ;\n                ;\n                    return ((((((((g && ((\"set\" in g)))) && i)) && (((f = g.set(a, d, c)) !== b)))) ? f : (a.setAttribute(c, ((\"\" + d))), d)));\n                }\n            ;\n            ;\n                return ((((((((g && ((\"get\" in g)))) && i)) && (((f = g.get(a, c)) !== null)))) ? f : (f = a.getAttribute(c), ((((f === null)) ? b : f)))));\n            },\n            removeAttr: function(a, b) {\n                var c, d, e, f, g = 0;\n                if (((b && ((a.nodeType === 1))))) {\n                    d = b.toLowerCase().split(R), f = d.length;\n                    for (; ((g < f)); g++) {\n                        e = d[g], ((e && (c = ((L.propFix[e] || e)), L.attr(a, e, \"\"), a.removeAttribute(((X ? e : c))), ((((W.test(e) && ((c in a)))) && (a[c] = !1))))));\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n            },\n            attrHooks: {\n                type: {\n                    set: function(a, b) {\n                        if (((T.test(a.nodeName) && a.parentNode))) {\n                            L.error(\"type property can't be changed\");\n                        }\n                         else {\n                            if (((((!L.support.radioValue && ((b === \"radio\")))) && L.nodeName(a, \"input\")))) {\n                                var c = a.value;\n                                return a.setAttribute(\"type\", b), ((c && (a.value = c))), b;\n                            }\n                        ;\n                        }\n                    ;\n                    ;\n                    }\n                },\n                value: {\n                    get: function(a, b) {\n                        return ((((Y && L.nodeName(a, \"button\"))) ? Y.get(a, b) : ((((b in a)) ? a.value : null))));\n                    },\n                    set: function(a, b, c) {\n                        if (((Y && L.nodeName(a, \"button\")))) {\n                            return Y.set(a, b, c);\n                        }\n                    ;\n                    ;\n                        a.value = b;\n                    }\n                }\n            },\n            propFix: {\n                tabindex: \"tabIndex\",\n                readonly: \"readOnly\",\n                \"for\": \"htmlFor\",\n                class: \"className\",\n                maxlength: \"maxLength\",\n                cellspacing: \"cellSpacing\",\n                cellpadding: \"cellPadding\",\n                rowspan: \"rowSpan\",\n                colspan: \"colSpan\",\n                usemap: \"useMap\",\n                frameborder: \"frameBorder\",\n                contenteditable: \"contentEditable\"\n            },\n            prop: function(a, c, d) {\n                var e, f, g, i = a.nodeType;\n                if (((((((!a || ((i === 3)))) || ((i === 8)))) || ((i === 2))))) {\n                    return;\n                }\n            ;\n            ;\n                return g = ((((i !== 1)) || !L.isXMLDoc(a))), ((g && (c = ((L.propFix[c] || c)), f = L.propHooks[c]))), ((((d !== b)) ? ((((((f && ((\"set\" in f)))) && (((e = f.set(a, d, c)) !== b)))) ? e : a[c] = d)) : ((((((f && ((\"get\" in f)))) && (((e = f.get(a, c)) !== null)))) ? e : a[c]))));\n            },\n            propHooks: {\n                tabIndex: {\n                    get: function(a) {\n                        var c = a.getAttributeNode(\"tabindex\");\n                        return ((((c && c.specified)) ? parseInt(c.value, 10) : ((((U.test(a.nodeName) || ((V.test(a.nodeName) && a.href)))) ? 0 : b))));\n                    }\n                }\n            }\n        }), L.attrHooks.tabindex = L.propHooks.tabIndex, Z = {\n            get: function(a, c) {\n                var d, e = L.prop(a, c);\n                return ((((((e === !0)) || ((((((typeof e != \"boolean\")) && (d = a.getAttributeNode(c)))) && ((d.nodeValue !== !1)))))) ? c.toLowerCase() : b));\n            },\n            set: function(a, b, c) {\n                var d;\n                return ((((b === !1)) ? L.removeAttr(a, c) : (d = ((L.propFix[c] || c)), ((((d in a)) && (a[d] = !0))), a.setAttribute(c, c.toLowerCase())))), c;\n            }\n        }, ((X || (ab = {\n            JSBNG__name: !0,\n            id: !0\n        }, Y = L.valHooks.button = {\n            get: function(a, c) {\n                var d;\n                return d = a.getAttributeNode(c), ((((d && ((ab[c] ? ((d.nodeValue !== \"\")) : d.specified)))) ? d.nodeValue : b));\n            },\n            set: function(a, b, c) {\n                var d = a.getAttributeNode(c);\n                return ((d || (d = I.createAttribute(c), a.setAttributeNode(d)))), d.nodeValue = ((b + \"\"));\n            }\n        }, L.attrHooks.tabindex.set = Y.set, L.each([\"width\",\"height\",], function(a, b) {\n            L.attrHooks[b] = L.extend(L.attrHooks[b], {\n                set: function(a, c) {\n                    if (((c === \"\"))) {\n                        return a.setAttribute(b, \"auto\"), c;\n                    }\n                ;\n                ;\n                }\n            });\n        }), L.attrHooks.contenteditable = {\n            get: Y.get,\n            set: function(a, b, c) {\n                ((((b === \"\")) && (b = \"false\"))), Y.set(a, b, c);\n            }\n        }))), ((L.support.hrefNormalized || L.each([\"href\",\"src\",\"width\",\"height\",], function(a, c) {\n            L.attrHooks[c] = L.extend(L.attrHooks[c], {\n                get: function(a) {\n                    var d = a.getAttribute(c, 2);\n                    return ((((d === null)) ? b : d));\n                }\n            });\n        }))), ((L.support.style || (L.attrHooks.style = {\n            get: function(a) {\n                return ((a.style.cssText.toLowerCase() || b));\n            },\n            set: function(a, b) {\n                return a.style.cssText = ((\"\" + b));\n            }\n        }))), ((L.support.optSelected || (L.propHooks.selected = L.extend(L.propHooks.selected, {\n            get: function(a) {\n                var b = a.parentNode;\n                return ((b && (b.selectedIndex, ((b.parentNode && b.parentNode.selectedIndex))))), null;\n            }\n        })))), ((L.support.enctype || (L.propFix.enctype = \"encoding\"))), ((L.support.checkOn || L.each([\"radio\",\"checkbox\",], function() {\n            L.valHooks[this] = {\n                get: function(a) {\n                    return ((((a.getAttribute(\"value\") === null)) ? \"JSBNG__on\" : a.value));\n                }\n            };\n        }))), L.each([\"radio\",\"checkbox\",], function() {\n            L.valHooks[this] = L.extend(L.valHooks[this], {\n                set: function(a, b) {\n                    if (L.isArray(b)) {\n                        return a.checked = ((L.inArray(L(a).val(), b) >= 0));\n                    }\n                ;\n                ;\n                }\n            });\n        });\n        var bb = /^(?:textarea|input|select)$/i, cb = /^([^\\.]*)?(?:\\.(.+))?$/, db = /\\bhover(\\.\\S+)?\\b/, eb = /^key/, fb = /^(?:mouse|contextmenu)|click/, gb = /^(?:focusinfocus|focusoutblur)$/, hb = /^(\\w*)(?:#([\\w\\-]+))?(?:\\.([\\w\\-]+))?$/, ib = function(a) {\n            var b = hb.exec(a);\n            return ((b && (b[1] = ((b[1] || \"\")).toLowerCase(), b[3] = ((b[3] && new RegExp(((((\"(?:^|\\\\s)\" + b[3])) + \"(?:\\\\s|$)\")))))))), b;\n        }, jb = function(a, b) {\n            var c = ((a.attributes || {\n            }));\n            return ((((((!b[1] || ((a.nodeName.toLowerCase() === b[1])))) && ((!b[2] || ((((c.id || {\n            })).value === b[2])))))) && ((!b[3] || b[3].test(((c[\"class\"] || {\n            })).value)))));\n        }, kb = function(a) {\n            return ((L.JSBNG__event.special.hover ? a : a.replace(db, \"mouseenter$1 mouseleave$1\")));\n        };\n        L.JSBNG__event = {\n            add: function(a, c, d, e, f) {\n                var g, i, j, k, l, m, n, o, p, q, r, s;\n                if (((((((((((a.nodeType === 3)) || ((a.nodeType === 8)))) || !c)) || !d)) || !(g = L._data(a))))) {\n                    return;\n                }\n            ;\n            ;\n                ((d.handler && (p = d, d = p.handler))), ((d.guid || (d.guid = L.guid++))), j = g.events, ((j || (g.events = j = {\n                }))), i = g.handle, ((i || (g.handle = i = function(a) {\n                    return ((((((typeof L == \"undefined\")) || ((!!a && ((L.JSBNG__event.triggered === a.type)))))) ? b : L.JSBNG__event.dispatch.apply(i.elem, arguments)));\n                }, i.elem = a))), c = L.trim(kb(c)).split(\" \");\n                for (k = 0; ((k < c.length)); k++) {\n                    l = ((cb.exec(c[k]) || [])), m = l[1], n = ((l[2] || \"\")).split(\".\").sort(), s = ((L.JSBNG__event.special[m] || {\n                    })), m = ((((f ? s.delegateType : s.bindType)) || m)), s = ((L.JSBNG__event.special[m] || {\n                    })), o = L.extend({\n                        type: m,\n                        origType: l[1],\n                        data: e,\n                        handler: d,\n                        guid: d.guid,\n                        selector: f,\n                        quick: ib(f),\n                        namespace: n.join(\".\")\n                    }, p), r = j[m];\n                    if (!r) {\n                        r = j[m] = [], r.delegateCount = 0;\n                        if (((!s.setup || ((s.setup.call(a, e, n, i) === !1))))) {\n                            ((a.JSBNG__addEventListener ? a.JSBNG__addEventListener(m, i, !1) : ((a.JSBNG__attachEvent && a.JSBNG__attachEvent(((\"JSBNG__on\" + m)), i)))));\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    ((s.add && (s.add.call(a, o), ((o.handler.guid || (o.handler.guid = d.guid)))))), ((f ? r.splice(r.delegateCount++, 0, o) : r.push(o))), L.JSBNG__event.global[m] = !0;\n                };\n            ;\n                a = null;\n            },\n            global: {\n            },\n            remove: function(a, b, c, d, e) {\n                var f = ((L.hasData(a) && L._data(a))), g, i, j, k, l, m, n, o, p, q, r, s;\n                if (((!f || !(o = f.events)))) {\n                    return;\n                }\n            ;\n            ;\n                b = L.trim(kb(((b || \"\")))).split(\" \");\n                for (g = 0; ((g < b.length)); g++) {\n                    i = ((cb.exec(b[g]) || [])), j = k = i[1], l = i[2];\n                    if (!j) {\n                        for (j in o) {\n                            L.JSBNG__event.remove(a, ((j + b[g])), c, d, !0);\n                        ;\n                        };\n                    ;\n                        continue;\n                    }\n                ;\n                ;\n                    p = ((L.JSBNG__event.special[j] || {\n                    })), j = ((((d ? p.delegateType : p.bindType)) || j)), r = ((o[j] || [])), m = r.length, l = ((l ? new RegExp(((((\"(^|\\\\.)\" + l.split(\".\").sort().join(\"\\\\.(?:.*\\\\.)?\"))) + \"(\\\\.|$)\"))) : null));\n                    for (n = 0; ((n < r.length)); n++) {\n                        s = r[n], ((((((((((e || ((k === s.origType)))) && ((!c || ((c.guid === s.guid)))))) && ((!l || l.test(s.namespace))))) && ((((!d || ((d === s.selector)))) || ((((d === \"**\")) && s.selector)))))) && (r.splice(n--, 1), ((s.selector && r.delegateCount--)), ((p.remove && p.remove.call(a, s))))));\n                    ;\n                    };\n                ;\n                    ((((((r.length === 0)) && ((m !== r.length)))) && (((((!p.teardown || ((p.teardown.call(a, l) === !1)))) && L.removeEvent(a, j, f.handle))), delete o[j])));\n                };\n            ;\n                ((L.isEmptyObject(o) && (q = f.handle, ((q && (q.elem = null))), L.removeData(a, [\"events\",\"handle\",], !0))));\n            },\n            customEvent: {\n                getData: !0,\n                setData: !0,\n                changeData: !0\n            },\n            trigger: function(c, d, e, f) {\n                if (((!e || ((((e.nodeType !== 3)) && ((e.nodeType !== 8))))))) {\n                    var g = ((c.type || c)), i = [], j, k, l, m, n, o, p, q, r, s;\n                    if (gb.test(((g + L.JSBNG__event.triggered)))) {\n                        return;\n                    }\n                ;\n                ;\n                    ((((g.indexOf(\"!\") >= 0)) && (g = g.slice(0, -1), k = !0))), ((((g.indexOf(\".\") >= 0)) && (i = g.split(\".\"), g = i.shift(), i.sort())));\n                    if (((((!e || L.JSBNG__event.customEvent[g])) && !L.JSBNG__event.global[g]))) {\n                        return;\n                    }\n                ;\n                ;\n                    c = ((((typeof c == \"object\")) ? ((c[L.expando] ? c : new L.JSBNG__Event(g, c))) : new L.JSBNG__Event(g))), c.type = g, c.isTrigger = !0, c.exclusive = k, c.namespace = i.join(\".\"), c.namespace_re = ((c.namespace ? new RegExp(((((\"(^|\\\\.)\" + i.join(\"\\\\.(?:.*\\\\.)?\"))) + \"(\\\\.|$)\"))) : null)), o = ((((g.indexOf(\":\") < 0)) ? ((\"JSBNG__on\" + g)) : \"\"));\n                    if (!e) {\n                        j = L.cache;\n                        for (l in j) {\n                            ((((j[l].events && j[l].events[g])) && L.JSBNG__event.trigger(c, d, j[l].handle.elem, !0)));\n                        ;\n                        };\n                    ;\n                        return;\n                    }\n                ;\n                ;\n                    c.result = b, ((c.target || (c.target = e))), d = ((((d != null)) ? L.makeArray(d) : [])), d.unshift(c), p = ((L.JSBNG__event.special[g] || {\n                    }));\n                    if (((p.trigger && ((p.trigger.apply(e, d) === !1))))) {\n                        return;\n                    }\n                ;\n                ;\n                    r = [[e,((p.bindType || g)),],];\n                    if (((((!f && !p.noBubble)) && !L.isWindow(e)))) {\n                        s = ((p.delegateType || g)), m = ((gb.test(((s + g))) ? e : e.parentNode)), n = null;\n                        for (; m; m = m.parentNode) {\n                            r.push([m,s,]), n = m;\n                        ;\n                        };\n                    ;\n                        ((((n && ((n === e.ownerDocument)))) && r.push([((((n.defaultView || n.parentWindow)) || a)),s,])));\n                    }\n                ;\n                ;\n                    for (l = 0; ((((l < r.length)) && !c.isPropagationStopped())); l++) {\n                        m = r[l][0], c.type = r[l][1], q = ((((L._data(m, \"events\") || {\n                        }))[c.type] && L._data(m, \"handle\"))), ((q && q.apply(m, d))), q = ((o && m[o])), ((((((q && L.acceptData(m))) && ((q.apply(m, d) === !1)))) && c.preventDefault()));\n                    ;\n                    };\n                ;\n                    return c.type = g, ((((((((((((((((((!f && !c.isDefaultPrevented())) && ((!p._default || ((p._default.apply(e.ownerDocument, d) === !1)))))) && ((((g !== \"click\")) || !L.nodeName(e, \"a\"))))) && L.acceptData(e))) && o)) && e[g])) && ((((((g !== \"JSBNG__focus\")) && ((g !== \"JSBNG__blur\")))) || ((c.target.offsetWidth !== 0)))))) && !L.isWindow(e))) && (n = e[o], ((n && (e[o] = null))), L.JSBNG__event.triggered = g, e[g](), L.JSBNG__event.triggered = b, ((n && (e[o] = n)))))), c.result;\n                }\n            ;\n            ;\n                return;\n            },\n            dispatch: function(c) {\n                c = L.JSBNG__event.fix(((c || a.JSBNG__event)));\n                var d = ((((L._data(this, \"events\") || {\n                }))[c.type] || [])), e = d.delegateCount, f = [].slice.call(arguments, 0), g = ((!c.exclusive && !c.namespace)), i = [], j, k, l, m, n, o, p, q, r, s, t;\n                f[0] = c, c.delegateTarget = this;\n                if (((((e && !c.target.disabled)) && ((!c.button || ((c.type !== \"click\"))))))) {\n                    m = L(this), m.context = ((this.ownerDocument || this));\n                    for (l = c.target; ((l != this)); l = ((l.parentNode || this))) {\n                        o = {\n                        }, q = [], m[0] = l;\n                        for (j = 0; ((j < e)); j++) {\n                            r = d[j], s = r.selector, ((((o[s] === b)) && (o[s] = ((r.quick ? jb(l, r.quick) : m.is(s)))))), ((o[s] && q.push(r)));\n                        ;\n                        };\n                    ;\n                        ((q.length && i.push({\n                            elem: l,\n                            matches: q\n                        })));\n                    };\n                ;\n                }\n            ;\n            ;\n                ((((d.length > e)) && i.push({\n                    elem: this,\n                    matches: d.slice(e)\n                })));\n                for (j = 0; ((((j < i.length)) && !c.isPropagationStopped())); j++) {\n                    p = i[j], c.currentTarget = p.elem;\n                    for (k = 0; ((((k < p.matches.length)) && !c.isImmediatePropagationStopped())); k++) {\n                        r = p.matches[k];\n                        if (((((g || ((!c.namespace && !r.namespace)))) || ((c.namespace_re && c.namespace_re.test(r.namespace)))))) {\n                            c.data = r.data, c.handleObj = r, n = ((((L.JSBNG__event.special[r.origType] || {\n                            })).handle || r.handler)).apply(p.elem, f), ((((n !== b)) && (c.result = n, ((((n === !1)) && (c.preventDefault(), c.stopPropagation()))))));\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                };\n            ;\n                return c.result;\n            },\n            props: \"attrChange attrName relatedNode srcElement altKey bubbles cancelable ctrlKey currentTarget eventPhase metaKey relatedTarget shiftKey target timeStamp view which\".split(\" \"),\n            fixHooks: {\n            },\n            keyHooks: {\n                props: \"char charCode key keyCode\".split(\" \"),\n                filter: function(a, b) {\n                    return ((((a.which == null)) && (a.which = ((((b.charCode != null)) ? b.charCode : b.keyCode))))), a;\n                }\n            },\n            mouseHooks: {\n                props: \"button buttons clientX clientY fromElement offsetX offsetY pageX pageY screenX screenY toElement\".split(\" \"),\n                filter: function(a, c) {\n                    var d, e, f, g = c.button, i = c.fromElement;\n                    return ((((((a.pageX == null)) && ((c.clientX != null)))) && (d = ((a.target.ownerDocument || I)), e = d.documentElement, f = d.body, a.pageX = ((((c.clientX + ((((((e && e.scrollLeft)) || ((f && f.scrollLeft)))) || 0)))) - ((((((e && e.clientLeft)) || ((f && f.clientLeft)))) || 0)))), a.pageY = ((((c.clientY + ((((((e && e.scrollTop)) || ((f && f.scrollTop)))) || 0)))) - ((((((e && e.clientTop)) || ((f && f.clientTop)))) || 0))))))), ((((!a.relatedTarget && i)) && (a.relatedTarget = ((((i === a.target)) ? c.toElement : i))))), ((((!a.which && ((g !== b)))) && (a.which = ((((g & 1)) ? 1 : ((((g & 2)) ? 3 : ((((g & 4)) ? 2 : 0))))))))), a;\n                }\n            },\n            fix: function(a) {\n                if (a[L.expando]) {\n                    return a;\n                }\n            ;\n            ;\n                var c, d, e = a, f = ((L.JSBNG__event.fixHooks[a.type] || {\n                })), g = ((f.props ? this.props.concat(f.props) : this.props));\n                a = L.JSBNG__Event(e);\n                for (c = g.length; c; ) {\n                    d = g[--c], a[d] = e[d];\n                ;\n                };\n            ;\n                return ((a.target || (a.target = ((e.srcElement || I))))), ((((a.target.nodeType === 3)) && (a.target = a.target.parentNode))), ((((a.metaKey === b)) && (a.metaKey = a.ctrlKey))), ((f.filter ? f.filter(a, e) : a));\n            },\n            special: {\n                ready: {\n                    setup: L.bindReady\n                },\n                load: {\n                    noBubble: !0\n                },\n                JSBNG__focus: {\n                    delegateType: \"focusin\"\n                },\n                JSBNG__blur: {\n                    delegateType: \"focusout\"\n                },\n                beforeunload: {\n                    setup: function(a, b, c) {\n                        ((L.isWindow(this) && (this.JSBNG__onbeforeunload = c)));\n                    },\n                    teardown: function(a, b) {\n                        ((((this.JSBNG__onbeforeunload === b)) && (this.JSBNG__onbeforeunload = null)));\n                    }\n                }\n            },\n            simulate: function(a, b, c, d) {\n                var e = L.extend(new L.JSBNG__Event, c, {\n                    type: a,\n                    isSimulated: !0,\n                    originalEvent: {\n                    }\n                });\n                ((d ? L.JSBNG__event.trigger(e, null, b) : L.JSBNG__event.dispatch.call(b, e))), ((e.isDefaultPrevented() && c.preventDefault()));\n            }\n        }, L.JSBNG__event.handle = L.JSBNG__event.dispatch, L.removeEvent = ((I.JSBNG__removeEventListener ? function(a, b, c) {\n            ((a.JSBNG__removeEventListener && a.JSBNG__removeEventListener(b, c, !1)));\n        } : function(a, b, c) {\n            ((a.JSBNG__detachEvent && a.JSBNG__detachEvent(((\"JSBNG__on\" + b)), c)));\n        })), L.JSBNG__Event = function(a, b) {\n            if (!((this instanceof L.JSBNG__Event))) {\n                return new L.JSBNG__Event(a, b);\n            }\n        ;\n        ;\n            ((((a && a.type)) ? (this.originalEvent = a, this.type = a.type, this.isDefaultPrevented = ((((((a.defaultPrevented || ((a.returnValue === !1)))) || ((a.getPreventDefault && a.getPreventDefault())))) ? i : g))) : this.type = a)), ((b && L.extend(this, b))), this.timeStamp = ((((a && a.timeStamp)) || L.now())), this[L.expando] = !0;\n        }, L.JSBNG__Event.prototype = {\n            preventDefault: function() {\n                this.isDefaultPrevented = i;\n                var a = this.originalEvent;\n                if (!a) {\n                    return;\n                }\n            ;\n            ;\n                ((a.preventDefault ? a.preventDefault() : a.returnValue = !1));\n            },\n            stopPropagation: function() {\n                this.isPropagationStopped = i;\n                var a = this.originalEvent;\n                if (!a) {\n                    return;\n                }\n            ;\n            ;\n                ((a.stopPropagation && a.stopPropagation())), a.cancelBubble = !0;\n            },\n            stopImmediatePropagation: function() {\n                this.isImmediatePropagationStopped = i, this.stopPropagation();\n            },\n            isDefaultPrevented: g,\n            isPropagationStopped: g,\n            isImmediatePropagationStopped: g\n        }, L.each({\n            mouseenter: \"mouseover\",\n            mouseleave: \"mouseout\"\n        }, function(a, b) {\n            L.JSBNG__event.special[a] = {\n                delegateType: b,\n                bindType: b,\n                handle: function(a) {\n                    var c = this, d = a.relatedTarget, e = a.handleObj, f = e.selector, g;\n                    if (((!d || ((((d !== c)) && !L.contains(c, d)))))) {\n                        a.type = e.origType, g = e.handler.apply(this, arguments), a.type = b;\n                    }\n                ;\n                ;\n                    return g;\n                }\n            };\n        }), ((L.support.submitBubbles || (L.JSBNG__event.special.submit = {\n            setup: function() {\n                if (L.nodeName(this, \"form\")) {\n                    return !1;\n                }\n            ;\n            ;\n                L.JSBNG__event.add(this, \"click._submit keypress._submit\", function(a) {\n                    var c = a.target, d = ((((L.nodeName(c, \"input\") || L.nodeName(c, \"button\"))) ? c.form : b));\n                    ((((d && !d._submit_attached)) && (L.JSBNG__event.add(d, \"submit._submit\", function(a) {\n                        ((((this.parentNode && !a.isTrigger)) && L.JSBNG__event.simulate(\"submit\", this.parentNode, a, !0)));\n                    }), d._submit_attached = !0)));\n                });\n            },\n            teardown: function() {\n                if (L.nodeName(this, \"form\")) {\n                    return !1;\n                }\n            ;\n            ;\n                L.JSBNG__event.remove(this, \"._submit\");\n            }\n        }))), ((L.support.changeBubbles || (L.JSBNG__event.special.change = {\n            setup: function() {\n                if (bb.test(this.nodeName)) {\n                    if (((((this.type === \"checkbox\")) || ((this.type === \"radio\"))))) {\n                        L.JSBNG__event.add(this, \"propertychange._change\", function(a) {\n                            ((((a.originalEvent.propertyName === \"checked\")) && (this._just_changed = !0)));\n                        }), L.JSBNG__event.add(this, \"click._change\", function(a) {\n                            ((((this._just_changed && !a.isTrigger)) && (this._just_changed = !1, L.JSBNG__event.simulate(\"change\", this, a, !0))));\n                        });\n                    }\n                ;\n                ;\n                    return !1;\n                }\n            ;\n            ;\n                L.JSBNG__event.add(this, \"beforeactivate._change\", function(a) {\n                    var b = a.target;\n                    ((((bb.test(b.nodeName) && !b._change_attached)) && (L.JSBNG__event.add(b, \"change._change\", function(a) {\n                        ((((((this.parentNode && !a.isSimulated)) && !a.isTrigger)) && L.JSBNG__event.simulate(\"change\", this.parentNode, a, !0)));\n                    }), b._change_attached = !0)));\n                });\n            },\n            handle: function(a) {\n                var b = a.target;\n                if (((((((((this !== b)) || a.isSimulated)) || a.isTrigger)) || ((((b.type !== \"radio\")) && ((b.type !== \"checkbox\"))))))) {\n                    return a.handleObj.handler.apply(this, arguments);\n                }\n            ;\n            ;\n            },\n            teardown: function() {\n                return L.JSBNG__event.remove(this, \"._change\"), bb.test(this.nodeName);\n            }\n        }))), ((L.support.focusinBubbles || L.each({\n            JSBNG__focus: \"focusin\",\n            JSBNG__blur: \"focusout\"\n        }, function(a, b) {\n            var c = 0, d = function(a) {\n                L.JSBNG__event.simulate(b, a.target, L.JSBNG__event.fix(a), !0);\n            };\n            L.JSBNG__event.special[b] = {\n                setup: function() {\n                    ((((c++ === 0)) && I.JSBNG__addEventListener(a, d, !0)));\n                },\n                teardown: function() {\n                    ((((--c === 0)) && I.JSBNG__removeEventListener(a, d, !0)));\n                }\n            };\n        }))), L.fn.extend({\n            JSBNG__on: function(a, c, d, e, f) {\n                var i, j;\n                if (((typeof a == \"object\"))) {\n                    ((((typeof c != \"string\")) && (d = c, c = b)));\n                    for (j in a) {\n                        this.JSBNG__on(j, c, d, a[j], f);\n                    ;\n                    };\n                ;\n                    return this;\n                }\n            ;\n            ;\n                ((((((d == null)) && ((e == null)))) ? (e = c, d = c = b) : ((((e == null)) && ((((typeof c == \"string\")) ? (e = d, d = b) : (e = d, d = c, c = b)))))));\n                if (((e === !1))) {\n                    e = g;\n                }\n                 else {\n                    if (!e) {\n                        return this;\n                    }\n                ;\n                }\n            ;\n            ;\n                return ((((f === 1)) && (i = e, e = function(a) {\n                    return L().off(a), i.apply(this, arguments);\n                }, e.guid = ((i.guid || (i.guid = L.guid++)))))), this.each(function() {\n                    L.JSBNG__event.add(this, a, e, d, c);\n                });\n            },\n            JSBNG__one: function(a, b, c, d) {\n                return this.JSBNG__on.call(this, a, b, c, d, 1);\n            },\n            off: function(a, c, d) {\n                if (((((a && a.preventDefault)) && a.handleObj))) {\n                    var e = a.handleObj;\n                    return L(a.delegateTarget).off(((e.namespace ? ((((e.type + \".\")) + e.namespace)) : e.type)), e.selector, e.handler), this;\n                }\n            ;\n            ;\n                if (((typeof a == \"object\"))) {\n                    for (var f in a) {\n                        this.off(f, c, a[f]);\n                    ;\n                    };\n                ;\n                    return this;\n                }\n            ;\n            ;\n                if (((((c === !1)) || ((typeof c == \"function\"))))) {\n                    d = c, c = b;\n                }\n            ;\n            ;\n                return ((((d === !1)) && (d = g))), this.each(function() {\n                    L.JSBNG__event.remove(this, a, d, c);\n                });\n            },\n            bind: function(a, b, c) {\n                return this.JSBNG__on(a, null, b, c);\n            },\n            unbind: function(a, b) {\n                return this.off(a, null, b);\n            },\n            live: function(a, b, c) {\n                return L(this.context).JSBNG__on(a, this.selector, b, c), this;\n            },\n            die: function(a, b) {\n                return L(this.context).off(a, ((this.selector || \"**\")), b), this;\n            },\n            delegate: function(a, b, c, d) {\n                return this.JSBNG__on(b, a, c, d);\n            },\n            undelegate: function(a, b, c) {\n                return ((((arguments.length == 1)) ? this.off(a, \"**\") : this.off(b, a, c)));\n            },\n            trigger: function(a, b) {\n                return this.each(function() {\n                    L.JSBNG__event.trigger(a, b, this);\n                });\n            },\n            triggerHandler: function(a, b) {\n                if (this[0]) {\n                    return L.JSBNG__event.trigger(a, b, this[0], !0);\n                }\n            ;\n            ;\n            },\n            toggle: function(a) {\n                var b = arguments, c = ((a.guid || L.guid++)), d = 0, e = function(c) {\n                    var e = ((((L._data(this, ((\"lastToggle\" + a.guid))) || 0)) % d));\n                    return L._data(this, ((\"lastToggle\" + a.guid)), ((e + 1))), c.preventDefault(), ((b[e].apply(this, arguments) || !1));\n                };\n                e.guid = c;\n                while (((d < b.length))) {\n                    b[d++].guid = c;\n                ;\n                };\n            ;\n                return this.click(e);\n            },\n            hover: function(a, b) {\n                return this.mouseenter(a).mouseleave(((b || a)));\n            }\n        }), L.each(\"blur focus focusin focusout load resize scroll unload click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup error contextmenu\".split(\" \"), function(a, b) {\n            L.fn[b] = function(a, c) {\n                return ((((c == null)) && (c = a, a = null))), ((((arguments.length > 0)) ? this.JSBNG__on(b, null, a, c) : this.trigger(b)));\n            }, ((L.attrFn && (L.attrFn[b] = !0))), ((eb.test(b) && (L.JSBNG__event.fixHooks[b] = L.JSBNG__event.keyHooks))), ((fb.test(b) && (L.JSBNG__event.fixHooks[b] = L.JSBNG__event.mouseHooks)));\n        });\n        (function() {\n            function a(a, b, c, d, f, g) {\n                for (var i = 0, j = d.length; ((i < j)); i++) {\n                    var k = d[i];\n                    if (k) {\n                        var l = !1;\n                        k = k[a];\n                        while (k) {\n                            if (((k[e] === c))) {\n                                l = d[k.sizset];\n                                break;\n                            }\n                        ;\n                        ;\n                            ((((((k.nodeType === 1)) && !g)) && (k[e] = c, k.sizset = i)));\n                            if (((k.nodeName.toLowerCase() === b))) {\n                                l = k;\n                                break;\n                            }\n                        ;\n                        ;\n                            k = k[a];\n                        };\n                    ;\n                        d[i] = l;\n                    }\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n            function c(a, b, c, d, f, g) {\n                for (var i = 0, j = d.length; ((i < j)); i++) {\n                    var k = d[i];\n                    if (k) {\n                        var l = !1;\n                        k = k[a];\n                        while (k) {\n                            if (((k[e] === c))) {\n                                l = d[k.sizset];\n                                break;\n                            }\n                        ;\n                        ;\n                            if (((k.nodeType === 1))) {\n                                ((g || (k[e] = c, k.sizset = i)));\n                                if (((typeof b != \"string\"))) {\n                                    if (((k === b))) {\n                                        l = !0;\n                                        break;\n                                    }\n                                ;\n                                ;\n                                }\n                                 else if (((n.filter(b, [k,]).length > 0))) {\n                                    l = k;\n                                    break;\n                                }\n                                \n                            ;\n                            ;\n                            }\n                        ;\n                        ;\n                            k = k[a];\n                        };\n                    ;\n                        d[i] = l;\n                    }\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n            var d = /((?:\\((?:\\([^()]+\\)|[^()]+)+\\)|\\[(?:\\[[^\\[\\]]*\\]|['\"][^'\"]*['\"]|[^\\[\\]'\"]+)+\\]|\\\\.|[^ >+~,(\\[\\\\]+)+|[>+~])(\\s*,\\s*)?((?:.|\\r|\\n)*)/g, e = ((\"sizcache\" + ((Math.JSBNG__random() + \"\")).replace(\".\", \"\"))), f = 0, g = Object.prototype.toString, i = !1, j = !0, k = /\\\\/g, l = /\\r\\n/g, m = /\\W/;\n            [0,0,].sort(function() {\n                return j = !1, 0;\n            });\n            var n = function(a, b, c, e) {\n                c = ((c || [])), b = ((b || I));\n                var f = b;\n                if (((((b.nodeType !== 1)) && ((b.nodeType !== 9))))) {\n                    return [];\n                }\n            ;\n            ;\n                if (((!a || ((typeof a != \"string\"))))) {\n                    return c;\n                }\n            ;\n            ;\n                var i, j, k, l, m, o, r, s, u = !0, v = n.isXML(b), w = [], y = a;\n                do {\n                    d.exec(\"\"), i = d.exec(y);\n                    if (i) {\n                        y = i[3], w.push(i[1]);\n                        if (i[2]) {\n                            l = i[3];\n                            break;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                } while (i);\n                if (((((w.length > 1)) && q.exec(a)))) if (((((w.length === 2)) && p.relative[w[0]]))) j = x(((w[0] + w[1])), b, e);\n                 else {\n                    j = ((p.relative[w[0]] ? [b,] : n(w.shift(), b)));\n                    while (w.length) {\n                        a = w.shift(), ((p.relative[a] && (a += w.shift()))), j = x(a, j, e);\n                    ;\n                    };\n                ;\n                }\n                \n                 else {\n                    ((((((((((((!e && ((w.length > 1)))) && ((b.nodeType === 9)))) && !v)) && p.match.ID.test(w[0]))) && !p.match.ID.test(w[((w.length - 1))]))) && (m = n.JSBNG__find(w.shift(), b, v), b = ((m.expr ? n.filter(m.expr, m.set)[0] : m.set[0])))));\n                    if (b) {\n                        m = ((e ? {\n                            expr: w.pop(),\n                            set: t(e)\n                        } : n.JSBNG__find(w.pop(), ((((((((w.length !== 1)) || ((((w[0] !== \"~\")) && ((w[0] !== \"+\")))))) || !b.parentNode)) ? b : b.parentNode)), v))), j = ((m.expr ? n.filter(m.expr, m.set) : m.set)), ((((w.length > 0)) ? k = t(j) : u = !1));\n                        while (w.length) {\n                            o = w.pop(), r = o, ((p.relative[o] ? r = w.pop() : o = \"\")), ((((r == null)) && (r = b))), p.relative[o](k, r, v);\n                        ;\n                        };\n                    ;\n                    }\n                     else k = w = [];\n                ;\n                ;\n                }\n            ;\n            ;\n                ((k || (k = j))), ((k || n.error(((o || a)))));\n                if (((g.call(k) === \"[object Array]\"))) {\n                    if (!u) {\n                        c.push.apply(c, k);\n                    }\n                     else {\n                        if (((b && ((b.nodeType === 1))))) {\n                            for (s = 0; ((k[s] != null)); s++) {\n                                ((((k[s] && ((((k[s] === !0)) || ((((k[s].nodeType === 1)) && n.contains(b, k[s]))))))) && c.push(j[s])));\n                            ;\n                            };\n                        }\n                         else {\n                            for (s = 0; ((k[s] != null)); s++) {\n                                ((((k[s] && ((k[s].nodeType === 1)))) && c.push(j[s])));\n                            ;\n                            };\n                        }\n                    ;\n                    }\n                ;\n                }\n                 else {\n                    t(k, c);\n                }\n            ;\n            ;\n                return ((l && (n(l, f, c, e), n.uniqueSort(c)))), c;\n            };\n            n.uniqueSort = function(a) {\n                if (v) {\n                    i = j, a.sort(v);\n                    if (i) {\n                        for (var b = 1; ((b < a.length)); b++) {\n                            ((((a[b] === a[((b - 1))])) && a.splice(b--, 1)));\n                        ;\n                        };\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                return a;\n            }, n.matches = function(a, b) {\n                return n(a, null, null, b);\n            }, n.matchesSelector = function(a, b) {\n                return ((n(b, null, null, [a,]).length > 0));\n            }, n.JSBNG__find = function(a, b, c) {\n                var d, e, f, g, i, j;\n                if (!a) {\n                    return [];\n                }\n            ;\n            ;\n                for (e = 0, f = p.order.length; ((e < f)); e++) {\n                    i = p.order[e];\n                    if (g = p.leftMatch[i].exec(a)) {\n                        j = g[1], g.splice(1, 1);\n                        if (((j.substr(((j.length - 1))) !== \"\\\\\"))) {\n                            g[1] = ((g[1] || \"\")).replace(k, \"\"), d = p.JSBNG__find[i](g, b, c);\n                            if (((d != null))) {\n                                a = a.replace(p.match[i], \"\");\n                                break;\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                };\n            ;\n                return ((d || (d = ((((typeof b.getElementsByTagName != \"undefined\")) ? b.getElementsByTagName(\"*\") : []))))), {\n                    set: d,\n                    expr: a\n                };\n            }, n.filter = function(a, c, d, e) {\n                var f, g, i, j, k, l, m, o, q, r = a, s = [], t = c, u = ((((c && c[0])) && n.isXML(c[0])));\n                while (((a && c.length))) {\n                    for (i in p.filter) {\n                        if ((((((f = p.leftMatch[i].exec(a)) != null)) && f[2]))) {\n                            l = p.filter[i], m = f[1], g = !1, f.splice(1, 1);\n                            if (((m.substr(((m.length - 1))) === \"\\\\\"))) {\n                                continue;\n                            }\n                        ;\n                        ;\n                            ((((t === s)) && (s = [])));\n                            if (p.preFilter[i]) {\n                                f = p.preFilter[i](f, t, d, s, e, u);\n                                if (!f) {\n                                    g = j = !0;\n                                }\n                                 else {\n                                    if (((f === !0))) {\n                                        continue;\n                                    }\n                                ;\n                                }\n                            ;\n                            ;\n                            }\n                        ;\n                        ;\n                            if (f) {\n                                for (o = 0; (((k = t[o]) != null)); o++) {\n                                    ((k && (j = l(k, f, o, t), q = ((e ^ j)), ((((d && ((j != null)))) ? ((q ? g = !0 : t[o] = !1)) : ((q && (s.push(k), g = !0))))))));\n                                ;\n                                };\n                            }\n                        ;\n                        ;\n                            if (((j !== b))) {\n                                ((d || (t = s))), a = a.replace(p.match[i], \"\");\n                                if (!g) {\n                                    return [];\n                                }\n                            ;\n                            ;\n                                break;\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    if (((a === r))) {\n                        if (((g != null))) {\n                            break;\n                        }\n                    ;\n                    ;\n                        n.error(a);\n                    }\n                ;\n                ;\n                    r = a;\n                };\n            ;\n                return t;\n            }, n.error = function(a) {\n                throw new Error(((\"Syntax error, unrecognized expression: \" + a)));\n            };\n            var o = n.getText = function(a) {\n                var b, c, d = a.nodeType, e = \"\";\n                if (d) {\n                    if (((((d === 1)) || ((d === 9))))) {\n                        if (((typeof a.textContent == \"string\"))) {\n                            return a.textContent;\n                        }\n                    ;\n                    ;\n                        if (((typeof a.innerText == \"string\"))) {\n                            return a.innerText.replace(l, \"\");\n                        }\n                    ;\n                    ;\n                        for (a = a.firstChild; a; a = a.nextSibling) {\n                            e += o(a);\n                        ;\n                        };\n                    ;\n                    }\n                     else if (((((d === 3)) || ((d === 4))))) {\n                        return a.nodeValue;\n                    }\n                    \n                ;\n                ;\n                }\n                 else for (b = 0; c = a[b]; b++) {\n                    ((((c.nodeType !== 8)) && (e += o(c))));\n                ;\n                }\n            ;\n            ;\n                return e;\n            }, p = n.selectors = {\n                order: [\"ID\",\"NAME\",\"TAG\",],\n                match: {\n                    ID: /#((?:[\\w\\u00c0-\\uFFFF\\-]|\\\\.)+)/,\n                    CLASS: /\\.((?:[\\w\\u00c0-\\uFFFF\\-]|\\\\.)+)/,\n                    NAME: /\\[name=['\"]*((?:[\\w\\u00c0-\\uFFFF\\-]|\\\\.)+)['\"]*\\]/,\n                    ATTR: /\\[\\s*((?:[\\w\\u00c0-\\uFFFF\\-]|\\\\.)+)\\s*(?:(\\S?=)\\s*(?:(['\"])(.*?)\\3|(#?(?:[\\w\\u00c0-\\uFFFF\\-]|\\\\.)*)|)|)\\s*\\]/,\n                    TAG: /^((?:[\\w\\u00c0-\\uFFFF\\*\\-]|\\\\.)+)/,\n                    CHILD: /:(only|nth|last|first)-child(?:\\(\\s*(even|odd|(?:[+\\-]?\\d+|(?:[+\\-]?\\d*)?n\\s*(?:[+\\-]\\s*\\d+)?))\\s*\\))?/,\n                    POS: /:(nth|eq|gt|lt|first|last|even|odd)(?:\\((\\d*)\\))?(?=[^\\-]|$)/,\n                    PSEUDO: /:((?:[\\w\\u00c0-\\uFFFF\\-]|\\\\.)+)(?:\\((['\"]?)((?:\\([^\\)]+\\)|[^\\(\\)]*)+)\\2\\))?/\n                },\n                leftMatch: {\n                },\n                attrMap: {\n                    class: \"className\",\n                    \"for\": \"htmlFor\"\n                },\n                attrHandle: {\n                    href: function(a) {\n                        return a.getAttribute(\"href\");\n                    },\n                    type: function(a) {\n                        return a.getAttribute(\"type\");\n                    }\n                },\n                relative: {\n                    \"+\": function(a, b) {\n                        var c = ((typeof b == \"string\")), d = ((c && !m.test(b))), e = ((c && !d));\n                        ((d && (b = b.toLowerCase())));\n                        for (var f = 0, g = a.length, i; ((f < g)); f++) {\n                            if (i = a[f]) {\n                                while ((((i = i.previousSibling) && ((i.nodeType !== 1))))) {\n                                ;\n                                };\n                            ;\n                                a[f] = ((((e || ((i && ((i.nodeName.toLowerCase() === b)))))) ? ((i || !1)) : ((i === b))));\n                            }\n                        ;\n                        ;\n                        };\n                    ;\n                        ((e && n.filter(b, a, !0)));\n                    },\n                    \"\\u003E\": function(a, b) {\n                        var c, d = ((typeof b == \"string\")), e = 0, f = a.length;\n                        if (((d && !m.test(b)))) {\n                            b = b.toLowerCase();\n                            for (; ((e < f)); e++) {\n                                c = a[e];\n                                if (c) {\n                                    var g = c.parentNode;\n                                    a[e] = ((((g.nodeName.toLowerCase() === b)) ? g : !1));\n                                }\n                            ;\n                            ;\n                            };\n                        ;\n                        }\n                         else {\n                            for (; ((e < f)); e++) {\n                                c = a[e], ((c && (a[e] = ((d ? c.parentNode : ((c.parentNode === b)))))));\n                            ;\n                            };\n                        ;\n                            ((d && n.filter(b, a, !0)));\n                        }\n                    ;\n                    ;\n                    },\n                    \"\": function(b, d, e) {\n                        var g, i = f++, j = c;\n                        ((((((typeof d == \"string\")) && !m.test(d))) && (d = d.toLowerCase(), g = d, j = a))), j(\"parentNode\", d, i, b, g, e);\n                    },\n                    \"~\": function(b, d, e) {\n                        var g, i = f++, j = c;\n                        ((((((typeof d == \"string\")) && !m.test(d))) && (d = d.toLowerCase(), g = d, j = a))), j(\"previousSibling\", d, i, b, g, e);\n                    }\n                },\n                JSBNG__find: {\n                    ID: function(a, b, c) {\n                        if (((((typeof b.getElementById != \"undefined\")) && !c))) {\n                            var d = b.getElementById(a[1]);\n                            return ((((d && d.parentNode)) ? [d,] : []));\n                        }\n                    ;\n                    ;\n                    },\n                    NAME: function(a, b) {\n                        if (((typeof b.getElementsByName != \"undefined\"))) {\n                            var c = [], d = b.getElementsByName(a[1]);\n                            for (var e = 0, f = d.length; ((e < f)); e++) {\n                                ((((d[e].getAttribute(\"JSBNG__name\") === a[1])) && c.push(d[e])));\n                            ;\n                            };\n                        ;\n                            return ((((c.length === 0)) ? null : c));\n                        }\n                    ;\n                    ;\n                    },\n                    TAG: function(a, b) {\n                        if (((typeof b.getElementsByTagName != \"undefined\"))) {\n                            return b.getElementsByTagName(a[1]);\n                        }\n                    ;\n                    ;\n                    }\n                },\n                preFilter: {\n                    CLASS: function(a, b, c, d, e, f) {\n                        a = ((((\" \" + a[1].replace(k, \"\"))) + \" \"));\n                        if (f) {\n                            return a;\n                        }\n                    ;\n                    ;\n                        for (var g = 0, i; (((i = b[g]) != null)); g++) {\n                            ((i && ((((e ^ ((i.className && ((((((\" \" + i.className)) + \" \")).replace(/[\\t\\n\\r]/g, \" \").indexOf(a) >= 0)))))) ? ((c || d.push(i))) : ((c && (b[g] = !1)))))));\n                        ;\n                        };\n                    ;\n                        return !1;\n                    },\n                    ID: function(a) {\n                        return a[1].replace(k, \"\");\n                    },\n                    TAG: function(a, b) {\n                        return a[1].replace(k, \"\").toLowerCase();\n                    },\n                    CHILD: function(a) {\n                        if (((a[1] === \"nth\"))) {\n                            ((a[2] || n.error(a[0]))), a[2] = a[2].replace(/^\\+|\\s*/g, \"\");\n                            var b = /(-?)(\\d*)(?:n([+\\-]?\\d*))?/.exec(((((((((((a[2] === \"even\")) && \"2n\")) || ((((a[2] === \"odd\")) && \"2n+1\")))) || ((!/\\D/.test(a[2]) && ((\"0n+\" + a[2])))))) || a[2])));\n                            a[2] = ((((b[1] + ((b[2] || 1)))) - 0)), a[3] = ((b[3] - 0));\n                        }\n                         else ((a[2] && n.error(a[0])));\n                    ;\n                    ;\n                        return a[0] = f++, a;\n                    },\n                    ATTR: function(a, b, c, d, e, f) {\n                        var g = a[1] = a[1].replace(k, \"\");\n                        return ((((!f && p.attrMap[g])) && (a[1] = p.attrMap[g]))), a[4] = ((((a[4] || a[5])) || \"\")).replace(k, \"\"), ((((a[2] === \"~=\")) && (a[4] = ((((\" \" + a[4])) + \" \"))))), a;\n                    },\n                    PSEUDO: function(a, b, c, e, f) {\n                        if (((a[1] === \"not\"))) {\n                            if (!((((((d.exec(a[3]) || \"\")).length > 1)) || /^\\w/.test(a[3])))) {\n                                var g = n.filter(a[3], b, c, ((!0 ^ f)));\n                                return ((c || e.push.apply(e, g))), !1;\n                            }\n                        ;\n                        ;\n                            a[3] = n(a[3], null, null, b);\n                        }\n                         else if (((p.match.POS.test(a[0]) || p.match.CHILD.test(a[0])))) {\n                            return !0;\n                        }\n                        \n                    ;\n                    ;\n                        return a;\n                    },\n                    POS: function(a) {\n                        return a.unshift(!0), a;\n                    }\n                },\n                filters: {\n                    enabled: function(a) {\n                        return ((((a.disabled === !1)) && ((a.type !== \"hidden\"))));\n                    },\n                    disabled: function(a) {\n                        return ((a.disabled === !0));\n                    },\n                    checked: function(a) {\n                        return ((a.checked === !0));\n                    },\n                    selected: function(a) {\n                        return ((a.parentNode && a.parentNode.selectedIndex)), ((a.selected === !0));\n                    },\n                    parent: function(a) {\n                        return !!a.firstChild;\n                    },\n                    empty: function(a) {\n                        return !a.firstChild;\n                    },\n                    has: function(a, b, c) {\n                        return !!n(c[3], a).length;\n                    },\n                    header: function(a) {\n                        return /h\\d/i.test(a.nodeName);\n                    },\n                    text: function(a) {\n                        var b = a.getAttribute(\"type\"), c = a.type;\n                        return ((((((a.nodeName.toLowerCase() === \"input\")) && ((\"text\" === c)))) && ((((b === c)) || ((b === null))))));\n                    },\n                    radio: function(a) {\n                        return ((((a.nodeName.toLowerCase() === \"input\")) && ((\"radio\" === a.type))));\n                    },\n                    checkbox: function(a) {\n                        return ((((a.nodeName.toLowerCase() === \"input\")) && ((\"checkbox\" === a.type))));\n                    },\n                    file: function(a) {\n                        return ((((a.nodeName.toLowerCase() === \"input\")) && ((\"file\" === a.type))));\n                    },\n                    password: function(a) {\n                        return ((((a.nodeName.toLowerCase() === \"input\")) && ((\"password\" === a.type))));\n                    },\n                    submit: function(a) {\n                        var b = a.nodeName.toLowerCase();\n                        return ((((((b === \"input\")) || ((b === \"button\")))) && ((\"submit\" === a.type))));\n                    },\n                    image: function(a) {\n                        return ((((a.nodeName.toLowerCase() === \"input\")) && ((\"image\" === a.type))));\n                    },\n                    reset: function(a) {\n                        var b = a.nodeName.toLowerCase();\n                        return ((((((b === \"input\")) || ((b === \"button\")))) && ((\"reset\" === a.type))));\n                    },\n                    button: function(a) {\n                        var b = a.nodeName.toLowerCase();\n                        return ((((((b === \"input\")) && ((\"button\" === a.type)))) || ((b === \"button\"))));\n                    },\n                    input: function(a) {\n                        return /input|select|textarea|button/i.test(a.nodeName);\n                    },\n                    JSBNG__focus: function(a) {\n                        return ((a === a.ownerDocument.activeElement));\n                    }\n                },\n                setFilters: {\n                    first: function(a, b) {\n                        return ((b === 0));\n                    },\n                    last: function(a, b, c, d) {\n                        return ((b === ((d.length - 1))));\n                    },\n                    even: function(a, b) {\n                        return ((((b % 2)) === 0));\n                    },\n                    odd: function(a, b) {\n                        return ((((b % 2)) === 1));\n                    },\n                    lt: function(a, b, c) {\n                        return ((b < ((c[3] - 0))));\n                    },\n                    gt: function(a, b, c) {\n                        return ((b > ((c[3] - 0))));\n                    },\n                    nth: function(a, b, c) {\n                        return ((((c[3] - 0)) === b));\n                    },\n                    eq: function(a, b, c) {\n                        return ((((c[3] - 0)) === b));\n                    }\n                },\n                filter: {\n                    PSEUDO: function(a, b, c, d) {\n                        var e = b[1], f = p.filters[e];\n                        if (f) {\n                            return f(a, c, b, d);\n                        }\n                    ;\n                    ;\n                        if (((e === \"contains\"))) {\n                            return ((((((((a.textContent || a.innerText)) || o([a,]))) || \"\")).indexOf(b[3]) >= 0));\n                        }\n                    ;\n                    ;\n                        if (((e === \"not\"))) {\n                            var g = b[3];\n                            for (var i = 0, j = g.length; ((i < j)); i++) {\n                                if (((g[i] === a))) {\n                                    return !1;\n                                }\n                            ;\n                            ;\n                            };\n                        ;\n                            return !0;\n                        }\n                    ;\n                    ;\n                        n.error(e);\n                    },\n                    CHILD: function(a, b) {\n                        var c, d, f, g, i, j, k, l = b[1], m = a;\n                        switch (l) {\n                          case \"JSBNG__only\":\n                        \n                          case \"first\":\n                            while (m = m.previousSibling) {\n                                if (((m.nodeType === 1))) {\n                                    return !1;\n                                }\n                            ;\n                            ;\n                            };\n                        ;\n                            if (((l === \"first\"))) {\n                                return !0;\n                            }\n                        ;\n                        ;\n                            m = a;\n                          case \"last\":\n                            while (m = m.nextSibling) {\n                                if (((m.nodeType === 1))) {\n                                    return !1;\n                                }\n                            ;\n                            ;\n                            };\n                        ;\n                            return !0;\n                          case \"nth\":\n                            c = b[2], d = b[3];\n                            if (((((c === 1)) && ((d === 0))))) {\n                                return !0;\n                            }\n                        ;\n                        ;\n                            f = b[0], g = a.parentNode;\n                            if (((g && ((((g[e] !== f)) || !a.nodeIndex))))) {\n                                j = 0;\n                                for (m = g.firstChild; m; m = m.nextSibling) {\n                                    ((((m.nodeType === 1)) && (m.nodeIndex = ++j)));\n                                ;\n                                };\n                            ;\n                                g[e] = f;\n                            }\n                        ;\n                        ;\n                            return k = ((a.nodeIndex - d)), ((((c === 0)) ? ((k === 0)) : ((((((k % c)) === 0)) && ((((k / c)) >= 0))))));\n                        };\n                    ;\n                    },\n                    ID: function(a, b) {\n                        return ((((a.nodeType === 1)) && ((a.getAttribute(\"id\") === b))));\n                    },\n                    TAG: function(a, b) {\n                        return ((((((b === \"*\")) && ((a.nodeType === 1)))) || ((!!a.nodeName && ((a.nodeName.toLowerCase() === b))))));\n                    },\n                    CLASS: function(a, b) {\n                        return ((((((\" \" + ((a.className || a.getAttribute(\"class\"))))) + \" \")).indexOf(b) > -1));\n                    },\n                    ATTR: function(a, b) {\n                        var c = b[1], d = ((n.attr ? n.attr(a, c) : ((p.attrHandle[c] ? p.attrHandle[c](a) : ((((a[c] != null)) ? a[c] : a.getAttribute(c))))))), e = ((d + \"\")), f = b[2], g = b[4];\n                        return ((((d == null)) ? ((f === \"!=\")) : ((((!f && n.attr)) ? ((d != null)) : ((((f === \"=\")) ? ((e === g)) : ((((f === \"*=\")) ? ((e.indexOf(g) >= 0)) : ((((f === \"~=\")) ? ((((((\" \" + e)) + \" \")).indexOf(g) >= 0)) : ((g ? ((((f === \"!=\")) ? ((e !== g)) : ((((f === \"^=\")) ? ((e.indexOf(g) === 0)) : ((((f === \"$=\")) ? ((e.substr(((e.length - g.length))) === g)) : ((((f === \"|=\")) ? ((((e === g)) || ((e.substr(0, ((g.length + 1))) === ((g + \"-\")))))) : !1)))))))) : ((e && ((d !== !1))))))))))))))));\n                    },\n                    POS: function(a, b, c, d) {\n                        var e = b[2], f = p.setFilters[e];\n                        if (f) {\n                            return f(a, c, b, d);\n                        }\n                    ;\n                    ;\n                    }\n                }\n            }, q = p.match.POS, r = function(a, b) {\n                return ((\"\\\\\" + ((((b - 0)) + 1))));\n            };\n            for (var s in p.match) {\n                p.match[s] = new RegExp(((p.match[s].source + /(?![^\\[]*\\])(?![^\\(]*\\))/.source))), p.leftMatch[s] = new RegExp(((/(^(?:.|\\r|\\n)*?)/.source + p.match[s].source.replace(/\\\\(\\d+)/g, r))));\n            ;\n            };\n        ;\n            var t = function(a, b) {\n                return a = Array.prototype.slice.call(a, 0), ((b ? (b.push.apply(b, a), b) : a));\n            };\n            try {\n                Array.prototype.slice.call(I.documentElement.childNodes, 0)[0].nodeType;\n            } catch (u) {\n                t = function(a, b) {\n                    var c = 0, d = ((b || []));\n                    if (((g.call(a) === \"[object Array]\"))) {\n                        Array.prototype.push.apply(d, a);\n                    }\n                     else {\n                        if (((typeof a.length == \"number\"))) {\n                            for (var e = a.length; ((c < e)); c++) {\n                                d.push(a[c]);\n                            ;\n                            };\n                        }\n                         else {\n                            for (; a[c]; c++) {\n                                d.push(a[c]);\n                            ;\n                            };\n                        }\n                    ;\n                    }\n                ;\n                ;\n                    return d;\n                };\n            };\n        ;\n            var v, w;\n            ((I.documentElement.compareDocumentPosition ? v = function(a, b) {\n                return ((((a === b)) ? (i = !0, 0) : ((((!a.compareDocumentPosition || !b.compareDocumentPosition)) ? ((a.compareDocumentPosition ? -1 : 1)) : ((((a.compareDocumentPosition(b) & 4)) ? -1 : 1))))));\n            } : (v = function(a, b) {\n                if (((a === b))) {\n                    return i = !0, 0;\n                }\n            ;\n            ;\n                if (((a.sourceIndex && b.sourceIndex))) {\n                    return ((a.sourceIndex - b.sourceIndex));\n                }\n            ;\n            ;\n                var c, d, e = [], f = [], g = a.parentNode, j = b.parentNode, k = g;\n                if (((g === j))) {\n                    return w(a, b);\n                }\n            ;\n            ;\n                if (!g) {\n                    return -1;\n                }\n            ;\n            ;\n                if (!j) {\n                    return 1;\n                }\n            ;\n            ;\n                while (k) {\n                    e.unshift(k), k = k.parentNode;\n                ;\n                };\n            ;\n                k = j;\n                while (k) {\n                    f.unshift(k), k = k.parentNode;\n                ;\n                };\n            ;\n                c = e.length, d = f.length;\n                for (var l = 0; ((((l < c)) && ((l < d)))); l++) {\n                    if (((e[l] !== f[l]))) {\n                        return w(e[l], f[l]);\n                    }\n                ;\n                ;\n                };\n            ;\n                return ((((l === c)) ? w(a, f[l], -1) : w(e[l], b, 1)));\n            }, w = function(a, b, c) {\n                if (((a === b))) {\n                    return c;\n                }\n            ;\n            ;\n                var d = a.nextSibling;\n                while (d) {\n                    if (((d === b))) {\n                        return -1;\n                    }\n                ;\n                ;\n                    d = d.nextSibling;\n                };\n            ;\n                return 1;\n            }))), function() {\n                var a = I.createElement(\"div\"), c = ((\"script\" + (new JSBNG__Date).getTime())), d = I.documentElement;\n                a.innerHTML = ((((\"\\u003Ca name='\" + c)) + \"'/\\u003E\")), d.insertBefore(a, d.firstChild), ((I.getElementById(c) && (p.JSBNG__find.ID = function(a, c, d) {\n                    if (((((typeof c.getElementById != \"undefined\")) && !d))) {\n                        var e = c.getElementById(a[1]);\n                        return ((e ? ((((((e.id === a[1])) || ((((typeof e.getAttributeNode != \"undefined\")) && ((e.getAttributeNode(\"id\").nodeValue === a[1])))))) ? [e,] : b)) : []));\n                    }\n                ;\n                ;\n                }, p.filter.ID = function(a, b) {\n                    var c = ((((typeof a.getAttributeNode != \"undefined\")) && a.getAttributeNode(\"id\")));\n                    return ((((((a.nodeType === 1)) && c)) && ((c.nodeValue === b))));\n                }))), d.removeChild(a), d = a = null;\n            }(), function() {\n                var a = I.createElement(\"div\");\n                a.appendChild(I.createComment(\"\")), ((((a.getElementsByTagName(\"*\").length > 0)) && (p.JSBNG__find.TAG = function(a, b) {\n                    var c = b.getElementsByTagName(a[1]);\n                    if (((a[1] === \"*\"))) {\n                        var d = [];\n                        for (var e = 0; c[e]; e++) {\n                            ((((c[e].nodeType === 1)) && d.push(c[e])));\n                        ;\n                        };\n                    ;\n                        c = d;\n                    }\n                ;\n                ;\n                    return c;\n                }))), a.innerHTML = \"\\u003Ca href='#'\\u003E\\u003C/a\\u003E\", ((((((a.firstChild && ((typeof a.firstChild.getAttribute != \"undefined\")))) && ((a.firstChild.getAttribute(\"href\") !== \"#\")))) && (p.attrHandle.href = function(a) {\n                    return a.getAttribute(\"href\", 2);\n                }))), a = null;\n            }(), ((I.querySelectorAll && function() {\n                var a = n, b = I.createElement(\"div\"), c = \"__sizzle__\";\n                b.innerHTML = \"\\u003Cp class='TEST'\\u003E\\u003C/p\\u003E\";\n                if (((b.querySelectorAll && ((b.querySelectorAll(\".TEST\").length === 0))))) {\n                    return;\n                }\n            ;\n            ;\n                n = function(b, d, e, f) {\n                    d = ((d || I));\n                    if (((!f && !n.isXML(d)))) {\n                        var g = /^(\\w+$)|^\\.([\\w\\-]+$)|^#([\\w\\-]+$)/.exec(b);\n                        if (((g && ((((d.nodeType === 1)) || ((d.nodeType === 9))))))) {\n                            if (g[1]) {\n                                return t(d.getElementsByTagName(b), e);\n                            }\n                        ;\n                        ;\n                            if (((((g[2] && p.JSBNG__find.CLASS)) && d.getElementsByClassName))) {\n                                return t(d.getElementsByClassName(g[2]), e);\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                        if (((d.nodeType === 9))) {\n                            if (((((b === \"body\")) && d.body))) {\n                                return t([d.body,], e);\n                            }\n                        ;\n                        ;\n                            if (((g && g[3]))) {\n                                var i = d.getElementById(g[3]);\n                                if (((!i || !i.parentNode))) {\n                                    return t([], e);\n                                }\n                            ;\n                            ;\n                                if (((i.id === g[3]))) {\n                                    return t([i,], e);\n                                }\n                            ;\n                            ;\n                            }\n                        ;\n                        ;\n                            try {\n                                return t(d.querySelectorAll(b), e);\n                            } catch (j) {\n                            \n                            };\n                        ;\n                        }\n                         else if (((((d.nodeType === 1)) && ((d.nodeName.toLowerCase() !== \"object\"))))) {\n                            var k = d, l = d.getAttribute(\"id\"), m = ((l || c)), o = d.parentNode, q = /^\\s*[+~]/.test(b);\n                            ((l ? m = m.replace(/'/g, \"\\\\$&\") : d.setAttribute(\"id\", m))), ((((q && o)) && (d = d.parentNode)));\n                            try {\n                                if (((!q || o))) {\n                                    return t(d.querySelectorAll(((((((\"[id='\" + m)) + \"'] \")) + b))), e);\n                                }\n                            ;\n                            ;\n                            } catch (r) {\n                            \n                            } finally {\n                                ((l || k.removeAttribute(\"id\")));\n                            };\n                        ;\n                        }\n                        \n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    return a(b, d, e, f);\n                };\n                for (var d in a) {\n                    n[d] = a[d];\n                ;\n                };\n            ;\n                b = null;\n            }())), function() {\n                var a = I.documentElement, b = ((((((a.matchesSelector || a.mozMatchesSelector)) || a.webkitMatchesSelector)) || a.msMatchesSelector));\n                if (b) {\n                    var c = !b.call(I.createElement(\"div\"), \"div\"), d = !1;\n                    try {\n                        b.call(I.documentElement, \"[test!='']:sizzle\");\n                    } catch (e) {\n                        d = !0;\n                    };\n                ;\n                    n.matchesSelector = function(a, e) {\n                        e = e.replace(/\\=\\s*([^'\"\\]]*)\\s*\\]/g, \"='$1']\");\n                        if (!n.isXML(a)) {\n                            try {\n                                if (((d || ((!p.match.PSEUDO.test(e) && !/!=/.test(e)))))) {\n                                    var f = b.call(a, e);\n                                    if (((((f || !c)) || ((a.JSBNG__document && ((a.JSBNG__document.nodeType !== 11))))))) {\n                                        return f;\n                                    }\n                                ;\n                                ;\n                                }\n                            ;\n                            ;\n                            } catch (g) {\n                            \n                            };\n                        }\n                    ;\n                    ;\n                        return ((n(e, null, null, [a,]).length > 0));\n                    };\n                }\n            ;\n            ;\n            }(), function() {\n                var a = I.createElement(\"div\");\n                a.innerHTML = \"\\u003Cdiv class='test e'\\u003E\\u003C/div\\u003E\\u003Cdiv class='test'\\u003E\\u003C/div\\u003E\";\n                if (((!a.getElementsByClassName || ((a.getElementsByClassName(\"e\").length === 0))))) {\n                    return;\n                }\n            ;\n            ;\n                a.lastChild.className = \"e\";\n                if (((a.getElementsByClassName(\"e\").length === 1))) {\n                    return;\n                }\n            ;\n            ;\n                p.order.splice(1, 0, \"CLASS\"), p.JSBNG__find.CLASS = function(a, b, c) {\n                    if (((((typeof b.getElementsByClassName != \"undefined\")) && !c))) {\n                        return b.getElementsByClassName(a[1]);\n                    }\n                ;\n                ;\n                }, a = null;\n            }(), ((I.documentElement.contains ? n.contains = function(a, b) {\n                return ((((a !== b)) && ((a.contains ? a.contains(b) : !0))));\n            } : ((I.documentElement.compareDocumentPosition ? n.contains = function(a, b) {\n                return !!((a.compareDocumentPosition(b) & 16));\n            } : n.contains = function() {\n                return !1;\n            })))), n.isXML = function(a) {\n                var b = ((a ? ((a.ownerDocument || a)) : 0)).documentElement;\n                return ((b ? ((b.nodeName !== \"HTML\")) : !1));\n            };\n            var x = function(a, b, c) {\n                var d, e = [], f = \"\", g = ((b.nodeType ? [b,] : b));\n                while (d = p.match.PSEUDO.exec(a)) {\n                    f += d[0], a = a.replace(p.match.PSEUDO, \"\");\n                ;\n                };\n            ;\n                a = ((p.relative[a] ? ((a + \"*\")) : a));\n                for (var i = 0, j = g.length; ((i < j)); i++) {\n                    n(a, g[i], e, c);\n                ;\n                };\n            ;\n                return n.filter(f, e);\n            };\n            n.attr = L.attr, n.selectors.attrMap = {\n            }, L.JSBNG__find = n, L.expr = n.selectors, L.expr[\":\"] = L.expr.filters, L.unique = n.uniqueSort, L.text = n.getText, L.isXMLDoc = n.isXML, L.contains = n.contains;\n        })();\n        var lb = /Until$/, mb = /^(?:parents|prevUntil|prevAll)/, nb = /,/, ob = /^.[^:#\\[\\.,]*$/, pb = Array.prototype.slice, qb = L.expr.match.POS, rb = {\n            children: !0,\n            contents: !0,\n            next: !0,\n            prev: !0\n        };\n        L.fn.extend({\n            JSBNG__find: function(a) {\n                var b = this, c, d;\n                if (((typeof a != \"string\"))) {\n                    return L(a).filter(function() {\n                        for (c = 0, d = b.length; ((c < d)); c++) {\n                            if (L.contains(b[c], this)) {\n                                return !0;\n                            }\n                        ;\n                        ;\n                        };\n                    ;\n                    });\n                }\n            ;\n            ;\n                var e = this.pushStack(\"\", \"JSBNG__find\", a), f, g, i;\n                for (c = 0, d = this.length; ((c < d)); c++) {\n                    f = e.length, L.JSBNG__find(a, this[c], e);\n                    if (((c > 0))) {\n                        for (g = f; ((g < e.length)); g++) {\n                            for (i = 0; ((i < f)); i++) {\n                                if (((e[i] === e[g]))) {\n                                    e.splice(g--, 1);\n                                    break;\n                                }\n                            ;\n                            ;\n                            };\n                        ;\n                        };\n                    }\n                ;\n                ;\n                };\n            ;\n                return e;\n            },\n            has: function(a) {\n                var b = L(a);\n                return this.filter(function() {\n                    for (var a = 0, c = b.length; ((a < c)); a++) {\n                        if (L.contains(this, b[a])) {\n                            return !0;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                });\n            },\n            not: function(a) {\n                return this.pushStack(k(this, a, !1), \"not\", a);\n            },\n            filter: function(a) {\n                return this.pushStack(k(this, a, !0), \"filter\", a);\n            },\n            is: function(a) {\n                return ((!!a && ((((typeof a == \"string\")) ? ((qb.test(a) ? ((L(a, this.context).index(this[0]) >= 0)) : ((L.filter(a, this).length > 0)))) : ((this.filter(a).length > 0))))));\n            },\n            closest: function(a, b) {\n                var c = [], d, e, f = this[0];\n                if (L.isArray(a)) {\n                    var g = 1;\n                    while (((((f && f.ownerDocument)) && ((f !== b))))) {\n                        for (d = 0; ((d < a.length)); d++) {\n                            ((L(f).is(a[d]) && c.push({\n                                selector: a[d],\n                                elem: f,\n                                level: g\n                            })));\n                        ;\n                        };\n                    ;\n                        f = f.parentNode, g++;\n                    };\n                ;\n                    return c;\n                }\n            ;\n            ;\n                var i = ((((qb.test(a) || ((typeof a != \"string\")))) ? L(a, ((b || this.context))) : 0));\n                for (d = 0, e = this.length; ((d < e)); d++) {\n                    f = this[d];\n                    while (f) {\n                        if (((i ? ((i.index(f) > -1)) : L.JSBNG__find.matchesSelector(f, a)))) {\n                            c.push(f);\n                            break;\n                        }\n                    ;\n                    ;\n                        f = f.parentNode;\n                        if (((((((!f || !f.ownerDocument)) || ((f === b)))) || ((f.nodeType === 11))))) {\n                            break;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                };\n            ;\n                return c = ((((c.length > 1)) ? L.unique(c) : c)), this.pushStack(c, \"closest\", a);\n            },\n            index: function(a) {\n                return ((a ? ((((typeof a == \"string\")) ? L.inArray(this[0], L(a)) : L.inArray(((a.jquery ? a[0] : a)), this))) : ((((this[0] && this[0].parentNode)) ? this.prevAll().length : -1))));\n            },\n            add: function(a, b) {\n                var c = ((((typeof a == \"string\")) ? L(a, b) : L.makeArray(((((a && a.nodeType)) ? [a,] : a))))), d = L.merge(this.get(), c);\n                return this.pushStack(((((j(c[0]) || j(d[0]))) ? d : L.unique(d))));\n            },\n            andSelf: function() {\n                return this.add(this.prevObject);\n            }\n        }), L.each({\n            parent: function(a) {\n                var b = a.parentNode;\n                return ((((b && ((b.nodeType !== 11)))) ? b : null));\n            },\n            parents: function(a) {\n                return L.dir(a, \"parentNode\");\n            },\n            parentsUntil: function(a, b, c) {\n                return L.dir(a, \"parentNode\", c);\n            },\n            next: function(a) {\n                return L.nth(a, 2, \"nextSibling\");\n            },\n            prev: function(a) {\n                return L.nth(a, 2, \"previousSibling\");\n            },\n            nextAll: function(a) {\n                return L.dir(a, \"nextSibling\");\n            },\n            prevAll: function(a) {\n                return L.dir(a, \"previousSibling\");\n            },\n            nextUntil: function(a, b, c) {\n                return L.dir(a, \"nextSibling\", c);\n            },\n            prevUntil: function(a, b, c) {\n                return L.dir(a, \"previousSibling\", c);\n            },\n            siblings: function(a) {\n                return L.sibling(a.parentNode.firstChild, a);\n            },\n            children: function(a) {\n                return L.sibling(a.firstChild);\n            },\n            contents: function(a) {\n                return ((L.nodeName(a, \"div\") ? ((a.contentDocument || a.contentWindow.JSBNG__document)) : L.makeArray(a.childNodes)));\n            }\n        }, function(a, b) {\n            L.fn[a] = function(c, d) {\n                var e = L.map(this, b, c);\n                return ((lb.test(a) || (d = c))), ((((d && ((typeof d == \"string\")))) && (e = L.filter(d, e)))), e = ((((((this.length > 1)) && !rb[a])) ? L.unique(e) : e)), ((((((((this.length > 1)) || nb.test(d))) && mb.test(a))) && (e = e.reverse()))), this.pushStack(e, a, pb.call(arguments).join(\",\"));\n            };\n        }), L.extend({\n            filter: function(a, b, c) {\n                return ((c && (a = ((((\":not(\" + a)) + \")\"))))), ((((b.length === 1)) ? ((L.JSBNG__find.matchesSelector(b[0], a) ? [b[0],] : [])) : L.JSBNG__find.matches(a, b)));\n            },\n            dir: function(a, c, d) {\n                var e = [], f = a[c];\n                while (((((f && ((f.nodeType !== 9)))) && ((((((d === b)) || ((f.nodeType !== 1)))) || !L(f).is(d)))))) {\n                    ((((f.nodeType === 1)) && e.push(f))), f = f[c];\n                ;\n                };\n            ;\n                return e;\n            },\n            nth: function(a, b, c, d) {\n                b = ((b || 1));\n                var e = 0;\n                for (; a; a = a[c]) {\n                    if (((((a.nodeType === 1)) && ((++e === b))))) {\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n                return a;\n            },\n            sibling: function(a, b) {\n                var c = [];\n                for (; a; a = a.nextSibling) {\n                    ((((((a.nodeType === 1)) && ((a !== b)))) && c.push(a)));\n                ;\n                };\n            ;\n                return c;\n            }\n        });\n        var sb = \"abbr|article|aside|audio|canvas|datalist|details|figcaption|figure|footer|header|hgroup|mark|meter|nav|output|progress|section|summary|time|video\", tb = / jQuery\\d+=\"(?:\\d+|null)\"/g, ub = /^\\s+/, vb = /<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\\w:]+)[^>]*)\\/>/gi, wb = /<([\\w:]+)/, xb = /<tbody/i, yb = /<|&#?\\w+;/, zb = /<(?:script|style)/i, Ab = /<(?:script|object|embed|option|style)/i, Bb = new RegExp(((((\"\\u003C(?:\" + sb)) + \")\")), \"i\"), Cb = /checked\\s*(?:[^=]|=\\s*.checked.)/i, Db = /\\/(java|ecma)script/i, Eb = /^\\s*<!(?:\\[CDATA\\[|\\-\\-)/, Fb = {\n            option: [1,\"\\u003Cselect multiple='multiple'\\u003E\",\"\\u003C/select\\u003E\",],\n            legend: [1,\"\\u003Cfieldset\\u003E\",\"\\u003C/fieldset\\u003E\",],\n            thead: [1,\"\\u003Ctable\\u003E\",\"\\u003C/table\\u003E\",],\n            tr: [2,\"\\u003Ctable\\u003E\\u003Ctbody\\u003E\",\"\\u003C/tbody\\u003E\\u003C/table\\u003E\",],\n            td: [3,\"\\u003Ctable\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\",\"\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\",],\n            col: [2,\"\\u003Ctable\\u003E\\u003Ctbody\\u003E\\u003C/tbody\\u003E\\u003Ccolgroup\\u003E\",\"\\u003C/colgroup\\u003E\\u003C/table\\u003E\",],\n            area: [1,\"\\u003Cmap\\u003E\",\"\\u003C/map\\u003E\",],\n            _default: [0,\"\",\"\",]\n        }, Gb = l(I);\n        Fb.optgroup = Fb.option, Fb.tbody = Fb.tfoot = Fb.colgroup = Fb.caption = Fb.thead, Fb.th = Fb.td, ((L.support.htmlSerialize || (Fb._default = [1,\"div\\u003Cdiv\\u003E\",\"\\u003C/div\\u003E\",]))), L.fn.extend({\n            text: function(a) {\n                return ((L.isFunction(a) ? this.each(function(b) {\n                    var c = L(this);\n                    c.text(a.call(this, b, c.text()));\n                }) : ((((((typeof a != \"object\")) && ((a !== b)))) ? this.empty().append(((((this[0] && this[0].ownerDocument)) || I)).createTextNode(a)) : L.text(this)))));\n            },\n            wrapAll: function(a) {\n                if (L.isFunction(a)) {\n                    return this.each(function(b) {\n                        L(this).wrapAll(a.call(this, b));\n                    });\n                }\n            ;\n            ;\n                if (this[0]) {\n                    var b = L(a, this[0].ownerDocument).eq(0).clone(!0);\n                    ((this[0].parentNode && b.insertBefore(this[0]))), b.map(function() {\n                        var a = this;\n                        while (((a.firstChild && ((a.firstChild.nodeType === 1))))) {\n                            a = a.firstChild;\n                        ;\n                        };\n                    ;\n                        return a;\n                    }).append(this);\n                }\n            ;\n            ;\n                return this;\n            },\n            wrapInner: function(a) {\n                return ((L.isFunction(a) ? this.each(function(b) {\n                    L(this).wrapInner(a.call(this, b));\n                }) : this.each(function() {\n                    var b = L(this), c = b.contents();\n                    ((c.length ? c.wrapAll(a) : b.append(a)));\n                })));\n            },\n            wrap: function(a) {\n                var b = L.isFunction(a);\n                return this.each(function(c) {\n                    L(this).wrapAll(((b ? a.call(this, c) : a)));\n                });\n            },\n            unwrap: function() {\n                return this.parent().each(function() {\n                    ((L.nodeName(this, \"body\") || L(this).replaceWith(this.childNodes)));\n                }).end();\n            },\n            append: function() {\n                return this.domManip(arguments, !0, function(a) {\n                    ((((this.nodeType === 1)) && this.appendChild(a)));\n                });\n            },\n            prepend: function() {\n                return this.domManip(arguments, !0, function(a) {\n                    ((((this.nodeType === 1)) && this.insertBefore(a, this.firstChild)));\n                });\n            },\n            before: function() {\n                if (((this[0] && this[0].parentNode))) {\n                    return this.domManip(arguments, !1, function(a) {\n                        this.parentNode.insertBefore(a, this);\n                    });\n                }\n            ;\n            ;\n                if (arguments.length) {\n                    var a = L.clean(arguments);\n                    return a.push.apply(a, this.toArray()), this.pushStack(a, \"before\", arguments);\n                }\n            ;\n            ;\n            },\n            after: function() {\n                if (((this[0] && this[0].parentNode))) {\n                    return this.domManip(arguments, !1, function(a) {\n                        this.parentNode.insertBefore(a, this.nextSibling);\n                    });\n                }\n            ;\n            ;\n                if (arguments.length) {\n                    var a = this.pushStack(this, \"after\", arguments);\n                    return a.push.apply(a, L.clean(arguments)), a;\n                }\n            ;\n            ;\n            },\n            remove: function(a, b) {\n                for (var c = 0, d; (((d = this[c]) != null)); c++) {\n                    if (((!a || L.filter(a, [d,]).length))) {\n                        ((((!b && ((d.nodeType === 1)))) && (L.cleanData(d.getElementsByTagName(\"*\")), L.cleanData([d,])))), ((d.parentNode && d.parentNode.removeChild(d)));\n                    }\n                ;\n                ;\n                };\n            ;\n                return this;\n            },\n            empty: function() {\n                for (var a = 0, b; (((b = this[a]) != null)); a++) {\n                    ((((b.nodeType === 1)) && L.cleanData(b.getElementsByTagName(\"*\"))));\n                    while (b.firstChild) {\n                        b.removeChild(b.firstChild);\n                    ;\n                    };\n                ;\n                };\n            ;\n                return this;\n            },\n            clone: function(a, b) {\n                return a = ((((a == null)) ? !1 : a)), b = ((((b == null)) ? a : b)), this.map(function() {\n                    return L.clone(this, a, b);\n                });\n            },\n            html: function(a) {\n                if (((a === b))) {\n                    return ((((this[0] && ((this[0].nodeType === 1)))) ? this[0].innerHTML.replace(tb, \"\") : null));\n                }\n            ;\n            ;\n                if (((((((((typeof a == \"string\")) && !zb.test(a))) && ((L.support.leadingWhitespace || !ub.test(a))))) && !Fb[((wb.exec(a) || [\"\",\"\",]))[1].toLowerCase()]))) {\n                    a = a.replace(vb, \"\\u003C$1\\u003E\\u003C/$2\\u003E\");\n                    try {\n                        for (var c = 0, d = this.length; ((c < d)); c++) {\n                            ((((this[c].nodeType === 1)) && (L.cleanData(this[c].getElementsByTagName(\"*\")), this[c].innerHTML = a)));\n                        ;\n                        };\n                    ;\n                    } catch (e) {\n                        this.empty().append(a);\n                    };\n                ;\n                }\n                 else ((L.isFunction(a) ? this.each(function(b) {\n                    var c = L(this);\n                    c.html(a.call(this, b, c.html()));\n                }) : this.empty().append(a)));\n            ;\n            ;\n                return this;\n            },\n            replaceWith: function(a) {\n                return ((((this[0] && this[0].parentNode)) ? ((L.isFunction(a) ? this.each(function(b) {\n                    var c = L(this), d = c.html();\n                    c.replaceWith(a.call(this, b, d));\n                }) : (((((typeof a != \"string\")) && (a = L(a).detach()))), this.each(function() {\n                    var b = this.nextSibling, c = this.parentNode;\n                    L(this).remove(), ((b ? L(b).before(a) : L(c).append(a)));\n                })))) : ((this.length ? this.pushStack(L(((L.isFunction(a) ? a() : a))), \"replaceWith\", a) : this))));\n            },\n            detach: function(a) {\n                return this.remove(a, !0);\n            },\n            domManip: function(a, c, d) {\n                var e, f, g, i, j = a[0], k = [];\n                if (((((((!L.support.checkClone && ((arguments.length === 3)))) && ((typeof j == \"string\")))) && Cb.test(j)))) {\n                    return this.each(function() {\n                        L(this).domManip(a, c, d, !0);\n                    });\n                }\n            ;\n            ;\n                if (L.isFunction(j)) {\n                    return this.each(function(e) {\n                        var f = L(this);\n                        a[0] = j.call(this, e, ((c ? f.html() : b))), f.domManip(a, c, d);\n                    });\n                }\n            ;\n            ;\n                if (this[0]) {\n                    i = ((j && j.parentNode)), ((((((((L.support.parentNode && i)) && ((i.nodeType === 11)))) && ((i.childNodes.length === this.length)))) ? e = {\n                        fragment: i\n                    } : e = L.buildFragment(a, this, k))), g = e.fragment, ((((g.childNodes.length === 1)) ? f = g = g.firstChild : f = g.firstChild));\n                    if (f) {\n                        c = ((c && L.nodeName(f, \"tr\")));\n                        for (var l = 0, n = this.length, o = ((n - 1)); ((l < n)); l++) {\n                            d.call(((c ? m(this[l], f) : this[l])), ((((e.cacheable || ((((n > 1)) && ((l < o)))))) ? L.clone(g, !0, !0) : g)));\n                        ;\n                        };\n                    ;\n                    }\n                ;\n                ;\n                    ((k.length && L.each(k, t)));\n                }\n            ;\n            ;\n                return this;\n            }\n        }), L.buildFragment = function(a, b, c) {\n            var d, e, f, g, i = a[0];\n            return ((((b && b[0])) && (g = ((b[0].ownerDocument || b[0]))))), ((g.createDocumentFragment || (g = I))), ((((((((((((((((((a.length === 1)) && ((typeof i == \"string\")))) && ((i.length < 512)))) && ((g === I)))) && ((i.charAt(0) === \"\\u003C\")))) && !Ab.test(i))) && ((L.support.checkClone || !Cb.test(i))))) && ((L.support.html5Clone || !Bb.test(i))))) && (e = !0, f = L.fragments[i], ((((f && ((f !== 1)))) && (d = f)))))), ((d || (d = g.createDocumentFragment(), L.clean(a, g, d, c)))), ((e && (L.fragments[i] = ((f ? d : 1))))), {\n                fragment: d,\n                cacheable: e\n            };\n        }, L.fragments = {\n        }, L.each({\n            appendTo: \"append\",\n            prependTo: \"prepend\",\n            insertBefore: \"before\",\n            insertAfter: \"after\",\n            replaceAll: \"replaceWith\"\n        }, function(a, b) {\n            L.fn[a] = function(c) {\n                var d = [], e = L(c), f = ((((this.length === 1)) && this[0].parentNode));\n                if (((((((f && ((f.nodeType === 11)))) && ((f.childNodes.length === 1)))) && ((e.length === 1))))) {\n                    return e[b](this[0]), this;\n                }\n            ;\n            ;\n                for (var g = 0, i = e.length; ((g < i)); g++) {\n                    var j = ((((g > 0)) ? this.clone(!0) : this)).get();\n                    L(e[g])[b](j), d = d.concat(j);\n                };\n            ;\n                return this.pushStack(d, a, e.selector);\n            };\n        }), L.extend({\n            clone: function(a, b, c) {\n                var d, e, f, g = ((((L.support.html5Clone || !Bb.test(((\"\\u003C\" + a.nodeName))))) ? a.cloneNode(!0) : s(a)));\n                if (((((((!L.support.noCloneEvent || !L.support.noCloneChecked)) && ((((a.nodeType === 1)) || ((a.nodeType === 11)))))) && !L.isXMLDoc(a)))) {\n                    o(a, g), d = p(a), e = p(g);\n                    for (f = 0; d[f]; ++f) {\n                        ((e[f] && o(d[f], e[f])));\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n                if (b) {\n                    n(a, g);\n                    if (c) {\n                        d = p(a), e = p(g);\n                        for (f = 0; d[f]; ++f) {\n                            n(d[f], e[f]);\n                        ;\n                        };\n                    ;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                return d = e = null, g;\n            },\n            clean: function(a, b, c, d) {\n                var e;\n                b = ((b || I)), ((((typeof b.createElement == \"undefined\")) && (b = ((((b.ownerDocument || ((b[0] && b[0].ownerDocument)))) || I)))));\n                var f = [], g;\n                for (var i = 0, j; (((j = a[i]) != null)); i++) {\n                    ((((typeof j == \"number\")) && (j += \"\")));\n                    if (!j) {\n                        continue;\n                    }\n                ;\n                ;\n                    if (((typeof j == \"string\"))) {\n                        if (!yb.test(j)) j = b.createTextNode(j);\n                         else {\n                            j = j.replace(vb, \"\\u003C$1\\u003E\\u003C/$2\\u003E\");\n                            var k = ((wb.exec(j) || [\"\",\"\",]))[1].toLowerCase(), m = ((Fb[k] || Fb._default)), n = m[0], o = b.createElement(\"div\");\n                            ((((b === I)) ? Gb.appendChild(o) : l(b).appendChild(o))), o.innerHTML = ((((m[1] + j)) + m[2]));\n                            while (n--) {\n                                o = o.lastChild;\n                            ;\n                            };\n                        ;\n                            if (!L.support.tbody) {\n                                var p = xb.test(j), q = ((((((k === \"table\")) && !p)) ? ((o.firstChild && o.firstChild.childNodes)) : ((((((m[1] === \"\\u003Ctable\\u003E\")) && !p)) ? o.childNodes : []))));\n                                for (g = ((q.length - 1)); ((g >= 0)); --g) {\n                                    ((((L.nodeName(q[g], \"tbody\") && !q[g].childNodes.length)) && q[g].parentNode.removeChild(q[g])));\n                                ;\n                                };\n                            ;\n                            }\n                        ;\n                        ;\n                            ((((!L.support.leadingWhitespace && ub.test(j))) && o.insertBefore(b.createTextNode(ub.exec(j)[0]), o.firstChild))), j = o.childNodes;\n                        }\n                    ;\n                    }\n                ;\n                ;\n                    var s;\n                    if (!L.support.appendChecked) {\n                        if (((j[0] && ((typeof (s = j.length) == \"number\"))))) {\n                            for (g = 0; ((g < s)); g++) {\n                                r(j[g]);\n                            ;\n                            };\n                        }\n                         else {\n                            r(j);\n                        }\n                    ;\n                    }\n                ;\n                ;\n                    ((j.nodeType ? f.push(j) : f = L.merge(f, j)));\n                };\n            ;\n                if (c) {\n                    e = function(a) {\n                        return ((!a.type || Db.test(a.type)));\n                    };\n                    for (i = 0; f[i]; i++) {\n                        if (((((d && L.nodeName(f[i], \"script\"))) && ((!f[i].type || ((f[i].type.toLowerCase() === \"text/javascript\"))))))) d.push(((f[i].parentNode ? f[i].parentNode.removeChild(f[i]) : f[i])));\n                         else {\n                            if (((f[i].nodeType === 1))) {\n                                var t = L.grep(f[i].getElementsByTagName(\"script\"), e);\n                                f.splice.apply(f, [((i + 1)),0,].concat(t));\n                            }\n                        ;\n                        ;\n                            c.appendChild(f[i]);\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n                return f;\n            },\n            cleanData: function(a) {\n                var b, c, d = L.cache, e = L.JSBNG__event.special, f = L.support.deleteExpando;\n                for (var g = 0, i; (((i = a[g]) != null)); g++) {\n                    if (((i.nodeName && L.noData[i.nodeName.toLowerCase()]))) {\n                        continue;\n                    }\n                ;\n                ;\n                    c = i[L.expando];\n                    if (c) {\n                        b = d[c];\n                        if (((b && b.events))) {\n                            for (var j in b.events) {\n                                ((e[j] ? L.JSBNG__event.remove(i, j) : L.removeEvent(i, j, b.handle)));\n                            ;\n                            };\n                        ;\n                            ((b.handle && (b.handle.elem = null)));\n                        }\n                    ;\n                    ;\n                        ((f ? delete i[L.expando] : ((i.removeAttribute && i.removeAttribute(L.expando))))), delete d[c];\n                    }\n                ;\n                ;\n                };\n            ;\n            }\n        });\n        var Hb = /alpha\\([^)]*\\)/i, Ib = /opacity=([^)]*)/, Jb = /([A-Z]|^ms)/g, Kb = /^-?\\d+(?:px)?$/i, Lb = /^-?\\d/, Mb = /^([\\-+])=([\\-+.\\de]+)/, Nb = {\n            position: \"absolute\",\n            visibility: \"hidden\",\n            display: \"block\"\n        }, Ob = [\"Left\",\"Right\",], Pb = [\"Top\",\"Bottom\",], Qb, Rb, Sb;\n        L.fn.css = function(a, c) {\n            return ((((((arguments.length === 2)) && ((c === b)))) ? this : L.access(this, a, c, !0, function(a, c, d) {\n                return ((((d !== b)) ? L.style(a, c, d) : L.css(a, c)));\n            })));\n        }, L.extend({\n            cssHooks: {\n                opacity: {\n                    get: function(a, b) {\n                        if (b) {\n                            var c = Qb(a, \"opacity\", \"opacity\");\n                            return ((((c === \"\")) ? \"1\" : c));\n                        }\n                    ;\n                    ;\n                        return a.style.opacity;\n                    }\n                }\n            },\n            cssNumber: {\n                fillOpacity: !0,\n                fontWeight: !0,\n                lineHeight: !0,\n                opacity: !0,\n                orphans: !0,\n                widows: !0,\n                zIndex: !0,\n                zoom: !0\n            },\n            cssProps: {\n                float: ((L.support.cssFloat ? \"cssFloat\" : \"styleFloat\"))\n            },\n            style: function(a, c, d, e) {\n                if (((((((!a || ((a.nodeType === 3)))) || ((a.nodeType === 8)))) || !a.style))) {\n                    return;\n                }\n            ;\n            ;\n                var f, g, i = L.camelCase(c), j = a.style, k = L.cssHooks[i];\n                c = ((L.cssProps[i] || i));\n                if (((d === b))) {\n                    return ((((((k && ((\"get\" in k)))) && (((f = k.get(a, !1, e)) !== b)))) ? f : j[c]));\n                }\n            ;\n            ;\n                g = typeof d, ((((((g === \"string\")) && (f = Mb.exec(d)))) && (d = ((((+((f[1] + 1)) * +f[2])) + parseFloat(L.css(a, c)))), g = \"number\")));\n                if (((((d == null)) || ((((g === \"number\")) && isNaN(d)))))) {\n                    return;\n                }\n            ;\n            ;\n                ((((((g === \"number\")) && !L.cssNumber[i])) && (d += \"px\")));\n                if (((((!k || !((\"set\" in k)))) || (((d = k.set(a, d)) !== b))))) {\n                    try {\n                        j[c] = d;\n                    } catch (l) {\n                    \n                    };\n                }\n            ;\n            ;\n            },\n            css: function(a, c, d) {\n                var e, f;\n                c = L.camelCase(c), f = L.cssHooks[c], c = ((L.cssProps[c] || c)), ((((c === \"cssFloat\")) && (c = \"float\")));\n                if (((((f && ((\"get\" in f)))) && (((e = f.get(a, !0, d)) !== b))))) {\n                    return e;\n                }\n            ;\n            ;\n                if (Qb) {\n                    return Qb(a, c);\n                }\n            ;\n            ;\n            },\n            swap: function(a, b, c) {\n                var d = {\n                };\n                for (var e in b) {\n                    d[e] = a.style[e], a.style[e] = b[e];\n                ;\n                };\n            ;\n                c.call(a);\n                for (e in b) {\n                    a.style[e] = d[e];\n                ;\n                };\n            ;\n            }\n        }), L.curCSS = L.css, L.each([\"height\",\"width\",], function(a, b) {\n            L.cssHooks[b] = {\n                get: function(a, c, d) {\n                    var e;\n                    if (c) {\n                        return ((((a.offsetWidth !== 0)) ? u(a, b, d) : (L.swap(a, Nb, function() {\n                            e = u(a, b, d);\n                        }), e)));\n                    }\n                ;\n                ;\n                },\n                set: function(a, b) {\n                    if (!Kb.test(b)) {\n                        return b;\n                    }\n                ;\n                ;\n                    b = parseFloat(b);\n                    if (((b >= 0))) {\n                        return ((b + \"px\"));\n                    }\n                ;\n                ;\n                }\n            };\n        }), ((L.support.opacity || (L.cssHooks.opacity = {\n            get: function(a, b) {\n                return ((Ib.test(((((((b && a.currentStyle)) ? a.currentStyle.filter : a.style.filter)) || \"\"))) ? ((((parseFloat(RegExp.$1) / 100)) + \"\")) : ((b ? \"1\" : \"\"))));\n            },\n            set: function(a, b) {\n                var c = a.style, d = a.currentStyle, e = ((L.isNumeric(b) ? ((((\"alpha(opacity=\" + ((b * 100)))) + \")\")) : \"\")), f = ((((((d && d.filter)) || c.filter)) || \"\"));\n                c.zoom = 1;\n                if (((((b >= 1)) && ((L.trim(f.replace(Hb, \"\")) === \"\"))))) {\n                    c.removeAttribute(\"filter\");\n                    if (((d && !d.filter))) {\n                        return;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                c.filter = ((Hb.test(f) ? f.replace(Hb, e) : ((((f + \" \")) + e))));\n            }\n        }))), L(function() {\n            ((L.support.reliableMarginRight || (L.cssHooks.marginRight = {\n                get: function(a, b) {\n                    var c;\n                    return L.swap(a, {\n                        display: \"inline-block\"\n                    }, function() {\n                        ((b ? c = Qb(a, \"margin-right\", \"marginRight\") : c = a.style.marginRight));\n                    }), c;\n                }\n            })));\n        }), ((((I.defaultView && I.defaultView.JSBNG__getComputedStyle)) && (Rb = function(a, b) {\n            var c, d, e;\n            return b = b.replace(Jb, \"-$1\").toLowerCase(), (((((d = a.ownerDocument.defaultView) && (e = d.JSBNG__getComputedStyle(a, null)))) && (c = e.getPropertyValue(b), ((((((c === \"\")) && !L.contains(a.ownerDocument.documentElement, a))) && (c = L.style(a, b))))))), c;\n        }))), ((I.documentElement.currentStyle && (Sb = function(a, b) {\n            var c, d, e, f = ((a.currentStyle && a.currentStyle[b])), g = a.style;\n            return ((((((((f === null)) && g)) && (e = g[b]))) && (f = e))), ((((!Kb.test(f) && Lb.test(f))) && (c = g.left, d = ((a.runtimeStyle && a.runtimeStyle.left)), ((d && (a.runtimeStyle.left = a.currentStyle.left))), g.left = ((((b === \"fontSize\")) ? \"1em\" : ((f || 0)))), f = ((g.pixelLeft + \"px\")), g.left = c, ((d && (a.runtimeStyle.left = d)))))), ((((f === \"\")) ? \"auto\" : f));\n        }))), Qb = ((Rb || Sb)), ((((L.expr && L.expr.filters)) && (L.expr.filters.hidden = function(a) {\n            var b = a.offsetWidth, c = a.offsetHeight;\n            return ((((((b === 0)) && ((c === 0)))) || ((!L.support.reliableHiddenOffsets && ((((((a.style && a.style.display)) || L.css(a, \"display\"))) === \"none\"))))));\n        }, L.expr.filters.visible = function(a) {\n            return !L.expr.filters.hidden(a);\n        })));\n        var Tb = /%20/g, Ub = /\\[\\]$/, Vb = /\\r?\\n/g, Wb = /#.*$/, Xb = /^(.*?):[ \\t]*([^\\r\\n]*)\\r?$/gm, Yb = /^(?:color|date|datetime|datetime-local|email|hidden|month|number|password|range|search|tel|text|time|url|week)$/i, Zb = /^(?:about|app|app\\-storage|.+\\-extension|file|res|widget):$/, $b = /^(?:GET|HEAD)$/, _b = /^\\/\\//, ac = /\\?/, bc = /<script\\b[^<]*(?:(?!<\\/script>)<[^<]*)*<\\/script>/gi, cc = /^(?:select|textarea)/i, dc = /\\s+/, ec = /([?&])_=[^&]*/, fc = /^([\\w\\+\\.\\-]+:)(?:\\/\\/([^\\/?#:]*)(?::(\\d+))?)?/, gc = L.fn.load, hc = {\n        }, ic = {\n        }, jc, kc, lc = (([\"*/\",] + [\"*\",]));\n        try {\n            jc = K.href;\n        } catch (mc) {\n            jc = I.createElement(\"a\"), jc.href = \"\", jc = jc.href;\n        };\n    ;\n        kc = ((fc.exec(jc.toLowerCase()) || [])), L.fn.extend({\n            load: function(a, c, d) {\n                if (((((typeof a != \"string\")) && gc))) {\n                    return gc.apply(this, arguments);\n                }\n            ;\n            ;\n                if (!this.length) {\n                    return this;\n                }\n            ;\n            ;\n                var e = a.indexOf(\" \");\n                if (((e >= 0))) {\n                    var f = a.slice(e, a.length);\n                    a = a.slice(0, e);\n                }\n            ;\n            ;\n                var g = \"GET\";\n                ((c && ((L.isFunction(c) ? (d = c, c = b) : ((((typeof c == \"object\")) && (c = L.param(c, L.ajaxSettings.traditional), g = \"POST\")))))));\n                var i = this;\n                return L.ajax({\n                    url: a,\n                    type: g,\n                    dataType: \"html\",\n                    data: c,\n                    complete: function(a, b, c) {\n                        c = a.responseText, ((a.isResolved() && (a.done(function(a) {\n                            c = a;\n                        }), i.html(((f ? L(\"\\u003Cdiv\\u003E\").append(c.replace(bc, \"\")).JSBNG__find(f) : c)))))), ((d && i.each(d, [c,b,a,])));\n                    }\n                }), this;\n            },\n            serialize: function() {\n                return L.param(this.serializeArray());\n            },\n            serializeArray: function() {\n                return this.map(function() {\n                    return ((this.elements ? L.makeArray(this.elements) : this));\n                }).filter(function() {\n                    return ((((this.JSBNG__name && !this.disabled)) && ((((this.checked || cc.test(this.nodeName))) || Yb.test(this.type)))));\n                }).map(function(a, b) {\n                    var c = L(this).val();\n                    return ((((c == null)) ? null : ((L.isArray(c) ? L.map(c, function(a, c) {\n                        return {\n                            JSBNG__name: b.JSBNG__name,\n                            value: a.replace(Vb, \"\\u000d\\u000a\")\n                        };\n                    }) : {\n                        JSBNG__name: b.JSBNG__name,\n                        value: c.replace(Vb, \"\\u000d\\u000a\")\n                    }))));\n                }).get();\n            }\n        }), L.each(\"ajaxStart ajaxStop ajaxComplete ajaxError ajaxSuccess ajaxSend\".split(\" \"), function(a, b) {\n            L.fn[b] = function(a) {\n                return this.JSBNG__on(b, a);\n            };\n        }), L.each([\"get\",\"post\",], function(a, c) {\n            L[c] = function(a, d, e, f) {\n                return ((L.isFunction(d) && (f = ((f || e)), e = d, d = b))), L.ajax({\n                    type: c,\n                    url: a,\n                    data: d,\n                    success: e,\n                    dataType: f\n                });\n            };\n        }), L.extend({\n            getScript: function(a, c) {\n                return L.get(a, b, c, \"script\");\n            },\n            getJSON: function(a, b, c) {\n                return L.get(a, b, c, \"json\");\n            },\n            ajaxSetup: function(a, b) {\n                return ((b ? x(a, L.ajaxSettings) : (b = a, a = L.ajaxSettings))), x(a, b), a;\n            },\n            ajaxSettings: {\n                url: jc,\n                isLocal: Zb.test(kc[1]),\n                global: !0,\n                type: \"GET\",\n                contentType: \"application/x-www-form-urlencoded\",\n                processData: !0,\n                async: !0,\n                accepts: {\n                    xml: \"application/xml, text/xml\",\n                    html: \"text/html\",\n                    text: \"text/plain\",\n                    json: \"application/json, text/javascript\",\n                    \"*\": lc\n                },\n                contents: {\n                    xml: /xml/,\n                    html: /html/,\n                    json: /json/\n                },\n                responseFields: {\n                    xml: \"responseXML\",\n                    text: \"responseText\"\n                },\n                converters: {\n                    \"* text\": a.String,\n                    \"text html\": !0,\n                    \"text json\": L.parseJSON,\n                    \"text xml\": L.parseXML\n                },\n                flatOptions: {\n                    context: !0,\n                    url: !0\n                }\n            },\n            ajaxPrefilter: v(hc),\n            ajaxTransport: v(ic),\n            ajax: function(a, c) {\n                function d(a, c, d, m) {\n                    if (((t === 2))) {\n                        return;\n                    }\n                ;\n                ;\n                    t = 2, ((r && JSBNG__clearTimeout(r))), q = b, o = ((m || \"\")), x.readyState = ((((a > 0)) ? 4 : 0));\n                    var n, p, s, v = c, w = ((d ? z(e, x, d) : b)), y, B;\n                    if (((((((a >= 200)) && ((a < 300)))) || ((a === 304))))) {\n                        if (e.ifModified) {\n                            if (y = x.getResponseHeader(\"Last-Modified\")) {\n                                L.lastModified[l] = y;\n                            }\n                        ;\n                        ;\n                            if (B = x.getResponseHeader(\"Etag\")) {\n                                L.etag[l] = B;\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                        if (((a === 304))) {\n                            v = \"notmodified\", n = !0;\n                        }\n                         else {\n                            try {\n                                p = A(e, w), v = \"success\", n = !0;\n                            } catch (C) {\n                                v = \"parsererror\", s = C;\n                            };\n                        }\n                    ;\n                    ;\n                    }\n                     else {\n                        s = v;\n                        if (((!v || a))) {\n                            v = \"error\", ((((a < 0)) && (a = 0)));\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    x.JSBNG__status = a, x.statusText = ((\"\" + ((c || v)))), ((n ? i.resolveWith(f, [p,v,x,]) : i.rejectWith(f, [x,v,s,]))), x.statusCode(k), k = b, ((u && g.trigger(((\"ajax\" + ((n ? \"Success\" : \"Error\")))), [x,e,((n ? p : s)),]))), j.fireWith(f, [x,v,]), ((u && (g.trigger(\"ajaxComplete\", [x,e,]), ((--L.active || L.JSBNG__event.trigger(\"ajaxStop\"))))));\n                };\n            ;\n                ((((typeof a == \"object\")) && (c = a, a = b))), c = ((c || {\n                }));\n                var e = L.ajaxSetup({\n                }, c), f = ((e.context || e)), g = ((((((f !== e)) && ((f.nodeType || ((f instanceof L)))))) ? L(f) : L.JSBNG__event)), i = L.Deferred(), j = L.Callbacks(\"JSBNG__once memory\"), k = ((e.statusCode || {\n                })), l, m = {\n                }, n = {\n                }, o, p, q, r, s, t = 0, u, v, x = {\n                    readyState: 0,\n                    setRequestHeader: function(a, b) {\n                        if (!t) {\n                            var c = a.toLowerCase();\n                            a = n[c] = ((n[c] || a)), m[a] = b;\n                        }\n                    ;\n                    ;\n                        return this;\n                    },\n                    getAllResponseHeaders: function() {\n                        return ((((t === 2)) ? o : null));\n                    },\n                    getResponseHeader: function(a) {\n                        var c;\n                        if (((t === 2))) {\n                            if (!p) {\n                                p = {\n                                };\n                                while (c = Xb.exec(o)) {\n                                    p[c[1].toLowerCase()] = c[2];\n                                ;\n                                };\n                            ;\n                            }\n                        ;\n                        ;\n                            c = p[a.toLowerCase()];\n                        }\n                    ;\n                    ;\n                        return ((((c === b)) ? null : c));\n                    },\n                    overrideMimeType: function(a) {\n                        return ((t || (e.mimeType = a))), this;\n                    },\n                    abort: function(a) {\n                        return a = ((a || \"abort\")), ((q && q.abort(a))), d(0, a), this;\n                    }\n                };\n                i.promise(x), x.success = x.done, x.error = x.fail, x.complete = j.add, x.statusCode = function(a) {\n                    if (a) {\n                        var b;\n                        if (((t < 2))) {\n                            for (b in a) {\n                                k[b] = [k[b],a[b],];\n                            ;\n                            };\n                        }\n                         else {\n                            b = a[x.JSBNG__status], x.then(b, b);\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    return this;\n                }, e.url = ((((a || e.url)) + \"\")).replace(Wb, \"\").replace(_b, ((kc[1] + \"//\"))), e.dataTypes = L.trim(((e.dataType || \"*\"))).toLowerCase().split(dc), ((((e.crossDomain == null)) && (s = fc.exec(e.url.toLowerCase()), e.crossDomain = !((!s || ((((((s[1] == kc[1])) && ((s[2] == kc[2])))) && ((((s[3] || ((((s[1] === \"http:\")) ? 80 : 443)))) == ((kc[3] || ((((kc[1] === \"http:\")) ? 80 : 443))))))))))))), ((((((e.data && e.processData)) && ((typeof e.data != \"string\")))) && (e.data = L.param(e.data, e.traditional)))), w(hc, e, c, x);\n                if (((t === 2))) {\n                    return !1;\n                }\n            ;\n            ;\n                u = e.global, e.type = e.type.toUpperCase(), e.hasContent = !$b.test(e.type), ((((u && ((L.active++ === 0)))) && L.JSBNG__event.trigger(\"ajaxStart\")));\n                if (!e.hasContent) {\n                    ((e.data && (e.url += ((((ac.test(e.url) ? \"&\" : \"?\")) + e.data)), delete e.data))), l = e.url;\n                    if (((e.cache === !1))) {\n                        var y = L.now(), B = e.url.replace(ec, ((\"$1_=\" + y)));\n                        e.url = ((B + ((((B === e.url)) ? ((((((ac.test(e.url) ? \"&\" : \"?\")) + \"_=\")) + y)) : \"\"))));\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                ((((((((e.data && e.hasContent)) && ((e.contentType !== !1)))) || c.contentType)) && x.setRequestHeader(\"Content-Type\", e.contentType))), ((e.ifModified && (l = ((l || e.url)), ((L.lastModified[l] && x.setRequestHeader(\"If-Modified-Since\", L.lastModified[l]))), ((L.etag[l] && x.setRequestHeader(\"If-None-Match\", L.etag[l])))))), x.setRequestHeader(\"Accept\", ((((e.dataTypes[0] && e.accepts[e.dataTypes[0]])) ? ((e.accepts[e.dataTypes[0]] + ((((e.dataTypes[0] !== \"*\")) ? ((((\", \" + lc)) + \"; q=0.01\")) : \"\")))) : e.accepts[\"*\"])));\n                for (v in e.headers) {\n                    x.setRequestHeader(v, e.headers[v]);\n                ;\n                };\n            ;\n                if (((!e.beforeSend || ((((e.beforeSend.call(f, x, e) !== !1)) && ((t !== 2))))))) {\n                    for (v in {\n                        success: 1,\n                        error: 1,\n                        complete: 1\n                    }) {\n                        x[v](e[v]);\n                    ;\n                    };\n                ;\n                    q = w(ic, e, c, x);\n                    if (!q) d(-1, \"No Transport\");\n                     else {\n                        x.readyState = 1, ((u && g.trigger(\"ajaxSend\", [x,e,]))), ((((e.async && ((e.timeout > 0)))) && (r = JSBNG__setTimeout(function() {\n                            x.abort(\"timeout\");\n                        }, e.timeout))));\n                        try {\n                            t = 1, q.send(m, d);\n                        } catch (C) {\n                            if (!((t < 2))) {\n                                throw C;\n                            }\n                        ;\n                        ;\n                            d(-1, C);\n                        };\n                    ;\n                    }\n                ;\n                ;\n                    return x;\n                }\n            ;\n            ;\n                return x.abort(), !1;\n            },\n            param: function(a, c) {\n                var d = [], e = function(a, b) {\n                    b = ((L.isFunction(b) ? b() : b)), d[d.length] = ((((encodeURIComponent(a) + \"=\")) + encodeURIComponent(b)));\n                };\n                ((((c === b)) && (c = L.ajaxSettings.traditional)));\n                if (((L.isArray(a) || ((a.jquery && !L.isPlainObject(a)))))) {\n                    L.each(a, function() {\n                        e(this.JSBNG__name, this.value);\n                    });\n                }\n                 else {\n                    for (var f in a) {\n                        y(f, a[f], c, e);\n                    ;\n                    };\n                }\n            ;\n            ;\n                return d.join(\"&\").replace(Tb, \"+\");\n            }\n        }), L.extend({\n            active: 0,\n            lastModified: {\n            },\n            etag: {\n            }\n        });\n        var nc = L.now(), oc = /(\\=)\\?(&|$)|\\?\\?/i;\n        L.ajaxSetup({\n            jsonp: \"callback\",\n            jsonpCallback: function() {\n                return ((((L.expando + \"_\")) + nc++));\n            }\n        }), L.ajaxPrefilter(\"json jsonp\", function(b, c, d) {\n            var e = ((((b.contentType === \"application/x-www-form-urlencoded\")) && ((typeof b.data == \"string\"))));\n            if (((((b.dataTypes[0] === \"jsonp\")) || ((((b.jsonp !== !1)) && ((oc.test(b.url) || ((e && oc.test(b.data)))))))))) {\n                var f, g = b.jsonpCallback = ((L.isFunction(b.jsonpCallback) ? b.jsonpCallback() : b.jsonpCallback)), i = a[g], j = b.url, k = b.data, l = ((((\"$1\" + g)) + \"$2\"));\n                return ((((b.jsonp !== !1)) && (j = j.replace(oc, l), ((((b.url === j)) && (((e && (k = k.replace(oc, l)))), ((((b.data === k)) && (j += ((((((((/\\?/.test(j) ? \"&\" : \"?\")) + b.jsonp)) + \"=\")) + g))))))))))), b.url = j, b.data = k, a[g] = function(a) {\n                    f = [a,];\n                }, d.always(function() {\n                    a[g] = i, ((((f && L.isFunction(i))) && a[g](f[0])));\n                }), b.converters[\"script json\"] = function() {\n                    return ((f || L.error(((g + \" was not called\"))))), f[0];\n                }, b.dataTypes[0] = \"json\", \"script\";\n            }\n        ;\n        ;\n        }), L.ajaxSetup({\n            accepts: {\n                script: \"text/javascript, application/javascript, application/ecmascript, application/x-ecmascript\"\n            },\n            contents: {\n                script: /javascript|ecmascript/\n            },\n            converters: {\n                \"text script\": function(a) {\n                    return L.globalEval(a), a;\n                }\n            }\n        }), L.ajaxPrefilter(\"script\", function(a) {\n            ((((a.cache === b)) && (a.cache = !1))), ((a.crossDomain && (a.type = \"GET\", a.global = !1)));\n        }), L.ajaxTransport(\"script\", function(a) {\n            if (a.crossDomain) {\n                var c, d = ((((I.head || I.getElementsByTagName(\"head\")[0])) || I.documentElement));\n                return {\n                    send: function(_, e) {\n                        c = I.createElement(\"script\"), c.async = \"async\", ((a.scriptCharset && (c.charset = a.scriptCharset))), c.src = a.url, c.JSBNG__onload = c.JSBNG__onreadystatechange = function(_, a) {\n                            if (((((a || !c.readyState)) || /loaded|complete/.test(c.readyState)))) {\n                                c.JSBNG__onload = c.JSBNG__onreadystatechange = null, ((((d && c.parentNode)) && d.removeChild(c))), c = b, ((a || e(200, \"success\")));\n                            }\n                        ;\n                        ;\n                        }, d.insertBefore(c, d.firstChild);\n                    },\n                    abort: function() {\n                        ((c && c.JSBNG__onload(0, 1)));\n                    }\n                };\n            }\n        ;\n        ;\n        });\n        var pc = ((a.ActiveXObject ? function() {\n            for (var a in rc) {\n                rc[a](0, 1);\n            ;\n            };\n        ;\n        } : !1)), qc = 0, rc;\n        L.ajaxSettings.xhr = ((a.ActiveXObject ? function() {\n            return ((((!this.isLocal && B())) || C()));\n        } : B)), function(a) {\n            L.extend(L.support, {\n                ajax: !!a,\n                cors: ((!!a && ((\"withCredentials\" in a))))\n            });\n        }(L.ajaxSettings.xhr()), ((L.support.ajax && L.ajaxTransport(function(c) {\n            if (((!c.crossDomain || L.support.cors))) {\n                var d;\n                return {\n                    send: function(e, f) {\n                        var g = c.xhr(), i, j;\n                        ((c.username ? g.open(c.type, c.url, c.async, c.username, c.password) : g.open(c.type, c.url, c.async)));\n                        if (c.xhrFields) {\n                            for (j in c.xhrFields) {\n                                g[j] = c.xhrFields[j];\n                            ;\n                            };\n                        }\n                    ;\n                    ;\n                        ((((c.mimeType && g.overrideMimeType)) && g.overrideMimeType(c.mimeType))), ((((!c.crossDomain && !e[\"X-Requested-With\"])) && (e[\"X-Requested-With\"] = \"JSBNG__XMLHttpRequest\")));\n                        try {\n                            for (j in e) {\n                                g.setRequestHeader(j, e[j]);\n                            ;\n                            };\n                        ;\n                        } catch (_) {\n                        \n                        };\n                    ;\n                        g.send(((((c.hasContent && c.data)) || null))), d = function(_, a) {\n                            var e, j, k, l, m;\n                            try {\n                                if (((d && ((a || ((g.readyState === 4))))))) {\n                                    d = b, ((i && (g.JSBNG__onreadystatechange = L.noop, ((pc && delete rc[i])))));\n                                    if (a) ((((g.readyState !== 4)) && g.abort()));\n                                     else {\n                                        e = g.JSBNG__status, k = g.getAllResponseHeaders(), l = {\n                                        }, m = g.responseXML, ((((m && m.documentElement)) && (l.xml = m))), l.text = g.responseText;\n                                        try {\n                                            j = g.statusText;\n                                        } catch (n) {\n                                            j = \"\";\n                                        };\n                                    ;\n                                        ((((((!e && c.isLocal)) && !c.crossDomain)) ? e = ((l.text ? 200 : 404)) : ((((e === 1223)) && (e = 204)))));\n                                    }\n                                ;\n                                ;\n                                }\n                            ;\n                            ;\n                            } catch (o) {\n                                ((a || f(-1, o)));\n                            };\n                        ;\n                            ((l && f(e, j, l, k)));\n                        }, ((((!c.async || ((g.readyState === 4)))) ? d() : (i = ++qc, ((pc && (((rc || (rc = {\n                        }, L(a).unload(pc)))), rc[i] = d))), g.JSBNG__onreadystatechange = d)));\n                    },\n                    abort: function() {\n                        ((d && d(0, 1)));\n                    }\n                };\n            }\n        ;\n        ;\n        })));\n        var sc = {\n        }, tc, uc, vc = /^(?:toggle|show|hide)$/, wc = /^([+\\-]=)?([\\d+.\\-]+)([a-z%]*)$/i, xc, yc = [[\"height\",\"marginTop\",\"marginBottom\",\"paddingTop\",\"paddingBottom\",],[\"width\",\"marginLeft\",\"marginRight\",\"paddingLeft\",\"paddingRight\",],[\"opacity\",],], zc;\n        L.fn.extend({\n            show: function(a, b, c) {\n                var d, e;\n                if (((a || ((a === 0))))) {\n                    return this.animate(F(\"show\", 3), a, b, c);\n                }\n            ;\n            ;\n                for (var f = 0, g = this.length; ((f < g)); f++) {\n                    d = this[f], ((d.style && (e = d.style.display, ((((!L._data(d, \"olddisplay\") && ((e === \"none\")))) && (e = d.style.display = \"\"))), ((((((e === \"\")) && ((L.css(d, \"display\") === \"none\")))) && L._data(d, \"olddisplay\", G(d.nodeName)))))));\n                ;\n                };\n            ;\n                for (f = 0; ((f < g)); f++) {\n                    d = this[f];\n                    if (d.style) {\n                        e = d.style.display;\n                        if (((((e === \"\")) || ((e === \"none\"))))) {\n                            d.style.display = ((L._data(d, \"olddisplay\") || \"\"));\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                };\n            ;\n                return this;\n            },\n            hide: function(a, b, c) {\n                if (((a || ((a === 0))))) {\n                    return this.animate(F(\"hide\", 3), a, b, c);\n                }\n            ;\n            ;\n                var d, e, f = 0, g = this.length;\n                for (; ((f < g)); f++) {\n                    d = this[f], ((d.style && (e = L.css(d, \"display\"), ((((((e !== \"none\")) && !L._data(d, \"olddisplay\"))) && L._data(d, \"olddisplay\", e))))));\n                ;\n                };\n            ;\n                for (f = 0; ((f < g)); f++) {\n                    ((this[f].style && (this[f].style.display = \"none\")));\n                ;\n                };\n            ;\n                return this;\n            },\n            _toggle: L.fn.toggle,\n            toggle: function(a, b, c) {\n                var d = ((typeof a == \"boolean\"));\n                return ((((L.isFunction(a) && L.isFunction(b))) ? this._toggle.apply(this, arguments) : ((((((a == null)) || d)) ? this.each(function() {\n                    var b = ((d ? a : L(this).is(\":hidden\")));\n                    L(this)[((b ? \"show\" : \"hide\"))]();\n                }) : this.animate(F(\"toggle\", 3), a, b, c))))), this;\n            },\n            fadeTo: function(a, b, c, d) {\n                return this.filter(\":hidden\").css(\"opacity\", 0).show().end().animate({\n                    opacity: b\n                }, a, c, d);\n            },\n            animate: function(a, b, c, d) {\n                function e() {\n                    ((((f.queue === !1)) && L._mark(this)));\n                    var b = L.extend({\n                    }, f), c = ((this.nodeType === 1)), d = ((c && L(this).is(\":hidden\"))), e, g, i, j, k, l, m, n, o;\n                    b.animatedProperties = {\n                    };\n                    for (i in a) {\n                        e = L.camelCase(i), ((((i !== e)) && (a[e] = a[i], delete a[i]))), g = a[e], ((L.isArray(g) ? (b.animatedProperties[e] = g[1], g = a[e] = g[0]) : b.animatedProperties[e] = ((((((b.specialEasing && b.specialEasing[e])) || b.easing)) || \"swing\"))));\n                        if (((((((g === \"hide\")) && d)) || ((((g === \"show\")) && !d))))) {\n                            return b.complete.call(this);\n                        }\n                    ;\n                    ;\n                        ((((c && ((((e === \"height\")) || ((e === \"width\")))))) && (b.overflow = [this.style.overflow,this.style.overflowX,this.style.overflowY,], ((((((L.css(this, \"display\") === \"inline\")) && ((L.css(this, \"float\") === \"none\")))) && ((((!L.support.inlineBlockNeedsLayout || ((G(this.nodeName) === \"inline\")))) ? this.style.display = \"inline-block\" : this.style.zoom = 1)))))));\n                    };\n                ;\n                    ((((b.overflow != null)) && (this.style.overflow = \"hidden\")));\n                    for (i in a) {\n                        j = new L.fx(this, b, i), g = a[i], ((vc.test(g) ? (o = ((L._data(this, ((\"toggle\" + i))) || ((((g === \"toggle\")) ? ((d ? \"show\" : \"hide\")) : 0)))), ((o ? (L._data(this, ((\"toggle\" + i)), ((((o === \"show\")) ? \"hide\" : \"show\"))), j[o]()) : j[g]()))) : (k = wc.exec(g), l = j.cur(), ((k ? (m = parseFloat(k[2]), n = ((k[3] || ((L.cssNumber[i] ? \"\" : \"px\")))), ((((n !== \"px\")) && (L.style(this, i, ((((m || 1)) + n))), l = ((((((m || 1)) / j.cur())) * l)), L.style(this, i, ((l + n)))))), ((k[1] && (m = ((((((((k[1] === \"-=\")) ? -1 : 1)) * m)) + l))))), j.custom(l, m, n)) : j.custom(l, g, \"\"))))));\n                    ;\n                    };\n                ;\n                    return !0;\n                };\n            ;\n                var f = L.speed(b, c, d);\n                return ((L.isEmptyObject(a) ? this.each(f.complete, [!1,]) : (a = L.extend({\n                }, a), ((((f.queue === !1)) ? this.each(e) : this.queue(f.queue, e))))));\n            },\n            JSBNG__stop: function(a, c, d) {\n                return ((((typeof a != \"string\")) && (d = c, c = a, a = b))), ((((c && ((a !== !1)))) && this.queue(((a || \"fx\")), []))), this.each(function() {\n                    function b(a, b, c) {\n                        var e = b[c];\n                        L.removeData(a, c, !0), e.JSBNG__stop(d);\n                    };\n                ;\n                    var c, e = !1, f = L.timers, g = L._data(this);\n                    ((d || L._unmark(!0, this)));\n                    if (((a == null))) {\n                        for (c in g) {\n                            ((((((g[c] && g[c].JSBNG__stop)) && ((c.indexOf(\".run\") === ((c.length - 4)))))) && b(this, g, c)));\n                        ;\n                        };\n                    }\n                     else {\n                        ((((g[c = ((a + \".run\"))] && g[c].JSBNG__stop)) && b(this, g, c)));\n                    }\n                ;\n                ;\n                    for (c = f.length; c--; ) {\n                        ((((((f[c].elem === this)) && ((((a == null)) || ((f[c].queue === a)))))) && (((d ? f[c](!0) : f[c].saveState())), e = !0, f.splice(c, 1))));\n                    ;\n                    };\n                ;\n                    ((((!d || !e)) && L.dequeue(this, a)));\n                });\n            }\n        }), L.each({\n            slideDown: F(\"show\", 1),\n            slideUp: F(\"hide\", 1),\n            slideToggle: F(\"toggle\", 1),\n            fadeIn: {\n                opacity: \"show\"\n            },\n            fadeOut: {\n                opacity: \"hide\"\n            },\n            fadeToggle: {\n                opacity: \"toggle\"\n            }\n        }, function(a, b) {\n            L.fn[a] = function(a, c, d) {\n                return this.animate(b, a, c, d);\n            };\n        }), L.extend({\n            speed: function(a, b, c) {\n                var d = ((((a && ((typeof a == \"object\")))) ? L.extend({\n                }, a) : {\n                    complete: ((((c || ((!c && b)))) || ((L.isFunction(a) && a)))),\n                    duration: a,\n                    easing: ((((c && b)) || ((((b && !L.isFunction(b))) && b))))\n                }));\n                d.duration = ((L.fx.off ? 0 : ((((typeof d.duration == \"number\")) ? d.duration : ((((d.duration in L.fx.speeds)) ? L.fx.speeds[d.duration] : L.fx.speeds._default))))));\n                if (((((d.queue == null)) || ((d.queue === !0))))) {\n                    d.queue = \"fx\";\n                }\n            ;\n            ;\n                return d.old = d.complete, d.complete = function(a) {\n                    ((L.isFunction(d.old) && d.old.call(this))), ((d.queue ? L.dequeue(this, d.queue) : ((((a !== !1)) && L._unmark(this)))));\n                }, d;\n            },\n            easing: {\n                linear: function(a, b, c, d) {\n                    return ((c + ((d * a))));\n                },\n                swing: function(a, b, c, d) {\n                    return ((((((((-Math.cos(((a * Math.PI))) / 2)) + 128416)) * d)) + c));\n                }\n            },\n            timers: [],\n            fx: function(a, b, c) {\n                this.options = b, this.elem = a, this.prop = c, b.orig = ((b.orig || {\n                }));\n            }\n        }), L.fx.prototype = {\n            update: function() {\n                ((this.options.step && this.options.step.call(this.elem, this.now, this))), ((L.fx.step[this.prop] || L.fx.step._default))(this);\n            },\n            cur: function() {\n                if (((((this.elem[this.prop] == null)) || ((!!this.elem.style && ((this.elem.style[this.prop] != null))))))) {\n                    var a, b = L.css(this.elem, this.prop);\n                    return ((isNaN(a = parseFloat(b)) ? ((((!b || ((b === \"auto\")))) ? 0 : b)) : a));\n                }\n            ;\n            ;\n                return this.elem[this.prop];\n            },\n            custom: function(a, c, d) {\n                function e(a) {\n                    return f.step(a);\n                };\n            ;\n                var f = this, g = L.fx;\n                this.startTime = ((zc || D())), this.end = c, this.now = this.start = a, this.pos = this.state = 0, this.unit = ((((d || this.unit)) || ((L.cssNumber[this.prop] ? \"\" : \"px\")))), e.queue = this.options.queue, e.elem = this.elem, e.saveState = function() {\n                    ((((f.options.hide && ((L._data(f.elem, ((\"fxshow\" + f.prop))) === b)))) && L._data(f.elem, ((\"fxshow\" + f.prop)), f.start)));\n                }, ((((((e() && L.timers.push(e))) && !xc)) && (xc = JSBNG__setInterval(g.tick, g.interval))));\n            },\n            show: function() {\n                var a = L._data(this.elem, ((\"fxshow\" + this.prop)));\n                this.options.orig[this.prop] = ((a || L.style(this.elem, this.prop))), this.options.show = !0, ((((a !== b)) ? this.custom(this.cur(), a) : this.custom(((((((this.prop === \"width\")) || ((this.prop === \"height\")))) ? 1 : 0)), this.cur()))), L(this.elem).show();\n            },\n            hide: function() {\n                this.options.orig[this.prop] = ((L._data(this.elem, ((\"fxshow\" + this.prop))) || L.style(this.elem, this.prop))), this.options.hide = !0, this.custom(this.cur(), 0);\n            },\n            step: function(a) {\n                var b, c, d, e = ((zc || D())), f = !0, g = this.elem, i = this.options;\n                if (((a || ((e >= ((i.duration + this.startTime))))))) {\n                    this.now = this.end, this.pos = this.state = 1, this.update(), i.animatedProperties[this.prop] = !0;\n                    for (b in i.animatedProperties) {\n                        ((((i.animatedProperties[b] !== !0)) && (f = !1)));\n                    ;\n                    };\n                ;\n                    if (f) {\n                        ((((((i.overflow != null)) && !L.support.shrinkWrapBlocks)) && L.each([\"\",\"X\",\"Y\",], function(a, b) {\n                            g.style[((\"overflow\" + b))] = i.overflow[a];\n                        }))), ((i.hide && L(g).hide()));\n                        if (((i.hide || i.show))) {\n                            for (b in i.animatedProperties) {\n                                L.style(g, b, i.orig[b]), L.removeData(g, ((\"fxshow\" + b)), !0), L.removeData(g, ((\"toggle\" + b)), !0);\n                            ;\n                            };\n                        }\n                    ;\n                    ;\n                        d = i.complete, ((d && (i.complete = !1, d.call(g))));\n                    }\n                ;\n                ;\n                    return !1;\n                }\n            ;\n            ;\n                return ((((i.duration == Infinity)) ? this.now = e : (c = ((e - this.startTime)), this.state = ((c / i.duration)), this.pos = L.easing[i.animatedProperties[this.prop]](this.state, c, 0, 1, i.duration), this.now = ((this.start + ((((this.end - this.start)) * this.pos))))))), this.update(), !0;\n            }\n        }, L.extend(L.fx, {\n            tick: function() {\n                var a, b = L.timers, c = 0;\n                for (; ((c < b.length)); c++) {\n                    a = b[c], ((((!a() && ((b[c] === a)))) && b.splice(c--, 1)));\n                ;\n                };\n            ;\n                ((b.length || L.fx.JSBNG__stop()));\n            },\n            interval: 13,\n            JSBNG__stop: function() {\n                JSBNG__clearInterval(xc), xc = null;\n            },\n            speeds: {\n                slow: 600,\n                fast: 200,\n                _default: 400\n            },\n            step: {\n                opacity: function(a) {\n                    L.style(a.elem, \"opacity\", a.now);\n                },\n                _default: function(a) {\n                    ((((a.elem.style && ((a.elem.style[a.prop] != null)))) ? a.elem.style[a.prop] = ((a.now + a.unit)) : a.elem[a.prop] = a.now));\n                }\n            }\n        }), L.each([\"width\",\"height\",], function(a, b) {\n            L.fx.step[b] = function(a) {\n                L.style(a.elem, b, ((Math.max(0, a.now) + a.unit)));\n            };\n        }), ((((L.expr && L.expr.filters)) && (L.expr.filters.animated = function(a) {\n            return L.grep(L.timers, function(b) {\n                return ((a === b.elem));\n            }).length;\n        })));\n        var Ac = /^t(?:able|d|h)$/i, Bc = /^(?:body|html)$/i;\n        ((((\"getBoundingClientRect\" in I.documentElement)) ? L.fn.offset = function(a) {\n            var b = this[0], c;\n            if (a) {\n                return this.each(function(b) {\n                    L.offset.setOffset(this, a, b);\n                });\n            }\n        ;\n        ;\n            if (((!b || !b.ownerDocument))) {\n                return null;\n            }\n        ;\n        ;\n            if (((b === b.ownerDocument.body))) {\n                return L.offset.bodyOffset(b);\n            }\n        ;\n        ;\n            try {\n                c = b.getBoundingClientRect();\n            } catch (d) {\n            \n            };\n        ;\n            var e = b.ownerDocument, f = e.documentElement;\n            if (((!c || !L.contains(f, b)))) {\n                return ((c ? {\n                    JSBNG__top: c.JSBNG__top,\n                    left: c.left\n                } : {\n                    JSBNG__top: 0,\n                    left: 0\n                }));\n            }\n        ;\n        ;\n            var g = e.body, i = H(e), j = ((((f.clientTop || g.clientTop)) || 0)), k = ((((f.clientLeft || g.clientLeft)) || 0)), l = ((((i.JSBNG__pageYOffset || ((L.support.boxModel && f.scrollTop)))) || g.scrollTop)), m = ((((i.JSBNG__pageXOffset || ((L.support.boxModel && f.scrollLeft)))) || g.scrollLeft)), n = ((((c.JSBNG__top + l)) - j)), o = ((((c.left + m)) - k));\n            return {\n                JSBNG__top: n,\n                left: o\n            };\n        } : L.fn.offset = function(a) {\n            var b = this[0];\n            if (a) {\n                return this.each(function(b) {\n                    L.offset.setOffset(this, a, b);\n                });\n            }\n        ;\n        ;\n            if (((!b || !b.ownerDocument))) {\n                return null;\n            }\n        ;\n        ;\n            if (((b === b.ownerDocument.body))) {\n                return L.offset.bodyOffset(b);\n            }\n        ;\n        ;\n            var c, d = b.offsetParent, e = b, f = b.ownerDocument, g = f.documentElement, i = f.body, j = f.defaultView, k = ((j ? j.JSBNG__getComputedStyle(b, null) : b.currentStyle)), l = b.offsetTop, m = b.offsetLeft;\n            while ((((((b = b.parentNode) && ((b !== i)))) && ((b !== g))))) {\n                if (((L.support.fixedPosition && ((k.position === \"fixed\"))))) {\n                    break;\n                }\n            ;\n            ;\n                c = ((j ? j.JSBNG__getComputedStyle(b, null) : b.currentStyle)), l -= b.scrollTop, m -= b.scrollLeft, ((((b === d)) && (l += b.offsetTop, m += b.offsetLeft, ((((L.support.doesNotAddBorder && ((!L.support.doesAddBorderForTableAndCells || !Ac.test(b.nodeName))))) && (l += ((parseFloat(c.borderTopWidth) || 0)), m += ((parseFloat(c.borderLeftWidth) || 0))))), e = d, d = b.offsetParent))), ((((L.support.subtractsBorderForOverflowNotVisible && ((c.overflow !== \"visible\")))) && (l += ((parseFloat(c.borderTopWidth) || 0)), m += ((parseFloat(c.borderLeftWidth) || 0))))), k = c;\n            };\n        ;\n            if (((((k.position === \"relative\")) || ((k.position === \"static\"))))) {\n                l += i.offsetTop, m += i.offsetLeft;\n            }\n        ;\n        ;\n            return ((((L.support.fixedPosition && ((k.position === \"fixed\")))) && (l += Math.max(g.scrollTop, i.scrollTop), m += Math.max(g.scrollLeft, i.scrollLeft)))), {\n                JSBNG__top: l,\n                left: m\n            };\n        })), L.offset = {\n            bodyOffset: function(a) {\n                var b = a.offsetTop, c = a.offsetLeft;\n                return ((L.support.doesNotIncludeMarginInBodyOffset && (b += ((parseFloat(L.css(a, \"marginTop\")) || 0)), c += ((parseFloat(L.css(a, \"marginLeft\")) || 0))))), {\n                    JSBNG__top: b,\n                    left: c\n                };\n            },\n            setOffset: function(a, b, c) {\n                var d = L.css(a, \"position\");\n                ((((d === \"static\")) && (a.style.position = \"relative\")));\n                var e = L(a), f = e.offset(), g = L.css(a, \"JSBNG__top\"), i = L.css(a, \"left\"), j = ((((((d === \"absolute\")) || ((d === \"fixed\")))) && ((L.inArray(\"auto\", [g,i,]) > -1)))), k = {\n                }, l = {\n                }, m, n;\n                ((j ? (l = e.position(), m = l.JSBNG__top, n = l.left) : (m = ((parseFloat(g) || 0)), n = ((parseFloat(i) || 0))))), ((L.isFunction(b) && (b = b.call(a, c, f)))), ((((b.JSBNG__top != null)) && (k.JSBNG__top = ((((b.JSBNG__top - f.JSBNG__top)) + m))))), ((((b.left != null)) && (k.left = ((((b.left - f.left)) + n))))), ((((\"using\" in b)) ? b.using.call(a, k) : e.css(k)));\n            }\n        }, L.fn.extend({\n            position: function() {\n                if (!this[0]) {\n                    return null;\n                }\n            ;\n            ;\n                var a = this[0], b = this.offsetParent(), c = this.offset(), d = ((Bc.test(b[0].nodeName) ? {\n                    JSBNG__top: 0,\n                    left: 0\n                } : b.offset()));\n                return c.JSBNG__top -= ((parseFloat(L.css(a, \"marginTop\")) || 0)), c.left -= ((parseFloat(L.css(a, \"marginLeft\")) || 0)), d.JSBNG__top += ((parseFloat(L.css(b[0], \"borderTopWidth\")) || 0)), d.left += ((parseFloat(L.css(b[0], \"borderLeftWidth\")) || 0)), {\n                    JSBNG__top: ((c.JSBNG__top - d.JSBNG__top)),\n                    left: ((c.left - d.left))\n                };\n            },\n            offsetParent: function() {\n                return this.map(function() {\n                    var a = ((this.offsetParent || I.body));\n                    while (((((a && !Bc.test(a.nodeName))) && ((L.css(a, \"position\") === \"static\"))))) {\n                        a = a.offsetParent;\n                    ;\n                    };\n                ;\n                    return a;\n                });\n            }\n        }), L.each([\"Left\",\"Top\",], function(a, c) {\n            var d = ((\"JSBNG__scroll\" + c));\n            L.fn[d] = function(c) {\n                var e, f;\n                return ((((c === b)) ? (e = this[0], ((e ? (f = H(e), ((f ? ((((\"JSBNG__pageXOffset\" in f)) ? f[((a ? \"JSBNG__pageYOffset\" : \"JSBNG__pageXOffset\"))] : ((((L.support.boxModel && f.JSBNG__document.documentElement[d])) || f.JSBNG__document.body[d])))) : e[d]))) : null))) : this.each(function() {\n                    f = H(this), ((f ? f.JSBNG__scrollTo(((a ? L(f).scrollLeft() : c)), ((a ? c : L(f).scrollTop()))) : this[d] = c));\n                })));\n            };\n        }), L.each([\"Height\",\"Width\",], function(a, c) {\n            var d = c.toLowerCase();\n            L.fn[((\"JSBNG__inner\" + c))] = function() {\n                var a = this[0];\n                return ((a ? ((a.style ? parseFloat(L.css(a, d, \"padding\")) : this[d]())) : null));\n            }, L.fn[((\"JSBNG__outer\" + c))] = function(a) {\n                var b = this[0];\n                return ((b ? ((b.style ? parseFloat(L.css(b, d, ((a ? \"margin\" : \"border\")))) : this[d]())) : null));\n            }, L.fn[d] = function(a) {\n                var e = this[0];\n                if (!e) {\n                    return ((((a == null)) ? null : this));\n                }\n            ;\n            ;\n                if (L.isFunction(a)) {\n                    return this.each(function(b) {\n                        var c = L(this);\n                        c[d](a.call(this, b, c[d]()));\n                    });\n                }\n            ;\n            ;\n                if (L.isWindow(e)) {\n                    var f = e.JSBNG__document.documentElement[((\"client\" + c))], g = e.JSBNG__document.body;\n                    return ((((((((e.JSBNG__document.compatMode === \"CSS1Compat\")) && f)) || ((g && g[((\"client\" + c))])))) || f));\n                }\n            ;\n            ;\n                if (((e.nodeType === 9))) {\n                    return Math.max(e.documentElement[((\"client\" + c))], e.body[((\"JSBNG__scroll\" + c))], e.documentElement[((\"JSBNG__scroll\" + c))], e.body[((\"offset\" + c))], e.documentElement[((\"offset\" + c))]);\n                }\n            ;\n            ;\n                if (((a === b))) {\n                    var i = L.css(e, d), j = parseFloat(i);\n                    return ((L.isNumeric(j) ? j : i));\n                }\n            ;\n            ;\n                return this.css(d, ((((typeof a == \"string\")) ? a : ((a + \"px\")))));\n            };\n        }), a.jQuery = a.$ = L, ((((((((typeof define == \"function\")) && define.amd)) && define.amd.jQuery)) && define(\"jquery\", [], function() {\n            return L;\n        })));\n    })(window), a();\n});\nprovide(\"libwrap/jquery\", function(a) {\n    using(((((window.twttr && window.twttr.isT1)) ? \"$lib/jquery-1.7.1.js\" : \"$lib/jquery-1.5.2.js\")), function() {\n        a(jQuery);\n    });\n});\nprovide(\"$lib/json2.js\", function(exports) {\n    ((this.JSON || (this.JSON = {\n    }))), function() {\n        function f(a) {\n            return ((((a < 10)) ? ((\"0\" + a)) : a));\n        };\n    ;\n        function quote(a) {\n            return escapable.lastIndex = 0, ((escapable.test(a) ? ((((\"\\\"\" + a.replace(escapable, function(a) {\n                var b = meta[a];\n                return ((((typeof b == \"string\")) ? b : ((\"\\\\u\" + ((\"0000\" + a.charCodeAt(0).toString(16))).slice(-4)))));\n            }))) + \"\\\"\")) : ((((\"\\\"\" + a)) + \"\\\"\"))));\n        };\n    ;\n        function str(a, b) {\n            var c, d, e, f, g = gap, i, j = b[a];\n            ((((((j && ((typeof j == \"object\")))) && ((typeof j.toJSON == \"function\")))) && (j = j.toJSON(a)))), ((((typeof rep == \"function\")) && (j = rep.call(b, a, j))));\n            switch (typeof j) {\n              case \"string\":\n                return quote(j);\n              case \"number\":\n                return ((isFinite(j) ? String(j) : \"null\"));\n              case \"boolean\":\n            \n              case \"null\":\n                return String(j);\n              case \"object\":\n                if (!j) {\n                    return \"null\";\n                }\n            ;\n            ;\n                gap += indent, i = [];\n                if (((Object.prototype.toString.apply(j) === \"[object Array]\"))) {\n                    f = j.length;\n                    for (c = 0; ((c < f)); c += 1) {\n                        i[c] = ((str(c, j) || \"null\"));\n                    ;\n                    };\n                ;\n                    return e = ((((i.length === 0)) ? \"[]\" : ((gap ? ((((((((((\"[\\u000a\" + gap)) + i.join(((\",\\u000a\" + gap))))) + \"\\u000a\")) + g)) + \"]\")) : ((((\"[\" + i.join(\",\"))) + \"]\")))))), gap = g, e;\n                }\n            ;\n            ;\n                if (((rep && ((typeof rep == \"object\"))))) {\n                    f = rep.length;\n                    for (c = 0; ((c < f)); c += 1) {\n                        d = rep[c], ((((typeof d == \"string\")) && (e = str(d, j), ((e && i.push(((((quote(d) + ((gap ? \": \" : \":\")))) + e))))))));\n                    ;\n                    };\n                ;\n                }\n                 else for (d in j) {\n                    ((Object.hasOwnProperty.call(j, d) && (e = str(d, j), ((e && i.push(((((quote(d) + ((gap ? \": \" : \":\")))) + e))))))));\n                ;\n                }\n            ;\n            ;\n                return e = ((((i.length === 0)) ? \"{}\" : ((gap ? ((((((((((\"{\\u000a\" + gap)) + i.join(((\",\\u000a\" + gap))))) + \"\\u000a\")) + g)) + \"}\")) : ((((\"{\" + i.join(\",\"))) + \"}\")))))), gap = g, e;\n            };\n        ;\n        };\n    ;\n        ((((typeof JSBNG__Date.prototype.toJSON != \"function\")) && (JSBNG__Date.prototype.toJSON = function(a) {\n            return ((isFinite(this.valueOf()) ? ((((((((((((((((((((((this.getUTCFullYear() + \"-\")) + f(((this.getUTCMonth() + 1))))) + \"-\")) + f(this.getUTCDate()))) + \"T\")) + f(this.getUTCHours()))) + \":\")) + f(this.getUTCMinutes()))) + \":\")) + f(this.getUTCSeconds()))) + \"Z\")) : null));\n        }, String.prototype.toJSON = Number.prototype.toJSON = Boolean.prototype.toJSON = function(a) {\n            return this.valueOf();\n        })));\n        var cx = /[\\u0000\\u00ad\\u0600-\\u0604\\u070f\\u17b4\\u17b5\\u200c-\\u200f\\u2028-\\u202f\\u2060-\\u206f\\ufeff\\ufff0-\\uffff]/g, escapable = /[\\\\\\\"\\x00-\\x1f\\x7f-\\x9f\\u00ad\\u0600-\\u0604\\u070f\\u17b4\\u17b5\\u200c-\\u200f\\u2028-\\u202f\\u2060-\\u206f\\ufeff\\ufff0-\\uffff]/g, gap, indent, meta = {\n            \"\\u0008\": \"\\\\b\",\n            \"\\u0009\": \"\\\\t\",\n            \"\\u000a\": \"\\\\n\",\n            \"\\u000c\": \"\\\\f\",\n            \"\\u000d\": \"\\\\r\",\n            \"\\\"\": \"\\\\\\\"\",\n            \"\\\\\": \"\\\\\\\\\"\n        }, rep;\n        ((((typeof JSON.stringify != \"function\")) && (JSON.stringify = function(a, b, c) {\n            var d;\n            gap = \"\", indent = \"\";\n            if (((typeof c == \"number\"))) {\n                for (d = 0; ((d < c)); d += 1) {\n                    indent += \" \";\n                ;\n                };\n            }\n             else {\n                ((((typeof c == \"string\")) && (indent = c)));\n            }\n        ;\n        ;\n            rep = b;\n            if (((((!b || ((typeof b == \"function\")))) || ((((typeof b == \"object\")) && ((typeof b.length == \"number\"))))))) {\n                return str(\"\", {\n                    \"\": a\n                });\n            }\n        ;\n        ;\n            throw new Error(\"JSON.stringify\");\n        }))), ((((typeof JSON.parse != \"function\")) && (JSON.parse = function(text, reviver) {\n            function walk(a, b) {\n                var c, d, e = a[b];\n                if (((e && ((typeof e == \"object\"))))) {\n                    for (c in e) {\n                        ((Object.hasOwnProperty.call(e, c) && (d = walk(e, c), ((((d !== undefined)) ? e[c] = d : delete e[c])))));\n                    ;\n                    };\n                }\n            ;\n            ;\n                return reviver.call(a, b, e);\n            };\n        ;\n            var j;\n            cx.lastIndex = 0, ((cx.test(text) && (text = text.replace(cx, function(a) {\n                return ((\"\\\\u\" + ((\"0000\" + a.charCodeAt(0).toString(16))).slice(-4)));\n            }))));\n            if (/^[\\],:{}\\s]*$/.test(text.replace(/\\\\(?:[\"\\\\\\/bfnrt]|u[0-9a-fA-F]{4})/g, \"@\").replace(/\"[^\"\\\\\\n\\r]*\"|true|false|null|-?\\d+(?:\\.\\d*)?(?:[eE][+\\-]?\\d+)?/g, \"]\").replace(/(?:^|:|,)(?:\\s*\\[)+/g, \"\"))) {\n                return j = eval(((((\"(\" + text)) + \")\"))), ((((typeof reviver == \"function\")) ? walk({\n                    \"\": j\n                }, \"\") : j));\n            }\n        ;\n        ;\n            throw new SyntaxError(\"JSON.parse\");\n        })));\n    }(), exports();\n});\nprovide(\"libwrap/json\", function(a) {\n    using(\"$lib/json2.js\", function() {\n        a(JSON);\n    });\n});\nprovide(\"$lib/hogan.js\", function(a) {\n    var b = {\n    }, c = !1;\n    ((((typeof window != \"undefined\")) && (c = ((window.$.browser.msie && ((parseInt(window.$.browser.version, 10) <= 7))))))), function(a, b) {\n        function c(a, b) {\n            function c() {\n            \n            };\n        ;\n            function d() {\n            \n            };\n        ;\n            c.prototype = a, d.prototype = a.subs;\n            var e = new c;\n            e.subs = new d;\n            for (var f in b) {\n                e.subs[f] = b[f];\n            ;\n            };\n        ;\n            return e;\n        };\n    ;\n        function d(a) {\n            return String(((((((a === null)) || ((a === undefined)))) ? \"\" : a)));\n        };\n    ;\n        function e(a) {\n            return a = d(a), ((l.test(a) ? a.replace(f, \"&amp;\").replace(g, \"&lt;\").replace(i, \"&gt;\").replace(j, \"&#39;\").replace(k, \"&quot;\") : a));\n        };\n    ;\n        a.Template = function(a, c, d, e) {\n            a = ((a || {\n            })), this.r = ((a.main || this.r)), this.c = d, this.options = e, this.text = ((c || \"\")), this.buf = ((b ? [] : \"\")), this.partials = ((a.partials || {\n            })), this.subs = ((a.subs || {\n            }));\n        }, a.Template.prototype = {\n            r: function(a, b, c) {\n                return \"\";\n            },\n            v: e,\n            t: d,\n            render: function(a, b, c) {\n                return this.ri([a,], ((b || {\n                })), c);\n            },\n            ri: function(a, b, c) {\n                return this.r(a, b, c);\n            },\n            ep: function(a, b) {\n                var d = this.partials[a], e = b[d.JSBNG__name];\n                if (((d.instance && ((d.base == e))))) {\n                    return d.instance;\n                }\n            ;\n            ;\n                if (((typeof e == \"string\"))) {\n                    if (!this.c) {\n                        throw new Error(\"No compiler available.\");\n                    }\n                ;\n                ;\n                    e = this.c.compile(e, this.options);\n                }\n            ;\n            ;\n                return ((e ? (this.partials[a].base = e, ((d.subs && (e = c(e, d.subs)))), this.partials[a].instance = e, e) : null));\n            },\n            rp: function(a, b, c, d) {\n                var e = this.ep(a, c);\n                return ((e ? e.ri(b, c, d) : \"\"));\n            },\n            rs: function(a, b, c) {\n                var d = a[((a.length - 1))];\n                if (!m(d)) {\n                    c(a, b, this);\n                    return;\n                }\n            ;\n            ;\n                for (var e = 0; ((e < d.length)); e++) {\n                    a.push(d[e]), c(a, b, this), a.pop();\n                ;\n                };\n            ;\n            },\n            s: function(a, b, c, d, e, f, g) {\n                var i;\n                return ((((m(a) && ((a.length === 0)))) ? !1 : (((((typeof a == \"function\")) && (a = this.ms(a, b, c, d, e, f, g)))), i = ((((a === \"\")) || !!a)), ((((((!d && i)) && b)) && b.push(((((typeof a == \"object\")) ? a : b[((b.length - 1))]))))), i)));\n            },\n            d: function(a, b, c, d) {\n                var e = a.split(\".\"), f = this.f(e[0], b, c, d), g = null;\n                if (((((a === \".\")) && m(b[((b.length - 2))])))) {\n                    return b[((b.length - 1))];\n                }\n            ;\n            ;\n                for (var i = 1; ((i < e.length)); i++) {\n                    ((((((f && ((typeof f == \"object\")))) && ((f[e[i]] != null)))) ? (g = f, f = f[e[i]]) : f = \"\"));\n                ;\n                };\n            ;\n                return ((((d && !f)) ? !1 : (((((!d && ((typeof f == \"function\")))) && (b.push(g), f = this.mv(f, b, c), b.pop()))), f)));\n            },\n            f: function(a, b, c, d) {\n                var e = !1, f = null, g = !1;\n                for (var i = ((b.length - 1)); ((i >= 0)); i--) {\n                    f = b[i];\n                    if (((((f && ((typeof f == \"object\")))) && ((f[a] != null))))) {\n                        e = f[a], g = !0;\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n                return ((g ? (((((!d && ((typeof e == \"function\")))) && (e = this.mv(e, b, c)))), e) : ((d ? !1 : \"\"))));\n            },\n            ls: function(a, b, c, e, f) {\n                var g = this.options.delimiters;\n                return this.options.delimiters = f, this.b(this.ct(d(a.call(b, e)), b, c)), this.options.delimiters = g, !1;\n            },\n            ct: function(a, b, c) {\n                if (this.options.disableLambda) {\n                    throw new Error(\"Lambda features disabled.\");\n                }\n            ;\n            ;\n                return this.c.compile(a, this.options).render(b, c);\n            },\n            b: ((b ? function(a) {\n                this.buf.push(a);\n            } : function(a) {\n                this.buf += a;\n            })),\n            fl: ((b ? function() {\n                var a = this.buf.join(\"\");\n                return this.buf = [], a;\n            } : function() {\n                var a = this.buf;\n                return this.buf = \"\", a;\n            })),\n            ms: function(a, b, c, d, e, f, g) {\n                var i = b[((b.length - 1))], j = a.call(i);\n                return ((((typeof j == \"function\")) ? ((d ? !0 : this.ls(j, i, c, this.text.substring(e, f), g))) : j));\n            },\n            mv: function(a, b, c) {\n                var e = b[((b.length - 1))], f = a.call(e);\n                return ((((typeof f == \"function\")) ? this.ct(d(f.call(e)), e, c) : f));\n            },\n            sub: function(a, b, c) {\n                var d = this.subs[a];\n                ((d && d(b, c, this)));\n            }\n        };\n        var f = /&/g, g = /</g, i = />/g, j = /\\'/g, k = /\\\"/g, l = /[&<>\\\"\\']/, m = ((Array.isArray || function(a) {\n            return ((Object.prototype.toString.call(a) === \"[object Array]\"));\n        }));\n    }(b, c), function(a) {\n        function b(a) {\n            ((((a.n.substr(((a.n.length - 1))) === \"}\")) && (a.n = a.n.substring(0, ((a.n.length - 1))))));\n        };\n    ;\n        function c(a) {\n            return ((a.trim ? a.trim() : a.replace(/^\\s*|\\s*$/g, \"\")));\n        };\n    ;\n        function d(a, b, c) {\n            if (((b.charAt(c) != a.charAt(0)))) {\n                return !1;\n            }\n        ;\n        ;\n            for (var d = 1, e = a.length; ((d < e)); d++) {\n                if (((b.charAt(((c + d))) != a.charAt(d)))) {\n                    return !1;\n                }\n            ;\n            ;\n            };\n        ;\n            return !0;\n        };\n    ;\n        function e(b, c, d, i) {\n            var j = [], k = null, l = null, m = null;\n            l = d[((d.length - 1))];\n            while (((b.length > 0))) {\n                m = b.shift();\n                if (!((((!l || ((l.tag != \"\\u003C\")))) || ((m.tag in u))))) {\n                    throw new Error(\"Illegal content in \\u003C super tag.\");\n                }\n            ;\n            ;\n                if (((((a.tags[m.tag] <= a.tags.$)) || f(m, i)))) d.push(m), m.nodes = e(b, m.tag, d, i);\n                 else {\n                    if (((m.tag == \"/\"))) {\n                        if (((d.length === 0))) {\n                            throw new Error(((\"Closing tag without opener: /\" + m.n)));\n                        }\n                    ;\n                    ;\n                        k = d.pop();\n                        if (((((m.n != k.n)) && !g(m.n, k.n, i)))) {\n                            throw new Error(((((((\"Nesting error: \" + k.n)) + \" vs. \")) + m.n)));\n                        }\n                    ;\n                    ;\n                        return k.end = m.i, j;\n                    }\n                ;\n                ;\n                    ((((m.tag == \"\\u000a\")) && (m.last = ((((b.length == 0)) || ((b[0].tag == \"\\u000a\")))))));\n                }\n            ;\n            ;\n                j.push(m);\n            };\n        ;\n            if (((d.length > 0))) {\n                throw new Error(((\"missing closing tag: \" + d.pop().n)));\n            }\n        ;\n        ;\n            return j;\n        };\n    ;\n        function f(a, b) {\n            for (var c = 0, d = b.length; ((c < d)); c++) {\n                if (((b[c].o == a.n))) {\n                    return a.tag = \"#\", !0;\n                }\n            ;\n            ;\n            };\n        ;\n        };\n    ;\n        function g(a, b, c) {\n            for (var d = 0, e = c.length; ((d < e)); d++) {\n                if (((((c[d].c == a)) && ((c[d].o == b))))) {\n                    return !0;\n                }\n            ;\n            ;\n            };\n        ;\n        };\n    ;\n        function i(a) {\n            var b = [];\n            for (var c in a) {\n                b.push(((((((((\"\\\"\" + k(c))) + \"\\\": function(c,p,t) {\")) + a[c])) + \"}\")));\n            ;\n            };\n        ;\n            return ((((\"{ \" + b.join(\",\"))) + \" }\"));\n        };\n    ;\n        function j(a, b, c) {\n            for (var d in a) {\n                b[d] = new Function(\"c\", \"p\", \"t\", a[d]);\n            ;\n            };\n        ;\n        };\n    ;\n        function k(a) {\n            return a.replace(t, \"\\\\\\\\\").replace(q, \"\\\\\\\"\").replace(r, \"\\\\n\").replace(s, \"\\\\r\");\n        };\n    ;\n        function l(a) {\n            return ((~a.indexOf(\".\") ? \"d\" : \"f\"));\n        };\n    ;\n        function m(a, b) {\n            var c = ((a.n + v++));\n            return b.partials[c] = {\n                JSBNG__name: a.n\n            }, b.code += ((((((((\"t.b(t.rp(\\\"\" + k(c))) + \"\\\",c,p,\\\"\")) + ((a.indent || \"\")))) + \"\\\"));\")), c;\n        };\n    ;\n        function n(a, b) {\n            b.code += ((((((((\"t.b(t.t(t.\" + l(a.n))) + \"(\\\"\")) + k(a.n))) + \"\\\",c,p,0)));\"));\n        };\n    ;\n        function o(a) {\n            return ((((\"t.b(\" + a)) + \");\"));\n        };\n    ;\n        var p = /\\S/, q = /\\\"/g, r = /\\n/g, s = /\\r/g, t = /\\\\/g;\n        a.tags = {\n            \"#\": 1,\n            \"^\": 2,\n            \"\\u003C\": 3,\n            $: 4,\n            \"/\": 5,\n            \"!\": 6,\n            \"\\u003E\": 7,\n            \"=\": 8,\n            _v: 9,\n            \"{\": 10,\n            \"&\": 11,\n            _t: 12\n        }, a.scan = function(e, f) {\n            function g() {\n                ((((t.length > 0)) && (u.push({\n                    tag: \"_t\",\n                    text: new String(t)\n                }), t = \"\")));\n            };\n        ;\n            function i() {\n                var b = !0;\n                for (var c = x; ((c < u.length)); c++) {\n                    b = ((((a.tags[u[c].tag] < a.tags._v)) || ((((u[c].tag == \"_t\")) && ((u[c].text.match(p) === null))))));\n                    if (!b) {\n                        return !1;\n                    }\n                ;\n                ;\n                };\n            ;\n                return b;\n            };\n        ;\n            function j(a, b) {\n                g();\n                if (((a && i()))) {\n                    for (var c = x, d; ((c < u.length)); c++) {\n                        ((u[c].text && ((((((d = u[((c + 1))]) && ((d.tag == \"\\u003E\")))) && (d.indent = u[c].text.toString()))), u.splice(c, 1))));\n                    ;\n                    };\n                }\n                 else {\n                    ((b || u.push({\n                        tag: \"\\u000a\"\n                    })));\n                }\n            ;\n            ;\n                v = !1, x = u.length;\n            };\n        ;\n            function k(a, b) {\n                var d = ((\"=\" + z)), e = a.indexOf(d, b), f = c(a.substring(((a.indexOf(\"=\", b) + 1)), e)).split(\" \");\n                return y = f[0], z = f[1], ((((e + d.length)) - 1));\n            };\n        ;\n            var l = e.length, m = 0, n = 1, o = 2, q = m, r = null, s = null, t = \"\", u = [], v = !1, w = 0, x = 0, y = \"{{\", z = \"}}\";\n            ((f && (f = f.split(\" \"), y = f[0], z = f[1])));\n            for (w = 0; ((w < l)); w++) {\n                ((((q == m)) ? ((d(y, e, w) ? (--w, g(), q = n) : ((((e.charAt(w) == \"\\u000a\")) ? j(v) : t += e.charAt(w))))) : ((((q == n)) ? (w += ((y.length - 1)), s = a.tags[e.charAt(((w + 1)))], r = ((s ? e.charAt(((w + 1))) : \"_v\")), ((((r == \"=\")) ? (w = k(e, w), q = m) : (((s && w++)), q = o))), v = w) : ((d(z, e, w) ? (u.push({\n                    tag: r,\n                    n: c(t),\n                    otag: y,\n                    ctag: z,\n                    i: ((((r == \"/\")) ? ((v - z.length)) : ((w + y.length))))\n                }), t = \"\", w += ((z.length - 1)), q = m, ((((r == \"{\")) && ((((z == \"}}\")) ? w++ : b(u[((u.length - 1))])))))) : t += e.charAt(w)))))));\n            ;\n            };\n        ;\n            return j(v, !0), u;\n        };\n        var u = {\n            _t: !0,\n            \"\\u000a\": !0,\n            $: !0,\n            \"/\": !0\n        };\n        a.stringify = function(b, c, d) {\n            var e = [], f = ((((\"{main: function (c,p,i) { \" + a.wrapMain(b.code))) + \" }, partials: {\"));\n            for (var g in b.partials) {\n                e.push(((((((((\"\\\"\" + k(g))) + \"\\\": {name:\\\"\")) + k(b.partials[g].JSBNG__name))) + \"\\\"}\")));\n            ;\n            };\n        ;\n            return f += ((((((e.join(\",\") + \"}, subs: \")) + i(b.subs))) + \" }\")), f;\n        };\n        var v = 0;\n        a.generate = function(b, c, d) {\n            v = 0;\n            var e = {\n                code: \"\",\n                subs: {\n                },\n                partials: {\n                }\n            };\n            return a.walk(b, e), ((d.asString ? this.stringify(e, c, d) : this.makeTemplate(e, c, d)));\n        }, a.wrapMain = function(a) {\n            return ((((\"var t=this;t.b(i=i||\\\"\\\");\" + a)) + \"return t.fl();\"));\n        }, a.template = a.Template, a.makeTemplate = function(a, b, c) {\n            var d = {\n                main: new Function(\"c\", \"p\", \"i\", this.wrapMain(a.code)),\n                subs: {\n                },\n                partials: {\n                }\n            };\n            d.partials = a.partials;\n            for (var e in d.partials) {\n                j(d.partials[e].subs, d.partials[e].subs);\n            ;\n            };\n        ;\n            return j(a.subs, d.subs), new this.template(d, b, this, c);\n        }, a.codegen = {\n            \"#\": function(b, c) {\n                c.code += ((((((((((((((((((((((((((((((\"if(t.s(t.\" + l(b.n))) + \"(\\\"\")) + k(b.n))) + \"\\\",c,p,1),\")) + \"c,p,0,\")) + b.i)) + \",\")) + b.end)) + \",\\\"\")) + b.otag)) + \" \")) + b.ctag)) + \"\\\")){\")) + \"t.rs(c,p,\")) + \"function(c,p,t){\")), a.walk(b.nodes, c), c.code += \"});c.pop();}\";\n            },\n            \"^\": function(b, c) {\n                c.code += ((((((((\"if(!t.s(t.\" + l(b.n))) + \"(\\\"\")) + k(b.n))) + \"\\\",c,p,1),c,p,1,0,0,\\\"\\\")){\")), a.walk(b.nodes, c), c.code += \"};\";\n            },\n            \"\\u003E\": m,\n            \"\\u003C\": function(b, c) {\n                var d = {\n                    partials: c.partials,\n                    code: \"\",\n                    subs: {\n                    },\n                    inPartial: !0\n                };\n                a.walk(b.nodes, d), c.partials[m(b, c)].subs = d.subs;\n            },\n            $: function(b, c) {\n                var d = {\n                    subs: {\n                    },\n                    code: \"\",\n                    partials: c.partials\n                };\n                a.walk(b.nodes, d), c.subs[b.n] = d.code, ((c.inPartial || (c.code += ((((\"t.sub(\\\"\" + k(b.n))) + \"\\\",c,p);\")))));\n            },\n            \"\\u000a\": function(a, b) {\n                b.code += o(((\"\\\"\\\\n\\\"\" + ((a.last ? \"\" : \" + i\")))));\n            },\n            _v: function(a, b) {\n                b.code += ((((((((\"t.b(t.v(t.\" + l(a.n))) + \"(\\\"\")) + k(a.n))) + \"\\\",c,p,0)));\"));\n            },\n            _t: function(a, b) {\n                b.code += o(((((\"\\\"\" + k(a.text))) + \"\\\"\")));\n            },\n            \"{\": n,\n            \"&\": n\n        }, a.walk = function(b, c) {\n            var d;\n            for (var e = 0, f = b.length; ((e < f)); e++) {\n                d = a.codegen[b[e].tag], ((d && d(b[e], c)));\n            ;\n            };\n        ;\n            return c;\n        }, a.parse = function(a, b, c) {\n            return c = ((c || {\n            })), e(a, \"\", [], ((c.sectionTags || [])));\n        }, a.cache = {\n        }, a.cacheKey = function(a, b) {\n            return [a,!!b.asString,!!b.disableLambda,].join(\"||\");\n        }, a.compile = function(b, c) {\n            c = ((c || {\n            }));\n            var d = a.cacheKey(b, c), e = this.cache[d];\n            return ((e ? e : (e = this.generate(this.parse(this.scan(b, c.delimiters), b, c), b, c), this.cache[d] = e)));\n        };\n    }(b);\n    var d = function(a) {\n        function b(b, c, d, e) {\n            var f = c, g = this.partials[b], i = this.f(g.JSBNG__name, c, d, 0);\n            return ((i && (f = f.concat(i)))), a.Template.prototype.rp.call(this, b, f, d, e);\n        };\n    ;\n        function c(b, c, d, e) {\n            var f = c[((c.length - 1))], g = a.Template.prototype.f.call(this, b, c, d, e);\n            if (((g === !1))) {\n                var i = ((f.lookup_missing_property ? f : c[0]));\n                ((i.lookup_missing_property && (g = i.lookup_missing_property(b, f), ((((!e && ((typeof g == \"function\")))) && (g = this.lv(g, c, d)))))));\n            }\n        ;\n        ;\n            return g;\n        };\n    ;\n        function d(b, c, d) {\n            var f = a.parse.call(this, b, c, d), g = \"\";\n            for (var i = 0; ((i < f.length)); i++) {\n                if (((((f[i].tag == \"_v\")) && ((f[i].n.indexOf(\"%TRANSLATION-HINT\") == 0))))) {\n                    var j = f.splice(i, 1)[0];\n                    i--, g = j.n.substring(((j.n.indexOf(\"mode=\") + \"mode=\".length)));\n                }\n            ;\n            ;\n            };\n        ;\n            return e(f, g, c, d);\n        };\n    ;\n        function e(b, c, d, i) {\n            var j = [];\n            for (var k = 0; ((k < b.length)); k++) {\n                if (((((b[k].tag == \"#\")) && ((b[k].n == \"_i\"))))) {\n                    var l = g(d.substring(b[k].i, b[k].end), c);\n                    ((((l.tag == \"raw\")) ? j.push(l) : Array.prototype.push.apply(j, a.parse(a.scan(l, i.delimiters), d, i))));\n                }\n                 else ((((((b[k].tag == \"#\")) || ((b[k].tag == \"^\")))) ? (b[k].nodes = e(b[k].nodes, c, d, i), j.push(b[k])) : j.push(b[k])));\n            ;\n            ;\n            };\n        ;\n            return f(j);\n        };\n    ;\n        function f(a) {\n            if (((a.length == 0))) {\n                return a;\n            }\n        ;\n        ;\n            var b = [a[0],];\n            for (var c = 1; ((c < a.length)); c++) {\n                ((((((b[((b.length - 1))].tag != \"_t\")) || ((((a[c].tag != \"\\u000a\")) && ((a[c].tag != \"_t\")))))) ? b.push(a[c]) : b[((b.length - 1))].text += ((a[c].text || \"\\u000a\"))));\n            ;\n            };\n        ;\n            return b;\n        };\n    ;\n        function g(a, b) {\n            var c = {\n                text: a,\n                mode: b\n            }, d = ((((typeof _ != \"undefined\")) ? _(c) : c.text));\n            return ((d ? d : a));\n        };\n    ;\n        var i = function(d, e, f, g) {\n            this.rp = b, this.f = c, a.Template.call(this, d, e, f, g);\n        };\n        i.prototype = a.Template.prototype;\n        var j, k = function() {\n        \n        };\n        return k.prototype = a, j = new k, j.template = i, j.parse = d, {\n            twitterHogan: j,\n            TwitterTemplate: i,\n            to_html: function(a, b, c, d) {\n                ((((a instanceof i)) || (a = j.compile(a, {\n                    sectionTags: [{\n                        o: \"_i\",\n                        c: \"i\"\n                    },]\n                }))));\n                var e = a.render(b, c);\n                if (!d) {\n                    return e;\n                }\n            ;\n            ;\n                d(e);\n            }\n        };\n    }(b);\n    ((((typeof window != \"undefined\")) && (window.Mustache = d))), ((((typeof module != \"undefined\")) && (module.exports = {\n        Mustache: d,\n        Hogan: b\n    }))), a();\n});\nprovide(\"libwrap/hogan\", function(a) {\n    using(\"$lib/hogan.js\", function() {\n        a(Mustache);\n    });\n});\nprovide(\"run/base\", function(a) {\n    using(\"libwrap/jquery\").as(function(b, c) {\n        function d(a, b) {\n            var c = window, d = a.split(\".\");\n            for (var e = 0, f = d.length; ((e < f)); e++) {\n                var g = d[e];\n                ((((typeof c[g] == \"undefined\")) && (c[g] = {\n                }))), c = c[g];\n            };\n        ;\n            if (b) {\n                for (var i in b) {\n                    c[i] = b[i];\n                ;\n                };\n            }\n        ;\n        ;\n            return c;\n        };\n    ;\n        window.h = function(a) {\n            var b = $(\"\\u003Cdiv/\\u003E\"), c = function(a) {\n                return ((a ? b.text(a).html().replace(/\\\"/gi, \"&quot;\") : a));\n            };\n            return h = function(a) {\n                return c(a);\n            }, c(a);\n        }, ((((c.browser.msie && ((c.browser.version === \"7.0\")))) && (c.cleanData = function(a) {\n            var b, d, e = c.cache, f = c.JSBNG__event.special, g = c.support.deleteExpando;\n            for (var i = 0, j; (((j = a[i]) != null)); i++) {\n                if (((j.nodeName && c.noData[j.nodeName.toLowerCase()]))) {\n                    continue;\n                }\n            ;\n            ;\n                d = j[c.expando];\n                if (d) {\n                    b = e[d];\n                    if (((b && b.events))) {\n                        for (var k in b.events) {\n                            ((f[k] ? c.JSBNG__event.remove(j, k) : c.removeEvent(j, k, b.handle)));\n                        ;\n                        };\n                    ;\n                        ((b.handle && (b.handle.elem = null)));\n                    }\n                ;\n                ;\n                    ((g ? delete j[c.expando] : ((j.removeAttribute && j.removeAttribute(c.expando.toLowerCase()))))), delete e[d];\n                }\n            ;\n            ;\n            };\n        ;\n        })));\n        var e = /\\[native code\\]/;\n        d(\"twttr\", {\n            provide: d,\n            augmentObject: function(a, b) {\n                for (var c in b) {\n                    a[c] = b[c];\n                ;\n                };\n            ;\n                return a;\n            },\n            aug: function() {\n                return twttr.augmentObject.apply({\n                }, arguments);\n            },\n            augmentString: function(a, b) {\n                var c = window, d = a.split(\".\");\n                for (var e = 0, f = d.length; ((e < f)); ++e) {\n                    c = c[d[e]] = ((c[d[e]] || ((((typeof d[((e + 1))] != \"undefined\")) ? {\n                    } : b))));\n                ;\n                };\n            ;\n                return c;\n            },\n            each: function(a, b, c) {\n                for (var d = 0, e = a.length; ((d < e)); ++d) {\n                    ((c ? b.call(c, a[d], d, a) : b(a[d], d, a)));\n                ;\n                };\n            ;\n            },\n            localize: function(a, b) {\n                return ((((typeof a[twttr.pageLocale] == \"undefined\")) ? b : a[twttr.pageLocale]));\n            },\n            filter: function(a, b, c) {\n                var d;\n                if (twttr.is.array(a)) {\n                    var e = [];\n                    for (var f = 0, g = a.length; ((f < g)); ++f) {\n                        d = ((c ? b.call(c, a[f], f, a) : b(a[f], f, a)));\n                        if (!d) {\n                            continue;\n                        }\n                    ;\n                    ;\n                        e.push(a[f]);\n                    };\n                ;\n                    return e;\n                }\n            ;\n            ;\n                if (twttr.is.object(a)) {\n                    var h = {\n                    };\n                    for (var i in a) {\n                        d = ((c ? b.call(c, i, a[i], a) : b(i, a[i], a)));\n                        if (!d) {\n                            continue;\n                        }\n                    ;\n                    ;\n                        h[i] = a[i];\n                    };\n                ;\n                    return h;\n                }\n            ;\n            ;\n            },\n            map: function(a, b, c, d) {\n                var e = ((twttr.is.array(a) ? [] : {\n                }));\n                ((((d && ((d == \"array\")))) && (e = [])));\n                for (var f in a) {\n                    e[f] = ((c ? b.call(c, a[f], f, a) : b(a[f], f, a)));\n                ;\n                };\n            ;\n                return e;\n            },\n            every: function(a, b, c) {\n                var d;\n                for (var e = 0, f = a.length; ((e < f)); ++e) {\n                    d = ((c ? b.call(c, a[e], e, a) : b(a[e], e, a)));\n                    if (!d) {\n                        return !1;\n                    }\n                ;\n                ;\n                };\n            ;\n                return !0;\n            },\n            inject: function() {\n                return this.reduce.apply(this, arguments);\n            },\n            reduce: function(a, b, c) {\n                return $.each(a, function(a, d) {\n                    b = c(b, a, d);\n                }), b;\n            },\n            exists: function(a, b) {\n                return ((((!twttr.is.object(a) || !twttr.is.def(b))) ? null : twttr.is.def(twttr.at(b, a))));\n            },\n            merge: function() {\n                var a = c.makeArray(arguments);\n                return ((((a.length === 1)) ? a[0] : (((twttr.is.bool(a[((a.length - 1))]) && a.unshift(a.pop()))), c.extend.apply(null, a))));\n            },\n            extend: function(a, b) {\n                function c() {\n                \n                };\n            ;\n                c.prototype = b.prototype, a.prototype = new c, a.prototype.constructor = a, a.uber = b.prototype, ((((b.prototype.constructor == Object.prototype.constructor)) && (b.prototype.constructor = b)));\n            },\n            method: function(a, b) {\n                return this.prototype[a] = b, this;\n            },\n            methods: function(a) {\n                this.prototype._namespace = this._namespace;\n                for (var b in a) {\n                    this.prototype[b] = a[b], ((twttr.is.fn(a[b]) && (this.prototype[b]._methodName = b)));\n                ;\n                };\n            ;\n                return this;\n            },\n            statics: function(a) {\n                return twttr.aug(this, a);\n            },\n            at: function(a, b) {\n                var c = a.split(\".\"), d = ((b || window));\n                while (((c.length > 0))) {\n                    d = d[c.shift()];\n                    if (((typeof d == \"undefined\"))) {\n                        return undefined;\n                    }\n                ;\n                ;\n                };\n            ;\n                return d;\n            },\n            klass: function(a, b) {\n                ((((typeof a != \"string\")) && (b = a, a = {\n                }[\"this evaluates to undefined\"])));\n                var c = ((b || function() {\n                    ((f.uberclass && f.uberclass.apply(this, arguments)));\n                })), d = [], f = function() {\n                    if (!((((!twttr.development && !twttr.isTestEnv)) || ((((this != window)) && !e.test(this.constructor)))))) {\n                        throw new Error(((((a ? a : \"(unnamed)\")) + \" constructor must be called with the 'new' keyword\")));\n                    }\n                ;\n                ;\n                    var b = this;\n                    c.apply(this, arguments), twttr.each(d, function(a) {\n                        new a(f, b);\n                    });\n                };\n                if (a) {\n                    twttr.augmentString(a, f);\n                    var g = a.split(\".\").pop();\n                    f.JSBNG__name = g.toLowerCase(), f._namespace = a, f._name = g;\n                }\n            ;\n            ;\n                return f.lazyLoad = function(a) {\n                    return d.push(a), f;\n                }, f.method = twttr.method, f.methods = twttr.methods, f.statics = twttr.statics, f._isKlass = !0, c._methodName = \"constructor\", f.subclassOf = function(a) {\n                    if (!a._isKlass) {\n                        throw \"You should not be subclassing something that is not a twttr.klass\";\n                    }\n                ;\n                ;\n                    twttr.extend(f, a);\n                    for (var b in a) {\n                        ((f.hasOwnProperty(b) || (f[b] = a[b])));\n                    ;\n                    };\n                ;\n                    return f.uberclass = a, f;\n                }, f.mixin = function() {\n                    for (var b = 0; ((b < arguments.length)); b++) {\n                        var c = arguments[b];\n                        ((twttr.is.def(c) ? c.call(f, f) : JSBNG__console.warn(((\"you have an undefined mixin coming from \" + a)))));\n                    };\n                ;\n                    return f;\n                }, f;\n            },\n            magic: function(a, b) {\n                return ((twttr.is.string(a) ? twttr.augmentString(a, b) : twttr.aug(a, b)));\n            },\n            bind: function(a, b, c) {\n                return function() {\n                    return b.apply(a, ((c ? c.concat(Array.prototype.slice.apply(arguments)) : arguments)));\n                };\n            }\n        }), twttr.deprecateAccess = function(a, b, c) {\n            c = ((c || {\n            }));\n            if (((((((((((!twttr.deprecateAccess.isActive || ((typeof JSBNG__console == \"undefined\")))) || ((typeof a.__defineGetter__ != \"function\")))) || ((typeof a.__defineSetter__ != \"function\")))) || ((typeof a.__lookupGetter__ != \"function\")))) || ((typeof a.__lookupSetter__ != \"function\"))))) {\n                return;\n            }\n        ;\n        ;\n            if (((a.__lookupGetter__(b) || a.__lookupSetter__(b)))) {\n                return;\n            }\n        ;\n        ;\n            ((((((!!c.now != !!c.daysRemaining)) && JSBNG__console)) && JSBNG__console.error(((((\"To deprecate \" + b)) + \", you must provide both a now property and a daysRemaining property, or neither\")))));\n            var d = a[b], e, g = new JSBNG__Date(((c.now + ((((((((c.daysRemaining * 1000)) * 60)) * 60)) * 24))))), i = ((g < new JSBNG__Date)), j = function() {\n                if (((e || f))) {\n                    return;\n                }\n            ;\n            ;\n                e = !0;\n                var d = [((((\"The property \\\"\" + b)) + \"\\\" on \")),a,\"is deprecated.\",];\n                ((c.replacement && d.push(((((\"  Please use \" + c.replacement)) + \" instead.\"))))), ((((c.daysRemaining && c.now)) && d.push(((\"\\u000aTHIS CODE WILL SELF-DESTRUCT ON \" + g.toString()))))), ((c.message && d.push(((\"\\u000aMessage: \" + message))))), d.push(\"\\u000aPlease remove the usage at \", {\n                    stack: (new Error).stack\n                }), JSBNG__console[((i ? \"error\" : \"warn\"))].apply(JSBNG__console, d);\n            };\n            a.__defineGetter__(b, function() {\n                return j(), d;\n            }), a.__defineSetter__(b, function(a) {\n                j(), d = a;\n            });\n        }, twttr.deprecateAccess.activate = function(a) {\n            ((((typeof a == \"undefined\")) && (a = !0))), twttr.deprecateAccess.isActive = a;\n        };\n        var f = !1;\n        twttr.unwarnedAccess = function(a, b) {\n            f = !0;\n            var c = a[b];\n            return f = !1, c;\n        }, twttr.klass.mixin = function(a, b) {\n            return twttr.magic(a, b);\n        }, d(\"twttr.is\", {\n            element: function(a) {\n                return ((!!a && !!((this.def(a.nodeType) || ((a.JSBNG__document && a.JSBNG__document.nodeType))))));\n            },\n            bool: function(a) {\n                return ((typeof a == \"boolean\"));\n            },\n            nil: function(a) {\n                return ((a === null));\n            },\n            def: function(a) {\n                return ((typeof a != \"undefined\"));\n            },\n            number: function(a) {\n                return ((((typeof a == \"number\")) && isFinite(a)));\n            },\n            fn: function(a) {\n                return ((typeof a == \"function\"));\n            },\n            array: function(a) {\n                return ((a ? ((this.number(a.length) && this.fn(a.splice))) : !1));\n            },\n            string: function(a) {\n                return ((typeof a == \"string\"));\n            },\n            blank: function(a) {\n                return ((a === \"\"));\n            },\n            falsy: function(a) {\n                return !a;\n            },\n            object: function(a) {\n                return !((!a || ((((typeof a != \"object\")) && !this.fn(a)))));\n            },\n            regex: function(a) {\n                return ((Object.prototype.toString.apply(a) === \"[object RegExp]\"));\n            },\n            inArray: function(a, b) {\n                var c = b.length, d = 0;\n                for (d = 0; ((d < c)); d++) {\n                    if (((b[d] === a))) {\n                        return !0;\n                    }\n                ;\n                ;\n                };\n            ;\n                return !1;\n            }\n        }), twttr.provide(\"twttr.assets\", {\n            getPathFromAbsoluteURL: function(a, b) {\n                if (!twttr.cdnBase) {\n                    return a;\n                }\n            ;\n            ;\n                if (((a.indexOf(\"/unversioned_dev_assets/\") === 0))) {\n                    return a;\n                }\n            ;\n            ;\n                var c;\n                if (a.match(/^https?:/)) {\n                    function d(a) {\n                        var b = a.split(\"://\")[1];\n                        return b.split(\"/\").slice(1).join(\"/\");\n                    };\n                ;\n                    c = d(a);\n                }\n                 else JSBNG__console.warn(\"A relative path (%o) was passed to getPathFromAbsoluteURL, which expects an absolute URL; you should use twttr.assets.path instead\", a), c = a;\n            ;\n            ;\n                return this.path(c, b);\n            },\n            path: function(a, b) {\n                if (!twttr.cdnBase) {\n                    return a;\n                }\n            ;\n            ;\n                if (a.match(/^https?:/)) {\n                    return ((((((typeof JSBNG__console != \"undefined\")) && JSBNG__console.warn)) && JSBNG__console.warn(\"A fully qualified URL (%o) was passed to twttr.assets.path, which expects a relative path; returning it unchanged\", a))), a;\n                }\n            ;\n            ;\n                b = ((b || {\n                }));\n                var c = ((((typeof b.isSSL == \"undefined\")) ? ((twttr.proto == \"https\")) : b.isSSL)), d = ((((typeof b.isVersioned == \"undefined\")) ? !0 : b.isVersioned)), e, f, g;\n                return ((d ? e = twttr.cdnBase.versioned : e = twttr.cdnBase.unversioned)), ((c ? (f = e.ssl, ((((e.ssl_akamai && twttr.decider.isAvailable(\"ssl_cdn_akamai_fraction\"))) && (f = e.ssl_akamai)))) : f = e.http)), ((((a[0] !== \"/\")) && (a = ((\"/\" + a))))), g = f[twttr.assets.stringToBucket(a, f.length)], ((g + a));\n            },\n            stringToBucket: function(a, b) {\n                if (!b) {\n                    throw new Error(\"Missing numberOfBuckets argument\");\n                }\n            ;\n            ;\n                var c = a.split(\"/\"), d = c[((c.length - 1))], e = 0;\n                for (var f = 0; ((f < d.length)); f++) {\n                    e += d.charCodeAt(f);\n                ;\n                };\n            ;\n                return ((e % b));\n            }\n        }), a(twttr);\n    });\n});\nprovide(\"_\", function(a) {\n    using(\"util\").as(function(b) {\n        var c = ((b.util.params().lang == \"en-xx\")), _ = window._ = function(a, b) {\n            var c = a, e;\n            return ((twttr.is.object(a) && (c = a.text, e = a.mode))), c = d(c, e), ((((b == null)) ? c : Mustache.to_html(c, b)));\n        };\n        _.pseudoTranslate = function(a) {\n            str = \"[\";\n            var b = 0;\n            for (var c = 0; ((c < a.length)); c++) {\n                ((((((a[c] == \"\\u003E\")) || ((a[c] == \"}\")))) ? b-- : ((((((a[c] == \"\\u003C\")) || ((a[c] == \"{\")))) && b++)))), ((((b > 0)) ? str += a[c] : str += a[c].replace(/a/g, \"\\u00e5\\u00e4\").replace(/e/g, \"\\u00e9\\u00ea\").replace(/i/g, \"\\u00ef\\u00ed\").replace(/o/g, \"\\u00f6\\u00f8\").replace(/u/g, \"\\u00fc\")));\n            ;\n            };\n        ;\n            return str += \"]\", str;\n        };\n        var d = function(a, b) {\n            var d = a;\n            if (!!twttr.i18n) {\n                var e = undefined;\n                ((b ? e = ((twttr.i18n[((((b + \":\")) + a))] || twttr.i18n[a])) : e = twttr.i18n[a])), ((e && (d = e)));\n            }\n        ;\n        ;\n            return ((c ? _.pseudoTranslate(d) : d));\n        };\n        a(_);\n    });\n});\nprovide(\"EventProvider\", function(a) {\n    using().as(function(b) {\n        twttr.provide(\"twttr.EventProvider\", {\n            events: null,\n            _provider: function() {\n                return ((this._eventProvider || (this._eventProvider = $(\"\\u003Cdiv/\\u003E\")))), this._eventProvider;\n            },\n            _createEvent: function(a) {\n                ((this.events || (this.events = {\n                }))), ((this.events[a] || (this.events[a] = new $.JSBNG__Event(a))));\n            },\n            trigger: function() {\n                this._createEvent(arguments[0]);\n                var a = this._provider();\n                a.trigger.apply(a, arguments);\n            },\n            bind: function() {\n                this._createEvent(arguments[0]);\n                var a = this._provider();\n                a.bind.apply(a, arguments);\n            },\n            JSBNG__one: function() {\n                this._createEvent(arguments[0]);\n                var a = this._provider();\n                a.JSBNG__one.apply(a, arguments);\n            },\n            unbind: function() {\n                var a = this._provider();\n                a.unbind.apply(a, arguments);\n            },\n            _signalProvider: function() {\n                return ((this._signalProviderObj || (this._signalProviderObj = {\n                    fired: {\n                    },\n                    queues: {\n                    }\n                }))), this._signalProviderObj;\n            },\n            signal: function(a) {\n                var b = this._signalProvider();\n                if (!b.fired[a]) {\n                    b.fired[a] = !0;\n                    var c = ((b.queues[a] || []));\n                    for (var d = 0; ((d < c.length)); d++) {\n                        c[d].call(null);\n                    ;\n                    };\n                ;\n                    delete b.queues[a];\n                }\n            ;\n            ;\n            },\n            waitForSignal: function(a, b) {\n                var c = this._signalProvider();\n                ((c.fired[a] ? b.call() : (((c.queues[a] || (c.queues[a] = []))), c.queues[a].push(b))));\n            }\n        }), a(twttr.EventProvider);\n    });\n});\nprovide(\"bluejs/init\", function(a) {\n    using(function() {\n        twttr.anywhere = ((twttr.anywhere || {\n        })), twttr.anywhere.api = ((twttr.anywhere.api || {\n        })), twttr.anywhere.remote = ((twttr.anywhere.remote || {\n        }));\n        var b = [\"models\",\"util\",\"proxies\",\"mixins\",];\n        for (var c = 0, d = b.length; ((c < d)); ++c) {\n            twttr.anywhere.api[b[c]] = {\n            };\n        ;\n        };\n    ;\n        twttr.anywhere.api.config = {\n            useLocalStorage: !1,\n            cacheObjects: !0,\n            includeEntities: !1\n        }, twttr.anywhere.api.updateConfig = function(a) {\n            twttr.aug(twttr.anywhere.api.config, a);\n        }, twttr.anywhere.api.initialize = function(a) {\n            this.updateConfig(a), twttr.anywhere.api.globalEvents = twttr.aug({\n            }, twttr.EventProvider);\n            for (var b in twttr.anywhere.api.models) {\n                if (((b == \"Base\"))) {\n                    continue;\n                }\n            ;\n            ;\n                (function() {\n                    twttr.anywhere.api.proxies[b] = twttr.anywhere.api.util.proxyModel(twttr.anywhere.api.models[b], function(a) {\n                        this.JSBNG__event = a;\n                    });\n                })();\n            };\n        ;\n            twttr.anywhere.api.util.BaseCollection._name = \"twttr.anywhere.proxies.Collection\", twttr.anywhere.api.proxies.Collection = twttr.anywhere.api.util.proxyModel(twttr.anywhere.api.util.BaseCollection, function(a) {\n                this.JSBNG__event = a;\n            }), delete twttr.anywhere.api.util.BaseCollection._name, ((((twttr.anywhere.api.config.useLocalStorage && window.JSBNG__localStorage)) ? twttr.anywhere.api.cache = new twttr.anywhere.api.util.LocalStorageCache : twttr.anywhere.api.cache = new twttr.anywhere.api.util.RequestCache));\n        }, a();\n    });\n});\nprovide(\"bluejs/config/endpoints\", function(a) {\n    using(function() {\n        var b = \"i\", c = \"1\", d = twttr.anywhere.api.endpoints = {\n            \"blocks/blocking/ids\": {\n                url: \"blocks/blocking/ids\",\n                type: \"GET\"\n            },\n            \":user/:list_id/subscribers/create\": {\n                url: \":user/:list_id/subscribers\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"promoted_content/:event_type/log\": {\n                url: \"promoted_content/:event_type/log\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \":user/lists\": {\n                url: \":user/lists\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"lists/all\": {\n                url: \"lists/all\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"geo/search\": {\n                url: \"geo/search\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"followers/ids\": {\n                url: \"followers/ids\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"users/show\": {\n                url: \"users/show\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"urls/resolve\": {\n                url: \"urls/resolve\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"account/settings\": {\n                url: \"account/settings\",\n                type: \"GET\"\n            },\n            \"account/update_profile_background_image\": {\n                url: \"account/update_profile_background_image\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"users/recommendations/hide\": {\n                url: \"users/recommendations/hide\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"friendships/update\": {\n                url: \"friendships/update\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \":user/lists/memberships\": {\n                url: \":user/lists/memberships\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"lists/destroy\": {\n                url: \"lists/destroy\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"saved_searches/show/:id\": {\n                url: \"saved_searches/show/:id\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"friendships/show\": {\n                url: \"friendships/show\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"lists/statuses\": {\n                url: \"lists/statuses\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/friends\": {\n                url: \"statuses/friends\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"users/lookup\": {\n                url: \"users/lookup\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/show\": {\n                url: \"statuses/show\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/user_timeline\": {\n                url: \"statuses/user_timeline\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/profile_timeline\": {\n                url: \"statuses/profile_timeline\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/network_timeline\": {\n                url: \"statuses/network_timeline\",\n                type: \"GET\",\n                optional_parameters: !0,\n                version: b,\n                internal_auth: !0\n            },\n            \"statuses/media_timeline\": {\n                url: \"statuses/media_timeline\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/:id/retweeted_by/ids\": {\n                url: \"statuses/:id/retweeted_by/ids\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"trends/available\": {\n                url: \"trends/available\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \":user/:id/subscribers/destroy\": {\n                url: \":user/:id/subscribers\",\n                type: \"DELETE\",\n                optional_parameters: !0\n            },\n            \":user/:id/members/destroy\": {\n                url: \":user/:id/members\",\n                type: \"DELETE\",\n                optional_parameters: !0\n            },\n            \"lists/members/destroy\": {\n                url: \"lists/members/destroy\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"account/update_delivery_device\": {\n                url: \"account/update_delivery_device\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"direct_messages/new\": {\n                url: \"direct_messages/new\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"users/suggestions/random\": {\n                url: \"users/suggestions/random\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"geo/nearby_places\": {\n                url: \"geo/nearby_places\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"blocks/blocking\": {\n                url: \"blocks/blocking\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"friendships/accept\": {\n                url: \"friendships/accept\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"statuses/update\": {\n                url: \"statuses/update\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"statuses/update_with_media\": {\n                url: \"statuses/update_with_media\",\n                type: \"POST\",\n                host: twttr.domains.upload,\n                use_host_in_prod: !0,\n                optional_parameters: !0\n            },\n            \"saved_searches/create\": {\n                url: \"saved_searches/create\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \":user/:list_id/subscribers\": {\n                url: \":user/:list_id/subscribers\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/retweeted_to_me\": {\n                url: \"statuses/retweeted_to_me\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \":user/:list_id/subscribers/:id\": {\n                url: \":user/:list_id/subscribers/:id\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/retweets/:id\": {\n                url: \"statuses/retweets/:id\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/public_timeline\": {\n                url: \"statuses/public_timeline\",\n                type: \"GET\"\n            },\n            \"statuses/friends_timeline\": {\n                url: \"statuses/friends_timeline\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"trends/weekly\": {\n                url: \"trends/weekly\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"account/update_profile_image\": {\n                url: \"account/update_profile_image\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"users/profile_image/:screen_name\": {\n                url: \"users/profile_image/:screen_name\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"users/suggestions\": {\n                url: \"users/suggestions\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"friendships/cancel\": {\n                url: \"friendships/cancel\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"statuses/sample\": {\n                url: \"statuses/sample\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"account/update_profile\": {\n                url: \"account/update_profile\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"notifications/follow\": {\n                url: \"notifications/follow\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"geo/place\": {\n                url: \"geo/place\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"lists/show\": {\n                url: \"lists/show\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/followers\": {\n                url: \"statuses/followers\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"friendships/accept_all\": {\n                url: \"friendships/accept_all\",\n                type: \"POST\"\n            },\n            \"help/test\": {\n                url: \"help/test\",\n                type: \"GET\"\n            },\n            \":user/lists/subscriptions\": {\n                url: \":user/lists/subscriptions\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"direct_messages/destroy\": {\n                url: \"direct_messages/destroy\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"statuses/home_timeline\": {\n                url: \"statuses/home_timeline\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \":user/:list_id/members/:id\": {\n                url: \":user/:list_id/members/:id\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            report_spam: {\n                url: \"report_spam\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"related_results/show/:id\": {\n                url: \"related_results/show/:id\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"account/rate_limit_status\": {\n                url: \"account/rate_limit_status\",\n                type: \"GET\"\n            },\n            \"urls/shorten\": {\n                url: \"urls/shorten\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"geo/reverse_geocode\": {\n                url: \"geo/reverse_geocode\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"trends/daily\": {\n                url: \"trends/daily\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"account/verify_credentials\": {\n                url: \"account/verify_credentials\",\n                type: \"GET\"\n            },\n            \":user/lists/create\": {\n                url: \":user/lists\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"account/update_profile_colors\": {\n                url: \"account/update_profile_colors\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"users/suggestions/:slug/members\": {\n                url: \"users/suggestions/:slug/members\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"geo/similar_places\": {\n                url: \"geo/similar_places\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"blocks/create\": {\n                url: \"blocks/create\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \":user/:list_id/members\": {\n                url: \":user/:list_id/members\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"friends/ids\": {\n                url: \"friends/ids\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"favorites/destroy/:id\": {\n                url: \"favorites/destroy/:id\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"geo/id/:id\": {\n                url: \"geo/id/:id\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/retweet\": {\n                url: \"statuses/retweet\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"favorites/:id\": {\n                url: \"favorites/:id\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/retweeted_by_me\": {\n                url: \"statuses/retweeted_by_me\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \":user/:list_id/members/create\": {\n                url: \":user/:list_id/members\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"lists/members/create\": {\n                url: \"lists/members/create\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"users/search\": {\n                url: \"users/search\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"users/typeahead_social\": {\n                url: \"search/typeahead\",\n                type: \"GET\",\n                optional_parameters: !0,\n                version: b,\n                internal_auth: !0\n            },\n            \"users/typeahead_global\": {\n                url: \"search/typeahead\",\n                type: \"GET\",\n                optional_parameters: !0,\n                version: b,\n                internal_auth: !0\n            },\n            \"statuses/filter\": {\n                url: \"statuses/filter\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"friendships/create\": {\n                url: \"friendships/create\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"friendships/create_all\": {\n                url: \"friendships/create_all\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"account/settings/create\": {\n                url: \"account/settings\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"trends/current\": {\n                url: \"trends/current\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"users/suggestions/:slug\": {\n                url: \"users/suggestions/:slug\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/firehose\": {\n                url: \"statuses/firehose\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            saved_searches: {\n                url: \"saved_searches\",\n                type: \"GET\"\n            },\n            direct_messages: {\n                url: \"direct_messages\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"friendships/deny_all\": {\n                url: \"friendships/deny_all\",\n                type: \"POST\"\n            },\n            \"lists/update\": {\n                url: \"lists/update\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"blocks/destroy\": {\n                url: \"blocks/destroy\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"friendships/exists\": {\n                url: \"friendships/exists\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"users/contributors\": {\n                url: \"users/contributors\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/mentions\": {\n                url: \"statuses/mentions\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"favorites/create/:id\": {\n                url: \"favorites/create/:id\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            trends: {\n                url: \"trends\",\n                type: \"GET\"\n            },\n            \"trends/:woeid\": {\n                url: \"trends/:woeid\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal_auth: !0\n            },\n            \"urls/shorten_multiple\": {\n                url: \"urls/shorten_multiple\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"statuses/destroy\": {\n                url: \"statuses/destroy\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"statuses/retweet/:id\": {\n                url: \"statuses/retweet/:id\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"direct_messages/sent\": {\n                url: \"direct_messages/sent\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"blocks/exists\": {\n                url: \"blocks/exists\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"saved_searches/destroy/:id\": {\n                url: \"saved_searches/destroy/:id\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"statuses/retweets_of_me\": {\n                url: \"statuses/retweets_of_me\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"friendships/deny\": {\n                url: \"friendships/deny\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"friendships/destroy\": {\n                url: \"friendships/destroy\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"account/end_session\": {\n                url: \"account/end_session\",\n                type: \"POST\"\n            },\n            \"notifications/leave\": {\n                url: \"notifications/leave\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"statuses/:id/retweeted_by\": {\n                url: \"statuses/:id/retweeted_by\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"users/recommendations\": {\n                url: \"users/recommendations\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"account/view_possibly_sensitive\": {\n                url: \"account/view_possibly_sensitive\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"account/update_view_possibly_sensitive\": {\n                url: \"account/update_view_possibly_sensitive\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"account/personalization_settings\": {\n                url: \"account/personalization_settings\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"account/update_personalization_settings\": {\n                url: \"account/update_personalization_settings\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"account/has_dismissed_geo_promo\": {\n                url: \"account/has_dismissed_geo_promo\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"account/update_has_dismissed_geo_promo\": {\n                url: \"account/update_has_dismissed_geo_promo\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"account/geo_location\": {\n                url: \"account/geo_location\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"account/email_status\": {\n                url: \"account/email_status\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"users/send_recommendation_rating\": {\n                url: \"users/send_recommendation_rating\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"users/send_invites_by_email\": {\n                url: \"users/send_invites_by_email\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"users/following_followers_of\": {\n                url: \"users/following_followers_of\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"users/follows_in_common_with\": {\n                url: \"users/follows_in_common_with\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"users/update_discoverability\": {\n                url: \"users/update_discoverability\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"users/show_for_profile\": {\n                url: \"users/show_for_profile\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"find_sources/contacts/services\": {\n                url: \"find_sources/contacts/services\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"find_sources/contacts/matches\": {\n                url: \"find_sources/contacts/matches\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"find_sources/contacts/others\": {\n                url: \"find_sources/contacts/others\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"find_sources/contacts/follow_all\": {\n                url: \"find_sources/contacts/follow_all\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"find_sources/contacts/add_to_list\": {\n                url: \"find_sources/contacts/add_to_list\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"promos/random_json_promo\": {\n                url: \"promos/random_json_promo\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0,\n                mime_type: \"\"\n            },\n            search: {\n                url: \"phoenix_search\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0,\n                mime_type: \"phoenix\"\n            },\n            \"i/search\": {\n                url: \"search\",\n                type: \"GET\",\n                optional_parameters: !0,\n                version: b,\n                internal_auth: !0\n            },\n            \"i/discovery\": {\n                url: \"discovery\",\n                type: \"GET\",\n                optional_parameters: !0,\n                version: b,\n                internal_auth: !0\n            },\n            \"api/related_results/show/:id\": {\n                url: \"api/related_results/show/:id\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"friendships/incoming\": {\n                url: \"friendships/incoming\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"friend_requests/accept\": {\n                url: \"friend_requests/accept\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"friend_requests/deny\": {\n                url: \"friend_requests/deny\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"friendships/set_shares\": {\n                url: \"friendships/set_shares\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"bouncers/reset\": {\n                url: \"bouncers/reset\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"account/resend_confirmation_email\": {\n                url: \"account/resend_confirmation_email\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0,\n                mime_type: \"\"\n            },\n            \"download/apps\": {\n                url: \"download/apps\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0,\n                mime_type: \"\"\n            },\n            \"download/send_link\": {\n                url: \"download/send_link\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"devices/list\": {\n                url: \"devices/list\",\n                type: \"GET\",\n                internal: !0\n            },\n            \"devices/carriers\": {\n                url: \"devices/carriers\",\n                type: \"GET\",\n                internal: !0\n            },\n            \"devices/create\": {\n                url: \"devices/create\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0,\n                mime_type: \"\"\n            },\n            \"devices/destroy\": {\n                url: \"devices/destroy\",\n                type: \"POST\",\n                optional_parameters: !0,\n                internal: !0,\n                mime_type: \"\"\n            },\n            \"statuses/flag_possibly_sensitive\": {\n                url: \"statuses/flag_possibly_sensitive\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"statuses/update_possibly_sensitive\": {\n                url: \"statuses/update_possibly_sensitive\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"promoted_content/home_timeline\": {\n                url: \"promoted_content/home_timeline\",\n                type: \"GET\"\n            },\n            \"promoted_content/feedback\": {\n                url: \"promoted_content/feedback\",\n                type: \"POST\",\n                optional_parameters: !0\n            },\n            \"statuses/oembed\": {\n                url: \"statuses/oembed\",\n                optional_parameters: !0\n            },\n            \"direct_messages/conversations\": {\n                url: \"direct_messages/conversations\",\n                type: \"GET\",\n                optional_parameters: !0,\n                version: b,\n                internal_auth: !0\n            },\n            \"direct_messages/conversation_with\": {\n                url: \"direct_messages/conversation_with\",\n                type: \"GET\",\n                optional_parameters: !0,\n                version: b,\n                internal_auth: !0\n            },\n            \"users/get_prompt\": {\n                url: \"users/get_prompt\",\n                type: \"GET\",\n                internal: !0,\n                optional_parameters: !0\n            },\n            \"users/dismiss_prompt\": {\n                url: \"users/dismiss_prompt\",\n                type: \"POST\",\n                internal: !0,\n                optional_parameters: !0\n            },\n            \"statuses/following_timeline\": {\n                url: \"statuses/following_timeline\",\n                type: \"GET\",\n                optional_parameters: !0\n            },\n            \"search/facets\": {\n                url: \"search/facets\",\n                type: \"GET\",\n                optional_parameters: !0,\n                internal: !0\n            },\n            \"search/image_facets\": {\n                url: \"search/image_facets\",\n                type: \"GET\",\n                optional_parameters: !0,\n                version: b,\n                internal_auth: !0\n            },\n            \"search/video_facets\": {\n                url: \"search/video_facets\",\n                type: \"GET\",\n                optional_parameters: !0,\n                version: b,\n                internal_auth: !0\n            },\n            \"activity/activity_by_user\": {\n                url: \"activity/by_user\",\n                optional_parameters: !0,\n                version: b\n            },\n            \"activity/activity_of_me\": {\n                url: \"activity/about_me\",\n                optional_parameters: !0,\n                version: b\n            },\n            \"activity/activity_by_people_i_follow\": {\n                url: \"activity/by_friends\",\n                optional_parameters: !0,\n                version: b\n            },\n            \"statuses/:id/activity\": {\n                url: \"statuses/:id/activity\",\n                optional_parameters: !1,\n                version: b\n            },\n            \"statuses/:id/activity/summary\": {\n                url: \"statuses/:id/activity/summary\",\n                optional_parameters: !1,\n                version: b\n            },\n            \"government_search/by_zip\": {\n                url: \"government_search/by_zip\",\n                optional_parameters: !0,\n                version: b,\n                internal_auth: !0\n            }\n        };\n        a(d);\n    });\n});\nprovide(\"bluejs/util/request_helpers\", function(a) {\n    using(function() {\n        function b(a, b) {\n            return function(c, d, e) {\n                delete g[a];\n                if (((((!c || ((d === 0)))) || ((d >= 600))))) b({\n                    error: !0,\n                    JSBNG__status: 0,\n                    reason: \"No response or network disconnected.\"\n                });\n                 else {\n                    var f = e.getResponseHeader(\"X-Twitter-Identity\");\n                    ((f && (c._identity = f))), b(c);\n                }\n            ;\n            ;\n            };\n        };\n    ;\n        function c(a, b) {\n            return function(c, d) {\n                function e(a) {\n                    try {\n                        return JSON.parse(a);\n                    } catch (b) {\n                        return {\n                        };\n                    };\n                ;\n                };\n            ;\n                delete g[a];\n                var f = \"An error occured\";\n                ((((c.JSBNG__status == 401)) ? f = \"Access denied\" : ((((c.JSBNG__status == 403)) && (f = \"Permission denied\"))))), b({\n                    error: !0,\n                    JSBNG__status: c.JSBNG__status,\n                    response: e(c.responseText),\n                    reason: f,\n                    xhr: c\n                });\n            };\n        };\n    ;\n        function d(a, b) {\n            var c = a.split(\"/\"), d = 0, e = $.map(c, function(a) {\n                return ((((a.indexOf(\":\") === 0)) ? b[d++] : a));\n            });\n            return e.join(\"/\");\n        };\n    ;\n        function e(a, b) {\n            if (b.headers) {\n                var c = b.headers;\n                b.headers = null, b.beforeSend = function(a) {\n                    for (var b in c) {\n                        a.setRequestHeader(b, c[b]);\n                    ;\n                    };\n                ;\n                };\n            }\n        ;\n        ;\n            var d = $.ajax(b);\n            g[a] = d;\n        };\n    ;\n        function f(a, b) {\n            var c, e, f = {\n                dataType: \"json\",\n                type: ((a.type || \"get\")),\n                url: \"\"\n            };\n            ((a.use_host_in_prod && (f.use_host_in_prod = !0))), f.type = f.type.toLowerCase(), ((a.domain ? f.url += a.domain : (f.url += \"/\", ((a.internal || (f.url += ((twttr.is.def(a.version) ? a.version : \"1\")), f.url += \"/\")))))), f.url += a.url, c = b.slice(0, ((a.url.split(\":\").length - 1))), ((((c.length > 0)) && (f.url = d(f.url, c)))), ((((a.mime_type !== \"\")) && (f.url += ((a.mime_type ? ((\".\" + a.mime_type)) : \".json\"))))), f.data = {\n            };\n            if (a.optional_parameters) {\n                e = b.slice(c.length);\n                if (((e.length > 1))) {\n                    throw new \"Optional parameter list is longer than expected\";\n                }\n            ;\n            ;\n                f.data = e[0];\n            }\n        ;\n        ;\n            if (((((f.type === \"delete\")) || ((f.type === \"put\"))))) {\n                f.data._method = a.type.toLowerCase(), f.type = \"post\";\n            }\n        ;\n        ;\n            ((a.headers && (f.headers = a.headers))), ((a.host && (f.host = a.host)));\n            if (((a.internal_auth || ((f.type !== \"get\"))))) {\n                f.data.post_authenticity_token = twttr.anywhere.api.config.postAuthenticityToken;\n            }\n        ;\n        ;\n            return f;\n        };\n    ;\n        var g = {\n        }, i = /localhost\\.twitter\\.com/, j = function() {\n            var a = 0, d, f;\n            return ((((window.JSBNG__XMLHttpRequest && ((((window.JSBNG__location.protocol !== \"file:\")) || !window.ActiveXObject)))) ? (d = function() {\n                return new twttr.anywhere.remote.server.contentWindow.JSBNG__XMLHttpRequest;\n            }, f = function(a) {\n                return function() {\n                    return new twttr.anywhere.api.util.RemoteRequest.hosts[a].contentWindow.JSBNG__XMLHttpRequest;\n                };\n            }) : (d = function() {\n                try {\n                    return new twttr.anywhere.remote.server.contentWindow.ActiveXObject(\"Microsoft.XMLHTTP\");\n                } catch (a) {\n                \n                };\n            ;\n            }, f = function(a) {\n                return function() {\n                    try {\n                        return new twttr.anywhere.api.util.RemoteRequest.hosts[a].contentWindow.ActiveXObject(\"Microsoft.XMLHTTP\");\n                    } catch (b) {\n                    \n                    };\n                ;\n                };\n            }))), function(g, j, k) {\n                var l = ++a;\n                return j.success = b(l, k), j.error = c(l, k), j.data = ((j.data || {\n                })), j.headers = ((j.headers || {\n                })), j.headers[\"X-PHX\"] = \"true\", ((((j.host && ((twttr.domains.local.match(i) || j.use_host_in_prod)))) ? (j.xhr = f(j.host), delete j.host, delete j.use_host_in_prod) : ((g || (j.xhr = d))))), e(l, j), l;\n            };\n        }();\n        ((window.isTestMode && (twttr.anywhere.api.buildRequestOptions = f))), twttr.anywhere.api.makeRequest = function(a, b, c) {\n            return j(a.internal, f(a, b), c);\n        }, twttr.anywhere.api.cancelApiRequest = function(a) {\n            var b = g[a];\n            ((b && b.abort()));\n        }, a({\n            makeRequest: twttr.anywhere.api.makeRequest,\n            cancelApiRequest: twttr.anywhere.api.cancelApiRequest\n        });\n    });\n});\nprovide(\"bluejs/util/local_storage_cache\", function(a) {\n    using(function() {\n        var b = {\n            \"users/show\": {\n            },\n            \"account/verify_credentials\": {\n            },\n            \"users/lookup\": {\n            }\n        }, c = 177443, d = twttr.klass(\"twttr.anywhere.api.util.LocalStorageCache\", function() {\n        \n        }).methods({\n            clear: function() {\n                for (var a in twttr.storage.getAll(/twitter_anywhere_cache_/)) {\n                    twttr.storage.expire(a);\n                ;\n                };\n            ;\n            },\n            put: function(a, d, e) {\n                if (((a in b))) {\n                    var f = this._createKey(a, d);\n                    return twttr.storage.setWithExpiry(f, JSON.stringify(e), c), !0;\n                }\n            ;\n            ;\n                return !1;\n            },\n            get: function(a, b) {\n                var c = this._createKey(a, b), d;\n                return (((d = twttr.storage.get(c)) ? JSON.parse(d) : null));\n            },\n            expire: function(a) {\n                for (var b in twttr.storage.getAll(/twitter_anywhere_cache_/)) {\n                    ((b.match(a) && twttr.storage.expire(b)));\n                ;\n                };\n            ;\n            },\n            writeThroughCallback: function(a, b, c) {\n                return twttr.bind(this, function(d) {\n                    this.put(a, b, d), c(d);\n                });\n            },\n            _createKey: function(a, b) {\n                return ((\"twitter_anywhere_cache_\" + JSON.stringify([a,b,])));\n            }\n        });\n        a(d);\n    });\n});\nprovide(\"bluejs/util/object_cache\", function(a) {\n    using(function() {\n        var b = twttr.klass(\"twttr.anywhere.api.util.ObjectCache\", function(a, b) {\n            this.store = {\n            }, this.size = 0, this.options = ((b || {\n            })), this.keys = ((this.options.keys || [{\n                JSBNG__name: \"id\",\n                type: \"number\"\n            },{\n                JSBNG__name: \"id\",\n                type: \"string\"\n            },])), this.keyNames = {\n            };\n            for (var c = 0; ((c < this.keys.length)); c++) {\n                this.keyNames[this.keys[c].type] = this.keys[c].JSBNG__name;\n            ;\n            };\n        ;\n            this.shouldCacheAssociated = !!this.options.cacheAssociated, this.shouldExpireAssociated = !!this.options.expireAssociated, this.klass = a, this.constructor._instances.push(this), a._cache = this;\n        }).statics({\n            _capacity: 7000,\n            _instances: [],\n            _currentSize: 0,\n            _epoch: new JSBNG__Date,\n            _maxAge: 300000,\n            isAtCapacity: function() {\n                return ((this._currentSize === this._capacity));\n            },\n            eject: function() {\n                var a = this._instances[0];\n                for (var b = 1, c = this._instances.length; ((b < c)); ++b) {\n                    ((((this._instances[b].size > a.size)) && (a = this._instances[b])));\n                ;\n                };\n            ;\n                a.eject();\n            },\n            sweeper: function() {\n                var a;\n                for (var b = 0, c = this._instances.length; ((b < c)); ++b) {\n                    a = this._instances[b];\n                    for (var d in a) {\n                        ((((((a[d].createdAt - this._epoch)) > this._maxAge)) && a[d].expire()));\n                    ;\n                    };\n                ;\n                };\n            ;\n            },\n            flush: function() {\n                for (var a = 0, b = this._instances.length; ((a < b)); ++a) {\n                    this._instances[a].flush();\n                ;\n                };\n            ;\n            }\n        }).methods({\n            _persist: function(a, b) {\n                this.store[a] = {\n                    value: b.data(),\n                    accessCount: 1,\n                    lastAccess: new JSBNG__Date\n                }, this.size++, this.constructor._currentSize++;\n            },\n            _touch: function(a) {\n                var b = new JSBNG__Date;\n                this.store[a].accessCount++, this.store[a].createdAt = b, this.store[a].lastAccess = ((b - this.constructor._epoch));\n            },\n            _eject: function() {\n                this.size--, this.constructor._currentSize--;\n            },\n            eject: function() {\n                var a, b = ((new JSBNG__Date - this.constructor._epoch));\n                for (var c in this.store) {\n                    ((((this.store[c].lastAccess < b)) && (a = c, b = this.store[c].lastAccess)));\n                ;\n                };\n            ;\n                delete this.store[a], this._eject();\n            },\n            flush: function() {\n                this.constructor._currentSize -= this.size, this.store = {\n                }, this.size = 0;\n            },\n            get: function(a) {\n                var b = typeof a, c = this.keyNames[b];\n                ((((b === \"string\")) && (a = a.toLowerCase())));\n                var d = ((((c + \"_\")) + a));\n                return ((this.store[d] ? (this._touch(d), new this.klass(this.store[d].value)) : null));\n            },\n            getMulti: function(a) {\n                var b = [], c = [];\n                for (var d = 0, e = a.length; ((d < e)); ++d) {\n                    var f = this.get(a[d]);\n                    ((f ? b.push(f) : c.push(a[d])));\n                };\n            ;\n                return {\n                    hits: new twttr.anywhere.api.util.BaseCollection(b),\n                    misses: c\n                };\n            },\n            cache: function(a, b) {\n                b = ((b || {\n                }));\n                var c = this.shouldCacheAssociated;\n                ((twttr.is.def(b.shouldCacheAssociated) && (c = b.shouldCacheAssociated))), ((this.constructor.isAtCapacity() && this.constructor.eject()));\n                var d, e, f;\n                for (var g = 0, i = this.keys.length; ((g < i)); ++g) {\n                    f = this.keys[g].JSBNG__name, d = ((a[f] || \"\")), ((((this.keys[g].type === \"string\")) && (d = d.toLowerCase()))), e = ((((f + \"_\")) + d)), this._persist(e, a);\n                ;\n                };\n            ;\n                if (c) {\n                    var j = a.constructor._registry;\n                    if (j) {\n                        for (var k in j) {\n                            var l = a[k];\n                            ((l && this.cacheAssociated(l)));\n                        };\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                return a;\n            },\n            cacheAssociated: function(a) {\n                if (((((a instanceof twttr.anywhere.api.util.BaseCollection)) && a.length()))) {\n                    a = a.array;\n                    var b = a[0].constructor._cache;\n                    if (b) {\n                        for (var c = 0, d = a.length; ((c < d)); ++c) {\n                            b.cache(a[c]);\n                        ;\n                        };\n                    }\n                ;\n                ;\n                }\n                 else {\n                    var b = a.constructor._cache;\n                    ((b && b.cache(a)));\n                }\n            ;\n            ;\n            },\n            expire: function(a, b) {\n                b = ((b || {\n                }));\n                var c = this.shouldExpireAssociated;\n                ((twttr.is.def(b.shouldExpireAssociated) && (c = b.shouldExpireAssociated)));\n                var d, e;\n                for (var f = 0, g = this.keys.length; ((f < g)); ++f) {\n                    e = ((a[this.keys[f]] + \"\")), d = ((d || this.store[e])), delete this.store[e], this._eject();\n                ;\n                };\n            ;\n                if (d) {\n                    if (c) {\n                        var i = a.constructor._registry;\n                        if (i) {\n                            for (var j in i) {\n                                var k = a[j];\n                                ((k && this.expireAssociated(k)));\n                            };\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    return !0;\n                }\n            ;\n            ;\n                return !1;\n            },\n            expireAssociated: function(a) {\n                if (((((a instanceof twttr.anywhere.api.util.BaseCollection)) && a.length()))) {\n                    a = a.array;\n                    var b = a[0].constructor._cache;\n                    if (b) {\n                        for (var c = 0, d = a.length; ((c < d)); ++c) {\n                            b.expire(a[c]);\n                        ;\n                        };\n                    }\n                ;\n                ;\n                }\n                 else {\n                    var b = a.constructor._cache;\n                    ((b && b.expire(a)));\n                }\n            ;\n            ;\n            }\n        });\n        twttr.augmentString(\"twttr.anywhere.api.util.expireObject\", function(a) {\n            this.constructor._cache.expire(this, a);\n        }), twttr.augmentString(\"twttr.anywhere.api.util.cacheObject\", function(a) {\n            this.constructor._cache.cache(this, a);\n        }), a(b);\n    });\n});\nprovide(\"bluejs/util/request_cache\", function(a) {\n    using(function() {\n        var b = {\n        }, c = twttr.klass(\"twttr.anywhere.api.util.RequestCache\", function() {\n            this.store = {\n            };\n        }).statics({\n            DEFAULT_TTL: 300000\n        }).methods({\n            clear: function() {\n                this.store = {\n                };\n            },\n            inject: function(a, b, c, d) {\n                var e = {\n                    response: c,\n                    timestamp: new JSBNG__Date\n                };\n                return ((d && (e.RTL = d))), this.store[twttr.anywhere.api.util._createRequestKey(a, b)] = e, !0;\n            },\n            put: function(a, c, d, e) {\n                return ((((a in b)) ? this.inject.apply(this, arguments) : !1));\n            },\n            get: function(a, b) {\n                var c = twttr.anywhere.api.util._createRequestKey(a, b), d, e = this.store[c];\n                if (e) {\n                    if (!((((((e.RTL !== undefined)) && ((e.RTL === 0)))) || ((((new JSBNG__Date - e.timestamp)) > this.constructor.DEFAULT_TTL))))) {\n                        return ((((e.RTL !== undefined)) && e.RTL--)), e.response;\n                    }\n                ;\n                ;\n                    delete this.store[c];\n                }\n            ;\n            ;\n                return null;\n            },\n            expire: function(a) {\n                for (var b in this.store) {\n                    ((b.match(a) && delete this.store[b]));\n                ;\n                };\n            ;\n            },\n            writeThroughCallback: function(a, b, c) {\n                return twttr.bind(this, function(d) {\n                    this.put(a, b, d), c(d);\n                });\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"bluejs/util/helpers\", function(a) {\n    using(function() {\n        twttr.klass(\"twttr.anywhere.api.util.EventChain\", function() {\n        \n        }).methods(twttr.EventProvider);\n        var b = {\n            cast: !0,\n            cancel: !0,\n            success: !0,\n            complete: !0,\n            timeout: !0,\n            error: !0,\n            before: !0,\n            eventName: !0,\n            cacheOptions: !0\n        }, c = [\"phxcom\",];\n        twttr.augmentObject(twttr.anywhere.api.util, {\n            chain: new twttr.anywhere.api.util.EventChain,\n            noop: function() {\n            \n            },\n            defaultTrigger: \"current_user\",\n            camelize: function() {\n                var a = {\n                };\n                return function(b) {\n                    var c = a[b];\n                    return ((c || (c = b.replace(/_(.)/g, function(a, b) {\n                        return b.toUpperCase();\n                    }), a[b] = c))), c;\n                };\n            }(),\n            filterOptions: function(a, b) {\n                var d = {\n                }, e = a.concat(c);\n                for (var f = 0, g = e.length; ((f < g)); ++f) {\n                    var i = e[f];\n                    ((twttr.is.def(b[i]) && (d[i] = b[i])));\n                };\n            ;\n                return d;\n            },\n            underscore: function() {\n                var a = {\n                };\n                return function(b) {\n                    var c = a[b];\n                    return ((c || (c = b.replace(/([a-z])([A-Z])/g, function(a, b, c) {\n                        return ((((b + \"_\")) + c)).toLowerCase();\n                    }), a[b] = c))), c;\n                };\n            }(),\n            buildCollection: function(a, b) {\n                var c = new twttr.anywhere.api.util.BaseCollection;\n                for (var d = 0, e = b.length; ((d < e)); ++d) {\n                    c.push(new a(b[d]));\n                ;\n                };\n            ;\n                return c;\n            },\n            traverse: function(a, b) {\n                if (!b.length) {\n                    return a;\n                }\n            ;\n            ;\n                var c = b.shift();\n                if (((twttr.is.def(a[c]) && !twttr.is.nil(a[c])))) {\n                    return twttr.anywhere.api.util.traverse(a[c], b);\n                }\n            ;\n            ;\n                var d = twttr.anywhere.api.util.traverseCurrentTrends(a, c);\n                return ((d ? d : null));\n            },\n            traverseCurrentTrends: function(a, b) {\n                if (((b == \"current_trends\"))) {\n                    for (key in a) {\n                        if (a.hasOwnProperty(key)) {\n                            return a[key];\n                        }\n                    ;\n                    ;\n                    };\n                }\n            ;\n            ;\n                return null;\n            },\n            cleanParams: function(a) {\n                var c = {\n                };\n                for (var d in a) {\n                    ((b[d] || (c[d] = a[d])));\n                ;\n                };\n            ;\n                return c;\n            },\n            optify: function(a) {\n                var b = {\n                    success: twttr.anywhere.api.util.noop,\n                    error: twttr.anywhere.api.util.noop,\n                    complete: twttr.anywhere.api.util.noop\n                };\n                return ((a ? ((twttr.is.fn(a) ? twttr.merge({\n                }, b, {\n                    success: a\n                }) : twttr.merge({\n                }, b, a))) : b));\n            },\n            useStringIdentifier: function(a, b) {\n                var c = ((b + \"_str\"));\n                if (!a) {\n                    return;\n                }\n            ;\n            ;\n                ((a[c] ? (a[b] = a[c].toString(), delete a[c]) : ((a[b] && (a[b] = a[b].toString())))));\n            },\n            normalizePromotedTweet: function(a) {\n                if (a.promoted_content) {\n                    var b = a.promoted_content;\n                    delete a.promoted_content, a = $.extend(a, b), a.socialContext = a.social_context, delete a.social_context;\n                }\n                 else if (((a.entities && a.entities.promoted_content))) {\n                    var b = a.entities.promoted_content;\n                    delete a.entities.promoted_content, a = $.extend(a, b);\n                }\n                \n            ;\n            ;\n                return a;\n            },\n            serializeArgs: function(a) {\n                var b = \"\";\n                for (var c = 0, d = a.length; ((c < d)); ++c) {\n                    var e = a[c], f = [];\n                    if (((typeof e == \"object\"))) {\n                        for (var g in e) {\n                            f.push(g);\n                        ;\n                        };\n                    ;\n                        f.sort();\n                        for (var i = 0, j = f.length; ((i < j)); ++i) {\n                            b += ((f[i] + e[f[i]]));\n                        ;\n                        };\n                    ;\n                    }\n                     else b += JSON.stringify(e);\n                ;\n                ;\n                };\n            ;\n                return b;\n            },\n            _createRequestKey: function(a, b) {\n                return JSON.stringify([a,twttr.anywhere.api.util.serializeArgs(b),]);\n            },\n            sanitize: function(a) {\n                if (!a) {\n                    return a;\n                }\n            ;\n            ;\n                var b = [\"\\u0000\",\"\\u200e\",\"\\u200f\",\"\\u2028\",\"\\u2029\",\"\\u202a\",\"\\u202b\",\"\\u202c\",\"\\u202d\",\"\\u202e\",\"\\ufffe\",\"\\ufeff\",\"\\uffff\",], c;\n                for (c = 0; ((c < b.length)); c++) {\n                    a = a.replace(new RegExp(b[c], \"g\"), \"\");\n                ;\n                };\n            ;\n                return a;\n            },\n            returnClassFromType: function(a) {\n                return ((twttr.is.array(a) ? [twttr.anywhere.api.models[a[0]],] : twttr.anywhere.api.models[a]));\n            },\n            genEventName: function() {\n                return ((((\"chain_\" + (new JSBNG__Date).getTime())) + ((Math.JSBNG__random() * 1000))));\n            },\n            proxyNameFromType: function(a) {\n                return ((((a === undefined)) ? null : ((((((a === null)) || twttr.is.array(a))) ? \"Collection\" : a))));\n            },\n            makeRemoteRequest: function(a, b, c, d) {\n                var e = this, f, g = b;\n                d = ((d || {\n                })), f = ((((typeof c == \"function\")) ? {\n                    success: c\n                } : c)), (new twttr.anywhere.api.util.RemoteRequest(twttr.merge({\n                    methodName: a,\n                    args: b,\n                    callbacks: f\n                }, d))).send();\n            },\n            callMethod: function(a) {\n                function b(b) {\n                    ((b.packed_response_type ? ((b.available_features && e.inject(\"account/available_features\", {\n                    }, b.available_features, 1))) : a.dataSource.shift()));\n                    var d = ((a.dataSource.length ? twttr.anywhere.api.util.traverse(b, a.dataSource) : b)), f = ((!twttr.is.def(d) || twttr.is.nil(d))), g;\n                    ((twttr.is.array(c) ? g = ((f ? new twttr.anywhere.api.util.BaseCollection : twttr.anywhere.api.util.buildCollection(c[0], d))) : ((f ? g = null : g = ((c ? new c(d) : d)))))), JSBNG__setTimeout(function() {\n                        a.options.success(g, b);\n                    }, 0);\n                };\n            ;\n                var c, d = twttr.anywhere.api.util.RemoteRequest.priorities.NORMAL, e = twttr.anywhere.api.cache, f = !0, g = {\n                };\n                ((a.options && (c = a.options.cast, delete a.options.cast, ((a.options.headers && (g = a.options.headers, delete a.options.headers))), ((a.options.priority && (d = a.options.priority, delete a.options.priority))), ((a.options.useRequestCache && (f = a.options.useRequestCache, delete a.options.useRequestCache)))))), c = ((c || a.cast));\n                var i = a.params[((a.params.length - 1))];\n                ((twttr.is.object(i) && (a.params[((a.params.length - 1))] = twttr.anywhere.api.util.cleanParams(i))));\n                var j;\n                if (((((e && f)) && (j = e.get(a.url, a.params))))) b(j);\n                 else {\n                    var k = {\n                        before: a.options.before,\n                        success: ((e ? e.writeThroughCallback(a.url, a.params, b) : b)),\n                        error: a.options.error,\n                        complete: a.options.complete,\n                        timeout: a.options.timeout,\n                        cancel: a.options.cancel\n                    };\n                    twttr.anywhere.api.util.makeRemoteRequest(a.url, a.params, k, {\n                        headers: g,\n                        priority: d\n                    });\n                }\n            ;\n            ;\n            },\n            chainableFn: function(a, b) {\n                function c(b, e) {\n                    ((((c._curry && ((b instanceof twttr.anywhere.api.util.BaseCollection)))) && ((((c._curry instanceof twttr.anywhere.api.util.BaseCollection)) ? b = b.concat(c._curry) : b.push(c._curry))))), a(b, {\n                        response: e\n                    }), twttr.anywhere.api.util.chain.trigger(d, [b,]);\n                };\n            ;\n                var d;\n                return ((b.eventName ? (d = b.eventName, delete b.eventName) : d = twttr.anywhere.api.util.genEventName())), c.JSBNG__event = d, c;\n            },\n            cacheFn: function(a, b) {\n                return function(c) {\n                    b = ((b || {\n                    }));\n                    var d;\n                    if (((c instanceof twttr.anywhere.api.util.BaseCollection))) {\n                        var e = c.toArray();\n                        for (var f = 0, g = e.length; ((f < g)); ++f) {\n                            ((((((twttr.is.object(e[f]) && e[f].constructor._isModel)) && e[f].constructor.isCacheable())) && (d = e[f].constructor._cache.get(e[f].toParam()), ((((b.skipOverwrite && d)) ? e[f] = d : e[f].cache(b))))));\n                        ;\n                        };\n                    ;\n                    }\n                     else ((((((c instanceof twttr.anywhere.api.models.Base)) && c.constructor.isCacheable())) && (d = c.constructor._cache.get(c.toParam()), ((((b.skipOverwrite && d)) ? c = d : c.cache(b))))));\n                ;\n                ;\n                    a.apply({\n                    }, arguments);\n                };\n            },\n            expiryFn: function(a) {\n                return function(b) {\n                    if (((b instanceof twttr.anywhere.api.util.BaseCollection))) {\n                        var c = b.toArray();\n                        for (var d = 0, e = c.length; ((d < e)); ++d) {\n                            ((((c[d].constructor._isModel && c[d].constructor.isCacheable())) && c[d].expire()));\n                        ;\n                        };\n                    ;\n                    }\n                     else ((((((b instanceof twttr.anywhere.api.models.Base)) && b.constructor.isCacheable())) && b.expire()));\n                ;\n                ;\n                    a.apply({\n                    }, arguments);\n                };\n            },\n            writeThroughFn: function(a, b, c, d) {\n                var e = function(a, b) {\n                    var e;\n                    for (var f in b) {\n                        e = b[f], ((twttr.is.fn(e) && (e = e.apply(c, [a,].concat(d))))), a.sync(f, e);\n                    ;\n                    };\n                ;\n                };\n                return function(c) {\n                    if (((c instanceof twttr.anywhere.api.util.BaseCollection))) {\n                        var d = c.toArray();\n                        for (var f = 0, g = d.length; ((f < g)); ++f) {\n                            ((((d[f].constructor._isModel && d[f].constructor.isCacheable())) && e(d[f], b)));\n                        ;\n                        };\n                    ;\n                    }\n                     else ((((((c instanceof twttr.anywhere.api.models.Base)) && c.constructor.isCacheable())) && e(c, b)));\n                ;\n                ;\n                    a.apply({\n                    }, arguments);\n                };\n            },\n            triggerFn: function(a, b, c) {\n                return function(d) {\n                    a.trigger(b, arguments), c.apply({\n                    }, arguments);\n                };\n            },\n            decorateCallbacks: function(a, b, c) {\n                var d, e = [\"success\",\"error\",\"complete\",\"before\",];\n                for (var f = 0, g = e.length; ((f < g)); ++f) {\n                    d = e[f], c.callbacks[d] = twttr.anywhere.api.util.triggerFn(a, ((((b + \"_\")) + d)), c.callbacks[d], c.args);\n                ;\n                };\n            ;\n            },\n            chainableMethod: function(a, b, c) {\n                ((twttr.is.fn(b) && (c = b, b = {\n                })));\n                var d = twttr.anywhere.api.util.proxyNameFromType(a), e = function() {\n                    var e = {\n                    }, f = ((((this instanceof twttr.anywhere.api.models.Base)) ? this.constructor : this)), g = Array.prototype.slice.call(arguments), i = g.pop();\n                    ((((((i !== undefined)) && ((i !== null)))) && ((((((twttr.is.array(i) || !twttr.is.object(i))) || ((((a === null)) && twttr.is.fn(i))))) ? g.push(i) : ((twttr.is.fn(i) ? e.success = i : e = i))))));\n                    var j = [].concat(((b.decorators || [])));\n                    e.success = ((e.success || twttr.anywhere.api.util.noop)), e.error = ((e.error || twttr.anywhere.api.util.noop)), e.before = ((e.before || twttr.anywhere.api.util.noop)), e.complete = ((e.complete || twttr.anywhere.api.util.noop)), ((b.writes ? (j.push({\n                        decorator: twttr.anywhere.api.util.writeThroughFn,\n                        args: [b.writes,this,g,]\n                    }), ((((!twttr.is.def(b.cache) || ((b.cache !== !1)))) && j.push({\n                        decorator: twttr.anywhere.api.util.cacheFn,\n                        args: [{\n                            skipOverwrite: !0\n                        },]\n                    })))) : (((((!twttr.is.def(b.cache) || ((b.cache !== !1)))) && j.push({\n                        decorator: twttr.anywhere.api.util.cacheFn,\n                        args: [e.cacheOptions,]\n                    }))), ((b.expire && j.push({\n                        decorator: twttr.anywhere.api.util.expiryFn,\n                        args: []\n                    }))))));\n                    var k, l;\n                    ((b.triggers && (l = ((twttr.is.fn(b.triggers) ? b.triggers(this) : b.triggers)), ((b.triggeredBy ? k = twttr.anywhere.api.models[b.triggeredBy] : k = f)), twttr.anywhere.api.util.decorateCallbacks(k, l, {\n                        callbacks: e,\n                        args: g\n                    })))), e = twttr.anywhere.api.util.optify(e), j.push({\n                        decorator: twttr.anywhere.api.util.chainableFn,\n                        args: [e,]\n                    }), e.cast = twttr.anywhere.api.util.returnClassFromType(a), g.push(e);\n                    var m = null;\n                    ((((((f._isModel && f.isCacheable())) && b.cacheLookup)) && (m = b.cacheLookup.apply(f, g))));\n                    if (((m && m.partialHit))) {\n                        for (var n = 0, o = j.length; ((n < o)); ++n) {\n                            e.success = j[n].decorator.apply(this, [e.success,].concat(j[n].args));\n                        ;\n                        };\n                    ;\n                        e.success._curry = m.curry, c.apply(this, m.args);\n                    }\n                     else if (m) e.success = twttr.anywhere.api.util.chainableFn(e.success, e), JSBNG__setTimeout(function() {\n                        e.success(m);\n                    }, 0);\n                     else {\n                        for (var n = 0, o = j.length; ((n < o)); ++n) {\n                            e.success = j[n].decorator.apply(this, [e.success,].concat(j[n].args));\n                        ;\n                        };\n                    ;\n                        m = c.apply(this, g);\n                    }\n                    \n                ;\n                ;\n                    return ((((((!e.eventName && d)) && ((this.constructor != twttr.anywhere.api.util.BaseCollection)))) ? new twttr.anywhere.api.proxies[d](e.success.JSBNG__event) : m));\n                };\n                return e.proxyName = d, e.returnType = a, e;\n            },\n            aliasMethod: function(a, b) {\n                var c = twttr.anywhere.api.util.proxyNameFromType(a), d = function() {\n                    return b.apply(this, arguments);\n                };\n                return d.proxyName = c, d;\n            },\n            proxyModel: function(a, b) {\n                var c = a._name.replace(\"models\", \"proxies\"), d = twttr.klass(c, b);\n                for (var e in a.prototype) {\n                    (function() {\n                        var b = e;\n                        d.prototype[b] = function() {\n                            var c = Array.prototype.slice.call(arguments), d = !!a.prototype[b].proxyName, e;\n                            if (d) {\n                                e = twttr.anywhere.api.util.genEventName();\n                                var f = c.pop(), g = {\n                                };\n                                ((((((f !== null)) && ((f !== undefined)))) && ((((((twttr.is.array(f) || !twttr.is.object(f))) || ((((a == twttr.anywhere.api.util.BaseCollection)) && twttr.is.fn(f))))) ? c.push(f) : g = f)))), g = twttr.anywhere.api.util.optify(g), g.eventName = e, c.push(g);\n                            }\n                        ;\n                        ;\n                            var i = this;\n                            twttr.anywhere.api.util.chain.JSBNG__one(this.JSBNG__event, function(d, e) {\n                                a.prototype[b].apply(e, c);\n                            });\n                            if (d) {\n                                return new twttr.anywhere.api.proxies[a.prototype[b].proxyName](e);\n                            }\n                        ;\n                        ;\n                        };\n                    })();\n                ;\n                };\n            ;\n                return d;\n            },\n            protoExtend: function(a) {\n                function b() {\n                \n                };\n            ;\n                return b.prototype = a, new b;\n            }\n        }), a();\n    });\n});\nprovide(\"bluejs/util/model\", function(a) {\n    using(function() {\n        twttr.augmentObject(twttr.anywhere.api.util, {\n            model: function(a, b) {\n                function c(a) {\n                    return twttr.anywhere.api.util.underscore(a).toLowerCase();\n                };\n            ;\n                function d(a, b) {\n                    b = ((b || c(a))), ((e._registry || (e._registry = {\n                    }))), e._registry[b] = a;\n                };\n            ;\n                ((b || (b = function(a) {\n                    twttr.anywhere.api.models.Base.call(this, a);\n                })));\n                var e = twttr.klass(a, b).subclassOf(twttr.anywhere.api.models.Base).statics({\n                    _eventing: twttr.aug({\n                    }, twttr.EventProvider)\n                }).statics({\n                    _isModel: !0,\n                    _uniqueKey: \"id\",\n                    _extensionMethods: [],\n                    trigger: function() {\n                        this._eventing.trigger.apply(this._eventing, arguments);\n                    },\n                    _bindWrapper: function(a, b) {\n                        return function(c) {\n                            c.type = a, b.apply({\n                            }, arguments);\n                        };\n                    },\n                    _bind: function(a, b, c) {\n                        ((twttr.is.fn(c) && (c = {\n                            success: c\n                        })));\n                        var d = this, e = b.split(\".\"), f, g;\n                        f = e.shift(), e = e.join(\".\");\n                        for (var i in c) {\n                            (function() {\n                                var b = i;\n                                g = ((((f + \"_\")) + b)), ((((e !== \"\")) && (g += ((\".\" + e))))), a.call(d._eventing, g, d._bindWrapper(f, c[b]));\n                            })();\n                        ;\n                        };\n                    ;\n                    },\n                    bind: function(a, b) {\n                        var c = a.split(\" \");\n                        for (var d = 0, e = c.length; ((d < e)); ++d) {\n                            this._bind(this._eventing.bind, c[d], b);\n                        ;\n                        };\n                    ;\n                    },\n                    JSBNG__one: function(a, b) {\n                        var c = a.split(\" \");\n                        for (var d = 0, e = c.length; ((d < e)); ++d) {\n                            this._bind(this._eventing.JSBNG__one, c[d], b);\n                        ;\n                        };\n                    ;\n                    },\n                    unbind: function(a, b) {\n                        var c = a.split(\" \");\n                        for (var d = 0, e = c.length; ((d < e)); ++d) {\n                            this._unbind(c[d], b);\n                        ;\n                        };\n                    ;\n                    },\n                    _unbind: function(a, b) {\n                        var c = [\"success\",\"error\",\"complete\",\"before\",];\n                        if (((a[0] == \".\"))) {\n                            this._eventing.unbind(a, b);\n                            return;\n                        }\n                    ;\n                    ;\n                        var d = this, e = a.split(\".\"), f, g;\n                        f = e.shift(), e = e.join(\".\");\n                        for (var i = 0, j = c.length; ((i < j)); ++i) {\n                            (function() {\n                                var a = c[i];\n                                g = ((((f + \"_\")) + a)), ((((e !== \"\")) && (g += ((\".\" + e))))), d._eventing.unbind(g, b);\n                            })();\n                        ;\n                        };\n                    ;\n                    },\n                    identify: function(a) {\n                        var b = a;\n                        return ((((a instanceof this)) && (b = a[this._uniqueKey]))), b;\n                    },\n                    isCacheable: function() {\n                        return ((!!twttr.anywhere.api.config.cacheObjects && !!this._cache));\n                    }\n                }).methods({\n                    toParam: function() {\n                        return this.constructor.identify(this);\n                    },\n                    reload: twttr.anywhere.api.util.aliasMethod(a.split(\".\").pop(), function() {\n                        var a = [this.constructor.identify(this),].concat(Array.prototype.slice.apply(arguments));\n                        return this.constructor.JSBNG__find.apply(this.constructor, a);\n                    })\n                });\n                return e.hasMany = function(a, b) {\n                    return b = ((b || c(a))), ((e._registry || (e._registry = {\n                    }))), e._registry[b] = [a,], e;\n                }, e.belongsTo = function(a, b) {\n                    return d(a, b), e;\n                }, e.hasOne = function(a, b) {\n                    return d(a, b), e;\n                }, e.cache = function(a) {\n                    return new twttr.anywhere.api.util.ObjectCache(e, a), e.prototype.cache = twttr.anywhere.api.util.cacheObject, e.prototype.expire = twttr.anywhere.api.util.expireObject, e;\n                }, e.uniqueKey = function(a) {\n                    return e._uniqueKey = a, e;\n                }, e.extend = function(a) {\n                    return e._extensionMethods.push(a), e;\n                }, e;\n            }\n        }), a(twttr.anywhere.api.util.model);\n    });\n});\nprovide(\"bluejs/util/remote_request\", function(a) {\n    using(function() {\n        var b = /localhost\\.twitter\\.com/, c = twttr.klass(\"twttr.anywhere.api.util.RemoteRequest\", function(a) {\n            this.id = ++this.constructor.requestId, this.methodName = a.methodName, this.requestParameters = ((a.args || [])), ((this.constructor.piggybackWhitelist[this.methodName] ? this.signature = twttr.anywhere.api.util._createRequestKey(this.methodName, this.requestParameters) : this.signature = this.id)), this.priority = ((a.priority || this.constructor.priorities.NORMAL)), this.headers = ((a.headers || {\n            })), this.retryCount = 0, this.timeoutTimer = null, this.pendingRequestId = null;\n            var b = this, c = twttr.anywhere.api.util.noop;\n            this.requestCallbacks = {\n                before: ((a.callbacks.before || c)),\n                success: ((a.callbacks.success || c)),\n                error: ((a.callbacks.error || c)),\n                complete: ((a.callbacks.complete || c)),\n                timeout: ((a.callbacks.timeout || function(a) {\n                    a.wait();\n                })),\n                cancel: ((a.callbacks.cancel || c))\n            };\n            var d = this.requestCallbacks.error;\n            this.requestCallbacks.error = function(c) {\n                function e(b, c) {\n                    trackClient({\n                        page: \"api\",\n                        action: \"error\"\n                    }, {\n                        status_code: b,\n                        item_names: [((\"methodName=\" + a.methodName)),((\"args=\" + JSON.stringify(((a.args || []))))),((\"X-MID=\" + c.getResponseHeader(\"X-MID\"))),((\"X-Transaction=\" + c.getResponseHeader(\"X-Transaction\"))),((\"X-RateLimit-Remaining=\" + c.getResponseHeader(\"X-RateLimit-Remaining\"))),((\"X-RateLimit-Class=\" + c.getResponseHeader(\"X-RateLimit-Class\"))),]\n                    });\n                };\n            ;\n                if (((c.JSBNG__status === b.constructor.RATE_LIMIT_STATUS))) {\n                    var f = b.constructor.apiErrorCodeFromResponse(c);\n                    ((((f === b.constructor.RATE_LIMIT_API_CODE)) ? twttr.anywhere.api.globalEvents.trigger(\"rate_limited\") : ((((f == null)) && (twttr.anywhere.api.globalEvents.trigger(\"unknown_error\"), ((c.xhr && e(400, c.xhr))))))));\n                }\n            ;\n            ;\n                ((((((twttr.loggedIn && ((c.JSBNG__status == b.constructor.UNAUTHORIZED_STATUS)))) && ((c[\"response\"][\"error\"] == \"Could not authenticate you.\")))) && window.JSBNG__location.reload())), d.apply({\n                }, arguments), ((((((c.JSBNG__status === b.constructor.FORBIDDEN_STATUS)) && c.xhr)) && e(403, c.xhr)));\n            };\n            var e = this.constructor.timings[this.methodName];\n            if (((!twttr.is.def(e) || ((e.totalRequests > this.constructor.sampleWindow))))) {\n                this.constructor.timings[this.methodName] = {\n                    timeTotal: 0,\n                    totalRequests: 0\n                };\n            }\n        ;\n        ;\n            this.constructor.timings[this.methodName].totalRequests++;\n        }).statics({\n            RATE_LIMIT_STATUS: 400,\n            UNAUTHORIZED_STATUS: 401,\n            FORBIDDEN_STATUS: 403,\n            RATE_LIMIT_API_CODE: 88,\n            useDynamicBackoff: !1,\n            requestId: 1,\n            sampleWindow: 15,\n            maxRetries: 3,\n            maxProcessing: 3,\n            defaultRequestLatency: 5000,\n            latencySteps: [5000,10000,20000,],\n            priorities: {\n                IMMEDIATE: 4,\n                HIGH: 3,\n                NORMAL: 2,\n                LOW: 1\n            },\n            hosts: {\n            },\n            timings: {\n            },\n            processing: 0,\n            pipeline: [],\n            pending: {\n            },\n            piggybackWhitelist: {\n                \"activity/activity_by_people_i_follow\": !0\n            },\n            apiErrorCodeFromResponse: function(a) {\n                return ((((((((a.response && a.response.errors)) && a.response.errors.length)) && a.response.errors[0])) ? a.response.errors[0].code : null));\n            },\n            isReady: function(a) {\n                if (window.isTestMode) {\n                    throw new Error(((\"JS API methods must be stubbed when used in tests: \" + a.url)));\n                }\n            ;\n            ;\n                return twttr.is.def(twttr.anywhere.remote.server);\n            },\n            isBacklogged: function() {\n                return ((this.pipeline.length > 0));\n            },\n            isCapped: function() {\n                return !1;\n            },\n            isAvailable: function() {\n                return ((this.processing < this.maxProcessing));\n            },\n            isIdle: function() {\n                return ((this.processing === 0));\n            },\n            flush: function() {\n                if (!this.isBacklogged()) {\n                    return;\n                }\n            ;\n            ;\n                var a = ((this.maxProcessing - this.processing));\n                for (var b = 0, c = a; ((b < c)); ++b) {\n                    this.reschedule();\n                ;\n                };\n            ;\n            },\n            reschedule: function() {\n                if (!this.isBacklogged()) {\n                    return;\n                }\n            ;\n            ;\n                var a = 0, b = this.pipeline[a];\n                for (var c = 0, d = this.pipeline.length; ((c < d)); ++c) {\n                    ((((this.pipeline[c].request.priority > b.request.priority)) && (a = c, b = this.pipeline[c])));\n                ;\n                };\n            ;\n                this.pipeline.splice(a, 1), b.runner();\n            }\n        }).methods({\n            setStart: function(a) {\n                this.startedOn = a;\n            },\n            setEnd: function(a) {\n                this.endedOn = a, this.constructor.timings[this.methodName].timeTotal += this.latency();\n            },\n            latency: function() {\n                return ((this.endedOn - this.startedOn));\n            },\n            dynamicBackoff: function() {\n                var a = this.constructor.timings[this.methodName];\n                return ((((a.timeTotal !== 0)) ? Math.floor(((a.timeTotal / a.totalRequests))) : this.constructor.defaultRequestLatency));\n            },\n            incrementalBackoff: function() {\n                return this.constructor.latencySteps[this.retryCount];\n            },\n            _stop: function() {\n                this[((\"stopped_\" + this.retryCount))] = !0, delete this.constructor.pending[this.signature], ((this.pendingRequestId && twttr.anywhere.api.cancelApiRequest(this.pendingRequestId))), this._clearTimer();\n            },\n            _clearTimer: function() {\n                ((this.timeoutTimer && (JSBNG__clearTimeout(this.timeoutTimer), this.timeoutTimer = null)));\n            },\n            _startTimer: function(a) {\n                var b = this;\n                a = !!a;\n                var c = null;\n                ((a && (c = ((this.constructor.useDynamicBackoff ? this.dynamicBackoff : this.incrementalBackoff))))), this._clearTimer(), this.timeoutTimer = JSBNG__setTimeout(function() {\n                    var a = b.constructor.pending[b.signature];\n                    for (var c = 0, d = a.length; ((c < d)); ++c) {\n                        a[c].requestCallbacks.timeout(b);\n                    ;\n                    };\n                ;\n                }, ((a ? c.call(this) : this.constructor.defaultRequestLatency)));\n            },\n            cancel: function() {\n                var a = this.constructor.pending[this.signature];\n                if (((a.length > 1))) {\n                    for (var b = 0, c = a.length; ((b < c)); ++b) {\n                        ((((a[b].id === this.id)) && a.splice(b, 1)));\n                    ;\n                    };\n                }\n                 else {\n                    this._stop();\n                }\n            ;\n            ;\n                this.requestCallbacks.cancel(this);\n            },\n            retry: function() {\n                var a = this.constructor.pending[this.signature];\n                if (((a.length > 1))) {\n                    for (var b = 0, c = a.length; ((b < c)); ++b) {\n                        ((((a[b].id === this.id)) && a.splice(b, 1)));\n                    ;\n                    };\n                }\n                 else {\n                    this._stop();\n                }\n            ;\n            ;\n                this.retryCount++;\n                if (((this.retryCount > this.constructor.maxRetries))) {\n                    var d = {\n                        response: {\n                            error: \"Connection timeout\"\n                        }\n                    };\n                    this.requestCallbacks.error(d), this.requestCallbacks.complete(d);\n                    return;\n                }\n            ;\n            ;\n                this.signature = ((((this.signature + \"_\")) + this.retryCount)), this.send();\n            },\n            wait: function() {\n                this._startTimer();\n            },\n            request: function(a, b) {\n                if (((((!this.constructor.isReady(a) && !a.internal)) || this.constructor.isCapped()))) {\n                    this.constructor.pipeline.push({\n                        request: this,\n                        runner: b\n                    });\n                    return;\n                }\n            ;\n            ;\n                this._run(b);\n            },\n            _run: function(a) {\n                this.setStart(new JSBNG__Date), this._startTimer(), this.constructor.processing++, a.call(this);\n            },\n            responseHandler: function(a, b) {\n                var c = this;\n                return function(d) {\n                    c.constructor.processing--, ((((c.constructor.isAvailable() && c.constructor.isBacklogged())) && c.constructor.reschedule())), c.setEnd(new JSBNG__Date), ((c[((\"stopped_\" + a))] || b(d)));\n                };\n            },\n            _buildRequestCallback: function() {\n                var a = this, b = this.retryCount;\n                return this.responseHandler(b, function(b) {\n                    a._clearTimer();\n                    var c = a.constructor.pending[a.signature], d = ((((b && b.error)) ? \"error\" : \"success\"));\n                    for (var e = 0, f = c.length; ((e < f)); ++e) {\n                        c[e].requestCallbacks[d].apply({\n                        }, [b,a,]), c[e].requestCallbacks.complete.apply({\n                        }, [b,a,]);\n                    ;\n                    };\n                ;\n                    delete a.constructor.pending[a.signature];\n                });\n            },\n            send: function() {\n                function a() {\n                    var a = c._buildRequestCallback(), b = Array.prototype.slice.apply(c.requestParameters);\n                    c.requestCallbacks.before.apply({\n                    }, [c,]), c.pendingRequestId = twttr.anywhere.api.makeRequest(d, b, a);\n                };\n            ;\n                var c = this, d = twttr.anywhere.api.endpoints[this.methodName];\n                if (!d) {\n                    throw new Error(((((\"The endpoint, \" + this.methodName)) + \" is not a registered API method\")));\n                }\n            ;\n            ;\n                if (this.constructor.pending[this.signature]) {\n                    this.constructor.pending[this.signature].push(this), this.requestCallbacks.before.apply({\n                    }, [this,]);\n                    return;\n                }\n            ;\n            ;\n                this.constructor.pending[this.signature] = [this,], d = twttr.merge({\n                }, d, {\n                    headers: this.headers\n                }), ((((((((twttr.domains.local.match(b) || d.use_host_in_prod)) && d.host)) && !this.constructor.hosts[d.host])) ? (url = ((((((twttr.proto + \"://\")) + d.host)) + \"/receiver.html\")), twttr.createIframe(url, function() {\n                    c.constructor.hosts[d.host] = this, c.request(d, a);\n                })) : this.request(d, a)));\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"bluejs/util/base_collection\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = function(a) {\n            return b(null, function() {\n                var b = Array.prototype.slice.call(arguments, 0), c = b.pop(), d = a.apply(this, b);\n                return c.success(d), d;\n            });\n        }, d = twttr.klass(\"twttr.anywhere.api.util.BaseCollection\", function(a) {\n            this.array = ((a || []));\n        }).methods({\n            each: c(function(a) {\n                for (var b = 0, c = this.array.length; ((b < c)); ++b) {\n                    a(this.array[b], b);\n                ;\n                };\n            ;\n                return this;\n            }),\n            sort: c(function() {\n                return this.array.sort.apply(this.array, arguments), this;\n            }),\n            isEmpty: function() {\n                return ((this.array.length === 0));\n            },\n            toArray: function() {\n                return this.array;\n            },\n            inject: function() {\n                return this.reduce.apply(this, arguments);\n            },\n            reduce: function(a, b) {\n                if (((arguments.length !== 2))) {\n                    throw \"Exception: Wrong number of arguments, 3 required\";\n                }\n            ;\n            ;\n                for (var c = 0, d = this.array.length; ((c < d)); ++c) {\n                    a = b(a, this.array[c]);\n                ;\n                };\n            ;\n                return a;\n            },\n            join: function(a, b) {\n                ((twttr.is.fn(a) && (b = a, a = \"\")));\n                var c = this.array.join(a);\n                return ((b && b(c))), c;\n            },\n            concat: function(a) {\n                return ((((a instanceof this.constructor)) && (a = a.array))), new this.constructor(this.array.concat(a));\n            },\n            JSBNG__find: c(function(a) {\n                for (var b = 0, c = this.array.length; ((b < c)); ++b) {\n                    if (a(this.array[b], b)) {\n                        return this.array[b];\n                    }\n                ;\n                ;\n                };\n            ;\n                return null;\n            }),\n            filter: c(function(a) {\n                var b = new this.constructor;\n                for (var c = 0, d = this.array.length; ((c < d)); ++c) {\n                    ((a(this.array[c], c) && b.push(this.array[c])));\n                ;\n                };\n            ;\n                return b;\n            }),\n            some: function(a) {\n                for (var b = 0, c = this.array.length; ((b < c)); ++b) {\n                    if (a.call(this.array, this.array[b], b, this.array)) {\n                        return !0;\n                    }\n                ;\n                ;\n                };\n            ;\n                return !1;\n            },\n            every: function(a) {\n                for (var b = 0, c = this.array.length; ((b < c)); ++b) {\n                    if (!a.call(this.array, this.array[b], b, this.array)) {\n                        return !1;\n                    }\n                ;\n                ;\n                };\n            ;\n                return !0;\n            },\n            map: c(function(a) {\n                var b = new this.constructor;\n                for (var c = 0, d = this.array.length; ((c < d)); ++c) {\n                    b.push(a(this.array[c], c));\n                ;\n                };\n            ;\n                return b;\n            }),\n            none: function(a) {\n                var b = this.any(a);\n                return !b;\n            },\n            length: function() {\n                return this.array.length;\n            },\n            get: c(function(a, b) {\n                var c = this.array[a];\n                return ((b && b(c))), c;\n            }),\n            push: function() {\n                return ((((arguments[0] instanceof this.constructor)) ? this.array.push.apply(this.array, arguments[0].array) : this.array.push.apply(this.array, arguments))), this;\n            },\n            pop: function(a, b) {\n                var c;\n                ((twttr.is.fn(a) && (b = a, a = undefined)));\n                if (a) {\n                    var d = ((this.array.length - a));\n                    c = new this.constructor(this.array.slice(d)), this.array = this.array.slice(0, d);\n                }\n                 else c = this.array.pop();\n            ;\n            ;\n                return ((b && b(c))), c;\n            },\n            shift: function() {\n                return this.array.shift();\n            },\n            unshift: function() {\n                return ((((arguments[0] instanceof this.constructor)) ? this.array.unshift.apply(this.array, arguments[0].array) : this.array.unshift.apply(this.array, arguments))), this;\n            },\n            first: c(function(a, b) {\n                ((a || (a = 1))), ((twttr.is.fn(a) && (b = a, a = 1)));\n                var c;\n                return ((((a == 1)) ? c = this.array[0] : c = new this.constructor(this.array.slice(0, a)))), ((b && b(c))), c;\n            }),\n            slice: function(a, b) {\n                var c = [a,];\n                ((((((b !== undefined)) && ((b !== null)))) && c.push(b)));\n                var d = this.array.slice.apply(this.array, c);\n                return new this.constructor(d);\n            },\n            reverse: c(function() {\n                return new this.constructor(this.array.reverse());\n            }),\n            last: c(function(a, b) {\n                ((a || (a = 1))), ((twttr.is.fn(a) && (b = a, a = 1)));\n                var c;\n                return ((((a == 1)) ? c = this.array[((this.array.length - 1))] : c = new this.constructor(this.array.slice(((this.array.length - a)))))), ((b && b(c))), c;\n            })\n        });\n        a(d);\n    });\n});\nprovide(\"bluejs/mixins/status_actions\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.augmentString(\"twttr.anywhere.api.mixins.StatusActions\", {\n            retweet: c(\"Status\", function(a) {\n                return twttr.anywhere.api.models.Status.retweet(this, a);\n            }),\n            favorite: c(\"Status\", function(a) {\n                return twttr.anywhere.api.models.Status.favorite(this, a);\n            }),\n            unfavorite: c(\"Status\", function(a) {\n                return twttr.anywhere.api.models.Status.unfavorite(this, a);\n            }),\n            reply: c(\"Status\", function(a, b) {\n                return twttr.anywhere.api.models.Status.reply(this, a, b);\n            })\n        });\n        a(e);\n    });\n});\nprovide(\"bluejs/mixins/phoenix/user\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.callMethod, d = twttr.anywhere.api.util.filterOptions, e = twttr.klass.mixin(\"twttr.anywhere.api.mixins.phoenix.User\", function(a) {\n            return a.statics({\n                _bulkFollowing: 0,\n                startBulkFollowing: function() {\n                    this._bulkFollowing++;\n                },\n                stopBulkFollowing: function() {\n                    this._bulkFollowing--;\n                },\n                isBulkFollowing: function() {\n                    return ((this._bulkFollowing > 0));\n                },\n                findForProfile: b(\"User\", {\n                    cacheLookup: function(a, b) {\n                        var c = this._cache.get(a);\n                        if (c) {\n                            var d = {\n                                cursor: -1,\n                                count: 15,\n                                user_id: c.id\n                            };\n                            return (((cachedFriends = twttr.API._requestCache.get(\"statuses/friends\", [d,])) ? (twttr.API._requestCache.inject(\"statuses/friends\", [d,], cachedFriends, 1), c) : !1));\n                        }\n                    ;\n                    ;\n                        return !1;\n                    },\n                    decorators: [{\n                        decorator: function(a) {\n                            return function(b, c) {\n                                if (c.response.friends) {\n                                    var d = {\n                                        cursor: -1,\n                                        count: 15,\n                                        user_id: b.id\n                                    };\n                                    twttr.API._requestCache.inject(\"statuses/friends\", [d,], c.response.friends, 1);\n                                }\n                            ;\n                            ;\n                                if (c.response.recommendations) {\n                                    var e = {\n                                        limit: 4,\n                                        pc: !1,\n                                        user_id: b.id\n                                    };\n                                    twttr.API._requestCache.inject(\"users/recommendations\", [e,], c.response.recommendations, 1);\n                                }\n                            ;\n                            ;\n                                if (c.response.timeline) {\n                                    var f = {\n                                        include_entities: 1,\n                                        include_available_features: 1,\n                                        contributor_details: !0,\n                                        include_rts: !0,\n                                        user_id: b.id\n                                    };\n                                    ((twttr.decider.isAvailable(\"platform_enable_cards\") && (f.include_cards = 1))), twttr.API._requestCache.inject(\"statuses/user_timeline\", [f,], c.response.timeline, 1);\n                                }\n                            ;\n                            ;\n                                a.apply({\n                                }, arguments);\n                            };\n                        },\n                        args: []\n                    },]\n                }, function(a, b) {\n                    var d;\n                    ((twttr.is.string(a) ? d = {\n                        screen_name: a\n                    } : d = {\n                        user_id: a\n                    })), c({\n                        options: b,\n                        url: \"users/show_for_profile\",\n                        params: [d,],\n                        dataSource: [\"\",\"user\",]\n                    });\n                })\n            }), a.methods({\n                setWantRetweetsOn: b(\"User\", {\n                    expire: !0,\n                    triggers: \"does_want_retweets\",\n                    triggerTarget: function(a) {\n                        return \"current_user\";\n                    }\n                }, function(a) {\n                    c({\n                        options: a,\n                        url: \"friendships/update\",\n                        params: [twttr.merge(a, {\n                            user_id: this.id,\n                            retweets: \"1\"\n                        }),],\n                        dataSource: [\"\",]\n                    });\n                }),\n                setWantRetweetsOff: b(\"User\", {\n                    expire: !0,\n                    triggers: \"doesnt_want_retweets\",\n                    triggerTarget: function(a) {\n                        return \"current_user\";\n                    }\n                }, function(a) {\n                    c({\n                        options: a,\n                        url: \"friendships/update\",\n                        params: [twttr.merge(a, {\n                            user_id: this.id,\n                            retweets: \"0\"\n                        }),],\n                        dataSource: [\"\",]\n                    });\n                })\n            }), a;\n        });\n        a(e);\n    });\n});\nprovide(\"bluejs/mixins/phoenix/current_user\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.callMethod, d = twttr.anywhere.api.util.filterOptions, e = twttr.klass.mixin(\"twttr.anywhere.api.mixins.phoenix.CurrentUser\", function(a) {\n            return a.methods({\n                followingFollowersOf: b([\"User\",], function(a, b) {\n                    var d = {\n                        cursor: -1\n                    };\n                    ((twttr.is.string(a) ? d.screen_name = a : d.user_id = a)), c({\n                        options: b,\n                        url: \"users/following_followers_of\",\n                        params: [twttr.merge(d, b),],\n                        dataSource: [\"\",\"users\",]\n                    });\n                }),\n                followsInCommonWith: b([\"User\",], function(a, b) {\n                    var d = {\n                        cursor: -1\n                    };\n                    ((twttr.is.string(a) ? d.screen_name = a : d.user_id = a)), c({\n                        options: b,\n                        url: \"users/follows_in_common_with\",\n                        params: [twttr.merge(d, b),],\n                        dataSource: [\"\",\"users\",]\n                    });\n                }),\n                updateDiscoverability: b(undefined, function(a, b) {\n                    c({\n                        options: b,\n                        url: \"users/update_discoverability\",\n                        params: [twttr.merge(a, {\n                            id: this.id\n                        }),],\n                        dataSource: [\"\",]\n                    });\n                }),\n                viewPossiblySensitive: b(undefined, function(a) {\n                    c({\n                        options: a,\n                        url: \"account/view_possibly_sensitive\",\n                        params: [{\n                        },],\n                        dataSource: [\"\",\"view_possibly_sensitive\",]\n                    });\n                }),\n                updateViewPossiblySensitive: b(undefined, function(a, b) {\n                    c({\n                        options: b,\n                        url: \"account/update_view_possibly_sensitive\",\n                        params: [{\n                            do_show: a\n                        },],\n                        dataSource: [\"\",\"view_possibly_sensitive\",]\n                    });\n                }),\n                personalizationSettings: b(undefined, function(a) {\n                    c({\n                        options: a,\n                        url: \"account/personalization_settings\",\n                        params: [{\n                        },],\n                        dataSource: [\"\",]\n                    });\n                }),\n                updatePersonalizationSettings: b(undefined, function(a, b) {\n                    c({\n                        options: b,\n                        url: \"account/update_personalization_settings\",\n                        params: [{\n                            use_cookie_personalization: a.use_cookie_personalization,\n                            cookie_personalization_prompt_displayed: a.cookie_personalization_prompt_displayed\n                        },],\n                        dataSource: [\"\",]\n                    });\n                }),\n                hasDismissedGeoPromo: b(undefined, function(a) {\n                    c({\n                        options: a,\n                        url: \"account/has_dismissed_geo_promo\",\n                        params: [{\n                        },],\n                        dataSource: [\"\",\"has_dismissed_geo_promo\",]\n                    });\n                }),\n                updateHasDismissedGeoPromo: b(undefined, function(a, b) {\n                    c({\n                        options: b,\n                        url: \"account/update_has_dismissed_geo_promo\",\n                        params: [{\n                            has_dismissed_geo_promo: a\n                        },],\n                        dataSource: [\"\",\"has_dismissed_geo_promo\",]\n                    });\n                }),\n                emailStatus: b(undefined, function(a) {\n                    c({\n                        options: a,\n                        url: \"account/email_status\",\n                        params: [{\n                        },],\n                        dataSource: [\"\",\"email_status\",]\n                    });\n                }),\n                emailBounceReset: b(undefined, function(a) {\n                    c({\n                        options: a,\n                        url: \"bouncers/reset\",\n                        params: [{\n                        },],\n                        dataSource: [\"\",]\n                    });\n                }),\n                emailResendConfirmation: b(undefined, function(a) {\n                    c({\n                        options: a,\n                        url: \"account/resend_confirmation_email\",\n                        params: [{\n                        },],\n                        dataSource: [\"\",]\n                    });\n                }),\n                geoLocation: b(undefined, function(a) {\n                    c({\n                        options: a,\n                        url: \"account/geo_location\",\n                        params: [a,],\n                        dataSource: [\"\",]\n                    });\n                })\n            }), twttr.augmentObject(a.prototype.friends, {\n                accept: b(\"User\", {\n                    triggers: \"acceptFollow\",\n                    triggeredBy: \"User\"\n                }, function(a, b) {\n                    c({\n                        options: b,\n                        url: \"friendships/accept\",\n                        params: [{\n                            user_id: a\n                        },],\n                        dataSource: [\"\",]\n                    });\n                }),\n                acceptAll: b(\"User\", function(a) {\n                    c({\n                        options: a,\n                        url: \"friendships/accept_all\",\n                        params: [{\n                        },],\n                        dataSource: [\"\",\"user\",]\n                    });\n                }),\n                deny: b(\"User\", function(a, b) {\n                    c({\n                        options: b,\n                        url: \"friendships/deny\",\n                        params: [{\n                            user_id: a\n                        },],\n                        dataSource: [\"\",]\n                    });\n                }),\n                denyAll: b(\"User\", function(a) {\n                    c({\n                        options: a,\n                        url: \"friendships/deny_all\",\n                        params: [{\n                        },],\n                        dataSource: [\"\",\"user\",]\n                    });\n                }),\n                cancel: b(\"User\", {\n                    triggers: \"cancel_request\",\n                    triggeredBy: \"User\"\n                }, function(a, b) {\n                    c({\n                        options: b,\n                        url: \"friendships/cancel\",\n                        params: [{\n                            user_id: a\n                        },],\n                        dataSource: [\"\",\"user\",]\n                    });\n                }),\n                followAll: b(undefined, function(a, b) {\n                    b = ((b || {\n                    }));\n                    var d = this, e = [], f = [], g = b.stringifiedIds;\n                    for (var i = 0, j = a.length; ((i < j)); ++i) {\n                        ((((twttr.is.string(a[i]) && !g)) ? e.push(a[i]) : f.push(a[i])));\n                    ;\n                    };\n                ;\n                    twttr.API.User.findAll(a, {\n                        stringifiedIds: g,\n                        success: function(a) {\n                            var g = b.success;\n                            b.success = function(_, b) {\n                                var c = {\n                                };\n                                for (var e = 0; ((e < b.length)); ++e) {\n                                    var f = b[e];\n                                    c[f.id] = f;\n                                };\n                            ;\n                                a.each(function(a) {\n                                    var b = c[a.id], d = {\n                                        requestParameters: [{\n                                            user_id: a.id\n                                        },]\n                                    };\n                                    if (b.is_blocking) {\n                                        return;\n                                    }\n                                ;\n                                ;\n                                    ((b.is_protected_follow_request ? (twttr.API.User.trigger(\"follow_request_before\", d), twttr.API.User.trigger(\"follow_request_success\", a)) : (twttr.API.User.trigger(\"follow_before\", d), twttr.API.User.trigger(\"follow_success\", a))));\n                                }), ((g && g.apply(d, arguments)));\n                            }, c({\n                                options: b,\n                                url: \"friendships/create_all\",\n                                params: [{\n                                    user_id: f.join(\",\"),\n                                    screen_name: e.join(\",\")\n                                },],\n                                dataSource: [\"\",\"bulk_follow_results\",]\n                            });\n                        }\n                    });\n                })\n            }), a;\n        });\n        a(e);\n    });\n});\nprovide(\"bluejs/mixins/phoenix/status\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.filterOptions, f = twttr.klass.mixin(\"twttr.anywhere.api.mixins.phoenix.Status\", function(a) {\n            return a.belongsTo(\"Status\", \"retweetingStatus\"), a.extend(function() {\n                ((this.isPromoted() && twttr.anywhere.api.util.PromotedStore.putStatus(this)));\n            }), a.statics({\n                search: b([\"Status\",], function(a, b) {\n                    ((b.near && (b.near = encodeURIComponent(b.near)))), ((b.within && (b.within = encodeURIComponent(b.within)))), d({\n                        options: b,\n                        url: \"search\",\n                        params: [twttr.merge({\n                            q: a\n                        }, b),],\n                        dataSource: [\"\",\"statuses\",]\n                    });\n                }),\n                related: b([\"RelatedTweets\",], function(a, b) {\n                    var c = $.extend({\n                    }, b);\n                    d({\n                        options: b,\n                        url: \"related_results/show/:id\",\n                        params: [a,c,],\n                        dataSource: [\"\",]\n                    });\n                })\n            }), a.methods({\n                related: c([\"RelatedTweets\",], function(a) {\n                    return twttr.anywhere.api.models.Status.related(this, a);\n                }),\n                isPromoted: function() {\n                    return !!this.impressionId;\n                },\n                logImpressionIfPromoted: function() {\n                    ((((this.isPromoted() && !this.loggedImpression)) && (twttr.API.util.PromotedContent.logImpression(this.impressionId), this.loggedImpression = !0)));\n                }\n            }), a;\n        });\n        a(f);\n    });\n});\nprovide(\"bluejs/mixins/phoenix/rate_user_recommendation\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.callMethod, d = twttr.klass.mixin(\"twttr.anywhere.api.mixins.phoenix.RateUserRecommendation\", function(a) {\n            return a.extend(function() {\n                ((!this.user.promotedContent || twttr.anywhere.api.util.PromotedStore.putUser(this.user)));\n            }), a.statics({\n                rate: b(undefined, function(a) {\n                    c({\n                        options: a,\n                        url: \"users/send_recommendation_rating\",\n                        params: [a,],\n                        dataSource: [\"\",]\n                    });\n                })\n            }), a;\n        });\n        a(d);\n    });\n});\nprovide(\"bluejs/models/base\", function(a) {\n    using(function() {\n        var b = 0, c = twttr.klass(\"twttr.anywhere.api.models.Base\", function(a) {\n            if (!a) {\n                return null;\n            }\n        ;\n        ;\n            if (((a.constructor.uber && ((a.constructor.uber.constructor == twttr.anywhere.api.models.Base))))) {\n                return a;\n            }\n        ;\n        ;\n            this.attributes = {\n            };\n            var c = this.constructor._registry;\n            for (var d in a) {\n                this.data(d, a[d]);\n                if (((d.indexOf(\"_\") !== 0))) {\n                    var e = twttr.anywhere.api.util.camelize(d);\n                    if (!this[e]) {\n                        var f = null, g = !1;\n                        if (((c && c[e]))) {\n                            var i = c[e];\n                            ((twttr.is.array(i) ? (i = i[0], ((twttr.is.fn(i) && (i = i(a))))) : ((twttr.is.fn(i) && (i = i(a)))))), ((i && (f = twttr.anywhere.api.models[i], g = twttr.is.array(c[e]))));\n                        }\n                    ;\n                    ;\n                        ((g ? this[e] = twttr.anywhere.api.util.buildCollection(f, this.data(d)) : ((f ? this[e] = new f(this.data(d)) : this[e] = this.data(d)))));\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            if (this.constructor._extensionMethods) {\n                var j = {\n                };\n                for (var k in this) {\n                    j[k] = !0;\n                ;\n                };\n            ;\n                for (var l = 0, m = this.constructor._extensionMethods.length; ((l < m)); ++l) {\n                    var n = this.constructor._extensionMethods[l];\n                    n.call(this, this);\n                };\n            ;\n                for (var k in this) {\n                    if (!twttr.is.def(j[k])) {\n                        var o = ((((this[k] && this[k].data)) && twttr.is.fn(this[k].data)));\n                        this.data(twttr.anywhere.api.util.underscore(k), ((o ? this[k].data() : this[k])));\n                    }\n                ;\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            this._objectId = ++b;\n        }).methods({\n            sync: function(a, b) {\n                var c = twttr.anywhere.api.util.underscore(a), d = twttr.anywhere.api.util.camelize(a);\n                return ((((b instanceof twttr.anywhere.api.models.Base)) ? this.attributes[c] = b.attributes : this.data(c, b))), this[d] = b, ((((this.constructor.isCacheable && this.constructor.isCacheable())) && this.cache())), b;\n            },\n            data: function(a, b) {\n                if (((((typeof a == \"string\")) && ((typeof b != \"undefined\"))))) {\n                    return this.attributes[a] = b, b;\n                }\n            ;\n            ;\n                if (((((typeof a == \"object\")) && ((typeof b == \"undefined\"))))) {\n                    return twttr.merge(this.attributes, a);\n                }\n            ;\n            ;\n                if (((((typeof a == \"string\")) && ((typeof b == \"undefined\"))))) {\n                    return this.attributes[a];\n                }\n            ;\n            ;\n                if (((((typeof a == \"undefined\")) && ((typeof b == \"undefined\"))))) {\n                    return this.attributes;\n                }\n            ;\n            ;\n            },\n            clone: function(a) {\n                var b = $.extend({\n                }, this);\n                b.attributes = $.extend({\n                }, this.attributes);\n                if (a) {\n                    for (var c in a) {\n                        b.sync(c, a[c]);\n                    ;\n                    };\n                }\n            ;\n            ;\n                return b;\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"bluejs/models/user\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.filterOptions, f = twttr.anywhere.api.util.noop, g = twttr.anywhere.api.util.defaultTrigger, i = twttr.anywhere.api.models.Base, j = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.User\", function(a) {\n            function b(a, b) {\n                return ((((a.length != 0)) && ((((b.length / a.length)) > 214823))));\n            };\n        ;\n            a.JSBNG__name = twttr.anywhere.api.util.sanitize(a.JSBNG__name);\n            if (((a.JSBNG__name && twttr.isRTL))) {\n                var c = a.JSBNG__name.match(twttr.constants.regexps.rtlChar);\n                if (((!c || !b(a.JSBNG__name, c)))) {\n                    a.JSBNG__name = ((((\"\\u202a\" + a.JSBNG__name)) + \"\\u202c\"));\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            a.description = twttr.anywhere.api.util.sanitize(a.description), ((((((window.JSBNG__location.protocol === \"https:\")) && twttr.cdnBase)) && (((((a.profile_image_url && ((a.profile_image_url.indexOf(\"http:\") === 0)))) && (a.profile_image_url = twttr.assets.getPathFromAbsoluteURL(a.profile_image_url, {\n                isSSL: !0,\n                isVersioned: !1\n            })))), ((((a.profile_background_image_url && ((a.profile_background_image_url.indexOf(\"http:\") === 0)))) && (a.profile_background_image_url = twttr.assets.getPathFromAbsoluteURL(a.profile_background_image_url, {\n                isSSL: !0,\n                isVersioned: !1\n            }))))))), twttr.anywhere.api.models.Base.call(this, a);\n            var d = this;\n            this.lists = function() {\n                return twttr.anywhere.api.models.User.prototype.lists.apply(d, arguments);\n            }, this.lists.JSBNG__find = function() {\n                return twttr.anywhere.api.models.User.prototype.lists.JSBNG__find.apply(d, arguments);\n            };\n        }).uniqueKey(\"screenName\").cache({\n            keys: [{\n                JSBNG__name: \"id\",\n                type: \"number\"\n            },{\n                JSBNG__name: \"screenName\",\n                type: \"string\"\n            },]\n        }).hasOne(\"Status\").statics({\n            JSBNG__find: b(\"User\", {\n                cacheLookup: function(a, b) {\n                    var c = this._cache.get(a);\n                    return ((c ? c : !1));\n                }\n            }, function(a, b) {\n                var c;\n                ((twttr.is.string(a) ? c = {\n                    screen_name: a\n                } : c = {\n                    user_id: a\n                })), d({\n                    options: b,\n                    url: \"users/show\",\n                    params: [c,],\n                    dataSource: [\"user\",]\n                });\n            }),\n            findAll: b([\"User\",], {\n                cacheLookup: function(a, b) {\n                    if (b.reload) {\n                        return delete b.reload, !1;\n                    }\n                ;\n                ;\n                    var c = this._cache.getMulti(a), d = c.hits;\n                    return ((c.misses.length ? ((d.isEmpty() ? !1 : {\n                        partialHit: !0,\n                        curry: d,\n                        args: [c.misses,b,]\n                    })) : d));\n                }\n            }, function(a, b) {\n                var c = [], e = [], f = ((b && b.stringifiedIds));\n                for (var g = 0, i = a.length; ((g < i)); ++g) {\n                    ((((twttr.is.string(a[g]) && !f)) ? c.push(a[g]) : e.push(a[g])));\n                ;\n                };\n            ;\n                d({\n                    options: b,\n                    url: \"users/lookup\",\n                    params: [{\n                        user_id: e.join(\",\"),\n                        screen_name: c.join(\",\")\n                    },],\n                    dataSource: [\"users\",]\n                });\n            }),\n            findAllCached: function(a) {\n                var b = this._cache.getMulti(a);\n                return b.hits;\n            },\n            current: b(\"CurrentUser\", function(a) {\n                d({\n                    options: a,\n                    url: \"account/verify_credentials\",\n                    params: [],\n                    dataSource: [\"user\",]\n                });\n            }),\n            typeaheadSocial: b(undefined, function(a, b) {\n                d({\n                    options: b,\n                    url: \"users/typeahead_social\",\n                    params: [twttr.merge(b, {\n                        prefetch: !0,\n                        result_type: \"users\"\n                    }),],\n                    dataSource: [\"\",\"users\",]\n                });\n            }),\n            typeaheadGlobal: b(undefined, function(a, b) {\n                d({\n                    options: b,\n                    url: \"users/typeahead_global\",\n                    params: [twttr.merge(b, {\n                        q: a\n                    }),],\n                    dataSource: [\"users\",]\n                });\n            }),\n            search: b([\"User\",], function(a, b) {\n                d({\n                    options: b,\n                    url: \"users/search\",\n                    params: [twttr.merge(b, {\n                        q: a\n                    }),],\n                    dataSource: [\"users\",]\n                });\n            }),\n            recommendedUsers: b([\"UserRecommendation\",], function(a) {\n                twttr.abdecider.choose(\"wtf_test_ranker_141\"), d({\n                    options: a,\n                    url: \"users/recommendations\",\n                    params: [a,],\n                    dataSource: [\"\",]\n                });\n            }),\n            recommendedUsers2: b([\"UserRecommendation\",], function(a) {\n                twttr.abdecider.choose(\"wtf_test_ranker_141\");\n                var b = {\n                    expanded_results_format: 1\n                };\n                (($.cookie(\"force_newt\") && (b.force_newt = !0))), (($.cookie(\"newt_ip\") && (b.ip = $.cookie(\"newt_ip\")))), d({\n                    options: a,\n                    url: \"users/recommendations\",\n                    params: [twttr.merge(b, a),],\n                    dataSource: [\"\",\"users\",]\n                });\n            })\n        }).methods({\n            bind: twttr.anywhere.api.util.bindMethod,\n            favorites: b([\"Status\",], function(a) {\n                ((twttr.is.def(a.include_entities) || (a.include_entities = twttr.anywhere.api.config.includeEntities))), d({\n                    options: a,\n                    url: \"favorites/:id\",\n                    params: [this.id,a,],\n                    dataSource: [\"statuses\",]\n                });\n            }),\n            timeline: b([\"Status\",], function(a) {\n                ((twttr.is.def(a.include_entities) || (a.include_entities = twttr.anywhere.api.config.includeEntities))), d({\n                    options: a,\n                    url: \"statuses/user_timeline\",\n                    params: [twttr.merge(a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"statuses\",]\n                });\n            }),\n            profileTimeline: b([\"Status\",], function(a) {\n                ((twttr.is.def(a.include_entities) || (a.include_entities = twttr.anywhere.api.config.includeEntities))), d({\n                    options: a,\n                    url: \"statuses/profile_timeline\",\n                    params: [twttr.merge(a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"statuses\",]\n                });\n            }),\n            media: b([\"Status\",], function(a) {\n                ((twttr.is.def(a.include_entities) || (a.include_entities = twttr.anywhere.api.config.includeEntities))), d({\n                    options: a,\n                    url: \"statuses/media_timeline\",\n                    params: [twttr.merge(a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"statuses\",]\n                });\n            }),\n            followingTweets: b([\"Status\",], function(a) {\n                ((twttr.is.def(a.include_entities) || (a.include_entities = twttr.anywhere.api.config.includeEntities))), d({\n                    options: a,\n                    url: \"statuses/following_timeline\",\n                    params: [twttr.merge(a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"statuses\",]\n                });\n            }),\n            followers: b([\"User\",], function(a) {\n                d({\n                    options: a,\n                    url: \"statuses/followers\",\n                    params: [twttr.merge({\n                        cursor: -1\n                    }, a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"\",\"users\",]\n                });\n            }),\n            friends: b([\"User\",], function(a) {\n                d({\n                    options: a,\n                    url: \"statuses/friends\",\n                    params: [twttr.merge({\n                        cursor: -1\n                    }, a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"\",\"users\",]\n                });\n            }),\n            activity: b([\"Activity\",], function(a) {\n                d({\n                    options: a,\n                    url: \"activity/activity_by_user\",\n                    params: [twttr.merge(a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"\",]\n                });\n            }),\n            friendIds: b(undefined, function(a) {\n                d({\n                    options: a,\n                    url: \"friends/ids\",\n                    params: [twttr.merge({\n                        cursor: -1\n                    }, a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"\",\"ids\",]\n                });\n            }),\n            followerIds: b(undefined, function(a) {\n                d({\n                    options: a,\n                    url: \"followers/ids\",\n                    params: [twttr.merge({\n                        cursor: -1\n                    }, a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"\",\"ids\",]\n                });\n            }),\n            _isFollowing: function(a, b, c) {\n                twttr.anywhere.api.util.makeRemoteRequest(\"friendships/exists\", [{\n                    user_a: a,\n                    user_b: b\n                },], {\n                    success: c.success,\n                    error: c.error\n                });\n            },\n            isFollowing: function(a, b) {\n                b = twttr.anywhere.api.util.optify(b);\n                var c = twttr.anywhere.api.models.User.identify(a);\n                this._isFollowing(this.id, c, b);\n            },\n            isFriend: function(a, b) {\n                this.isFollowing(a, b);\n            },\n            isFollowedBy: function(a, b) {\n                b = twttr.anywhere.api.util.optify(b);\n                var c = twttr.anywhere.api.models.User.identify(a);\n                this._isFollowing(c, this.id, b);\n            },\n            isMutual: function(a, b) {\n                b = twttr.anywhere.api.util.optify(b);\n                var c = twttr.anywhere.api.models.User.identify(a), d = b.success;\n                return b.success = function(a) {\n                    d(((a.following && a.followedBy)));\n                }, this.relationshipWith(a, b);\n            },\n            relationshipWith: function(a, b) {\n                b = twttr.anywhere.api.util.optify(b);\n                var c = this, d = twttr.anywhere.api.models.User.identify(a), e = {\n                    source_id: this.id\n                };\n                ((twttr.is.string(d) ? e.target_screen_name = d : e.target_id = d)), twttr.anywhere.api.util.makeRemoteRequest(\"friendships/show\", [e,], {\n                    success: function(a) {\n                        var d = {\n                            following: a.relationship.source.following,\n                            followedBy: a.relationship.source.followed_by\n                        };\n                        ((((c instanceof twttr.anywhere.api.models.CurrentUser)) && (d.notifications = a.relationship.source.notifications_enabled, d.blocking = a.relationship.source.blocking, d.wantRetweets = a.relationship.source.want_retweets, d.canDM = a.relationship.source.can_dm))), b.success(d);\n                    },\n                    error: b.error\n                });\n            },\n            block: b(\"User\", {\n                expire: !0,\n                triggers: \"block\",\n                triggerTarget: g\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \"blocks/create\",\n                    params: [twttr.merge(a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"user\",]\n                });\n            }),\n            unblock: b(\"User\", {\n                expire: !0,\n                triggers: \"unblock\",\n                triggerTarget: g\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \"blocks/destroy\",\n                    params: [twttr.merge(a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"user\",]\n                });\n            }),\n            similarUsers: b([\"UserRecommendation\",], function(a) {\n                d({\n                    options: a,\n                    url: \"users/recommendations\",\n                    params: [twttr.merge(a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"\",]\n                });\n            }),\n            directMessage: c(\"DirectMessage\", function(a, b) {\n                return twttr.anywhere.api.models.DirectMessage.send(this.id, a, b);\n            }),\n            dm: c(\"DirectMessage\", function(a, b) {\n                return this.directMessage(a, b);\n            }),\n            follow: b(\"User\", {\n                expire: !0,\n                writes: {\n                    followRequestSent: function(a) {\n                        return ((a[\"protected\"] ? !0 : !1));\n                    },\n                    following: function(a) {\n                        return ((a[\"protected\"] ? !1 : !0));\n                    }\n                },\n                triggers: function(a) {\n                    return ((((a[\"protected\"] && !a.following)) ? \"follow_request\" : \"follow\"));\n                },\n                triggerTarget: g\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \"friendships/create\",\n                    params: [$.extend({\n                        user_id: this.id\n                    }, a),],\n                    dataSource: [\"user\",]\n                });\n            }),\n            unfollow: b(\"User\", {\n                expire: !0,\n                writes: {\n                    followRequestSent: !1,\n                    following: !1\n                },\n                triggers: \"unfollow\",\n                triggerTarget: g\n            }, function(a) {\n                var b = ((((this[\"protected\"] && this.followRequestSent)) ? \"friendships/cancel\" : \"friendships/destroy\"));\n                d({\n                    options: a,\n                    url: b,\n                    params: [$.extend({\n                        user_id: this.id\n                    }, a),],\n                    dataSource: [\"user\",]\n                });\n            }),\n            report: b(\"User\", {\n                expire: !0,\n                triggers: \"report\",\n                triggerTarget: g\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \"report_spam\",\n                    params: [twttr.merge(a, {\n                        user_id: this.id\n                    }),],\n                    dataSource: [\"user\",]\n                });\n            }),\n            setNotificationsOn: b(\"User\", {\n                expire: !0,\n                writes: {\n                    notifications: !0\n                },\n                triggers: \"subscribe\",\n                triggerTarget: g\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \"friendships/update\",\n                    params: [{\n                        user_id: this.id,\n                        device: \"1\"\n                    },],\n                    dataSource: [\"user\",]\n                });\n            }),\n            setNotificationsOff: b(\"User\", {\n                expire: !0,\n                writes: {\n                    notifications: !1\n                },\n                triggers: \"unsubscribe\",\n                triggerTarget: g\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \"friendships/update\",\n                    params: [{\n                        user_id: this.id,\n                        device: \"0\"\n                    },],\n                    dataSource: [\"user\",]\n                });\n            }),\n            lists: b([\"List\",], function(a) {\n                d({\n                    options: a,\n                    url: \":user/lists\",\n                    params: [this.id,a,],\n                    dataSource: [\"lists_list\",\"lists\",]\n                });\n            }),\n            allLists: b([\"List\",], function(a) {\n                a.user_id = this.id, a.reverse = !0, d({\n                    options: a,\n                    url: \"lists/all\",\n                    params: [a,],\n                    dataSource: [\"lists_list\",]\n                });\n            }),\n            memberships: b([\"List\",], function(a) {\n                d({\n                    options: a,\n                    url: \":user/lists/memberships\",\n                    params: [this.id,a,],\n                    dataSource: [\"lists_list\",\"lists\",]\n                });\n            }),\n            subscriptions: b([\"List\",], function(a) {\n                d({\n                    options: a,\n                    url: \":user/lists/subscriptions\",\n                    params: [this.id,a,],\n                    dataSource: [\"lists_list\",\"lists\",]\n                });\n            }),\n            contributors: b([\"User\",], function(a) {\n                d({\n                    options: a,\n                    url: \"users/contributors\",\n                    params: [{\n                        id: this.id\n                    },],\n                    dataSource: [\"\",]\n                });\n            })\n        }).mixin(twttr.anywhere.api.mixins.phoenix.User);\n        twttr.klass(\"twttr.anywhere.api.models.CurrentUser\", function(a) {\n            twttr.anywhere.api.models.User.call(this, a);\n            var b = this;\n            this.lists.create = function() {\n                return b.constructor.prototype.lists.create.apply(b, arguments);\n            };\n        }).subclassOf(twttr.anywhere.api.models.User).statics({\n            _eventing: twttr.aug({\n            }, twttr.EventProvider)\n        }).methods({\n            recommendedUsers: c([\"UserRecommendation\",], function(a) {\n                return twttr.anywhere.api.models.User.recommendedUsers(a);\n            }),\n            recommendedUsers2: c([\"UserRecommendation\",], function(a) {\n                return twttr.anywhere.api.models.User.recommendedUsers2(a);\n            }),\n            inboundActivity: b([\"Activity\",], function(a) {\n                d({\n                    options: a,\n                    url: \"activity/activity_of_me\",\n                    params: [a,],\n                    dataSource: [\"\",]\n                });\n            }),\n            networkActivity: b([\"Activity\",], function(a) {\n                d({\n                    options: a,\n                    url: \"activity/activity_by_people_i_follow\",\n                    params: [a,],\n                    dataSource: [\"\",]\n                });\n            }),\n            directMessages: b([\"DirectMessage\",], function(a) {\n                ((twttr.is.def(a.include_entities) || (a.include_entities = twttr.anywhere.api.config.includeEntities))), d({\n                    options: a,\n                    url: \"direct_messages\",\n                    params: [a,],\n                    dataSource: [\"direct_messages\",]\n                });\n            }),\n            dms: c([\"DirectMessage\",], function(a) {\n                return this.directMessages(a);\n            }),\n            conversations: b([\"Conversation\",], function(a) {\n                d({\n                    options: a,\n                    url: \"direct_messages/conversations\",\n                    params: [a,],\n                    dataSource: [\"\",]\n                });\n            }),\n            conversationWith: b([\"DirectMessage\",], function(a) {\n                d({\n                    options: a,\n                    url: \"direct_messages/conversation_with\",\n                    params: [a,],\n                    dataSource: [\"\",]\n                });\n            }),\n            _isFollowing: function(a, b, c) {\n                twttr.anywhere.api.util.makeRemoteRequest(\"friendships/exists\", [{\n                    user_a: a,\n                    user_b: b\n                },], {\n                    success: c.success,\n                    error: c.error\n                });\n            },\n            isFollowing: function(a, b) {\n                b = twttr.anywhere.api.util.optify(b);\n                var c = twttr.anywhere.api.models.User.identify(a);\n                ((((this.constructor.isCacheable() && !((a instanceof twttr.anywhere.api.models.User)))) && (a = this.constructor._cache.get(c))));\n                if (((a instanceof twttr.anywhere.api.models.User))) {\n                    b.success(a.following);\n                    return;\n                }\n            ;\n            ;\n                this._isFollowing(this.id, c, b);\n            },\n            receivedMessages: c([\"DirectMessage\",], function(a) {\n                return this.directMessages(a);\n            }),\n            sentMessages: b([\"DirectMessage\",], function(a) {\n                ((twttr.is.def(a.include_entities) || (a.include_entities = twttr.anywhere.api.config.includeEntities))), d({\n                    options: a,\n                    url: \"direct_messages/sent\",\n                    params: [a,],\n                    dataSource: [\"direct_messages\",]\n                });\n            }),\n            homeTimeline: b([\"Status\",], function(a) {\n                var b = \"statuses/home_timeline\";\n                ((twttr.is.def(a.include_entities) || (a.include_entities = twttr.anywhere.api.config.includeEntities))), ((a.withoutRetweets && (b = \"statuses/friends_timeline\"))), d({\n                    options: a,\n                    url: b,\n                    params: [a,],\n                    dataSource: [\"statuses\",]\n                });\n            }),\n            mentions: b([\"Status\",], function(a) {\n                d({\n                    options: a,\n                    url: \"statuses/mentions\",\n                    params: [a,],\n                    dataSource: [\"statuses\",]\n                });\n            }),\n            _retweets: b([\"Status\",], function(a, b) {\n                d({\n                    options: b,\n                    url: a,\n                    params: [b,],\n                    dataSource: [\"statuses\",]\n                });\n            }),\n            trendLocation: b([\"Location\",], function(a) {\n                d({\n                    options: a,\n                    url: \"account/settings\",\n                    params: [],\n                    dataSource: [\"\",\"trend_location\",]\n                });\n            }),\n            setTrendLocation: b([\"Location\",], {\n                triggers: \"changedLocation\"\n            }, function(a, b, c) {\n                var e = {\n                    trend_location_woeid: a\n                };\n                ((b && (e.personalized_trends = b))), d({\n                    options: c,\n                    url: \"account/settings/create\",\n                    params: [e,],\n                    dataSource: [\"\",\"trend_location\",]\n                });\n            }),\n            setGeoEnabled: function(a, b) {\n                var c = this, e = b.success;\n                b.success = function() {\n                    c.sync(\"geoEnabled\", a), ((e && e.apply(c, arguments)));\n                }, d({\n                    options: b,\n                    url: \"account/settings/create\",\n                    params: [{\n                        geo_enabled: a\n                    },],\n                    dataSource: [\"\",\"geo_enabled\",]\n                });\n            },\n            setLanguage: b([\"Language\",], function(a, b) {\n                d({\n                    options: b,\n                    url: \"account/settings/create\",\n                    params: [{\n                        lang: a\n                    },],\n                    dataSource: []\n                });\n            }),\n            retweeting: c([\"Status\",], function(a) {\n                return this._retweets(\"statuses/retweeted_by_me\", a);\n            }),\n            retweets: c([\"Status\",], function(a) {\n                return this._retweets(\"statuses/retweeted_to_me\", a);\n            }),\n            retweeted: c([\"Status\",], function(a) {\n                return this._retweets(\"statuses/retweets_of_me\", a);\n            }),\n            blocks: b([\"User\",], function(a) {\n                d({\n                    options: a,\n                    url: \"blocks/blocking\",\n                    params: [a,],\n                    dataSource: [\"users\",]\n                });\n            }),\n            lists: c([\"List\",], function(a) {\n                return this.constructor.uber.lists.call(this, a);\n            }),\n            friends: c([\"User\",], function(a) {\n                return this.constructor.uber.friends.call(this, a);\n            }),\n            isBlocking: function(a, b) {\n                b = twttr.anywhere.api.util.optify(b);\n                var c = twttr.anywhere.api.models.User.identify(a);\n                twttr.anywhere.api.util.makeRemoteRequest(\"blocks/exists\", [{\n                    user_id: c\n                },], {\n                    success: function(a) {\n                        b.success(((a.user ? !0 : !1)));\n                    },\n                    error: function(a) {\n                        ((((a.JSBNG__status == 404)) ? b.success(!1) : b.error(a)));\n                    }\n                });\n            },\n            update: b(\"User\", {\n                expire: !0,\n                triggers: \"update\",\n                triggeredBy: \"User\"\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \"account/update_profile\",\n                    params: [a,],\n                    dataSource: [\"user\",]\n                });\n            }),\n            profileImage: b(undefined, function(a, b) {\n                d({\n                    options: b,\n                    url: \"users/profile_image/:screen_name\",\n                    params: [a,twttr.merge({\n                        redirect: !1\n                    }, b),],\n                    dataSource: [\"\",]\n                });\n            }),\n            savedSearches: b([\"SavedSearch\",], function(a) {\n                d({\n                    options: a,\n                    url: \"saved_searches\",\n                    params: [],\n                    dataSource: [\"saved_searches\",]\n                });\n            }),\n            searches: c([\"SavedSearch\",], function(a) {\n                return this.savedSearches(a);\n            }),\n            logout: function(a) {\n                parent.twttr.anywhere.signOut();\n            }\n        }), twttr.augmentObject(twttr.anywhere.api.models.User.prototype.lists, {\n            JSBNG__find: b(\"List\", {\n                cacheLookup: function(a, b) {\n                    var c = twttr.API.List._cache.get(a);\n                    return ((c ? c : !1));\n                }\n            }, function(a, b) {\n                b = twttr.anywhere.api.util.optify(b), ((twttr.is.string(a) ? b.slug = a : b.list_id = a)), d({\n                    options: b,\n                    url: \"lists/show\",\n                    params: [twttr.merge({\n                        owner_id: this.id\n                    }, b),],\n                    dataSource: [\"list\",]\n                });\n            })\n        }), twttr.augmentObject(twttr.anywhere.api.models.CurrentUser.prototype.lists, {\n            create: b(\"List\", {\n                triggers: \"create\",\n                triggeredBy: \"List\"\n            }, function(a, b) {\n                d({\n                    options: b,\n                    url: \":user/lists/create\",\n                    params: [this.id,twttr.merge(b, {\n                        JSBNG__name: a,\n                        send_error_codes: !0\n                    }),],\n                    dataSource: [\"list\",]\n                });\n            })\n        }), twttr.augmentObject(twttr.anywhere.api.models.CurrentUser.prototype.savedSearches, {\n            JSBNG__find: b(\"SavedSearch\", function(a, b) {\n                d({\n                    options: b,\n                    url: \"saved_searches/show/:id\",\n                    params: [a,b,],\n                    dataSource: [\"saved_search\",]\n                });\n            }),\n            create: b(\"SavedSearch\", {\n                triggers: \"create\",\n                triggeredBy: \"SavedSearch\"\n            }, function(a, b) {\n                d({\n                    options: b,\n                    url: \"saved_searches/create\",\n                    params: [{\n                        query: a\n                    },],\n                    dataSource: [\"saved_search\",]\n                });\n            })\n        }), twttr.augmentObject(twttr.anywhere.api.models.CurrentUser.prototype.friends, {\n            pending: b(undefined, function(a) {\n                var b = e([\"cursor\",], a);\n                d({\n                    options: a,\n                    url: \"friendships/incoming\",\n                    params: [b,],\n                    dataSource: [\"\",\"ids\",]\n                });\n            })\n        }), twttr.anywhere.api.models.CurrentUser.prototype._name = function() {\n            return \"current_user\";\n        }, twttr.anywhere.api.models.CurrentUser.identify = twttr.anywhere.api.models.User.identify, twttr.anywhere.api.models.CurrentUser._registry = twttr.anywhere.api.models.User._registry, twttr.anywhere.api.models.CurrentUser._extensionMethods = twttr.anywhere.api.models.User._extensionMethods, twttr.anywhere.api.models.CurrentUser.isCacheable = twttr.anywhere.api.models.User.isCacheable, ((twttr.anywhere.api.models.CurrentUser.isCacheable() && (twttr.anywhere.api.models.CurrentUser._cache = twttr.anywhere.api.models.User._cache)));\n        var k = [\"trigger\",\"bind\",\"_bind\",\"unbind\",\"_unbind\",\"JSBNG__one\",\"_bindWrapper\",];\n        for (var l = 0, m = k.length; ((l < m)); ++l) {\n            twttr.anywhere.api.models.CurrentUser[k[l]] = twttr.anywhere.api.models.User[k[l]];\n        ;\n        };\n    ;\n        var n = [\"block\",\"unblock\",\"report\",\"follow\",\"unfollow\",\"setNotificationsOn\",\"setNotificationsOff\",];\n        for (var l = 0, m = n.length; ((l < m)); ++l) {\n            twttr.anywhere.api.models.CurrentUser.prototype[n[l]] = f;\n        ;\n        };\n    ;\n        twttr.anywhere.api.models.CurrentUser.mixin(twttr.anywhere.api.mixins.phoenix.CurrentUser), a(j);\n    });\n});\nprovide(\"bluejs/models/direct_message\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.defaultTrigger, f = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.DirectMessage\", function(a) {\n            ((a && twttr.anywhere.api.util.useStringIdentifier(a, \"id\"))), this.constructor.uberclass.call(this, a);\n        }).belongsTo(\"User\", \"sender\").belongsTo(\"User\", \"recipient\").statics({\n            send: b(\"DirectMessage\", {\n                triggers: \"send\",\n                triggerSource: e,\n                triggerTarget: function(a) {\n                    return a.recipient;\n                }\n            }, function(a, b, c) {\n                d({\n                    options: c,\n                    url: \"direct_messages/new\",\n                    params: [{\n                        user: twttr.anywhere.api.models.User.identify(a),\n                        text: b\n                    },],\n                    dataSource: [\"direct_message\",]\n                });\n            })\n        }).methods({\n            destroy: b(\"DirectMessage\", {\n                triggers: \"delete\",\n                triggerTarget: e\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \"direct_messages/destroy\",\n                    params: [{\n                        id: this.id\n                    },],\n                    dataSource: [\"direct_message\",]\n                });\n            })\n        });\n        a(f);\n    });\n});\nprovide(\"bluejs/models/saved_search\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.defaultTrigger, f = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.SavedSearch\").methods({\n            destroy: b(\"SavedSearch\", {\n                triggers: \"delete\",\n                triggerTarget: e\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \"saved_searches/destroy/:id\",\n                    params: [this.id,a,],\n                    dataSource: [\"saved_search\",]\n                });\n            }),\n            results: b([\"SearchResult\",], function(a) {\n                a.q = this.query, d({\n                    options: a,\n                    url: \"search\",\n                    params: [a,],\n                    dataSource: [\"\",\"results\",]\n                });\n            })\n        });\n        a(f);\n    });\n});\nprovide(\"bluejs/models/list\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.filterOptions, f = twttr.anywhere.api.util.defaultTrigger, g = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.List\").cache({\n            keys: [{\n                JSBNG__name: \"id\",\n                type: \"number\"\n            },],\n            shouldCacheAssociated: !1\n        }).belongsTo(\"User\").methods({\n            subscribe: b(\"List\", {\n                expire: !0,\n                triggers: \"follow\",\n                triggerTarget: f,\n                writes: {\n                    subscriberCount: function() {\n                        return ((this.subscriberCount + 1));\n                    }\n                }\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \":user/:list_id/subscribers/create\",\n                    params: [this.user.id,this.id,{\n                    },],\n                    dataSource: [\"list\",]\n                });\n            }),\n            follow: c(\"List\", function(a) {\n                return this.subscribe(a);\n            }),\n            unsubscribe: b(\"List\", {\n                expire: !0,\n                triggers: \"unfollow\",\n                triggerTarget: f,\n                writes: {\n                    subscriberCount: function() {\n                        return ((this.subscriberCount - 1));\n                    }\n                }\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \":user/:id/subscribers/destroy\",\n                    params: [this.user.id,this.id,{\n                    },],\n                    dataSource: [\"list\",]\n                });\n            }),\n            unfollow: c(\"List\", function(a) {\n                return this.unsubscribe(a);\n            }),\n            add: b(\"List\", {\n                expire: !0,\n                triggers: \"add\",\n                triggerTarget: f,\n                writes: {\n                    memberCount: function() {\n                        return this.memberCount;\n                    }\n                }\n            }, function(a, b) {\n                d({\n                    options: b,\n                    url: \"lists/members/create\",\n                    params: [{\n                        list_id: this.id,\n                        user_id: a.id\n                    },],\n                    dataSource: [\"list\",]\n                });\n            }),\n            remove: b(\"List\", {\n                expire: !0,\n                triggers: \"remove\",\n                triggerTarget: f,\n                writes: {\n                    memberCount: function() {\n                        return ((this.memberCount - 1));\n                    }\n                }\n            }, function(a, b) {\n                d({\n                    options: b,\n                    url: \"lists/members/destroy\",\n                    params: [{\n                        list_id: this.id,\n                        user_id: a.id\n                    },],\n                    dataSource: [\"list\",]\n                });\n            }),\n            owner: function() {\n                return this.user;\n            },\n            isMember: function(a, b) {\n                b = twttr.anywhere.api.util.optify(b);\n                var c = b.error;\n                b.error = function(a) {\n                    ((((((a.JSBNG__status === 404)) && a.reason.match(\"not a member\"))) ? b.success(!1) : ((c && c(a)))));\n                };\n                var e = b.success;\n                b.success = function(a) {\n                    ((a.screenName ? e(!0) : e(!1)));\n                }, d({\n                    options: b,\n                    url: \":user/:list_id/members/:id\",\n                    params: [this.user.id,this.id,twttr.anywhere.api.models.User.identify(a),{\n                    },],\n                    cast: twttr.anywhere.api.models.User,\n                    dataSource: [\"user\",]\n                });\n            },\n            isSubscriber: function(a, b) {\n                b = twttr.anywhere.api.util.optify(b);\n                var c = b.error;\n                b.error = function(a) {\n                    ((((((a.JSBNG__status === 404)) && a.reason.match(\"not a subscriber\"))) ? b.success(!1) : ((c && c(a)))));\n                };\n                var e = b.success;\n                b.success = function(a) {\n                    ((a.screenName ? e(!0) : e(!1)));\n                }, d({\n                    options: b,\n                    url: \":user/:list_id/subscribers/:id\",\n                    params: [this.user.id,this.id,twttr.anywhere.api.models.User.identify(a),{\n                    },],\n                    cast: twttr.anywhere.api.models.User,\n                    dataSource: [\"user\",]\n                });\n            },\n            destroy: b(\"List\", {\n                expire: !0,\n                cache: !1,\n                triggers: \"delete\",\n                triggerTarget: f\n            }, function(a) {\n                d({\n                    options: a,\n                    url: \"lists/destroy\",\n                    params: [{\n                        list_id: this.id\n                    },],\n                    dataSource: [\"list\",]\n                });\n            }),\n            update: b(\"List\", {\n                expire: !0,\n                triggers: \"update\",\n                triggerTarget: f\n            }, function(a) {\n                a = twttr.anywhere.api.util.optify(a);\n                var b = e([\"JSBNG__name\",\"description\",\"mode\",], a);\n                d({\n                    options: a,\n                    url: \"lists/update\",\n                    params: [twttr.merge({\n                        list_id: this.id,\n                        send_error_codes: !0\n                    }, b),],\n                    dataSource: [\"list\",]\n                });\n            }),\n            statuses: b([\"Status\",], function(a) {\n                a = twttr.anywhere.api.util.optify(a), ((twttr.is.def(a.include_entities) || (a.include_entities = twttr.anywhere.api.config.includeEntities))), d({\n                    options: a,\n                    url: \"lists/statuses\",\n                    params: [twttr.merge({\n                        list_id: this.id\n                    }, a),],\n                    dataSource: [\"statuses\",]\n                });\n            }),\n            subscribers: b([\"User\",], function(a) {\n                d({\n                    options: a,\n                    url: \":user/:list_id/subscribers\",\n                    params: [this.user.id,this.id,a,],\n                    dataSource: [\"users_list\",\"users\",]\n                });\n            }),\n            followers: c([\"User\",], function(a) {\n                return this.subscribers(a);\n            }),\n            members: b([\"User\",], function(a) {\n                d({\n                    options: a,\n                    url: \":user/:list_id/members\",\n                    params: [this.user.id,this.id,a,],\n                    dataSource: [\"users_list\",\"users\",]\n                });\n            }),\n            following: c([\"User\",], function(a) {\n                return this.members(a);\n            })\n        });\n        a(g);\n    });\n});\nprovide(\"bluejs/models/location\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.filterOptions, f = twttr.anywhere.api.cache, g = twttr.anywhere.api.util.noop, i = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Location\").uniqueKey(\"woeid\").statics({\n            trends: b([\"Trend\",], function(a, b) {\n                var c = this.identify(a);\n                d({\n                    options: b,\n                    url: \"trends/:woeid\",\n                    params: [c,b,],\n                    dataSource: [\"\",]\n                });\n            })\n        }).methods({\n            trends: c([\"Trend\",], function(a) {\n                return this.constructor.trends(this.woeid, a);\n            })\n        });\n        a(i);\n    });\n});\nprovide(\"bluejs/models/trend\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.filterOptions, f = twttr.anywhere.api.cache, g = twttr.anywhere.api.util.noop, i = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Trend\").uniqueKey(\"query\").statics({\n            locations: b([\"Location\",], function(a) {\n                var b = e([\"lat\",\"long\",\"lang\",], a);\n                d({\n                    options: a,\n                    url: \"trends/available\",\n                    params: [b,],\n                    dataSource: [\"\",]\n                });\n            }),\n            current: b([\"Trend\",], function(a) {\n                d({\n                    options: a,\n                    url: \"trends/current\",\n                    params: [a,],\n                    dataSource: [\"\",\"trends\",\"current_trends\",]\n                });\n            })\n        });\n        a(i);\n    });\n});\nprovide(\"bluejs/models/status\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.defaultTrigger, f = twttr.anywhere.api.util.filterOptions, g = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Status\", function(a) {\n            ((a && (a = twttr.anywhere.api.util.normalizePromotedTweet(a), twttr.anywhere.api.util.useStringIdentifier(a, \"id\"), twttr.anywhere.api.util.useStringIdentifier(a, \"in_reply_to_status_id\"), twttr.anywhere.api.util.useStringIdentifier(a.current_user_retweet, \"id\"), a.text = twttr.anywhere.api.util.sanitize(a.text)))), this.constructor.uberclass.call(this, a);\n        }).cache({\n            keys: [{\n                JSBNG__name: \"id\",\n                type: \"string\"\n            },],\n            cacheAssociated: !0\n        }).belongsTo(\"User\").belongsTo(\"Status\", \"retweetedStatus\").hasOne(\"Place\").extend(function() {\n            this.isRetweet = !!this.retweetedStatus;\n        }).statics({\n            JSBNG__find: b(\"Status\", {\n                cacheLookup: function(a, b) {\n                    var c = this._cache.get(a);\n                    return ((c ? c : !1));\n                }\n            }, function(a, b) {\n                var c = f([\"trim_user\",\"include_entities\",\"contributor_details\",\"include_cards\",], b);\n                ((((twttr.decider.isAvailable(\"platform_enable_cards\") && !twttr.is.def(c.include_cards))) && (c.include_cards = 1))), ((twttr.is.def(c.include_entities) || (c.include_entities = twttr.anywhere.api.config.includeEntities))), ((twttr.is.def(c.contributor_details) || (c.contributor_details = !0))), ((twttr.is.def(c.include_entities) || (c.include_entities = 1))), d({\n                    options: b,\n                    url: \"statuses/show\",\n                    params: [twttr.merge(c, {\n                        id: a\n                    }),],\n                    dataSource: [\"JSBNG__status\",]\n                });\n            }),\n            unretweet: b(\"Status\", {\n                expire: !0,\n                cache: !1,\n                triggers: \"unretweet\",\n                triggerTarget: function(a) {\n                    return \"current_user\";\n                }\n            }, function(a, b) {\n                var c = this.identify(a), e = b.success;\n                b.success = function(a) {\n                    a.expire(), e.apply(a, arguments);\n                }, d({\n                    options: b,\n                    url: \"statuses/destroy\",\n                    params: [{\n                        id: c\n                    },],\n                    dataSource: [\"JSBNG__status\",]\n                });\n            }),\n            update: b(\"Status\", {\n                triggers: \"update\",\n                triggerTarget: e\n            }, function(a, b) {\n                b.include_entities = !0, ((twttr.decider.isAvailable(\"platform_enable_cards\") && (b.include_cards = 1))), b.JSBNG__status = a, d({\n                    options: b,\n                    url: \"statuses/update\",\n                    params: [b,],\n                    dataSource: [\"JSBNG__status\",]\n                });\n            }),\n            updateWithMedia: b(\"Status\", {\n                triggers: \"update_with_media\",\n                triggerTarget: e\n            }, function(a, b) {\n                b.include_entities = !0, ((twttr.decider.isAvailable(\"platform_enable_cards\") && (b.include_cards = 1))), b.JSBNG__status = a, d({\n                    options: b,\n                    url: \"statuses/update_with_media\",\n                    params: [b,],\n                    dataSource: [\"JSBNG__status\",]\n                });\n            }),\n            publicTimeline: b([\"Status\",], function(a) {\n                d({\n                    options: a,\n                    url: \"statuses/public_timeline\",\n                    params: [],\n                    dataSource: [\"statuses\",]\n                });\n            }),\n            networkTimeline: b([\"Status\",], function(a) {\n                d({\n                    options: a,\n                    url: \"statuses/network_timeline\",\n                    params: [a,],\n                    dataSource: [\"statuses\",]\n                });\n            }),\n            promotedHomeTimeline: b([\"Status\",], function(a) {\n                d({\n                    options: a,\n                    url: \"promoted_content/home_timeline\",\n                    params: [],\n                    dataSource: [\"\",\"promoted_tweets\",]\n                });\n            }),\n            retweet: b(\"Status\", {\n                triggers: \"retweet\",\n                triggerSource: function(a) {\n                    return ((((a instanceof twttr.anywhere.api.models.Base)) ? a : ((\"status_\" + a))));\n                },\n                triggerTarget: function(a) {\n                    return \"current_user\";\n                }\n            }, function(a, b) {\n                var c = this.identify(a);\n                d({\n                    options: b,\n                    url: \"statuses/retweet/:id\",\n                    params: [c,b,],\n                    dataSource: [\"JSBNG__status\",]\n                });\n            }),\n            favorite: b(\"Status\", {\n                triggers: \"favorite\",\n                triggerSource: function(a) {\n                    return ((((a instanceof twttr.anywhere.api.models.Base)) ? a : ((\"status_\" + a))));\n                },\n                triggerTarget: function(a) {\n                    return \"current_user\";\n                }\n            }, function(a, b) {\n                var c = this.identify(a);\n                d({\n                    options: b,\n                    url: \"favorites/create/:id\",\n                    params: [c,b,],\n                    dataSource: [\"JSBNG__status\",]\n                });\n            }),\n            unfavorite: b(\"Status\", {\n                triggers: \"unfavorite\",\n                triggerSource: function(a) {\n                    return ((((a instanceof twttr.anywhere.api.models.Base)) ? a : ((\"status_\" + a))));\n                },\n                triggerTarget: function(a) {\n                    return \"current_user\";\n                }\n            }, function(a, b) {\n                var c = this.identify(a);\n                d({\n                    options: b,\n                    url: \"favorites/destroy/:id\",\n                    params: [c,b,],\n                    dataSource: [\"JSBNG__status\",]\n                });\n            }),\n            reply: c(\"Status\", function(a, b, c) {\n                var d = this.identify(a);\n                return c = twttr.merge(twttr.anywhere.api.util.optify(c), {\n                    in_reply_to_status_id: d\n                }), this.update(b, c);\n            }),\n            search: b([\"SearchResult\",], function(a, b) {\n                d({\n                    options: b,\n                    url: \"search\",\n                    params: [twttr.merge({\n                        q: a\n                    }, b),],\n                    dataSource: [\"\",\"results\",]\n                });\n            })\n        }).methods(twttr.anywhere.api.mixins.StatusActions).methods({\n            bind: twttr.anywhere.api.util.bindMethod,\n            activity: b([\"Activity\",], function(a) {\n                d({\n                    options: a,\n                    url: \"statuses/:id/activity\",\n                    params: [this.id,],\n                    dataSource: [\"\",]\n                });\n            }),\n            summary: b(undefined, function(a) {\n                d({\n                    options: a,\n                    url: \"statuses/:id/activity/summary\",\n                    params: [this.id,],\n                    dataSource: [\"\",]\n                });\n            }),\n            destroy: b(\"Status\", {\n                expire: !0,\n                cache: !1,\n                triggers: \"delete\",\n                triggerTarget: function(a) {\n                    return \"current_user\";\n                }\n            }, function(a) {\n                var b = this, c = a.success;\n                a.success = function() {\n                    b.expire(), c.apply(b, arguments);\n                }, d({\n                    options: a,\n                    url: \"statuses/destroy\",\n                    params: [{\n                        id: this.id\n                    },],\n                    dataSource: [\"JSBNG__status\",]\n                });\n            }),\n            retweets: b([\"Status\",], function(a) {\n                d({\n                    options: a,\n                    url: \"statuses/retweets/:id\",\n                    params: [this.id,a,],\n                    dataSource: [\"JSBNG__status\",]\n                });\n            }),\n            retweeters: b([\"User\",], function(a) {\n                d({\n                    options: a,\n                    url: \"statuses/:id/retweeted_by\",\n                    params: [this.id,a,],\n                    dataSource: [\"users\",]\n                });\n            }),\n            contributor: c([\"User\",], function(a) {\n                var b = this.data(\"contributors\");\n                if (((((b && twttr.is.array(b))) && ((b.length === 1))))) {\n                    return twttr.anywhere.api.models.User.JSBNG__find(this.data(\"contributors\")[0], a);\n                }\n            ;\n            ;\n                a.success(null);\n            }),\n            inReplyToUser: c(\"User\", function(a) {\n                a = twttr.anywhere.api.util.optify(a);\n                if (this.inReplyToUserId) {\n                    return twttr.anywhere.api.models.User.JSBNG__find(this.inReplyToUserId, a);\n                }\n            ;\n            ;\n                a.success(null);\n            }),\n            inReplyTo: c(\"Status\", function(a) {\n                a = twttr.anywhere.api.util.optify(a);\n                if (this.inReplyToStatusId) {\n                    return twttr.anywhere.api.models.Status.JSBNG__find(this.inReplyToStatusId, a);\n                }\n            ;\n            ;\n                a.success(null);\n            }),\n            flag: b(undefined, function(a) {\n                var b, c = {\n                    id: this.id\n                };\n                ((a.isOurTweet ? (b = \"statuses/update_possibly_sensitive\", c.possibly_sensitive = ((((typeof a.possibly_sensitive == \"undefined\")) || a.possibly_sensitive))) : b = \"statuses/flag_possibly_sensitive\")), d({\n                    options: a,\n                    url: b,\n                    params: [c,],\n                    dataSource: [\"JSBNG__status\",]\n                });\n            }),\n            oembed: b(undefined, function(a) {\n                var b = {\n                    url: ((((((\"http://twitter.com/\" + this.user.status_name)) + \"/statuses/\")) + this.id)),\n                    lang: a.lang,\n                    target: a.target,\n                    align: a.align\n                };\n                d({\n                    options: a,\n                    url: \"statuses/oembed\",\n                    params: [b,],\n                    dataSource: [\"JSBNG__status\",]\n                });\n            })\n        }).mixin(twttr.anywhere.api.mixins.phoenix.Status);\n        a(g);\n    });\n});\nprovide(\"bluejs/models/promptbird\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.callMethod, d = null, e = function(a, b) {\n            a = ((a || {\n            })), c({\n                options: b,\n                url: \"users/get_prompt\",\n                params: [a,],\n                dataSource: [\"\",]\n            });\n        }, f = b(d, e), g = function(a, b) {\n            a = ((a || {\n            })), c({\n                options: b,\n                url: \"users/dismiss_prompt\",\n                params: [a,],\n                dataSource: [\"\",]\n            });\n        }, i = b(d, g), j = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Promptbird\").statics({\n            getPrompt: f,\n            dismissPrompt: i\n        });\n        a(j);\n    });\n});\nprovide(\"bluejs/models/search_result\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.aliasMethod, c = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.SearchResult\").methods(twttr.anywhere.api.mixins.StatusActions);\n        a(c);\n    });\n});\nprovide(\"bluejs/models/place\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.filterOptions, f = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Place\").belongsTo(\"Place\", \"contained_within\").statics({\n            JSBNG__find: b(\"Place\", function(a, b) {\n                d({\n                    options: b,\n                    url: \"geo/id/:id\",\n                    params: [a,b,],\n                    dataSource: [\"place\",]\n                });\n            }),\n            search: b([\"Place\",], function(a) {\n                var b = [\"lat\",\"long\",\"lon\",\"query\",\"ip\",\"granularity\",\"accuracy\",\"autocomplete\",\"max_results\",\"contained_within\",\"attribute:street_address\",\"require_activity\",], c = e(b, a);\n                d({\n                    options: a,\n                    url: \"geo/search\",\n                    params: [c,],\n                    dataSource: [\"\",\"result\",\"places\",]\n                });\n            }),\n            reverseGeocode: b([\"Place\",], function(a, b, c) {\n                var f = [\"long\",\"accuracy\",\"granularity\",\"max_results\",], g = e(f, c);\n                ((g[\"long\"] && (b = g[\"long\"], delete g[\"long\"]))), d({\n                    options: c,\n                    url: \"geo/reverse_geocode\",\n                    params: [twttr.merge({\n                    }, g, {\n                        lat: a,\n                        lon: b\n                    }),],\n                    dataSource: [\"\",\"result\",\"places\",]\n                });\n            }),\n            create: b(\"Place\", function(a, b, c, f, g, i) {\n                var j = [\"long\",\"attribute:street_address\",\"accuracy\",], k = e(j, i);\n                ((k[\"long\"] && (c = k[\"long\"], delete k[\"long\"]))), d({\n                    options: i,\n                    url: \"geo/place\",\n                    params: [twttr.merge({\n                    }, k, {\n                        token: a,\n                        lat: b,\n                        lon: c,\n                        JSBNG__name: f,\n                        contained_within: g\n                    }),],\n                    dataSource: [\"\",]\n                });\n            }),\n            similar: b([\"Place\",], function(a, b, c, f) {\n                var g = [\"long\",\"contained_within\",\"attribute:street_address\",\"accuracy\",], i = e(g, f);\n                ((i[\"long\"] && (b = i[\"long\"], delete i[\"long\"]))), d({\n                    options: f,\n                    url: \"geo/similar_places\",\n                    params: [twttr.merge({\n                    }, i, {\n                        lat: a,\n                        lon: b,\n                        JSBNG__name: c\n                    }),],\n                    dataSource: [\"\",\"result\",\"places\",]\n                });\n            })\n        });\n        a(f);\n    });\n});\nprovide(\"bluejs/models/user_recommendation\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.callMethod, d = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.UserRecommendation\").hasOne(\"User\").hasMany(\"User\", \"connections\").statics({\n            hide: b([\"UserRecommendation\",], function(a, b, d) {\n                d.recommended_user_id = a, d.token = b, c({\n                    options: d,\n                    url: \"users/recommendations/hide\",\n                    params: [d,],\n                    dataSource: [\"\",]\n                });\n            })\n        }).mixin(twttr.anywhere.api.mixins.phoenix.RateUserRecommendation);\n        a(d);\n    });\n});\nprovide(\"bluejs/models/suggestion_category\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util, c = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.SuggestionCategory\").hasMany(\"SuggestionCategory\", \"categories\").hasMany(\"User\", \"users\").hasMany(\"User\", \"sample\").statics({\n            getAll: b.chainableMethod([\"SuggestionCategory\",], function(a) {\n                a.localize = !0, b.callMethod({\n                    options: a,\n                    url: \"users/suggestions\",\n                    params: [a,],\n                    dataSource: [\"\",]\n                });\n            }),\n            randomSample: b.chainableMethod([\"User\",], function(a) {\n                a.localize = !0, b.callMethod({\n                    options: a,\n                    url: \"users/suggestions/random\",\n                    params: [a,],\n                    dataSource: [\"\",]\n                });\n            })\n        }).methods({\n            members: b.chainableMethod([\"User\",], function(a) {\n                a.localize = !0, b.callMethod({\n                    options: a,\n                    url: \"users/suggestions/:slug/members\",\n                    params: [this.slug,a,],\n                    dataSource: [\"\",]\n                });\n            })\n        });\n        a(c);\n    });\n});\nprovide(\"bluejs/models/related_tweets\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.RelatedTweets\").hasMany(\"RelatedResult\", \"results\");\n        a(b);\n    });\n});\nprovide(\"bluejs/models/related_result\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.RelatedResult\").hasOne(\"Status\", \"value\");\n        a(b);\n    });\n});\nprovide(\"bluejs/util/promoted_content\", function(a) {\n    using(\"constants\").as(function(b, c) {\n        var d = twttr.anywhere.api.util.filterOptions, e = c.promotedContent.linkType, f = twttr.klass(\"twttr.anywhere.api.util.PromotedContent\", twttr.anywhere.api.util.noop).statics({\n            loggedImpressions: {\n            },\n            logImpression: function(a) {\n                ((this.loggedImpressions[a] || (this.loggedImpressions[a] = !0, this._logImpressionIdEvent(a, e.DISPLAYED))));\n            },\n            logProfileImageClick: function(a) {\n                this._logImpressionIdEvent(a, e.PROFILE_PIC);\n            },\n            logScreenNameClick: function(a) {\n                this._logImpressionIdEvent(a, e.SCREEN_NAME);\n            },\n            logPermalinkClick: function(a) {\n                this._logImpressionIdEvent(a, e.PERMALINK);\n            },\n            logDismissUser: function(a) {\n                this._logImpressionIdEvent(a, e.DISMISS_WITHOUT_REASON);\n            },\n            logShowDetails: function(a) {\n                this._logImpressionIdEvent(a, e.DETAIL);\n            },\n            logHashtagClick: function(a, b) {\n                b = b.replace(/^#/, \"\"), this._logImpressionIdEvent(a, e.HASHTAG, {\n                    q: b\n                });\n            },\n            logUserMentionClick: function(a, b) {\n                this._logImpressionIdEvent(a, e.USER_NAME, {\n                    username: b\n                });\n            },\n            logUrlClick: function(a, b) {\n                this._logImpressionIdEvent(a, e.JSBNG__URL, {\n                    src: b\n                });\n            },\n            logDismissUninteresting: function(a) {\n                this._logImpressionIdEvent(a, e.DISMISS_UNINTERESTING);\n            },\n            logDismissRepetitive: function(a) {\n                this._logImpressionIdEvent(a, e.DISMISS_REPETITIVE);\n            },\n            logDismissSpam: function(a) {\n                this._logImpressionIdEvent(a, e.DISMISS_SPAM);\n            },\n            logDismissOther: function(a) {\n                this._logImpressionIdEvent(a, e.DISMISS_WITHOUT_REASON);\n            },\n            logFooterProfileClick: function(a) {\n                this._logImpressionIdEvent(a, e.FOOTER_PROFILE);\n            },\n            logTrendImpression: function(a, b) {\n                this._logPromotedTrendIdEvent(a, \"i\", b);\n            },\n            logTrendClick: function(a, b) {\n                this._logPromotedTrendIdEvent(a, \"c\", b);\n            },\n            feedback: function(a) {\n                var b = d([\"impression_id\",\"status_id\",\"reason\",\"comments\",], a);\n                callMethod({\n                    options: a,\n                    url: \"promoted_content/feedback\",\n                    params: [b,],\n                    dataSource: [\"\",]\n                });\n            },\n            _logPromotedTrendIdEvent: function(a, b, c) {\n                ((((a && b)) && (c = $.extend({\n                    promoted_trend_id: a\n                }, c), this._logEvent(b, c))));\n            },\n            _logImpressionIdEvent: function(a, b, c) {\n                ((((a && b)) && (c = $.extend({\n                    impression_id: a\n                }, c), this._logEvent(b, c))));\n            },\n            _logEvent: function(a, b) {\n                var c = ((((((((twttr.hosts.remote + \"/1/promoted_content/\")) + a)) + \"/log.png?\")) + $.param(b)));\n                (new JSBNG__Image).src = c;\n            }\n        });\n        twttr.klass(\"twttr.anywhere.api.util.PromotedStore\", twttr.anywhere.api.util.noop).statics({\n            get: function(a) {\n                return this._store()[a];\n            },\n            putStatus: function(a) {\n                var b = a.impressionId;\n                this._store()[b] = this._promotedDataForStatus(a);\n            },\n            putUser: function(a) {\n                var b = a.promotedContent.impression_id;\n                this._store()[b] = this._promotedDataForUser(a);\n            },\n            getPromotedUserInstance: function(a, b) {\n                var c = twttr.anywhere.api.util.protoExtend;\n                a = c(a), a.attributes = c(a.attributes), a.impressionId = b, a.attributes.impression_id = b;\n                var d = this.get(b);\n                return ((d && (a.promotedContent = d.promotedContent, a.attributes.promoted_content = d.promotedContent))), a;\n            },\n            getPromotedStatusInstance: function(a, b) {\n                var c = twttr.anywhere.api.util.protoExtend, d = this.get(b);\n                return a = c(a), a.impressionId = d.impressionId, a.experiments = d.experiments, a.attributes = c(a.attributes), a.attributes.impression_id = d.impressionId, a.attributes.experiments = d.experiments, a;\n            },\n            _promotedDataForStatus: function(a) {\n                return a = $.extend({\n                }, a), {\n                    impressionId: a.impressionId,\n                    experiments: a.experiments\n                };\n            },\n            _promotedDataForUser: function(a) {\n                return a = $.extend({\n                }, a), {\n                    promotedContent: a.promotedContent\n                };\n            },\n            _store: function() {\n                return this.store = ((this.store || {\n                })), this.store;\n            }\n        }), a(f);\n    });\n});\nprovide(\"bluejs/models/address_book\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.callMethod, d = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.AddressBook\").statics({\n            contactsServices: b(undefined, function(a) {\n                c({\n                    options: a,\n                    url: \"find_sources/contacts/services\",\n                    params: [a,],\n                    dataSource: [\"\",\"services\",]\n                });\n            }),\n            contactsMatches: b([\"User\",], function(a) {\n                c({\n                    options: a,\n                    url: \"find_sources/contacts/matches\",\n                    params: [a,],\n                    dataSource: [\"\",\"users\",]\n                });\n            }),\n            contactsOthers: b(\"\", function(a) {\n                c({\n                    options: a,\n                    url: \"find_sources/contacts/others\",\n                    params: [a,],\n                    dataSource: [\"\",\"contacts\",]\n                });\n            }),\n            followAllContacts: b(\"\", function(a) {\n                c({\n                    options: a,\n                    url: \"find_sources/contacts/follow_all\",\n                    params: [a,],\n                    dataSource: [\"\",]\n                });\n            }),\n            addContactsToList: b(\"\", function(a, b) {\n                c({\n                    options: b,\n                    url: \"find_sources/contacts/add_to_list\",\n                    params: [{\n                        list_id: a\n                    },],\n                    dataSource: [\"\",\"user_ids\",]\n                });\n            }),\n            sendInvitesByEmail: b(undefined, function(a, b) {\n                source = ((b && b.source)), c({\n                    options: b,\n                    url: \"users/send_invites_by_email\",\n                    params: [{\n                        addresses: a.join(\",\"),\n                        source: source\n                    },],\n                    dataSource: [\"\",]\n                });\n            })\n        });\n        a(d);\n    });\n});\nprovide(\"bluejs/models/promo\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.callMethod, d = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Promo\").statics({\n            JSBNG__random: b(undefined, function(a, b) {\n                c({\n                    options: b,\n                    url: \"promos/random_json_promo\",\n                    params: [a,],\n                    dataSource: [\"\",]\n                });\n            })\n        });\n        a(d);\n    });\n});\nprovide(\"bluejs/models/urls\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.callMethod, d = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Urls\").statics({\n            resolve: b(undefined, function(a, b) {\n                c({\n                    options: b,\n                    url: \"urls/resolve\",\n                    params: [{\n                        urls: a\n                    },],\n                    dataSource: [\"\",]\n                });\n            }),\n            shorten: b(undefined, function(a, b) {\n                c({\n                    options: b,\n                    url: \"urls/shorten\",\n                    params: [{\n                        url: a\n                    },],\n                    dataSource: [\"\",]\n                });\n            }),\n            shortenMultiple: b(undefined, function(a, b) {\n                c({\n                    options: b,\n                    url: \"urls/shorten_multiple\",\n                    params: [{\n                        urls: a\n                    },],\n                    dataSource: [\"\",]\n                });\n            })\n        });\n        a(d);\n    });\n});\nprovide(\"bluejs/models/blob\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.aliasMethod, c = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.JSBNG__Blob\").methods({\n            get: function(a) {\n                a(this);\n            }\n        });\n        a(c);\n    });\n});\nprovide(\"bluejs/models/device\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.callMethod, d = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Device\").statics({\n            list: b(null, function(a) {\n                c({\n                    options: a,\n                    url: \"devices/list\",\n                    params: [],\n                    dataSource: [\"\",]\n                });\n            }),\n            carriers: b(\"JSBNG__Blob\", function(a) {\n                c({\n                    options: a,\n                    url: \"devices/carriers\",\n                    params: [a,],\n                    dataSource: [\"carriers\",]\n                });\n            }),\n            create: b(null, function(a, b) {\n                c({\n                    options: b,\n                    url: \"devices/create\",\n                    params: [a,],\n                    dataSource: [\"\",]\n                });\n            }),\n            destroy: b(null, function(a, b) {\n                c({\n                    options: b,\n                    url: \"devices/destroy\",\n                    params: [{\n                        id: a\n                    },],\n                    dataSource: [\"\",]\n                });\n            })\n        });\n        a(d);\n    });\n});\nprovide(\"bluejs/models/search\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.defaultTrigger, f = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Search\", function(a) {\n            this.constructor.uberclass.call(this, a);\n        }).statics({\n            search: b(\"SearchStory\", function(a, b) {\n                d({\n                    options: b,\n                    url: \"i/search\",\n                    params: [twttr.merge({\n                        q: a\n                    }, b),],\n                    dataSource: [\"\",]\n                });\n            }),\n            imageFacets: b([\"Status\",], function(a, b) {\n                twttr.anywhere.api.models.Search._requestFacets(\"search/image_facets\", a, b);\n            }),\n            videoFacets: b([\"Status\",], function(a, b) {\n                twttr.anywhere.api.models.Search._requestFacets(\"search/video_facets\", a, b);\n            }),\n            _requestFacets: function(a, b, c) {\n                ((twttr.is.def(c.include_entities) || (c.include_entities = twttr.anywhere.api.config.includeEntities))), d({\n                    options: c,\n                    url: a,\n                    params: [twttr.merge({\n                        q: b\n                    }, c),],\n                    dataSource: [\"statuses\",]\n                });\n            }\n        });\n        a(f);\n    });\n});\nprovide(\"bluejs/models/conversation\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.defaultTrigger, f = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Conversation\", function(a) {\n            ((a && twttr.anywhere.api.util.useStringIdentifier(a, \"id\"))), this.constructor.uberclass.call(this, a);\n        }).belongsTo(\"User\");\n        a(f);\n    });\n});\nprovide(\"bluejs/models/activity\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.aliasMethod, d = twttr.anywhere.api.util.callMethod, e = twttr.anywhere.api.util.defaultTrigger, f = twttr.anywhere.api.util.camelize, g = twttr.anywhere.api.util.BaseCollection, i = {\n            favorite: {\n                sources: \"User\",\n                targets: \"Status\",\n                target_objects: null\n            },\n            mention: {\n                sources: \"User\",\n                targets: \"User\",\n                target_objects: \"Status\"\n            },\n            reply: {\n                sources: \"User\",\n                targets: \"Status\",\n                target_objects: \"Status\"\n            },\n            retweet: {\n                sources: \"User\",\n                targets: \"Status\",\n                target_objects: \"Status\"\n            },\n            follow: {\n                sources: \"User\",\n                targets: \"User\",\n                target_objects: null\n            },\n            list_member_added: {\n                sources: \"User\",\n                targets: \"User\",\n                target_objects: \"List\"\n            },\n            list_created: {\n                sources: \"User\",\n                targets: \"List\",\n                target_objects: null\n            }\n        }, j = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Activity\", function(a) {\n            ((a.JSBNG__event ? a.action = a.JSBNG__event : ((a.action && (a.JSBNG__event = a.action))))), twttr.anywhere.api.models.Base.call(this, a);\n            for (var b in i) {\n                this.sync(((\"is_\" + b)), ((this.JSBNG__event === b)));\n            ;\n            };\n        ;\n            this.sync(\"timestamp\", twttr.helpers.parseDateString(this.createdAt));\n        });\n        j.hasMany(function(a) {\n            return ((i[a.JSBNG__event].sources || null));\n        }, \"sources\").hasMany(function(a) {\n            return ((i[a.JSBNG__event].targets || null));\n        }, \"targets\").hasMany(function(a) {\n            return ((i[a.JSBNG__event].target_objects || null));\n        }, \"targetObjects\").statics({\n            classMap: i\n        }), a(j);\n    });\n});\nprovide(\"bluejs/models/topic_story\", function(a) {\n    using(function() {\n        twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.TopicStory\").methods({\n            getId: function() {\n                return this.attributes.query;\n            }\n        }), a();\n    });\n});\nprovide(\"bluejs/models/news_article\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.NewsArticle\").methods({\n            getId: function() {\n                return this.getExpandedUrl();\n            },\n            getDisplayUrl: function() {\n                return this.url.display_url;\n            },\n            getExpandedUrl: function() {\n                return this.url.expanded_url;\n            },\n            getImage: function(a) {\n                for (var b = 0, c = this.media.length; ((b < c)); b++) {\n                    var d = this.media[b];\n                    if (((d.type === \"photo\"))) {\n                        return ((((a && d.media_url_https)) || d.media_url));\n                    }\n                ;\n                ;\n                };\n            ;\n                return null;\n            }\n        });\n        a();\n    });\n});\nprovide(\"bluejs/models/news_story\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.NewsStory\").hasMany(\"NewsArticle\", \"articles\").methods({\n            getId: function() {\n                return this.articles.get(0).getId();\n            }\n        });\n        a();\n    });\n});\nprovide(\"bluejs/models/user_story\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.UserStory\");\n        b.hasMany(\"User\", \"users\"), a(b);\n    });\n});\nprovide(\"bluejs/models/tweet_story\", function(a) {\n    using(function() {\n        twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.TweetStory\").hasOne(\"Status\", \"JSBNG__status\").methods({\n            getId: function() {\n                return this.JSBNG__status.id;\n            }\n        }), a();\n    });\n});\nprovide(\"bluejs/models/story\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Story\", function(a) {\n            var b = {\n            };\n            $.extend(b, a), b.JSBNG__content = a.data, delete b.data, twttr.anywhere.api.models.Base.call(this, b);\n        }).methods({\n            getId: function() {\n                return this.JSBNG__content.getId();\n            }\n        }).hasOne(\"SocialProof\", \"socialProof\").hasOne(function(a) {\n            return ((twttr.util.capitalize(a.type) + \"Story\"));\n        }, \"JSBNG__content\");\n        a(b);\n    });\n});\nprovide(\"bluejs/models/search_story\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.SearchStory\");\n        b.hasMany(\"Story\", \"stories\"), a(b);\n    });\n});\nprovide(\"bluejs/models/stories\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Stories\");\n        b.hasMany(\"Story\", \"stories\"), a();\n    });\n});\nprovide(\"bluejs/models/discovery\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.callMethod;\n        twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.Discovery\", function(a) {\n            this.constructor.uberclass.call(this, a);\n        }).statics({\n            discovery: b(\"Stories\", function(a) {\n                c({\n                    options: a,\n                    url: \"i/discovery\",\n                    params: [a,],\n                    dataSource: [\"\",]\n                });\n            })\n        }), a();\n    });\n});\nprovide(\"bluejs/models/sports_story\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.SportsStory\").hasOne(function(a) {\n            return ((twttr.util.capitalize(a.sport) + \"SportsEvents\"));\n        }, \"events\");\n        a();\n    });\n});\nprovide(\"bluejs/models/soccer_events\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.SoccerSportsEvents\").methods({\n            getMatchedEvent: function() {\n                return this.items[this.matchedEventId];\n            },\n            getMatchedEventData: function() {\n                return this.items[this.matchedEventId].event_data;\n            },\n            getMatchedTeam: function(a) {\n                var b = ((a ? this.getMatchedEventData().home_team : this.getMatchedEventData().away_team));\n                return b.team_logo_url = ((((b.team_logo_url_https && twttr.isSSL())) ? b.team_logo_url_https : b.team_logo_url_http)), ((b.team_logo_url || (b.team_logo_url = ((((b.user.profile_image_url_https && twttr.isSSL())) ? b.user.profile_image_url_https : b.user.profile_image_url))))), b;\n            },\n            getMatchState: function() {\n                return this.getMatchedEventData().match_state;\n            },\n            getOtherMatchState: function() {\n                var a = this, b = jQuery.map(this.items, function(b, c) {\n                    if (((((b.event_data.match_state.current_status === \"scheduled\")) || ((c === a.matchedEventId))))) {\n                        return null;\n                    }\n                ;\n                ;\n                    var d = decodeURIComponent(b.event_data.match_hashtag);\n                    return {\n                        event_id: c,\n                        home_name: b.event_data.home_team.team_name,\n                        away_name: b.event_data.away_team.team_name,\n                        score: b.event_data.match_state.score,\n                        search_path: twttr.router.searchResultsPath({\n                            query: d\n                        }),\n                        live: ((b.event_data.match_state.current_status == \"inprogress\")),\n                        hashtag: d\n                    };\n                });\n                return b;\n            }\n        });\n        a();\n    });\n});\nprovide(\"bluejs/models/us_political_rep\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.chainableMethod, c = twttr.anywhere.api.util.callMethod, d = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.UsPoliticalRep\").hasOne(\"User\").statics({\n            findByZip: b([\"UsPoliticalRep\",], function(a, b) {\n                c({\n                    options: b,\n                    url: \"government_search/by_zip\",\n                    params: [twttr.merge(b, {\n                        zip: a\n                    }),],\n                    dataSource: [\"\",]\n                });\n            })\n        });\n        a(d);\n    });\n});\nprovide(\"bluejs/models/social_proof\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.SocialProof\").hasOne(\"ReferencedBy\", \"referencedBy\");\n        a();\n    });\n});\nprovide(\"bluejs/models/referenced_by\", function(a) {\n    using(function() {\n        var b = twttr.anywhere.api.util.model(\"twttr.anywhere.api.models.ReferencedBy\").hasMany(\"Status\", \"statuses\");\n        a();\n    });\n});\nprovide(\"extendAPI\", function(a) {\n    using().as(function(b) {\n        twttr.extendAPI = function() {\n            twttr.API.DirectMessage.extend(function() {\n                this.threadId = ((((this.senderScreenName === twttr.currentUser.screenName)) ? this.recipientScreenName : this.senderScreenName));\n            });\n            var a = function(a) {\n                var c = a.retweetedStatus, d = new twttr.API.Status, e;\n                for (e in a) {\n                    if (((e === \"activities\"))) {\n                        continue;\n                    }\n                ;\n                ;\n                    d[e] = a[e], delete a[e];\n                };\n            ;\n                for (e in c) {\n                    a[e] = c[e];\n                ;\n                };\n            ;\n                a.retweetingStatus = d, a.wasRetweeted = !0, ((((((twttr.currentUser && d.user)) && ((d.user.id === twttr.currentUser.id)))) && c.sync(\"current_user_retweet\", {\n                    id: d.id\n                }))), delete a.retweetingStatus.retweetedStatus, delete a.retweetingStatus.attributes.retweeted_status, b(a);\n            }, b = function(a) {\n                ((a.retweetingStatus.isPromoted() && (a.attributes.impression_id = a.retweetingStatus.attributes.impression_id, a.attributes.experiments = a.retweetingStatus.attributes.experiments, a.attributes.disclosure_text = a.retweetingStatus.attributes.disclosure_text, a.attributes.disclosure_type = a.retweetingStatus.attributes.disclosure_type, a.impressionId = a.retweetingStatus.impressionId, a.experiments = a.retweetingStatus.experiments, a.disclosureText = a.retweetingStatus.disclosureText, a.disclosureType = a.retweetingStatus.disclosureType, delete a.retweetingStatus.impressionId, delete a.retweetingStatus.experiments, delete a.retweetingStatus.attributes.impression_id, delete a.retweetingStatus.attributes.experiments, delete a.retweetingStatus.disclosureText, delete a.retweetingStatus.disclosureType, delete a.retweetingStatus.attributes.disclosure_text, delete a.retweetingStatus.attributes.disclosure_type)));\n            };\n            twttr.API.Status.extend(function() {\n                function b(a) {\n                    return ((((a === null)) || ((typeof a == \"undefined\"))));\n                };\n            ;\n                ((this.isRetweet && a(this))), this.isReply = !!this.inReplyToStatusId, this.hasGeo = Boolean(((!b(this.coordinates) || ((this.place && this.place.id))))), ((this.hasGeo && (this.placeName = ((((this.place && this.place.fullName)) ? this.place.fullName : null)))));\n                var c = ((!b(this.coordinates) || ((!b(this.place) && ((this.place.placeType == \"poi\")))))), d = ((((this.entities && this.entities.places)) && ((this.entities.places.length > 0))));\n                this.showGeoMap = ((c && !d)), this.showGeoIcon = ((c || d));\n            }), twttr.API.User.extend(function() {\n                var a = ((twttr.currentUserScreenName === this.screenName));\n                this.is_only_admin_accessible = ((((twttr.isAdmin && !a)) && ((((this.deactivated_bit || this.suspended)) || ((this[\"protected\"] && !this.following))))));\n            }), twttr.API.CurrentUser.extend(function() {\n                var a = this;\n                this.hasLists = function() {\n                    return ((a.counts && ((a.counts.lists.owned || a.counts.lists.subscribed))));\n                }, this.hasSavedSearches = function() {\n                    return ((a.counts && a.counts.saved_searches));\n                };\n            }), twttr.API.List.extend(function() {\n                this.isOwnList = ((twttr.currentUser ? ((twttr.currentUser.id === this.user.id)) : null));\n            }), twttr.API.SavedSearch.extend(function() {\n                var a = this.query.match(/^place:([a-f0-9]{16})$/);\n                this.isPlaceSearch = Boolean(a), ((a && (this.placeId = a[1])));\n            });\n        }, a(twttr.extendAPI);\n    });\n});\nprovide(\"bluejs/api\", function(a) {\n    using(\"bluejs/init\", function() {\n        twttr.anywhere.api.initialize();\n        var b = {\n        };\n        twttr.aug(b, twttr.anywhere.api.models), twttr.aug(b, {\n            globalEvents: twttr.anywhere.api.globalEvents\n        }), b.setConfig = twttr.anywhere.api.updateConfig, b.getConfig = function() {\n            return twttr.anywhere.api.config;\n        }, ((b.util || (b.util = {\n        }))), twttr.aug(b.util, twttr.anywhere.api.util), ((b._requestCache || (b._requestCache = twttr.anywhere.api.cache))), a(b);\n    });\n});\nprovide(\"$lib/jquery.color.js\", function(a) {\n    (function(a) {\n        function b(b) {\n            var c;\n            return ((((((b && ((b.constructor == Array)))) && ((b.length == 3)))) ? b : (((c = /rgb\\(\\s*([0-9]{1,3})\\s*,\\s*([0-9]{1,3})\\s*,\\s*([0-9]{1,3})\\s*\\)/.exec(b)) ? [parseInt(c[1]),parseInt(c[2]),parseInt(c[3]),] : (((c = /rgb\\(\\s*([0-9]+(?:\\.[0-9]+)?)\\%\\s*,\\s*([0-9]+(?:\\.[0-9]+)?)\\%\\s*,\\s*([0-9]+(?:\\.[0-9]+)?)\\%\\s*\\)/.exec(b)) ? [((parseFloat(c[1]) * 2.55)),((parseFloat(c[2]) * 2.55)),((parseFloat(c[3]) * 2.55)),] : (((c = /#([a-fA-F0-9]{2})([a-fA-F0-9]{2})([a-fA-F0-9]{2})/.exec(b)) ? [parseInt(c[1], 16),parseInt(c[2], 16),parseInt(c[3], 16),] : (((c = /#([a-fA-F0-9])([a-fA-F0-9])([a-fA-F0-9])/.exec(b)) ? [parseInt(((c[1] + c[1])), 16),parseInt(((c[2] + c[2])), 16),parseInt(((c[3] + c[3])), 16),] : d[a.trim(b).toLowerCase()]))))))))));\n        };\n    ;\n        function c(c, d) {\n            var e;\n            do {\n                e = a.curCSS(c, d);\n                if (((((((e != \"\")) && ((e != \"transparent\")))) || a.nodeName(c, \"body\")))) {\n                    break;\n                }\n            ;\n            ;\n                d = \"backgroundColor\";\n            } while (c = c.parentNode);\n            return b(e);\n        };\n    ;\n        a.each([\"backgroundColor\",\"borderBottomColor\",\"borderLeftColor\",\"borderRightColor\",\"borderTopColor\",\"color\",\"outlineColor\",], function(d, e) {\n            a.fx.step[e] = function(a) {\n                ((((a.state == 0)) && (a.start = c(a.elem, e), a.end = b(a.end)))), a.elem.style[e] = ((((\"rgb(\" + [Math.max(Math.min(parseInt(((((a.pos * ((a.end[0] - a.start[0])))) + a.start[0]))), 255), 0),Math.max(Math.min(parseInt(((((a.pos * ((a.end[1] - a.start[1])))) + a.start[1]))), 255), 0),Math.max(Math.min(parseInt(((((a.pos * ((a.end[2] - a.start[2])))) + a.start[2]))), 255), 0),].join(\",\"))) + \")\"));\n            };\n        });\n        var d = {\n            aqua: [0,255,255,],\n            azure: [240,255,255,],\n            beige: [245,245,220,],\n            black: [0,0,0,],\n            blue: [0,0,255,],\n            brown: [165,42,42,],\n            cyan: [0,255,255,],\n            darkblue: [0,0,139,],\n            darkcyan: [0,139,139,],\n            darkgrey: [169,169,169,],\n            darkgreen: [0,100,0,],\n            darkkhaki: [189,183,107,],\n            darkmagenta: [139,0,139,],\n            darkolivegreen: [85,107,47,],\n            darkorange: [255,140,0,],\n            darkorchid: [153,50,204,],\n            darkred: [139,0,0,],\n            darksalmon: [233,150,122,],\n            darkviolet: [148,0,211,],\n            fuchsia: [255,0,255,],\n            gold: [255,215,0,],\n            green: [0,128,0,],\n            indigo: [75,0,130,],\n            khaki: [240,230,140,],\n            lightblue: [173,216,230,],\n            lightcyan: [224,255,255,],\n            lightgreen: [144,238,144,],\n            lightgrey: [211,211,211,],\n            lightpink: [255,182,193,],\n            lightyellow: [255,255,224,],\n            lime: [0,255,0,],\n            magenta: [255,0,255,],\n            maroon: [128,0,0,],\n            navy: [0,0,128,],\n            olive: [128,128,0,],\n            orange: [255,165,0,],\n            pink: [255,192,203,],\n            purple: [128,0,128,],\n            violet: [128,0,128,],\n            red: [255,0,0,],\n            silver: [192,192,192,],\n            white: [255,255,255,],\n            yellow: [255,255,0,]\n        };\n    })(jQuery), a();\n});\nprovide(\"$lib/modernizr-1.5.js\", function(a) {\n    window.Modernizr = function(a, b, c) {\n        function d(a) {\n            q.cssText = a;\n        };\n    ;\n        function e(a, b) {\n            return d(((gb.join(((a + \";\"))) + ((b || \"\")))));\n        };\n    ;\n        function f(a, b) {\n            return ((((\"\" + a)).indexOf(b) !== -1));\n        };\n    ;\n        function g(a, b) {\n            for (var d in a) {\n                if (((((q[a[d]] !== c)) && ((!b || b(a[d], p)))))) {\n                    return !0;\n                }\n            ;\n            ;\n            };\n        ;\n        };\n    ;\n        function i(a, b) {\n            var c = ((a.charAt(0).toUpperCase() + a.substr(1))), d = [a,((\"Webkit\" + c)),((\"Moz\" + c)),((\"O\" + c)),((\"ms\" + c)),((\"Khtml\" + c)),];\n            return !!g(d, b);\n        };\n    ;\n        function j() {\n            l[L] = function(a) {\n                for (var b = 0, c = a.length; ((b < c)); b++) {\n                    jb[a[b]] = ((a[b] in r));\n                ;\n                };\n            ;\n                return jb;\n            }(\"autocomplete autofocus list placeholder max min multiple pattern required step\".split(\" \")), l[M] = function(a) {\n                for (var b = 0, c, d = a.length; ((b < d)); b++) {\n                    r.setAttribute(\"type\", a[b]), c = ((r.type !== \"text\")), ((c && (r.value = eb, ((/tel|search/.test(r.type) || ((/url|email/.test(r.type) ? c = ((r.checkValidity && ((r.checkValidity() === !1)))) : c = ((r.value != eb))))))))), ib[a[b]] = !!c;\n                ;\n                };\n            ;\n                return ib;\n            }(\"search tel url email datetime date month week time datetime-local number range color\".split(\" \"));\n        };\n    ;\n        var k = \"1.5\", l = {\n        }, m = !0, n = b.documentElement, o = \"modernizr\", p = b.createElement(o), q = p.style, r = b.createElement(\"input\"), s = \"canvas\", t = \"canvastext\", u = \"rgba\", v = \"hsla\", w = \"multiplebgs\", x = \"backgroundsize\", y = \"borderimage\", z = \"borderradius\", A = \"boxshadow\", B = \"opacity\", C = \"cssanimations\", D = \"csscolumns\", E = \"cssgradients\", F = \"cssreflections\", G = \"csstransforms\", H = \"csstransforms3d\", I = \"csstransitions\", J = \"video\", K = \"audio\", L = \"input\", M = ((L + \"types\")), N = \"svg\", O = \"smil\", P = ((N + \"clippaths\")), Q = \"background\", R = ((Q + \"Color\")), S = \"canPlayType\", T = \"JSBNG__localStorage\", U = \"JSBNG__sessionStorage\", V = \"JSBNG__applicationCache\", W = \"webworkers\", X = \"hashchange\", Y = \"crosswindowmessaging\", Z = \"historymanagement\", ab = \"draganddrop\", bb = \"websqldatabase\", cb = \"indexedDB\", db = \"websockets\", eb = \":)\", fb = Object.prototype.toString, gb = \" -o- -moz- -ms- -webkit- -khtml- \".split(\" \"), hb = {\n        }, ib = {\n        }, jb = {\n        }, kb = [], lb = function() {\n            function a(a, d) {\n                var e = ((arguments.length == 1));\n                if (((e && c[a]))) {\n                    return c[a];\n                }\n            ;\n            ;\n                d = ((d || JSBNG__document.createElement(((b[a] || \"div\"))))), a = ((\"JSBNG__on\" + a));\n                var f = ((a in d));\n                return ((((!f && d.setAttribute)) && (d.setAttribute(a, \"return;\"), f = ((typeof d[a] == \"function\"))))), d = null, ((e ? c[a] = f : f));\n            };\n        ;\n            var b = {\n                select: \"input\",\n                change: \"input\",\n                submit: \"form\",\n                reset: \"form\",\n                error: \"img\",\n                load: \"img\",\n                abort: \"img\"\n            }, c = {\n            };\n            return a;\n        }(), mb = {\n        }.hasOwnProperty, nb;\n        ((((((typeof mb != \"undefined\")) && ((typeof mb.call != \"undefined\")))) ? nb = function(a, b) {\n            return mb.call(a, b);\n        } : nb = function(a, b) {\n            return ((((b in a)) && ((typeof a.constructor.prototype[b] == \"undefined\"))));\n        })), hb[s] = function() {\n            return !!b.createElement(s).getContext;\n        }, hb[t] = function() {\n            return ((!!hb[s]() && ((typeof b.createElement(s).getContext(\"2d\").fillText == \"function\"))));\n        }, hb[Y] = function() {\n            return !!a.JSBNG__postMessage;\n        }, hb[bb] = function() {\n            var b = !!a.JSBNG__openDatabase;\n            if (b) {\n                try {\n                    b = !!JSBNG__openDatabase(\"testdb\", \"1.0\", \"html5 test db\", 200000);\n                } catch (c) {\n                    b = !1;\n                };\n            }\n        ;\n        ;\n            return b;\n        }, hb[cb] = function() {\n            return !!a[cb];\n        }, hb[X] = function() {\n            return ((lb(X, a) && ((((JSBNG__document.documentMode === c)) || ((JSBNG__document.documentMode > 7))))));\n        }, hb[Z] = function() {\n            return ((!!a.JSBNG__history && !!JSBNG__history.pushState));\n        }, hb[ab] = function() {\n            return ((((((((((((lb(\"drag\") && lb(\"dragstart\"))) && lb(\"dragenter\"))) && lb(\"dragover\"))) && lb(\"dragleave\"))) && lb(\"dragend\"))) && lb(\"drop\")));\n        }, hb[db] = function() {\n            return ((\"JSBNG__WebSocket\" in a));\n        }, hb[u] = function() {\n            return d(((Q + \"-color:rgba(150,255,150,.5)\"))), f(q[R], u);\n        }, hb[v] = function() {\n            return d(((Q + \"-color:hsla(120,40%,100%,.5)\"))), f(q[R], u);\n        }, hb[w] = function() {\n            return d(((Q + \":url(//:),url(//:),red url(//:)\"))), (new RegExp(\"(url\\\\s*\\\\(.*?){3}\")).test(q[Q]);\n        }, hb[x] = function() {\n            return i(((Q + \"Size\")));\n        }, hb[y] = function() {\n            return i(\"borderImage\");\n        }, hb[z] = function() {\n            return i(\"borderRadius\", \"\", function(a) {\n                return f(a, \"orderRadius\");\n            });\n        }, hb[A] = function() {\n            return i(\"boxShadow\");\n        }, hb[B] = function() {\n            return e(\"opacity:.5\"), f(q[B], \"0.5\");\n        }, hb[C] = function() {\n            return i(\"animationName\");\n        }, hb[D] = function() {\n            return i(\"columnCount\");\n        }, hb[E] = function() {\n            var a = ((Q + \"-image:\")), b = \"gradient(linear,left top,right bottom,from(#9f9),to(white));\", c = \"linear-gradient(left top,#9f9, white);\";\n            return d(((((a + gb.join(((b + a))))) + gb.join(((c + a))))).slice(0, -a.length)), f(q.backgroundImage, \"gradient\");\n        }, hb[F] = function() {\n            return i(\"boxReflect\");\n        }, hb[G] = function() {\n            return !!g([\"transformProperty\",\"WebkitTransform\",\"MozTransform\",\"OTransform\",\"msTransform\",]);\n        }, hb[H] = function() {\n            var a = !!g([\"perspectiveProperty\",\"WebkitPerspective\",\"MozPerspective\",\"OPerspective\",\"msPerspective\",]);\n            if (a) {\n                var c = JSBNG__document.createElement(\"style\"), d = b.createElement(\"div\");\n                c.textContent = ((((\"@media (\" + gb.join(\"transform-3d),(\"))) + \"modernizr){#modernizr{height:3px}}\")), b.getElementsByTagName(\"head\")[0].appendChild(c), d.id = \"modernizr\", n.appendChild(d), a = ((d.offsetHeight === 3)), c.parentNode.removeChild(c), d.parentNode.removeChild(d);\n            }\n        ;\n        ;\n            return a;\n        }, hb[I] = function() {\n            return i(\"transitionProperty\");\n        }, hb[J] = function() {\n            var a = b.createElement(J), c = !1;\n            try {\n                if (c = !!a.canPlayType) {\n                    c = new Boolean(c), c.ogg = a.canPlayType(\"video/ogg; codecs=\\\"theora\\\"\");\n                    var d = \"video/mp4; codecs=\\\"avc1.42E01E\";\n                    c.h264 = ((a.canPlayType(((d + \"\\\"\"))) || a.canPlayType(((d + \", mp4a.40.2\\\"\"))))), c.webm = a.canPlayType(\"video/webm; codecs=\\\"vp8, vorbis\\\"\");\n                }\n            ;\n            ;\n            } catch (e) {\n            \n            };\n        ;\n            return c;\n        }, hb[K] = function() {\n            var a = b.createElement(K), c = !1;\n            try {\n                if (c = !!a.canPlayType) {\n                    c = new Boolean(c), c.ogg = a.canPlayType(\"audio/ogg; codecs=\\\"vorbis\\\"\"), c.mp3 = a.canPlayType(\"audio/mpeg;\"), c.wav = a.canPlayType(\"audio/wav; codecs=\\\"1\\\"\"), c.m4a = ((a.canPlayType(\"audio/x-m4a;\") || a.canPlayType(\"audio/aac;\")));\n                }\n            ;\n            ;\n            } catch (d) {\n            \n            };\n        ;\n            return c;\n        }, hb[T] = function() {\n            try {\n                return ((((\"JSBNG__localStorage\" in a)) && ((a[T] !== null))));\n            } catch (b) {\n                return !1;\n            };\n        ;\n        }, hb[U] = function() {\n            try {\n                return ((((\"JSBNG__sessionStorage\" in a)) && ((a[U] !== null))));\n            } catch (b) {\n                return !1;\n            };\n        ;\n        }, hb[W] = function() {\n            return !!a.JSBNG__Worker;\n        }, hb[V] = function() {\n            var b = a[V];\n            return ((((((!!b && ((typeof b.JSBNG__status != \"undefined\")))) && ((typeof b.update == \"function\")))) && ((typeof b.swapCache == \"function\"))));\n        }, hb[N] = function() {\n            return ((!!b.createElementNS && !!b.createElementNS(\"http://www.w3.org/2000/svg\", \"svg\").createSVGRect));\n        }, hb[O] = function() {\n            return ((!!b.createElementNS && /SVG/.test(fb.call(b.createElementNS(\"http://www.w3.org/2000/svg\", \"animate\")))));\n        }, hb[P] = function() {\n            return ((!!b.createElementNS && /SVG/.test(fb.call(b.createElementNS(\"http://www.w3.org/2000/svg\", \"clipPath\")))));\n        };\n        for (var ob in hb) {\n            ((nb(hb, ob) && kb.push((((((l[ob.toLowerCase()] = hb[ob]()) ? \"\" : \"no-\")) + ob.toLowerCase())))));\n        ;\n        };\n    ;\n        return ((l[L] || j())), l.addTest = function(a, b) {\n            a = a.toLowerCase();\n            if (l[a]) {\n                return;\n            }\n        ;\n        ;\n            return b = !!b(), n.className += ((((\" \" + ((b ? \"\" : \"no-\")))) + a)), l[a] = b, l;\n        }, d(\"\"), p = r = null, ((((m && function() {\n            var a = b.createElement(\"div\");\n            return a.innerHTML = \"\\u003Celem\\u003E\\u003C/elem\\u003E\", ((a.childNodes.length !== 1));\n        }())) && function(a, b) {\n            function c(a, d) {\n                if (j[a]) j[a].styleSheet.cssText += d;\n                 else {\n                    var e = g[o], f = b[p](\"style\");\n                    f.media = a, e.insertBefore(f, e[o]), j[a] = f, c(a, d);\n                }\n            ;\n            ;\n            };\n        ;\n            function d(a, b) {\n                for (var e = new RegExp(((((\"\\\\b(\" + k)) + \")\\\\b(?!.*[;}])\")), \"gi\"), f = function(a) {\n                    return ((\".iepp_\" + a));\n                }, h = -1; ((++h < a.length)); ) {\n                    b = ((a[h].media || b)), d(a[h].imports, b), c(b, a[h].cssText.replace(e, f));\n                ;\n                };\n            ;\n            };\n        ;\n            function e() {\n                for (var a, c = b.getElementsByTagName(\"*\"), e, f, h = new RegExp(((((\"^\" + k)) + \"$\")), \"i\"), g = -1; ((++g < c.length)); ) {\n                    (((((a = c[g]) && (f = a.nodeName.match(h)))) && (e = new RegExp(((((((((\"^\\\\s*\\u003C\" + f)) + \"(.*)\\\\/\")) + f)) + \"\\u003E\\\\s*$\")), \"i\"), i.innerHTML = a.outerHTML.replace(/\\r|\\n/g, \" \").replace(e, ((((a.currentStyle.display == \"block\")) ? \"\\u003Cdiv$1/div\\u003E\" : \"\\u003Cspan$1/span\\u003E\"))), e = i.childNodes[0], e.className += ((\" iepp_\" + f)), e = m[m.length] = [a,e,], a.parentNode.replaceChild(e[1], e[0]))));\n                ;\n                };\n            ;\n                d(b.styleSheets, \"all\");\n            };\n        ;\n            function f() {\n                for (var a = -1, b; ((++a < m.length)); ) {\n                    m[a][1].parentNode.replaceChild(m[a][0], m[a][1]);\n                ;\n                };\n            ;\n                for (b in j) {\n                    g[o].removeChild(j[b]);\n                ;\n                };\n            ;\n                j = {\n                }, m = [];\n            };\n        ;\n            for (var g = b.documentElement, i = b.createDocumentFragment(), j = {\n            }, k = \"abbr|article|aside|audio|canvas|command|datalist|details|figure|figcaption|footer|header|hgroup|keygen|mark|meter|nav|output|progress|section|source|summary|time|video\", l = k.split(\"|\"), m = [], n = -1, o = \"firstChild\", p = \"createElement\"; ((++n < l.length)); ) {\n                b[p](l[n]), i[p](l[n]);\n            ;\n            };\n        ;\n            i = i.appendChild(b[p](\"div\")), a.JSBNG__attachEvent(\"JSBNG__onbeforeprint\", e), a.JSBNG__attachEvent(\"JSBNG__onafterprint\", f);\n        }(this, b))), l._enableHTML5 = m, l._version = k, n.className = ((n.className.replace(/\\bno-js\\b/, \"\") + \" js\")), l;\n    }(this, this.JSBNG__document), a();\n});\nprovide(\"$lib/jquery.hashchange.js\", function(a) {\n    (function($) {\n        var a = function() {\n            function a(a, d) {\n                var e = ((arguments.length == 1));\n                if (((e && c[a]))) {\n                    return c[a];\n                }\n            ;\n            ;\n                d = ((d || JSBNG__document.createElement(((b[a] || \"div\"))))), a = ((\"JSBNG__on\" + a));\n                var f = ((a in d));\n                return ((((!f && d.setAttribute)) && (d.setAttribute(a, \"return;\"), f = ((typeof d[a] == \"function\"))))), d = null, ((e ? c[a] = f : f));\n            };\n        ;\n            var b = {\n                select: \"input\",\n                change: \"input\",\n                submit: \"form\",\n                reset: \"form\",\n                error: \"img\",\n                load: \"img\",\n                abort: \"img\"\n            }, c = {\n            };\n            return a;\n        }();\n        $.fn.hashchange = function(b) {\n            if (((a(\"hashchange\", window) && ((((JSBNG__document.documentMode === undefined)) || ((JSBNG__document.documentMode > 7))))))) this.bind(\"hashchange\", b);\n             else {\n                var c = JSBNG__location.hash;\n                JSBNG__setInterval(function() {\n                    ((((c !== JSBNG__location.hash)) && (b($.JSBNG__Event(\"hashchange\")), c = JSBNG__location.hash)));\n                }, 250);\n            }\n        ;\n        ;\n            return this;\n        };\n    })(jQuery), a();\n});\nprovide(\"$lib/jquery.cookie.js\", function(a) {\n    jQuery.cookie = function(a, b, c) {\n        if (((typeof b == \"undefined\"))) {\n            var d = null;\n            if (((JSBNG__document.cookie && ((JSBNG__document.cookie != \"\"))))) {\n                var e = JSBNG__document.cookie.split(\";\");\n                for (var f = 0; ((f < e.length)); f++) {\n                    var g = jQuery.trim(e[f]);\n                    if (((g.substring(0, ((a.length + 1))) == ((a + \"=\"))))) {\n                        d = decodeURIComponent(g.substring(((a.length + 1))));\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            return d;\n        }\n    ;\n    ;\n        c = ((c || {\n        })), ((((b === null)) && (b = \"\", c.expires = -1)));\n        var i = \"\";\n        if (((c.expires && ((((typeof c.expires == \"number\")) || c.expires.toUTCString))))) {\n            var j;\n            ((((typeof c.expires == \"number\")) ? (j = new JSBNG__Date, j.setTime(((j.getTime() + ((((((((c.expires * 24)) * 60)) * 60)) * 1000)))))) : j = c.expires)), i = ((\"; expires=\" + j.toUTCString()));\n        }\n    ;\n    ;\n        var k = ((c.path ? ((\"; path=\" + c.path)) : \"\")), l = ((c.domain ? ((\"; domain=\" + c.domain)) : \"\")), m = ((c.secure ? \"; secure\" : \"\"));\n        JSBNG__document.cookie = [a,\"=\",encodeURIComponent(b),i,k,l,m,].join(\"\");\n    }, a();\n});\nprovide(\"$lib/jquery.tipsy.js\", function(a) {\n    (function($) {\n        function a(a, b) {\n            this.$element = $(a), this.options = b, this.enabled = !0, this.fixTitle();\n        };\n    ;\n        a.prototype = {\n            show: function() {\n                var a = this.getTitle();\n                if (((a && this.enabled))) {\n                    var b = this.tip();\n                    b.JSBNG__find(\".tipsy-inner\")[((this.options.html ? \"html\" : \"text\"))](a), b[0].className = \"tipsy\", b.remove().css({\n                        JSBNG__top: 0,\n                        left: 0,\n                        visibility: \"hidden\",\n                        display: \"block\"\n                    }).appendTo(JSBNG__document.body);\n                    var c = $.extend({\n                    }, this.$element.offset(), {\n                        width: this.$element[0].offsetWidth,\n                        height: this.$element[0].offsetHeight\n                    }), d = b[0].offsetWidth, e = b[0].offsetHeight, f = ((((typeof this.options.gravity == \"function\")) ? this.options.gravity.call(this.$element[0]) : this.options.gravity));\n                    function g(a) {\n                        return ((twttr.isRTL ? ((((a === \"e\")) ? \"w\" : \"e\")) : a));\n                    };\n                ;\n                    var i;\n                    switch (f.charAt(0)) {\n                      case \"n\":\n                        i = {\n                            JSBNG__top: ((((c.JSBNG__top + c.height)) + this.options.offset)),\n                            left: ((((c.left + ((c.width / 2)))) - ((d / 2))))\n                        };\n                        break;\n                      case \"s\":\n                        i = {\n                            JSBNG__top: ((((c.JSBNG__top - e)) - this.options.offset)),\n                            left: ((((c.left + ((c.width / 2)))) - ((d / 2))))\n                        };\n                        break;\n                      case g(\"e\"):\n                        i = {\n                            JSBNG__top: ((((c.JSBNG__top + ((c.height / 2)))) - ((e / 2)))),\n                            left: ((((c.left - d)) - this.options.offset))\n                        };\n                        break;\n                      case g(\"w\"):\n                        i = {\n                            JSBNG__top: ((((c.JSBNG__top + ((c.height / 2)))) - ((e / 2)))),\n                            left: ((((c.left + c.width)) + this.options.offset))\n                        };\n                    };\n                ;\n                    ((((f.length == 2)) && ((((f.charAt(1) == g(\"w\"))) ? i.left = ((((c.left + ((c.width / 2)))) - 15)) : i.left = ((((((c.left + ((c.width / 2)))) - d)) + 15)))))), b.css(i).addClass(((\"tipsy-\" + f))), ((this.options.fade ? b.JSBNG__stop().css({\n                        opacity: 0,\n                        display: \"block\",\n                        visibility: \"visible\"\n                    }).animate({\n                        opacity: this.options.opacity\n                    }) : b.css({\n                        visibility: \"visible\",\n                        opacity: this.options.opacity\n                    }))), ((this.options.className && b.addClass(this.options.className)));\n                }\n            ;\n            ;\n            },\n            hide: function() {\n                ((this.options.fade ? this.tip().JSBNG__stop().fadeOut(function() {\n                    $(this).remove();\n                }) : this.tip().remove()));\n            },\n            fixTitle: function() {\n                var a = this.$element;\n                ((((a.attr(\"title\") || ((typeof a.attr(\"original-title\") != \"string\")))) && a.attr(\"original-title\", ((a.attr(\"title\") || \"\"))).removeAttr(\"title\")));\n            },\n            getTitle: function() {\n                var a, b = this.$element, c = this.options;\n                this.fixTitle();\n                var a, c = this.options;\n                return ((((typeof c.title == \"string\")) ? a = b.attr(((((c.title == \"title\")) ? \"original-title\" : c.title))) : ((((typeof c.title == \"function\")) && (a = c.title.call(b[0])))))), a = ((\"\" + a)).replace(/(^\\s*|\\s*$)/, \"\"), ((a || c.fallback));\n            },\n            tip: function() {\n                return ((this.$tip || (this.$tip = $(\"\\u003Cdiv class=\\\"tipsy\\\"\\u003E\\u003C/div\\u003E\").html(\"\\u003Cdiv class=\\\"tipsy-arrow\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"tipsy-inner\\\"\\u003E\\u003C/div\\u003E\")))), this.$tip;\n            },\n            validate: function() {\n                ((this.$element[0].parentNode || (this.hide(), this.$element = null, this.options = null)));\n            },\n            enable: function() {\n                this.enabled = !0;\n            },\n            disable: function() {\n                this.enabled = !1;\n            },\n            toggleEnabled: function() {\n                this.enabled = !this.enabled;\n            }\n        }, $.fn.tipsy = function(b) {\n            function c(c) {\n                var d = $.data(c, \"tipsy\");\n                return ((d || (d = new a(c, $.fn.tipsy.elementOptions(c, b)), $.data(c, \"tipsy\", d)))), d;\n            };\n        ;\n            function d() {\n                var a = c(this);\n                a.hoverState = \"in\", ((((b.delayIn == 0)) ? a.show() : (a.fixTitle(), JSBNG__setTimeout(function() {\n                    ((((a.hoverState == \"in\")) && a.show()));\n                }, b.delayIn))));\n            };\n        ;\n            function e() {\n                var a = c(this);\n                a.hoverState = \"out\", ((((b.delayOut == 0)) ? a.hide() : JSBNG__setTimeout(function() {\n                    ((((a.hoverState == \"out\")) && a.hide()));\n                }, b.delayOut)));\n            };\n        ;\n            if ((($.browser.msie && (($.browser.version < 9))))) {\n                return this;\n            }\n        ;\n        ;\n            if (((b === !0))) {\n                return this.data(\"tipsy\");\n            }\n        ;\n        ;\n            if (((typeof b == \"string\"))) {\n                var f = this.data(\"tipsy\");\n                return ((f && f[b]())), this;\n            }\n        ;\n        ;\n            b = $.extend({\n            }, $.fn.tipsy.defaults, b);\n            if (b.stopThat) {\n                this.each(function() {\n                    c(this).hide();\n                });\n                return;\n            }\n        ;\n        ;\n            ((b.live || this.each(function() {\n                c(this);\n            })));\n            if (((b.trigger != \"manual\"))) {\n                var g = ((b.live ? \"live\" : \"bind\")), i = ((((b.trigger == \"hover\")) ? \"mouseenter\" : \"JSBNG__focus\")), j = ((((b.trigger == \"hover\")) ? \"mouseleave\" : \"JSBNG__blur\"));\n                this[g](i, d)[g](j, e);\n            }\n        ;\n        ;\n            return this;\n        }, $.fn.tipsy.defaults = {\n            delayIn: 0,\n            delayOut: 0,\n            fade: !1,\n            fallback: \"\",\n            gravity: \"n\",\n            html: !1,\n            live: !1,\n            offset: 0,\n            opacity: 278071,\n            title: \"title\",\n            trigger: \"hover\"\n        }, $.fn.tipsy.elementOptions = function(a, b) {\n            return (($.metadata ? $.extend({\n            }, b, $(a).metadata()) : b));\n        }, $.fn.tipsy.autoNS = function() {\n            return (((($(this).offset().JSBNG__top > (($(JSBNG__document).scrollTop() + (($(window).height() / 2)))))) ? \"s\" : \"n\"));\n        }, $.fn.tipsy.autoWE = function() {\n            return (((($(this).offset().left > (($(JSBNG__document).scrollLeft() + (($(window).width() / 2)))))) ? \"e\" : \"w\"));\n        };\n    })(jQuery), a();\n});\nprovide(\"$lib/jquery.cssanimation.js\", function(a) {\n    (function($) {\n        var a = /([A-Z])/g;\n        $.fn.stopCssAnimation = function() {\n            this.each(function() {\n                var b = $(this), c = b.data(\"cssAnimatedProps\"), d = window.JSBNG__getComputedStyle(this, null), e = {\n                };\n                for (var f in c) {\n                    f = f.replace(a, \"-$1\").toLowerCase(), e[f] = d.getPropertyValue(f);\n                ;\n                };\n            ;\n                b.css({\n                    \"-moz-transition-property\": \"none\",\n                    \"-moz-transition-duration\": \"\",\n                    \"-moz-transition-timing-function\": \"\",\n                    \"-webkit-transition-property\": \"none\",\n                    \"-webkit-transition-duration\": \"\",\n                    \"-webkit-transition-timing-function\": \"\"\n                });\n                for (var f in e) {\n                    b.css(f, e[f]);\n                ;\n                };\n            ;\n                b.data(\"cssAnimatedProps\", null);\n                var g = b.data(\"cssTimeoutId\");\n                ((((g != null)) && (JSBNG__clearTimeout(g), b.data(\"cssTimeoutId\", null))));\n            });\n        }, $.fn.animateWithCss = function(b, c, d, e) {\n            var f = jQuery.speed(c, d, e);\n            if (jQuery.isEmptyObject(b)) {\n                return this.each(f.complete);\n            }\n        ;\n        ;\n            var g = {\n                bounce: \"cubic-bezier(0.0, 0.35, .5, 1.3)\",\n                linear: \"linear\",\n                swing: \"ease-in-out\"\n            };\n            f.easing = ((f.easing || \"swing\")), f.easing = ((g[f.easing] ? g[f.easing] : f.easing)), this.each(function() {\n                $(this).data(\"cssAnimatedProps\", b);\n                var c = window.JSBNG__getComputedStyle(this, null);\n                for (var d in b) {\n                    d = d.replace(a, \"-$1\").toLowerCase(), $(this).css(d, c.getPropertyValue(d));\n                ;\n                };\n            ;\n            });\n            var i = [];\n            for (var j in b) {\n                i.push(j);\n            ;\n            };\n        ;\n            var k = ((i.length ? i.join(\",\") : \"all\"));\n            this.css({\n                \"-moz-transition-property\": k,\n                \"-moz-transition-duration\": ((f.duration + \"ms\")),\n                \"-moz-transition-timing-function\": f.easing,\n                \"-webkit-transition-property\": k,\n                \"-webkit-transition-duration\": ((f.duration + \"ms\")),\n                \"-webkit-transition-timing-function\": f.easing\n            }), this.css(b);\n            var l = this, m = JSBNG__setTimeout(function() {\n                l.css({\n                    \"-moz-transition-property\": \"none\",\n                    \"-moz-transition-duration\": \"\",\n                    \"-moz-transition-timing-function\": \"\",\n                    \"-webkit-transition-property\": \"none\",\n                    \"-webkit-transition-duration\": \"\",\n                    \"-webkit-transition-timing-function\": \"\"\n                }), l.data(\"cssAnimatedProps\", null), l.data(\"cssTimeoutId\", null), ((jQuery.isFunction(f.complete) && f.complete.apply(l)));\n            }, f.duration);\n            return this.data(\"cssTimeoutId\", m), this;\n        };\n    })(jQuery), a();\n});\nprovide(\"div\", function(a) {\n    using().as(function(b) {\n        twttr.provide(\"twttr.IFrame\"), twttr.IFrame = function() {\n            function a() {\n                var a = [\"webkit\",\"mozilla\",\"JSBNG__opera\",\"msie\",];\n                for (var b = 0; ((b < a.length)); b++) {\n                    if ($.browser[a[b]]) {\n                        return a[b];\n                    }\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n            var b = \"\\u003C!DOCTYPE html\\u003E\\u003Chtml\\u003E\\u003Chead\\u003E\", c = \"\\u003C/head\\u003E\\u003Cbody\\u003E\", d = \"\\u003C/body\\u003E\\u003C/html\\u003E\", e = function(a, b) {\n                for (var c in b) {\n                    a[c] = b[c];\n                ;\n                };\n            ;\n                return a;\n            }, f = function(a) {\n                return jQuery.map(((a || [])), function(a, b) {\n                    return ((((\"\\u003Clink rel=\\\"stylesheet\\\" href=\\\"\" + a)) + \"\\\" type=\\\"text/css\\\"\\u003E\"));\n                }).join(\"\");\n            }, g = 0, i = function(a) {\n                return ((a ? (g = a.length, jQuery.map(((a || [])), function(a, b) {\n                    return ((((((((((\"\\u003Cscript \" + (($.browser.msie ? \"JSBNG__onReadyStateChange\" : \"JSBNG__onLoad\")))) + \"=\\\"scriptReady(this);\\\" type=\\\"text/javascript\\\" src=\\\"\")) + a)) + \"\\\"\\u003E\\u003C/scr\")) + \"ipt\\u003E\"));\n                }).join(\"\")) : \"\"));\n            }, j = function(i) {\n                var j = i.window.JSBNG__document, k = this, l = $(\"\\u003Ciframe allowtransparency=\\\"true\\\" frameborder=\\\"0\\\" tabindex=\\\"-1\\\" role=\\\"presentation\\\" scrolling=\\\"no\\\"/\\u003E\", j), m = l[0], n = i.complete, o = i.JSBNG__content, p = $.browser;\n                ((i.css && l.css(i.css))), this.node = m;\n                var q = function() {\n                    this.window = this.contentWindow = m.contentWindow, this.$node = l, $(m.contentWindow.JSBNG__document.body).addClass(a());\n                    var b = e(function(a) {\n                        return $(a, m.contentWindow.JSBNG__document);\n                    }, $);\n                    this.jQuery = b;\n                    try {\n                        ((this.window.jQuery || (this.window.jQuery = b, this.window.$ = b)));\n                    } catch (c) {\n                    \n                    };\n                ;\n                    n(this);\n                };\n                if (o) {\n                    if (twttr.is.string(o)) ((n && l.bind(\"load\", twttr.bind(this, function() {\n                        l.unbind(\"load\"), q.call(this);\n                    })))), m.src = o;\n                     else {\n                        var r = \"\";\n                        ((p.mozilla && (m.src = ((((\"javascript:\" + (new JSBNG__Date).getTime())) + \";'';\"))))), ((((p.msie && i.domain)) && (m.src = ((((\"javascript:'\\u003Cscript\\u003Ewindow.JSBNG__onload=function(){document.write(\\\\'\\u003Cscript\\u003Edocument.domain=\\\\\\\"\" + JSBNG__document.domain)) + \"\\\\\\\";\\u003C\\\\\\\\/script\\u003E\\\\');document.close();};\\u003C/script\\u003E'\")), r = ((((\"\\u003Cscript\\u003Edocument.domain = \\\"\" + i.domain)) + \"\\\";\\u003C/script\\u003E\"))))), l.bind(\"load\", twttr.bind(this, function(a) {\n                            l.unbind(\"load\"), m.contentWindow.JSBNG__document.scriptReady = function(a) {\n                                if (((((a.readyState && ((((a.readyState == \"loaded\")) || ((a.readyState == \"complete\")))))) || !$.browser.msie))) {\n                                    g--, ((g || q.call(j)));\n                                }\n                            ;\n                            ;\n                            };\n                            var e = m.contentWindow.JSBNG__document, i = ((((((((((((b + r)) + f(o.css))) + ((o.styles ? ((((((((\"\\u003Cbase href=\\\"\" + twttr.assets.path(\"/\"))) + \"\\\"\\u003E\\u003Cstyle type=\\\"text/css\\\"\\u003E\")) + o.styles)) + \"\\u003C/style\\u003E\")) : \"\")))) + c)) + ((o.body || \"\")))) + d)), j = this;\n                            e.open(), e.write(i), e.close(), ((g || q.call(j)));\n                        }));\n                    }\n                ;\n                ;\n                    var s = i.parentNode;\n                    ((((typeof i.parentNode == \"string\")) ? s = $(i.parentNode, j) : s = i.parentNode)), l[((i.insert || \"appendTo\"))](((s || j.body)));\n                }\n            ;\n            ;\n            };\n            return {\n                create: function(a, b) {\n                    return a = e({\n                        window: window,\n                        complete: b\n                    }, a), (new j(a)).node;\n                }\n            };\n        }(), a(twttr.IFrame);\n    });\n});\nprovide(\"util\", function(a) {\n    using(\"run/base\").as(function(b) {\n        var c = null, d = /([a-zA-Z0-9])([A-Z])/g, e = /_(.)/g, f = /\\?(.*)/, g = {\n            supplant: function() {\n                var a = /\\{([^\\{\\}]*)\\}/g;\n                return function(b, c) {\n                    return b.replace(a, function(a, b) {\n                        var d = c[b];\n                        return ((((twttr.is.string(d) || twttr.is.number(d))) ? d : a));\n                    });\n                };\n            }(),\n            joinPath: function(a, b) {\n                return ((((a.substr(-1) === \"/\")) ? ((a + b)) : ((((a + \"/\")) + b))));\n            },\n            defaulted: function(a, b) {\n                return ((twttr.is.def(a) ? a : b));\n            },\n            create: function(a) {\n                function b() {\n                \n                };\n            ;\n                return b.prototype = a, b.constructor = b, new b;\n            },\n            params: function(a) {\n                if (((!a && c))) {\n                    return c;\n                }\n            ;\n            ;\n                var b = {\n                }, d = ((a || window.JSBNG__location.search));\n                return ((d ? (((((d.charAt(0) === \"?\")) && (d = d.slice(1)))), twttr.each(d.split(\"&\"), function(a) {\n                    a = a.split(\"=\");\n                    var c = a.shift(), d = decodeURIComponent(a.join(\"=\"));\n                    b[c] = d.replace(/\\+/, \" \");\n                }), ((a || (c = b))), b) : b));\n            },\n            paramsFromUrl: function(a) {\n                return ((((!a || ((a.indexOf(\"?\") < 0)))) ? null : g.params(a.split(f)[1])));\n            },\n            underscore: function(a) {\n                return ((((a.toUpperCase() === a)) ? a : a.replace(d, function(a, b, c) {\n                    return ((((b + \"_\")) + c));\n                }).toLowerCase()));\n            },\n            camelize: function(a) {\n                return a.replace(e, function(a, b) {\n                    return b.toUpperCase();\n                });\n            },\n            camelizeObject: function(a) {\n                if (!twttr.is.object(a)) {\n                    throw new Error(\"The carmelizeObject() method only accepts apples.\");\n                }\n            ;\n            ;\n                var b = {\n                };\n                for (var c in a) {\n                    b[g.camelize(c)] = a[c];\n                ;\n                };\n            ;\n                return b;\n            },\n            capitalize: function(a) {\n                return ((a.charAt(0).toUpperCase() + a.substr(1)));\n            },\n            addCommas: function(a, b) {\n                return b = ((b || \",\")), parseInt(a, 10).toString().replace(/(.)(?=(.{3})+$)/g, function(a, c) {\n                    return ((c + b));\n                });\n            },\n            _numberFormats: {\n                de: {\n                    grouping_separator: \".\"\n                },\n                en: {\n                    grouping_separator: \",\"\n                },\n                es: {\n                    grouping_separator: \".\"\n                },\n                fr: {\n                    grouping_separator: \" \"\n                },\n                it: {\n                    grouping_separator: \".\"\n                },\n                ja: {\n                    grouping_separator: \",\"\n                },\n                pt: {\n                    grouping_separator: \".\"\n                },\n                tr: {\n                    grouping_separator: \".\"\n                },\n                nl: {\n                    grouping_separator: \".\"\n                },\n                id: {\n                    grouping_separator: \".\"\n                }\n            },\n            formatNumber: function(a, b) {\n                var c = \",\";\n                return ((((twttr.is.def(b) && g._numberFormats[b])) && (c = g._numberFormats[b].grouping_separator))), g.addCommas(a, c);\n            },\n            diff: function(a, b, c) {\n                var d = {\n                };\n                if (((!twttr.is.object(a) || !twttr.is.object(b)))) {\n                    throw new Error(\"util.diff currently supports only single-level object comparison\");\n                }\n            ;\n            ;\n                for (var e in a) {\n                    ((c ? ((c(a[e], b[e]) || (d[e] = [a[e],b[e],]))) : ((((a[e] !== b[e])) && (d[e] = [a[e],b[e],])))));\n                ;\n                };\n            ;\n                for (var e in b) {\n                    ((d[e] || ((c ? ((c(b[e], a[e]) || (d[e] = [a[e],b[e],]))) : ((((a[e] !== b[e])) && (d[e] = [a[e],b[e],])))))));\n                ;\n                };\n            ;\n                return d;\n            },\n            trim: function(a) {\n                return a.replace(/(^\\s*|\\s*$)/g, \"\");\n            },\n            lazyBind: function() {\n                var a = {\n                }, b = function(b) {\n                    return JSBNG__setInterval(function() {\n                        $.each(a[b], function(a, b) {\n                            b.callback.call(b.node, b.JSBNG__event);\n                        }), a[b] = {\n                        };\n                    }, b);\n                }, c = {\n                }, d = 0, e = 0;\n                return function(f, g, i, j) {\n                    j = ((j || 1000)), a[j] = ((a[j] || {\n                    }));\n                    var k = $(f);\n                    ((i.id || (i.id = ++d))), ((k.data(\"lazy-id\") || k.data(\"lazy-id\", e++))), k.bind(g, function(b) {\n                        var c = ((((k.data(\"lazy-id\") + g)) + i.id));\n                        a[j][c] = {\n                            callback: i,\n                            JSBNG__event: b,\n                            node: f\n                        };\n                    }), ((c[j] || (c[j] = b(j), ((((!$.browser.msie && !twttr.selenium)) && ($(window).bind(\"JSBNG__blur\", function(a) {\n                        ((c[j] && (JSBNG__clearInterval(c[j]), c[j] = null)));\n                    }), $(window).bind(\"JSBNG__focus\", function() {\n                        ((c[j] || (c[j] = b(j))));\n                    })))))));\n                };\n            }(),\n            displayLength: function(a) {\n                if (((typeof a != \"string\"))) {\n                    throw new Error(\"displayLength() requires a single input of type string\");\n                }\n            ;\n            ;\n                var b = 0, c = 0, d = function(a, b) {\n                    var c = a.charCodeAt(b), d = \"\", e = \"\";\n                    if (((((55296 <= c)) && ((c <= 56319))))) {\n                        if (((a.length <= ((b + 1))))) {\n                            throw \"High surrogate without following low surrogate\";\n                        }\n                    ;\n                    ;\n                        d = a.charCodeAt(((b + 1)));\n                        if (((((56320 > d)) || ((d > 57343))))) {\n                            throw \"High surrogate without following low surrogate\";\n                        }\n                    ;\n                    ;\n                        return ((a.charAt(b) + a.charAt(((b + 1)))));\n                    }\n                ;\n                ;\n                    if (((((56320 <= c)) && ((c <= 57343))))) {\n                        if (((b === 0))) {\n                            throw \"Low surrogate without preceding high surrogate\";\n                        }\n                    ;\n                    ;\n                        e = a.charCodeAt(((b - 1)));\n                        if (((((55296 > e)) || ((e > 56319))))) {\n                            throw \"Low surrogate without preceding high surrogate\";\n                        }\n                    ;\n                    ;\n                        return !1;\n                    }\n                ;\n                ;\n                    return ((((((8206 == c)) || ((8207 == c)))) ? !1 : a.charAt(b)));\n                };\n                for (b = 0, c = 0; ((b < a.length)); b++) {\n                    if (((d(a, b) === !1))) {\n                        continue;\n                    }\n                ;\n                ;\n                    c++;\n                };\n            ;\n                return c;\n            },\n            objKeys: function(a) {\n                var b = [];\n                for (var c in a) {\n                    ((Object.prototype.hasOwnProperty.call(a, c) && b.push(c)));\n                ;\n                };\n            ;\n                return b;\n            },\n            arrayUniq: function(a) {\n                var b = 0;\n                while (((b < a.length))) {\n                    (((($.inArray(a[b], a) < b)) ? a.splice(b, 1) : b++));\n                ;\n                };\n            ;\n                return a;\n            },\n            arrayMap: function(a, b) {\n                var c = [];\n                for (var d = 0, e = a.length; ((d < e)); ++d) {\n                    c.push(b.call(a[d], a[d], d, a));\n                ;\n                };\n            ;\n                return c;\n            },\n            linkifyEntities: function(a, b) {\n                return ((((b.entities && b.entities.urls)) && twttr.each(b.entities.urls, function(b) {\n                    ((b.display_url && (a = a.replace(new RegExp(((((\"\\u003E\" + g.escapeRegExpChars(h(b.url)))) + \"\\u003C\\\\/a\\u003E\"))), function() {\n                        return ((((\"\\u003E\" + h(b.display_url))) + \"\\u003C/a\\u003E\"));\n                    })))), ((b.expanded_url && (a = a.replace(new RegExp(((((\"(href=[\\\"']\" + g.escapeRegExpChars(h(b.url)))) + \"[\\\"'])\"))), function(a, c) {\n                        return ((((((((((c + \" data-expanded-url=\\\"\")) + h(b.expanded_url))) + \"\\\" title=\\\"\")) + h(b.expanded_url))) + \"\\\"\"));\n                    }))));\n                }))), ((((((b.entities && b.entities.media)) && ((b.entities.media.length > 0)))) && twttr.each(b.entities.media, function(c) {\n                    var d = b.text.substring(c.indices[0], c.indices[1]);\n                    if (c.display_url) {\n                        var e = \"\";\n                        if (((c.sizes && c.sizes.medium))) {\n                            var f = c.sizes.medium;\n                            e = ((((((((\" data-media-h=\\\"\" + h(f.h))) + \"\\\" data-media-w=\\\"\")) + h(f.w))) + \"\\\"\"));\n                        }\n                    ;\n                    ;\n                        a = a.replace(new RegExp(((((\"\\u003E\" + g.escapeRegExpChars(h(d)))) + \"\\u003C\\\\/a\\u003E\"))), function() {\n                            return ((((((e + \" data-twitter-media-url=\\\"true\\\"\\u003E\")) + h(c.display_url))) + \"\\u003C/a\\u003E\"));\n                        });\n                    }\n                ;\n                ;\n                    if (c.expanded_url) {\n                        if (((twttr.domains.local.indexOf(\"staging\") === 0))) {\n                            var i = c.expanded_url.replace(/http[s]?:\\/\\/twitter.com/, ((\"//\" + twttr.domains.local)));\n                            a = a.replace(new RegExp(((((\"(href=[\\\"']\" + g.escapeRegExpChars(h(d)))) + \"[\\\"'])\"))), function() {\n                                return ((((((((((((\"href=\\\"\" + h(i))) + \"\\\" data-expanded-url=\\\"\")) + h(c.expanded_url))) + \"\\\" title=\\\"\")) + h(c.expanded_url))) + \"\\\"\"));\n                            });\n                        }\n                         else a = a.replace(new RegExp(((((\"(href=[\\\"']\" + g.escapeRegExpChars(h(d)))) + \"[\\\"'])\"))), function(a, b) {\n                            return ((((((((((b + \" data-expanded-url=\\\"\")) + h(c.expanded_url))) + \"\\\" title=\\\"\")) + h(c.expanded_url))) + \"\\\"\"));\n                        });\n                    ;\n                    }\n                ;\n                ;\n                }))), a;\n            },\n            linkify: function(a) {\n                var b = twttr.decider.isAvailable(((twttr.loggedIn ? \"swift_profile\" : \"swift_profile_logged_out\"))), c = {\n                    hashtagClass: \"twitter-hashtag pretty-link\",\n                    hashtagUrlBase: ((((\"/search/?src=\" + twttr.search.urlParamQuerySource.HASHTAG)) + \"&q=%23\")),\n                    symbolTag: \"s\",\n                    textWithSymbolTag: \"b\",\n                    linkAttributeBlock: function(a, b) {\n                        ((a.hashtag && (b[\"data-query-source\"] = twttr.search.searchQuerySource.HASHTAG))), ((a.url && (b.rel = \"nofollow\")));\n                    },\n                    cashtagClass: \"twitter-cashtag pretty-link\",\n                    cashtagUrlBase: \"/#!/search/%24\",\n                    usernameClass: \"twitter-atreply pretty-link\",\n                    usernameUrlBase: ((b ? \"/\" : \"/#!/\")),\n                    usernameIncludeSymbol: !0,\n                    listClass: \"twitter-listname pretty-link\",\n                    urlClass: \"twitter-timeline-link\",\n                    urlTarget: \"_blank\",\n                    suppressNoFollow: !0\n                };\n                return ((((twttr.decider && !twttr.decider.isAvailable(\"linkify_cashtags\"))) ? twttr.txt.autoLinkUsernamesOrLists(twttr.txt.autoLinkUrlsCustom(twttr.txt.autoLinkHashtags(a, c), c), c) : twttr.txt.autoLink(a, c)));\n            },\n            queryHighlight: function(a, b) {\n                var c = a.replace(/\"/gi, \"\"), d = b.replace(/<[^>]+>/g, \"\");\n                return twttr.txt.hitHighlight(b, g.highlightIndices(c, d), {\n                    tag: \"strong\"\n                });\n            },\n            escapeRegExpChars: function() {\n                var a = \"\\\\/{}|()[]?.*+:^$\";\n                return specialCharsMatcher = new RegExp(((((\"((\\\\\" + a.split(\"\").join(\")|(\\\\\"))) + \"))\")), \"gi\"), function(a) {\n                    return a.replace(specialCharsMatcher, function(a, b) {\n                        return ((\"\\\\\" + b));\n                    });\n                };\n            }(),\n            normalizeCharacters: function(a) {\n                return a.replace(/[ÄÅÖØÜäåöøüÆæß]/g, function(a) {\n                    switch (a) {\n                      case \"\\u00c4\":\n                        return \"AE\";\n                      case \"\\u00c5\":\n                        return \"AA\";\n                      case \"\\u00d6\":\n                    \n                      case \"\\u00d8\":\n                        return \"OE\";\n                      case \"\\u00dc\":\n                        return \"UE\";\n                      case \"\\u00e4\":\n                        return \"ae\";\n                      case \"\\u00e5\":\n                        return \"aa\";\n                      case \"\\u00f6\":\n                    \n                      case \"\\u00f8\":\n                        return \"oe\";\n                      case \"\\u00fc\":\n                        return \"ue\";\n                      case \"\\u00c6\":\n                        return \"AE\";\n                      case \"\\u00e6\":\n                        return \"ae\";\n                      case \"\\u00df\":\n                        return \"ss\";\n                      default:\n                        return a;\n                    };\n                ;\n                });\n            },\n            highlightIndices: function(a, b) {\n                a = g.escapeRegExpChars(a);\n                var c;\n                ((twttr.decider.isAvailable(\"escape_ampersands_in_search_highlighter\") ? c = twttr.util.arrayMap(a.split(/\\s+/), function(a) {\n                    return a.replace(\"&\", \"&amp;\");\n                }) : c = a.split(/\\s+/)));\n                var d = [];\n                for (var e in c) {\n                    d.push(g.normalizeCharacters(c[e]));\n                ;\n                };\n            ;\n                var f = [], i = ((((((((\"(\" + c.join(\")|(\"))) + \")|(\")) + d.join(\")|(\"))) + \")\")), j = \"!#%&+,-./:;\\u003C=\\u003E?@^_{|}~\".split(\"\").join(\"\\\\\"), k = new RegExp(((((((((((((\"(^|\\\\b|\\\\W|[\" + j)) + \"])(\")) + i)) + \")(\\\\b|\\\\s|$|[\")) + j)) + \"])\")), \"gi\");\n                return b.replace(k, function(a, b, c) {\n                    var d = ((arguments[((arguments.length - 2))] + b.length));\n                    f.push([d,((d + c.length)),]);\n                }), f;\n            },\n            inspect: function(a) {\n                JSBNG__console.clear();\n                var b = $(a), c = b.data(\"events\"), d = 0, e = 0, f = [], g = [];\n                for (key in c) {\n                    f.push(key), d++, g.push(\"\\u000a*******************\\u000a\"), g.push(((((\"Events for \" + key)) + \"\\u000a\\u000a\")));\n                    for (fn in c[key]) {\n                        var i = c[key][fn];\n                        e++, g.push(((i.toSource() + \"\\u000a\")));\n                    };\n                ;\n                };\n            ;\n                JSBNG__console.log(\"************* Summary *************\"), JSBNG__console.log(\"for target\", b), JSBNG__console.log(((d + \" types of events\")), f), JSBNG__console.log(e, \"Total Event Listeners\"), JSBNG__console.log(\"Event listeners assigned to target\"), JSBNG__console.log(g.join(\" \"));\n            },\n            regexSupplant: function(a, b) {\n                return b = ((b || \"\")), ((((typeof a != \"string\")) && (((((a.global && ((b.indexOf(\"g\") < 0)))) && (b += \"g\"))), ((((a.ignoreCase && ((b.indexOf(\"i\") < 0)))) && (b += \"i\"))), ((((a.multiline && ((b.indexOf(\"m\") < 0)))) && (b += \"m\"))), a = a.source))), new RegExp(a.replace(/#\\{(\\w+)\\}/g, function(a, b) {\n                    var c = ((twttr.regexps[b] || \"\"));\n                    return ((((typeof c != \"string\")) && (c = c.source))), c;\n                }), b);\n            },\n            leven: function(a, b) {\n                var c, d, e = a.length, f = b.length;\n                if (!e) {\n                    return f;\n                }\n            ;\n            ;\n                if (!f) {\n                    return e;\n                }\n            ;\n            ;\n                var g = [];\n                for (var i = 0; ((i <= e)); i++) {\n                    g[i] = [], g[i][0] = i;\n                ;\n                };\n            ;\n                for (var j = 0; ((j <= f)); j++) {\n                    g[0][j] = j;\n                ;\n                };\n            ;\n                for (var i = 1; ((i <= e)); i++) {\n                    c = a.charAt(((i - 1)));\n                    for (var j = 1; ((j <= f)); j++) {\n                        g[i][j] = Math.min(((g[((i - 1))][j] + 1)), ((g[i][((j - 1))] + 1)), ((g[((i - 1))][((j - 1))] + ((((c == b.charAt(((j - 1))))) ? 0 : 1)))));\n                    ;\n                    };\n                ;\n                };\n            ;\n                return g[e][f];\n            },\n            uriRegex: new RegExp(\"^(?:([^:/?#]+):)?(?://([^/?#]*))?([^?#]*)?(?:\\\\?([^#]*))?(?:#(.*))?$\", \"i\"),\n            noopInT1: function() {\n            \n            },\n            noopInP1: function() {\n            \n            }\n        };\n        g.Location = twttr.klass(function(a) {\n            ((a.match(/^\\/\\//) ? a = ((\"http:\" + a)) : ((a.match(/^[a-z]+:\\/\\//) || (a = ((\"http://\" + a)))))));\n            var b = a.match(/^([a-z]+:)\\/\\/([\\w\\-\\.]+)(\\:\\d+)?(.+)?/);\n            this.href = a, this.protocol = b[1], this.hostname = b[2], this.host = ((b[2] + ((b[3] || \"\")))), this.port = ((b[3] ? b[3].slice(1) : ((((b[1] === \"https:\")) ? \"443\" : \"80\"))));\n            var c = b[2].match(/\\.(\\w+)$/);\n            ((c ? this.extension = c[1] : this.ext = \"\"));\n            if (!b[4]) this.hash = \"\", this.search = \"\", this.pathname = \"/\";\n             else {\n                ((b[4].match(/^\\//) || (b[4] = ((\"/\" + b[4])))));\n                var d = b[4].split(\"?\"), e = b[4].split(\"#\");\n                this.pathname = d[0], ((/\\/$/.test(this.pathname) || (this.pathname = ((this.pathname + \"/\"))))), this.search = ((((d.length > 1)) ? ((\"?\" + function() {\n                    return d.shift(), d.join(\"\").replace(/#.*$/, \"\");\n                }())) : \"\")), this.hash = ((((e.length > 1)) ? ((\"#\" + e[1])) : \"\"));\n            }\n        ;\n        ;\n        }).methods({\n            query: function(a) {\n                return ((this.search ? ((g.params(this.search)[a] || \"\")) : \"\"));\n            }\n        }), g.WaitQueue = twttr.klass(function() {\n            this._methods = [], this._response = null, this._flushed = !1;\n        }).methods({\n            add: function(a) {\n                ((this._flushed ? a(this._response) : this._methods.push(a)));\n            },\n            flush: function(a) {\n                if (this._flushed) {\n                    return;\n                }\n            ;\n            ;\n                this._response = a, this._flushed = !0;\n                while (this._methods[0]) {\n                    this._methods.shift()(a);\n                ;\n                };\n            ;\n            }\n        }), twttr.provide(\"twttr.util\", g), a(g);\n    });\n});\nprovide(\"constants\", function(a) {\n    using().as(function(b) {\n        var c = {\n            sessionPollInterval: 10000,\n            directMessagePollInterval: 90000,\n            defaultScribeCategory: \"webclient\",\n            scribeHostName: \"scribe.twitter.com\",\n            maxUrlLength: 2083,\n            tcoLength: 20,\n            japaneseAdUrl: \"//pages.quantumads.com/transformer/async.js?callback=twttr.components.JapaneseAd.callbacks.\",\n            japaneseAdIframeUrl: \"//web-jp.ad-v.jp/adam/detect?tag=htm&cat=twitter.all&format=side_banner\",\n            keyCodes: {\n                enter: 13,\n                escape: 27,\n                esc: 27,\n                tab: 9,\n                del: 8,\n                spacebar: 32,\n                upArrow: 38,\n                downArrow: 40,\n                leftArrow: 37,\n                rightArrow: 39\n            },\n            which: {\n                period: 46\n            },\n            charCodes: {\n                space: 32,\n                questionMark: 63\n            },\n            placeTypes: {\n                city: 7\n            },\n            promotedContent: {\n                linkType: {\n                    JSBNG__URL: 1,\n                    PROFILE_PIC: 2,\n                    SCREEN_NAME: 3,\n                    HASHTAG: 4,\n                    USER_NAME: 5,\n                    DISPLAYED: 27,\n                    DETAIL: 28,\n                    DISMISS_WITHOUT_REASON: 31,\n                    DISMISS_UNINTERESTING: 32,\n                    DISMISS_REPETITIVE: 33,\n                    DISMISS_SPAM: 34,\n                    DISMISS_OTHER: 35,\n                    FOOTER_PROFILE: 36,\n                    PERMALINK: 40\n                }\n            },\n            videos: {\n                widescreen: \"16:9\",\n                fullscreen: \"4:3\"\n            },\n            jQueryEvents: \"blur hover focus focusin focusout load resize scroll unload click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup error\".split(\" \"),\n            errorCodes: {\n                notFollowing: \"NotFollowingErrorMessage\",\n                duplicateTweet: \"DuplicateTweetErrorMessage\",\n                malwareTweet: \"MalwareErrorMessage\",\n                dailyLimit: \"DailyLimitErrorMessage\",\n                tooLongTweet: \"TooLongErrorMessage\",\n                whale: \"DefaultErrorMessage\",\n                otherUserSuspended: \"OtherUserSuspendedErrorMessage\",\n                suspended: \"SuspendedErrorMessage\",\n                permission: \"PermissionErrorMessage\",\n                photoTimeout: \"PhotoTimeoutErrorMessage\",\n                followingLimitReached: \"FollowingLimitReachedErrorMessage\",\n                blockedFromFollowing: \"BlockedFromFollowingErrorMessage\",\n                tooLongListName: \"TooLongListNameErrorMessage\",\n                tooLongListDescription: \"TooLongListDescriptionErrorMessage\",\n                noLetterStartListName: \"NoLetterStartListNameErrorMessage\",\n                userNotFound: \"UserNotFoundErrorMessage\",\n                tweetNotFound: \"TweetNotFoundErrorMessage\"\n            },\n            regexps: {\n                JSBNG__name: /\\S+/,\n                usernameForSignup: /^[@＠]?([a-zA-Z0-9_]{1,15})$/,\n                username: /^[@＠]?([a-zA-Z0-9_]{1,22})$/,\n                usernameWithAt: /^[@＠]{1}([a-zA-Z0-9_]{1,22}) /,\n                usernameWithSpace: /^[@＠]{1}(\\w{1,22})\\s*$/,\n                suggestionCategoryPath: /\\/(who_to_follow|welcome)\\/interests\\/([^\\/]+)/,\n                userSearchPath: /(\\/(who_to_follow|welcome)\\/search\\/|\\/search\\/users\\/)([^\\/]+)/,\n                email: /^[\\w-]+([^@,\\s\\<\\>\\(\\)]*[\\w-]+)?\\@[\\w-]+(\\.[\\w-]+)*\\.[a-z]{2,}$/i,\n                rtlChar: /[\\u0600-\\u06FF]|[\\u0750-\\u077F]|[\\u0590-\\u05FF]|[\\uFE70-\\uFEFF]/gm,\n                dirMark: /\\u200e|\\u200f/gm,\n                rtlHashtag: /^#.*([\\u0600-\\u06FF]|[\\u0750-\\u077F]|[\\u0590-\\u05FF]|[\\uFE70-\\uFEFF])+/gm\n            },\n            recaptcha: {\n                srcUrl: ((twttr.recaptchaUrlForTest || \"https://www.google.com/recaptcha/api/js/recaptcha_ajax.js\")),\n                publicKey: \"6LfbTAAAAAAAAE0hk8Vnfd1THHnn9lJuow6fgulO\"\n            },\n            noob: {\n                dismissed: -2,\n                notNoob: -1,\n                total: 0,\n                invited: 1,\n                friendless: 2,\n                silent: 3,\n                talking: 4,\n                popular: 5,\n                lonely: 6,\n                struggling: 7\n            },\n            imageSizes: {\n                small: \"small\",\n                medium: \"medium\",\n                large: \"large\",\n                original: \"original\"\n            },\n            slideshow: {\n                fadeOutArrowTimeout: 2000,\n                fadeInArrowTimeout: 750,\n                fadeAnimationTime: 400,\n                photoMinHeight: 340,\n                videoMinHeight: 390,\n                videoMaxWidth: 480\n            },\n            clientEvent: {\n                itemType: {\n                    tweet: 0,\n                    promotedTweet: 1,\n                    popularTweet: 2,\n                    user: 3,\n                    promotedUser: 4,\n                    activity: 5,\n                    message: 6,\n                    story: 7\n                }\n            },\n            media: {\n                photoIcon: \"photo\"\n            },\n            users: {\n                maxLookupSize: 100\n            },\n            scribe: {\n                CLIENT_SIDE_USER: 0,\n                CLIENT_SIDE_APP: 2\n            }\n        };\n        twttr.constants = c, a(c);\n    });\n});\nprovide(\"cache\", function(a) {\n    using().as(function(b) {\n        twttr.provide(\"twttr.cache\"), twttr.provide(\"twttr.caches\"), twttr.klass(\"twttr.cache.Simple\", function() {\n            this._cache = {\n            };\n        }).methods({\n            set: function(a, b, c) {\n                this._cache[a] = {\n                    value: b,\n                    expire: ((twttr.is.number(c) ? ((this._getTime() + c)) : null))\n                };\n                var d = this._writeThrough();\n                return ((((d === !1)) && this.remove(a))), b;\n            },\n            get: function(a) {\n                return this._checkExpiry(a), ((this._cache[a] ? this._cache[a].value : undefined));\n            },\n            remove: function(a) {\n                delete this._cache[a], this._writeThrough();\n            },\n            clear: function() {\n                this._cache = {\n                }, this._writeThrough();\n            },\n            _checkExpiry: function(a) {\n                ((((((this._cache[a] && this._cache[a].expire)) && ((this._cache[a].expire < this._getTime())))) && this.remove(a)));\n            },\n            _getTime: function() {\n                return (new JSBNG__Date).getTime();\n            },\n            _writeThrough: function() {\n                return !0;\n            }\n        }), function() {\n            function a(a) {\n                return window.JSBNG__localStorage.getItem(a);\n            };\n        ;\n            function b(a, b) {\n                return window.JSBNG__localStorage.setItem(a, b);\n            };\n        ;\n            function c(a) {\n                return window.JSBNG__localStorage.removeItem(a);\n            };\n        ;\n            function d(a) {\n                return window.JSBNG__sessionStorage.getItem(a);\n            };\n        ;\n            function e(a, b) {\n                return window.JSBNG__sessionStorage.setItem(a, b);\n            };\n        ;\n            function f(a) {\n                return window.JSBNG__sessionStorage.removeItem(a);\n            };\n        ;\n            function g() {\n            \n            };\n        ;\n            var i, j, k = !1;\n            try {\n                i = ((((\"JSBNG__localStorage\" in window)) && ((window.JSBNG__localStorage !== null)))), j = ((((\"JSBNG__sessionStorage\" in window)) && ((window.JSBNG__sessionStorage !== null)))), k = !0;\n            } catch (l) {\n                i = !1, j = !1, k = !1;\n            };\n        ;\n            try {\n                if (JSBNG__document.documentElement.addBehavior) {\n                    k = !1, i = !0;\n                    var m = JSBNG__document.createElement(\"div\");\n                    JSBNG__document.body.appendChild(m), m.style.display = \"none\", m.addBehavior(\"#default#userData\"), m.load(\"phoenix\");\n                    var n = m.xmlDocument, o = n.documentElement;\n                    function p(a) {\n                        var b = o.childNodes, c, d = null;\n                        for (var e = 0, f = b.length; ((e < f)); e++) {\n                            c = b.item(e);\n                            if (((c.getAttribute(\"key\") == a))) {\n                                d = c;\n                                break;\n                            }\n                        ;\n                        ;\n                        };\n                    ;\n                        return d;\n                    };\n                ;\n                    function q(a) {\n                        var b = p(a), c = null;\n                        return ((b && (c = b.getAttribute(\"value\")))), c;\n                    };\n                ;\n                    function r(a, b) {\n                        var c = p(a);\n                        return ((c ? c.setAttribute(\"value\", b) : (c = n.createNode(1, \"item\", \"\"), c.setAttribute(\"key\", a), c.setAttribute(\"value\", b), o.appendChild(c)))), m.save(\"phoenix\"), b;\n                    };\n                ;\n                    function s(a) {\n                        var b = p(a);\n                        ((b && o.removeChild(b))), m.save(\"phoenix\");\n                    };\n                ;\n                    function t() {\n                        while (o.firstChild) {\n                            o.removeChild(o.firstChild);\n                        ;\n                        };\n                    ;\n                        m.save(\"phoenix\");\n                    };\n                ;\n                }\n            ;\n            ;\n            } catch (l) {\n                i = !1;\n            };\n        ;\n            var u = g, v = g, w = g, x = g;\n            ((i && (u = ((k ? b : r)), v = ((k ? a : q)), w = ((k ? c : s)), x = ((k ? c : t))))), twttr.klass(\"twttr.cache.LocalProvider\", function(a) {\n                twttr.cache.Simple.call(this), this._namespace = a, this._cache = JSON.parse(((v(a) || \"{}\"))), twttr.cache.LocalProvider._caches.push(this);\n            }).subclassOf(twttr.cache.Simple).statics({\n                hasLocalStorage: i,\n                _caches: [],\n                clearAll: function() {\n                    twttr.each(this._caches, function(a) {\n                        a.clear();\n                    }), this._caches = [];\n                }\n            }).methods({\n                _writeThrough: function() {\n                    try {\n                        return u(this._namespace, JSON.stringify(this._cache)), !0;\n                    } catch (a) {\n                        return !1;\n                    };\n                ;\n                }\n            });\n        }(), twttr.klass(\"twttr.cache.local.User\", function(a) {\n            this.JSBNG__name = a, this.cache = new twttr.cache.LocalProvider(\":USER:\"), this.user = ((this.cache.get(a) || this.cache.set(a, {\n                login: (new JSBNG__Date).getTime(),\n                store: {\n                }\n            }))), this.clean();\n        }).methods({\n            _getTime: function() {\n                return (new JSBNG__Date).getTime();\n            },\n            clean: function() {\n                this.user.login = (new JSBNG__Date).getTime();\n                var a = 0, b = (new JSBNG__Date).getTime(), c = null;\n                for (var d in this.cache._cache) {\n                    a++;\n                    var e = this.cache._cache[d], f = e.value.login;\n                    ((((f < b)) && (b = f, c = d)));\n                };\n            ;\n                ((((a > 3)) && this.cache.remove(c)));\n            },\n            remove: function(a) {\n                delete this.user.store[a], this.save();\n            },\n            get: function(a) {\n                var b = this.user.store[a];\n                if (!twttr.is.def(b)) {\n                    return undefined;\n                }\n            ;\n            ;\n                var c = this._getTime();\n                return ((((b.expire && ((b.expire < c)))) ? undefined : b.value));\n            },\n            set: function(a, b, c) {\n                var d = {\n                    value: b,\n                    expire: ((twttr.is.number(c) ? ((this._getTime() + c)) : null))\n                };\n                return this.user.store[a] = d, this.save(), b;\n            },\n            update: function(a, b, c) {\n                var d = ((twttr.is.def(this.user.store[a]) ? c : this.user.store[a].expire));\n                return this.set(a, b, d), b;\n            },\n            save: function() {\n                this.cache.set(this.JSBNG__name, this.user);\n            }\n        }), a({\n            Simple: twttr.cache.Simple,\n            LocalProvider: twttr.cache.LocalProvider,\n            User: twttr.cache.local.User,\n            caches: twttr.caches\n        });\n    });\n});\nprovide(\"singletons/namespaced_store\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.cache.NamespacedStore\", function(a) {\n            if (((this.cache_key === null))) {\n                throw \"You need to set a cache key to use a NamespacedStore.\";\n            }\n        ;\n        ;\n            this.cache = new twttr.cache.LocalProvider(a);\n        }).methods({\n            ttl: 60000,\n            cache_key: null,\n            clear: function() {\n                this.cache.remove(this.cache_key);\n            },\n            getData: function() {\n                var a = this.cache.get(this.cache_key);\n                try {\n                    return JSON.parse(a);\n                } catch (b) {\n                    return null;\n                };\n            ;\n            },\n            setData: function(a) {\n                this.cache.set(this.cache_key, JSON.stringify(a), this.ttl);\n            }\n        }), a(twttr.cache.NamespacedStore);\n    });\n});\nprovide(\"singletons/promoted_account_store\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.promotedAccountStoreSingleton\", function() {\n            twttr.cache.NamespacedStore.apply(this, [\"promoted_accounts\",]);\n        }).subclassOf(twttr.cache.NamespacedStore).methods({\n            ttl: 60000,\n            cache_key: \"promoted_account\",\n            getAccount: function() {\n                return this.getData();\n            },\n            hasAccount: function() {\n                return !!this.getAccount();\n            },\n            setAccount: function(a, b) {\n                var c = {\n                    id: a,\n                    impressionId: b\n                };\n                this.setData(c);\n            }\n        }), twttr.promotedAccountStore = new twttr.promotedAccountStoreSingleton, a(twttr.promotedAccountStore);\n    });\n});\nprovide(\"singletons/promoted_tweet_store\", function(a) {\n    using(\"libwrap/jquery\").as(function(b, $) {\n        var c = \"h\";\n        twttr.klass(\"twttr.promotedTweetStoreSingleton\", function() {\n            twttr.cache.NamespacedStore.apply(this, [\"promoted_tweets\",]);\n        }).subclassOf(twttr.cache.NamespacedStore).methods({\n            ttl: 1800000,\n            cache_key: \"promoted_tweet\",\n            clear: function() {\n                this.constructor.uber.clear.apply(this, arguments), $.cookie(c, null);\n            },\n            getTweetInfo: function() {\n                if (!twttr.decider.isAvailable(\"ptw_reinjection\")) {\n                    return null;\n                }\n            ;\n            ;\n                var a = this.getData();\n                return ((((((a && a.data)) && a.data.promoted_status)) ? (this.clear(), null) : a));\n            },\n            hasTweetInfo: function() {\n                return ((twttr.decider.isAvailable(\"ptw_reinjection\") ? !!this.getTweetInfo() : !1));\n            },\n            setTweetInfo: function(a, b, d) {\n                if (!twttr.decider.isAvailable(\"ptw_reinjection\")) {\n                    return;\n                }\n            ;\n            ;\n                var e = [b.id_str,a,((d ? \"po\" : \"pr\")),].join(\",\"), f = new JSBNG__Date;\n                f.setTime(((f.getTime() + this.ttl)));\n                var b = {\n                    olderTweetId: a,\n                    data: b\n                };\n                this.setData(b), $.cookie(c, e, {\n                    expires: f\n                });\n            }\n        }), twttr.promotedTweetStore = new twttr.promotedTweetStoreSingleton, a(twttr.promotedTweetStore);\n    });\n});\nprovide(\"decider\", function(a) {\n    using(\"util\").as(function(b) {\n        twttr.klass(\"twttr.Decider\", function(a, b) {\n            a = ((a || {\n            })), this._updateFeatures(a), b = ((b || this.constructor.DEFAULT_REFRESH_INTERVAL)), JSBNG__setInterval(twttr.bind(this, this.updateFeatures), b);\n        }).statics({\n            DECIDER_URL: \"/account/available_features\",\n            DEFAULT_REFRESH_INTERVAL: 180000\n        }).methods(twttr.EventProvider).methods({\n            features: function() {\n                return ((this._features || {\n                }));\n            },\n            isActivityEnabled: function() {\n                return this.isAvailable(\"activity_read\");\n            },\n            isExpando: function() {\n                return ((twttr.expando || twttr.isT1));\n            },\n            isInfiniteScroll: function() {\n                return ((this.isAvailable(\"infinite_scroll\") && !(($.browser.msie && ((parseInt($.browser.version, 10) < 8))))));\n            },\n            hasInlineReplies: function() {\n                return ((twttr.decider.isAvailable(\"inline_reply_box\") || ((twttr.abdecider.choose(\"inline_reply_box_197\") === \"reply_box\"))));\n            },\n            isAvailable: function(a) {\n                return ((((twttr.deciderOverrides && ((twttr.deciderOverrides[a] !== undefined)))) ? !!twttr.deciderOverrides[a] : ((twttr.is.fn(a) ? a() : ((this._features ? !!this._features[a] : !1))))));\n            },\n            featureUrl: function(a) {\n                var b = ((a && a.spoof_country));\n                return ((b ? ((((this.constructor.DECIDER_URL + \"?spoof_country=\")) + b)) : this.constructor.DECIDER_URL));\n            },\n            updateFeatures: function() {\n                var a = twttr.API._requestCache.get(\"account/available_features\", {\n                });\n                ((a ? this._updateFeatures(a) : this._makeRemoteRequest()));\n            },\n            _makeRemoteRequest: function(a) {\n                $.getJSON(this.featureUrl(b.util.params()), twttr.bind(this, function(b) {\n                    ((b && this._updateFeatures(b))), ((a && a()));\n                }));\n            },\n            _updateFeatures: function(a, c) {\n                var d = ((this._features || {\n                }));\n                this._features = a;\n                if (c) {\n                    return;\n                }\n            ;\n            ;\n                var e = b.util.diff(d, this._features);\n                for (var f in e) {\n                    var g = {\n                        key: f,\n                        previous: e[f][0],\n                        current: e[f][1]\n                    };\n                    this.trigger(\"keyChanged\", g);\n                };\n            ;\n            },\n            goodAtCss: function() {\n                return (($.support.boxModel && !(($.browser.msie && ((parseFloat($.browser.version) <= 6))))));\n            }\n        }), twttr.decider = new twttr.Decider, signal(\"\\u003Edecider\"), a(twttr.decider);\n    });\n});\nprovide(\"multiGlobals/scribble\", function(a) {\n    using(\"constants\").as(function(b) {\n        twttr.klass(\"twttr.ScribeBuffer\", function() {\n            if (twttr.ScribeBuffer.instance) {\n                throw \"This is a singleton, yo\";\n            }\n        ;\n        ;\n            twttr.ScribeBuffer.instance = this, this.ajax = $.ajax, this.reset();\n            try {\n                var a = JSBNG__sessionStorage.getItem(\"ScribeTransport\");\n                if (a) {\n                    var b = this;\n                    twttr.each(JSON.parse(((((\"[\" + a)) + \"]\"))), function(a) {\n                        b.addData(a);\n                    }), JSBNG__sessionStorage.removeItem(\"ScribeTransport\");\n                }\n            ;\n            ;\n            } catch (c) {\n            \n            };\n        ;\n        }).methods({\n            getBuffer: \"\",\n            postBuffer: [],\n            maxLength: null,\n            reset: function() {\n                this.getBuffer = \"\", this.postBuffer = [];\n                var a = ((\"q=\" + (+(new JSBNG__Date)).toString().slice(-4)));\n                this.path = \"/scribe\", this.url = ((((this.path + \"?\")) + a)), ((window.JSBNG__location.hostname.match(/^(www\\.|[A-Z]{2}\\.|^)twitter.com$/i) && (this.url = ((((((window.JSBNG__location.protocol + \"//\")) + b.constants.scribeHostName)) + this.url))))), this.maxLength = ((((((twttr.decider.isAvailable(\"use_scribe_post\") ? ((twttr.scribeBufferSize || 10)) : 1)) * b.constants.maxUrlLength)) - this.url.length));\n            },\n            _isEmpty: function() {\n                return ((((this.getBuffer.length === 0)) && ((this.postBuffer.length === 0))));\n            },\n            send: function(a) {\n                if (this._isEmpty()) {\n                    return;\n                }\n            ;\n            ;\n                ((twttr.decider.isAvailable(\"use_scribe_post\") ? this.ajax({\n                    url: this.path,\n                    data: {\n                        log: this.postBuffer\n                    },\n                    type: \"POST\",\n                    async: !a\n                }) : (new JSBNG__Image).src = ((this.url + this.getBuffer)))), this.reset();\n            },\n            getPostBufferForForm: function() {\n                var a = this.postBuffer;\n                return this.reset(), JSON.stringify(a);\n            },\n            sendReliabilityEvent: function(a) {\n                this.ajax({\n                    url: this.path,\n                    data: {\n                        reliability_event: \"true\"\n                    },\n                    type: \"POST\",\n                    success: a\n                });\n            },\n            addData: function(a) {\n                var b = JSON.stringify(a), c = this._encodeStringifiedData(b);\n                ((((c.length > twttr.ScribeBuffer.instance.maxLength)) && (a = this._truncateData(a), b = JSON.stringify(a), c = this._encodeStringifiedData(b)))), ((((((((this.url.length + this.getBuffer.length)) + c.length)) > this.maxLength)) && this.send())), this.getBuffer += ((\"&\" + c)), this.postBuffer.push(b);\n                if (window.scribeConsole) {\n                    var d = ((((window.JSBNG__location.protocol + \"//\")) + window.JSBNG__location.host));\n                    try {\n                        window.scribeConsole.JSBNG__postMessage(a, d);\n                    } catch (e) {\n                        var f = ((((\"unserializable scribe data [\" + category)) + \"]\"));\n                        window.scribeConsole.JSBNG__postMessage({\n                            error: f,\n                            event_data: JSON.stringify(a)\n                        }, d);\n                    };\n                ;\n                }\n            ;\n            ;\n                ((twttr.is.array(twttr.allScribeEvents) && (twttr.allScribeEvents.push(b), JSBNG__localStorage.twttrAllScribeEvents = JSON.stringify(twttr.allScribeEvents))));\n                if ((($.cookie(\"phx_scribe_now\") == \"1\"))) {\n                    var g = this;\n                    window.JSBNG__setTimeout(function() {\n                        g.send();\n                    }, 0);\n                }\n            ;\n            ;\n            },\n            _encodeStringifiedData: function(a) {\n                return ((\"log%5B%5D=\" + encodeURIComponent(a)));\n            },\n            _truncateData: function(a) {\n                var b = {\n                };\n                for (var c in a) {\n                    ((((a.hasOwnProperty(c) && ((typeof a[c] != \"object\")))) && (b[c] = a[c])));\n                ;\n                };\n            ;\n                return b._truncated_for_scribe = !0, b;\n            }\n        }), twttr.klass(\"twttr.Scribbler\", function(a, c, d, e, f) {\n            this.expectedToHaveComponent = ((arguments.length > 0)), this.component = ((a || \"\")), this.contextData = ((c || {\n            })), this.category = ((d || b.constants.defaultScribeCategory)), this.eventPrefix = ((e || \"\")), this.options = ((f || {\n            }));\n        }).methods({\n            DECIDERED_CATEGORIES: {\n                client_event: 1\n            },\n            spawn: function(a, b) {\n                var c = twttr.merge({\n                }, this.contextData, ((a || {\n                })));\n                return new this.constructor(this.component, c, this.category, ((b || this.eventPrefix)), this.options);\n            },\n            _contextData: function() {\n                return twttr.merge({\n                }, this.contextData);\n            },\n            _mapAPIObjectData: function(a) {\n                var b = {\n                };\n                for (var c in a) {\n                    ((((((a[c] && a[c].array)) && twttr.is.array(a[c].array))) ? b[c] = a[c].array : b[c] = a[c]));\n                ;\n                };\n            ;\n                return b;\n            },\n            _isCategoryAvailable: function(a) {\n                return ((!this.DECIDERED_CATEGORIES[a] || twttr.decider.isAvailable(((\"scribe_\" + a)))));\n            },\n            scribe: function(a, b, c, d) {\n                if (((this.expectedToHaveComponent && !this.component))) {\n                    return;\n                }\n            ;\n            ;\n                if (((!twttr.decider.isAvailable(\"phoenix_scribe\") || !this._isCategoryAvailable(((c || this.category)))))) {\n                    return;\n                }\n            ;\n            ;\n                d = ((d || {\n                })), b = ((b || {\n                })), ((((twttr && !twttr.loggedIn)) && (b.user_id = 0))), b.page = twttr.audit.currentPage(), b._category_ = ((c || this.category)), b.ts = (new JSBNG__Date).getTime();\n                if (filter = ((d.filter || this.options.filter))) {\n                    b._filter_ = d.filter;\n                }\n            ;\n            ;\n                b = twttr.merge(this._contextData(), b);\n                for (var e in b) {\n                    ((twttr.is.fn(b[e]) && (b[e] = b[e].call(this.component, a, b, c))));\n                ;\n                };\n            ;\n                if (a) {\n                    ((twttr.is.fn(this.eventPrefix) ? a = this.eventPrefix.call(this.component, a) : a = ((this.eventPrefix + a))));\n                    var f = twttr.merge({\n                        event_name: a\n                    }, b);\n                    twttr.ScribeBuffer.instance.addData(this._mapAPIObjectData(f));\n                }\n            ;\n            ;\n            }\n        }), function() {\n            twttr.ScribeBuffer.instance = new twttr.ScribeBuffer, twttr.Scribbler.global = new twttr.Scribbler, window.scribble = twttr.scribble = function() {\n                return twttr.Scribbler.global.scribe.apply(twttr.Scribbler.global, arguments);\n            }, $(window).bind(\"unload\", function() {\n                twttr.ScribeBuffer.instance.send(!0);\n            }), $(JSBNG__document).delegate(\"form\", \"submit\", function() {\n                if (twttr.decider.isAvailable(\"scribe_form_piggyback\")) {\n                    var a = $(this).JSBNG__find(\"input[name='scribe_log']\"), b = $(this).JSBNG__find(\"input[name='reliability_event']\");\n                    ((((a.length && ((b.val() != \"true\")))) && a.val(twttr.ScribeBuffer.instance.getPostBufferForForm())));\n                }\n            ;\n            ;\n            }), (($.browser.msie ? JSBNG__document.JSBNG__onfocusout = function() {\n                twttr.ScribeBuffer.instance.send();\n            } : $(window).JSBNG__blur(function() {\n                twttr.ScribeBuffer.instance.send();\n            })));\n            var a = ((twttr.isPreflight || window.JSBNG__location.host.match(/^(localhost|staging)/gi)));\n            ((((a && window.JSBNG__postMessage)) && $(JSBNG__document).keypress(function(a) {\n                if (((((((a.charCode == 205)) && a.shiftKey)) && a.altKey))) {\n                    var b = \"menubar=no,toolbar=no,personalbar=no,location=no,resizable=yes,status=no,dependent=yes,height=600,width=600,screenX=100,screenY=100,scrollbars=yes\";\n                    window.scribeConsole = window.open(\"/scribe/console\", \"scribe_console\", b);\n                }\n            ;\n            ;\n            })));\n        }(), a();\n    });\n});\nprovide(\"abdecider\", function(a) {\n    using(\"util\").as(function(b) {\n        twttr.klass(\"twttr.AbDecider\", function(a, b) {\n            this._impressions = {\n            }, this._updateExperiments(((a || {\n            }))), b = ((b || this.constructor.DEFAULT_REFRESH_INTERVAL));\n            if (((b > 0))) {\n                var c = this;\n                JSBNG__setTimeout(function() {\n                    JSBNG__setInterval(twttr.bind(c, c.updateExperiments), b);\n                }, ((b / 2)));\n            }\n        ;\n        ;\n        }).statics({\n            ABDECIDER_URL: \"/account/available_ab_buckets\",\n            LOG_EVENTS: !1,\n            DEFAULT_REFRESH_INTERVAL: -1\n        }).methods(twttr.EventProvider).methods({\n            experiments: function() {\n                return ((this._experiments || {\n                }));\n            },\n            choose: function(a, b) {\n                if (!this._experiments) {\n                    return \"\";\n                }\n            ;\n            ;\n                var c = this._experiments[a];\n                if (((!c || !c.bucket))) {\n                    return \"\";\n                }\n            ;\n            ;\n                var d = c.bucket, e = c.experiment_key;\n                return ((b || ((((this._impressions[e] != d)) && (this._trackInternal(a), this._impressions[e] = d))))), d;\n            },\n            chooseWithoutImpression: function(a) {\n                return this.choose(a, !0);\n            },\n            track: function(a, b, c) {\n                if (((b == this.constructor.AB_IMPRESSION_EVENT))) {\n                    return;\n                }\n            ;\n            ;\n                this._trackInternal(a, b, c);\n            },\n            updateExperiments: function() {\n                $.getJSON(this.constructor.ABDECIDER_URL, twttr.bind(this, function(a) {\n                    ((a && this._updateExperiments(a)));\n                }));\n            },\n            _updateExperiments: function(a, c) {\n                var d = ((this._experiments || {\n                }));\n                this._experiments = a;\n                if (c) {\n                    return;\n                }\n            ;\n            ;\n                var e = b.util.diff(d, this._experiments, function(a, b) {\n                    return ((((!a || !b)) ? !1 : ((((a.bucket === b.bucket)) && ((a.version === b.version))))));\n                });\n                for (var f in e) {\n                    var g = {\n                        key: f,\n                        previous: e[f][0],\n                        current: e[f][1]\n                    };\n                    this.trigger(\"keyChanged\", g);\n                };\n            ;\n            },\n            set: function(a, b) {\n                if (((!this._experiments || !this._experiments[a]))) {\n                    return;\n                }\n            ;\n            ;\n                this._experiments[a] = twttr.merge({\n                }, this._experiments[a], {\n                    bucket: b\n                });\n            },\n            remove: function(a) {\n                this._experiments[a] = null;\n            },\n            _trackInternal: function(a, b, c) {\n                if (!this._experiments) {\n                    return;\n                }\n            ;\n            ;\n                var d = this._experiments[a];\n                if (!d) {\n                    return;\n                }\n            ;\n            ;\n                var e = twttr.merge(((c || {\n                })), {\n                    bucket: d.bucket,\n                    experiment_key: d.experiment_key,\n                    version: d.version\n                });\n                ((this.constructor.LOG_EVENTS && JSBNG__console.log(((((a + \": \")) + ((b || \"impression\")))))));\n                if (b) {\n                    var f = b.replace(/[^0-9A-Z]+/gi, \"_\").toLowerCase(), g = ((((((((\"web:ddg:\" + d.experiment_key)) + \"::\")) + f)) + \":track\"));\n                    scribble(g, e, \"client_event\");\n                }\n                 else scribble(((((\"web:ddg:\" + d.experiment_key)) + \":::experiment\")), e, \"client_event\");\n            ;\n            ;\n            }\n        }), twttr.abdecider = new twttr.AbDecider, signal(\"\\u003Eab_decider\"), a(twttr.abdecider);\n    });\n});\nprovide(\"app\", function(a) {\n    using(\"util\").as(function(b) {\n        twttr.provide(\"twttr.app\", twttr.merge({\n            init: function(a) {\n                var b = this;\n                this.signal(\"init\"), this.$globalActions = $(\"#global-actions\");\n                var c = [\"\\u003EallCodeLoaded\",];\n                ((a && c.push(\"\\u003EwokeUp\"))), using(c, function() {\n                    b._fullyLoaded = !0, b.signal(\"fullyLoaded\");\n                });\n            },\n            fullyLoaded: function() {\n                return !!this._fullyLoaded;\n            },\n            switchToPage: function(a) {\n                this.trigger(\"switchToPage\", a.toLowerCase());\n                if (((this.currentPageName() !== a))) {\n                    var c = this.currentPage();\n                    this._currentPageName = a;\n                    var d = b.util.capitalize(b.util.camelize(a)), e = !1, f = this.pages[a];\n                    ((f || (f = this.pages[a] = new twttr.PagePromise(d), f.whenUnavailable(function() {\n                        twttr.app.switchToPage(\"404\").send(\"notFound\");\n                    }), f.bind(\"loginRequired\", function() {\n                        twttr.ScribeBuffer.instance.send(), twttr.app.switchToPage(\"Login\").send(\"loginRequired\");\n                    }), f.bind(\"notFound\", function() {\n                        twttr.app.switchToPage(\"404\").send(\"notFound\");\n                    }), f.build(), e = !0))), ((c ? (c.send(\"JSBNG__onSwitchAway\"), c.$node.detach(), $(\"#page-container\").empty().append(f.$node)) : f.JSBNG__one(\"rendered\", function() {\n                        (((($(\"#page-container\").has(f.$node).length > 0)) || $(\"#page-container\").empty().append(f.$node)));\n                    }))), this.highlightGlobalNav(a), f.send(\"JSBNG__onSwitchTo\"), ((e && (f.send(\"JSBNG__onFirstSwitch\"), f.send(\"shouldAutoRender\", function(a) {\n                        ((a && f.send(\"render\")));\n                    })))), ((((!c && window.ttft)) && (window.ttft.firstPage = a)));\n                }\n                 else this.currentPage().send(\"initializeProfiler\");\n            ;\n            ;\n                return this.currentPage();\n            },\n            highlightGlobalNav: function(a, b) {\n                a = a.toLowerCase(), this.$globalActions.JSBNG__find(\"li.active[data-global-action]\").removeClass(\"active\"), ((((((a === \"profile\")) && ((b == undefined)))) && (b = twttr.helpers.isCurrentUser($(\"div.profile-header\").attr(\"data-screen-name\"))))), ((((a && ((((a !== \"profile\")) || b)))) && this.$globalActions.JSBNG__find(((((\"li[data-global-action='\" + a)) + \"']\"))).addClass(\"active\")));\n            },\n            currentPage: function() {\n                return this.pages[this._currentPageName];\n            },\n            currentPageName: function() {\n                return this._currentPageName;\n            },\n            getPage: function(a) {\n                return this.pages[a];\n            },\n            isOnPage: function(a) {\n                return ((a === this.currentPageName()));\n            },\n            recalculatePadding: function() {\n                var a = (($(\"div.js-banners\").children().length <= 1));\n                ((a ? this.resetPadding() : this._resizeTopBar()));\n            },\n            _resizeTopBar: function() {\n                var a = 20, b = ((twttr.isT1 ? $(\".js-banners\").height() : (($(\".js-topbar\").height() + a)))), c = $(\"#page-outer\");\n                c.css({\n                    \"padding-top\": b\n                }), ((twttr.isT1 && $(\"#message-drawer\").css({\n                    marginTop: b\n                }))), this._resizeDetailsPane();\n            },\n            _resizeDetailsPane: function() {\n                var a = this.currentPage();\n                ((a && a.send(\"resizeDetailsPane\")));\n            },\n            _repositionDetailsPane: function() {\n                var a = twttr.app.currentPage();\n                ((a && a.send(\"repositionDetailsPane\")));\n            },\n            resetPadding: function() {\n                var a = $(\"#page-outer\");\n                a.css({\n                    \"padding-top\": \"\"\n                }), ((twttr.isT1 && $(\"#message-drawer\").css({\n                    marginTop: \"\"\n                }))), this._resizeDetailsPane();\n            },\n            addComponentToAppBody: function(a) {\n                a.bind(\"destroyed\", function() {\n                    twttr.app.recalculatePadding(), twttr.app._repositionDetailsPane();\n                }), $(\"#page-outer\").prepend(a.$node);\n            },\n            pages: {\n            },\n            caches: {\n                deletedTweets: new twttr.cache.LocalProvider(\"deleted_tweets\"),\n                dmThreads: new twttr.cache.LocalProvider(\"dm_threads\"),\n                draftTweets: new twttr.cache.LocalProvider(\"draft_tweets\"),\n                searchQuerySource: new twttr.cache.LocalProvider(\"__searchQuerySource__:source\")\n            }\n        }, twttr.EventProvider)), a(twttr.app);\n    });\n});\nprovide(\"singletons/external_url_store\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.externalURLStoreSingleton\", function() {\n            twttr.cache.NamespacedStore.apply(this, [\"external_urls\",]);\n        }).subclassOf(twttr.cache.NamespacedStore).methods({\n            ttl: 3600000,\n            cache_key: \"external_url\",\n            minimumDuration: 1000,\n            scribeFocusAfterClick: function() {\n                if (!twttr.decider.isAvailable(\"eurl_dwell_time_store\")) {\n                    return;\n                }\n            ;\n            ;\n                var a = this.getData();\n                if (a) {\n                    var b = ((this.currentTimeAsInt() - a.clickTime));\n                    if (((b > this.minimumDuration))) {\n                        var c = twttr.merge(a.scribeData, {\n                            duration_ms: b\n                        });\n                        trackClient({\n                            action: \"refocus\"\n                        }, c), this.clear();\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            },\n            setData: function(a, b) {\n                if (!twttr.decider.isAvailable(\"eurl_dwell_time_store\")) {\n                    return;\n                }\n            ;\n            ;\n                if (this.isNotTwitterURL(a)) {\n                    var c = twttr.merge(b.scribeData, {\n                        event_info: \"external_link\",\n                        url: a\n                    }), d = {\n                        clickTime: this.currentTimeAsInt(),\n                        scribeData: c\n                    };\n                    this.constructor.uber.setData.apply(this, [d,]);\n                }\n            ;\n            ;\n            },\n            isNotTwitterURL: function(a) {\n                var b = a.split(\"/\");\n                return ((((b[0].indexOf(\"twitter.com\") == -1)) && ((b[2].indexOf(\"twitter.com\") == -1))));\n            },\n            currentTimeAsInt: function() {\n                return +(new JSBNG__Date);\n            }\n        }), twttr.externalURLStore = new twttr.externalURLStoreSingleton, twttr.app.waitForSignal(\"init\", function() {\n            twttr.externalURLStore.scribeFocusAfterClick();\n        }), a(twttr.externalURLStore);\n    });\n});\nprovide(\"singletons/Router\", function(a) {\n    using().as(function(b) {\n        var c = /^\\/*/, d = /\\/*$/;\n        twttr.klass(\"twttr.Router\", function() {\n            this._routes = [], this.routeMethodsForMustache = {\n            }, this.routeMethods = {\n            }, this.viewedPagesCount = 0, this.pageViewsPerRefresh = 50, this.routingEnabled = !0, this.swiftRoutes = {\n            };\n        }).statics(twttr.EventProvider).statics({\n            match: function(a, b) {\n                a = this.normalizePath(a), b = this.normalizePath(b);\n                var c = {\n                };\n                if (((a === b))) {\n                    return c;\n                }\n            ;\n            ;\n                if (((a === \"\"))) {\n                    return !1;\n                }\n            ;\n            ;\n                var d = a.split(\"/\"), e = b.split(\"/\");\n                if (((d.length !== e.length))) {\n                    return !1;\n                }\n            ;\n            ;\n                for (var f = 0; ((f < d.length)); f++) {\n                    if (((e[f].charAt(0) === \":\"))) {\n                        if (d[f].match(/^\\s*$/)) {\n                            return !1;\n                        }\n                    ;\n                    ;\n                        c[e[f].slice(1)] = decodeURIComponent(d[f]);\n                    }\n                     else if (((d[f] !== e[f]))) {\n                        return !1;\n                    }\n                    \n                ;\n                ;\n                };\n            ;\n                return c;\n            },\n            generatePathFunction: function(a) {\n                var b = this;\n                return function(c) {\n                    var d = b.supplantPath(a, c);\n                    return ((((((d === !1)) && !twttr.isTestEnv)) && JSBNG__console.error(\"Failed to generate a path\", a, c))), d;\n                };\n            },\n            supplantPath: function(a, b) {\n                var c = a.split(\"#\").join(\"/#\").split(\"=\").join(\"=/\").split(\"/\"), d = [];\n                for (var e = 0; ((e < c.length)); e++) {\n                    var f = c[e], g = !1;\n                    ((((f.charAt(0) === \"#\")) && (f = f.slice(1), g = !0)));\n                    if (((f.charAt(0) === \":\"))) {\n                        var i = f.slice(1);\n                        if (((typeof b[i] == \"undefined\"))) {\n                            return !1;\n                        }\n                    ;\n                    ;\n                        f = b[i], ((((typeof f == \"function\")) && (f = f.call(b)))), f = encodeURIComponent(f);\n                    }\n                ;\n                ;\n                    ((g && (f = ((\"#\" + f))))), d.push(f);\n                };\n            ;\n                return d.join(\"/\").split(\"=/\").join(\"=\").split(\"/#\").join(\"#\");\n            },\n            sanitizeRedirectUrl: function(a) {\n                var b = a, c = b.match(twttr.util.uriRegex), d = c[1];\n                return ((((d && ((d.indexOf(\"javascript\") >= 0)))) && (b = \"http://twitter.com/\"))), b;\n            },\n            performRedirect: function(a) {\n                window.JSBNG__location.assign(this.sanitizeRedirectUrl(a));\n            },\n            getWindowLocation: function() {\n                return window.JSBNG__location;\n            },\n            getCurrentPath: function() {\n                var a = this.getWindowLocation(), b = a.href;\n                if (((((a.hash === \"\")) && ((b.indexOf(\"#\") !== -1))))) {\n                    var c = a.pathname.split(\"/\");\n                    for (var d = 0; ((d < c.length)); d++) {\n                        c[d] = encodeURIComponent(c[d]);\n                    ;\n                    };\n                ;\n                    b = ((a.origin + c.join(\"/\")));\n                }\n            ;\n            ;\n                return this.getPathFromHref(b);\n            },\n            getPathFromHref: function(a) {\n                var b = a.split(\"/\").slice(2).join(\"/\");\n                ((((b.indexOf(\"#\") === -1)) && (b += \"#\")));\n                var c = b.split(\"#\"), d = c[0], e = c[1];\n                ((((d.indexOf(\"/\") === -1)) && (d += \"/\")));\n                var f = d.split(\"/\").slice(1).join(\"/\");\n                return ((((f.indexOf(\"?\") >= 0)) && (f = f.slice(0, f.indexOf(\"?\"))))), ((((e.indexOf(\"?\") >= 0)) && (e = e.slice(0, e.indexOf(\"?\"))))), ((twttr.decider.isAvailable(\"swift_home_timeline\") && (f = f.replace(/^(i$|i\\/)/, \"\")))), ((((((\"/\" + f)) + \"#\")) + e));\n            },\n            getCurrentQueryStringParams: function() {\n                return this.getQueryStringParamsFromHref(window.JSBNG__location.href);\n            },\n            getQueryStringParamsFromHref: function(a) {\n                var b = a.split(\"#\"), c = ((b[0].split(\"?\")[1] || \"\")), d = ((((b[1] || \"\")).split(\"?\")[1] || \"\"));\n                return twttr.merge(this.parseQueryString(c), this.parseQueryString(d));\n            },\n            parseQueryString: function(a) {\n                var b = a.split(\"&\"), c = {\n                };\n                for (var d = 0; ((d < b.length)); d++) {\n                    if (b[d]) {\n                        var e = b[d].split(\"=\");\n                        c[decodeURIComponent(e[0])] = ((e[1] ? decodeURIComponent(e[1].replace(/\\+/g, \"%20\")) : !0));\n                    }\n                ;\n                ;\n                };\n            ;\n                return c;\n            },\n            getHashUpdate: function(a, b) {\n                var c = this.normalizePath(a), d = this.normalizePath(b);\n                if (((c === d))) {\n                    return !1;\n                }\n            ;\n            ;\n                a = a.split(\"/#\").join(\"#\"), b = b.split(\"/#\").join(\"#\"), ((((a.indexOf(\"#\") === -1)) && (a += \"#\"))), ((((b.indexOf(\"#\") === -1)) && (b += \"#\")));\n                var e = a.split(\"#\"), f = b.split(\"#\");\n                return ((((e[0] === f[0])) ? ((\"#\" + f[1])) : ((((((e[1] === \"\")) && ((f[1] === \"\")))) ? ((\"#\" + f[0].slice(a.length))) : ((\"#\" + d))))));\n            },\n            normalizePath: function(a) {\n                if (((twttr.griffin && twttr.griffin.current))) {\n                    for (var b = 0; ((b < twttr.griffin.current.length)); b++) {\n                        if (((a.toLowerCase() == ((\"/#\" + twttr.griffin.current[b].toLowerCase()))))) {\n                            return a.toLowerCase();\n                        }\n                    ;\n                    ;\n                    };\n                }\n            ;\n            ;\n                return this.trimSlashes(a.replace(/\\/?#(!|%21)?\\/?/g, \"/\"));\n            },\n            shouldRedirect: function(a, b) {\n                var c = b.split(\"#\"), d = a.split(\"#\");\n                return ((((this.trimSlashes(c[0]) === this.trimSlashes(d[0]))) ? !1 : ((((this.trimSlashes(c[1]) === this.trimSlashes(d[0]))) ? !1 : !0))));\n            },\n            trimSlashes: function(a) {\n                return ((a ? a.replace(c, \"\").replace(d, \"\") : a));\n            },\n            detectHistorySupport: function() {\n                return ((!!window.JSBNG__history && !!JSBNG__history.pushState));\n            }\n        }).methods(twttr.EventProvider).methods({\n            startRouting: function() {\n                this._callCurrentRoutingAction(), this._listenToUrl();\n            },\n            route: function(a, b, c) {\n                var d = this._addRouteMethods(a, b);\n                return this._routes.push({\n                    JSBNG__name: a,\n                    path: b,\n                    fn: c,\n                    method: d\n                }), d;\n            },\n            staticRoute: function(a, b) {\n                var c = this;\n                this.route(a, b, function() {\n                    c.constructor.performRedirect(b);\n                });\n            },\n            redirectRoute: function(a, b, c) {\n                var d = this;\n                this.route(a, b, function(a, b) {\n                    d.redirectTo(d.routeMethods[c](a, b));\n                });\n            },\n            redirectTo: function(a) {\n                this.performRoute(a, !0);\n            },\n            routeTo: function(a) {\n                this.performRoute(a, !1);\n            },\n            performRoute: function(a, b) {\n                if (!this.routingEnabled) {\n                    return;\n                }\n            ;\n            ;\n                if (((this.pageViewsPerRefresh <= this.viewedPagesCount))) {\n                    return this.constructor.performRedirect(a);\n                }\n            ;\n            ;\n                this.viewedPagesCount++;\n                if (((!this._useHistory() && this.constructor.shouldRedirect(this.constructor.getCurrentPath(), a)))) {\n                    return this.constructor.performRedirect(a);\n                }\n            ;\n            ;\n                this._changeUrlAndCallAction(a, b);\n            },\n            shouldRedirectTo: function(a) {\n                return ((this._useHistory() ? !1 : this.constructor.shouldRedirect(this.constructor.getCurrentPath(), a)));\n            },\n            findMatchingRoute: function(a) {\n                for (var b = 0; ((b < this._routes.length)); b++) {\n                    var c = this.constructor.match(a, this._routes[b].path);\n                    if (c) {\n                        return {\n                            JSBNG__name: this._routes[b].JSBNG__name,\n                            fn: this._routes[b].fn,\n                            args: c,\n                            method: this._routes[b].method,\n                            path: this._routes[b].path\n                        };\n                    }\n                ;\n                ;\n                };\n            ;\n                return !1;\n            },\n            getCurrentRoute: function() {\n                return this.findMatchingRoute(this.constructor.getCurrentPath());\n            },\n            _setLocationHash: function(a) {\n                (((($.browser.safari && !JSBNG__navigator.userAgent.match(/Chrome/))) ? window.JSBNG__location.href = ((window.JSBNG__location.href.split(\"#\")[0] + a)) : window.JSBNG__location.hash = a));\n            },\n            replaceHashWithoutRouting: function(a) {\n                this.ignoreNextHashChange = !0, window.JSBNG__location.hash = a;\n            },\n            _changeUrlAndCallAction: function(a, b) {\n                if (!this.routingEnabled) {\n                    return;\n                }\n            ;\n            ;\n                var c = !1, d = !1, e = this.findMatchingRoute(a);\n                ((this._useHistory() && (((b ? window.JSBNG__history.replaceState(null, null, a) : window.JSBNG__history.pushState(null, null, a))), d = !0)));\n                var f = this.constructor.getHashUpdate(this.constructor.getCurrentPath(), a);\n                if (((twttr.decider.isAvailable(\"swift_home_timeline\") && ((a == \"/\"))))) {\n                    window.JSBNG__location = \"/\";\n                    return;\n                }\n            ;\n            ;\n                ((f && ((b ? window.JSBNG__location.replace(a) : (this._setLocationHash(f), c = !0, d = !0))))), ((c || this._callRoutingActionFor(e))), this.trigger(\"routed\", [e,a,]), ((d && this.trigger(\"urlChanged\", [e,])));\n            },\n            _callRoutingActionForPath: function(a) {\n                var b = this.findMatchingRoute(a);\n                return ((b && this.trigger(\"routeFollowed\", [b,a,]))), this._callRoutingActionFor(b);\n            },\n            _callCurrentRoutingAction: function() {\n                return this._callRoutingActionForPath(this.constructor.getCurrentPath());\n            },\n            _callRoutingActionFor: function(a) {\n                if (!this.routingEnabled) {\n                    return;\n                }\n            ;\n            ;\n                if (!a) {\n                    this.trigger(\"routeNotFound\");\n                    return;\n                }\n            ;\n            ;\n                return a.fn.call(null, a.args, this.constructor.getCurrentQueryStringParams());\n            },\n            lookupAndNormalizeRoute: function(a) {\n                var b = this.findMatchingRoute(a);\n                return ((b ? this.routeMethods[b.JSBNG__name](b.args) : a));\n            },\n            _addRouteMethods: function(a, b) {\n                var c = this.constructor.generatePathFunction(b), d = ((a + \"Path\"));\n                return this[d] = c, this.routeMethods[a] = c, this.trigger(\"routeAdded\", [d,c,]), c;\n            },\n            _listenToUrl: function() {\n                var a = this;\n                $(window).hashchange(function(b) {\n                    if (a.ignoreNextHashChange) {\n                        a.ignoreNextHashChange = !1;\n                        return;\n                    }\n                ;\n                ;\n                    a._callCurrentRoutingAction();\n                }), ((this.constructor.detectHistorySupport() && $(window).bind(\"popstate\", function(b) {\n                    ((a._useHistory() && a._callCurrentRoutingAction()));\n                })));\n            },\n            _useHistory: function() {\n                return ((((twttr.secrets && twttr.secrets.html5Routing)) && this.constructor.detectHistorySupport()));\n            },\n            _current_path_and_hash: function() {\n                return ((window.JSBNG__location.pathname + window.JSBNG__location.hash));\n            },\n            _current_query_params: function() {\n                return window.JSBNG__location.search;\n            },\n            shouldRedirectToCanonicalUrl: function(a) {\n                var b = this.swiftRoutes[a.JSBNG__name];\n                if (((!b || !twttr.decider.isAvailable(b.decider)))) {\n                    return !1;\n                }\n            ;\n            ;\n                ((a.args.screen_name && (a.args.screen_name = a.args.screen_name.replace(/^@/, \"\"))));\n                var c = a.method(a.args), d = this._current_path_and_hash().split(\"?\")[0];\n                if (((((d !== \"/\")) && ((d !== c))))) {\n                    var e = this._current_query_params();\n                    return c.toLowerCase().replace(/(?=#|$)/, function() {\n                        return e;\n                    });\n                }\n            ;\n            ;\n                return !1;\n            }\n        }), a(twttr.Router);\n    });\n});\nprovide(\"streams/Stream\", function(a) {\n    using(\"_\", \"mixins/serverRenderableObject\").as(function(b, _, c) {\n        twttr.stream = twttr.klass;\n        var d = twttr.klass(\"twttr.streams.Stream\", function(a, b, c) {\n            this.params = ((a || {\n            })), b = ((b || [])), ((((b instanceof twttr.API.util.BaseCollection)) && (b = b.array))), this.items = b, this.screenName = this.params.screenName, this.newItemsCount = this.items.length, this.itemViewClass = ((this.params.itemViewClass || this.itemViewClass)), this.streamItemClass = ((this.params.streamItemClass || \"stream-item\")), this.additionalStreamItemClass = ((this.params.additionalStreamItemClass || this.additionalStreamItemClass)), this.oldItemsCount = 0, this._page = 1, this.focusedItemId = null, this.highlightedItemId = null, this.scribbler = ((this.params.scribbler || new twttr.Scribbler(!1))), this.scribeComponentName = \"stream\", this.ignoreScribeItemPosition = !0, this.streamManager = c, this.streamManagerDomNodeSelector = ((c ? c.domNodeSelector : null)), ((this.params._setHeader && this.methods({\n                _setHeader: a._setHeader\n            })));\n            var d = twttr.views[this.streamViewClass];\n            ((d || (((twttr.development && JSBNG__console.warn(((((\"Stream view class '\" + this.streamViewClass)) + \"' not found. Defaulting to twttr.views.Stream\"))))), d = twttr.views.Stream))), this.$node = this.$domNode(function() {\n                return (new d({\n                })).$html();\n            }), ((twttr.isT1 && this.$node.attr(\"data-component-term\", this.scribeComponentName)));\n        }).mixin(c).methods(twttr.EventProvider).methods({\n            domNodeSelector: function() {\n                if (!this.streamManagerDomNodeSelector) {\n                    return null;\n                }\n            ;\n            ;\n                var a = this._namespace.match(/\\.([^.]+)$/)[1];\n                return streamClass = ((twttr.util.underscore(a) + \"-stream\")), ((((this.streamManagerDomNodeSelector + \" div.\")) + streamClass));\n            },\n            NEW_ITEMS_COUNT_MAX: 100,\n            NEW_ITEMS_COUNT_CUTOFF: 40,\n            _shouldCache: !0,\n            _expandable: !0,\n            streamViewClass: \"Stream\",\n            itemViewClass: null,\n            afterSwitchingToAgain: function(a) {\n                ((a ? a() : $.noop));\n            },\n            afterFirstSwitchingTo: function(a) {\n                ((a ? a() : $.noop));\n            },\n            beforeSwitchingAway: function() {\n            \n            },\n            _setTitle: function() {\n            \n            },\n            _getHeaderComponent: function() {\n            \n            },\n            hasPromotedContent: function() {\n                return !1;\n            },\n            getMoreOldItems: function(a) {\n                var b = this;\n                if (((((this._loadingMoreLock || this.noMoreOldItems)) || this._errorComponent))) {\n                    return;\n                }\n            ;\n            ;\n                var c = ((((this.page || this.cursor)) || this._sinceId));\n                this.isLoadingMore(), using(twttr.bundleMore, function() {\n                    b._fetchItems(function(d, e) {\n                        if (((e !== twttr.streams.SUCCESS))) b._showError(e);\n                         else {\n                            var f = b.items.slice(((b.items.length - b.oldItemsCount)));\n                            ((((c && ((c > 0)))) ? b.JSBNG__onGotOldItems(f) : b.JSBNG__onGotInitialResults(b.items))), b._showOldItems(), b._page++;\n                        }\n                    ;\n                    ;\n                        b.doneLoadingMore(), b.updateHeader(), ((a && a(d, e))), ((twttr.decider.isInfiniteScroll() && b.showLoadingSpinner()));\n                    });\n                });\n            },\n            getCurrentlyFocusedItem: function() {\n                return ((this.focusedItemId ? this.$streamItems().JSBNG__find(this.itemSelector(this.focusedItemId)) : null));\n            },\n            getCurrentlyHighlightedItem: function() {\n                return ((this.highlightedItemId ? this.$streamItems().JSBNG__find(this.itemSelector(this.highlightedItemId)) : null));\n            },\n            getFirstItem: function() {\n                return this.$streamItems().JSBNG__find(((((\".\" + this.streamItemClass)) + \":first\")));\n            },\n            focusItem: function(a) {\n                this.focusedItemId = a.attr(\"data-item-id\"), a.JSBNG__focus();\n            },\n            unfocusItem: function(a) {\n                this.focusedItemId = null, a.JSBNG__blur();\n            },\n            highlightItem: function(a) {\n                var b = this.getCurrentlyHighlightedItem();\n                ((b && b.removeClass(\"hovered-stream-item\").removeClass(\"js-had-hovered-stream-item\"))), this.focusedItemId = a.attr(\"data-item-id\"), this.highlightedItemId = a.attr(\"data-item-id\"), ((a.hasClass(\"open\") ? a.addClass(\"js-had-hovered-stream-item\") : a.addClass(\"hovered-stream-item\")));\n            },\n            highlightNext: function() {\n                this.shiftHighlight(!1);\n            },\n            highlightPrevious: function() {\n                this.shiftHighlight(!0);\n            },\n            shiftHighlight: function(a) {\n                var b = this.getCurrentlyHighlightedItem();\n                if (!b) {\n                    this.highlightItem(this.getFirstItem());\n                    return;\n                }\n            ;\n            ;\n                var c = ((a ? b.prev() : b.next()));\n                ((c.length && (this.highlightItem(c), this.scrollStreamTo(c))));\n            },\n            scrollStreamTo: function(a) {\n                var b = a.offset().JSBNG__top, c = Math.round(((b - ((twttr.$win.height() / 2)))));\n                twttr.$win.scrollTop(c);\n            },\n            dom: function() {\n                return this.$node;\n            },\n            $streamItems: function() {\n                return this.$find(\"div.stream-items\");\n            },\n            $find: function() {\n                var a = this.dom();\n                return a.JSBNG__find.apply(a, arguments);\n            },\n            itemSelector: function(a) {\n                return ((((((((\".\" + this.streamItemClass)) + \"[data-item-id='\")) + a)) + \"']\"));\n            },\n            selectedItem: function(a) {\n                return this.$streamItems().JSBNG__find(this.itemSelector(a));\n            },\n            unshift: function(a) {\n                ((twttr.is.array(a) ? (this.newItemsCount += a.length, this.items.unshift.apply(this.items, a)) : (this.newItemsCount += arguments.length, this.items.unshift(arguments)))), this.trigger(\"newItemsCountChanged\", [this.newItemsCount,]);\n            },\n            addAsNewItem: function(a) {\n                this.items.unshift(a), this.newItemsCount++, this.allowRerender(a);\n            },\n            push: function(a) {\n                ((twttr.is.array(a) ? (this.oldItemsCount += a.length, this.items.push.apply(this.items, a)) : (this.oldItemsCount += arguments.length, this.items.push(arguments))));\n            },\n            splice: function(a, b) {\n                var c;\n                ((twttr.is.array(b) ? (c = [a,0,].concat(b), this.items.splice.apply(this.items, c)) : (c = Array.prototype.slice.call(arguments), c.splice(1, 0, 0), this.items.splice.apply(this.items, c))));\n            },\n            markAsRendered: function(a) {\n                this.itemIds = ((this.itemIds || {\n                }));\n                var b = ((this.streamItemId ? this.streamItemId(a) : a.id));\n                this.itemIds[b] = 1;\n            },\n            isDuplicate: function(a) {\n                var b = ((this.streamItemId ? this.streamItemId(a) : a.id));\n                return this.itemIds = ((this.itemIds || {\n                })), !!this.itemIds[b];\n            },\n            allowRerender: function(a) {\n                var b = ((this.streamItemId ? this.streamItemId(a) : a.id));\n                this.itemIds = ((this.itemIds || {\n                })), delete this.itemIds[b];\n            },\n            _renderItemHtml: function(a) {\n                function b() {\n                    return ((f.render_withheld && f.render_withheld()));\n                };\n            ;\n                var c = ((this.streamItemId ? this.streamItemId(a) : a.id));\n                this.markAsRendered(a);\n                var d;\n                ((twttr.is.fn(this.itemViewClass) ? d = this.itemViewClass(a) : d = twttr.views[this.itemViewClass]));\n                var e = a;\n                ((((this.itemForRender && twttr.is.fn(this.itemForRender))) && (e = this.itemForRender.call(this, a))));\n                var f = new d(e);\n                f.query = ((this.params.query || f.query));\n                var g = twttr.views.StreamItem;\n                ((this.itemViewWrapperClass && (g = twttr.views[this.itemViewWrapperClass])));\n                var i = ((this.streamItemClass ? [this.streamItemClass,] : []));\n                if (this.additionalStreamItemClass) {\n                    var j = ((twttr.is.fn(this.additionalStreamItemClass) ? this.additionalStreamItemClass(a) : this.additionalStreamItemClass));\n                    i.push(j);\n                }\n            ;\n            ;\n                if (((((this._expandable && twttr.decider.isExpando())) && !b()))) {\n                    i.push(\"expanding-stream-item\");\n                    if (((((twttr.expando !== !0)) && ((twttr.expando !== \"expando\"))))) {\n                        switch (twttr.expando) {\n                          case \"labels\":\n                            i.push(\"yes-to-labels\");\n                            break;\n                          case \"more\":\n                            i.push(\"more-not-open\");\n                            break;\n                          case \"colorful\":\n                            i.push(\"colorful-links\");\n                        };\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                return ((b() ? i.push(\"withheld-item\") : ((((((f.is_withheld && f.is_withheld())) && f.is_current_user())) && i.push(\"withheld-own-item\"))))), (new g({\n                    item_html: f.html(),\n                    item_id: c,\n                    item_type: this.streamItemType,\n                    item_class: i.join(\" \")\n                })).html();\n            },\n            _renderItemsHtml: function(a) {\n                var b = this, c = [];\n                return $.each(a, function(a, d) {\n                    ((b.isDuplicate(d) || c.push(b._renderItemHtml(d))));\n                }), c.join(\"\");\n            },\n            _renderItems: function(a) {\n                return $(this._renderItemsHtml(a));\n            },\n            remove: function(a) {\n                this.selectedItem(a).remove();\n            },\n            rerenderItem: function(a, b) {\n                this.selectedItem(a).replaceWith(this._renderItemHtml(b));\n            },\n            _showNewItems: function(a) {\n                var b = this.$streamItems();\n                this.beforeShowNewItems(), ((((this.newItemsCount > this.NEW_ITEMS_COUNT_MAX)) && (b.empty(), this.items = this.items.slice(0, this.NEW_ITEMS_COUNT_CUTOFF), this.newItemsCount = this.NEW_ITEMS_COUNT_CUTOFF)));\n                var c = this.items.slice(0, this.newItemsCount), d = this._renderItems(c);\n                ((((a == \"initial\")) ? this.JSBNG__onGotInitialResults(this.items) : ((((((a != \"initial\")) && ((this.newItemsCount > 0)))) && this.JSBNG__onGotNewItems(c))))), b.prepend(d), this.JSBNG__onShowNewItems(d), this.newItemsCount = 0, this.trigger(\"newItemsCountChanged\", [0,]);\n            },\n            _showOldItems: function(a) {\n                var b = this.$streamItems();\n                this.beforeShowOldItems();\n                var c = this.items.slice(((this.items.length - this.oldItemsCount))), d = this._renderItems(c);\n                b.append(d), this.JSBNG__onShowOldItems(d), this.oldItemsCount = 0;\n            },\n            render: function() {\n                this._showNewItems(\"initial\"), this._showOldItems(!0);\n            },\n            isEmpty: function() {\n                return ((this.items.length === 0));\n            },\n            reachedTheEnd: function() {\n                ((this.noMoreOldItems || (this.noMoreOldItems = !0, this.markStreamEnd(), this.hideLoadingSpinner(), this.trigger(\"streamEnd\"))));\n            },\n            markStreamEnd: function() {\n                var a = this;\n                if (this._alreadyMarkedEnd) {\n                    return;\n                }\n            ;\n            ;\n                this._alreadyMarkedEnd = !0, using(twttr.bundleMore, function() {\n                    a.endOfStreamComponent = ((a.isEmpty() ? a._getEmptyStreamComponent() : a._getStreamEndComponent())), ((a.endOfStreamComponent && a.endOfStreamComponent.$node.appendTo(a.$node)));\n                });\n            },\n            switchEndOfStreamMarker: function() {\n                if (this.endOfStreamComponent) {\n                    var a = this._getStreamEndComponent();\n                    ((a && (this.endOfStreamComponent.$node.replaceWith(a.$node), this.endOfStreamComponent = a)));\n                }\n            ;\n            ;\n            },\n            _showError: function(a) {\n                var b = this;\n                using(twttr.bundleMore, function() {\n                    b.hideLoadingSpinner(), ((b._errorComponent && (b._errorComponent.destroy(), delete b._errorComponent)));\n                    var c = b._getStreamErrorComponent(a);\n                    if (!c) {\n                        return;\n                    }\n                ;\n                ;\n                    c.bind(\"tryAgain\", function(a) {\n                        c.destroy(), delete b._errorComponent, b.getMoreOldItems();\n                    }), b._errorComponent = c, c.$node.appendTo(b.dom());\n                });\n            },\n            _getStreamEndComponent: function() {\n                return new twttr.components.StreamEnd(this._getStreamEndHtml(), this._getStreamEndShowBird());\n            },\n            _getEmptyStreamComponent: function() {\n                return new twttr.components.StreamEnd(this._getEmptyStreamHtml());\n            },\n            _getStreamErrorComponent: function(a) {\n                return ((((a === twttr.streams.DECIDER)) ? new twttr.components.StreamEnd(this._getStreamErrorHtml(a)) : new twttr.components.StreamWhaleEnd(this._getStreamWhaleText())));\n            },\n            _getStreamLoadingComponent: function() {\n                return new twttr.views.StreamLoading;\n            },\n            _getStreamWhaleText: function() {\n                return _(\"Loading seems to be taking a while.\");\n            },\n            _getEmptyStreamHtml: function() {\n            \n            },\n            _getStreamEndHtml: function() {\n                return ((((this.items.length < 20)) ? \"\" : _(\"\\u003Ca href='#' class='back-to-top'\\u003EBack to top &uarr;\\u003C/a\\u003E\")));\n            },\n            _getStreamErrorHtml: function(a) {\n                return _(\"This feature is temporarily unavailable.\");\n            },\n            _getStreamEndShowBird: function() {\n                return !0;\n            },\n            isLoadingMore: function() {\n                this._loadingMoreLock = !0, this.showLoadingSpinner();\n            },\n            showLoadingSpinner: function() {\n                var a = this.dom();\n                ((((((((a.JSBNG__find(\"div.stream-loading\").length === 0)) && !this._alreadyMarkedEnd)) && !this._errorComponent)) && this._getStreamLoadingComponent().render(a, \"append\")));\n            },\n            stream_user_is_current_user: function() {\n                return ((((twttr.currentUser && this.screenName)) && ((twttr.currentUser.screenName === this.screenName))));\n            },\n            doneLoadingMore: function() {\n                this._loadingMoreLock = !1, this.hideLoadingSpinner(), this.trigger(\"doneLoadingMore\");\n            },\n            hideLoadingSpinner: function() {\n                this.dom().JSBNG__find(\"div.stream-loading\").remove();\n            },\n            JSBNG__onGotInitialResults: function(a) {\n                this._scribeResults(\"initial\", a);\n            },\n            JSBNG__onInsertItems: function(a) {\n                this._scribeResults(\"insert\", a);\n            },\n            JSBNG__onGotNewItems: function(a) {\n                this._scribeResults(\"get_newer\", a);\n            },\n            JSBNG__onGotOldItems: function(a) {\n                this._scribeResults(\"get_older\", a);\n            },\n            _scribeResults: function(a, b, c) {\n                (((($.inArray(a, [\"initial\",\"error\",\"insert\",]) == -1)) && this.scribbler.scribe({\n                    component: \"stream\",\n                    action: a\n                }, {\n                    item_count: b.length,\n                    cursor_or_page: this._cursorOrPage()\n                })));\n            },\n            _scribeEmptyResults: function(a, b, c) {\n                var d = this._cursorOrPage();\n                if (((((a == \"error\")) || ((((a == \"initial\")) && !b.length))))) {\n                    var e = {\n                        item_count: 0,\n                        event_value: 0,\n                        referring_event: a\n                    };\n                    ((d && (e.cursor_or_page = d))), ((((((((a == \"error\")) && c)) && c.status_code)) && (e.status_code = c.status_code))), this.scribbler.scribe({\n                        component: \"stream\",\n                        action: ((((a == \"error\")) ? \"error\" : \"no_results\"))\n                    }, e);\n                }\n                 else if (((((a != \"initial\")) && ((a != \"insert\"))))) {\n                    var f = {\n                        item_count: b.length\n                    };\n                    ((d && (f.cursor_or_page = d))), this.scribbler.scribe({\n                        component: \"stream\",\n                        action: a\n                    }, f);\n                }\n                \n            ;\n            ;\n            },\n            _cursorOrPage: function() {\n                return ((((((((this._sinceId || this.cursor)) || ((((this.page && ((this.page > 0)))) && this.page)))) || ((((this._page && ((this._page > 0)))) && this._page)))) || -1));\n            },\n            _registerAddToStreamEvent: function(a, b, c) {\n                var d = this;\n                this._registerEvent(a, b, function() {\n                    var a = c.apply(this, arguments);\n                    ((a && (d.addAsNewItem(a), d._showNewItems())));\n                });\n            },\n            _registerRemoveFromStreamEvent: function(a, b, c, d) {\n                var e = this;\n                this._registerEvent(a, b, function() {\n                    var a = c.apply(this, arguments);\n                    ((a && (d = ((d || \"id\")), e.remove(a[d]), e.items = twttr.filter(e.items, function(b) {\n                        return ((((b[d] !== a[d])) ? b : null));\n                    }), ((e.isEmpty() && e.reachedTheEnd())))));\n                });\n            },\n            _registerUpdateStreamEvent: function(a, b, c, d) {\n                var e = this;\n                this._registerEvent(a, b, function() {\n                    var a = c.apply(this, arguments);\n                    ((a && (d = ((d || \"id\")), e.items = twttr.map(e.items, function(b) {\n                        return ((((b[d] === a[d])) ? a : b));\n                    }), e.rerenderItem(a[((d || \"id\"))], a))));\n                });\n            },\n            _registerEvent: function(a, b, c) {\n                ((this._boundEvents || (this._boundEvents = []))), a.bind(b, c), this._boundEvents.push({\n                    obj: a,\n                    JSBNG__name: b,\n                    cb: c\n                });\n            },\n            unbindEvents: function() {\n                ((this._boundEvents && (twttr.each(this._boundEvents, function(a) {\n                    a.obj.unbind(a.JSBNG__name, a.cb);\n                }), this._boundEvents = [])));\n            },\n            beforeShowNewItems: function() {\n            \n            },\n            beforeShowOldItems: function() {\n            \n            },\n            JSBNG__onShowNewItems: function(a) {\n            \n            },\n            JSBNG__onShowOldItems: function(a) {\n            \n            }\n        });\n        twttr.aug(twttr.streams, {\n            SUCCESS: 1,\n            ERROR: 2,\n            PROTECTED: 3,\n            DECIDER: 4,\n            WHALE: 5,\n            TIMEOUT: 6\n        }), ((twttr.isT1 ? d.methods({\n            _setHeader: null,\n            _expandable: !1,\n            updateHeader: function() {\n                var a = ((this.streamManager && this.streamManager.$headerContainer()));\n                if (!a) {\n                    return;\n                }\n            ;\n            ;\n                this._updateHeaderFromStream(a);\n            },\n            _updateHeaderFromStream: function(a) {\n            \n            }\n        }) : d.methods({\n            updateHeader: function() {\n                ((this.header || (((this.header = this._getHeaderComponent()) && this.$find(\"div.stream-items\").prepend(this.header.$node.addClass(\"stream-header\"))))));\n            }\n        }))), a(twttr.streams.Stream);\n    });\n});\nprovide(\"scribbles\", function(a) {\n    using().as(function(b) {\n        twttr.augmentString(\"twttr.scribbles\", {\n            logViewProfileDetails: function(a) {\n                var b = $(this), c = {\n                }, d = $(a.target), e = \"view-profile\";\n                ((d.is(\"img\") ? c.target = \"image\" : ((d.is(\"a\") && (c.target = \"link\")))));\n                if (b.is(\"div.dashboard .user-profile-link\")) {\n                    c.component = \"dashboard\", ((b.is(\".new-followers .user-profile-link\") && (c.subcomponent = \"new-followers\")));\n                }\n                 else {\n                    if (b.is(\"div.details-pane .user-profile-link, div.details-pane .twitter-atreply\")) {\n                        c.component = \"details-pane\";\n                        if (b.is(\".related-tweets .user-profile-link, .related-tweets .twitter-atreply\")) {\n                            var f = b.closest(\".tweet\");\n                            twttr.viewHelpers.addRelatedTweetsLogging(f, c, e);\n                        }\n                    ;\n                    ;\n                    }\n                     else ((b.is(\".stream-tweet .user-profile-link, .stream-tweet .twitter-atreply\") ? c.component = \"stream\" : ((b.is(\".twttr-dialog .user-profile-link\") && (c.component = \"dialog\", c.dialog_type = b.closest(\".twttr-dialog\").attr(\"type\"))))));\n                ;\n                }\n            ;\n            ;\n                c.input = \"click\", c.tweet_id = ((b.closest(\".tweet\").attr(\"data-tweet-id\") || \"\")), c.profile_id = ((((b.data(\"user-id\") || b.data(\"screen-name\"))) || b.closest(\".js-profile-popup-actionable\").data(\"user-id\"))), scribble(e, c);\n            }\n        }), a(twttr.scribbles);\n    });\n});\nprovide(\"Cards\", function(a) {\n    using(\"util\", \"constants\").as(function(b) {\n        var c = function(a) {\n            return ((((twttr.decider.isAvailable(\"platform_enable_cards\") && twttr.exists(a, \"cards.photos.length\"))) && !!a.cards.photos.length));\n        }, d = function(a) {\n            var b = 0, c;\n            if (((a.has_embedded_player !== undefined))) {\n                return a.has_embedded_player;\n            }\n        ;\n        ;\n            if (((((twttr.decider.isAvailable(\"platform_enable_cards\") && twttr.exists(a, \"cards.players.length\"))) && !!a.cards.players.length))) {\n                c = a.cards.players.length;\n                for (; ((b < c)); b++) {\n                    a.cards.players[b].players = twttr.filter(a.cards.players[b].players, function(a) {\n                        return ((a && ((a.source_type == \"text/html\"))));\n                    });\n                ;\n                };\n            ;\n                return a.has_embedded_player = !!c, a.has_embedded_player;\n            }\n        ;\n        ;\n            return !1;\n        }, e = function(a) {\n            return ((((twttr.decider.isAvailable(\"platform_enable_cards\") && twttr.exists(a, \"cards.summaries.length\"))) && !!a.cards.summaries.length));\n        }, f = function(a) {\n            return ((twttr.exists(a, \"entities.media.length\") && !!a.entities.media.length));\n        }, g = function(a) {\n            return ((((d(a) || e(a))) || c(a)));\n        }, i = twttr.klass(\"twttr.Cards\").methods({\n            hasPhotos: c,\n            hasPlayers: d,\n            hasSummaries: e,\n            hasCards: g,\n            hasCardPhotoEntities: f\n        });\n        a(i);\n    });\n});\nprovide(\"multiGlobals/client_app_tracking\", function(a) {\n    using(\"util\", \"constants\").as(function(b) {\n        (function() {\n            twttr.Scribbler.clientAppDefaultTerms = function() {\n                var a = {\n                    client: \"web\"\n                }, c = twttr.audit.currentPage();\n                ((c && (a.page = b.util.underscore(c))));\n                var d = twttr.audit.currentAction();\n                return ((d && (a.section = b.util.underscore(d)))), a;\n            }, twttr.Scribbler.clientAppEventNameGenerator = function(a, b) {\n                return b = ((b || twttr.Scribbler.clientAppDefaultTerms())), a = twttr.merge(b, a), [a.client,a.page,a.section,a.component,a.element,a.action,].join(\":\");\n            }, twttr.Scribbler.clientEvent = new twttr.Scribbler({\n            }, {\n                noob_level: function() {\n                    var a = ((twttr.loggedIn ? twttr.helpers.userNoobLevel(twttr.currentUser) : -1));\n                    return ((((a >= 0)) ? a : null));\n                },\n                internal_referer: function() {\n                    return ((((twttr.audit && twttr.audit.path(1))) || null));\n                },\n                referring_event: function(a) {\n                    if (((twttr.isT1 && a))) {\n                        if (((twttr.is.object(a) && ((a[\"action\"] == \"impression\"))))) {\n                            return twttr.clicks.lastClick();\n                        }\n                    ;\n                    ;\n                        if (twttr.is.string(a)) {\n                            var b = a.split(\":\");\n                            if (((b[((b.length - 1))] == \"impression\"))) {\n                                return twttr.clicks.lastClick();\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                }\n            }, \"client_event\", twttr.Scribbler.clientAppEventNameGenerator), twttr.Scribbler.getElementEventNameTerms = function(a) {\n                var b = $(a), c = b.closest(\"[data-element-term]\"), d = b.closest(\"[data-component-term]\"), e = b.closest(\"[data-section-term]\"), f = c.attr(\"data-element-term\");\n                componentTerm = d.attr(\"data-component-term\"), sectionTerm = e.attr(\"data-section-term\");\n                var g = {\n                };\n                if (((componentTerm && f))) {\n                    g.component = ((((componentTerm + \"_\")) + f));\n                }\n                 else {\n                    if (((componentTerm || f))) {\n                        g.component = ((componentTerm || f));\n                    }\n                ;\n                }\n            ;\n            ;\n                return ((sectionTerm && (g.section = sectionTerm))), g;\n            }, twttr.Scribbler.clientEvent.spawnWithTerms = function(a, b) {\n                var c = function(b) {\n                    var c = twttr.Scribbler.clientAppDefaultTerms();\n                    return scribeTerms = twttr.merge({\n                    }, b, a), twttr.Scribbler.clientAppEventNameGenerator(scribeTerms, c);\n                }, d = this.spawn(b, c);\n                return d.spawnWithTerms = this.spawnWithTerms, d;\n            }, window.trackClient = twttr.trackClient = function(a, b) {\n                return ((((arguments[1] && ((typeof arguments[1] == \"string\")))) && (arguments[1] = {\n                    context: arguments[1]\n                }))), twttr.Scribbler.clientEvent.scribe.apply(twttr.Scribbler.clientEvent, arguments);\n            }, window.trackElement = twttr.trackElement = function(a, b, c) {\n                ((((typeof b == \"string\")) && (b = {\n                    action: b\n                })));\n                var d = twttr.merge(twttr.Scribbler.getElementEventNameTerms(a), b);\n                ((d.component && trackClient(d, c)));\n            }, window._scribble = function() {\n                ((twttr.decider.isAvailable(\"old_webclient_events\") && twttr.Scribbler.global.scribe.apply(twttr.Scribbler.global, arguments)));\n            };\n        })(), twttr.app.waitForSignal(\"init\", function() {\n            ((twttr.isT1 ? twttr.app.bind(\"streamSwitchedTo\", function(a, b) {\n                var c = {\n                }, d = b.pageNameUnderscore;\n                ((b.addImpressionData && b.addImpressionData(c))), trackClient({\n                    action: \"impression\"\n                }, c);\n            }) : ($(\"#logo\").click(function() {\n                trackClient({\n                    section: \"top_nav\",\n                    component: \"logo\",\n                    action: \"click\"\n                });\n            }), $(\"#global-actions li a\").click(function() {\n                var a = $(this).parent().attr(\"data-global-action\");\n                trackClient({\n                    section: \"top_nav\",\n                    component: ((a + \"_nav\")),\n                    action: \"click\"\n                });\n            })))), $(\"button.js-global-new-tweet,a.js-global-new-tweet\").click(function() {\n                trackClient({\n                    section: \"top_nav\",\n                    component: \"new_tweet_button\",\n                    action: \"click\"\n                });\n            }), ((twttr.decider.isAvailable(\"scribe_general_reliability_events\") && window.JSBNG__setTimeout(function() {\n                twttr.ScribeBuffer.instance.sendReliabilityEvent(function() {\n                    trackClient({\n                        page: \"scribe\",\n                        section: \"reliability\",\n                        component: \"client\",\n                        action: \"impression\"\n                    });\n                });\n            }, 30000)));\n        }), a();\n    });\n});\nprovide(\"mixins/streamablePageDetailsPane\", function(a) {\n    using(\"_\", \"util\").as(function(b, _) {\n        var c = twttr.klass.mixin(\"twttr.mixins.streamablePageDetailsPane\", function() {\n            return this.click({\n                \".stream span.js-actions, .stream ul.js-actions\": function(a, b) {\n                    return a.stopPropagation(), a.preventDefault(), !1;\n                },\n                \"div.details-pane div.stream-item\": function(a, b) {\n                    if ($(a.target).is(\".twitter-timeline-link\")) {\n                        return;\n                    }\n                ;\n                ;\n                    var c = b.JSBNG__find(\".tweet\"), d = c.attr(\"data-tweet-id\"), e = {\n                        component: \"details-pane\"\n                    };\n                    ((b.is(\".related-tweets .stream-item\") ? twttr.viewHelpers.addRelatedTweetsLogging(c, e, \"tweet-click\") : ((b.is(\".in-reply-to .stream-item\") && (e.subcomponent = \"in-reply-to\"))))), e.embedded_media_types = c.JSBNG__find(\".icons .media\").map(function(a, b) {\n                        var c = $(b);\n                        return [c.data(\"media-type\"),c.data(\"media-class\"),];\n                    }).get();\n                    var f = c.attr(\"data-impression-id\");\n                    this.loadItemInDetailsPane(d, \"tweet\", {\n                        log: e,\n                        push: !0,\n                        impressionId: f\n                    });\n                },\n                \"div.details-pane .user-detailed-list-item .user-screen-name\": function(a, b) {\n                    var c = parseInt(b.attr(\"data-user-id\"), 10);\n                    return this.loadItemInDetailsPane(c, \"user\", {\n                        push: !0\n                    }), a.stopPropagation(), a.preventDefault(), !1;\n                },\n                \".stream-tabs .stream-tab \\u003E a, .stream-tabs .dropdown-link .stream-link \\u003E a\": function(a, b) {\n                    var c = b.parent(), d = b.attr(\"href\");\n                    if (((d != \"#\"))) {\n                        var e = twttr.router.findMatchingRoute(d);\n                        if (((((e && e.fn.pageName)) && e.fn.actionName))) {\n                            var f = twttr.util.underscore(e.fn.actionName), g = twttr.util.underscore(e.fn.pageName);\n                            trackClient({\n                                page: g,\n                                section: f,\n                                component: \"stream_nav_tab\",\n                                action: \"click\"\n                            });\n                        }\n                    ;\n                    ;\n                    }\n                     else if (((!c.hasClass(\"stream-tab-lists\") && c.closest(\".stream-tab-lists\").length))) {\n                        var i = ((((twttr.audit.currentPage() == \"JSBNG__home\")) ? \"list_in_home\" : \"lists\"));\n                        trackClient({\n                            section: i,\n                            component: \"stream_nav_tab\",\n                            action: \"create\"\n                        });\n                    }\n                    \n                ;\n                ;\n                },\n                \".stream .stream-item\": function(a, b) {\n                    $eventTarget = $(a.target);\n                    var c = $eventTarget.is(\"div.stream-item a.tweet-timestamp, div.stream-item a.tweet-timestamp *\"), d = $eventTarget.is(\"div.stream-item a.twitter-timeline-link\"), e = $eventTarget.is(\"div.stream-user-buttons *\"), f = $eventTarget.parents(\"div.stream-item\").is(\"div.feedback-shown\"), g = $eventTarget.is(\"div.stream-item a.twitter-timeline-link[data-twitter-media-url=\\\"true\\\"]\"), i = $eventTarget.is(\"div.withheld-item *\"), j = ((b.is(\".js-activity\") && !b.is(\".js-activity-retweet, .js-activity-favorite, .js-activity-reply, .js-activity-mention\")));\n                    if (((((((((((c || ((d && !g)))) || e)) || f)) || j)) || i))) {\n                        return;\n                    }\n                ;\n                ;\n                    this.toggleFocus(b), ((((twttr.decider.isAvailable(\"turkey_prevent_timeline_click\") && g)) && a.preventDefault()));\n                },\n                \".stream-item-activity .user-content-medium\": function(a, b) {\n                    var c = b.parents(\".stream-item\"), d = b.closest(\".sub-stream-item\"), e = ((((c.hasClass(\"focused-stream-item\") && d.hasClass(\"expand-activity-item\"))) && ((this.panes.size() <= 1))));\n                    return ((e || (d.siblings().removeClass(\"expand-activity-item\"), d.addClass(\"expand-activity-item\"), c.removeClass(\"focused-stream-item\")))), this.toggleFocus(c), !1;\n                },\n                \".stream .user-profile-link, .stream .twitter-atreply, div.details-pane .user-profile-link, div.details-pane .twitter-atreply\": function(a, b) {\n                    var c = twttr.helpers.getUserIdentifier(b), d = {\n                    }, e = {\n                        component: \"stream\"\n                    };\n                    d.log = e, ((b.is(\"div.details-pane .user-profile-link, div.details-pane .twitter-atreply\") && (d.push = !0, e.component = \"details-pane\")));\n                    var f = ((b.closest(\".promoted-tweet\").attr(\"data-impression-id\") || b.closest(\".promoted-account\").attr(\"data-impression-id\")));\n                    ((b.is(\"div.details-pane .user-profile-link, .stream .user-profile-link\") && (d.impressionId = f))), ((((twttr.app.isOnPage(\"search\") && b.is(\".stream .user-profile-link, .stream .twitter-atreply\"))) && (d.searchClick = b.closest(\".stream-tweet\")))), twttr.scribbles.logViewProfileDetails.call(b, a);\n                    var g = b.is(\"div.withheld-item *\");\n                    return ((g || this.loadItemInDetailsPane(c, \"user\", d))), a.stopPropagation(), a.preventDefault(), !1;\n                },\n                \".stream .twitter-hashtag\": function(a, b) {\n                    a.stopPropagation();\n                },\n                \".stream .twitter-place, div.details-pane .twitter-place\": function(a, b) {\n                    var c = b.closest(\".tweet\").attr(\"data-tweet-id\"), d = {\n                        placeId: b.attr(\"data-place-id\")\n                    };\n                    return ((b.is(\"div.details-pane .js-tweets-at-this-place\") && (d.push = !0))), this.loadItemInDetailsPane(c, \"tweet_geo\", d), !1;\n                },\n                \".stream .twitter-listname\": function(a, b) {\n                    return twttr.router.routeTo(twttr.router.lookupAndNormalizeRoute($this.attr(\"href\"))), a.stopPropagation(), a.preventDefault(), !1;\n                },\n                \".js-tweet-geo-text, div.details-pane .js-tweets-at-this-place\": function(a, b) {\n                    var c = b.attr(\"data-tweet-id\"), d = {\n                        placeId: b.attr(\"data-place-id\")\n                    };\n                    return ((b.is(\"div.details-pane .js-tweets-at-this-place, div.details-pane .tweet-geo-text\") && (d.push = !0))), this.loadItemInDetailsPane(c, \"tweet_geo\", d), a.stopPropagation(), a.preventDefault(), !1;\n                },\n                \".pane-toolbar a.pane-close\": function(a, b) {\n                    return this.unfocusStreamItem(), a.stopPropagation(), a.preventDefault(), !1;\n                },\n                \".pane-toolbar a.pane-back\": function(a, b) {\n                    return this.panes.pop(), a.stopPropagation(), a.preventDefault(), !1;\n                }\n            }).JSBNG__focus({\n                \".stream span.js-actions, .stream ul.js-actions\": function(a, b) {\n                    return a.stopPropagation(), !1;\n                }\n            }).methods({\n                toggleFocus: function(a) {\n                    ((((a.hasClass(\"focused-stream-item\") && ((this.panes.size() <= 1)))) ? (this.streamManager.getCurrent().unfocusItem(a), this.unfocusStreamItem()) : (this.streamManager.getCurrent().focusItem(a), this.focusStreamItem(a))));\n                },\n                focusStreamItem: function(a) {\n                    a.addClass(\"focused-stream-item\").siblings().removeClass(\"focused-stream-item\").removeClass(\"light\");\n                    var b, c, d = a.attr(\"data-item-type\"), e = {\n                    };\n                    ((((((((d === \"list\")) || ((d === \"message_thread\")))) || ((d === \"tweet\")))) ? b = a.attr(\"data-item-id\") : ((((d === \"activity\")) ? (((a.is(\".js-activity-reply, .js-activity-mention\") ? c = a.JSBNG__find(\".stream-item-content\") : ((a.is(\".js-activity-retweet, .js-activity-favorite\") ? (c = a.JSBNG__find(\".activity-truncated-tweet .tweet\"), ((c.length || (c = a.JSBNG__find(\".sub-stream-item:not('.sub-stream-item-hidden') .stream-item-content\"))))) : c = a.JSBNG__find(\".expand-activity-item .stream-item-content\"))))), ((c.is(\".tweet\") ? (d = \"tweet\", b = c.attr(\"data-item-id\")) : ((c.is(\".user-content-medium\") && (d = \"user\", b = parseInt(c.attr(\"data-user-id\"), 10)))))), e.streamType = \"activity-stream\", e.itemType = d, e.activityType = a.JSBNG__find(\".stream-item-activity\").attr(\"data-activity-type\"), e.activityId = b) : b = parseInt(a.attr(\"data-item-id\"), 10))))), e.stream = this.streamManager.getCurrent().constructor._name, e.component = \"stream\", e.page_number = this.streamManager.getCurrent()._page;\n                    var f = ((a.JSBNG__find(\".tweet\").attr(\"data-impression-id\") || a.JSBNG__find(\".user-content-medium\").attr(\"data-impression-id\")));\n                    ((((d === \"tweet\")) && (e.embedded_media_types = a.JSBNG__find(\".icons .media\").map(function(a, b) {\n                        return [[b.getAttribute(\"data-media-type\"),b.getAttribute(\"data-media-class\"),],];\n                    }).get()))), a.addClass(\"focused-stream-item\").siblings().removeClass(\"focused-stream-item\"), this.loadItemInDetailsPane(b, d, {\n                        log: e,\n                        impressionId: f,\n                        searchClick: ((((twttr.app.isOnPage(\"search\") && a.is(\".stream .stream-item\"))) ? a.children(\".stream-tweet\") : null))\n                    });\n                    var g = ((this.streamManager && this.streamManager.getCurrent()));\n                    if (g) {\n                        var i = ((((d == \"user\")) ? \"select.user\" : \"select.tweet\"));\n                        g.trigger(i, [a,a,\"select\",]);\n                    }\n                ;\n                ;\n                },\n                unfocusStreamItem: function() {\n                    var a = this.$detailsPane().hasClass(\"opened\");\n                    if (((this.closeDetailsPane() !== !1))) {\n                        var b = this.$node.JSBNG__find(\"div.focused-stream-item\");\n                        this.$node.JSBNG__find(\"div.stream-item\").removeClass(\"focused-stream-item\");\n                        if (a) {\n                            var c = ((this.streamManager && this.streamManager.getCurrent()));\n                            if (c) {\n                                var d = ((((b.attr(\"data-item-type\") == \"user\")) ? \"deselect.user\" : \"deselect.tweet\"));\n                                c.trigger(d, [b,b,\"deselect\",]);\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                },\n                loadItemInDetailsPane: function(a, b, c) {\n                    this.yScroll = twttr.$win.scrollTop();\n                    if (!b) {\n                        return;\n                    }\n                ;\n                ;\n                    var d = this, e = {\n                    }, c = ((c || {\n                    }));\n                    ((c.log && twttr.merge(e, c.log))), ((((b === \"tweet\")) ? (this.loadTweetInDetailsPane(a, c), this.openDetailsPane()) : ((((b === \"user\")) ? (this.loadUserInDetailsPane(a, c), this.openDetailsPane()) : ((((b === \"tweet_geo\")) ? (this.loadTweetGeoInDetailsPane(a, c), this.openDetailsPane()) : ((((b === \"list\")) ? twttr.router.routeTo(twttr.router.lookupAndNormalizeRoute(a)) : ((((b === \"message_thread\")) && (this.loadMessageThreadInDetailsPane(a, c), this.resizeDetailsPane()))))))))))), ((c.searchClick && twttr.components.pages.Search.addSearchClickLogging(c.searchClick, e))), e.details_type = b, e.item_id = a, e.input = \"click\", scribble(\"load-details-pane\", e), $(\"div.tipsy\").remove();\n                },\n                viewId: function(a, b, c) {\n                    return ((((a + b)) + ((c ? ((\"_\" + c)) : \"\"))));\n                },\n                loadTweetInDetailsPane: function(a, b) {\n                    var c = this, d = b.impressionId, e = this.viewId(\"tweet_pane_\", a, d), f = new twttr.views.DetailsPane(e), g = this.panes.cached(e), i = ((b.push ? this.panes.push(f) : this.panes.reset(f))), j = i.$dom;\n                    ((g ? j.JSBNG__find(\".map_canvas:visible\").trigger(\"refreshMap\") : (this.$find(\".pane-components-inner\").addClass(\"tweet-components\"), using(twttr.bundleMore, function() {\n                        twttr.API.Status.JSBNG__find(a, function(a) {\n                            i._backLabel = _(\"@{{screen_name}}'s Tweet\", {\n                                screen_name: a.user.screenName\n                            }), ((d && (a = twttr.API.util.PromotedStore.getPromotedStatusInstance(a, d), twttr.API.util.PromotedContent.logShowDetails(d))));\n                            var b = c.streamManager.getCurrent();\n                            new twttr.components.Conversation(a, b, function(d) {\n                                d.bind(\"deleted\", function() {\n                                    ((c.panes.contains(i) && (c.panes.remove(i), c.panes.reset(), c.closeDetailsPane())));\n                                });\n                                var e = [], f = j.JSBNG__find(\".component:visible:first\"), g = j.width();\n                                ((((f.length !== 0)) && (g = f.width()))), g -= 55;\n                                var k = new twttr.components.Media(a, g);\n                                e.push(d, new twttr.components.TweetGeoSmall(a), new twttr.components.MachineTranslatedTweet(a)), ((((twttr.decider.isActivityEnabled() && twttr.decider.isAvailable(\"activity_social_context\"))) ? (e.push(new twttr.components.TweetActivity(a)), e.push(new twttr.components.Replies(a, b, d.resultGroups))) : (e.push(new twttr.components.Replies(a, b, d.resultGroups)), e.push(new twttr.components.Retweeters(a, 10))))), e.push(new twttr.components.MentionedInTweet(a)), c.addComponentsToDetailsPane(j, e), k.$node.appendTo(j.JSBNG__find(\"div.js-tweet-media-container\"));\n                            });\n                        });\n                    }))));\n                },\n                loadUserInDetailsPane: function(a, b) {\n                    var c = ((twttr.is.string(a) ? \"user_pane_by_screen_name_\" : \"user_pane_by_id_\")), d = this, e = b.impressionId, f = this.viewId(c, a, e), g = new twttr.views.DetailsPane(f), i = this.panes.cached(f), j = ((b.push ? this.panes.push(g) : this.panes.reset(g))), k = j.$dom;\n                    ((i || (twttr.ui.toggleSpinner(k, !0), using(twttr.bundleMore, function() {\n                        twttr.API.User.JSBNG__find(a, {\n                            success: function(a) {\n                                twttr.ui.toggleSpinner(k), twttr.app.trigger(\"view_profile_pane\", a), j._backLabel = _(\"@{{screen_name}}'s profile\", {\n                                    screen_name: a.screenName\n                                }), ((e && (a = twttr.API.util.PromotedStore.getPromotedUserInstance(a, e)))), d.addComponentsToDetailsPane(k, [new twttr.components.ProfilePane(a),new twttr.components.UserMedia(a, {\n                                    itemWidth: 48,\n                                    itemHeight: 48,\n                                    itemDisplayWidth: 50,\n                                    width: 320,\n                                    noSpacer: !0\n                                }),new twttr.components.RecentTweets(a),]);\n                            },\n                            error: function(a) {\n                                d.addComponentsToDetailsPane(k, [new twttr.components.NoUserExists,]);\n                            }\n                        });\n                    }))));\n                },\n                loadTweetGeoInDetailsPane: function(a, b) {\n                    var c = this, d = this.viewId(\"tweet_geo_pane_\", a, b.placeId), e = new twttr.views.DetailsPane(d), f = this.panes.cached(d), g = ((b.push ? this.panes.push(e) : this.panes.reset(e))), i = g.$dom;\n                    ((f ? i.JSBNG__find(\".map_canvas:visible\").trigger(\"refreshMap\") : using(twttr.bundleMore, function() {\n                        twttr.API.Status.JSBNG__find(a, function(a) {\n                            var d = ((b.placeId || ((a.place ? a.place.id : null))));\n                            g._backLabel = _(\"@{{screen_name}}'s Tweet location\", {\n                                screen_name: a.user.screenName\n                            });\n                            var e = function(b) {\n                                var e = [new twttr.components.TweetGeoBig(a, d),];\n                                ((b && e.push(new twttr.components.PlaceTweets(b)))), c.addComponentsToDetailsPane(i, e);\n                            };\n                            ((d ? ((((a.place && ((a.place.id == d)))) ? e(a.place) : twttr.API.Place.JSBNG__find(d, {\n                                success: function(a) {\n                                    e(a.data());\n                                },\n                                error: function() {\n                                    e();\n                                }\n                            }))) : e()));\n                        });\n                    })));\n                },\n                loadMessageThreadInDetailsPane: function(a, b) {\n                    if (!twttr.loggedIn) {\n                        throw \"Something went wrong. You're not supposed to be able to load a message pane while logged out...\";\n                    }\n                ;\n                ;\n                    var c = this, d = this.viewId(\"message_thread_pane_\", a), e = new twttr.views.DetailsPane(d, {\n                        closable: !1\n                    }), f = c.panes.cached(d), g = c.panes.reset(e), i = g.$dom;\n                    using(twttr.bundleMore, function() {\n                        twttr.messageManager.getThread(a, function(b) {\n                            var d = ((twttr.decider.isAvailable(\"phoenix_use_conversation_endpoint\") ? twttr.components.ConversationThread : twttr.components.MessageThread)), e = new d(b);\n                            g._backLabel = _(\"Conversation with {{screen_name}}\", {\n                                screen_name: b.threadId\n                            });\n                            if (!f) {\n                                var j = new twttr.components.SendMessageBox(a, 522);\n                                j.bind(\"sentMessage\", function(a, b) {\n                                    twttr.messageManager.addMessage(b);\n                                }), j.$node.appendTo(i.JSBNG__find(\".pane-toolbar\"));\n                            }\n                        ;\n                        ;\n                            c.addComponentsToDetailsPane(i, [e,]);\n                        });\n                    });\n                },\n                $detailsPane: function() {\n                    return this.$find(\".details-pane\");\n                },\n                openDetailsPane: function() {\n                    if (this._detailsPaneDisabled()) {\n                        return !1;\n                    }\n                ;\n                ;\n                    var a = this.$detailsPane();\n                    ((a.hasClass(\"opened\") || (a.show(), this._slideDetailsPaneTo(((this.$mainContent.width() - 10))), this.$dashboard.hide(), a.addClass(\"opened\")))), this.repositionDetailsPane(), this.resizeDetailsPane();\n                },\n                _slideDetailsPaneTo: function(a, b) {\n                    this.$detailsPane()[((Modernizr.csstransitions ? \"animateWithCss\" : \"animate\"))](((((twttr.i18n && twttr.i18n.rtl)) ? {\n                        right: a\n                    } : {\n                        left: a\n                    })), 250, ((Modernizr.csstransitions ? \"ease-out\" : \"linear\")), b);\n                },\n                closeDetailsPane: function() {\n                    if (((this.isDPLocked === !0))) {\n                        return this.isDPLocked = !1, !1;\n                    }\n                ;\n                ;\n                    if (this._detailsPaneDisabled()) {\n                        return !1;\n                    }\n                ;\n                ;\n                    var a = this.$detailsPane();\n                    ((a.hasClass(\"opened\") && (this.panes.JSBNG__top().hide(), this.$dashboard.show(), this._slideDetailsPaneTo(10, function() {\n                        $(this).hide();\n                    }), a.removeClass(\"opened\"), scribble(\"close-details-pane\", {\n                        input: \"click\",\n                        current_tweet_id: this.streamManager.getCurrent().focusedItemId\n                    }))));\n                },\n                resizeDetailsPane: function() {\n                    var a = this.$detailsPane();\n                    $pageOuter = $(\"#page-outer\"), pagePaddingTop = parseInt($pageOuter.css(\"padding-top\"), 10);\n                    if (((a.length > 0))) {\n                        var b = $(\"#page-container\"), c = $(\"#page-container\").width(), d = ((this.$mainContent ? this.$mainContent.width() : 0)), e = ((c - d)), f = ((twttr.$win.height() - pagePaddingTop)), g = ((((f - a[0].offsetTop)) - 8));\n                        ((this.$mainContent && this.$mainContent.css(\"min-height\", f))), a.height(g), a.width(e), a.JSBNG__find(\".pane-components\").height(((g - a.JSBNG__find(\".inner-pane.active .pane-toolbar\").JSBNG__outerHeight())));\n                    }\n                ;\n                ;\n                },\n                repositionDetailsPane: function() {\n                    if (((!twttr.decider.goodAtCss() || !this.$detailsPaneOuter))) {\n                        return;\n                    }\n                ;\n                ;\n                    if (this.windowHasHorizontalScroll()) {\n                        var a = twttr.$win.scrollTop();\n                        this.$detailsPaneOuter.addClass(\"tracking-vertically\"), this.$detailsPaneOuter.css({\n                            \"margin-top\": a,\n                            JSBNG__top: 0\n                        });\n                    }\n                     else {\n                        var b = this.getTopPositionForDetailsPane();\n                        this.$detailsPaneOuter.removeClass(\"tracking-vertically\"), this.$detailsPaneOuter.css({\n                            \"margin-top\": null,\n                            JSBNG__top: b\n                        });\n                    }\n                ;\n                ;\n                },\n                getTopPositionForDetailsPane: function() {\n                    var a = twttr.$win.scrollTop(), b = parseInt($(\"#page-outer\").css(\"padding-top\"), 10), c = (($(\"#page-container\").position().JSBNG__top - a));\n                    return ((((c < b)) && (c = b))), c;\n                },\n                windowHasHorizontalScroll: function() {\n                    return ((twttr.$win.width() < 1000));\n                },\n                addComponentToDetailsPane: function(a, b, c) {\n                    c = ((c || \"append\")), a.JSBNG__find(\".pane-components-inner\")[c](b.$node);\n                },\n                addComponentsToDetailsPane: function(a, b) {\n                    for (var c = 0; ((c < b.length)); c++) {\n                        this.addComponentToDetailsPane(a, b[c]);\n                    ;\n                    };\n                ;\n                }\n            }).addAfterRender(function() {\n                this.$dashboard = this.$find(\".dashboard\"), this.$mainContent = this.$find(\"div.main-content\"), this.$detailsPaneOuter = this.$find(\"#details-pane-outer\"), this.resizeDetailsPane(), ((this.streamManager || (this.streamManager = new twttr.streams.StreamManager(this.pageNameUnderscore, this.$node), this.streamManager.bind(\"newItemsCountChanged\", twttr.bind(this, function(a, b) {\n                    this.hasNewItems(b);\n                })), this.streamManager.bind(\"notFound\", twttr.bind(this, function(a) {\n                    this.trigger(\"notFound\");\n                })), this.streamManager.bind(\"switchTo\", twttr.bind(this, function(a) {\n                    this.closeDetailsPane();\n                })), ((twttr.decider.isExpando() && this.streamManager.bind(\"doneLoadingMore\", twttr.bind(this, function(a) {\n                    this.$find(\".expanding-stream-item\").removeClass(\"expanding-stream-item\");\n                }))))))), ((this.streamManager.preRendered || this.$node.JSBNG__find(\"div.js-stream-manager-container\").append(this.streamManager.$node))), this.panes = new twttr.ViewStack(this.$detailsPane(), \"append\"), this.trigger(\"streamManagerReady\");\n            }).addOnSwitchTo(function() {\n                ((twttr.decider.isExpando() && ($(\"#page-container\").removeClass(\"expando-container\"), $(\"#page-outer\").removeClass(\"flush-to-top\"))));\n                var a = twttr.audit.trail()[1];\n                ((((a && a.page.match(/userMedia/))) && (this.isDPLocked = !0, ((this.yScroll && twttr.$win.scrollTop(this.yScroll)))))), this.resizeDetailsPane();\n            }), this;\n        });\n        a(c);\n    });\n});\nprovide(\"mixins/streamablePageDropdownEdition\", function(a) {\n    using().as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.streamablePageDropdownEdition\", function(a) {\n            var b = $(\"html, body\"), c = 8, d = 700, e = 50, f = 30, g = 436, i = 75, j = 105, k = 40, l = 20, m = 40;\n            ((twttr.decider.isAvailable(\"platform_enable_cards\") && (d = 375)));\n            var n = {\n                toggle: function(a, b) {\n                    ((a.is(\".js-original-tweet\") && (b.topLevelExpansion = !0, ((((!b.autoExpanded && ((b.containerClass === \".expanding-stream-item\")))) && (b.fullExpansion = !0))))));\n                    var c = n.expandTweetDom(a, b.containerClass), d = 0;\n                    return ((c.$target.hasClass(\"animating\") ? 0 : (((c.$target.data(\"dropdown.showing\") ? (n.close(c, b), n.scribeClose(c, b.currentStream), d = -1) : ((b.forceClose || (((c.$target.data(\"dropdown.loaded\") ? n.open(c, b) : (n.load(c, b), ((b.autoExpanded && JSBNG__setTimeout(function() {\n                        c.$target.next().addClass(\"after-expanded\");\n                    }, 0)))))), d = 1, n.scribeLoad(c, b.currentStream)))))), ((b.topLevelExpansion ? d : 0)))));\n                },\n                expandTweetDom: function(a, b) {\n                    var c = ((b ? a.closest(b) : a));\n                    return {\n                        $target: c,\n                        $tweet: a,\n                        $expansion: a.parent(),\n                        $ancestors: c.JSBNG__find(\"div.js-tweet-ancestors\"),\n                        $replies: c.JSBNG__find(\"div.js-conversation-replies\")\n                    };\n                },\n                open: function(a, b) {\n                    a.$tweet.JSBNG__find(\"iframe[data-expando-iframe-media-url]\").each(function(a, b) {\n                        var c = b.getAttribute(\"data-expando-iframe-media-url\");\n                        ((!c || (b.src = c)));\n                    }), a.$target.data(\"dropdown.showing\", !0).addClass(\"animating\"), n.enterExpandedState(a.$target, b), n.showHideContent(!1, n.expandTweetDom(a.$tweet, b.containerClass), b), a.$tweet.trigger(\"expanded.tweet\");\n                },\n                close: function(a, b) {\n                    a.$target.data(\"dropdown.showing\", !1).addClass(\"animating\"), n.exitExpandedState(a.$target, b), n.showHideContent(!0, a, b, function() {\n                        a.$target.JSBNG__find(\".opened-tweet\").each(function() {\n                            n.toggle($(this), {\n                                noAnimation: !0,\n                                currentStream: b.currentStream\n                            });\n                        }), a.$tweet.trigger(\"collapsed.tweet\");\n                    });\n                },\n                enterExpandedState: function(a, b) {\n                    a.addClass(\"open\").filter(\".js-stream-item\").animate({\n                        marginTop: ((((a.index() === 0)) ? 0 : c)),\n                        marginBottom: c\n                    }, {\n                        duration: ((b.noAnimation ? 0 : i)),\n                        queue: !1\n                    }).prev().addClass(\"before-expanded\").end().next().addClass(\"after-expanded\"), ((a.hasClass(\"hovered-stream-item\") && a.removeClass(\"hovered-stream-item\").addClass(\"js-had-hovered-stream-item\")));\n                },\n                exitExpandedState: function(a, b) {\n                    a.removeClass(\"open\").filter(\".js-stream-item\").animate({\n                        marginTop: 0,\n                        marginBottom: 0\n                    }, {\n                        duration: ((b.noAnimation ? 0 : i)),\n                        queue: !1,\n                        complete: function() {\n                            a.prev().removeClass(\"before-expanded\").end().next().removeClass(\"after-expanded\"), ((a.hasClass(\"js-had-hovered-stream-item\") && a.removeClass(\"js-had-hovered-stream-item\").addClass(\"hovered-stream-item\")));\n                        }\n                    });\n                },\n                simpleShowHideContent: function(a, b) {\n                    var c = b.children().height();\n                    b.animate({\n                        height: ((a ? 0 : c))\n                    }, {\n                        duration: n.guessGoodSpeed(c)\n                    });\n                },\n                showHideContent: function(a, d, f, g) {\n                    d.$target.addClass(\"animating\"), ((!a && d.$tweet.addClass(\"opened-tweet\")));\n                    var i = ((d.$expansion.data(\"height\") || 0)), j = ((((d.$ancestors.height() || d.$ancestors.data(\"height\"))) || 0)), k = d.$tweet.JSBNG__innerHeight(), l = ((((((d.$replies.height() || d.$replies.data(\"height\"))) || 0)) + k)), m = ((l - i)), o = ((f.noAnimation ? 0 : n.guessGoodSpeed(j, m))), p = twttr.$win.scrollTop(), q = ((d.$target.offset().JSBNG__top - c)), r = ((((p + e)) - q));\n                    ((a || d.$expansion.height(i))), d.$expansion.animate({\n                        height: ((a ? i : l))\n                    }, {\n                        duration: o,\n                        step: function(c) {\n                            var e = ((c - i)), g = ((e / m));\n                            d.$ancestors.height(((j * g))), ((((((((r > 0)) && a)) && !f.noAnimation)) && b.scrollTop(((p - ((r * ((1 - g)))))))));\n                        },\n                        complete: function() {\n                            n.resetEmbeddedContent(d, a), d.$target.removeClass(\"animating\"), ((a && d.$tweet.removeClass(\"opened-tweet\"))), d.$expansion.height(\"auto\"), d.$ancestors.height(\"auto\"), ((g && g()));\n                            var b = d.$tweet.data(\"inline-tweetbox\");\n                            ((((((f.focusOnReply && b)) && !a)) && b.JSBNG__focus()));\n                        }\n                    });\n                },\n                guessGoodSpeed: function() {\n                    var a = Math.max.apply(Math, arguments);\n                    return Math.round(((((358708 * Math.log(a))) * j)));\n                },\n                load: function(a, b) {\n                    a.$target.addClass(\"animating\").data(\"dropdown.loaded\", !0), ((b.tweet ? using(twttr.bundleMore, function() {\n                        n.loadWithTweet(a, b, b.tweet);\n                    }) : twttr.API.Status.JSBNG__find(a.$tweet.attr(\"data-tweet-id\"), function(c) {\n                        n.loadWithTweet(a, b, c);\n                    })));\n                },\n                loadWithTweet: function(a, b, c) {\n                    (new twttr.views.TweetDetails(c)).render(a.$target.JSBNG__find(\"div.js-tweet-details-dropdown\"), \"append\");\n                    var d = a.$tweet.JSBNG__find(\"div.js-tweet-media-container\");\n                    a.$expansion = n.wrapComponents(a, a.$tweet.JSBNG__outerHeight());\n                    var e;\n                    ((twttr.Cards.prototype.hasCardPhotoEntities(c) ? e = n.sumEntityMediaEmbedHeights(c.entities.media) : ((twttr.Cards.prototype.hasCards(c) ? e = n.sumCardMediaHeights(c.cards) : e = n.sumMediaEmbedHeights(a.$tweet.JSBNG__find(\"a.twitter-timeline-link\")))))), ((((e > 0)) ? d.css(\"min-height\", Math.ceil(e)) : d.hide())), n.open(a, b), o.media(c, d), o.translation(c, a.$target.JSBNG__find(\"div.js-machine-translated-tweet-container\"));\n                    var f = ((b.fullExpansion ? 7 : 6));\n                    o.socialProof(c, a.$target.JSBNG__find(\"div.js-tweet-stats-container\"), f), o.geo(c, a.$target.JSBNG__find(\"div.js-tiny-geo\"));\n                    if (((b.fullExpansion && !b.autoExpanded))) {\n                        o.conversation(c, a, b);\n                        var g = a.$tweet.attr(\"data-impression-id\");\n                        ((g && (c = twttr.API.util.PromotedStore.getPromotedStatusInstance(c, g), twttr.API.util.PromotedContent.logShowDetails(g))));\n                    }\n                ;\n                ;\n                },\n                sumCardMediaHeights: function(a) {\n                    var b, c = 0;\n                    return ((((a.photos && (b = a.photos[0]))) ? ((((b.images && b.images.web)) && (c = b.images.web.height))) : ((((a.players && (b = a.players[0]))) ? ((((((b.players && b.players.length)) && b.players[0].height)) && (c = b.players[0].height))) : ((((a.summaries && (b = a.summaries[0]))) && ((((b.images && b.images.web)) ? c = b.images.web.height : c = k)))))))), ((c && (c += k))), ((b.author_user_id_str && (c += l))), ((b.site_user_id_str && (c += m))), c;\n                },\n                sumEntityMediaEmbedHeights: function(a) {\n                    return twttr.reduce(a, 0, function(a, b, c) {\n                        var e, i;\n                        ((((c.type === \"photo\")) ? (e = c.sizes.medium.h, width = c.sizes.medium.w) : (e = c.thumbnails[0].height, width = c.thumbnails[0].width))), ((((width && ((width > g)))) && (e = ((g * ((e / width)))))));\n                        var j = ((e ? ((Math.min(e, d) + f)) : 75));\n                        return ((a + j));\n                    });\n                },\n                sumMediaEmbedHeights: function(a) {\n                    return twttr.reduce(a, 0, function(a, b, c) {\n                        var e = $(c), i = e.data(\"media-type\");\n                        if (i) {\n                            var j = ((e.data(\"media-h\") || i.height)), k = e.data(\"media-w\");\n                            ((((k && ((k > g)))) && (j = ((g * ((j / k)))))));\n                            var l = ((j ? ((Math.min(j, d) + f)) : 75));\n                            return ((a + l));\n                        }\n                    ;\n                    ;\n                        return ((a + 0));\n                    });\n                },\n                wrapComponents: function(a, b) {\n                    var c = $(\"\\u003Cdiv/\\u003E\", {\n                        class: \"expansion-container js-expansion-container\",\n                        height: b,\n                        data: {\n                            height: b\n                        }\n                    });\n                    return a.$tweet.wrap(c), a.$target.JSBNG__find(\"div.js-expansion-container\");\n                },\n                resetEmbeddedContent: function(a, b) {\n                    var c = a.$target.JSBNG__find(\"*[has-playable-media='true'] div.tweet-media\");\n                    ((c.length && ((b ? c.height(c.height()).empty() : c.filter(\":empty\").trigger(\"showMedia\"))))), ((((b && twttr.decider.isAvailable(\"platform_enable_cards\"))) && a.$target.JSBNG__find(\".cards-base.cards-multimedia iframe\").each(function(a, b) {\n                        b.setAttribute(\"data-expando-iframe-media-url\", b.src), b.src = \"\";\n                    })));\n                },\n                scribeLoad: function(a, b) {\n                    var c = a.$tweet.JSBNG__find(\"span.js-icon-container .media\").map(function(a, b) {\n                        return [[b.getAttribute(\"data-media-type\"),b.getAttribute(\"data-media-class\"),],];\n                    }).get();\n                    scribble(\"load-details-pane\", {\n                        component: \"stream\",\n                        details_type: \"tweet\",\n                        item_id: a.$target.attr(\"data-item-id\"),\n                        stream: b.constructor._name,\n                        page_number: b._page,\n                        embedded_media_types: c\n                    }), b.trigger(\"select.tweet\", [a.$target,a.$target,\"select\",]);\n                },\n                scribeClose: function(a, b) {\n                    scribble(\"close-details-pane\", {\n                        input: \"click\",\n                        current_tweet_id: b.focusedItemId\n                    }), b.trigger(\"deselect.tweet\", [a.$target,a.$target,\"deselect\",]);\n                }\n            }, o = {\n                media: function(a, b) {\n                    using(\"components/Media\", function(c) {\n                        if (!b.is(\":empty\")) {\n                            return;\n                        }\n                    ;\n                    ;\n                        (new c(a, g, {\n                            afterRender: function(a) {\n                                var c = a.icon();\n                                ((((((c === \"video\")) || ((c === \"song\")))) && b.attr(\"has-playable-media\", !0).show()));\n                            },\n                            whenNotDisplayed: function(a) {\n                                b.css(\"min-height\", 0).show();\n                            }\n                        })).$node.appendTo(b);\n                    });\n                },\n                translation: function(a, b) {\n                    using(\"components/MachineTranslationBackend\", function(c) {\n                        if (!b.is(\":empty\")) {\n                            return;\n                        }\n                    ;\n                    ;\n                        (new twttr.components.MachineTranslatedTweet(a)).$node.appendTo(b);\n                    });\n                },\n                conversation: function(a, b, c) {\n                    using(\"components/Conversation\", \"components/Replies\", function(d, e) {\n                        var f;\n                        new d(a, null, function(d) {\n                            new e(a, null, d.resultGroups, function() {\n                                if (b.$expansion.JSBNG__find(\".js-conversation-replies\").length) {\n                                    return;\n                                }\n                            ;\n                            ;\n                                var a = $(\"\\u003Cdiv class='replies js-conversation-replies'\\u003E\\u003C/div\\u003E\").height(0).appendTo(b.$expansion);\n                                this.$node.appendTo(a), f = new twttr.components.InlineReplyBox(b.$tweet, a, this.$node, 421);\n                            });\n                            if (((b.$tweet.data(\"is-reply-to\") && ((b.$target.JSBNG__find(\".js-tweet-ancestors\").length === 0))))) {\n                                b.$target.addClass(\"animating\");\n                                var g = d.$node.JSBNG__find(\".js-tweet-ancestors\");\n                                g.attr(\"data-component-term\", \"conversation\"), g.height(0).prependTo(b.$target);\n                            }\n                        ;\n                        ;\n                            JSBNG__setTimeout(function() {\n                                var a = n.expandTweetDom(b.$tweet, c.containerClass), d = ((!c.noAnimation && b.$target.data(\"dropdown.showing\")));\n                                p(a.$ancestors, d), p(a.$replies, d, function() {\n                                    ((f && (b.$tweet.data(\"inline-tweetbox\", f), ((c.focusOnReply && f.JSBNG__focus())))));\n                                });\n                            }, 0);\n                        });\n                    });\n                },\n                socialProof: function(a, b, c) {\n                    using(\"components/TweetStats\", \"components/Retweeters\", function(d, e) {\n                        var f = (($.trim(b.html()) == \"\"));\n                        if (!f) {\n                            return;\n                        }\n                    ;\n                    ;\n                        var g = ((((((twttr.loggedIn && twttr.decider.isActivityEnabled())) && twttr.decider.isAvailable(\"activity_status_summary\"))) ? d : e));\n                        (new g(a, c, function() {\n                            b.show();\n                        })).$node.appendTo(b);\n                    });\n                },\n                geo: function(a, b) {\n                    using(\"components/TweetGeoSmall\", function(c) {\n                        if (!b.is(\":empty\")) {\n                            return;\n                        }\n                    ;\n                    ;\n                        (new c(a)).$node.appendTo(b);\n                    });\n                }\n            }, p = function(a, b, c) {\n                if (!a.length) {\n                    return;\n                }\n            ;\n            ;\n                var d = a.children().height();\n                a.data(\"height\", d), ((b ? a.animate({\n                    height: d\n                }, n.guessGoodSpeed(d), function() {\n                    a.parent().removeClass(\"animating\"), a.height(\"auto\"), ((c && c()));\n                }) : a.height(\"auto\")));\n            };\n            return a.mixin(twttr.mixins.profilePopupActionable).keypress({\n                l: function() {\n                    this.closeAllTweets();\n                }\n            }).click({\n                \"div.js-tiny-geo .map_canvas\": function(a, b) {\n                    a.stopPropagation();\n                },\n                \".js-activity-tweet\": function(a, b) {\n                    this.handleExpandoClick(a, b, \".supplement\");\n                },\n                \".expanding-stream-item .js-original-tweet\": function(a, b) {\n                    this.handleExpandoClick(a, b, \".expanding-stream-item\");\n                },\n                \".expanding-stream-item .js-expando-link\": function(a, b) {\n                    this.simpleShowHide(b);\n                },\n                \".js-tweet-ancestors .js-stream-tweet, .js-conversation-replies .js-stream-tweet\": function(a, b) {\n                    this.handleExpandoClick(a, b);\n                }\n            }).methods({\n                closeAllTweets: function() {\n                    var a = twttr.$win.scrollTop(), c = this.firstVisibleItemBelow(a);\n                    if (c) {\n                        var d = c.offset().JSBNG__top, e = this;\n                        this.$find(\"div.open.expanding-stream-item div.js-original-tweet\").each(function() {\n                            e.showHide($(this), {\n                                containerClass: \".expanding-stream-item\",\n                                noAnimation: !0\n                            });\n                        }), this.$find(\"div.open.expanding-stream-item div.js-expando-link\").each(function() {\n                            e.simpleShowHide($(this));\n                        });\n                        var f = c.offset().JSBNG__top;\n                        b.scrollTop(((a - ((d - f)))));\n                    }\n                ;\n                ;\n                },\n                firstVisibleItemBelow: function(a) {\n                    var b;\n                    return this.$find(\".js-stream-item\").each(function() {\n                        var c = $(this);\n                        if (((c.offset().JSBNG__top >= a))) {\n                            return b = c, !1;\n                        }\n                    ;\n                    ;\n                    }), b;\n                },\n                handleExpandoClick: function(a, b, c, d) {\n                    d = ((d || {\n                    }));\n                    var e = $(a.target).is(\".js-open-close-tweet, .js-open-close-tweet *\");\n                    (($(a.target).hasClass(\"action-reply-container\") && (d.focusOnReply = !0)));\n                    if (((e || !this.shouldPreventClickFrom($(a.target))))) {\n                        var f = twttr.tco.JSBNG__getSelection();\n                        a.preventDefault(), a.stopPropagation();\n                        if (((((e || f.isCollapsed)) || ((f.htmlText === \"\"))))) {\n                            d.containerClass = c, this.showHide(b, d);\n                            var g = \"tweet_anatomy_2_231\";\n                            ((((((!b.is(\".open\") && twttr.isT1)) && twttr.abdecider.choose(g))) && (($(a.target).is(\".open-tweet\") ? twttr.abdecider.track(g, \"open-tweet-open-label\") : (($(a.target).is(\".view-open\") ? twttr.abdecider.track(g, \"open-tweet-view-label\") : twttr.abdecider.track(g, \"open-tweet-whitespace\")))))));\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                },\n                shouldPreventClickFrom: function(a) {\n                    var b = ((a.is(\"a, a *, button, button *\") && !a.is(\".js-details *\"))), c = a.is(\"embed,object\");\n                    return ((b || c));\n                },\n                getTweetFromItems: function(a, b) {\n                    var c, d = ((b && b.items));\n                    if (d) {\n                        for (var e = 0, f = d.length; ((e < f)); e++) {\n                            if (((a === d[e].id))) {\n                                c = d[e];\n                                break;\n                            }\n                        ;\n                        ;\n                        };\n                    }\n                ;\n                ;\n                    return c;\n                },\n                simpleShowHide: function(a) {\n                    var b = \".expanding-stream-item\", c = a.closest(b), d = {\n                    }, e = a.closest(\".stream-item\").JSBNG__find(\".js-expando-control-expanded\"), f = e.hasClass(\"show\");\n                    ((f ? (this.updateExpandoControl(!0, e), n.exitExpandedState(c, d), n.simpleShowHideContent(!0, c.JSBNG__find(\"div.js-expando-content\")), a.trigger(\"simpleExpandoContract\"), this.openCount += -1) : (this.updateExpandoControl(!1, e), n.enterExpandedState(c, d), n.simpleShowHideContent(!1, c.JSBNG__find(\"div.js-expando-content\")), a.trigger(\"simpleExpandoExpand\"), this.openCount += 1))), this.showHideCloseAllButton();\n                },\n                showHide: function(a, b) {\n                    b = ((b || {\n                    })), b.currentStream = this.streamManager.getCurrent(), b.tweet = this.getTweetFromItems(a.attr(\"data-tweet-id\"), b.currentStream), this.openCount += n.toggle(a, b), this.showHideCloseAllButton();\n                },\n                toggleFocus: function(a) {\n                    this.showHide(a.JSBNG__find(\".js-original-tweet\"), {\n                        containerClass: \".expanding-stream-item\"\n                    });\n                },\n                showHideCloseAllButton: function() {\n                    ((this.$closer && ((((this.openCount > 0)) ? this.$closer.fadeIn(\"fast\") : this.$closer.fadeOut(\"fast\")))));\n                },\n                updateExpandoControl: function(a, b) {\n                    var c = b.closest(\".stream-item\");\n                    c.JSBNG__find(\".js-expando-control-expanded\").removeClass(((a ? \"show\" : \"hide\"))).addClass(((a ? \"hide\" : \"show\"))), c.JSBNG__find(\".js-expando-control-unexpanded\").removeClass(((a ? \"hide\" : \"show\"))).addClass(((a ? \"show\" : \"hide\")));\n                },\n                resetCloseAllButton: function() {\n                    this.$closer = $(\"a.js-close-all-tweets\"), this.openCount = this.$find(\"div.open\").length, ((((this.openCount > 0)) ? this.$closer.show() : this.$closer.hide()));\n                },\n                dropdown: n,\n                focusStreamItem: twttr.util.noopInT1,\n                unfocusStreamItem: twttr.util.noopInT1,\n                resizeDetailsPane: twttr.util.noopInT1,\n                repositionDetailsPane: twttr.util.noopInT1\n            }).addAfterRender(function() {\n                this.$dashboard = this.$find(\"div.dashboard\"), this.$mainContent = this.$find(\"div.main-content\");\n                var a = this;\n                ((this.streamManager || (this.streamManager = new twttr.streams.StreamManager(this.pageNameUnderscore, this.$node), this.streamManager.bind(\"newItemsCountChanged\", twttr.bind(this, function(a, b) {\n                    this.hasNewItems(b);\n                })), this.streamManager.bind(\"notFound\", twttr.bind(this, function(a) {\n                    this.trigger(\"notFound\");\n                })), this.streamManager.bind(\"switchTo didNotSwitch\", twttr.bind(this, function(b) {\n                    twttr.app.trigger(\"streamSwitchedTo\", [this,]), JSBNG__setTimeout(function() {\n                        a.resetCloseAllButton(), a.$find(\"div.tweet-media\").trigger(\"showMedia\");\n                    }, 0);\n                }))))), ((this.streamManager.preRendered || this.$node.JSBNG__find(\"div.js-stream-manager-container\").append(this.streamManager.$node))), this.panes = [], this.$find(\".stream-item\").addClass(\"expanding-stream-item\"), this.trigger(\"streamManagerReady\");\n            }).addOnSwitchAway(function() {\n                ((this.$closer && this.$closer.hide()));\n            });\n        }), a();\n    });\n});\nprovide(\"mixins/streamablePageWithInlineMedia\", function(a) {\n    using().as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.streamablePageWithInlineMedia\", function() {\n            this.methods({\n                addInlineMediaIcons: function(a, b) {\n                    using([twttr.bundleMore,\"media/Iconifier\",], function() {\n                        new twttr.media.Iconifier(a, b);\n                    });\n                }\n            });\n        }), a(twttr.mixins.streamablePageWithInlineMedia);\n    });\n});\nprovide(\"mixins/itemActionableScribing\", function(a) {\n    using(\"util\", \"constants\").as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.itemActionableScribing\", function(a) {\n            return a.methods({\n                _tweetHasCard: function(a) {\n                    return ((a.hasClass(\"has-cards\") || ((a.JSBNG__find(\".has-cards\").length > 0))));\n                },\n                _getDataFromTweet: function(a) {\n                    var b = {\n                    }, c = a.JSBNG__find(\".cards-base\");\n                    return b.tweetHasCard = c.length, ((b.tweetHasCard && (b.cardType = c.data(\"card-type\"), b.cardUrl = c.data(\"card-url\"), b.publisherUserId = this._getUserIdFromElement(c.JSBNG__find(\".source .js-user-profile-link\")), b.creatorUserId = this._getUserIdFromElement(c.JSBNG__find(\".byline .js-user-profile-link\"))))), b;\n                },\n                _getUserIdFromElement: function(a) {\n                    return ((a.length ? a.attr(\"data-user-id\") : null));\n                },\n                _prepareCustomScribeData: function(a) {\n                    var b = {\n                        associations: {\n                        }\n                    };\n                    return b.associations[2] = {\n                        association_id: a.publisherUserId,\n                        association_type: 3\n                    }, b.associations[3] = {\n                        association_id: a.creatorUserId,\n                        association_type: 3\n                    }, b.message = a.cardUrl, {\n                        scribeData: b\n                    };\n                },\n                _registerTweetActionScribeListeners: function() {\n                    var a = this;\n                    this.bind(\"favorite.tweet unfavorite.tweet retweet.tweet unretweet.tweet delete.tweet reply.tweet dismiss.tweet not_relevant.tweet deselect.tweet permalink_click.tweet\", function(b, c, d, e) {\n                        var f = a._itemMetadata(c);\n                        a._itemScribe(e, {\n                            event_info: e\n                        }, f);\n                        if (((((e == \"deselect\")) && a._tweetHasCard(c)))) {\n                            var g = a._getDataFromTweet(c);\n                            a._itemScribe(\"hide\", {\n                                event_info: \"hide\",\n                                element: ((((\"platform_\" + g.cardType)) + \"_card\"))\n                            }, twttr.merge(f, a._prepareCustomScribeData(g)));\n                        }\n                    ;\n                    ;\n                    }), this.bind(\"select.tweet\", function(b, c, d, e) {\n                        var f = a._itemMetadata(c), g = {\n                            event_info: e\n                        };\n                        if (d.JSBNG__find(\".sm-image\").length) {\n                            var i = d.JSBNG__find(\"a[data-expanded-url]\").attr(\"data-expanded-url\");\n                            ((i && (g.url = i)));\n                        }\n                    ;\n                    ;\n                        a._itemScribe(e, g, f);\n                        if (a._tweetHasCard(c)) {\n                            var g = a._getDataFromTweet(c);\n                            a._itemScribe(\"show\", {\n                                event_info: \"show\",\n                                element: ((((\"platform_\" + g.cardType)) + \"_card\"))\n                            }, twttr.merge(f, a._prepareCustomScribeData(g)));\n                        }\n                    ;\n                    ;\n                    }), this.bind(\"avatar_click.tweet screen_name_click.tweet promoted_badge_click.tweet\", function(b, c, d, e) {\n                        var f = a._itemMetadata(c);\n                        f.itemDetails.target_id = ((((d.JSBNG__find(\"[data-user-id]\").attr(\"data-user-id\") || d.attr(\"data-user-id\"))) || d.closest(\"[data-user-id]\").attr(\"data-user-id\")));\n                        if (a._tweetHasCard(c)) {\n                            var g = a._getDataFromTweet(c);\n                            ((g.tweetHasCard && a._itemScribe(\"profile_click\", {\n                                event_info: e,\n                                element: ((((\"platform_\" + g.cardType)) + \"_card\"))\n                            }, twttr.merge(f, a._prepareCustomScribeData(g)))));\n                        }\n                    ;\n                    ;\n                        a._itemScribe(\"profile_click\", {\n                            event_info: e\n                        }, f);\n                    }), this.bind(\"hashtag_click.tweet\", function(b, c, d, e) {\n                        var f = a._itemMetadata(c);\n                        a._itemScribe(\"search\", {\n                            event_info: \"hashtag\",\n                            query: d.text()\n                        }, f);\n                    }), this.bind(\"mention_click.tweet\", function(b, c, d, e) {\n                        var f = a._itemMetadata(c);\n                        a._itemScribe(\"mention_click\", {\n                            event_info: \"mention\"\n                        }, f);\n                    }), this.bind(\"external_link_click.tweet\", function(b, c, d, e) {\n                        var f = a._itemMetadata(c), g = ((d.attr(\"data-expanded-url\") || d.attr(\"href\"))), i = {\n                            event_info: \"external_link\",\n                            url: g\n                        }, j = d.closest(\".has-cards\").JSBNG__find(\".cards-base\").data(\"card-type\");\n                        ((((((j !== null)) && ((j !== undefined)))) && (i.element = ((((\"platform_\" + j)) + \"_card\"))))), a._itemScribe(\"open_link\", i, f), twttr.externalURLStore.setData(g, f), ((twttr.abdecider.chooseWithoutImpression(\"long_tweet_urls_2_259\") && ((d.attr(\"data-long_tweet_urls_2_259\") ? twttr.abdecider.track(\"long_tweet_urls_2_259\", \"open_link_expanded\") : twttr.abdecider.track(\"long_tweet_urls_2_259\", \"open_link_short\")))));\n                    });\n                },\n                _registerUserActionScribeListeners: function() {\n                    var a = this;\n                    this.bind(\"follow.user unfollow.user follow.tweet\", function(b, c, d, e) {\n                        var f = a._itemMetadata(c);\n                        f.itemDetails.target_id = d.attr(\"data-user-id\");\n                        var g = {\n                            event_info: e\n                        };\n                        if (c.hasClass(\"has-cards\")) {\n                            var i = a._getDataFromTweet(c);\n                            g.element = ((((\"platform_\" + i.cardType)) + \"_card\")), f = twttr.merge(f, a._prepareCustomScribeData(i));\n                        }\n                    ;\n                    ;\n                        a._itemScribe(e, g, f), ((c.attr(\"data-impression-id\") && trackClient({\n                            component: \"promoted_user_recommendations\",\n                            action: e\n                        })));\n                    }), this.bind(\"select.user deselect.user dismiss.user reply.user block.user unblock.user add_to_list.user report_as_spam.user accept.user deny.user dm.user\", function(b, c, d, e) {\n                        var f = a._itemMetadata(c);\n                        a._itemScribe(e, {\n                            event_info: e\n                        }, f);\n                    }), this.bind(\"avatar_click.user screen_name_click.user promoted_badge_click.user\", function(b, c, d, e) {\n                        var f = a._itemMetadata(c);\n                        f.itemDetails.target_id = ((d.JSBNG__find(\"[data-user-id]\").attr(\"data-user-id\") || d.attr(\"data-user-id\"))), a._itemScribe(\"profile_click\", {\n                            event_info: e\n                        }, f), ((c.attr(\"data-impression-id\") && trackClient({\n                            component: \"promoted_user_recommendations\",\n                            action: \"profile_click\"\n                        })));\n                    });\n                },\n                getScribbler: function() {\n                    if (this.scribbler) {\n                        return this.scribbler;\n                    }\n                ;\n                ;\n                    if (this.getStreamManager) {\n                        var a = this.getStreamManager(), b = ((a && a.getCurrent()));\n                        if (((b && b.scribbler))) {\n                            return b.scribbler;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    return twttr.Scribbler.clientEvent;\n                },\n                _getScribeComponentName: function() {\n                    return ((this.scribeComponentName ? this.scribeComponentName : ((((this.constructor && this.constructor._name)) ? b.util.underscore(this.constructor._name) : \"\"))));\n                },\n                _itemScribe: function(a, b, c) {\n                    var d = {\n                        component: this._getScribeComponentName(c.targetItem),\n                        action: a\n                    };\n                    ((b.element && (d.element = b.element)));\n                    if (c.targetObj) {\n                        var e = twttr.Scribbler.getElementEventNameTerms(c.targetObj);\n                        ((e.component && (d.component = e.component)));\n                    }\n                ;\n                ;\n                    if (((c.itemType && c.itemId))) {\n                        var f = {\n                        };\n                        f[((c.itemId + \"\"))] = c.itemDetails, c.scribeData.item_details = f;\n                    }\n                ;\n                ;\n                    this.getScribbler().scribe(d, twttr.merge(b, c.scribeData)), ((((((twttr.profileUser && twttr.profileUser.verified)) && ((twttr.app.currentPageName() == \"profile\")))) && twttr.abdecider.track(\"replies_stripped_on_verified_profiles_222\", a))), this._itemDetailsScribe(a, c.itemType, c.itemObj);\n                },\n                _itemDetailsScribe: function(a, b, c) {\n                    var d = \"tweet_anatomy_2_231\";\n                    if (((((((b === \"tweet\")) && twttr.isT1)) && twttr.abdecider.choose(d)))) {\n                        if (((a === \"impression\"))) {\n                            var e = c.attr(\"data-tweet-id\"), f = window.__tweet_anatomy_2_231_impressionSink;\n                            ((f || (f = window.__tweet_anatomy_2_231_impressionSink = [])));\n                            if ((($.inArray(e, f) !== -1))) {\n                                return;\n                            }\n                        ;\n                        ;\n                            f.unshift(e), ((((f.length > 5000)) && (f.length = 5000)));\n                        }\n                    ;\n                    ;\n                        var g = {\n                            hashtag: \".twitter-hashtag\",\n                            link: \".twitter-timeline-link\",\n                            username: \".twitter-atreply\",\n                            photo: \".sm-image\",\n                            video: \".sm-video\",\n                            audio: \".sm-audio\",\n                            geo: \".sm-geo\",\n                            convo: \".sm-convo\",\n                            embed: \".sm-embed\",\n                            summary: \".sm-summary\",\n                            retweet: \".sm-rt\",\n                            reply: \".sm-reply\",\n                            promoted: \".badge-promoted\"\n                        }, i = ((c.JSBNG__find(g.promoted).length ? \"-promoted\" : \"-organic\"));\n                        twttr.abdecider.track(d, ((a + i)));\n                        for (var j in g) {\n                            ((c.JSBNG__find(g[j]).length && twttr.abdecider.track(d, ((((((a + i)) + \"-has-\")) + j)))));\n                        ;\n                        };\n                    ;\n                        $.each(c.JSBNG__find(\".twitter-timeline-link\"), function(b, c) {\n                            var e = ((c.getAttribute(\"data-expanded-url\") || c.href));\n                            ((((e === c.getAttribute(\"data-ultimate-url\"))) ? twttr.abdecider.track(d, ((((a + i)) + \"-has-link-expanded\"))) : twttr.abdecider.track(d, ((((a + i)) + \"-has-link-short\")))));\n                        });\n                    }\n                ;\n                ;\n                },\n                _itemMetadata: function(a) {\n                    var c = this._findOrCurrent(a, \".js-actionable-tweet, .js-actionable-user\"), d = this._closestOrCurrent(c, \"[data-item-type]\"), e = d.attr(\"data-item-type\"), f = {\n                        item_count: 1\n                    }, g = {\n                    }, i, j, k, l;\n                    (((($.inArray(e, [\"tweet\",\"user\",\"activity\",]) == -1)) && ((c.is(\".js-actionable-tweet\") ? e = \"tweet\" : ((c.is(\".js-actionable-user\") && (e = \"user\")))))));\n                    if (d.length) {\n                        switch (e) {\n                          case \"tweet\":\n                            k = !!this._findOrCurrent(c, \".top-tweet\").length, j = this._findOrCurrent(c, \"[data-impression-id]\").attr(\"data-impression-id\");\n                            var m = ((j ? \"promotedTweet\" : ((k ? \"popularTweet\" : \"tweet\"))));\n                            g.item_type = b.constants.clientEvent.itemType[m], i = this._findOrCurrent(c, \"[data-tweet-id]\").attr(\"data-tweet-id\"), ((this.ignoreScribeItemPosition || (g.item_position = this._itemPosition(c, \"tweet\"))));\n                            break;\n                          case \"user\":\n                            j = this._findOrCurrent(d, \"[data-impression-id]\").attr(\"data-impression-id\");\n                            var n = d.attr(\"data-feedback-token\"), m = ((j ? \"promotedUser\" : \"user\"));\n                            g.item_type = b.constants.clientEvent.itemType[m], i = ((d.attr(\"data-item-id\") || d.attr(\"data-user-id\"))), ((this.ignoreScribeItemPosition || (g.item_position = this._itemPosition(c, \"user\")))), ((n && (f.item_names = [n,])));\n                            break;\n                          case \"activity\":\n                            var o = this._activityType(d);\n                            g.item_type = b.constants.clientEvent.itemType.activity, g.item_description = o;\n                            var p = d.attr(\"data-item-id\");\n                            i = ((this._findOrCurrent(d, \"div[data-activity-min-position]\").attr(\"data-activity-min-position\") || p.split(\"_\")[0]));\n                            var q = a.attr(\"data-tweet-id\");\n                            ((q && (g.target_id = q))), f.item_names = [p,];\n                            break;\n                          default:\n                            i = d.attr(\"data-item-id\");\n                        };\n                    ;\n                        ((j && (g.item_token = j))), ((((g.item_description && !f.item_names)) && (f.item_names = [g.item_description,]))), ((i && (f.item_ids = [i,])));\n                    }\n                ;\n                ;\n                    return {\n                        scribeData: f,\n                        itemId: i,\n                        itemType: e,\n                        itemDetails: g,\n                        itemObj: d,\n                        targetObj: a,\n                        impressionId: j,\n                        popular: k\n                    };\n                },\n                _activityType: function(a) {\n                    var b = this._findOrCurrent(a, \".stream-item-activity\").attr(\"data-activity-type\"), c;\n                    return ((b || ((a.is(\".reply\") ? b = \"reply\" : ((a.is(\".mention\") && (b = \"mention\"))))))), b;\n                },\n                MAX_ITEM_POSITION: 40,\n                _itemPosition: function(a, b) {\n                    var c = ((((b == \"tweet\")) ? \"div.js-actionable-tweet\" : \"div.js-actionable-user, li.js-actionable-user\")), d = ((((b == \"tweet\")) ? \"data-tweet-id\" : \"data-user-id\")), e = a.attr(d), f = [];\n                    return this.$node.JSBNG__find(c).each(function(a, b) {\n                        f.push($(b).attr(d));\n                    }), $.inArray(e, twttr.util.arrayUniq(f).slice(0, this.MAX_ITEM_POSITION));\n                },\n                _findOrCurrent: function(a, b) {\n                    return ((a.is(b) ? a : a.JSBNG__find(b)));\n                },\n                _closestOrCurrent: function(a, b) {\n                    var c = ((a.is(b) ? a : a.closest(b)));\n                    return ((c.length ? c : a));\n                }\n            }), a;\n        }), a();\n    });\n});\nprovide(\"mixins/streamablePage\", function(a) {\n    using(\"_\", \"util\").as(function(b, _) {\n        twttr.klass.mixin(\"twttr.mixins.streamablePage\", function() {\n            this.addViewData(function() {\n                var a = {\n                };\n                return a[((\"active_tab_\" + this._activeTab))] = 1, a;\n            }).addOnSwitchAway(function() {\n                ((this.streamManager && this.streamManager.JSBNG__onSwitchAway()));\n            }).keydown({\n                f: function(a) {\n                    if ($(a.target).is(\":not(input)\")) {\n                        a.preventDefault();\n                        var b = this.streamManager.getCurrent();\n                        if (!b.focusedItemId) {\n                            return;\n                        }\n                    ;\n                    ;\n                        b.tweetActionFavorite(b.getCurrentlyFocusedItem().JSBNG__find(\".tweet\"), \"keyboard\");\n                    }\n                ;\n                ;\n                },\n                r: function(a) {\n                    if ($(a.target).is(\":not(input)\")) {\n                        a.preventDefault();\n                        var b = this.streamManager.getCurrent();\n                        if (!b.focusedItemId) {\n                            return;\n                        }\n                    ;\n                    ;\n                        b.tweetActionReply(b.getCurrentlyFocusedItem().JSBNG__find(\".js-original-tweet\"), \"keyboard\");\n                    }\n                ;\n                ;\n                },\n                t: function(a) {\n                    if ($(a.target).is(\":not(input)\")) {\n                        a.preventDefault();\n                        var b = this.streamManager.getCurrent();\n                        if (!b.focusedItemId) {\n                            return;\n                        }\n                    ;\n                    ;\n                        b.tweetActionRetweet(b.getCurrentlyFocusedItem().JSBNG__find(\".tweet\"), \"keyboard\");\n                    }\n                ;\n                ;\n                }\n            }).keypress({\n                k: function(a) {\n                    this.streamManager.getCurrent().highlightPrevious(), a.preventDefault();\n                },\n                j: function(a) {\n                    this.streamManager.getCurrent().highlightNext(), a.preventDefault();\n                },\n                \"return\": function(a) {\n                    var b = this.streamManager.getCurrent();\n                    if (!b) {\n                        return;\n                    }\n                ;\n                ;\n                    var c = this.$find(((((\".stream-item[data-item-id=\\\"\" + b.highlightedItemId)) + \"\\\"]\")));\n                    if (((c.length === 0))) {\n                        return;\n                    }\n                ;\n                ;\n                    a.preventDefault(), this.toggleFocus(c);\n                },\n                period: function(a) {\n                    twttr.$win.scrollTop(0);\n                    var b = this.streamManager.getCurrent();\n                    b.fetchTweets(twttr.bind(this, function(a) {\n                        ((((a.newItemsCount > 0)) && (a._showNewItems(), a.restartFetcher())));\n                        var b = a.getFirstItem();\n                        a.highlightItem(b), a.scrollStreamTo(b), twttr.$win.scrollTop(0);\n                    })), twttr.components.JapaneseAd.refreshAds();\n                }\n            }).methods({\n                getStreamManager: function() {\n                    return this.streamManager;\n                },\n                focusStreamTab: function(a) {\n                    var b;\n                    this.$node.JSBNG__find(\"ul.stream-tabs li.stream-tab, ul.stream-subtabs\").removeClass(\"active\"), ((a && (b = ((((((\"ul.stream-tabs li.stream-tab-\" + a)) + \", ul.stream-subtabs-\")) + a)), this.$node.JSBNG__find(b).addClass(\"active\")))), this._activeTab = a, scribble(\"subnav\", {\n                        item: a\n                    });\n                },\n                focusStreamSubtab: function(a) {\n                    var b;\n                    this.$node.JSBNG__find(\"ul.stream-subtabs li.stream-tab\").removeClass(\"active\"), ((a && this.$node.JSBNG__find(((\"ul.stream-subtabs li.stream-subtab-\" + a))).addClass(\"active\"))), this._activeSubtab = a, scribble(\"subsubnav\", {\n                        item: a\n                    });\n                },\n                _detailsPaneDisabled: function() {\n                    return ((!twttr.decider.goodAtCss() || twttr.isT1));\n                }\n            });\n            var a = {\n                Messages: 1,\n                WhoToFollow: 1,\n                SimilarTo: 1,\n                WelcomeLearnFlow: 1\n            };\n            return ((((!twttr.decider.isExpando() || ((this._name in a)))) ? this.mixin(twttr.mixins.streamablePageDetailsPane) : this.mixin(twttr.mixins.streamablePageDropdownEdition)));\n        }), a(twttr.mixins.streamablePage);\n    });\n});\nprovide(\"mixins/userActionableT1\", function(a) {\n    using().as(function(b) {\n        var c = twttr.klass.mixin(\"twttr.mixins.userActionableT1\", function() {\n            return this.methods({\n                getActionableUser: function(a) {\n                    return a.closest(\".js-actionable-user\");\n                },\n                getComboButton: function(a) {\n                    return this.$node.JSBNG__find(((((\".js-follow-combo[data-user-id=\\\"\" + a)) + \"\\\"]\")));\n                },\n                getDropdownButton: function(a) {\n                    return this.$node.JSBNG__find(((((\".js-action-profilemenu[data-user-id=\\\"\" + a)) + \"\\\"]\")));\n                },\n                getUserId: function(a) {\n                    return twttr.helpers.getUserIdentifier(a);\n                },\n                getUserRelationship: function(a, b) {\n                    var c = this, d = this.getActionableUser(a), e = +d.attr(\"data-user-id\");\n                    if (d.data(\"user\")) {\n                        var f = d.data(\"user\");\n                        this.getRelationship(f, b);\n                    }\n                     else twttr.API.User.JSBNG__find(e, function(a) {\n                        d.data(\"user\", a), c.getRelationship(a, b);\n                    });\n                ;\n                ;\n                },\n                getRelationship: function(a, b) {\n                    if (!twttr.loggedIn) {\n                        var c = {\n                            notifications: !1,\n                            following: !1,\n                            followedBy: !1,\n                            blocking: !1,\n                            followRequestSent: !1,\n                            wantRetweets: !1,\n                            canDM: !1\n                        };\n                        b(c, {\n                            user: a,\n                            id: a.id,\n                            JSBNG__name: a.JSBNG__name,\n                            screen_name: a.screenName,\n                            notifications: c.notifications,\n                            following: c.following,\n                            followed_by: c.followedBy,\n                            blocking: c.blocking,\n                            follow_request_sent: a.followRequestSent,\n                            want_retweets: c.wantRetweets,\n                            can_dm: c.canDM,\n                            reported: !1\n                        });\n                        return;\n                    }\n                ;\n                ;\n                    twttr.currentUser.relationshipWith(a, function(c) {\n                        var d = {\n                            user: a,\n                            id: a.id,\n                            JSBNG__name: a.JSBNG__name,\n                            screen_name: a.screenName,\n                            notifications: c.notifications,\n                            following: c.following,\n                            followed_by: c.followedBy,\n                            blocking: c.blocking,\n                            follow_request_sent: a.followRequestSent,\n                            want_retweets: c.wantRetweets,\n                            can_dm: c.canDM,\n                            reported: !1\n                        };\n                        b(c, d);\n                    });\n                },\n                showFollowOrUnfollow: function(a) {\n                    var b = this;\n                    ((twttr.helpers.isCurrentUser(a) || b.getRelationship(a, function(a, c) {\n                        ((c.followed_by && b.$node.JSBNG__find(\".js-follows-you\").show()));\n                    })));\n                },\n                showMiniSocialProof: function(a) {\n                    var b = this;\n                    ((((twttr.currentUser && !twttr.helpers.isCurrentUser(a))) && twttr.currentUser.followingFollowersOf(a.id, function(c) {\n                        if (c.length()) {\n                            var d = b.makeLongSocialContextHtml(a.screenName, c.toArray());\n                            b.$find(\".js-mini-social-proof-container\").html(d);\n                        }\n                    ;\n                    ;\n                    })));\n                },\n                showUserProfileMenu: function(a) {\n                    var b = this;\n                    $(JSBNG__document).trigger(\"click.button\"), a.addClass(\"open\"), a.closest(\".js-stream-item\").addClass(\"has-follow-dropdown-open\"), $(JSBNG__document).bind(\"click.button\", function() {\n                        b.hideUserProfileMenu(a);\n                    });\n                },\n                hideUserProfileMenu: function(a) {\n                    a.removeClass(\"open\"), a.closest(\".js-stream-item\").removeClass(\"has-follow-dropdown-open\"), $(JSBNG__document).unbind(\"click.button\");\n                },\n                toggleUserProfileMenu: function(a) {\n                    var b = this, c = this.getActionableUser(a), d = +c.attr(\"data-user-id\"), e = this.getDropdownButton(d);\n                    if (c.attr(\"data-dropdown\")) {\n                        ((c.hasClass(\"open\") ? this.hideUserProfileMenu(c) : this.showUserProfileMenu(c)));\n                        return;\n                    }\n                ;\n                ;\n                    this.getUserRelationship(a, function(a, d) {\n                        b.renderUserProfileMenu(c, e, d), b.showUserProfileMenu(c);\n                    });\n                },\n                renderUserProfileMenu: function(a, b, c) {\n                    ((c.want_retweets && a.addClass(\"including\"))), ((((((twttr.currentUser && twttr.currentUser.deviceSetup)) && c.notifications)) ? a.addClass(\"notifying\") : a.removeClass(\"notifying\"))), ((c.blocking && a.addClass(\"blocked\").removeClass(\"following not-following follow-request-sent\"))), ((c.can_dm && a.addClass(\"can-dm\"))), (new twttr.views.ComboFollowButtonDropdown(c)).render(b, \"append\"), a.attr(\"data-dropdown\", !0);\n                },\n                JSBNG__onUserActionFollowSync: function(a, b) {\n                    var c = this.getComboButton(a);\n                    ((c.length ? this.updateButtonFollow(c, b) : this.updateFollowStateLink(a, !0, b)));\n                },\n                JSBNG__onUserActionFollowSuccess: function(a, b, c) {\n                    var d = this.getActionableUser(c);\n                    this.updateButtonFollow(d, b);\n                },\n                updateButtonFollow: function(a, b) {\n                    ((b ? a.removeClass(\"not-following\").addClass(\"follow-request-sent\") : a.removeClass(\"not-following\").addClass(\"following including\")));\n                },\n                updateFollowStateLink: function(a, b, c) {\n                    if (b) {\n                        var d = ((c ? twttr.views.FollowRequestSentLink : twttr.views.UnfollowLink));\n                    }\n                     else {\n                        var d = twttr.views.FollowLink;\n                    }\n                ;\n                ;\n                    var e = this.$node.JSBNG__find(((((\".js-follow-state .js-link[data-user-id=\\\"\" + a)) + \"\\\"]\")));\n                    (new d({\n                        id: a\n                    })).render(e, \"replaceWith\");\n                },\n                JSBNG__onUserActionUnfollowSuccess: function(a, b) {\n                    var c = this.getActionableUser(b);\n                    this.updateButtonUnfollow(c);\n                },\n                JSBNG__onUserActionUnfollowSync: function(a) {\n                    var b = this.getComboButton(a);\n                    ((b.length ? this.updateButtonUnfollow(b) : this.updateFollowStateLink(a, !1)));\n                },\n                updateButtonUnfollow: function(a) {\n                    a.removeClass(\"following follow-request-sent\").addClass(\"not-following\");\n                },\n                updateUserAttributesFromRelationship: function(a) {\n                    ((twttr.decider.isAvailable(\"profile_pane_fresh\") && $.extend(this.user.attributes, {\n                        following: a.following,\n                        blocking: a.blocking,\n                        notifications: a.notifications,\n                        can_dm: a.canDM,\n                        want_retweets: a.wantRetweets\n                    })));\n                },\n                JSBNG__onUserActionFollowError: function(a, b) {\n                    twttr.helpers.showErrorFromResponse(a, \"follow\");\n                },\n                JSBNG__onUserActionUnfollowError: function(a) {\n                    twttr.helpers.showErrorFromResponse(a, \"follow\");\n                },\n                registerFollowAction: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-action-follow, .js-action-follow-request\", \"click\", function(b) {\n                        var c = $(this), d = a.getActionableUser(c);\n                        return ((twttr.loggedIn && (d.removeClass(\"not-following\"), ((d.hasClass(\"protected\") ? d.addClass(\"follow-request-sent first-hover\") : d.addClass(\"following including first-hover\")))))), d.JSBNG__one(\"mouseleave\", function() {\n                            d.removeClass(\"first-hover\");\n                        }), a.userActionFollow(c), b.preventDefault(), b.stopPropagation(), !1;\n                    });\n                },\n                registerUnfollowAction: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-action-unfollow\", \"click\", function(b) {\n                        var c = a.getActionableUser($(this));\n                        return c.removeClass(\"following follow-request-sent\").addClass(\"not-following\"), a.userActionUnfollow($(this)), b.preventDefault(), b.stopPropagation(), !1;\n                    });\n                },\n                registerProfileMenuAction: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-action-profilemenu\", \"click\", function(b) {\n                        return a.toggleUserProfileMenu($(this)), b.preventDefault(), b.stopPropagation(), !1;\n                    });\n                },\n                registerBlockAction: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-action-block\", \"click\", function(b) {\n                        var c = a.getActionableUser($(this)), d = +c.attr(\"data-user-id\"), e = c.attr(\"data-impression-id\"), f = \"block\";\n                        return a.markAsPending(c, f), c.addClass(\"blocked\").removeClass(\"following not-following follow-request-sent\"), twttr.API.User.JSBNG__find(d, function(b) {\n                            var d = \"not-following\";\n                            ((b.following ? d = \"following\" : ((b.followRequestSent && (d = \"follow-request-sent\"))))), b.block({\n                                impression_id: e,\n                                complete: function() {\n                                    a.markAsComplete(c, f);\n                                },\n                                timeout: function(a) {\n                                    a.retry();\n                                },\n                                success: function(b) {\n                                    a.trigger(\"block.user\", [c,$(this),\"block\",]), c.addClass(\"blocked\").removeClass(\"following not-following follow-request-sent\");\n                                },\n                                error: function() {\n                                    twttr.showError(_(\"Whoops! We weren't able to block that user. Try again in a minute\")), c.removeClass(\"blocked\").addClass(d);\n                                }\n                            });\n                        }), a.hideUserProfileMenu(c), b.preventDefault(), b.stopPropagation(), !1;\n                    });\n                },\n                registerUnblockAction: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-action-unblock\", \"click\", function(b) {\n                        var c = a.getActionableUser($(this)), d = +c.attr(\"data-user-id\"), e = c.attr(\"data-impression-id\"), f = \"unblock\";\n                        return a.markAsPending(c, f), c.removeClass(\"blocked\").addClass(\"not-following\"), twttr.API.User.JSBNG__find(d, function(b) {\n                            b.unblock({\n                                impression_id: e,\n                                before: function() {\n                                    $(((((\".stream .stream-tweet[data-user-id=\\\"\" + b.id)) + \"\\\"]\"))).closest(\".stream-item\").show();\n                                },\n                                complete: function() {\n                                    a.markAsComplete(c, f);\n                                },\n                                success: function() {\n                                    a.trigger(\"unblock.user\", [c,$(this),\"unblock\",]), c.removeClass(\"blocked\").addClass(\"not-following\");\n                                },\n                                error: function() {\n                                    c.addClass(\"blocked\").removeClass(\"not-following following follow-request-sent\");\n                                }\n                            });\n                        }), a.hideUserProfileMenu(c), b.preventDefault(), b.stopPropagation(), !1;\n                    });\n                },\n                registerReportAction: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-action-spam\", \"click\", function(b) {\n                        var c = a.getActionableUser($(this)), d = +c.attr(\"data-user-id\"), e = c.attr(\"data-impression-id\"), f = \"report\";\n                        return a.markAsPending(c, f), c.addClass(\"blocked\").removeClass(\"following not-following follow-request-sent\"), twttr.API.User.JSBNG__find(d, function(b) {\n                            var d = \"not-following\";\n                            ((b.following ? d = \"following\" : ((b.followRequestSent && (d = \"follow-request-sent\"))))), b.report({\n                                impression_id: e,\n                                before: function() {\n                                    $(((((\".stream .stream-tweet[data-user-id=\\\"\" + b.id)) + \"\\\"]\"))).closest(\".stream-item\").hide();\n                                },\n                                complete: function() {\n                                    a.markAsComplete(c, f);\n                                },\n                                success: function(d) {\n                                    twttr.showMessage(_(\"You have reported {{screenName}} for spam\", b)), a.trigger(\"report_as_spam.user\", [c,$(this),\"report_as_spam\",]), c.addClass(\"blocked\").removeClass(\"following not-following follow-request-sent\");\n                                },\n                                error: function(a) {\n                                    twttr.errors.showErrorFromResponse(a, \"report\"), c.removeClass(\"blocked\").addClass(d);\n                                }\n                            });\n                        }), a.hideUserProfileMenu(c), b.preventDefault(), b.stopPropagation(), !1;\n                    });\n                },\n                registerMentionAction: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-action-mention\", \"click\", function(b) {\n                        var c = a.getActionableUser($(this)), d = +c.attr(\"data-user-id\");\n                        return twttr.API.User.JSBNG__find(d, function(b) {\n                            (new twttr.widget.TweetDialog({\n                                template: {\n                                    title: ((\"Mention \" + b.screenName))\n                                },\n                                draggable: !0,\n                                defaultContent: ((((\"@\" + b.screenName)) + \" \")),\n                                origin: \"profile-actions-dropdown-mention\"\n                            })).open().JSBNG__focus(), a.trigger(\"reply.user\", [c,$(this),\"reply\",]);\n                        }), a.hideUserProfileMenu(c), b.preventDefault(), b.stopPropagation(), !1;\n                    });\n                },\n                registerAddToListAction: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-action-add-to-list\", \"click\", function(b) {\n                        var c = a.getActionableUser($(this)), d = +c.attr(\"data-user-id\");\n                        return twttr.API.User.JSBNG__find(d, function(b) {\n                            (new twttr.widget.ListMembershipDialog(b)).open(), a.trigger(\"add_to_list.user\", [c,$(this),\"add_to_list\",]);\n                        }), a.hideUserProfileMenu(c), b.preventDefault(), b.stopPropagation(), !1;\n                    });\n                },\n                registerDeviceNotificationToggle: function() {\n                    var a, b, c, d = this;\n                    this.$node.delegate(\".js-device-notifications\", \"click\", function(e) {\n                        var f = d.getActionableUser($(this)), g = +f.attr(\"data-user-id\"), i = f.hasClass(\"notifying\"), j = ((i ? \"setNotificationsOff\" : \"setNotificationsOn\"));\n                        return twttr.API.User.JSBNG__find(g, function(d) {\n                            if (!twttr.currentUser.deviceSetup) {\n                                ((((!twttr.currentUser.deviceVerified && ((!twttr.currentUser.pushTweetsDecidered || !twttr.currentUser.pushDevice)))) ? (a = {\n                                    title: _(\"Setup mobile notifications\"),\n                                    JSBNG__content: (new twttr.views.PhoneSetupPrompt({\n                                        screen_name: d.screenName,\n                                        ok: _(\"Set up phone\"),\n                                        cancel: _(\"Cancel\")\n                                    })).html()\n                                }, b = twttr.router.devicesPath()) : (a = {\n                                    title: _(\"Enable mobile notifications for Tweets\"),\n                                    JSBNG__content: (new twttr.views.PhoneTweetsOffPrompt({\n                                        screen_name: d.screenName,\n                                        ok: _(\"Enable Tweet notifications\"),\n                                        cancel: _(\"Close\")\n                                    })).html()\n                                }, ((((twttr.currentUser.pushDevice && twttr.currentUser.pushTweetsDecidered)) ? b = twttr.router.pushHelpPath() : b = twttr.router.devicesPath()))))), (new twttr.widget.Prompt({\n                                    modal: !0,\n                                    callback: function(a) {\n                                        ((a && (c = function() {\n                                            twttr.router.routeTo(b);\n                                        }, twttr.API.User.bind(\"subscribe\", c), d.setNotificationsOn())));\n                                    },\n                                    template: a\n                                })).open();\n                                return;\n                            }\n                        ;\n                        ;\n                            d[j](), ((i ? f.removeClass(\"notifying\") : f.addClass(\"notifying\")));\n                        }), e.preventDefault(), e.stopPropagation(), !1;\n                    });\n                },\n                registerRetweetToggle: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-retweet-setting\", \"click\", function(b) {\n                        var c = a.getActionableUser($(this)), d = +c.attr(\"data-user-id\"), e = c.hasClass(\"including\"), f = ((e ? \"setWantRetweetsOff\" : \"setWantRetweetsOn\"));\n                        return twttr.API.User.JSBNG__find(d, function(a) {\n                            a[f](), ((e ? (c.removeClass(\"including\"), twttr.showMessage(_(\"Retweets from @{{screenName}} will no longer appear in your timeline\", a))) : (c.addClass(\"including\"), twttr.showMessage(_(\"Retweets from @{{screenName}} will appear in your timeline\", a)))));\n                        }), a.hideUserProfileMenu(c), b.preventDefault(), b.stopPropagation(), !1;\n                    });\n                },\n                registerDirectMessageAction: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-direct-message-action\", \"click\", function(b) {\n                        var c = $(this), d = a.getActionableUser(c), e = +d.attr(\"data-user-id\");\n                        return twttr.API.User.JSBNG__find(e, function(b) {\n                            twttr.dialogs.dmSingle({\n                                user: {\n                                    screenName: b.screenName,\n                                    user_id: e,\n                                    JSBNG__name: b.attributes.JSBNG__name,\n                                    profile_image_url: b.attributes.profile_image_url\n                                },\n                                origin: \"user-actionable-direct-message\"\n                            }).open(), a.trigger(\"dm.user\", [d,c,\"dm\",]);\n                        }), a.hideUserProfileMenu(d), b.preventDefault(), b.stopPropagation(), !1;\n                    });\n                },\n                registerProfileAction: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-action-profile-avatar\", \"click\", function(b) {\n                        var c = $(this);\n                        a.trigger(\"avatar_click.user\", [a.getActionableUser(c),c,\"avatar\",]);\n                    }), this.$node.delegate(\".js-action-profile-name\", \"click\", function(b) {\n                        var c = $(this);\n                        a.trigger(\"screen_name_click.user\", [a.getActionableUser(c),c,\"screen_name\",]);\n                    }), this.$node.delegate(\".js-action-profile-promoted\", \"click\", function(b) {\n                        var c = $(this);\n                        a.trigger(\"promoted_badge_click.user\", [a.getActionableUser(c),c,\"promoted_badge\",]);\n                    }), this.$node.delegate(\".js-account-group, .js-mini-profile-user\", \"click\", function(b) {\n                        var c = a.$node.JSBNG__find(\".js-actionable-user\"), d = +c.attr(\"data-user-id\"), e = c.closest(\"[data-impression-id]\").attr(\"data-impression-id\");\n                        a._updateTwttrPromotedAccount(d, e);\n                    });\n                },\n                registerUserActionEvents: function() {\n                    var a = this;\n                    this.registerFollowAction(), this.registerUnfollowAction(), this.registerProfileAction(), this.registerPromotedUserActionEvents(), ((twttr.loggedIn && (this.registerProfileMenuAction(), this.registerBlockAction(), this.registerUnblockAction(), this.registerReportAction(), this.registerMentionAction(), this.registerAddToListAction(), this.registerDeviceNotificationToggle(), this.registerRetweetToggle(), this.registerDirectMessageAction(), this._registerUserActionAPIListeners(), this._registerUserActionScribeListeners())));\n                }\n            }), this;\n        });\n        a(c);\n    });\n});\nprovide(\"mixins/userActionable\", function(a) {\n    using(((twttr.isT1 ? \"mixins/userActionableT1\" : []))).as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.userActionable\", function(a) {\n            return a.mixin(twttr.mixins.itemActionableScribing, twttr.mixins.pendingActions).methods({\n                userActionFollow: function(a, b) {\n                    var c = this, d = twttr.helpers.getUserId(a), e = a.closest(\".js-actionable-user, .js-actionable-tweet\"), f = ((e.attr(\"data-impression-id\") || e.closest(\"[data-impression-id]\").attr(\"data-impression-id\"))), g = \"follow\";\n                    this.markAsPending(e, g), twttr.API.User.JSBNG__find(d, function(i) {\n                        var j = ((i[\"protected\"] && !i.following));\n                        ((twttr.loggedIn ? (c._updateTwttrPromotedAccount(d, f), i.follow({\n                            complete: function() {\n                                c.markAsComplete(e, g);\n                            },\n                            success: function(f) {\n                                b = ((b || ((e.is(\".js-actionable-tweet\") ? \"follow.tweet\" : \"follow.user\")))), c.trigger(b, [e,a,\"follow\",]);\n                                var g = e.closest(\".js-stream-item\").length;\n                                ((((j && !g)) && twttr.showMessage(_(\"A follow request has been sent to {{user}}.\", {\n                                    user: ((i.JSBNG__name || i.screenName))\n                                })))), c.JSBNG__onUserActionFollowSuccess(d, j, a);\n                            },\n                            error: function(a) {\n                                c.JSBNG__onUserActionFollowError(a, j);\n                            },\n                            impression_id: f\n                        })) : twttr.dialogs.signinOrSignup({\n                            follow: i,\n                            justSignup: !0\n                        }).open()));\n                    });\n                },\n                userActionUnfollow: function(a) {\n                    var b = this, c = twttr.helpers.getUserId(a), d = a.closest(\".js-actionable-user\"), e = ((d.attr(\"data-impression-id\") || d.closest(\"[data-impression-id]\").attr(\"data-impression-id\"))), f = \"unfollow\";\n                    this.markAsPending(d, f), twttr.API.User.JSBNG__find(c, function(g) {\n                        g.unfollow({\n                            complete: function() {\n                                b.markAsComplete(d, f);\n                            },\n                            success: function() {\n                                b._updateTwttrPromotedAccount(c, e), b.trigger(\"unfollow.user\", [d,a,\"unfollow\",]), b.JSBNG__onUserActionUnfollowSuccess(c, a);\n                            },\n                            error: function(a) {\n                                b.JSBNG__onUserActionUnfollowError(a);\n                            },\n                            impression_id: e\n                        });\n                    });\n                },\n                userActionMenu: function(a) {\n                    var b = this, c = twttr.helpers.getUserIdentifier(a);\n                    if (a.attr(\"data-opened\")) {\n                        return;\n                    }\n                ;\n                ;\n                    a.attr(\"data-opened\", !0), twttr.API.User.JSBNG__find(c, function(c) {\n                        twttr.currentUser.relationshipWith(c, twttr.bind(this, function(d) {\n                            var e = {\n                                user: c,\n                                id: c.id,\n                                screen_name: c.screenName,\n                                notifications: d.notifications,\n                                following: d.following,\n                                followed_by: d.followedBy,\n                                blocking: d.blocking,\n                                follow_request_sent: c.followRequestSent,\n                                want_retweets: d.wantRetweets,\n                                reported: !1\n                            };\n                            b.userProfileActionsDropdown = b._getUserActionsDropdown(c, a, e), b.userProfileActionsDropdown.render(a, \"after\").open();\n                        }));\n                    });\n                },\n                JSBNG__onUserActionFollowSync: function(a, b) {\n                    var c = this.$node.JSBNG__find(((((\".js-action-follow[data-user-id='\" + a)) + \"']\"))), d;\n                    ((c.length && (((c.is(\".js-button\") ? d = ((b ? twttr.views.FollowRequestSentButton : twttr.views.UnfollowButton)) : ((c.is(\".js-link\") && (d = ((b ? twttr.views.FollowRequestSentLink : twttr.views.UnfollowLink))))))), this._updateFollowState(a, c, d))));\n                },\n                JSBNG__onUserActionUnfollowSync: function(a) {\n                    var b = this.$node.JSBNG__find(((((\".js-action-unfollow[data-user-id='\" + a)) + \"']\"))), c;\n                    ((b.length && (((b.is(\".js-button\") ? c = twttr.views.FollowButton : ((b.is(\".js-link\") && (c = twttr.views.FollowLink))))), this._updateFollowState(a, b, c))));\n                },\n                _updateFollowState: function(a, b, c) {\n                    ((c && (new c({\n                        id: a\n                    })).render(b, \"replaceWith\")));\n                },\n                _userLinkHtml: function(a) {\n                    return (new twttr.views.UserLink(a)).html();\n                },\n                makeShortSocialContextHtml: function(a, b) {\n                    var c = \"\";\n                    return ((((b.length == 1)) ? c += _(\"Followed by {{{user}}}\", {\n                        user: this._userLinkHtml(b[0])\n                    }) : c += _(\"Followed by {{{user}}} and \\u003Ca href=\\\"{{url}}\\\" class=\\\"pretty-link\\\"\\u003E\\u003Cb\\u003Eothers\\u003C/b\\u003E\\u003C/a\\u003E\", {\n                        user: this._userLinkHtml(b[0]),\n                        url: twttr.router.followersYouFollowPath({\n                            screen_name: a\n                        })\n                    }))), c;\n                },\n                makeLongSocialContextHtml: function(a, b) {\n                    var c = \"\";\n                    switch (b.length) {\n                      case 1:\n                        c += _(\"Followed by {{{user}}}.\", {\n                            user: this._userLinkHtml(b[0])\n                        });\n                        break;\n                      case 2:\n                        c += _(\"Followed by {{{first}}} and {{{second}}}.\", {\n                            first: this._userLinkHtml(b[0]),\n                            second: this._userLinkHtml(b[1])\n                        });\n                        break;\n                      case 3:\n                        c += _(\"Followed by {{{first}}}, {{{second}}} and {{{third}}}.\", {\n                            first: this._userLinkHtml(b[0]),\n                            second: this._userLinkHtml(b[1]),\n                            third: this._userLinkHtml(b[2])\n                        });\n                        break;\n                      case 4:\n                        c += _(\"Followed by {{{first}}}, {{{second}}}, {{{third}}} and {{{other}}}.\", {\n                            first: this._userLinkHtml(b[0]),\n                            second: this._userLinkHtml(b[1]),\n                            third: this._userLinkHtml(b[2]),\n                            other: this._userLinkHtml(b[3])\n                        });\n                        break;\n                      default:\n                        c += _(\"Followed by {{{first}}}, {{{second}}}, {{{third}}} and \\u003Ca href=\\\"{{url}}\\\" class=\\\"pretty-link\\\"\\u003E\\u003Cb\\u003E{{count}} others\\u003C/b\\u003E\\u003C/a\\u003E.\", {\n                            first: this._userLinkHtml(b[0]),\n                            second: this._userLinkHtml(b[1]),\n                            third: this._userLinkHtml(b[2]),\n                            count: ((((b.length > 13)) ? \"10+\" : ((b.length - 3)))),\n                            url: twttr.router.followersYouFollowPath({\n                                screen_name: a\n                            })\n                        });\n                    };\n                ;\n                    return c;\n                },\n                makeSocialContextHtml: function(a, b) {\n                    var c = this;\n                    if (a.socialContext) {\n                        var d = a.socialContext, e = a.screenName;\n                    }\n                     else {\n                        var d = a.attributes.connections, e = a.user.screenName;\n                    }\n                ;\n                ;\n                    var f = \"\";\n                    return ((((((!this.screenName && d)) && d.length)) && ((b ? f += this.makeLongSocialContextHtml(e, d) : f += this.makeShortSocialContextHtml(e, d))))), f;\n                },\n                JSBNG__onUserActionFollowSuccess: function(a, b, c) {\n                \n                },\n                JSBNG__onUserActionFollowError: function(a, b) {\n                    twttr.helpers.showErrorFromResponse(a, \"follow\");\n                },\n                JSBNG__onUserActionUnfollowSuccess: function(a, b) {\n                \n                },\n                JSBNG__onUserActionUnfollowError: function(a) {\n                    twttr.helpers.showErrorFromResponse(a, \"follow\");\n                },\n                registerPromotedUserActionEvents: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-actionable-user .js-action-dismiss\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-user\"), e = d.attr(\"data-impression-id\");\n                        a._updateTwttrPromotedAccount(parseInt(d.attr(\"data-user-id\")), e), twttr.API.util.PromotedContent.logDismissUser(e), a.trigger(\"dismiss.user\", [d,c,\"dismiss\",]);\n                    }), this.$node.delegate(\".js-actionable-user img.user-profile-link, .js-actionable-user .js-action-profile-avatar\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-user\"), e = d.attr(\"data-impression-id\");\n                        a._updateTwttrPromotedAccount(parseInt(d.attr(\"data-user-id\")), e), twttr.API.util.PromotedContent.logProfileImageClick(e), a.trigger(\"avatar_click.user\", [d,c,\"avatar\",]);\n                    }), this.$node.delegate(\".js-actionable-user .js-promoted-badge\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-user\"), e = d.attr(\"data-impression-id\");\n                        a._updateTwttrPromotedAccount(parseInt(d.attr(\"data-user-id\")), e), twttr.API.util.PromotedContent.logFooterProfileClick(e), a.trigger(\"promoted_badge_click.user\", [d,c,\"promoted_badge\",]);\n                    }), this.$node.delegate(\".js-actionable-user .user-name .user-profile-link, .js-actionable-user .js-action-profile-name\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-user\"), e = d.attr(\"data-impression-id\");\n                        a._updateTwttrPromotedAccount(parseInt(d.attr(\"data-user-id\")), e), twttr.API.util.PromotedContent.logScreenNameClick(e), a.trigger(\"screen_name_click.user\", [d,c,\"screen_name\",]);\n                    });\n                },\n                registerUserActionEvents: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-actionable-user .js-action-follow, .js-actionable-tweet .js-action-follow\", \"click\", function(b) {\n                        return a.userActionFollow($(this)), b.preventDefault(), b.stopPropagation(), !1;\n                    }), this.$node.delegate(\".js-actionable-user .js-action-unfollow\", \"click\", function(b) {\n                        return a.userActionUnfollow($(this)), b.preventDefault(), b.stopPropagation(), !1;\n                    }), this.$node.delegate(\".js-actionable-user .js-action-profilemenu\", \"click\", function(b) {\n                        return a.userActionMenu($(this)), b.preventDefault(), b.stopPropagation(), !1;\n                    }), this.registerPromotedUserActionEvents(), this._registerUserActionAPIListeners(), this._registerUserActionScribeListeners();\n                },\n                _registerUserActionAPIListeners: function() {\n                    var a = this;\n                    twttr.API.User.bind(\"follow\", {\n                        before: function(b, c) {\n                            var d = c.requestParameters[0].user_id;\n                            twttr.API.User.JSBNG__find(d, function(a) {\n                                a.sync(\"following\", !0), a.sync(\"followers_count\", ((a.followersCount + 1)));\n                            }), a.JSBNG__onUserActionFollowSync(d);\n                        },\n                        error: function(b, c, d) {\n                            var e = d.requestParameters[0].user_id;\n                            twttr.API.User.JSBNG__find(e, function(a) {\n                                a.sync(\"following\", !1), a.sync(\"followers_count\", ((a.followersCount - 1)));\n                            }), a.JSBNG__onUserActionUnfollowSync(e);\n                        }\n                    }), twttr.API.User.bind(\"follow_request\", {\n                        before: function(b, c) {\n                            var d = c.requestParameters[0].user_id;\n                            twttr.API.User.JSBNG__find(d, function(a) {\n                                a.sync(\"follow_request_sent\", !0);\n                            }), a.JSBNG__onUserActionFollowSync(d, !0);\n                        },\n                        error: function(b, c, d) {\n                            var e = d.requestParameters[0].user_id;\n                            twttr.API.User.JSBNG__find(e, function(a) {\n                                a.sync(\"following_request_sent\", !1);\n                            }), a.JSBNG__onUserActionUnfollowSync(e);\n                        }\n                    }), twttr.API.User.bind(\"unfollow\", {\n                        before: function(b, c) {\n                            var d = c.requestParameters[0].user_id;\n                            twttr.API.User.JSBNG__find(d, function(a) {\n                                a.sync(\"following\", !1), ((a[\"protected\"] || a.sync(\"followers_count\", ((a.followersCount - 1)))));\n                            }), a.JSBNG__onUserActionUnfollowSync(d);\n                        },\n                        error: function(b, c, d) {\n                            var e = d.requestParameters[0].user_id;\n                            twttr.API.User.JSBNG__find(e, function(a) {\n                                a.sync(\"following\", !0), ((a[\"protected\"] || a.sync(\"followers_count\", ((a.followersCount + 1)))));\n                            }), a.JSBNG__onUserActionFollowSync(e);\n                        }\n                    });\n                },\n                _updateTwttrPromotedAccount: function(a, b) {\n                    ((b ? twttr.promotedAccountStore.setAccount(a, b) : twttr.promotedAccountStore.clear()));\n                },\n                _getUserActionsDropdown: function(a, b, c) {\n                    var d = this, e = b.closest(\".js-actionable-user\"), f = [];\n                    return f.push({\n                        label: _(\"Mention {{screen_name}}\", c),\n                        icon: \"mention\",\n                        className: \"js-action-reply\",\n                        handlers: {\n                            click: function() {\n                                (new twttr.widget.TweetDialog({\n                                    template: {\n                                        title: ((\"Mention \" + a.screenName))\n                                    },\n                                    draggable: !0,\n                                    defaultContent: ((((\"@\" + a.screenName)) + \" \")),\n                                    origin: \"profile-actions-dropdown-mention\"\n                                })).open().JSBNG__focus(), d.trigger(\"reply.user\", [e,b,\"reply\",]);\n                            }\n                        }\n                    }), f.push({\n                        label: _(\"Add to list\"),\n                        icon: \"user-list\",\n                        className: \"js-action-addtolist\",\n                        handlers: {\n                            click: function() {\n                                (new twttr.widget.ListMembershipDialog(a)).open(), d.trigger(\"add_to_list.user\", [e,b,\"add_to_list\",]);\n                            }\n                        }\n                    }), ((c.blocking ? f.push({\n                        label: _(\"Unblock {{screen_name}}\", c),\n                        icon: \"block\",\n                        className: \"js-action-unblock\",\n                        handlers: {\n                            click: function() {\n                                var c = $(\"div.profile-pane\").attr(\"data-impression-id\");\n                                a.unblock({\n                                    before: function() {\n                                        $(((((\".stream .stream-tweet[data-user-id=\\\"\" + a.id)) + \"\\\"]\"))).closest(\".stream-item\").show();\n                                    },\n                                    success: function() {\n                                        d.trigger(\"unblock.user\", [e,b,\"unblock\",]);\n                                    },\n                                    impression_id: c\n                                });\n                            }\n                        }\n                    }) : f.push({\n                        label: _(\"Block {{screen_name}}\", c),\n                        icon: \"block\",\n                        className: \"js-action-block\",\n                        handlers: {\n                            click: function() {\n                                var c = $(\"div.profile-pane\").attr(\"data-impression-id\");\n                                a.block({\n                                    timeout: function(a) {\n                                        a.retry();\n                                    },\n                                    error: function() {\n                                        twttr.showError(_(\"Whoops! We weren't able to block that user. Try again in a minute\"));\n                                    },\n                                    success: function(a) {\n                                        d.trigger(\"block.user\", [e,b,\"block\",]);\n                                    },\n                                    impression_id: c\n                                });\n                            }\n                        }\n                    }))), ((c.blocking || f.push({\n                        label: _(\"Report \\u003Cspan class=\\\"truncate\\\"\\u003E{{screen_name}}\\u003C/span\\u003E for spam\", c),\n                        icon: \"spam\",\n                        className: \"js-action-spam\",\n                        handlers: {\n                            click: function() {\n                                var c = $(\"div.profile-pane\").attr(\"data-impression-id\");\n                                a.report({\n                                    before: function() {\n                                        $(((((\".stream .stream-tweet[data-user-id=\\\"\" + a.id)) + \"\\\"]\"))).closest(\".stream-item\").hide();\n                                    },\n                                    error: function(a) {\n                                        twttr.errors.showErrorFromResponse(a, \"report\");\n                                    },\n                                    success: function(a) {\n                                        d.trigger(\"report_as_spam.user\", [e,b,\"report_as_spam\",]);\n                                    },\n                                    impression_id: c\n                                });\n                            }\n                        }\n                    }))), new twttr.control.Dropdown(b, {\n                        itemView: twttr.views.UserDropdownItem,\n                        items: f,\n                        direction: \"right\"\n                    });\n                }\n            }), ((twttr.isT1 && a.mixin(b.mixins.userActionableT1))), a;\n        }), a(twttr.mixins.userActionable);\n    });\n});\nprovide(\"mixins/profilePopupActionable\", function(a) {\n    using().as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.profilePopupActionable\", function() {\n            this.methods({\n                showProfilePopup: function(a) {\n                    using(\"widget/MiniProfileDialog\", function(b) {\n                        (new b(a)).open();\n                    });\n                }\n            }).click({\n                \".user-profile-link,          .js-user-profile-link,          .twitter-atreply,          .js-account-group\": function(a, b) {\n                    var c = this;\n                    if (b.is(\".withheld-item .twitter-atreply\")) {\n                        return !1;\n                    }\n                ;\n                ;\n                    ((b.hasClass(\"js-bubble-event\") || (a.stopPropagation(), a.preventDefault())));\n                    var d = ((((b.data(\"user-id\") || b.attr(\"data-screen-name\"))) || b.closest(\".js-profile-popup-actionable\").data(\"user-id\")));\n                    if (!d) {\n                        ((twttr.development && JSBNG__console.log(\"can't open profile popup: no user identifier found\")));\n                        return;\n                    }\n                ;\n                ;\n                    var e = b.closest(\".js-actionable-tweet, .js-actionable-user\"), f = e.attr(\"data-impression-id\");\n                    e.trigger(((\"profile_popup.\" + ((e.is(\".js-actionable-tweet\") ? \"tweet\" : \"user\"))))), twttr.API.User.JSBNG__find(d, {\n                        success: function(d) {\n                            d = twttr.API.util.PromotedStore.getPromotedUserInstance(d, f), c.showProfilePopup(d), b.data(\"user-id\", d.id), twttr.scribbles.logViewProfileDetails.call(b, a);\n                        },\n                        error: function(a) {\n                            twttr.errors.showErrorFromResponse(a);\n                        }\n                    });\n                }\n            });\n        }), a(twttr.mixins.profilePopupActionable);\n    });\n});\nprovide(\"mixins/listActionable\", function(a) {\n    using(\"_\").as(function(b, _) {\n        var c = twttr.klass.mixin(\"twttr.mixins.listActionable\", function() {\n            return this.methods({\n                listDeleted: function() {\n                \n                },\n                listUpdated: function() {\n                \n                },\n                _setListFollowing: function(a, b, c) {\n                    var d = ((c ? \"subscribe\" : \"unsubscribe\"));\n                    twttr.API.User.JSBNG__find(a, function(a) {\n                        a.lists.JSBNG__find(b, function(a) {\n                            a[d]({\n                                error: function() {\n                                    ((c ? twttr.showError(_(\"There was an error subscribing to the list\")) : twttr.showError(_(\"There was an error unsubscribing from the list\"))));\n                                }\n                            });\n                        });\n                    });\n                },\n                unfollowList: function(a, b) {\n                    this._setListFollowing(a, parseInt(b, 10), !1);\n                },\n                followList: function(a, b) {\n                    this._setListFollowing(a, parseInt(b, 10), !0);\n                }\n            }).click({\n                \".js-delete-list-action\": function(a, b) {\n                    return (new twttr.widget.Prompt({\n                        modal: !0,\n                        template: {\n                            title: _(\"Are you sure you want to delete this list?\")\n                        },\n                        callback: function(a) {\n                            ((a && twttr.currentUser.lists.JSBNG__find(parseInt(b.attr(\"data-list-id\"), 10), function(a) {\n                                twttr.app.currentPage().send(\"listDeleted\", [a,]), a.destroy({\n                                    error: function() {\n                                        twttr.showError(_(\"There was an error deleting the list\"));\n                                    },\n                                    success: function() {\n                                        twttr.app.currentPage().send(\"listDeleted\", [a,]);\n                                    }\n                                });\n                            })));\n                        }\n                    })).open(), a.stopPropagation(), !1;\n                },\n                \".js-edit-list-action\": function(a, b) {\n                    return twttr.currentUser.lists.JSBNG__find(parseInt(b.attr(\"data-list-id\"), 10), function(a) {\n                        (new twttr.widget.ListDialog({\n                            list: a,\n                            JSBNG__onSuccess: function(a) {\n                                twttr.app.currentPage().send(\"listUpdated\", [a,]);\n                            }\n                        })).open();\n                    }), a.stopPropagation(), !1;\n                },\n                \".js-unfollow-list-action\": function(a, b) {\n                    return this.unfollowList(b.attr(\"data-screen-name\"), parseInt(b.attr(\"data-list-id\"), 10)), a.stopPropagation(), !1;\n                },\n                \".js-follow-list-action\": function(a, b) {\n                    return this.followList(b.attr(\"data-screen-name\"), parseInt(b.attr(\"data-list-id\"), 10)), a.stopPropagation(), !1;\n                }\n            }), this;\n        });\n        a(c);\n    });\n});\nprovide(\"mixins/tweetActionable\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass.mixin(\"twttr.mixins.tweetActionable\", function(a) {\n            return a.mixin(twttr.mixins.itemActionableScribing, twttr.mixins.pendingActions).methods({\n                deletedTweetCacheDuration: 600000,\n                _updateTweetDisplay: function(a, b) {\n                    var c = this;\n                    ((((b === \"delete\")) ? (twttr.showMessage(_(\"Your tweet has been deleted.\")), c.JSBNG__onTweetActionDelete(a)) : twttr.API.Status.JSBNG__find(a, function(d) {\n                        var e = c.$find(((((\"div.js-actionable-tweet[data-tweet-id=\" + a)) + \"]\")));\n                        switch (b) {\n                          case \"favorite\":\n                            d.sync(\"favorited\", !0), e.addClass(\"favorited\");\n                            break;\n                          case \"unfavorite\":\n                            d.sync(\"favorited\", !1), e.removeClass(\"favorited\");\n                            break;\n                          case \"retweet\":\n                            d.sync(\"current_user_retweet\", !0), e.addClass(\"retweeted\");\n                            break;\n                          case \"unretweet\":\n                            d.sync(\"current_user_retweet\", !1), e.removeClass(\"retweeted\");\n                            break;\n                          case \"hide\":\n                            c.JSBNG__onTweetActionHide(a);\n                            break;\n                          case \"show\":\n                            c.JSBNG__onTweetActionShow(a);\n                        };\n                    ;\n                        c.rerenderTweetActionsView(b, d, e);\n                    })));\n                },\n                JSBNG__onTweetActionDelete: function(a) {\n                    this._getActionableTweets(a).remove();\n                },\n                JSBNG__onTweetActionHide: function(a) {\n                    this._getActionableTweets(a).hide();\n                },\n                JSBNG__onTweetActionShow: function(a) {\n                    this._getActionableTweets(a).show();\n                },\n                getTweetId: function(a) {\n                    return a.attr(\"data-tweet-id\");\n                },\n                getScreenName: function(a) {\n                    return a.attr(\"data-screen-name\");\n                },\n                getImpressionId: function(a) {\n                    return a.attr(\"data-impression-id\");\n                },\n                getScribeComponent: function(a) {\n                    return ((a.is(\"div.details-pane .js-actionable-tweet\") ? \"details-pane\" : ((a.is(\"div.stream .js-actionable-tweet\") ? \"stream\" : \"generic-component\"))));\n                },\n                getStreamName: function() {\n                    var a = twttr.app.currentPage(), b = a.getInstanceProperty(\"streamManager\");\n                    return ((b ? b.getCurrent().constructor._name : null));\n                },\n                tweetActionFavorite: function(a, b) {\n                    if (((((!a || ((a.length === 0)))) || !twttr.loggedIn))) {\n                        return;\n                    }\n                ;\n                ;\n                    var c = this.getTweetId(a), d = a.hasClass(\"favorited\"), e = ((d ? \"unfavorite\" : \"favorite\")), f = this.getImpressionId(a);\n                    twttr.API.Status[e](c, {\n                        impression_id: f,\n                        cacheOptions: {\n                            skipOverwrite: !0\n                        }\n                    });\n                    var g = twttr.app.currentPage().getInstanceProperty(\"streamManager\"), i = {\n                        input: b,\n                        tweet_id: c,\n                        favorited: !d,\n                        component: this.getScribeComponent(a),\n                        stream: ((g && g.getCurrent().constructor._name))\n                    };\n                    ((d ? twttr.viewHelpers.addActivityItemLogging(a, i, \"unfavorite-tweet\") : twttr.viewHelpers.addExtraLogging(a, i, \"favorite-tweet\")));\n                    var j = ((d ? \"unfavorite\" : \"favorite\"));\n                    this.trigger(((j + \".tweet\")), [a,a.JSBNG__find(\"a.js-toggle-fav\"),j,]), _scribble(\"favorite-tweet\", i);\n                },\n                tweetActionRetweet: function(a, b) {\n                    if (((((!a || ((a.length === 0)))) || !twttr.loggedIn))) {\n                        return;\n                    }\n                ;\n                ;\n                    var c = this.getTweetId(a), d = this.getScreenName(a), e = this.getImpressionId(a), f = a.hasClass(\"retweeted\"), g = this.getScribeComponent(a), i = this.getStreamName(), j = !!a.attr(\"data-protected\");\n                    if (((twttr.helpers.isCurrentUser(d) || ((j && !f))))) {\n                        return;\n                    }\n                ;\n                ;\n                    if (f) {\n                        var k = a.attr(\"data-my-retweet-id\");\n                        ((k && (this.trigger(\"unretweet.tweet\", [a,a.JSBNG__find(\"a.js-toggle-rt\"),\"unretweet\",]), twttr.API.Status.unretweet(k))));\n                    }\n                     else {\n                        var l = this;\n                        using([twttr.bundleMore,\"dialogs\",], function() {\n                            twttr.API.Status.JSBNG__find(c, function(d) {\n                                twttr.dialogs.retweet(c, d.text, function(d) {\n                                    ((d && (twttr.API.Status.retweet(c, {\n                                        impression_id: e\n                                    }), l.trigger(\"retweet.tweet\", [a,a.JSBNG__find(\"a.js-toggle-rt\"),\"retweet\",]), _scribble(\"tweet\", {\n                                        tweet_type: \"retweet\",\n                                        origin: \"tweet-action-retweet\",\n                                        input: b,\n                                        component: g,\n                                        stream: i\n                                    }))));\n                                }).open();\n                            });\n                        });\n                    }\n                ;\n                ;\n                    var m = {\n                        input: b,\n                        tweet_id: c,\n                        component: g,\n                        stream: i\n                    };\n                    twttr.viewHelpers.addExtraLogging(a, m, \"retweet-tweet-opened\"), _scribble(\"retweet-tweet-opened\", m);\n                },\n                tweetActionReply: function(a, b, c) {\n                    if (((((!a || ((a.length === 0)))) || !twttr.loggedIn))) {\n                        return;\n                    }\n                ;\n                ;\n                    var d = this.getTweetId(a), e = this.getImpressionId(a), f = this.getScreenName(a), g = this.getScribeComponent(a), i = this.getStreamName(), j = {\n                        $tweet: a,\n                        tweetId: d,\n                        impressionId: e,\n                        screenName: f,\n                        origin: \"tweet-action-reply\",\n                        input: b,\n                        component: g,\n                        stream: i\n                    };\n                    if (!c) {\n                        var k = this;\n                        using([twttr.bundleMore,\"dialogs\",], function() {\n                            var b = twttr.dialogs.reply(j);\n                            b.view.tweetBox.bind(\"sendingTweet\", function(b, c) {\n                                k.trigger(\"reply.tweet\", [a,a.JSBNG__find(\"a.js-action-reply\"),\"reply\",]);\n                            }), b.open();\n                        });\n                    }\n                ;\n                ;\n                    var l = {\n                        input: b,\n                        tweet_id: d,\n                        component: g,\n                        stream: i\n                    };\n                    return twttr.viewHelpers.addExtraLogging(a, l, \"reply-to-tweet-opened\"), _scribble(\"reply-to-tweet-opened\", l), j;\n                },\n                tweetActionDismiss: function(a, b) {\n                    var c = this.getImpressionId(a), d = a.parent(\".js-stream-item\");\n                    ((d.hasClass(\"focused-stream-item\") && twttr.app.currentPage().send(\"closeDetailsPane\"))), d.fadeOut(300, function() {\n                        d.remove();\n                    });\n                    for (var e = 0; ((e < this.items.length)); e++) {\n                        if (((this.items[e].impressionId == c))) {\n                            this.items.splice(e, 1);\n                            break;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    twttr.API.util.PromotedContent.logDismissOther(c), this.trigger(\"dismiss.tweet\", [a,a.JSBNG__find(\".js-action-dismiss, div.js-action-dismiss\"),\"dismiss\",]), twttr.promotedTweetStore.clear();\n                },\n                tweetActionNotRelevant: function(a) {\n                    var b = {\n                        query: a.JSBNG__find(\"a.js-action-notrel\").attr(\"data-search-query\"),\n                        tweet_id: this.getTweetId(a),\n                        stream_index: String(a.closest(\".stream-item\").parent().JSBNG__find(\".stream-tweet:not([data-promoted=\\\"true\\\"])\").index(a))\n                    };\n                    this.trigger(\"not_relevant.tweet\", [a,a.JSBNG__find(\"a.js-action-notrel\"),\"not_relevant\",]), _scribble(\"not-relevant-tweet\", b);\n                },\n                tweetActionDelete: function(a, b) {\n                    var c = this;\n                    if (((((!a || ((a.length === 0)))) || !twttr.loggedIn))) {\n                        return;\n                    }\n                ;\n                ;\n                    var d = this.getTweetId(a);\n                    using([twttr.bundleMore,\"widget/Prompt\",], function() {\n                        (new twttr.widget.Prompt({\n                            template: {\n                                title: _(\"Are you sure you want to delete this tweet?\")\n                            },\n                            callback: function(a) {\n                                ((a && twttr.API.Status.JSBNG__find(d).destroy({\n                                    success: function() {\n                                        twttr.app.caches.deletedTweets.set(d, !0, c.deletedTweetCacheDuration);\n                                    },\n                                    error: function(a) {\n                                        twttr.errors.showErrorFromResponse(a, \"delete\");\n                                    }\n                                })));\n                            }\n                        })).open();\n                    }), this.trigger(\"delete.tweet\", [a,a.JSBNG__find(\"a.js-action-del\"),\"delete\",]);\n                    var e = {\n                        input: b,\n                        tweet_id: d,\n                        component: this.getScribeComponent(a)\n                    };\n                    _scribble(\"delete-tweet-opened\", e);\n                },\n                _getActionableTweets: function(a) {\n                    return this.$find(((((\"div.js-actionable-tweet[data-tweet-id=\" + a)) + \"]\")));\n                },\n                _getActionableMyRetweets: function(a) {\n                    return this.$find(((((\"div.js-actionable-tweet[data-my-retweet-id=\" + a)) + \"]\")));\n                },\n                _registerTweetActionAPIListeners: function() {\n                    var a = this;\n                    twttr.API.Status.bind(\"favorite\", {\n                        before: function(b, c) {\n                            var d = c.requestParameters[0];\n                            a.markAsPending(a._getActionableTweets(d), \"favorite\"), a._updateTweetDisplay(d, \"favorite\");\n                        },\n                        complete: function(b, c, d) {\n                            var e = d.requestParameters[0];\n                            a.markAsComplete(a._getActionableTweets(e), \"favorite\");\n                        },\n                        error: function(b, c, d) {\n                            var e = d.requestParameters[0];\n                            a._updateTweetDisplay(e, \"unfavorite\"), twttr.errors.showErrorFromResponse(c, \"favorite\");\n                        }\n                    }), twttr.API.Status.bind(\"unfavorite\", {\n                        before: function(b, c) {\n                            var d = c.requestParameters[0];\n                            a.markAsPending(a._getActionableTweets(d), \"unfavorite\"), a._updateTweetDisplay(d, \"unfavorite\");\n                        },\n                        complete: function(b, c, d) {\n                            var e = d.requestParameters[0];\n                            a.markAsComplete(a._getActionableTweets(e), \"unfavorite\");\n                        },\n                        error: function(b, c, d) {\n                            var e = d.requestParameters[0];\n                            a._updateTweetDisplay(e, \"favorite\"), twttr.errors.showErrorFromResponse(c, \"unfavorite\");\n                        }\n                    }), twttr.API.Status.bind(\"retweet\", {\n                        before: function(b, c) {\n                            var d = c.requestParameters[0];\n                            a.markAsPending(a._getActionableTweets(d), \"retweet\"), a._updateTweetDisplay(d, \"retweet\");\n                        },\n                        complete: function(b, c, d) {\n                            var e = d.requestParameters[0];\n                            a.markAsComplete(a._getActionableTweets(e), \"retweet\");\n                        },\n                        error: function(b, c, d) {\n                            var e = d.requestParameters[0];\n                            a._updateTweetDisplay(e, \"unretweet\"), twttr.errors.showErrorFromResponse(c, \"retweet\");\n                        },\n                        success: function(b, c) {\n                            var d = c.retweetingStatus.id, e = c.id;\n                            c.sync(\"current_user_retweet\", {\n                                id: d\n                            }), a.$find(((((\"div.js-actionable-tweet[data-tweet-id=\" + e)) + \"]\"))).attr(\"data-my-retweet-id\", d);\n                        }\n                    }), twttr.API.Status.bind(\"unretweet\", {\n                        before: function(b, c) {\n                            var d = c.requestParameters[0].id, e = a._getActionableMyRetweets(d);\n                            a.markAsPending(e, \"unretweet\");\n                            var f = e.attr(\"data-tweet-id\");\n                            a._updateTweetDisplay(f, \"unretweet\");\n                        },\n                        complete: function(b, c, d) {\n                            var e = d.requestParameters[0].id, f = a._getActionableMyRetweets(e);\n                            a.markAsComplete(f, \"unretweet\");\n                        },\n                        error: function(b, c, d) {\n                            var e = d.requestParameters[0].id, f = a._getActionableMyRetweets(e), g = f.attr(\"data-tweet-id\");\n                            a._updateTweetDisplay(g, \"retweet\");\n                        },\n                        success: function(b, c, d) {\n                            var e = c.id, f = c.retweetingStatus.id;\n                            a._updateTweetDisplay(e, \"unretweet\"), a._getActionableTweets(e).attr(\"data-my-retweet-id\", null);\n                        }\n                    }), twttr.API.Status.bind(\"delete\", {\n                        before: function(b, c) {\n                            var d = c.requestParameters[0].id;\n                            a.markAsPending(a._getActionableTweets(d), \"delete\"), a._updateTweetDisplay(d, \"hide\");\n                        },\n                        complete: function(b, c, d) {\n                            var e = d.requestParameters[0].id;\n                            a.markAsComplete(a._getActionableTweets(e), \"delete\");\n                        },\n                        error: function(b, c, d) {\n                            var e = d.requestParameters[0].id;\n                            a._updateTweetDisplay(e, \"show\");\n                        },\n                        success: function(b, c, d) {\n                            var e = c.id;\n                            a._updateTweetDisplay(e, \"delete\");\n                        }\n                    });\n                },\n                registerTweetActionEvents: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-actionable-tweet .js-action-profile-avatar\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-tweet\"), e = d.attr(\"data-impression-id\");\n                        ((e && twttr.API.util.PromotedContent.logProfileImageClick(e))), a.trigger(\"avatar_click.tweet\", [d,c,\"avatar\",]);\n                    }), this.$node.delegate(\".js-actionable-tweet .js-action-profile-name\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-tweet\"), e = d.attr(\"data-impression-id\");\n                        ((e && twttr.API.util.PromotedContent.logScreenNameClick(e))), a.trigger(\"screen_name_click.tweet\", [d,c,\"screen_name\",]);\n                    }), this.$node.delegate(\".js-actionable-tweet .js-action-profile-promoted\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-tweet\"), e = d.attr(\"data-impression-id\");\n                        ((e && twttr.API.util.PromotedContent.logFooterProfileClick(e))), a.trigger(\"promoted_badge_click.tweet\", [d,c,\"promoted_badge\",]);\n                    }), this.$node.delegate(\".js-actionable-tweet .twitter-hashtag\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-tweet\"), e = d.attr(\"data-impression-id\");\n                        ((e && twttr.API.util.PromotedContent.logHashtagClick(e, c.text()))), a.trigger(\"hashtag_click.tweet\", [d,c,\"hashtag\",]);\n                    }), this.$node.delegate(\".js-actionable-tweet .twitter-atreply\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-tweet\"), e = d.attr(\"data-impression-id\");\n                        ((e && twttr.API.util.PromotedContent.logUserMentionClick(e, c.text()))), a.trigger(\"mention_click.tweet\", [d,c,\"mention\",]);\n                    }), this.$node.delegate(\".js-actionable-tweet .twitter-timeline-link\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-tweet\"), e = d.attr(\"data-impression-id\");\n                        ((e && twttr.API.util.PromotedContent.logUrlClick(e, c.text()))), a.trigger(\"external_link_click.tweet\", [d,c,\"external_link\",]);\n                    }), this.$node.delegate(\".js-stream-item .js-permalink\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-stream-item\").JSBNG__find(\"div.js-actionable-tweet\"), e = d.attr(\"data-impression-id\");\n                        ((e && twttr.API.util.PromotedContent.logPermalinkClick(e))), a.trigger(\"permalink_click.tweet\", [d,c,\"permalink\",]);\n                    }), this.$node.delegate(\".js-actions .js-toggle-fav\", \"click\", function(b) {\n                        return ((twttr.loggedIn ? a.tweetActionFavorite($(this).closest(\".js-actionable-tweet\"), \"click\") : twttr.dialogs.signinOrSignup().open())), b.preventDefault(), b.stopPropagation(), !1;\n                    }), this.$node.delegate(\".js-actions .js-action-reply\", \"click\", function(b) {\n                        if (twttr.loggedIn) {\n                            var c = $(this).closest(\".js-actionable-tweet\");\n                            if (((((twttr.decider.hasInlineReplies() && c.hasClass(\"original-tweet\"))) && !c.hasClass(\"js-activity-tweet\")))) {\n                                if (!c.hasClass(\"opened-tweet\")) c.JSBNG__find(\".action-reply-container\").trigger(\"click\");\n                                 else {\n                                    var d = c.data(\"inline-tweetbox\");\n                                    ((d && d.JSBNG__focus()));\n                                }\n                            ;\n                            }\n                             else {\n                                a.tweetActionReply(c, \"click\");\n                            }\n                        ;\n                        ;\n                        }\n                         else twttr.dialogs.signinOrSignup().open();\n                    ;\n                    ;\n                        return b.preventDefault(), b.stopPropagation(), !1;\n                    }), this.$node.delegate(\".js-action-dismiss\", \"click\", function(b) {\n                        return a.tweetActionDismiss($(this).closest(\".js-actionable-tweet\"), \"click\"), b.preventDefault(), b.stopPropagation(), !1;\n                    }), this.$node.delegate(\".js-actions .js-action-del\", \"click\", function(b) {\n                        return a.tweetActionDelete($(this).closest(\".js-actionable-tweet\"), \"click\"), b.preventDefault(), b.stopPropagation(), !1;\n                    }), this.$node.delegate(\".js-actions .js-toggle-rt\", \"click\", function(b) {\n                        return ((twttr.loggedIn ? a.tweetActionRetweet($(this).closest(\".js-actionable-tweet\"), \"click\") : twttr.dialogs.signinOrSignup().open())), b.preventDefault(), b.stopPropagation(), !1;\n                    }), this.$node.delegate(\".js-actions .js-action-notrel\", \"click\", function(b) {\n                        return a.tweetActionNotRelevant($(this).closest(\".js-actionable-tweet\"), \"click\"), b.preventDefault(), b.stopPropagation(), !1;\n                    }), this._registerTweetActionAPIListeners(), this._registerTweetActionScribeListeners();\n                }\n            }), ((twttr.isT1 ? this.methods({\n                rerenderTweetActionsView: twttr.util.noopInT1\n            }) : this.methods({\n                rerenderTweetActionsView: function(a, b, c) {\n                    var d = new twttr.views.TweetActions(b);\n                    ((((a === \"unretweet\")) && (d.retweeted = !1))), c.JSBNG__find(\"span.js-actions, ul.js-actions\").replaceWith(d.html());\n                }\n            }))), a;\n        }), a(twttr.mixins.tweetActionable);\n    });\n});\nprovide(\"mixins/pendingActions\", function(a) {\n    using().as(function(b) {\n        var c = twttr.klass.mixin(\"twttr.mixins.pendingActions\", function() {\n            function a(a) {\n                var b = a.attr(\"data-pending\");\n                return ((b ? b.split(\" \") : []));\n            };\n        ;\n            function b(a, b) {\n                ((((b.length === 0)) ? a.removeAttr(\"data-pending\") : a.attr(\"data-pending\", b.join(\" \"))));\n            };\n        ;\n            var $ = jQuery;\n            return this.methods({\n                markAsPending: function(c, d) {\n                    var e = a(c);\n                    (((($.inArray(d, e) == -1)) && (e.push(d), b(c, e))));\n                },\n                markAsComplete: function(c, d) {\n                    var e = a(c), f = $.inArray(d, e);\n                    ((((f >= 0)) && (e.splice(f, 1), b(c, e))));\n                }\n            }), this;\n        });\n        a(c);\n    });\n});\nprovide(\"mixins/i18nTweet\", function(a) {\n    using().as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.i18nTweet\", function() {\n            var a = 419298, b = twttr.constants.regexps.rtlChar, c = /((<a[^>+]+>.+?<\\/a>|[ ^]RT:|:-?[DP\\$\\)\\(])+)/g;\n            this.methods({\n                updateI18nDisplay: function() {\n                    var a = this;\n                    this.$find(\"div.tweet, div.tweet-row\").each(function() {\n                        a.updateRtlDisplay($(this));\n                    });\n                },\n                getMachedRtlChars: function(a) {\n                    return a.match(b);\n                },\n                shouldBeRTL: function(b, c) {\n                    var d = twttr.txt.extractMentions(b).concat(twttr.txt.extractUrls(b)), e = 0;\n                    ((((d.length > 0)) && (e = ((((d.length * 2)) + d.join(\"\").length)))));\n                    var f = ((b.length - e));\n                    return ((((f != 0)) && ((((c.length / f)) > a))));\n                },\n                updateRtlDisplay: function(a) {\n                    var b = this, d = a.JSBNG__find(\"div.js-tweet-text, p.js-tweet-text\");\n                    if (d.hasClass(\"tweet-text-rtl\")) {\n                        return;\n                    }\n                ;\n                ;\n                    var e = this.getMachedRtlChars(d.text());\n                    ((((e != undefined)) && (d.JSBNG__find(\".twitter-hashtag\").each(function() {\n                        var a = $(this).attr(\"title\");\n                        if (!a) {\n                            return;\n                        }\n                    ;\n                    ;\n                        ((a.match(twttr.constants.regexps.rtlHashtag) ? $(this).html(((((\"\\u202b\" + $(this).html())) + \"\\u202c\"))) : $(this).html(((((\"\\u202a\" + $(this).html())) + \"\\u202c\")))));\n                    }), ((this.shouldBeRTL(d.text(), e) && (d.addClass(\"tweet-text-rtl\"), d.html(d.html().replace(c, \"\\u200e$1\\u200f\")), d.addClass(\"tweet-rtl\")))))));\n                }\n            });\n        }), a(twttr.mixins.i18nTweet);\n    });\n});\nprovide(\"mixins/i18nTweetBox\", function(a) {\n    using().as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.i18nTweetBox\", function() {\n            this.mixin(twttr.mixins.i18nTweet).methods({\n                registerTextDirEvents: function() {\n                    this.editor.bind(\"didChangeContent\", twttr.bind(this, this._toggleTextDir));\n                },\n                _insertLTRMarker: function(a) {\n                    var b = 0, c = [];\n                    return $(twttr.txt.extractMentionsWithIndices(a)).each(function(d, e) {\n                        c.push(a.substring(b, e.indices[0])), ((((((e.indices[0] === 0)) || ((a[((e.indices[0] - 1))] !== \"\\u200e\")))) && c.push(\"\\u200e\"))), c.push(a.substring(e.indices[0], e.indices[1])), ((((((e.indices[1] === 0)) || ((a[((e.indices[1] + 1))] !== \"\\u200f\")))) && c.push(\"\\u200f\"))), b = e.indices[1];\n                    }), c.push(a.substr(b)), a = c.join(\"\"), b = 0, c.length = 0, $(twttr.txt.extractHashtagsWithIndices(a)).each(function(d, e) {\n                        c.push(a.substring(b, e.indices[0])), ((((!a[((e.indices[0] + 1))].match(twttr.constants.regexps.rtlChar) && ((((e.indices[0] === 0)) || ((a[((e.indices[0] - 1))] !== \"\\u200e\")))))) && c.push(\"\\u200e\"))), b = e.indices[0];\n                    }), c.push(a.substr(b)), a = c.join(\"\"), b = 0, c.length = 0, $(twttr.txt.extractUrlsWithIndices(a)).each(function(d, e) {\n                        c.push(a.substring(b, e.indices[1])), ((((((e.indices[1] !== 0)) && ((a[((e.indices[1] + 1))] !== \"\\u200e\")))) && c.push(\"\\u200e\"))), b = e.indices[1];\n                    }), c.push(a.substr(b)), a = c.join(\"\"), a;\n                },\n                _eraseCheck: function(a) {\n                    if (((this._prev_txt && ((((this._prev_txt.length - a.length)) === 1))))) {\n                        for (i = 0; ((i < this._prev_txt.length)); ++i) {\n                            if (((((this._prev_txt[i] !== a[i])) && ((((this._prev_txt[i] === \"\\u200e\")) || ((this._prev_txt[i] === \"\\u200f\"))))))) {\n                                return ((a.substring(0, ((i - 1))) + a.substr(i)));\n                            }\n                        ;\n                        ;\n                        };\n                    }\n                ;\n                ;\n                    return a;\n                },\n                _markAtmarkLTR: function(a) {\n                    function b(a) {\n                        var b = 0;\n                        if (JSBNG__document.selection) {\n                            var c = JSBNG__document.selection.createRange();\n                            if (((c && ((c.parentElement() === a))))) {\n                                var d = a.value.length, e = a.createTextRange();\n                                e.moveToBookmark(c.getBookmark());\n                                var f = a.createTextRange();\n                                f.collapse(!1), ((((e.compareEndPoints(\"StartToEnd\", f) > -1)) ? b = d : b = -e.moveStart(\"character\", -d)));\n                            }\n                        ;\n                        ;\n                        }\n                         else if (((a.selectionStart || ((a.selectionStart == \"0\"))))) {\n                            b = a.selectionStart;\n                        }\n                        \n                    ;\n                    ;\n                        return b;\n                    };\n                ;\n                    function c(a, b) {\n                        if (a.setSelectionRange) {\n                            a.JSBNG__focus(), a.setSelectionRange(b, b);\n                        }\n                         else {\n                            if (a.createTextRange) {\n                                var c = a.createTextRange();\n                                c.collapse(!0), c.moveEnd(\"character\", b), c.moveStart(\"character\", b), c.select();\n                            }\n                        ;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    var d = ((a.parents(\"body\").length !== 0)), e = 0;\n                    ((d && (e = b(a[0]))));\n                    var f = a.val().length, g = this._eraseCheck(a.val()).replace(twttr.constants.regexps.dirMark, \"\");\n                    g = this._insertLTRMarker(g);\n                    if (((d && ((this._prev_txt !== g))))) {\n                        this._prev_txt = g, a.val(g);\n                        var i = ((((e + g.length)) - f));\n                        c(a[0], i);\n                    }\n                ;\n                ;\n                },\n                markPunctuation: function(a, b) {\n                    var c = b.val(), d = c.match(twttr.constants.regexps.rtlChar), e = twttr.isRTL;\n                    ((d ? e = this.shouldBeRTL(c, d) : ((((c.length !== 0)) && (e = !1))))), b.attr(\"dir\", ((e ? \"rtl\" : \"ltr\"))), ((((d && (((($.browser.mozilla || (((($.browser.webkit && a)) && ((a.type === \"keydown\")))))) || (((($.browser.msie && a)) && ((a.type === \"keyup\")))))))) && this._markAtmarkLTR(b)));\n                },\n                _toggleTextDir: function(a, b, c) {\n                    this.markPunctuation(c, this.editor.$editor);\n                }\n            });\n        }), a(twttr.mixins.i18nTweetBox);\n    });\n});\nprovide(\"mixins/promotedTweetStream\", function(a) {\n    using(\"_\").as(function(b, _) {\n        var c = twttr.klass.mixin(\"twttr.mixins.promotedTweetStream\", function(a) {\n            return a.methods({\n                hasPromotedContent: function() {\n                    for (var a = 0, b = this.items.length; ((a < b)); a++) {\n                        if (this.items[a].isPromoted()) {\n                            return !0;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    return !1;\n                },\n                logPromotedImpressions: function(a) {\n                    function b(a) {\n                        a.logImpressionIfPromoted();\n                    };\n                ;\n                    ((a.each ? a.each(b) : twttr.each(a, b)));\n                },\n                movePromotedTweetToTop: function() {\n                    var a = this.getMostRecentPromotedTweet();\n                    ((a && (this.removePromotedTweetDOMElements(), this.removePromotedTweetItems(), this.addAsNewItem(a))));\n                },\n                getMostRecentPromotedTweet: function() {\n                    for (var a = this.newItemsCount, b = this.items.length; ((a < b)); a++) {\n                        if (this.items[a].isPromoted()) {\n                            return this.items[a];\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                },\n                promotedTweetIsExpanded: function() {\n                    var a = this.$find(\".promoted-tweet\").closest(\".js-stream-item\");\n                    return a.hasClass(\"open\");\n                },\n                removePromotedTweetDOMElements: function() {\n                    this.$find(\".promoted-tweet\").closest(\".js-stream-item\").remove();\n                },\n                removePromotedTweetItems: function() {\n                    for (var a = this.newItemsCount; ((a < this.items.length)); a++) {\n                        ((this.items[a].isPromoted() && this.items.splice(a, 1)));\n                    ;\n                    };\n                ;\n                }\n            }), a;\n        });\n        a(c);\n    });\n});\nprovide(\"mixins/componentEvents\", function(a) {\n    using(\"util\", \"constants\").as(function(b) {\n        var c;\n        twttr.klass.mixin(\"twttr.mixins.componentEvents\", function(a) {\n            return $.each(b.constants.jQueryEvents, function(c, d) {\n                a[d] = function(a) {\n                    return ((twttr.is.inArray(d, [\"keypress\",\"keydown\",\"keyup\",]) && $.each(a, function(b, c) {\n                        a[b] = function(a) {\n                            return ((((((a.ctrlKey || a.metaKey)) || a.altKey)) ? undefined : c.apply(this, arguments)));\n                        };\n                    }))), ((this.prototype.hasOwnProperty(((\"_\" + d))) || ((((this.uberclass && this.uberclass.prototype[((\"_\" + d))])) ? this.prototype[((\"_\" + d))] = b.util.create(this.uberclass.prototype[((\"_\" + d))]) : this.prototype[((\"_\" + d))] = {\n                    })))), twttr.augmentObject(this.prototype[((\"_\" + d))], a), this;\n                };\n            }), a.statics({\n                debugUserEvents: function(a) {\n                    c = ((((typeof a == \"undefined\")) ? !0 : a));\n                }\n            }), a.methods({\n                initComponentEvents: function(a) {\n                    var d = this;\n                    a = ((a || this.$node)), $.each(b.constants.jQueryEvents, function(b, e) {\n                        if (twttr.is.inArray(e, [\"keypress\",\"keydown\",\"keyup\",])) {\n                            return;\n                        }\n                    ;\n                    ;\n                        $.each(((d[((\"_\" + e))] || {\n                        })), function(b, f) {\n                            var g = [b,e,], i = (($.isArray(f) ? f : [f,]));\n                            $.each(i, function(a, f) {\n                                g.push(function(a) {\n                                    ((c && JSBNG__console.log(\"User event fired\", {\n                                        component: d,\n                                        JSBNG__event: e,\n                                        selector: b,\n                                        handler: f\n                                    })));\n                                    if (!a.isImmediatePropagationStopped()) {\n                                        return f.call(d, a, $(this));\n                                    }\n                                ;\n                                ;\n                                });\n                            }), a.delegate.apply(a, g);\n                        });\n                    });\n                }\n            }), a;\n        }), a(twttr.mixins.componentEvents);\n    });\n});\nprovide(\"mixins/protectedUserActionable\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.klass.mixin(\"twttr.mixins.protectedUserActionable\", function(a) {\n            return a.methods({\n                registerProtectedUserActions: function() {\n                    var a = this;\n                    this.$node.delegate(\".js-actionable-user .js-action-deny\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-user\");\n                        return twttr.currentUser.friends.deny(parseInt(d.attr(\"data-user-id\")), function(b) {\n                            a.trigger(\"deny.user\", [d,c,\"deny\",]), d.parents(\".js-stream-item\").remove();\n                        }), b.stopImmediatePropagation(), !1;\n                    }), this.$node.delegate(\".js-actionable-user .js-action-accept\", \"click\", function(b) {\n                        var c = $(this), d = c.closest(\".js-actionable-user\");\n                        return twttr.currentUser.friends.accept(parseInt(d.attr(\"data-user-id\")), function(b) {\n                            a.trigger(\"accept.user\", [d,c,\"accept\",]), (new twttr.views.StreamUser(b)).render(d, \"replaceWith\");\n                        }), b.stopImmediatePropagation(), !1;\n                    });\n                }\n            }), a;\n        }), a(twttr.mixins.protectedUserActionable);\n    });\n});\nprovide(\"mixins/serverRenderableObject\", function(a) {\n    using(\"libwrap/jquery\").as(function(b, $) {\n        twttr.klass.mixin(\"twttr.mixins.serverRenderableObject\", function(a) {\n            return a.methods({\n                preRendered: !1,\n                $domNode: function(a) {\n                    return ((this.$node ? this.$node : (((this.isPresentInDom() ? (this.preRendered = !0, this.$node = $(this.selectorAsString())) : (this.preRendered = !1, ((((typeof a == \"function\")) && (a = a.call(this)))), this.$node = $(a), ((((this.$node.length > 1)) && (this.$node = $(\"\\u003Cdiv /\\u003E\").html(a))))))), this.$node)));\n                },\n                domNodeSelector: null,\n                selectorAsString: function() {\n                    return ((((typeof this.domNodeSelector == \"function\")) ? this.domNodeSelector() : this.domNodeSelector));\n                },\n                isPresentInDom: function() {\n                    var a = this.selectorAsString();\n                    return ((a && (($(a).length === 1))));\n                }\n            }), a;\n        }), a(twttr.mixins.serverRenderableObject);\n    });\n});\nprovide(\"mixins/welcomeScribing\", function(a) {\n    using().as(function(b) {\n        twttr.klass.mixin(\"twttr.mixins.welcomeScribing\", function(a) {\n            return a.methods({\n                setWelcomeSkipCookie: function() {\n                    twttr.mixins.welcomeScribing._noWelcomeSkipCookie = !1, $.cookie(\"welcome\", \"1\", {\n                        expires: new JSBNG__Date(((+(new JSBNG__Date) + 3600000)))\n                    });\n                },\n                clearWelcomeSkipCookie: function() {\n                    ((twttr.mixins.welcomeScribing._noWelcomeSkipCookie || (twttr.mixins.welcomeScribing._noWelcomeSkipCookie = !0, $.cookie(\"welcome\", null))));\n                },\n                maybeScribeWelcomeSkip: function() {\n                    if (((twttr.mixins.welcomeScribing._noWelcomeSkipCookie || (($.cookie(\"welcome\") != \"1\"))))) {\n                        twttr.mixins.welcomeScribing._noWelcomeSkipCookie = !0;\n                        return;\n                    }\n                ;\n                ;\n                    var a = {\n                        page: \"welcome\",\n                        section: \"finished\",\n                        action: \"skip\"\n                    };\n                    trackClient(a), this.clearWelcomeSkipCookie();\n                }\n            }), a;\n        }), a();\n    });\n});\nprovide(\"mixins/t1/emptyTimelineRecommendations\", function(a) {\n    using().as(function() {\n        twttr.klass.mixin(\"twttr.mixins.emptyTimelineRecommendations\", function() {\n            this.statics({\n                showing: !1\n            }).methods({\n                insertEmptyTimeline: function(a) {\n                    var a = ((a || {\n                    })), b = this;\n                    using([twttr.bundleMore,\"components/t1/EmptyTimelineRecommendations\",], function() {\n                        if (!twttr.decider.isAvailable(\"empty_timeline_recommendations\")) {\n                            return b._dontShowSignalCompleted(b);\n                        }\n                    ;\n                    ;\n                        if (!twttr.util.params().empty_timeline) {\n                            if (((twttr.cache.local.shownWelcomeFlow && ((twttr.currentUser.friendsCount > 0))))) {\n                                return b._dontShowSignalCompleted(b);\n                            }\n                        ;\n                        ;\n                            if (((twttr.currentUser.friendsCount >= twttr.components.t1.EmptyTimelineRecommendations.avatarLimit))) {\n                                return b._dontShowSignalCompleted(b);\n                            }\n                        ;\n                        ;\n                            if (((((((((Math.floor((((new JSBNG__Date).getTime() - new JSBNG__Date(twttr.currentUser.createdAt)))) / 86400000)) > 60)) && ((twttr.currentUser.followersCount > 100)))) && ((twttr.currentUser.friendsCount > 0))))) {\n                                return b._dontShowSignalCompleted(b);\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                        var c = b.$find(\"#js-empty-timeline-recommendations-module-hook\"), d = b.$find(\".js-stream-manager-container, .js-stream-header\");\n                        c.show(), twttr.mixins.emptyTimelineRecommendations.showing = !0, twttr.router.JSBNG__one(\"routed.EmptyTimelineRecommendations\", function(a, b) {\n                            ((((e === b.JSBNG__name)) ? twttr.router.JSBNG__one(\"routed.EmptyTimelineRecommendations\", arguments.callee) : (c.hide(), d.show())));\n                        });\n                        var e = twttr.router.getCurrentRoute().JSBNG__name;\n                        if (((c.JSBNG__find(\".js-empty-timeline\").size() > 0))) {\n                            b.signal(\"emptyTimelineModuleLogicCompleted\");\n                            return;\n                        }\n                    ;\n                    ;\n                        var f = new twttr.components.t1.EmptyTimelineRecommendations({\n                            scribeComponentName: \"empty_timeline_recommendations\"\n                        });\n                        c.html(f.$node), f.trigger(\"addedToPage\"), ((((typeof a.JSBNG__onDestroyCb == \"function\")) && f.bind(\"destroyed\", a.JSBNG__onDestroyCb)));\n                        var g = {\n                            success: function() {\n                                var c = b.streamManager.streams.current;\n                                ((a.reloadStream && c.trigger(\"reloadCurrentStream\", c.constructor))), d.show();\n                            }\n                        };\n                        twttr.API.User.bind(\"follow.EmptyTimelineRecommendations\", g);\n                        var g = {\n                            success: function() {\n                                var c = b.streamManager.streams.current;\n                                ((a.reloadStream && c.trigger(\"reloadCurrentStream\", c.constructor))), ((((twttr.currentUser.friendsCount === 0)) && d.hide()));\n                            }\n                        };\n                        twttr.API.User.bind(\"unfollow.EmptyTimelineRecommendations\", g), b.signal(\"emptyTimelineModuleLogicCompleted\");\n                    });\n                },\n                _dontShowSignalCompleted: function(a) {\n                    twttr.mixins.emptyTimelineRecommendations.showing = !1, a.signal(\"emptyTimelineModuleLogicCompleted\");\n                }\n            });\n        }), a(twttr.mixins.emptyTimelineRecommendations);\n    });\n});\nprovide(\"lib/natcompare\", function(a) {\n    using().as(function(b) {\n        var c = twttr.augmentString(\"twttr.natcompare\", function() {\n            var a = function(a) {\n                var b;\n                return b = a.charCodeAt(0), ((((b <= 32)) ? !0 : !1));\n            }, b = function(a) {\n                var b;\n                return b = a.charCodeAt(0), ((((((b >= 48)) && ((b <= 57)))) ? !0 : !1));\n            }, c = function(a, c) {\n                var d = 0, e = 0, f = 0, g, i;\n                for (; ; e++, f++) {\n                    g = a.charAt(e), i = c.charAt(f);\n                    if (((!b(g) && !b(i)))) {\n                        return d;\n                    }\n                ;\n                ;\n                    if (!b(g)) {\n                        return -1;\n                    }\n                ;\n                ;\n                    if (!b(i)) {\n                        return 1;\n                    }\n                ;\n                ;\n                    ((((g < i)) ? ((((d == 0)) && (d = -1))) : ((((((g > i)) && ((d == 0)))) && (d = 1)))));\n                };\n            ;\n            };\n            return function(d, e) {\n                ((((typeof d == \"number\")) && (d = d.toString()))), ((((typeof e == \"number\")) && (e = e.toString())));\n                var f = 0, g = 0, i = 0, j = 0, k, l, m;\n                for (; ; ) {\n                    i = j = 0, k = d.charAt(f), l = e.charAt(g);\n                    while (((a(k) || ((k == \"0\"))))) {\n                        ((((k == \"0\")) ? i++ : i = 0)), k = d.charAt(++f);\n                    ;\n                    };\n                ;\n                    while (((a(l) || ((l == \"0\"))))) {\n                        ((((l == \"0\")) ? j++ : j = 0)), l = e.charAt(++g);\n                    ;\n                    };\n                ;\n                    if (((((b(k) && b(l))) && (((m = c(d.substring(f), e.substring(g))) != 0))))) {\n                        return m;\n                    }\n                ;\n                ;\n                    if (((((k == 0)) && ((l == 0))))) {\n                        return ((i - j));\n                    }\n                ;\n                ;\n                    if (((k < l))) {\n                        return -1;\n                    }\n                ;\n                ;\n                    if (((k > l))) {\n                        return 1;\n                    }\n                ;\n                ;\n                    ++f, ++g;\n                };\n            ;\n            };\n        }());\n        twttr.augmentString(\"twttr.util.natcompare\", c), a(c);\n    });\n});\nprovide(\"$lib/twitter-text-1.5.0.js\", function(a) {\n    if (((((typeof window == \"undefined\")) || ((window === null))))) {\n        window = {\n            twttr: {\n            }\n        };\n    }\n;\n;\n    ((((window.twttr == null)) && (window.twttr = {\n    })));\n    if (((((typeof twttr == \"undefined\")) || ((twttr === null))))) {\n        twttr = {\n        };\n    }\n;\n;\n    (function() {\n        function a(a, b) {\n            return b = ((b || \"\")), ((((typeof a != \"string\")) && (((((a.global && ((b.indexOf(\"g\") < 0)))) && (b += \"g\"))), ((((a.ignoreCase && ((b.indexOf(\"i\") < 0)))) && (b += \"i\"))), ((((a.multiline && ((b.indexOf(\"m\") < 0)))) && (b += \"m\"))), a = a.source))), new RegExp(a.replace(/#\\{(\\w+)\\}/g, function(a, b) {\n                var c = ((twttr.txt.regexen[b] || \"\"));\n                return ((((typeof c != \"string\")) && (c = c.source))), c;\n            }), b);\n        };\n    ;\n        function b(a, b) {\n            return a.replace(/#\\{(\\w+)\\}/g, function(a, c) {\n                return ((b[c] || \"\"));\n            });\n        };\n    ;\n        function c(a, b, c) {\n            var d = String.fromCharCode(b);\n            return ((((c !== b)) && (d += ((\"-\" + String.fromCharCode(c)))))), a.push(d), a;\n        };\n    ;\n        function d(a) {\n            var b = {\n            };\n            for (var c in a) {\n                ((a.hasOwnProperty(c) && (b[c] = a[c])));\n            ;\n            };\n        ;\n            return b;\n        };\n    ;\n        function e(a, b, c) {\n            return ((c ? ((!a || ((a.match(b) && ((RegExp[\"$&\"] === a)))))) : ((((((typeof a == \"string\")) && a.match(b))) && ((RegExp[\"$&\"] === a))))));\n        };\n    ;\n        twttr.txt = {\n        }, twttr.txt.regexen = {\n        };\n        var f = {\n            \"&\": \"&amp;\",\n            \"\\u003E\": \"&gt;\",\n            \"\\u003C\": \"&lt;\",\n            \"\\\"\": \"&quot;\",\n            \"'\": \"&#39;\"\n        };\n        twttr.txt.htmlEscape = function(a) {\n            return ((a && a.replace(/[&\"'><]/g, function(a) {\n                return f[a];\n            })));\n        }, twttr.txt.regexSupplant = a, twttr.txt.stringSupplant = b, twttr.txt.addCharsToCharClass = c;\n        var g = String.fromCharCode, i = [g(32),g(133),g(160),g(5760),g(6158),g(8232),g(8233),g(8239),g(8287),g(12288),];\n        c(i, 9, 13), c(i, 8192, 8202);\n        var j = [g(65534),g(65279),g(65535),];\n        c(j, 8234, 8238), twttr.txt.regexen.spaces_group = a(i.join(\"\")), twttr.txt.regexen.spaces = a(((((\"[\" + i.join(\"\"))) + \"]\"))), twttr.txt.regexen.invalid_chars_group = a(j.join(\"\")), twttr.txt.regexen.punct = /\\!'#%&'\\(\\)*\\+,\\\\\\-\\.\\/:;<=>\\?@\\[\\]\\^_{|}~\\$/;\n        var k = [];\n        c(k, 1024, 1279), c(k, 1280, 1319), c(k, 11744, 11775), c(k, 42560, 42655), c(k, 1425, 1471), c(k, 1473, 1474), c(k, 1476, 1477), c(k, 1479, 1479), c(k, 1488, 1514), c(k, 1520, 1524), c(k, 64274, 64296), c(k, 64298, 64310), c(k, 64312, 64316), c(k, 64318, 64318), c(k, 64320, 64321), c(k, 64323, 64324), c(k, 64326, 64335), c(k, 1552, 1562), c(k, 1568, 1631), c(k, 1646, 1747), c(k, 1749, 1756), c(k, 1758, 1768), c(k, 1770, 1775), c(k, 1786, 1788), c(k, 1791, 1791), c(k, 1872, 1919), c(k, 2208, 2208), c(k, 2210, 2220), c(k, 2276, 2302), c(k, 64336, 64433), c(k, 64467, 64829), c(k, 64848, 64911), c(k, 64914, 64967), c(k, 65008, 65019), c(k, 65136, 65140), c(k, 65142, 65276), c(k, 8204, 8204), c(k, 3585, 3642), c(k, 3648, 3662), c(k, 4352, 4607), c(k, 12592, 12677), c(k, 43360, 43391), c(k, 44032, 55215), c(k, 55216, 55295), c(k, 65441, 65500), c(k, 12449, 12538), c(k, 12540, 12542), c(k, 65382, 65439), c(k, 65392, 65392), c(k, 65296, 65305), c(k, 65313, 65338), c(k, 65345, 65370), c(k, 12353, 12438), c(k, 12441, 12446), c(k, 13312, 19903), c(k, 19968, 40959), c(k, 173824, 177983), c(k, 177984, 178207), c(k, 194560, 195103), c(k, 12291, 12291), c(k, 12293, 12293), c(k, 12347, 12347), twttr.txt.regexen.nonLatinHashtagChars = a(k.join(\"\"));\n        var l = [];\n        c(l, 192, 214), c(l, 216, 246), c(l, 248, 255), c(l, 256, 591), c(l, 595, 596), c(l, 598, 599), c(l, 601, 601), c(l, 603, 603), c(l, 611, 611), c(l, 616, 616), c(l, 623, 623), c(l, 626, 626), c(l, 649, 649), c(l, 651, 651), c(l, 699, 699), c(l, 768, 879), c(l, 7680, 7935), twttr.txt.regexen.latinAccentChars = a(l.join(\"\")), twttr.txt.regexen.hashSigns = /[#＃]/, twttr.txt.regexen.hashtagAlpha = a(/[a-z_#{latinAccentChars}#{nonLatinHashtagChars}]/i), twttr.txt.regexen.hashtagAlphaNumeric = a(/[a-z0-9_#{latinAccentChars}#{nonLatinHashtagChars}]/i), twttr.txt.regexen.endHashtagMatch = a(/^(?:#{hashSigns}|:\\/\\/)/), twttr.txt.regexen.hashtagBoundary = a(/(?:^|$|[^&a-z0-9_#{latinAccentChars}#{nonLatinHashtagChars}])/), twttr.txt.regexen.validHashtag = a(/(#{hashtagBoundary})(#{hashSigns})(#{hashtagAlphaNumeric}*#{hashtagAlpha}#{hashtagAlphaNumeric}*)/gi), twttr.txt.regexen.validMentionPrecedingChars = /(?:^|[^a-zA-Z0-9_!#$%&*@＠]|RT:?)/, twttr.txt.regexen.atSigns = /[@＠]/, twttr.txt.regexen.validMentionOrList = a(\"(#{validMentionPrecedingChars})(#{atSigns})([a-zA-Z0-9_]{1,20})(/[a-zA-Z][a-zA-Z0-9_-]{0,24})?\", \"g\"), twttr.txt.regexen.validReply = a(/^(?:#{spaces})*#{atSigns}([a-zA-Z0-9_]{1,20})/), twttr.txt.regexen.endMentionMatch = a(/^(?:#{atSigns}|[#{latinAccentChars}]|:\\/\\/)/), twttr.txt.regexen.validUrlPrecedingChars = a(/(?:[^A-Za-z0-9@＠$#＃#{invalid_chars_group}]|^)/), twttr.txt.regexen.invalidUrlWithoutProtocolPrecedingChars = /[-_.\\/]$/, twttr.txt.regexen.invalidDomainChars = b(\"#{punct}#{spaces_group}#{invalid_chars_group}\", twttr.txt.regexen), twttr.txt.regexen.validDomainChars = a(/[^#{invalidDomainChars}]/), twttr.txt.regexen.validSubdomain = a(/(?:(?:#{validDomainChars}(?:[_-]|#{validDomainChars})*)?#{validDomainChars}\\.)/), twttr.txt.regexen.validDomainName = a(/(?:(?:#{validDomainChars}(?:-|#{validDomainChars})*)?#{validDomainChars}\\.)/), twttr.txt.regexen.validGTLD = a(/(?:(?:aero|asia|biz|cat|com|coop|edu|gov|info|int|jobs|mil|mobi|museum|name|net|org|pro|tel|travel|xxx)(?=[^0-9a-zA-Z]|$))/), twttr.txt.regexen.validCCTLD = a(/(?:(?:ac|ad|ae|af|ag|ai|al|am|an|ao|aq|ar|as|at|au|aw|ax|az|ba|bb|bd|be|bf|bg|bh|bi|bj|bm|bn|bo|br|bs|bt|bv|bw|by|bz|ca|cc|cd|cf|cg|ch|ci|ck|cl|cm|cn|co|cr|cs|cu|cv|cx|cy|cz|dd|de|dj|dk|dm|do|dz|ec|ee|eg|eh|er|es|et|eu|fi|fj|fk|fm|fo|fr|ga|gb|gd|ge|gf|gg|gh|gi|gl|gm|gn|gp|gq|gr|gs|gt|gu|gw|gy|hk|hm|hn|hr|ht|hu|id|ie|il|im|in|io|iq|ir|is|it|je|jm|jo|jp|ke|kg|kh|ki|km|kn|kp|kr|kw|ky|kz|la|lb|lc|li|lk|lr|ls|lt|lu|lv|ly|ma|mc|md|me|mg|mh|mk|ml|mm|mn|mo|mp|mq|mr|ms|mt|mu|mv|mw|mx|my|mz|na|nc|ne|nf|ng|ni|nl|no|np|nr|nu|nz|om|pa|pe|pf|pg|ph|pk|pl|pm|pn|pr|ps|pt|pw|py|qa|re|ro|rs|ru|rw|sa|sb|sc|sd|se|sg|sh|si|sj|sk|sl|sm|sn|so|sr|ss|st|su|sv|sy|sz|tc|td|tf|tg|th|tj|tk|tl|tm|tn|to|tp|tr|tt|tv|tw|tz|ua|ug|uk|us|uy|uz|va|vc|ve|vg|vi|vn|vu|wf|ws|ye|yt|za|zm|zw)(?=[^0-9a-zA-Z]|$))/), twttr.txt.regexen.validPunycode = a(/(?:xn--[0-9a-z]+)/), twttr.txt.regexen.validDomain = a(/(?:#{validSubdomain}*#{validDomainName}(?:#{validGTLD}|#{validCCTLD}|#{validPunycode}))/), twttr.txt.regexen.validAsciiDomain = a(/(?:(?:[a-z0-9#{latinAccentChars}]+)\\.)+(?:#{validGTLD}|#{validCCTLD}|#{validPunycode})/gi), twttr.txt.regexen.invalidShortDomain = a(/^#{validDomainName}#{validCCTLD}$/), twttr.txt.regexen.validPortNumber = a(/[0-9]+/), twttr.txt.regexen.validGeneralUrlPathChars = a(/[a-z0-9!\\*';:=\\+,\\.\\$\\/%#\\[\\]\\-_~|&#{latinAccentChars}]/i), twttr.txt.regexen.validUrlBalancedParens = a(/\\(#{validGeneralUrlPathChars}+\\)/i), twttr.txt.regexen.validUrlPathEndingChars = a(/[\\+\\-a-z0-9=_#\\/#{latinAccentChars}]|(?:#{validUrlBalancedParens})/i), twttr.txt.regexen.validUrlPath = a(\"(?:(?:#{validGeneralUrlPathChars}*(?:#{validUrlBalancedParens}#{validGeneralUrlPathChars}*)*#{validUrlPathEndingChars})|(?:@#{validGeneralUrlPathChars}+/))\", \"i\"), twttr.txt.regexen.validUrlQueryChars = /[a-z0-9!?\\*'\\(\\);:&=\\+\\$\\/%#\\[\\]\\-_\\.,~|]/i, twttr.txt.regexen.validUrlQueryEndingChars = /[a-z0-9_&=#\\/]/i, twttr.txt.regexen.extractUrl = a(\"((#{validUrlPrecedingChars})((https?:\\\\/\\\\/)?(#{validDomain})(?::(#{validPortNumber}))?(\\\\/#{validUrlPath}*)?(\\\\?#{validUrlQueryChars}*#{validUrlQueryEndingChars})?))\", \"gi\"), twttr.txt.regexen.validTcoUrl = /^https?:\\/\\/t\\.co\\/[a-z0-9]+/i, twttr.txt.regexen.cashtag = /[a-z]{1,6}(?:[._][a-z]{1,2})?/i, twttr.txt.regexen.validCashtag = a(\"(?:^|#{spaces})\\\\$(#{cashtag})(?=$|\\\\s|[#{punct}])\", \"gi\"), twttr.txt.regexen.validateUrlUnreserved = /[a-z0-9\\-._~]/i, twttr.txt.regexen.validateUrlPctEncoded = /(?:%[0-9a-f]{2})/i, twttr.txt.regexen.validateUrlSubDelims = /[!$&'()*+,;=]/i, twttr.txt.regexen.validateUrlPchar = a(\"(?:#{validateUrlUnreserved}|#{validateUrlPctEncoded}|#{validateUrlSubDelims}|[:|@])\", \"i\"), twttr.txt.regexen.validateUrlScheme = /(?:[a-z][a-z0-9+\\-.]*)/i, twttr.txt.regexen.validateUrlUserinfo = a(\"(?:#{validateUrlUnreserved}|#{validateUrlPctEncoded}|#{validateUrlSubDelims}|:)*\", \"i\"), twttr.txt.regexen.validateUrlDecOctet = /(?:[0-9]|(?:[1-9][0-9])|(?:1[0-9]{2})|(?:2[0-4][0-9])|(?:25[0-5]))/i, twttr.txt.regexen.validateUrlIpv4 = a(/(?:#{validateUrlDecOctet}(?:\\.#{validateUrlDecOctet}){3})/i), twttr.txt.regexen.validateUrlIpv6 = /(?:\\[[a-f0-9:\\.]+\\])/i, twttr.txt.regexen.validateUrlIp = a(\"(?:#{validateUrlIpv4}|#{validateUrlIpv6})\", \"i\"), twttr.txt.regexen.validateUrlSubDomainSegment = /(?:[a-z0-9](?:[a-z0-9_\\-]*[a-z0-9])?)/i, twttr.txt.regexen.validateUrlDomainSegment = /(?:[a-z0-9](?:[a-z0-9\\-]*[a-z0-9])?)/i, twttr.txt.regexen.validateUrlDomainTld = /(?:[a-z](?:[a-z0-9\\-]*[a-z0-9])?)/i, twttr.txt.regexen.validateUrlDomain = a(/(?:(?:#{validateUrlSubDomainSegment]}\\.)*(?:#{validateUrlDomainSegment]}\\.)#{validateUrlDomainTld})/i), twttr.txt.regexen.validateUrlHost = a(\"(?:#{validateUrlIp}|#{validateUrlDomain})\", \"i\"), twttr.txt.regexen.validateUrlUnicodeSubDomainSegment = /(?:(?:[a-z0-9]|[^\\u0000-\\u007f])(?:(?:[a-z0-9_\\-]|[^\\u0000-\\u007f])*(?:[a-z0-9]|[^\\u0000-\\u007f]))?)/i, twttr.txt.regexen.validateUrlUnicodeDomainSegment = /(?:(?:[a-z0-9]|[^\\u0000-\\u007f])(?:(?:[a-z0-9\\-]|[^\\u0000-\\u007f])*(?:[a-z0-9]|[^\\u0000-\\u007f]))?)/i, twttr.txt.regexen.validateUrlUnicodeDomainTld = /(?:(?:[a-z]|[^\\u0000-\\u007f])(?:(?:[a-z0-9\\-]|[^\\u0000-\\u007f])*(?:[a-z0-9]|[^\\u0000-\\u007f]))?)/i, twttr.txt.regexen.validateUrlUnicodeDomain = a(/(?:(?:#{validateUrlUnicodeSubDomainSegment}\\.)*(?:#{validateUrlUnicodeDomainSegment}\\.)#{validateUrlUnicodeDomainTld})/i), twttr.txt.regexen.validateUrlUnicodeHost = a(\"(?:#{validateUrlIp}|#{validateUrlUnicodeDomain})\", \"i\"), twttr.txt.regexen.validateUrlPort = /[0-9]{1,5}/, twttr.txt.regexen.validateUrlUnicodeAuthority = a(\"(?:(#{validateUrlUserinfo})@)?(#{validateUrlUnicodeHost})(?::(#{validateUrlPort}))?\", \"i\"), twttr.txt.regexen.validateUrlAuthority = a(\"(?:(#{validateUrlUserinfo})@)?(#{validateUrlHost})(?::(#{validateUrlPort}))?\", \"i\"), twttr.txt.regexen.validateUrlPath = a(/(\\/#{validateUrlPchar}*)*/i), twttr.txt.regexen.validateUrlQuery = a(/(#{validateUrlPchar}|\\/|\\?)*/i), twttr.txt.regexen.validateUrlFragment = a(/(#{validateUrlPchar}|\\/|\\?)*/i), twttr.txt.regexen.validateUrlUnencoded = a(\"^(?:([^:/?#]+):\\\\/\\\\/)?([^/?#]*)([^?#]*)(?:\\\\?([^#]*))?(?:#(.*))?$\", \"i\");\n        var m = \"tweet-url list-slug\", n = \"tweet-url username\", o = \"tweet-url hashtag\", p = \"tweet-url cashtag\", q = {\n            urlClass: !0,\n            listClass: !0,\n            usernameClass: !0,\n            hashtagClass: !0,\n            cashtagClass: !0,\n            usernameUrlBase: !0,\n            listUrlBase: !0,\n            hashtagUrlBase: !0,\n            cashtagUrlBase: !0,\n            usernameUrlBlock: !0,\n            listUrlBlock: !0,\n            hashtagUrlBlock: !0,\n            linkUrlBlock: !0,\n            usernameIncludeSymbol: !0,\n            suppressLists: !0,\n            suppressNoFollow: !0,\n            suppressDataScreenName: !0,\n            urlEntities: !0,\n            symbolTag: !0,\n            textWithSymbolTag: !0,\n            urlTarget: !0,\n            invisibleTagAttrs: !0,\n            linkAttributeBlock: !0,\n            linkTextBlock: !0\n        }, r = {\n            disabled: !0,\n            readonly: !0,\n            multiple: !0,\n            checked: !0\n        };\n        twttr.txt.tagAttrs = function(a) {\n            var b = \"\";\n            for (var c in a) {\n                var d = a[c];\n                ((r[c] && (d = ((d ? c : null)))));\n                if (((d == null))) {\n                    continue;\n                }\n            ;\n            ;\n                b += ((((((((\" \" + twttr.txt.htmlEscape(c))) + \"=\\\"\")) + twttr.txt.htmlEscape(d.toString()))) + \"\\\"\"));\n            };\n        ;\n            return b;\n        }, twttr.txt.linkToText = function(a, c, d, e) {\n            ((e.suppressNoFollow || (d.rel = \"nofollow\"))), ((e.linkAttributeBlock && e.linkAttributeBlock(a, d))), ((e.linkTextBlock && (c = e.linkTextBlock(a, c))));\n            var f = {\n                text: c,\n                attr: twttr.txt.tagAttrs(d)\n            };\n            return b(\"\\u003Ca#{attr}\\u003E#{text}\\u003C/a\\u003E\", f);\n        }, twttr.txt.linkToTextWithSymbol = function(a, b, c, d, e) {\n            var f = ((e.symbolTag ? ((((((((((((\"\\u003C\" + e.symbolTag)) + \"\\u003E\")) + b)) + \"\\u003C/\")) + e.symbolTag)) + \"\\u003E\")) : b));\n            c = twttr.txt.htmlEscape(c);\n            var g = ((e.textWithSymbolTag ? ((((((((((((\"\\u003C\" + e.textWithSymbolTag)) + \"\\u003E\")) + c)) + \"\\u003C/\")) + e.textWithSymbolTag)) + \"\\u003E\")) : c));\n            return ((((e.usernameIncludeSymbol || !b.match(twttr.txt.regexen.atSigns))) ? twttr.txt.linkToText(a, ((f + g)), d, e) : ((f + twttr.txt.linkToText(a, g, d, e)))));\n        }, twttr.txt.linkToHashtag = function(a, b, c) {\n            var e = b.substring(a.indices[0], ((a.indices[0] + 1))), f = twttr.txt.htmlEscape(a.hashtag), g = d(((c.htmlAttrs || {\n            })));\n            return g.href = ((c.hashtagUrlBase + encodeURIComponent(f))), g.title = ((\"#\" + f)), g[\"class\"] = c.hashtagClass, twttr.txt.linkToTextWithSymbol(a, e, f, g, c);\n        }, twttr.txt.linkToCashtag = function(a, b, c) {\n            var e = twttr.txt.htmlEscape(a.cashtag), f = d(((c.htmlAttrs || {\n            })));\n            return f.href = ((c.cashtagUrlBase + e)), f.title = ((\"$\" + e)), f[\"class\"] = c.cashtagClass, twttr.txt.linkToTextWithSymbol(a, \"$\", e, f, c);\n        }, twttr.txt.linkToMentionAndList = function(a, b, c) {\n            var e = b.substring(a.indices[0], ((a.indices[0] + 1))), f = twttr.txt.htmlEscape(a.screenName), g = twttr.txt.htmlEscape(a.listSlug), i = ((a.listSlug && !c.suppressLists)), j = d(((c.htmlAttrs || {\n            })));\n            return j[\"class\"] = ((i ? c.listClass : c.usernameClass)), j.href = ((i ? ((((c.listUrlBase + f)) + g)) : ((c.usernameUrlBase + f)))), ((((!i && !c.suppressDataScreenName)) && (j[\"data-screen-name\"] = f))), twttr.txt.linkToTextWithSymbol(a, e, ((i ? ((f + g)) : f)), j, c);\n        }, twttr.txt.linkToUrl = function(a, b, c) {\n            var e = a.url, f = e, g = twttr.txt.htmlEscape(f), i = ((((c.urlEntities && c.urlEntities[e])) || a));\n            ((i.display_url && (g = twttr.txt.linkTextWithEntity(i, c))));\n            var j = d(((c.htmlAttrs || {\n            })));\n            return j.href = e, ((c.urlClass && (j[\"class\"] = c.urlClass))), ((c.urlTarget && (j.target = c.urlTarget))), ((((!c.title && i.display_url)) && (j.title = i.expanded_url))), twttr.txt.linkToText(a, g, j, c);\n        }, twttr.txt.linkTextWithEntity = function(a, c) {\n            var d = a.display_url, e = a.expanded_url, f = d.replace(/…/g, \"\");\n            if (((e.indexOf(f) != -1))) {\n                var g = e.indexOf(f), i = {\n                    displayUrlSansEllipses: f,\n                    beforeDisplayUrl: e.substr(0, g),\n                    afterDisplayUrl: e.substr(((g + f.length))),\n                    precedingEllipsis: ((d.match(/^…/) ? \"\\u2026\" : \"\")),\n                    followingEllipsis: ((d.match(/…$/) ? \"\\u2026\" : \"\"))\n                };\n                for (var j in i) {\n                    ((i.hasOwnProperty(j) && (i[j] = twttr.txt.htmlEscape(i[j]))));\n                ;\n                };\n            ;\n                return i.invisible = c.invisibleTagAttrs, b(\"\\u003Cspan class='tco-ellipsis'\\u003E#{precedingEllipsis}\\u003Cspan #{invisible}\\u003E&nbsp;\\u003C/span\\u003E\\u003C/span\\u003E\\u003Cspan #{invisible}\\u003E#{beforeDisplayUrl}\\u003C/span\\u003E\\u003Cspan class='js-display-url'\\u003E#{displayUrlSansEllipses}\\u003C/span\\u003E\\u003Cspan #{invisible}\\u003E#{afterDisplayUrl}\\u003C/span\\u003E\\u003Cspan class='tco-ellipsis'\\u003E\\u003Cspan #{invisible}\\u003E&nbsp;\\u003C/span\\u003E#{followingEllipsis}\\u003C/span\\u003E\", i);\n            }\n        ;\n        ;\n            return d;\n        }, twttr.txt.autoLinkEntities = function(a, b, c) {\n            c = d(((c || {\n            }))), c.hashtagClass = ((c.hashtagClass || o)), c.hashtagUrlBase = ((c.hashtagUrlBase || \"https://twitter.com/#!/search?q=%23\")), c.cashtagClass = ((c.cashtagClass || p)), c.cashtagUrlBase = ((c.cashtagUrlBase || \"https://twitter.com/#!/search?q=%24\")), c.listClass = ((c.listClass || m)), c.usernameClass = ((c.usernameClass || n)), c.usernameUrlBase = ((c.usernameUrlBase || \"https://twitter.com/\")), c.listUrlBase = ((c.listUrlBase || \"https://twitter.com/\")), c.htmlAttrs = twttr.txt.extractHtmlAttrsFromOptions(c), c.invisibleTagAttrs = ((c.invisibleTagAttrs || \"style='position:absolute;left:-9999px;'\"));\n            var e, f, g;\n            if (c.urlEntities) {\n                e = {\n                };\n                for (f = 0, g = c.urlEntities.length; ((f < g)); f++) {\n                    e[c.urlEntities[f].url] = c.urlEntities[f];\n                ;\n                };\n            ;\n                c.urlEntities = e;\n            }\n        ;\n        ;\n            var i = \"\", j = 0;\n            b.sort(function(a, b) {\n                return ((a.indices[0] - b.indices[0]));\n            });\n            for (var f = 0; ((f < b.length)); f++) {\n                var k = b[f];\n                i += a.substring(j, k.indices[0]), ((k.url ? i += twttr.txt.linkToUrl(k, a, c) : ((k.hashtag ? i += twttr.txt.linkToHashtag(k, a, c) : ((k.screenName ? i += twttr.txt.linkToMentionAndList(k, a, c) : ((k.cashtag && (i += twttr.txt.linkToCashtag(k, a, c)))))))))), j = k.indices[1];\n            };\n        ;\n            return i += a.substring(j, a.length), i;\n        }, twttr.txt.autoLinkWithJSON = function(a, b, c) {\n            var d = [];\n            for (var e in b) {\n                d = d.concat(b[e]);\n            ;\n            };\n        ;\n            for (var f = 0; ((f < d.length)); f++) {\n                entity = d[f], ((entity.screen_name ? entity.screenName = entity.screen_name : ((entity.text && (entity.hashtag = entity.text)))));\n            ;\n            };\n        ;\n            return twttr.txt.modifyIndicesFromUnicodeToUTF16(a, d), twttr.txt.autoLinkEntities(a, d, c);\n        }, twttr.txt.extractHtmlAttrsFromOptions = function(a) {\n            var b = {\n            };\n            for (var c in a) {\n                var d = a[c];\n                if (q[c]) {\n                    continue;\n                }\n            ;\n            ;\n                ((r[c] && (d = ((d ? c : null)))));\n                if (((d == null))) {\n                    continue;\n                }\n            ;\n            ;\n                b[c] = d;\n            };\n        ;\n            return b;\n        }, twttr.txt.autoLink = function(a, b) {\n            var c = twttr.txt.extractEntitiesWithIndices(a, {\n                extractUrlWithoutProtocol: !1\n            });\n            return twttr.txt.autoLinkEntities(a, c, b);\n        }, twttr.txt.autoLinkUsernamesOrLists = function(a, b) {\n            var c = twttr.txt.extractMentionsOrListsWithIndices(a);\n            return twttr.txt.autoLinkEntities(a, c, b);\n        }, twttr.txt.autoLinkHashtags = function(a, b) {\n            var c = twttr.txt.extractHashtagsWithIndices(a);\n            return twttr.txt.autoLinkEntities(a, c, b);\n        }, twttr.txt.autoLinkCashtags = function(a, b) {\n            var c = twttr.txt.extractCashtagsWithIndices(a);\n            return twttr.txt.autoLinkEntities(a, c, b);\n        }, twttr.txt.autoLinkUrlsCustom = function(a, b) {\n            var c = twttr.txt.extractUrlsWithIndices(a, {\n                extractUrlWithoutProtocol: !1\n            });\n            return twttr.txt.autoLinkEntities(a, c, b);\n        }, twttr.txt.removeOverlappingEntities = function(a) {\n            a.sort(function(a, b) {\n                return ((a.indices[0] - b.indices[0]));\n            });\n            var b = a[0];\n            for (var c = 1; ((c < a.length)); c++) {\n                ((((b.indices[1] > a[c].indices[0])) ? (a.splice(c, 1), c--) : b = a[c]));\n            ;\n            };\n        ;\n        }, twttr.txt.extractEntitiesWithIndices = function(a, b) {\n            var c = twttr.txt.extractUrlsWithIndices(a, b).concat(twttr.txt.extractMentionsOrListsWithIndices(a)).concat(twttr.txt.extractHashtagsWithIndices(a, {\n                checkUrlOverlap: !1\n            })).concat(twttr.txt.extractCashtagsWithIndices(a));\n            return ((((c.length == 0)) ? [] : (twttr.txt.removeOverlappingEntities(c), c)));\n        }, twttr.txt.extractMentions = function(a) {\n            var b = [], c = twttr.txt.extractMentionsWithIndices(a);\n            for (var d = 0; ((d < c.length)); d++) {\n                var e = c[d].screenName;\n                b.push(e);\n            };\n        ;\n            return b;\n        }, twttr.txt.extractMentionsWithIndices = function(a) {\n            var b = [], c = twttr.txt.extractMentionsOrListsWithIndices(a);\n            for (var d = 0; ((d < c.length)); d++) {\n                mentionOrList = c[d], ((((mentionOrList.listSlug == \"\")) && b.push({\n                    screenName: mentionOrList.screenName,\n                    indices: mentionOrList.indices\n                })));\n            ;\n            };\n        ;\n            return b;\n        }, twttr.txt.extractMentionsOrListsWithIndices = function(a) {\n            if (((!a || !a.match(twttr.txt.regexen.atSigns)))) {\n                return [];\n            }\n        ;\n        ;\n            var b = [], c = 0;\n            return a.replace(twttr.txt.regexen.validMentionOrList, function(d, e, f, g, i, j, k) {\n                var l = k.slice(((j + d.length)));\n                if (!l.match(twttr.txt.regexen.endMentionMatch)) {\n                    i = ((i || \"\"));\n                    var m = a.indexOf(((((f + g)) + i)), c);\n                    c = ((((((m + g.length)) + i.length)) + 1)), b.push({\n                        screenName: g,\n                        listSlug: i,\n                        indices: [m,c,]\n                    });\n                }\n            ;\n            ;\n            }), b;\n        }, twttr.txt.extractReplies = function(a) {\n            if (!a) {\n                return null;\n            }\n        ;\n        ;\n            var b = a.match(twttr.txt.regexen.validReply);\n            return ((((!b || RegExp.rightContext.match(twttr.txt.regexen.endMentionMatch))) ? null : b[1]));\n        }, twttr.txt.extractUrls = function(a, b) {\n            var c = [], d = twttr.txt.extractUrlsWithIndices(a, b);\n            for (var e = 0; ((e < d.length)); e++) {\n                c.push(d[e].url);\n            ;\n            };\n        ;\n            return c;\n        }, twttr.txt.extractUrlsWithIndices = function(a, b) {\n            ((b || (b = {\n                extractUrlsWithoutProtocol: !0\n            })));\n            if (((!a || ((b.extractUrlsWithoutProtocol ? !a.match(/\\./) : !a.match(/:/)))))) {\n                return [];\n            }\n        ;\n        ;\n            var c = [];\n            while (twttr.txt.regexen.extractUrl.exec(a)) {\n                var d = RegExp.$2, e = RegExp.$3, f = RegExp.$4, g = RegExp.$5, i = RegExp.$7, j = twttr.txt.regexen.extractUrl.lastIndex, k = ((j - e.length));\n                if (!f) {\n                    if (((!b.extractUrlsWithoutProtocol || d.match(twttr.txt.regexen.invalidUrlWithoutProtocolPrecedingChars)))) {\n                        continue;\n                    }\n                ;\n                ;\n                    var l = null, m = !1, n = 0;\n                    g.replace(twttr.txt.regexen.validAsciiDomain, function(a) {\n                        var b = g.indexOf(a, n);\n                        n = ((b + a.length)), l = {\n                            url: a,\n                            indices: [((k + b)),((k + n)),]\n                        }, m = a.match(twttr.txt.regexen.invalidShortDomain), ((m || c.push(l)));\n                    });\n                    if (((l == null))) {\n                        continue;\n                    }\n                ;\n                ;\n                    ((i && (((m && c.push(l))), l.url = e.replace(g, l.url), l.indices[1] = j)));\n                }\n                 else ((e.match(twttr.txt.regexen.validTcoUrl) && (e = RegExp.lastMatch, j = ((k + e.length))))), c.push({\n                    url: e,\n                    indices: [k,j,]\n                });\n            ;\n            ;\n            };\n        ;\n            return c;\n        }, twttr.txt.extractHashtags = function(a) {\n            var b = [], c = twttr.txt.extractHashtagsWithIndices(a);\n            for (var d = 0; ((d < c.length)); d++) {\n                b.push(c[d].hashtag);\n            ;\n            };\n        ;\n            return b;\n        }, twttr.txt.extractHashtagsWithIndices = function(a, b) {\n            ((b || (b = {\n                checkUrlOverlap: !0\n            })));\n            if (((!a || !a.match(twttr.txt.regexen.hashSigns)))) {\n                return [];\n            }\n        ;\n        ;\n            var c = [], d = 0;\n            a.replace(twttr.txt.regexen.validHashtag, function(b, e, f, g, i, j) {\n                var k = j.slice(((i + b.length)));\n                if (k.match(twttr.txt.regexen.endHashtagMatch)) {\n                    return;\n                }\n            ;\n            ;\n                var l = a.indexOf(((f + g)), d);\n                d = ((((l + g.length)) + 1)), c.push({\n                    hashtag: g,\n                    indices: [l,d,]\n                });\n            });\n            if (b.checkUrlOverlap) {\n                var e = twttr.txt.extractUrlsWithIndices(a);\n                if (((e.length > 0))) {\n                    var f = c.concat(e);\n                    twttr.txt.removeOverlappingEntities(f), c = [];\n                    for (var g = 0; ((g < f.length)); g++) {\n                        ((f[g].hashtag && c.push(f[g])));\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            return c;\n        }, twttr.txt.extractCashtags = function(a) {\n            var b = [], c = twttr.txt.extractCashtagsWithIndices(a);\n            for (var d = 0; ((d < c.length)); d++) {\n                b.push(c[d].cashtag);\n            ;\n            };\n        ;\n            return b;\n        }, twttr.txt.extractCashtagsWithIndices = function(a) {\n            if (((!a || ((a.indexOf(\"$\") == -1))))) {\n                return [];\n            }\n        ;\n        ;\n            var b = [], c = 0;\n            return a.replace(twttr.txt.regexen.validCashtag, function(d, e, f, g) {\n                var i = a.indexOf(((\"$\" + e)), c);\n                c = ((((i + e.length)) + 1)), b.push({\n                    cashtag: e,\n                    indices: [i,c,]\n                });\n            }), b;\n        }, twttr.txt.modifyIndicesFromUnicodeToUTF16 = function(a, b) {\n            twttr.txt.convertUnicodeIndices(a, b, !1);\n        }, twttr.txt.modifyIndicesFromUTF16ToUnicode = function(a, b) {\n            twttr.txt.convertUnicodeIndices(a, b, !0);\n        }, twttr.txt.convertUnicodeIndices = function(a, b, c) {\n            if (((b.length == 0))) {\n                return;\n            }\n        ;\n        ;\n            var d = 0, e = 0;\n            b.sort(function(a, b) {\n                return ((a.indices[0] - b.indices[0]));\n            });\n            var f = 0, g = b[0];\n            while (((d < a.length))) {\n                if (((g.indices[0] == ((c ? d : e))))) {\n                    var i = ((g.indices[1] - g.indices[0]));\n                    g.indices[0] = ((c ? e : d)), g.indices[1] = ((g.indices[0] + i)), f++;\n                    if (((f == b.length))) {\n                        break;\n                    }\n                ;\n                ;\n                    g = b[f];\n                }\n            ;\n            ;\n                var j = a.charCodeAt(d);\n                ((((((((55296 <= j)) && ((j <= 56319)))) && ((d < ((a.length - 1)))))) && (j = a.charCodeAt(((d + 1))), ((((((56320 <= j)) && ((j <= 57343)))) && d++))))), e++, d++;\n            };\n        ;\n        }, twttr.txt.splitTags = function(a) {\n            var b = a.split(\"\\u003C\"), c, d = [], e;\n            for (var f = 0; ((f < b.length)); f += 1) {\n                e = b[f];\n                if (!e) d.push(\"\");\n                 else {\n                    c = e.split(\"\\u003E\");\n                    for (var g = 0; ((g < c.length)); g += 1) {\n                        d.push(c[g]);\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            return d;\n        }, twttr.txt.hitHighlight = function(a, b, c) {\n            var d = \"em\";\n            b = ((b || [])), c = ((c || {\n            }));\n            if (((b.length === 0))) {\n                return a;\n            }\n        ;\n        ;\n            var e = ((c.tag || d)), f = [((((\"\\u003C\" + e)) + \"\\u003E\")),((((\"\\u003C/\" + e)) + \"\\u003E\")),], g = twttr.txt.splitTags(a), i, j, k = \"\", l = 0, m = g[0], n = 0, o = 0, p = !1, q = m, r = [], s, t, u, v, w;\n            for (i = 0; ((i < b.length)); i += 1) {\n                for (j = 0; ((j < b[i].length)); j += 1) {\n                    r.push(b[i][j]);\n                ;\n                };\n            ;\n            };\n        ;\n            for (s = 0; ((s < r.length)); s += 1) {\n                t = r[s], u = f[((s % 2))], v = !1;\n                while (((((m != null)) && ((t >= ((n + m.length))))))) {\n                    k += q.slice(o), ((((p && ((t === ((n + q.length)))))) && (k += u, v = !0))), ((g[((l + 1))] && (k += ((((\"\\u003C\" + g[((l + 1))])) + \"\\u003E\"))))), n += q.length, o = 0, l += 2, m = g[l], q = m, p = !1;\n                ;\n                };\n            ;\n                ((((!v && ((m != null)))) ? (w = ((t - n)), k += ((q.slice(o, w) + u)), o = w, ((((((s % 2)) === 0)) ? p = !0 : p = !1))) : ((v || (v = !0, k += u)))));\n            };\n        ;\n            if (((m != null))) {\n                ((((o < q.length)) && (k += q.slice(o))));\n                for (s = ((l + 1)); ((s < g.length)); s += 1) {\n                    k += ((((((s % 2)) === 0)) ? g[s] : ((((\"\\u003C\" + g[s])) + \"\\u003E\"))));\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            return k;\n        };\n        var s = 140, t = [g(65534),g(65279),g(65535),g(8234),g(8235),g(8236),g(8237),g(8238),];\n        twttr.txt.getTweetLength = function(a, b) {\n            ((b || (b = {\n                short_url_length: 20,\n                short_url_length_https: 21\n            })));\n            var c = a.length, d = twttr.txt.extractUrlsWithIndices(a);\n            for (var e = 0; ((e < d.length)); e++) {\n                c += ((d[e].indices[0] - d[e].indices[1])), ((d[e].url.toLowerCase().match(/^https:\\/\\//) ? c += b.short_url_length_https : c += b.short_url_length));\n            ;\n            };\n        ;\n            return c;\n        }, twttr.txt.isInvalidTweet = function(a) {\n            if (!a) {\n                return \"empty\";\n            }\n        ;\n        ;\n            if (((twttr.txt.getTweetLength(a) > s))) {\n                return \"too_long\";\n            }\n        ;\n        ;\n            for (var b = 0; ((b < t.length)); b++) {\n                if (((a.indexOf(t[b]) >= 0))) {\n                    return \"invalid_characters\";\n                }\n            ;\n            ;\n            };\n        ;\n            return !1;\n        }, twttr.txt.isValidTweetText = function(a) {\n            return !twttr.txt.isInvalidTweet(a);\n        }, twttr.txt.isValidUsername = function(a) {\n            if (!a) {\n                return !1;\n            }\n        ;\n        ;\n            var b = twttr.txt.extractMentions(a);\n            return ((((b.length === 1)) && ((b[0] === a.slice(1)))));\n        };\n        var u = a(/^#{validMentionOrList}$/);\n        twttr.txt.isValidList = function(a) {\n            var b = a.match(u);\n            return ((((!!b && ((b[1] == \"\")))) && !!b[4]));\n        }, twttr.txt.isValidHashtag = function(a) {\n            if (!a) {\n                return !1;\n            }\n        ;\n        ;\n            var b = twttr.txt.extractHashtags(a);\n            return ((((b.length === 1)) && ((b[0] === a.slice(1)))));\n        }, twttr.txt.isValidUrl = function(a, b, c) {\n            ((((b == null)) && (b = !0))), ((((c == null)) && (c = !0)));\n            if (!a) {\n                return !1;\n            }\n        ;\n        ;\n            var d = a.match(twttr.txt.regexen.validateUrlUnencoded);\n            if (((!d || ((d[0] !== a))))) {\n                return !1;\n            }\n        ;\n        ;\n            var f = d[1], g = d[2], i = d[3], j = d[4], k = d[5];\n            return ((((((((((!c || ((e(f, twttr.txt.regexen.validateUrlScheme) && f.match(/^https?$/i))))) && e(i, twttr.txt.regexen.validateUrlPath))) && e(j, twttr.txt.regexen.validateUrlQuery, !0))) && e(k, twttr.txt.regexen.validateUrlFragment, !0))) ? ((((b && e(g, twttr.txt.regexen.validateUrlUnicodeAuthority))) || ((!b && e(g, twttr.txt.regexen.validateUrlAuthority))))) : !1));\n        }, ((((((typeof module != \"undefined\")) && module.exports)) && (module.exports = twttr.txt)));\n    })(), a();\n});\nprovide(\"setup\", function(a) {\n    using(\"util\").as(function(b) {\n        ((twttr.is.nil($.cookie(\"js\")) && $.cookie(\"js\", 1, {\n            expires: 30,\n            path: \"/\"\n        }))), twttr.setup = function(a) {\n            function c() {\n                var a = [\"webkit\",\"mozilla\",\"JSBNG__opera\",\"msie\",];\n                for (var b = 0; ((b < a.length)); b++) {\n                    if ($.browser[a[b]]) {\n                        return a[b];\n                    }\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n            $(\"body\").addClass(c()), ((twttr.hoversInCss || $(\".js-hover\").live(\"mouseenter mouseleave\", function(a) {\n                $(this).toggleClass(\"hover\", ((a.type == \"mouseenter\")));\n            }))), ((twttr.currentUser ? twttr.caches.User = new twttr.cache.local.User(twttr.currentUser.screenName) : twttr.caches.User = new twttr.cache.local.User($.cookie(\"guest_id\")))), twttr.app.init(a), twttr.$win = $(window), twttr.$doc = $(JSBNG__document), twttr.provide(\"twttr.$elements\", {\n                page: $(\"#page-outer\")\n            }), twttr.windowHeight = twttr.$win.height(), twttr[\"interface\"].setup(), twttr.ui.loadBar(), twttr.search.setup(), twttr.API.globalEvents.bind(\"rate_limited\", function(a) {\n                twttr.errors.showErrorFromCode(twttr.constants.errorCodes.dailyLimit);\n            }), twttr.API.globalEvents.bind(\"unknown_error\", function(a) {\n                twttr.errors.showErrorFromResponse({\n                });\n            }), using(twttr.bundleMore, function() {\n                var a = $(\"div.welcome-banner-outer\");\n                if (((a.length > 0))) {\n                    var b = twttr.banners.welcomeToPhoenix();\n                    b.bind(\"JSBNG__closed\", function() {\n                        $.cookie(((\"show_phx_welcome_\" + twttr.currentUser.id)), null);\n                    }), a.remove(), b.insert();\n                }\n            ;\n            ;\n                var c = $(\"div.became-user-banner-outer\");\n                ((((c.length > 0)) && (c.remove(), twttr.banners.becameUser().insert())));\n                var d = $(\"div.top-bar-inside,div.banner div.banner-inside\");\n                ((twttr.isT1 || twttr.$win.JSBNG__scroll(function() {\n                    d.css(\"left\", -twttr.$win.scrollLeft());\n                })));\n            }), twttr.router.bind(\"routed\", function(a, b) {\n                twttr.$win.scrollTop(0);\n            }), twttr.router.bind(\"urlChanged\", function(a, b) {\n                twttr.trackPageView(b.JSBNG__name);\n            }), twttr.router.bind(\"routeNotFound\", function() {\n                twttr.app.switchToPage(\"404\").send(\"notFound\");\n            }), twttr.router.startRouting(), ((twttr.decider.isInfiniteScroll() && b.util.lazyBind(window, \"JSBNG__scroll\", function(a) {\n                if (((((twttr.widget && twttr.widget.Dialog)) && twttr.widget.Dialog.currentModal))) {\n                    return;\n                }\n            ;\n            ;\n                var b = twttr.app.currentPage();\n                b.send(\"scrollEnd\", [twttr.$win.scrollTop(),]), ((((Math.abs(((((twttr.$doc.scrollTop() + twttr.windowHeight)) - twttr.$doc.height()))) < 500)) && b.send(\"getStreamManager\", function(a) {\n                    ((((a && !a.noInfiniteScroll)) && a.getMoreOldItems(function(a) {\n                        _scribble(\"stream-scrolled\", {\n                            page: a._page,\n                            stream: a._cacheKey,\n                            focused_tweet_id: ((a.focusedItemId || \"\"))\n                        });\n                    })));\n                })));\n            }))), ((twttr.isT1 || b.util.lazyBind(window, \"JSBNG__scroll\", function(a) {\n                twttr.app.currentPage().send(\"repositionDetailsPane\");\n            }, 100))), b.util.lazyBind(window, \"resize\", function(a) {\n                var b = twttr.app.currentPage();\n                twttr.windowHeight = twttr.$win.height(), ((b && b.send(\"resizeDetailsPane\"))), twttr.windowHeight = twttr.$win.height();\n            }), ((twttr.isT1 && using(\"idleDetector\", function(a) {\n                a({\n                    wait: 300000\n                });\n            }))), function() {\n                function a() {\n                    var a = $(this), b = parseInt(a.attr(\"data-time\"), 10);\n                    if (((((d - b)) > 86400000))) a.removeClass(\"_timestamp\").addClass(\"_old-timestamp\");\n                     else {\n                        var c = twttr.helpers.timeAgo(b, JSON.parse(((a.attr(\"data-long-form\") || \"false\"))), JSON.parse(((a.attr(\"data-include-sec\") || \"false\"))));\n                        ((((c !== a.text())) && a.text(c)));\n                    }\n                ;\n                ;\n                };\n            ;\n                function b() {\n                    var e = twttr.app.currentPage(), f = ((twttr.isT1 && twttr.at(\"widget.Dialog.currentModal\", twttr)));\n                    d = +(new JSBNG__Date), ((e && e.$find(((((\"span._timestamp[data-time$=\\\"\" + c)) + \"000\\\"]\"))).each(a))), ((f && f.$find(((((\"span._timestamp[data-time$=\\\"\" + c)) + \"000\\\"]\"))).each(a)));\n                    var g = ((+(new JSBNG__Date) - d));\n                    c++, c %= 10, JSBNG__setTimeout(b, 2000);\n                };\n            ;\n                var c = 0, d;\n                JSBNG__setTimeout(b, 2000);\n            }(), using([twttr.bundleMore,\"components/Autocomplete\",], function() {\n                twttr.API.User.bind(\"follow acceptFollow\", function(a, b) {\n                    twttr.currentUser.sync(\"friendsCount\", ++twttr.currentUser.friendsCount), twttr.components.Autocomplete.getAutocompletedUsers(function() {\n                        twttr.components.Autocomplete.addToList([b.id,b.screenName,b.JSBNG__name,b.profileImageUrl,]);\n                    }), $(JSBNG__document).trigger(\"currentUserUpdated\");\n                });\n            }), twttr.API.User.bind(\"unfollow\", function(a, b) {\n                twttr.currentUser.sync(\"friendsCount\", Math.max(--twttr.currentUser.friendsCount, 0)), $(JSBNG__document).trigger(\"currentUserUpdated\");\n            });\n            var d = $(\"#loading_indicator_container\");\n            d.fadeOut(\"fast\", function() {\n                d.remove(), JSBNG__document.body.style.overflow = \"\";\n            });\n        }, twttr.showError = function(a) {\n            return twttr.openMessageDrawer(a, \"error\");\n        }, twttr.showMessage = function(a, b) {\n            var c = twttr.openMessageDrawer(a, \"message\", {\n                close_button: !!b\n            });\n            ((((c && !b)) && JSBNG__setTimeout(function() {\n                c.$dom.css(\"opacity\", 1).animate({\n                    opacity: 0\n                }, 1000, function() {\n                    c.$dom.remove(), twttr.views.MessageDrawer.isOpen = !1;\n                });\n            }, 2000)));\n        }, function() {\n            var a = {\n                close_button: !0\n            };\n            twttr.openMessageDrawer = function(b, c, d) {\n                d = twttr.merge({\n                }, a, ((d || {\n                }))), d.text = b, d.type = c, twttr.views.MessageDrawer.close();\n                var e = new twttr.views.MessageDrawer(d);\n                return e.render(\"#message-drawer\", \"append\"), twttr.views.MessageDrawer.isOpen = !0, e;\n            };\n        }(), twttr.messageNotification = function(a) {\n            var b = new twttr.views.MessageNotification({\n                message: a.attributes\n            }), c = a.senderScreenName, d = a.id;\n            $(\"#message-notifications\").append(b.$html());\n            var e = $(((((\"#message-notifications [data-message-id=\" + d)) + \"].notification\")));\n            e.bind(\"click\", function() {\n                var a = $(this);\n                a.unbind(), a.JSBNG__find(\".message-notification-reply-box\").show();\n                var b = new twttr.Editor(((((\"#message-notifications [data-message-id=\" + d)) + \"].notification  .message-notification-reply-editor\")), function() {\n                    var a = this;\n                    this.JSBNG__focus(), this.height(36), $(((((\"#message-notifications [data-message-id=\" + d)) + \"].notification .message-notification-reply-button\"))).click(function() {\n                        e.html(\"Sent!\"), JSBNG__setTimeout(function() {\n                            e.remove();\n                        }, 2000), twttr.API.DirectMessage.send(c, a.JSBNG__content());\n                    });\n                });\n            });\n        }, twttr.provide(\"twttr.ui\", {\n            toggleSpinner: function(a, b) {\n                if (b) {\n                    var c = $(((((\"\\u003Cdiv class=\\\"loading-spinner\\\"\\u003E\\u003Cimg src=\\\"/phoenix/img/loader.gif\\\" alt=\\\"\" + _(\"Loading\"))) + \"\\\"/\\u003E\\u003C/div\\u003E\"))).appendTo(a);\n                }\n                 else {\n                    $(a).JSBNG__find(\"div.loading-spinner\").remove();\n                }\n            ;\n            ;\n            },\n            loadBar: function() {\n                var a = $(\"#global-actions\");\n                a.JSBNG__find(\"a\").not(\".js-dropdown-toggle\").each(function() {\n                    $(this).attr(\"href\", twttr.router.lookupAndNormalizeRoute($(this).attr(\"href\")));\n                }), ((twttr.loggedIn && a.delegate(\"a\", \"mousedown\", function(a) {\n                    var b = $(this);\n                    scribble(\"globalnav\", {\n                        input: \"click\",\n                        JSBNG__name: b.text(),\n                        href: b.attr(\"href\")\n                    });\n                })));\n            }\n        }), a(twttr.setup);\n    });\n});\nprovide(\"search\", function(a) {\n    using().as(function(b) {\n        twttr.search = {\n            setup: function() {\n                var a = this;\n                this.$searchQuery = $(\"#search-query\"), ((Modernizr.input.placeholder || (this.$searchQuery.bind({\n                    JSBNG__focus: function() {\n                        a.hidePlaceholder($(this));\n                    },\n                    JSBNG__blur: function() {\n                        a.showPlaceholder($(this));\n                    }\n                }), ((this.$searchQuery[0].hasFocus ? this.$searchQuery.addClass(\"focused\") : this.$searchQuery.JSBNG__blur()))))), ((twttr.isT1 ? (twttr.app.bind(\"switchToPage\", function(b, c) {\n                    a.updatePlaceholder(c);\n                }), this.attachTypeahead(), this.registerSearchInputEvents(), ((twttr.loggedIn && this.setupSavedSearches()))) : this.setupFocusP1()));\n            },\n            setupSavedSearches: function() {\n                if (!twttr.loggedIn) {\n                    return;\n                }\n            ;\n            ;\n                var a = this;\n                this.updateSavedSearches(), twttr.API.SavedSearch.bind(\"create delete\", function() {\n                    a.updateSavedSearches();\n                });\n            },\n            updateSavedSearches: function() {\n                var a = this;\n                twttr.currentUser.savedSearches(function(b) {\n                    ((((b.length() > 0)) ? (a.savedSearches = b, $(\".global-nav .js-search-form\").addClass(\"has-saved-searches\")) : $(\".global-nav .js-search-form\").removeClass(\"has-saved-searches\")));\n                });\n            },\n            updatePlaceholder: function(a) {\n                switch (a) {\n                  case \"connect\":\n                    this.setPlaceholder(_(\"Enter an @name or full name\"));\n                    break;\n                  case \"discover\":\n                    this.setPlaceholder(_(\"Enter a #hashtag or keyword\"));\n                    break;\n                  default:\n                    this.setPlaceholder();\n                };\n            ;\n            },\n            setPlaceholder: function(a) {\n                a = ((a || _(\"Search\"))), this.$searchQuery.attr(\"placeholder\", a), ((((!Modernizr.input.placeholder && this.$searchQuery.data(\"placeholding\"))) && this.$searchQuery.val(this.$searchQuery.attr(\"placeholder\")))), $(JSBNG__document).trigger(\"searchPlaceholderUpdate\", [a,]), this.$searchQuery.JSBNG__blur();\n            },\n            hidePlaceholder: function(a) {\n                ((a.data(\"placeholding\") && (a.val(\"\"), a.data(\"placeholding\", !1))));\n            },\n            showPlaceholder: function(a) {\n                ((((!a.data(\"placeholding\") && ((a.val() === \"\")))) && (a.data(\"placeholding\", !0), a.val(a.attr(\"placeholder\")))));\n            },\n            attachTypeahead: function() {\n                var a = this;\n                using(twttr.bundleMore, function() {\n                    a.$typeahead = new twttr.components.GlobalNavTypeahead;\n                });\n            },\n            queryWasEntered: function() {\n                return ((((this.$searchQuery.val() !== this.$searchQuery.attr(\"placeholder\"))) && ((this.$searchQuery.val() !== \"\"))));\n            },\n            setupFocusP1: function() {\n                var a = this;\n                this.$searchQuery.bind({\n                    JSBNG__focus: function() {\n                        $(this).addClass(\"focused\").select().closest(\"form\").addClass(\"focused\");\n                    },\n                    JSBNG__blur: function() {\n                        $(this).removeClass(\"focused\").closest(\"form\").removeClass(\"focused\");\n                    }\n                });\n            },\n            clear: function() {\n                this.focusQuery(\"\").JSBNG__blur();\n            },\n            isSavedSearch: function(a) {\n                if (!this.savedSearches) {\n                    return !1;\n                }\n            ;\n            ;\n                var b = this.savedSearches.filter(function(b) {\n                    return ((b.query === a));\n                });\n                return ((b.length() ? b.first() : !1));\n            },\n            setLastQuerySource: function(a) {\n                twttr.app.caches.searchQuerySource.set(\"source\", a, 60000);\n            },\n            getLastQuerySource: function() {\n                var a = twttr.app.caches.searchQuerySource.get(\"source\");\n                return ((a || twttr.search.searchQuerySource.UNKNOWN));\n            },\n            registerSearchInputEvents: function() {\n                var a = this;\n                $(\"span.js-search-action\").bind({\n                    mouseenter: function() {\n                        a.mouseOverMagnifying = !0;\n                    },\n                    mouseleave: function() {\n                        a.mouseOverMagnifying = !1;\n                    },\n                    click: function() {\n                        ((((!a.$searchQuery.data(\"placeholding\") && a.$searchQuery.val())) ? (twttr.search.setLastQuerySource(twttr.search.searchQuerySource.TYPED_QUERY), twttr.search.doSearch(), a.$searchQuery.JSBNG__blur(), twttr.widget.Dialog.trigger(\"close\")) : a.$searchQuery.JSBNG__focus()));\n                    }\n                }), this.$searchQuery.bind(\"JSBNG__focus\", function(b) {\n                    a.$searchQuery.addClass(\"JSBNG__focus\"), a.$searchQuery.siblings(\"#search-query-hint\").addClass(\"JSBNG__focus\"), a.$searchQuery.parent(\".js-search-form\").addClass(\"JSBNG__focus\");\n                }), this.$searchQuery.bind(\"JSBNG__blur\", function(b) {\n                    ((((!a.mouseOverMagnifying && !a.mouseIsOverTypeaheadDropdown())) && (a.$searchQuery.removeClass(\"JSBNG__focus\"), a.$searchQuery.siblings(\"#search-query-hint\").removeClass(\"JSBNG__focus\"), a.$searchQuery.parent(\".js-search-form\").removeClass(\"JSBNG__focus\"))));\n                });\n            },\n            mouseIsOverTypeaheadDropdown: function() {\n                return ((this.$typeahead && this.$typeahead.mouseOverDropDown));\n            },\n            focusQuery: function(a) {\n                return ((((!this.$searchQuery[0].hasFocus && !twttr.isT1)) && this.$searchQuery.JSBNG__focus())), ((twttr.is.def(a) && this.$searchQuery.val(a))), this.$searchQuery;\n            },\n            doSearch: function(a) {\n                var b = this.focusQuery(a).val();\n                if (b) {\n                    trackClient({\n                        section: \"top_nav\",\n                        component: \"searchbox\",\n                        action: \"search\"\n                    }, {\n                        query: b\n                    });\n                    var c = twttr.router.getCurrentRoute().JSBNG__name, d = ((twttr.isT1 && ((((twttr.app.currentPageName() == \"Connect\")) || ((c == \"userSearch\")))))), e = ((twttr.isT1 && ((c == \"searchTimeline\")))), f = ((twttr.isT1 && ((c == \"searchRealtime\"))));\n                    ((d ? twttr.router.routeTo(twttr.router.userSearchPath({\n                        query: b\n                    })) : ((e ? twttr.router.routeTo(twttr.router.searchTimelinePath({\n                        query: b\n                    })) : ((f ? twttr.router.routeTo(twttr.router.searchRealtimePath({\n                        query: b\n                    })) : twttr.router.routeTo(twttr.router.searchResultsPath({\n                        query: b\n                    }))))))));\n                }\n                 else this.$searchQuery.JSBNG__blur();\n            ;\n            ;\n            },\n            latestQuery: \"\",\n            formifyLatestQuery: function(a) {\n                var b = jQuery.trim(this.latestQuery).replace(/\\s+/, \" \");\n                if (b) {\n                    if (a.is(\".advanced-search form\")) {\n                        var c, d = /(|#|\\-|@|\\w+:|OR |AND )?\\\"([^\\\"]+)\\\"/i, e = function(b, c) {\n                            var d = {\n                                \"#\": \"tag\",\n                                \"-\": \"nots\",\n                                \"@\": \"ref\",\n                                \"to:\": \"to\",\n                                \"from:\": \"from\",\n                                \"near:\": \"near\",\n                                or: \"ors\",\n                                and: \"ands\"\n                            }, e = ((b ? d[jQuery.trim(b).toLowerCase()] : \"phrase\"));\n                            if (e) {\n                                var f = a.JSBNG__find(((((\"input[name=\" + e)) + \"]\"))), g = f.val();\n                                f.val(((((g ? ((g + \" \")) : \"\")) + c)));\n                            }\n                        ;\n                        ;\n                        };\n                        while (c = d.exec(b)) {\n                            ((((c && c[2])) && e(c[1], c[2]))), b = b.replace(c[0], \"\");\n                        ;\n                        };\n                    ;\n                        twttr.each(b.split(\" \"), function(b, d, f) {\n                            switch (b.toLowerCase()) {\n                              case \":)\":\n                            \n                              case \":(\":\n                            \n                              case \"?\":\n                                a.JSBNG__find(((((\"input[value=\\\"\" + b)) + \"\\\"]\"))).attr(\"checked\", \"checked\");\n                                break;\n                              case \"include:retweets\":\n                                a.JSBNG__find(\"input[name=include]\").attr(\"checked\", \"checked\");\n                                break;\n                              case \"\":\n                            \n                              case \"or\":\n                            \n                              case \"and\":\n                                break;\n                              default:\n                                c = /^(#|\\-|@|to:|from:|near:)(.*)/i.exec(b);\n                                if (((c && c[2]))) {\n                                    e(c[1], c[2]);\n                                    break;\n                                }\n                            ;\n                            ;\n                                c = /^within:(\\d+)(mi|km)*/i.exec(b);\n                                if (c) {\n                                    var g = a.JSBNG__find(\"select[name=within]\");\n                                    ((g.JSBNG__find(((((\"option[value=\" + c[1])) + \"]\"))) && g.val(c[1]))), ((c[2].match(/km/i) && a.JSBNG__find(\"input[name=units]\").each(function() {\n                                        var a = $(this);\n                                        a.attr(\"checked\", ((((a.val() == \"km\")) ? \"checked\" : \"\")));\n                                    })));\n                                    break;\n                                }\n                            ;\n                            ;\n                                c = /^lang:(\\w+)/i.exec(b);\n                                if (c) {\n                                    var i = a.JSBNG__find(\"select[name=lang]\");\n                                    ((i.JSBNG__find(((((\"option[value=\" + c[1])) + \"]\"))) && i.val(c[1])));\n                                    break;\n                                }\n                            ;\n                            ;\n                                ((((d && f[((d - 1))].match(/OR/i))) ? e(\"or\", b) : e(\"and\", b)));\n                            };\n                        ;\n                        });\n                    }\n                     else a.JSBNG__find(\"input[name=q]\").val(((b || \"\")));\n                ;\n                }\n            ;\n            ;\n            },\n            serializeAdvancedForm: function(a) {\n                var b = a.serializeArray(), c = [];\n                for (var d in b) {\n                    var e = b[d], f = jQuery.trim(e.value);\n                    if (!f) {\n                        continue;\n                    }\n                ;\n                ;\n                    switch (e.JSBNG__name) {\n                      case \"attd\":\n                    \n                      case \"ands\":\n                        c.push(f);\n                        break;\n                      case \"ors\":\n                        c.push(f.split(\" \").join(\" OR \"));\n                        break;\n                      case \"phrase\":\n                        c.push(((((\"\\\"\" + f)) + \"\\\"\")));\n                        break;\n                      case \"nots\":\n                        c.push(((\"-\" + f.split(\" \").join(\" -\"))));\n                        break;\n                      case \"tag\":\n                        c.push(((\"#\" + f.replace(/#+/g, \"\").split(\" \").join(\" OR #\"))));\n                        break;\n                      case \"from\":\n                        c.push(((\"from:\" + f.replace(/@+/g, \"\").split(\" \").join(\" OR from:\"))));\n                        break;\n                      case \"to\":\n                        c.push(((\"to:\" + f.replace(/@+/g, \"\").split(\" \").join(\" OR to:\"))));\n                        break;\n                      case \"ref\":\n                        c.push(((\"@\" + f.replace(/@+/g, \"\").split(\" \").join(\" OR @\"))));\n                        break;\n                      case \"near\":\n                        c.push(((((((((\"near:\\\"\" + f)) + \"\\\" within:\")) + a.JSBNG__find(\"select[name=within]\").val())) + a.JSBNG__find(\"input:radio[name=units]:checked\").val())));\n                        break;\n                      case \"include\":\n                        c.push(\"include:retweets\");\n                        break;\n                      case \"lang\":\n                        ((((f !== \"all\")) && c.push(((\"lang:\" + f)))));\n                    };\n                ;\n                };\n            ;\n                return c.join(\" \");\n            },\n            searchQuerySource: {\n                UNKNOWN: \"unknown\",\n                TYPED_QUERY: \"typed_query\",\n                HASHTAG: \"hashtag_click\",\n                TREND: \"trend_click\",\n                SAVED_SEARCH: \"saved_search_click\",\n                TYPEAHEAD: \"typeahead_click\",\n                SPELLING_CORRECTION: \"spelling_correction_click\",\n                RELATED_QUERY: \"related_query_click\"\n            },\n            urlParamQuerySource: {\n                UNKNOWN: \"unkn\",\n                TYPED_QUERY: \"typd\",\n                HASHTAG: \"hash\",\n                TREND: \"tren\",\n                SAVED_SEARCH: \"savs\",\n                TYPEAHEAD: \"tyah\",\n                SPELLING_CORRECTION: \"corr\",\n                RELATED_QUERY: \"rela\"\n            }\n        }, a(twttr.search);\n    });\n});\nprovide(\"helpers\", function(a) {\n    using(\"_\", \"util\", \"constants\", \"errors\").as(function(b, _) {\n        twttr.helpers = {\n            timeStrings: function() {\n                if (((twttr.at(\"QUnit\") || !twttr.helpers.timeStrings.memo))) {\n                    twttr.helpers.timeStrings.memo = {\n                        words: {\n                            longForm: {\n                                singular: {\n                                    now: _(\"now\"),\n                                    seconds: _(\"{{one}} second ago\"),\n                                    minutes: _(\"{{one}} minute ago\"),\n                                    hours: _(\"{{one}} hour ago\"),\n                                    days: _(\"{{one}} day ago\")\n                                },\n                                plural: {\n                                    now: _(\"now\"),\n                                    seconds: _(\"{{plural_number}} seconds ago\"),\n                                    minutes: _(\"{{plural_number}} minutes ago\"),\n                                    hours: _(\"{{plural_number}} hours ago\"),\n                                    days: _(\"{{plural_number}} days ago\")\n                                }\n                            },\n                            shortForm: {\n                                allCounts: {\n                                    now: _(\"now\"),\n                                    seconds: _(\"{{number}}s\"),\n                                    minutes: _(\"{{number}}m\"),\n                                    hours: _(\"{{number}}h\"),\n                                    days: _(\"{{number}}d\")\n                                }\n                            }\n                        },\n                        dates: {\n                            months: [_(\"Jan\"),_(\"Feb\"),_(\"Mar\"),_(\"Apr\"),_(\"May\"),_(\"Jun\"),_(\"Jul\"),_(\"Aug\"),_(\"Sep\"),_(\"Oct\"),_(\"Nov\"),_(\"Dec\"),],\n                            dates: [_(\"1st\"),_(\"2nd\"),_(\"3rd\"),_(\"4th\"),_(\"5th\"),_(\"6th\"),_(\"7th\"),_(\"8th\"),_(\"9th\"),_(\"10th\"),_(\"11th\"),_(\"12th\"),_(\"13th\"),_(\"14th\"),_(\"15th\"),_(\"16th\"),_(\"17th\"),_(\"18th\"),_(\"19th\"),_(\"20th\"),_(\"21st\"),_(\"22nd\"),_(\"23rd\"),_(\"24th\"),_(\"25th\"),_(\"26th\"),_(\"27th\"),_(\"28th\"),_(\"29th\"),_(\"30th\"),_(\"31st\"),]\n                        }\n                    };\n                }\n            ;\n            ;\n                return twttr.helpers.timeStrings.memo;\n            },\n            resolveHexColor: function(a) {\n                function b(a) {\n                    return parseInt(((a + a)).slice(0, 2), 16);\n                };\n            ;\n                if (((((!a || !a.match(/^#?([0-9A-F]{6}|[0-9A-F]{3})$/i))) || !RegExp.$1))) {\n                    return;\n                }\n            ;\n            ;\n                return RegExp.$1.match(/(..?)(..?)(..?)/), [b(RegExp.$1),b(RegExp.$2),b(RegExp.$3),];\n            },\n            hexToRGBA: function(a, b) {\n                var c = this.resolveHexColor(a);\n                if (!c) {\n                    return;\n                }\n            ;\n            ;\n                return c.push(((b || \"1\"))), ((((\"rgba(\" + c.join(\",\"))) + \")\"));\n            },\n            blendHexColor: function(a, b, c) {\n                var d = this.resolveHexColor(a), e = this.resolveHexColor(b), f = ((1 - c));\n                if (((!d || !e))) {\n                    return;\n                }\n            ;\n            ;\n                return twttr.map(d, function(a, b) {\n                    var d = e[b], g = Math.floor(((((a * c)) + ((d * f)))));\n                    return ((g + 256)).toString(16).slice(1);\n                }).join(\"\").toUpperCase();\n            },\n            sanitizeCssColor: function(a) {\n                if (((a && a.match(/^[0-9a-f]{3,6}$/i)))) {\n                    return a;\n                }\n            ;\n            ;\n            },\n            parseDateString: function(a) {\n                var b = new JSBNG__Date(a);\n                return (((($.browser.msie && a)) && (b = new JSBNG__Date(JSBNG__Date.parse(a.replace(/( \\+)/, \" UTC$1\")))))), +b;\n            },\n            prettyTime: function(a, b) {\n                var c = twttr.helpers.timeStrings(), d = new JSBNG__Date(a), e = {\n                    year4: d.getFullYear().toString(),\n                    year: d.getFullYear().toString().slice(2),\n                    month: c.dates.months[d.getMonth()],\n                    day: d.getDate(),\n                    hours24: d.getHours(),\n                    hours12: ((((d.getHours() % 12)) || 12)),\n                    minutes: d.getMinutes().toString().replace(/^(\\d)$/, \"0$1\"),\n                    amPm: ((((d.getHours() < 12)) ? _(\"AM\") : _(\"PM\"))),\n                    date: c.dates.dates[((d.getDate() - 1))]\n                };\n                return ((((twttr.isT1 && !b)) ? _(\"{{hours12}}:{{minutes}} {{amPm}} - {{day}} {{month}} {{year}}\", e) : _(\"{{hours12}}:{{minutes}} {{amPm}}, {{month}} {{date}}\", e)));\n            },\n            timeAgo: function(a, b, c, d) {\n                ((((twttr.decider.isExpando() && !d)) && (b = !1)));\n                var e = twttr.helpers.timeStrings(), f = e.words[((b ? \"longForm\" : \"shortForm\"))], g = new JSBNG__Date, i = new JSBNG__Date(a), j = ((g - i)), k = 1000, l = ((k * 60)), m = ((l * 60)), n = ((m * 24)), o = ((n * 7)), p, q, r;\n                return ((((isNaN(j) || ((j < 0)))) ? \"\" : (((((j < ((k * 3)))) ? (p = \"\", q = \"now\", c = !1) : ((((j < l)) ? (p = Math.floor(((j / k))), q = \"seconds\", c = !1) : ((((j < m)) ? (p = Math.floor(((j / l))), q = \"minutes\", c = !1) : ((((j < n)) ? (p = Math.floor(((j / m))), q = \"hours\", c = !1) : ((((j < ((n * 365)))) ? r = _(\"{{date}} {{month}}\", {\n                    date: i.getDate(),\n                    month: e.dates.months[i.getMonth()]\n                }) : r = _(\"{{date}} {{month}} {{year}}\", {\n                    date: i.getDate(),\n                    month: e.dates.months[i.getMonth()],\n                    year: i.getFullYear().toString().slice(2),\n                    year4: i.getFullYear().toString()\n                }))))))))))), ((r || (((f.allCounts ? f = f.allCounts : ((((p === 1)) ? f = f.singular : f = f.plural)))), r = Mustache.to_html(f[q], {\n                    JSBNG__one: p,\n                    number: p,\n                    plural_number: p\n                })))), ((c && (r += ((\" \" + _(\"at {{time}}\", {\n                    time: i.toTimeString().split(\":\").slice(0, 2).join(\":\")\n                })))))), r)));\n            },\n            timeAgoRounded: function(a) {\n                var b = new JSBNG__Date, c = new JSBNG__Date(a), d = ((b - c)), e = 1000, f = ((e * 60)), g = ((f * 60)), i = ((g * 24)), j = ((i * 7)), k = ((i * 30)), l = ((i * 365)), m;\n                return ((((isNaN(d) || ((d < 0)))) ? \"\" : (((((d <= ((f * 5)))) ? m = _(\"5 minutes\") : ((((d <= ((f * 15)))) ? m = _(\"15 minutes\") : ((((d <= ((f * 30)))) ? m = _(\"30 minutes\") : ((((d <= ((f * 45)))) ? m = _(\"45 minutes\") : ((((d <= g)) ? m = _(\"1 hour\") : ((((d <= ((g * 12)))) ? m = ((Math.floor(((d / g))) + _(\" hours\"))) : ((((d < ((g * 24)))) ? m = _(\"over 12 hours\") : ((((d <= ((i * 2)))) ? m = _(\"yesterday\") : ((((d <= ((i * 14)))) ? m = ((Math.floor(((d / i))) + _(\" days\"))) : ((((d < k)) ? m = _(\"over 2 weeks\") : ((((d < ((k * 2)))) ? m = _(\"over 1 month\") : ((((d < ((k * 3)))) ? m = _(\"over 2 months\") : ((((d < l)) ? m = _(\"over 6 months\") : ((((d < ((l * 2)))) ? m = _(\"over 1 year\") : m = _(\"over 2 years\"))))))))))))))))))))))))))))), m)));\n            },\n            transformProfileImageUrl: function(a, b) {\n                if (!twttr.is.string(a)) {\n                    return a;\n                }\n            ;\n            ;\n                ((((!b && a.match(/default_profile_\\d_normal.png$/))) && (b = \"bigger\")));\n                var c = /_normal(\\..*)?$/i;\n                return ((b ? a.replace(c, ((((\"_\" + b)) + \"$1\"))) : a.replace(c, \"$1\")));\n            },\n            isCurrentUser: function(a) {\n                return ((twttr.currentUser ? ((twttr.is.string(a) ? ((twttr.currentUser.screenName === a)) : ((twttr.is.object(a) ? ((a.id === twttr.currentUser.id)) : ((twttr.currentUser.id === a)))))) : !1));\n            },\n            isProfileUser: function() {\n                return ((twttr.profileUser && twttr.helpers.isCurrentUser(twttr.profileUser)));\n            },\n            userNoobLevel: function(a) {\n                var c = parseInt(twttr.Router.getCurrentQueryStringParams().nooblevel, 10);\n                if (!isNaN(c)) {\n                    return twttr.caches.User.set(\"noobLevel\", c), c;\n                }\n            ;\n            ;\n                var d = twttr.caches.User.get(\"noobLevel\");\n                if (((d < 0))) {\n                    return d;\n                }\n            ;\n            ;\n                var e = b.constants.noob;\n                return a = ((a || twttr.currentUser)), ((((a && twttr.decider.isAvailable(\"flock\"))) ? ((((a.statusesCount == 0)) ? ((((a.followersCount > 49)) ? e.notNoob : ((((a.friendsCount === 0)) ? ((a.followersCount ? e.invited : e.total)) : ((((a.followersCount || ((a.friendsCount > 9)))) ? e.silent : e.friendless)))))) : ((((((a.friendsCount > 9)) || ((((a.friendsCount === 0)) && ((a.followersCount > 49)))))) ? e.notNoob : ((((a.friendsCount === 0)) ? ((a.followersCount ? e.popular : e.talking)) : ((a.followersCount ? e.struggling : e.lonely)))))))) : e.notNoob));\n            },\n            canViewUser: function(a) {\n                return ((((((!a[\"protected\"] || a.following)) || this.isCurrentUser(a))) || ((twttr.is.def(twttr.isAdmin) && twttr.isAdmin))));\n            },\n            truncate: function(a, b, c) {\n                c = ((c || \"&hellip;\"));\n                var d = $(\"\\u003Cdiv/\\u003E\").html(c).text().length;\n                return ((((a.length > b)) && (a = ((a.slice(0, ((b - d))) + c))))), a;\n            },\n            displayUrl: function() {\n                var a = /^www\\./;\n                return function(c, d) {\n                    d = ((d || 16));\n                    var e = new b.util.Location(c), f = e.hostname.replace(a, \"\");\n                    ((((((e.port != 80)) && ((e.port != 443)))) && (f += ((\":\" + e.port)))));\n                    var g = ((((e.pathname + e.search)) + e.hash));\n                    return ((f + twttr.helpers.truncate(g, d, \"\\u2026\")));\n                };\n            }(),\n            getUserId: function(a) {\n                var b = parseInt(a.attr(\"data-user-id\"), 10);\n                return ((isNaN(b) ? 0 : b));\n            },\n            getUserIdentifier: function(a) {\n                var b = twttr.helpers.getUserId(a), c = a.attr(\"data-screen-name\");\n                return ((((((!b && !c)) && a.attr(\"hash\"))) && (c = twttr.router.findMatchingRoute(a.attr(\"hash\")).args.screen_name))), ((b || c));\n            },\n            parseEmailAddress: function(a) {\n                var c = b.constants.regexps.email.exec(a.replace(/^\\s+|\\s+$/g, \"\"));\n                return ((c ? c[0] : null));\n            },\n            extractEmailAddresses: function(a) {\n                return ((((a.indexOf(\"\\u003C\") == -1)) ? twttr.filter(twttr.map(a.split(\",\"), twttr.helpers.parseEmailAddress), function(a) {\n                    return !twttr.is.nil(a);\n                }) : [a,]));\n            },\n            handlePopupLinks: function(a) {\n                a.JSBNG__find(\".js-popup\").click(function(a) {\n                    a.preventDefault(), a.stopPropagation();\n                    var b = $(this);\n                    window.open(b.attr(\"href\"), ((b.attr(\"JSBNG__name\") || \"twttr_popup\")), b.attr(\"data-popup\"));\n                });\n            },\n            addFormEvents: function(a, c, d) {\n                d = ((d || {\n                })), a.bind(\"submit\", function(b) {\n                    if (a.hasClass(\"submitting\")) {\n                        b.preventDefault();\n                        return;\n                    }\n                ;\n                ;\n                    if (c) {\n                        b.preventDefault();\n                        var d = {\n                        };\n                        $.each($(this).serializeArray(), function() {\n                            ((d[this.JSBNG__name] ? (((d[this.JSBNG__name].push || (d[this.JSBNG__name] = [d[this.JSBNG__name],]))), d[this.JSBNG__name].push(((this.value || \"\")))) : d[this.JSBNG__name] = ((this.value || \"\"))));\n                        }), c.call(this, b, d);\n                    }\n                ;\n                ;\n                }).bind(\"keydown keypress\", function(c) {\n                    if (((c.ctrlKey || ((c.which == b.constants.keyCodes.escape))))) {\n                        return;\n                    }\n                ;\n                ;\n                    c.stopPropagation(), ((((((c.which == b.constants.keyCodes.enter)) && !$(c.target).is(\"textarea, [autocomplete=\\\"on\\\"]\"))) && (c.preventDefault(), c.target.JSBNG__blur(), a.submit())));\n                }), a.JSBNG__find(((((d.submitSelector || \"div.button.submit\")) + \", .js-submit\"))).attr(\"tabindex\", 0).click(function() {\n                    a.submit();\n                }), a.JSBNG__find(\"input:text, textarea\").bind(\"keydown\", function(a) {\n                    if (((a.which == b.constants.keyCodes.escape))) {\n                        this.JSBNG__blur();\n                        return;\n                    }\n                ;\n                ;\n                }).each(function() {\n                    var a = $(this), b = a.attr(\"placeholder\");\n                    if (((b && !Modernizr.input.placeholder))) {\n                        var c = !1;\n                        a.JSBNG__focus(function() {\n                            ((c && (a.val(\"\"), c = !1))), a.addClass(\"js-focused\").removeClass(\"js-placeholded placeholded\").select();\n                        }).JSBNG__blur(function() {\n                            ((((!c && ((a.val() === \"\")))) && (c = !0, a.val(b), a.addClass(\"js-placeholded placeholded\")))), a.removeClass(\"js-focused\");\n                        }), JSBNG__setTimeout(function() {\n                            a.JSBNG__blur();\n                        }, 0);\n                    }\n                ;\n                ;\n                });\n            },\n            addHoldingInputEvents: function(a) {\n                a.JSBNG__find(\"div.holding, div.placeholding-input\").each(function() {\n                    var a = $(this), b = a.JSBNG__find(\"input\");\n                    a.JSBNG__find(\"span\").click(function() {\n                        b.JSBNG__focus();\n                    }), b.JSBNG__blur(function() {\n                        ((b.val().length || a.removeClass(\"hasome\")));\n                    }), b.keydown(function(c) {\n                        JSBNG__setTimeout(function() {\n                            ((((((c && ((c.keyCode == 8)))) || b.val().length)) ? a.addClass(\"hasome\") : a.removeClass(\"hasome\")));\n                        }, 0);\n                    });\n                }), ((twttr.helpers._holdingInterval || (twttr.helpers._holdingInterval = window.JSBNG__setInterval(function() {\n                    $(\"form div.holding, form div.placeholding-input\").each(function() {\n                        var a = $(this), b = a.JSBNG__find(\"input\");\n                        ((((b.val() && b.val().length)) && a.addClass(\"hasome\")));\n                    });\n                }, 1111))));\n            },\n            chainAnimate: function(a, b, c, d) {\n                var e = 0;\n                (function() {\n                    var f = c[e++];\n                    if (twttr.is.def(f)) {\n                        var g = {\n                        };\n                        g[b] = f, a.animate(g, ((d || 100)), arguments.callee);\n                    }\n                ;\n                ;\n                })();\n            },\n            isModifier: function(a) {\n                return !!((((((a.shiftKey || a.metaKey)) || a.ctrlKey)) || a.altKey));\n            },\n            isTextOverflowEllipsisSupported: function() {\n                return ((\"textOverflow\" in $(\"\\u003Cdiv\\u003E\")[0].style));\n            },\n            ellipsify: function(a, b, c, d, e) {\n                if (c) {\n                    $(a).ellipsis(d, e);\n                    return;\n                }\n            ;\n            ;\n                return ((twttr.helpers.isTextOverflowEllipsisSupported() ? !1 : ($(a).each(function() {\n                    var a = $(this), c;\n                    if (a.hasClass(\"ellipsify-container\")) {\n                        if (!b) {\n                            return !0;\n                        }\n                    ;\n                    ;\n                        c = a.JSBNG__find(\"span.ellip-content\"), ((c.length && a.html(c.html())));\n                    }\n                ;\n                ;\n                    a.addClass(\"ellipsify-container\").wrapInner($(\"\\u003Cspan\\u003E\").addClass(\"ellip-content\")), c = a.JSBNG__find(\"span.ellip-content\");\n                    if (((c.width() > a.width()))) {\n                        var d = $(\"\\u003Cdiv class=\\\"ellip\\\"\\u003E&hellip;\\u003C/div\\u003E\");\n                        a.append(d), c.width(((a.width() - d.width()))).css(\"margin-right\", d.width());\n                    }\n                ;\n                ;\n                }), !0)));\n            },\n            showErrorFromResponse: function(a, b) {\n                return twttr.errors.showErrorFromResponse(a, b);\n            }\n        }, a(twttr.helpers);\n    });\n});\nprovide(\"errors\", function(a) {\n    using(\"constants\").as(function(b) {\n        function c(a, b, c) {\n            return {\n                regex: a,\n                errorCode: b,\n                requestRegex: c\n            };\n        };\n    ;\n        var d = [c(/not following/, b.constants.errorCodes.notFollowing),c(/duplicate|already said that/, b.constants.errorCodes.duplicateTweet),c(/malware/, b.constants.errorCodes.malwareTweet),c(/daily|only send so many/, b.constants.errorCodes.dailyLimit),c(/140/, b.constants.errorCodes.tooLongTweet),c(/(this account|User) has been suspended/, b.constants.errorCodes.otherUserSuspended),c(/suspend/, b.constants.errorCodes.suspended),c(/photo/, b.constants.errorCodes.photoTimeout),c(/unable to follow more people/, b.constants.errorCodes.followingLimitReached),c(/blocked from following/, b.constants.errorCodes.blockedFromFollowing),c(/list's name.+25 characters/, b.constants.errorCodes.tooLongListName),c(/list's description.+100 characters/, b.constants.errorCodes.tooLongListDescription),c(/list's name.+start with a letter/, b.constants.errorCodes.noLetterStartListName),c(/Not found/, b.constants.errorCodes.tweetNotFound, /statuses\\/retweet/),c(/No status found/, b.constants.errorCodes.tweetNotFound),c(/Not found/, b.constants.errorCodes.userNotFound),];\n        twttr.errors = {\n            errorCodeFromResponse: function(a) {\n                var c, e, f, g = ((((a.response && ((a.response.error || ((a.response.errors && a.response.errors[0].message)))))) || null));\n                if (g) {\n                    for (c = 0, e = d.length; ((c < e)); c++) {\n                        f = d[c];\n                        if (((f.regex.test(g) && ((!f.requestRegex || f.requestRegex.test(a.response.request)))))) {\n                            return f.errorCode;\n                        }\n                    ;\n                    ;\n                    };\n                }\n            ;\n            ;\n                return ((((a.JSBNG__status === 403)) ? b.constants.errorCodes.permission : b.constants.errorCodes.whale));\n            },\n            showErrorFromResponse: function(a, b) {\n                var c = twttr.errors.errorCodeFromResponse(a);\n                return twttr.errors.showErrorFromCode(c, b);\n            },\n            showErrorFromCode: function(a, b) {\n                var c = twttr.errors.getViewForErrorCode(a, b);\n                return twttr.showError(c.html()), a;\n            },\n            getViewForErrorCode: function(a, b) {\n                var c = ((twttr.views[a] || twttr.views.DefaultErrorMessage));\n                if (((!b || !/^(dm|(re)?tweet|(un)?follow|(un)?block|report|delete|(un)?favorite)$/.test(b)))) {\n                    b = \"generic\";\n                }\n            ;\n            ;\n                var d = {\n                };\n                return d[((\"is_\" + b))] = !0, new c(d);\n            }\n        }, a(twttr.errors);\n    });\n});\nprovide(\"viewHelpers\", function(a) {\n    using(\"_\").as(function(b, _) {\n        twttr.viewHelpers = {\n            addRelatedTweetsLogging: function(a, b, c) {\n                b.subcomponent = \"related-tweets\";\n                var d;\n                if (((a && (d = a.closest(\".related-tweets\")).length))) {\n                    var e = a.attr(\"data-tweet-id\");\n                    b.related_tweet_info = {\n                        impression_id: d.attr(\"data-related-impression-id\"),\n                        group_name: d.attr(\"data-related-group-name\"),\n                        annotations: d.attr(\"data-related-annotations\"),\n                        tweet_id: ((e ? e : \"0\"))\n                    };\n                    var f = d.attr(\"data-ab-data-bucket\");\n                    if (f) {\n                        var g = {\n                            bucket: f,\n                            experiment_key: d.attr(\"data-ab-data-experiment-key\"),\n                            version: d.attr(\"data-ab-data-version\")\n                        };\n                        scribble(c, g, \"www_ab_testing\");\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            },\n            addActivityItemLogging: function(a, b, c, d) {\n                b.streamType = \"activity-stream\", b.activityId = a.closest(\".stream-item\").attr(\"data-item-id\");\n            },\n            addExtraLogging: function(a, b, c) {\n                var d = a.closest(\".stream-tweet\"), e = twttr.app.currentPage();\n                ((((twttr.app.isOnPage(\"search\") && d.is(\".stream .stream-tweet\"))) ? using([twttr.bundleMore,\"components/pages/Search\",], function() {\n                    twttr.components.pages.Search.addSearchClickLogging(d, b);\n                }) : ((d.is(\"div.details-pane .related-tweets .stream-tweet\") ? twttr.viewHelpers.addRelatedTweetsLogging(d, b, c) : e.send(\"getStreamManager\", function(a) {\n                    if (a) {\n                        var e = a.getCurrent();\n                        using([twttr.bundleMore,\"streams/ActivityStream\",], function() {\n                            ((((e instanceof twttr.streams.ActivityStream)) && twttr.viewHelpers.addActivityItemLogging(d, b, c, e)));\n                        });\n                    }\n                ;\n                ;\n                })))));\n            }\n        }, a(twttr.viewHelpers);\n    });\n});\nprovide(\"components/Base\", function(a) {\n    using(\"util\").as(function(b) {\n        twttr.provide(\"twttr.components\"), twttr.klass.component = function(a, b) {\n            return twttr.klass(a, b).subclassOf(twttr.components.Base);\n        }, twttr.deprecateAccess(twttr.klass, \"component\", {\n            replacement: \"twttr.klass(...).subclassOf(twttr.components.Base)\",\n            now: 1313800194870,\n            daysRemaining: 30\n        }), $.fn.component = function() {\n            var a = $(this), b = a.parent();\n            return ((a.data(\"component\") || ((b.length && b.component()))));\n        }, twttr.klass(\"twttr.components.Base\", function() {\n            var a = ((!this.constructor._deciderKey || twttr.decider.isAvailable(this.constructor._deciderKey)));\n            ((((this.constructor._baseView && a)) ? this.$node = (new this.constructor._baseView(this.constructor._baseViewOptions)).$html() : this.$node = ((this.$node || $(\"\\u003Cdiv/\\u003E\").addClass(\"component\"))))), this.$node.addClass(\"component\").data(\"component\", this);\n            if (!a) {\n                ((this._decideredOff && this._decideredOff()));\n                return;\n            }\n        ;\n        ;\n            ((this.constructor._initializer && this.constructor._initializer.apply(this, arguments)));\n            if (twttr.isT1) {\n                var c = this.scribeComponentName;\n                ((c || ((((this.constructor && this.constructor._name)) && (c = b.util.underscore(this.constructor._name)))))), ((c && this.$node.attr(\"data-component-term\", c)));\n            }\n        ;\n        ;\n            this.initComponentEvents();\n        }).statics({\n            initializer: function(a) {\n                return a._owner = this, this._initializer = a, this;\n            },\n            destructor: function(a) {\n                return this._destructor = a, this;\n            },\n            deciderKey: function(a) {\n                return this._deciderKey = a, this;\n            },\n            setBaseView: function(a, b) {\n                return this._baseView = a, this._baseViewOptions = b, this;\n            },\n            setBaseViewOptions: function(a) {\n                return this._baseViewOptions = a, this;\n            }\n        }).mixin(twttr.mixins.componentEvents).methods(twttr.EventProvider).methods({\n            hasRendered: function() {\n                this._hasRendered = !0, ((((!this.noSpacer && !twttr.isT1)) && this.$node.append(\"\\u003Chr class='component-spacer' /\\u003E\")));\n            },\n            $find: function() {\n                return this.$node.JSBNG__find.apply(this.$node, arguments);\n            },\n            _superInitializer: function() {\n                var a = arguments.callee.caller._owner;\n                if (a) {\n                    var b = a.uberclass._initializer;\n                    ((b && b.apply(this, arguments)));\n                }\n            ;\n            ;\n            },\n            destroy: function() {\n                ((this.constructor._destructor && this.constructor._destructor.apply(this))), this.$node.remove(), this.trigger(\"destroyed\"), ((this._boundEvents && (twttr.each(this._boundEvents, function(a) {\n                    a.obj.unbind(a.JSBNG__name, a.cb);\n                }), this._boundEvents = []))), this.unbind();\n            },\n            _registerEvent: function(a, b, c) {\n                ((this._boundEvents || (this._boundEvents = []))), a.bind(b, c), this._boundEvents.push({\n                    obj: a,\n                    JSBNG__name: b,\n                    cb: c\n                });\n            }\n        }), a(twttr.components.Base);\n    });\n});\nprovide(\"idleDetector\", function(a) {\n    function b() {\n        var a = (new JSBNG__Date).getTime();\n        ((((!j && ((((a - k)) > g)))) && ($(JSBNG__document).trigger(\"inactive\"), JSBNG__clearInterval(l), j = !0)));\n    };\n;\n    function c() {\n        $(JSBNG__document).off(\".idleDetect\"), JSBNG__clearInterval(l), k = (new JSBNG__Date).getTime(), JSBNG__setTimeout(d, i), ((j && ($(JSBNG__document).trigger(\"active\"), j = !1)));\n    };\n;\n    function d() {\n        k = (new JSBNG__Date).getTime(), l = JSBNG__setInterval(b, i), $(JSBNG__document).JSBNG__on(m, c);\n    };\n;\n    function e() {\n        j = !0, $(JSBNG__document).off(\".idleDetect\"), JSBNG__clearInterval(l);\n    };\n;\n    function f(a) {\n        return a = $.extend({\n        }, {\n            wait: 300000,\n            heartBeat: 1000\n        }, a), g = a.wait, i = a.heartBeat, d(), {\n            deactivate: e\n        };\n    };\n;\n    var g, i, j = !0, k = 0, l = 0, m = \"mousemove.idleDetect keydown.idleDetect DOMMouseScroll.idleDetect mousewheel.idleDetect mousedown.idleDetect touchstart.idleDetect touchmove.idleDetect\";\n    a(f);\n});\nprovide(\"interface\", function(a) {\n    using(\"_\", \"util\", \"constants\").as(function(b, _) {\n        twttr.klass(\"twttr.Interface\").mixin(twttr.mixins.i18nTweetBox).methods({\n            enableRtl: function() {\n                twttr.i18n.rtl = !0, JSBNG__document.body.dir = \"rtl\";\n            },\n            setup: function() {\n                $(JSBNG__document).delegate(\"a[data-send-impression-cookie]\", \"click\", function(a) {\n                    var b = a.currentTarget;\n                    if (((((((!b || ((b.hostname != window.JSBNG__location.hostname)))) || !b.pathname)) || ((b.pathname.indexOf(\"/#!/\") == 0))))) {\n                        return;\n                    }\n                ;\n                ;\n                    var c = $(b), d = c.closest(\"[data-impression-cookie]\").attr(\"data-impression-cookie\");\n                    if (!d) {\n                        return;\n                    }\n                ;\n                ;\n                    var e = new JSBNG__Date, f = 60000, g = new JSBNG__Date(((e.getTime() + f)));\n                    $.cookie(\"ic\", d, {\n                        expires: g\n                    });\n                }), $(\"a[href$='#']\").live(\"click\", function(a) {\n                    a.preventDefault();\n                }), $(\".user-profile-link\").live(\"click\", twttr.scribbles.logViewProfileDetails), $(\"a[href^='/']\").live(\"click\", function(a) {\n                    if (((((((a.which == 1)) && !a.metaKey)) && !a.shiftKey))) {\n                        var b = $(this), c = b.attr(\"href\"), d = b.attr(\"target\");\n                        twttr.search.setLastQuerySource(((twttr.isT1 ? $(a.currentTarget).data(\"query-source\") : null)));\n                        if (((d && twttr.router.shouldRedirectTo(c)))) {\n                            return;\n                        }\n                    ;\n                    ;\n                        return twttr.router.routeTo(c), a.preventDefault(), !1;\n                    }\n                ;\n                ;\n                }), ((((((twttr.isT1 && twttr.i18n)) && $(\"body\").hasClass(\"rtl\"))) && this.enableRtl())), $(\"li.user-thumb-list-member img\").tipsy({\n                    live: !0,\n                    gravity: \"s\"\n                }), ((twttr.isT1 ? ($(\"div.promoted-account a.js-promoted-badge, div.promoted-account small.js-disclosure, div.promoted-tweet span.js-disclosure\").tipsy({\n                    live: !0,\n                    gravity: \"n\",\n                    delayIn: 500\n                }), $(\"li.promoted-trend span.js-disclosure\").tipsy({\n                    live: !0,\n                    gravity: \"s\",\n                    delayIn: 500\n                })) : ($(\"div.promoted-account a.icon-link, div.promoted-tweet a.icon-link, li.promoted-account a.icon-link\").tipsy({\n                    live: !0,\n                    gravity: \"n\",\n                    delayIn: 500\n                }), $(\"li.promoted-trend span.icon-link\").tipsy({\n                    live: !0,\n                    gravity: \"s\",\n                    delayIn: 500\n                }), $(\"form.js-search-form .js-search-action\").click(function(a) {\n                    $(\"form.js-search-form\").submit();\n                })))), $(\"div.tweet a.twitter-timeline-link\").live(\"mousedown\", function() {\n                    var a = $(this), b = {\n                    };\n                    ((a.is(\"div.dashboard a\") ? b.component = \"dashboard\" : ((a.is(\"div.details-pane a\") ? b.component = \"details-pane\" : ((a.is(\".stream-tweet a\") ? b.component = \"stream\" : ((a.is(\".twttr-dialog a\") && (b.component = \"dialog\", b.dialog_type = a.closest(\".twttr-dialog\").attr(\"type\")))))))))), twttr.viewHelpers.addExtraLogging(a, b, \"tweet-link\"), b.tweet_id = a.closest(\".tweet\").attr(\"data-tweet-id\"), b.input = \"click\", b.href = a.attr(\"href\"), b.text = a.text(), scribble(\"tweet-link\", b);\n                }), $(\"a.media-attribution-link\").live(\"mousedown\", function(a) {\n                    scribble(\"follow-attribution-link\", {\n                        component: \"inline-media\",\n                        input: \"click\",\n                        type: $(this).attr(\"data-media-type\")\n                    });\n                }), $(\"a.inline-media-image\").live(\"mousedown\", function(a) {\n                    scribble(\"open-inline-media-photo\", {\n                        component: \"inline-media\",\n                        input: \"click\",\n                        type: $(this).attr(\"data-media-type\")\n                    });\n                }), $(\"button.js-global-new-tweet,a.js-global-new-tweet\").click(function(a) {\n                    a.stopPropagation(), a.preventDefault(), using([twttr.bundleMore,\"widget/TweetDialog\",], function() {\n                        (new twttr.widget.TweetDialog({\n                            draggable: !0,\n                            template: {\n                                title: _(\"What&#8217;s happening?\")\n                            },\n                            enableDraft: \"global-tweetbox\",\n                            origin: \"new-tweet-titlebar-button\"\n                        })).open().JSBNG__focus();\n                    });\n                }).tipsy({\n                    gravity: \"n\",\n                    offset: 6\n                }), twttr.helpers.ellipsify($(\"#screen-name\")), $(\"a.js-close-all-tweets\").click(function() {\n                    $(\".tipsy\").remove(), twttr.app.currentPage().send(\"closeAllTweets\");\n                }).tipsy({\n                    gravity: \"ne\",\n                    delayIn: 500\n                }), $(\"form.js-search-form\").submit(function(a) {\n                    var b = $(\"#search-query\");\n                    ((b.val() && (twttr.search.setLastQuerySource(twttr.search.searchQuerySource.TYPED_QUERY), twttr.search.doSearch()))), a.preventDefault();\n                }), $(\"#message-drawer\").delegate(\".dismiss\", \"click\", function() {\n                    return twttr.views.MessageDrawer.close(), !1;\n                }), $(\"#message-drawer\").delegate(\".js-reload\", \"click\", function() {\n                    return window.JSBNG__location.reload(), !1;\n                }), $(\"a.js-signout-button\").click(function(a) {\n                    a.preventDefault(), twttr.cache.LocalProvider.clearAll(), ((window.JSBNG__localStorage && JSBNG__localStorage.clear())), trackClient({\n                        component: \"topnav\",\n                        action: \"logout\"\n                    }), ((twttr.decider.isAvailable(\"scribe_logout_reliability_events\") && ($(\"#signout-form .js-reliability-event\").attr(\"value\", \"true\"), trackClient({\n                        page: \"logout\",\n                        section: \"reliability\",\n                        component: \"client\",\n                        action: \"impression\"\n                    })))), $(\"#signout-form\").submit();\n                }), $(\"a.back-to-top\").live(\"click\", function(a) {\n                    return $(window).scrollTop(0), a.preventDefault(), !1;\n                }), $(\"a.sms-codes-link\").live(\"click\", function(a) {\n                    twttr.dialogs.smsCodes().open();\n                }), $(\"a.use-old-twitter\").live(\"click\", function(a) {\n                    $.cookie(((\"phx_seen_dialog-\" + twttr.currentUser.id)), null);\n                }), ((twttr.isT1 || $(\".contributor-account-link\").each(function(a) {\n                    var b = $(this), c = b.attr(\"data-profile-image-url\");\n                    ((c && (((((((window.JSBNG__location.protocol === \"https:\")) && twttr.cdnBase)) && (c = twttr.assets.getPathFromAbsoluteURL(c, {\n                        isSSL: !0,\n                        isVersioned: !1\n                    })))), b.JSBNG__find(\"img\").attr(\"src\", c))));\n                })));\n                var a = this;\n                $(\"#search-query\").bind(\"keyup keypress keydown\", function(b) {\n                    if (b.ctrlKey) {\n                        return;\n                    }\n                ;\n                ;\n                    a.markPunctuation(b, $(this)), b.stopPropagation();\n                });\n                var c = ((parseInt(b.util.params($.cookie(\"twll\")).l, 10) || 0));\n                twttr.verifySession = function() {\n                    var a = ((parseInt(b.util.params($.cookie(\"twll\")).l, 10) || 0));\n                    ((((a !== c)) && window.JSBNG__location.reload(!0)));\n                }, window.JSBNG__setInterval(function() {\n                    twttr.verifySession();\n                }, b.constants.sessionPollInterval), (($.browser.msie ? JSBNG__document.JSBNG__onfocusout = function() {\n                    twttr.verifySession(), twttr.externalURLStore.scribeFocusAfterClick();\n                } : $(window).JSBNG__focus(function() {\n                    twttr.verifySession(), twttr.externalURLStore.scribeFocusAfterClick();\n                }))), $(window).scrollTop(0);\n            }\n        }), twttr[\"interface\"] = new twttr.Interface, a(twttr[\"interface\"]);\n    });\n});\nprovide(\"run/topbarDropdown\", function(a) {\n    using().as(function(b) {\n        function c() {\n            if (((twttr.loggedIn && twttr.decider.isAvailable(\"api_verify_credentials_counts\")))) {\n                var a = $(\".dropdown-menu li[data-name='lists']\"), b = twttr.currentUser.counts.lists, c = function() {\n                    ((twttr.currentUser.hasLists() || a.hide()));\n                };\n                c(), twttr.API.List.bind(\"create follow\", function(c) {\n                    ((((c.type == \"create\")) ? b.owned += 1 : b.subscribed += 1)), a.show();\n                }), twttr.API.List.bind(\"delete unfollow\", function(a) {\n                    ((((a.type == \"delete\")) ? b.owned -= 1 : b.subscribed -= 1)), c();\n                });\n            }\n        ;\n        ;\n        };\n    ;\n        $(JSBNG__document).ready(function() {\n            function a() {\n                return ((twttr.app && twttr.app.isOnPage(\"login\")));\n            };\n        ;\n            var b = $(\".js-session\"), d = ((twttr.isT1 ? \"open\" : \"active\"));\n            b.click(function() {\n                ((a() ? twttr.router.routeTo(twttr.router.signupPath()) : (b.toggleClass(d), ((((!twttr.loggedIn && b.hasClass(d))) && b.JSBNG__find(\".username input\").JSBNG__focus())))));\n            }), $(JSBNG__document).bind(\"click\", function(a) {\n                var c = b.get(0);\n                ((((((c && ((a.target !== c)))) && !$.contains(c, a.target))) && b.removeClass(d)));\n            }).bind(\"keydown\", function(a) {\n                ((((a.keyCode === 27)) && b.removeClass(d)));\n            });\n            if (twttr.isT1) {\n                var e = $(\"li.js-language-dropdown\");\n                e.click(function(a) {\n                    e.toggleClass(\"open\"), a.preventDefault();\n                }), e.JSBNG__find(\".js-language-link\").bind(\"click\", function(a) {\n                    var b = e.JSBNG__find(\"form\");\n                    b.JSBNG__find(\"input[name=\\\"lang\\\"]\").val($(this).attr(\"data-lang-code\")), b.JSBNG__find(\"input[name=\\\"redirect\\\"]\").val(window.JSBNG__location.href), b.submit(), a.preventDefault(), a.stopPropagation();\n                });\n                var f = $(\"li.js-country-dropdown\");\n                f.click(function(a) {\n                    f.toggleClass(\"open\"), a.preventDefault();\n                }), f.JSBNG__find(\".js-country-link\").bind(\"click\", function(a) {\n                    var b = $(this);\n                    twttr.countryCode = b.attr(\"data-country-code\"), $.cookie(\"co\", twttr.countryCode, {\n                        domain: \".twitter.com\",\n                        path: \"/\",\n                        expires: 3650\n                    }), a.preventDefault(), a.stopPropagation(), JSBNG__location.reload();\n                }), $(\"a.js-dm-dialog\").click(function(a) {\n                    using([twttr.bundleMore,\"components/t1/DirectMessageDialog\",], function(a, b) {\n                        (new b).open();\n                    }), b.removeClass(d), a.stopPropagation(), a.preventDefault();\n                }), $(JSBNG__document).bind(\"click\", function(a) {\n                    var b = e.get(0);\n                    ((((((b && ((a.target !== b)))) && !$.contains(b, a.target))) && e.removeClass(d)));\n                    var c = f.get(0);\n                    ((((((c && ((a.target !== c)))) && !$.contains(c, a.target))) && f.removeClass(d)));\n                }).bind(\"keydown\", function(a) {\n                    ((((a.keyCode === 27)) && e.removeClass(d)));\n                }), c();\n            }\n        ;\n        ;\n            if (!twttr.loggedIn) {\n                $(\"#session \\u003E a\").attr(\"href\", \"#\");\n                var g = $(\"#signin-dropdown form\"), i = g.JSBNG__find(\"input\");\n                g.bind(\"click\", function(a) {\n                    a.stopPropagation();\n                }), g.bind(\"submit\", function(a) {\n                    if (twttr.app) {\n                        var b = ((twttr.app.isOnPage(\"mobile_gallery\") ? \"/\" : twttr.Router.getCurrentPath()));\n                        $(this).JSBNG__find(\"input[name=redirect_after_login]\").val(b);\n                    }\n                ;\n                ;\n                }), ((((JSBNG__navigator.userAgent.toLowerCase().indexOf(\"JSBNG__chrome\") > -1)) && i.each(function() {\n                    if (this.type.match(/text|password/)) {\n                        var a = $(this);\n                        a.clone().appendTo(a.parent()), a.remove();\n                    }\n                ;\n                ;\n                }))), ((twttr.helpers && twttr.helpers.addFormEvents(g))), i.bind(\"JSBNG__focus\", function() {\n                    ((a() ? twttr.app.currentPage().$find(\".username input\").JSBNG__focus() : b.addClass(d)));\n                });\n            }\n        ;\n        ;\n        }), a();\n    });\n});\nprovide(\"tco\", function(a) {\n    using().as(function(b) {\n        twttr.app.waitForSignal(\"init\", function() {\n            $(JSBNG__document.body).bind(\"copy\", twttr.bind(twttr.tco, twttr.tco.JSBNG__onCopy)), $(JSBNG__document.body).bind(\"aftercopy\", twttr.bind(twttr.tco, twttr.tco.JSBNG__onAfterCopy));\n        }), twttr.provide(\"twttr.tco\"), twttr.tco = {\n            shouldRefreshSelection: function() {\n                return !$.browser.msie;\n            },\n            JSBNG__onCopy: function(a) {\n                var b = twttr.tco.JSBNG__getSelection(), c;\n                ((this.shouldRefreshSelection() && (c = this.getCurrentRange())));\n                var d = ((b.anchorNode ? twttr.tco.nearestCommonAncestor(b.anchorNode, b.focusNode) : a.target));\n                if (!this.displayToTco(d)) {\n                    return;\n                }\n            ;\n            ;\n                window.JSBNG__setTimeout(function() {\n                    $(JSBNG__document.body).trigger(\"aftercopy\", [d,c,]);\n                }, 0);\n            },\n            linksForTarget: function(a) {\n                var b = $(a).JSBNG__find(\"a.twitter-timeline-link\");\n                return ((((a.tagName.toLowerCase() === \"a\")) && b.push(a))), b;\n            },\n            nearestCommonAncestor: function(a, b) {\n                if (((a == b))) {\n                    return a.parentNode;\n                }\n            ;\n            ;\n                var c = $.makeArray($(a).parents()).reverse().concat(a), d = $.makeArray($(b).parents()).reverse().concat(b), e = 0;\n                while (((c[e] == d[e]))) {\n                    e++;\n                ;\n                };\n            ;\n                return c[((e - 1))];\n            },\n            isFirstChild: function(a, b) {\n                while (((a != b))) {\n                    if (((a != a.parentNode.childNodes[0]))) {\n                        return !1;\n                    }\n                ;\n                ;\n                    a = a.parentNode;\n                };\n            ;\n                return !0;\n            },\n            isLastChild: function(a, b) {\n                while (((a != b))) {\n                    var c = a.parentNode.childNodes;\n                    if (((a != c[((c.length - 1))]))) {\n                        return !1;\n                    }\n                ;\n                ;\n                    a = a.parentNode;\n                };\n            ;\n                return !0;\n            },\n            displayToTco: function(a) {\n                var b = this, c = !1, d = twttr.tco.getCurrentRange(), e = ((d.focusNode ? $(d.focusNode).text().length : undefined)), f = twttr.tco.linksForTarget(a);\n                return $(f).each(function(a, f) {\n                    var g = $(f), i = g.attr(\"data-expanded-url\");\n                    if (!i) {\n                        return;\n                    }\n                ;\n                ;\n                    var j = ((d.focusNode && !!$(f).has(d.focusNode).length));\n                    if (j) {\n                        var k = twttr.tco.isFirstChild(d.focusNode, f), l = twttr.tco.isLastChild(d.focusNode, f), m = ((((k && ((d.focusOffset == 0)))) || ((l && ((d.focusOffset == e))))));\n                        if (!m) {\n                            return !1;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    ((((g.text().indexOf(\"pic.twitter.com/\") === 0)) && (i = g.attr(\"href\").replace(/t\\.co/, \"pic.twitter.com\")))), g.data(\"original-child-nodes\", $.map(f.childNodes, function(a) {\n                        return a;\n                    })), g.empty(), g.text(i), ((((j && ((d.focusOffset > 0)))) && b.adjustTextSelectionEndpoint())), c = !0;\n                }), c;\n            },\n            tcoToDisplay: function(a) {\n                var b = twttr.tco.linksForTarget(a);\n                $(b).each(function(a, b) {\n                    var c = $(b), d = c.data(\"original-child-nodes\");\n                    ((d && (c.empty().append(d), c.data(\"original-child-nodes\", null))));\n                });\n            },\n            getCurrentRange: function() {\n                var a = twttr.tco.JSBNG__getSelection();\n                return {\n                    anchorNode: a.anchorNode,\n                    anchorOffset: a.anchorOffset,\n                    focusNode: a.focusNode,\n                    focusOffset: a.focusOffset\n                };\n            },\n            JSBNG__onAfterCopy: function(a, b, c) {\n                this.tcoToDisplay(b), ((c && this.updateSelection(c)));\n            },\n            adjustTextSelectionEndpoint: function() {\n                var a = twttr.tco.JSBNG__getSelection(), b = JSBNG__document.createRange(), c = ((((a.focusNode.nodeType == 3)) ? a.focusNode.length : a.focusNode.childNodes.length));\n                b.setStart(a.anchorNode, a.anchorOffset), b.setEnd(a.focusNode, c), a.removeAllRanges(), a.addRange(b);\n            },\n            JSBNG__getSelection: function() {\n                return ((window.JSBNG__getSelection ? window.JSBNG__getSelection() : JSBNG__document.selection.createRange()));\n            },\n            updateSelection: function(a) {\n                var b = twttr.tco.JSBNG__getSelection(), c = JSBNG__document.createRange();\n                c.setStart(a.anchorNode, a.anchorOffset), c.setEnd(a.focusNode, a.focusOffset), ((((((((((c.startOffset === c.endOffset)) && ((c.anchorNode === c.focusNode)))) && ((c.anchorNode !== a.anchorNode)))) && ((c.focusNode !== a.focusNode)))) && (c.setStart(a.focusNode, a.focusOffset), c.setEnd(a.anchorNode, a.anchorOffset)))), b.removeAllRanges(), b.addRange(c);\n            }\n        }, a(twttr.tco);\n    });\n});\nprovide(\"streams/TweetStream\", function(a) {\n    using().as(function(b) {\n        var c = {\n            ACTIVE: 30000,\n            INACTIVE: 90000\n        }, d = c.ACTIVE;\n        $(window).JSBNG__focus(function() {\n            d = c.ACTIVE;\n        }), $(window).JSBNG__blur(function() {\n            d = c.INACTIVE;\n        }), twttr.tweetStream = function(a, b) {\n            ((b || (b = function() {\n                twttr.streams.TweetStream.apply(this, arguments);\n            })));\n            var c = twttr.stream(a, b);\n            return c.subclassOf(twttr.streams.TweetStream), c.prototype._updateMethod = function() {\n            \n            }, c.update = function(a) {\n                return this.prototype._updateMethod = a, this;\n            }, c.every = function(a) {\n                return this.prototype._interval = ((a * 1000)), this;\n            }, c.setTitle = function(a) {\n                return this.prototype._setTitle = a, this;\n            }, c.deciderKey = function(a) {\n                return c._deciderKey = a, c;\n            }, c.pollingDeciderKey = function(a) {\n                return c._pollingDeciderKey = a, c;\n            }, c;\n        }, twttr.klass(\"twttr.streams.TweetStream\", function() {\n            var a = this;\n            twttr.streams.Stream.apply(this, arguments), twttr.API.User.bind(\"block\", function(b, c) {\n                a.blockTweetsBy(c);\n            }), twttr.API.User.bind(\"unblock\", function(b, c) {\n                a.blockTweetsBy(c, !0);\n            }), this.bind(\"didTweet\", function(b, c) {\n                a.fetchTweets(function(a) {\n                    a.render();\n                });\n            }), this.registerTweetActionEvents(), this.registerUserActionEvents(), this.updateI18nDisplay(), this.periodicUpdater = null, this.scribbler = twttr.Scribbler.clientEvent;\n        }).subclassOf(twttr.streams.Stream).mixin(twttr.mixins.tweetActionable, twttr.mixins.i18nTweet, twttr.mixins.userActionable, twttr.mixins.promotedTweetStream, twttr.mixins.streamablePageWithInlineMedia).methods(twttr.EventProvider).methods({\n            itemViewClass: \"StreamTweet\",\n            streamItemType: \"tweet\",\n            _expandable: !0\n        }).methods({\n            _fetchCount: function() {\n            \n            },\n            _fetchMoreCount: function() {\n                return 20;\n            },\n            convertToStatus: function(a) {\n                return new twttr.API.Status(a);\n            },\n            afterFirstSwitchingTo: function(a) {\n                var b = this, c = new JSBNG__Date;\n                ((this._attachedTweetBarEvent || (this._attachedTweetBarEvent = !0, this.dom().delegate(\".js-new-tweets-bar\", \"click\", function() {\n                    b._showNewItems();\n                })))), this.startPeriodicFetcher(), this._loadedStreamOnce = !0;\n                if (this.preRendered) {\n                    ((twttr.bootTimings && (twttr.bootTimings.add(\"tweets_visible\", twttr.tweetsVisibleTime), twttr.bootTimings.done()))), (((($(this.streamManagerDomNodeSelector).JSBNG__find(\"div.stream-end\").length == 1)) && (this._alreadyMarkedEnd = !0))), this.items = [], this.itemIds = {\n                    };\n                    var d = this.$node.JSBNG__find(\"div.js-stream-tweet, div.stream-tweet\"), e = twttr.promotedTweetStore.getTweetInfo();\n                    storedPromotedTweetId = null, ((((e && e.data.promoted_status)) ? storedPromotedTweetId = e.data.promoted_status.id_str : ((e && (storedPromotedTweetId = e.data.id_str))))), d.each(function(a, c) {\n                        var f = $(c), g, i, j, k, l, m, n;\n                        g = JSON.parse(f.attr(\"data-status\"));\n                        if (((storedPromotedTweetId === g.id_str))) {\n                            g = e.data, i = g.promoted_content.impression_id, f.attr(\"data-impression-id\", i);\n                            var o = ((g.id_str + \"-promoted\"));\n                            f.parent().attr(\"data-item-id\", o).attr(\"id\", ((\"stream-item-tweet-\" + o)));\n                        }\n                         else ((f.attr(\"data-impression-id\") && (k = d[((a + 1))], ((k && (l = $(k).attr(\"data-tweet-id\"), j = !!f.JSBNG__find(\"i.badge-political\").length, twttr.promotedTweetStore.setTweetInfo(l, g, j)))))));\n                    ;\n                    ;\n                        n = b.convertToStatus(g), m = new twttr.views.StreamTweet(n), m.wakeUp(), b.items.push(n), b.markAsRendered(n);\n                    }), ((((this.items.length == 0)) && (this.noMoreOldItems = !0))), this.updateI18nDisplay(), this.wokeUp(), this.JSBNG__onGotInitialResults(this.items), this._updateSinceId(this.items), this.logPromotedImpressions(this.items), this.addInlineMediaIcons(this.$node, function() {\n                        b._scribeTweetImpressions();\n                    }), using(\"\\u003EallCodeLoaded\", function() {\n                        b.addActivityByFriendsToTweets(b.items);\n                    });\n                }\n                 else this.isLoadingMore(), this.fetchTweets(!0, function(c, d) {\n                    c.render(), ((twttr.tweetsVisibleTime || (twttr.tweetsVisibleTime = new JSBNG__Date))), ((twttr.bootTimings && (twttr.bootTimings.add(\"tweets_visible\"), twttr.bootTimings.done()))), ((twttr.util.params().show_time && twttr.showMessage(((((\"Stream loaded at \" + ((((+(new JSBNG__Date) - JSBNG__document.startTime)) / 1000)))) + \"s\"))))), c.doneLoadingMore(), ((((d !== twttr.streams.SUCCESS)) ? b._showError(d) : b.fetchUntilScreenIsFull())), ((a ? a() : $.noop)), b._scribeTweetImpressions();\n                });\n            ;\n            ;\n            },\n            fetchUntilScreenIsFull: function() {\n                var a = this;\n                ((((((!this.noMoreOldItems && this._isInDOM())) && this._shorterThanWindow())) && this.getMoreOldItems(function(b, c) {\n                    ((((c !== twttr.streams.SUCCESS)) ? a._showError(c) : a.fetchUntilScreenIsFull()));\n                })));\n            },\n            _isInDOM: function() {\n                return jQuery.contains(JSBNG__document.body, this.$node[0]);\n            },\n            _shorterThanWindow: function() {\n                return ((this.$node.height() < twttr.windowHeight));\n            },\n            afterSwitchingToAgain: function(a) {\n                this.fetchTweets(twttr.bind(this, function(b) {\n                    var c = this.newItemsCount;\n                    ((((this.newItemsCount > 0)) && this._showNewItems())), this.restartFetcher();\n                    if (!twttr.isT1) {\n                        var d = this.getFirstItem();\n                        this.highlightItem(d);\n                    }\n                ;\n                ;\n                    ((a ? a() : $.noop));\n                }));\n            },\n            _getStreamWhaleText: function() {\n                return _(\"Loading Tweets seems to be taking a while.\");\n            },\n            streamItemId: function(a) {\n                return ((a.impressionId ? ((a.id + \"-promoted\")) : a.id));\n            },\n            blockTweetsBy: function(a, b) {\n                var c = ((((this.constructor._name === \"User\")) && ((this.screenName === a.screenName)))), d = ((this.constructor._name === \"Search\"));\n                if (((c || d))) {\n                    return;\n                }\n            ;\n            ;\n                var e = this.$find(((((\".stream-item [data-screen-name=\\\"\" + a.screenName)) + \"\\\"]\"))).parent();\n                e[((b ? \"addClass\" : \"removeClass\"))](\"blocked\");\n            },\n            JSBNG__onTweetActionDelete: function(a) {\n                this.remove(a);\n                for (var b = 0; ((b < this.items.length)); b++) {\n                    ((((this.items[b].id === a)) && this.items.splice(b, 1)));\n                ;\n                };\n            ;\n            },\n            JSBNG__onTweetActionHide: function(a) {\n                this.selectedItem(a).hide();\n            },\n            JSBNG__onTweetActionShow: function(a) {\n                this.selectedItem(a).show();\n            },\n            beforeShowNewItems: function() {\n                var a;\n                ((this.keepPromotedTweetsAtTop ? a = this.$find(\".js-original-tweet:not(.promoted-tweet)\").first().closest(\".js-stream-item\") : a = this.$find(\".js-stream-item\").first())), this.$find(\".last-new-tweet\").removeClass(\"last-new-tweet\"), a.addClass(\"first-old-tweet\");\n                if (a.hasClass(\"expanding-stream-item\")) {\n                    var b = a.css(\"margin-bottom\");\n                    ((b && a.css(\"margin-top\", b)));\n                }\n            ;\n            ;\n            },\n            separateOldAndNewTweets: function() {\n                var a = this.$find(\".first-old-tweet\").removeClass(\"first-old-tweet\").first(), b = a.prev().addClass(\"last-new-tweet\");\n                ((a.is(\".expanding-stream-item.open\") && b.addClass(\"before-expanded\")));\n            },\n            JSBNG__onShowNewItems: function(a) {\n                this.updateI18nDisplay();\n                var b = this;\n                this.addInlineMediaIcons(a, function() {\n                    b._scribeTweetImpressions();\n                }), this.separateOldAndNewTweets(), this.$find(\".js-new-tweets-bar\").remove();\n            },\n            JSBNG__onShowOldItems: function(a) {\n                this.updateI18nDisplay();\n                var b = this;\n                this.addInlineMediaIcons(a, function() {\n                    b._scribeTweetImpressions();\n                });\n            },\n            addActivityByFriendsToTweets: function(a) {\n                if (((((!twttr.currentUser || !twttr.decider.isActivityEnabled())) || !twttr.decider.isAvailable(\"activity_social_context\")))) {\n                    return;\n                }\n            ;\n            ;\n                var b = this, c = {\n                }, d = {\n                };\n                return $.each(a, function(a, b) {\n                    c[b.id] = {\n                        retweeters: [],\n                        favoriters: []\n                    }, ((b.wasRetweeted && (c[b.id].retweeters.push(b.retweetingStatus.user), d[b.retweetingStatus.user.id] = !0)));\n                }), this.activityByFriendIntersection(a, c, d);\n            },\n            activityByFriendIntersection: function(a, b, c) {\n                var d = this;\n                this.loadFriends(function(e) {\n                    var f = {\n                    }, g = {\n                    };\n                    $.each(a, function(a, b) {\n                        if (!b.activities) {\n                            return;\n                        }\n                    ;\n                    ;\n                        $.each(b.activities.favoriters, function(a, c) {\n                            if (!e[c]) {\n                                return;\n                            }\n                        ;\n                        ;\n                            ((g[c] || (g[c] = []))), g[c].push(b.id);\n                        }), $.each(b.activities.retweeters, function(a, d) {\n                            if (((!e[d] || c[d]))) {\n                                return;\n                            }\n                        ;\n                        ;\n                            ((f[d] || (f[d] = []))), f[d].push(b.id);\n                        });\n                    });\n                    var i = twttr.util.arrayUniq(twttr.util.objKeys(g).concat(twttr.util.objKeys(f))).slice(0, twttr.constants.users.maxLookupSize);\n                    twttr.API.User.findAll(i, {\n                        stringifiedIds: !0,\n                        success: function(a) {\n                            a.each(function(a) {\n                                faves = g[a.id], retweets = f[a.id], ((faves && $.each(faves, function(c, d) {\n                                    b[d].favoriters.push(a);\n                                }))), ((retweets && $.each(retweets, function(c, d) {\n                                    b[d].retweeters.push(a);\n                                })));\n                            }), d.appendActivities(b);\n                        },\n                        error: function() {\n                            d.appendActivities(b);\n                        }\n                    });\n                });\n            },\n            appendActivities: function(a) {\n                for (tweetId in a) {\n                    var b = a[tweetId], c = this.$node.JSBNG__find(((((\".stream-item[data-item-id='\" + tweetId)) + \"']\")));\n                    ((b.retweeters.length && (new twttr.views.StreamActivity({\n                        items: b.retweeters,\n                        item_type: \"retweets\"\n                    })).render(c.JSBNG__find(\".tweet-activity-retweets\"), \"html\"))), ((((!b.retweeters.length && b.favoriters.length)) && (new twttr.views.StreamActivity({\n                        items: b.favoriters,\n                        item_type: \"favorites\"\n                    })).render(c.JSBNG__find(\".tweet-activity-favorites\"), \"html\")));\n                };\n            ;\n            },\n            loadFriends: function() {\n                var a;\n                return function(b) {\n                    if (a) {\n                        return b(a);\n                    }\n                ;\n                ;\n                    twttr.currentUser.friendIds(function(c) {\n                        a = twttr.inject(c, {\n                        }, function(a, b, c) {\n                            return a[c] = !0, a;\n                        }), b(a);\n                    });\n                };\n            }(),\n            JSBNG__onGotInitialResults: function(a) {\n                var b = a.slice(this.newItemsCount);\n                twttr.streams.Stream.prototype.JSBNG__onGotInitialResults.apply(this, arguments), this.addActivityByFriendsToTweets(b);\n            },\n            JSBNG__onGotNewItems: function(a) {\n                twttr.streams.Stream.prototype.JSBNG__onGotNewItems.apply(this, arguments), this.addActivityByFriendsToTweets(a);\n            },\n            JSBNG__onGotOldItems: function(a) {\n                twttr.streams.Stream.prototype.JSBNG__onGotOldItems.apply(this, arguments), this.addActivityByFriendsToTweets(a);\n            },\n            _scribeTweetImpressions: function() {\n                var a = this;\n                ((twttr.abdecider.chooseWithoutImpression(\"tweet_anatomy_2_231\") && a.$node.JSBNG__find(\"div.js-stream-tweet\").each(function(b, c) {\n                    c = $(c), ((c.height() && a._itemDetailsScribe(\"impression\", \"tweet\", c)));\n                })));\n            },\n            _scribeResults: function(a, b, c) {\n                this._scribeEmptyResults(a, b, c);\n                if (b.length) {\n                    var d = [], e;\n                    twttr.each(b, function(a, b) {\n                        var c;\n                        d.push(a.id), ((((a.isPromoted && a.isPromoted())) ? c = {\n                            item_type: twttr.constants.clientEvent.itemType.promotedTweet,\n                            item_token: a.impressionId\n                        } : ((((a.resultCategory == \"popular\")) && (c = {\n                            item_type: twttr.constants.clientEvent.itemType.popularTweet\n                        }))))), ((c && (e = ((e || {\n                        })), c.item_position = b, e[a.id] = c)));\n                    }), this.scribbler.scribe({\n                        component: \"stream\",\n                        action: \"results\"\n                    }, {\n                        item_ids: d,\n                        item_count: d.length,\n                        event_value: d.length,\n                        cursor_or_page: this._sinceId,\n                        item_details: e,\n                        referring_event: a\n                    });\n                }\n            ;\n            ;\n            },\n            beforeSwitchingAway: function() {\n                this.stopPeriodicFetcher(), this.trigger(\"switchingAway\");\n            },\n            _fetchItems: function(a) {\n                this.fetchTweets(!0, a);\n            },\n            fetchTweets: function(a, b, c) {\n                ((twttr.is.fn(a) && (c = b, b = a, a = !1)));\n                if (((this.preRendered && this._alreadyMarkedEnd))) {\n                    b(this, twttr.streams.SUCCESS);\n                    return;\n                }\n            ;\n            ;\n                if (((!twttr.decider.isAvailable(\"tweet_streams\") || ((this.constructor._deciderKey && !twttr.decider.isAvailable(this.constructor._deciderKey)))))) {\n                    b(this, twttr.streams.DECIDER);\n                    return;\n                }\n            ;\n            ;\n                var d = this, e = twttr.audit.trail(), f = ((a ? this._optionsForOld(b) : this._optionsForNew(b)));\n                c = ((c || {\n                })), f = twttr.merge(c, f), ((twttr.decider.isAvailable(\"platform_enable_cards\") && (f.include_cards = 1))), f.include_entities = 1, f.include_available_features = 1, f.contributor_details = ((!e[1] || ((e[1].page !== \"welcome\")))), this._updateMethod(f, this.params, b);\n            },\n            _idForTweet: function(a) {\n                return ((a.wasRetweeted ? a.retweetingStatus.id : a.id));\n            },\n            _optionsForNew: function(a) {\n                var b = this, c = {\n                    success: function(c) {\n                        ((((c instanceof twttr.API.util.BaseCollection)) && (c = c.array))), c = b.cleanStream(c);\n                        var d = !b.items.length;\n                        b.unshift(c), b._updateSinceId(c), ((((d && b.items.length)) && b.switchEndOfStreamMarker())), ((a && a(b, twttr.streams.SUCCESS)));\n                    },\n                    error: function(c) {\n                        ((((c.JSBNG__status === 502)) ? a(b, twttr.streams.WHALE) : a(b, twttr.streams.ERROR))), b._scribeResults(\"error\", [], {\n                            status_code: c.JSBNG__status\n                        });\n                    }\n                };\n                return ((this.items.length && (c.since_id = this._sinceId))), c;\n            },\n            _updateSinceId: function(a) {\n                ((twttr.is.array(a) || (a = Array.prototype.slice.call(arguments))));\n                for (var b = 0; ((b < a.length)); b++) {\n                    var c = a[b], d = this._idForTweet(c);\n                    if (((!c.isPromoted() && ((c.resultCategory !== \"popular\"))))) {\n                        ((((twttr.natcompare(d, ((this._sinceId || \"0\"))) > 0)) && (this._sinceId = d)));\n                        return;\n                    }\n                ;\n                ;\n                };\n            ;\n            },\n            _streamMaxId: function() {\n                for (var a = ((this.items.length - 1)); ((a >= 0)); a--) {\n                    if (!this.items[a].isPromoted()) {\n                        return this._idForTweet(this.items[a]);\n                    }\n                ;\n                ;\n                };\n            ;\n            },\n            cleanStream: function(a) {\n                return a = this._filterMutedUsers(a), a = this._filterDeletedTweets(a), a = this._filterOutRetweets(a), a;\n            },\n            _filterOutRetweets: function(a) {\n                return ((twttr.currentUser ? twttr.filter(a, function(a) {\n                    return ((a.wasRetweeted ? a : a));\n                }) : a));\n            },\n            _filterMutedUsers: function(a) {\n                ((twttr.decider.isAvailable(\"muteUsers\") || a));\n                if (((twttr.currentUser && ((this.constructor._name == \"Home\"))))) {\n                    var b = twttr.caches.User.get(\"muted\");\n                    a = twttr.filter(a, function(a) {\n                        if (((((!twttr.is.def(b) || ((a.wasRetweeted && !twttr.is.def(b[a.retweetingStatus.user.id]))))) || ((!a.wasRetweeted && !twttr.is.def(b[a.user.id])))))) {\n                            return a;\n                        }\n                    ;\n                    ;\n                    });\n                }\n            ;\n            ;\n                return a;\n            },\n            _filterDeletedTweets: function(a) {\n                return twttr.filter(a, function(a) {\n                    if (!twttr.app.caches.deletedTweets.get(a.id)) {\n                        return a;\n                    }\n                ;\n                ;\n                });\n            },\n            _optionsForOld: function(a) {\n                var b = this, c = {\n                    success: function(d) {\n                        ((((d instanceof twttr.API.util.BaseCollection)) && (d = d.array))), ((c.max_id && (d = twttr.filter(d, function(a) {\n                            return ((a.id !== c.max_id));\n                        })))), d = b.cleanStream(d), b.push(d), b._updateSinceId(d), ((d.length || b.reachedTheEnd())), ((a && a(b, twttr.streams.SUCCESS)));\n                    },\n                    error: function(c) {\n                        ((((c.JSBNG__status === 502)) ? a(b, twttr.streams.WHALE) : a(b, twttr.streams.ERROR)));\n                    },\n                    timeout: function(a) {\n                        a.retry();\n                    },\n                    cancel: function() {\n                        a(b, twttr.streams.TIMEOUT);\n                    }\n                };\n                return ((this.items.length ? (c.max_id = this._streamMaxId(), c.count = ((this._fetchMoreCount() + 1))) : ((this._fetchCount() && (c.count = this._fetchCount()))))), c;\n            },\n            _getInterval: function() {\n                return d;\n            },\n            startPeriodicFetcher: function() {\n                if (((((this.periodicUpdater || !twttr.decider.isAvailable(\"tweet_streams_polling\"))) || ((this.constructor._pollingDeciderKey && !twttr.decider.isAvailable(this.constructor._pollingDeciderKey)))))) {\n                    return;\n                }\n            ;\n            ;\n                this.periodicUpdater = JSBNG__setTimeout(twttr.bind(this, this.fetchNewTweetsThenPoll), this._getInterval());\n            },\n            fetchNewTweetsThenPoll: function() {\n                var a = {\n                    headers: {\n                        \"X-Twitter-Polling\": !0\n                    },\n                    interval: this._getInterval()\n                };\n                this.fetchTweets(twttr.bind(this, function(a) {\n                    var b = a.newItemsCount;\n                    ((((b > 0)) && (this.showNewTweetsBar(b), this.trigger(\"newTweets\", [a,b,]))));\n                }), a), this.restartFetcher();\n            },\n            stopPeriodicFetcher: function() {\n                ((this.periodicUpdater && (JSBNG__clearTimeout(this.periodicUpdater), this.periodicUpdater = null)));\n            },\n            restartFetcher: function() {\n                this.stopPeriodicFetcher(), this.startPeriodicFetcher();\n            },\n            addInlineMediaIcons: function(a, b) {\n                using([twttr.bundleMore,\"media/Iconifier\",], function() {\n                    new twttr.media.Iconifier(a, b);\n                }), using([twttr.bundleMore,\"stork\",], function() {\n                    if (a) {\n                        var b = a.JSBNG__find(\".js-stream-items\");\n                        ((b.length || (b = a.closest(\".js-stream-items\")))), twttr.stork.storkifyTweets(b);\n                    }\n                ;\n                ;\n                });\n            },\n            showNewTweetsBar: function(a) {\n                var b = this.$find(\".js-new-tweets-bar\"), c = (new twttr.views.NewTweetsBar({\n                    count: a,\n                    is_tweet: !0\n                })).$html();\n                ((((b.length > 0)) ? ((twttr.isT1 ? b.parent() : b)).replaceWith(c) : c.hide().prependTo(this.dom()).slideDown()));\n            },\n            screen_name: function() {\n                return this.params.screenName;\n            },\n            _getUserStreamErrorComponent: function(a) {\n                return this.wokeUp(), ((((a === twttr.streams.PROTECTED)) ? new twttr.components.ProtectedUser({\n                    screen_name: this.params.screenName\n                }) : this.constructor.uber._getStreamErrorComponent.apply(this, arguments)));\n            },\n            wokeUp: function() {\n                signal(\"\\u003EwokeUp\");\n            }\n        }), a(twttr.streams.TweetStream);\n    });\n});\nprovide(\"streams/Home\", function(a) {\n    using().as(function(b) {\n        twttr.tweetStream(\"twttr.streams.Home\", function() {\n            var a = this;\n            twttr.streams.TweetStream.apply(this, arguments), this.unbind(\"didTweet\"), this.bind(\"didTweet\", function(b, c) {\n                a.fetchTweets(function(b, d) {\n                    if (((((d != twttr.streams.WHALE)) && ((d != twttr.streams.ERROR))))) {\n                        a.insertTweetIfNotPresent(c);\n                        var e = a.$node.JSBNG__find(\".js-stream-item:first\"), f = ((e.length > 0)), g = ((f && e.position().JSBNG__top));\n                        b._showNewItems(\"insert\");\n                        if (f) {\n                            var i = e.position().JSBNG__top, j = twttr.$win.scrollTop();\n                            $(\"html, body\").scrollTop(((j + ((i - g)))));\n                        }\n                    ;\n                    ;\n                        b._showOldItems(!0);\n                    }\n                ;\n                ;\n                });\n            });\n        }).update(function(a, b, c) {\n            a.pc = !0, twttr.currentUser.homeTimeline(a);\n        }).methods({\n            JSBNG__onShowNewItems: function(a) {\n                this.constructor.uber.JSBNG__onShowNewItems.apply(this, arguments), this.logPromotedImpressions(this.items.slice(0, this.newItemsCount));\n            },\n            JSBNG__onShowOldItems: function(a) {\n                this.constructor.uber.JSBNG__onShowOldItems.apply(this, arguments), this.logPromotedImpressions(this.items.slice(((this.items.length - this.oldItemsCount)))), ((twttr.streams.Home.scribeTweetDensity && (this._scribeTweetDensity(a), twttr.streams.Home.scribeTweetDensity = !1)));\n            },\n            _scribeTweetDensity: function(a) {\n                var b = a.JSBNG__find(\".js-stream-tweet\"), c = {\n                };\n                if (((b.length < 10))) {\n                    return;\n                }\n            ;\n            ;\n                for (var d = 0; ((d < 10)); ++d) {\n                    var e = b.eq(d), f = e.attr(\"data-user-id\");\n                    ((c[f] ? c[f]++ : c[f] = 1));\n                };\n            ;\n                var g = 0, i = null, j = 0, k = 0;\n                $.each(c, function(a, b) {\n                    ((((b > g)) && (g = b, i = a))), j += ((b * ((b - 1))));\n                    var c = ((b / 10));\n                    k += ((c * Math.log(((1 / c)))));\n                });\n                var l = ((1 - ((j / 90))));\n                k /= Math.log(10), scribble(\"welcome-timeline-stats\", {\n                    density: g,\n                    density_leader: i,\n                    diversity: l,\n                    entropy: k\n                });\n            },\n            _fetchCount: function() {\n                return null;\n            },\n            _fetchMoreCount: function() {\n                return 20;\n            },\n            _getStreamEndComponent: function() {\n                return this.constructor.uber._getStreamEndComponent.apply(this, arguments);\n            },\n            insertTweetIfNotPresent: function(a) {\n                ((((a instanceof twttr.API.Status)) || (a = new twttr.API.Status(a))));\n                var b = this.cleanStream([a,]);\n                if (((b && !this.hasTweet(a)))) {\n                    var c = this.insertionIndexOfTweet(a);\n                    this.splice(c, b), this.newItemsCount++, ((((c == 0)) && this._updateSinceId(b))), this.JSBNG__onInsertItems(b);\n                }\n            ;\n            ;\n            },\n            hasTweet: function(a) {\n                for (var b = 0, c = this.items.length; ((b < c)); b++) {\n                    if (((this.items[b].id == a.id))) {\n                        return !0;\n                    }\n                ;\n                ;\n                };\n            ;\n                return !1;\n            },\n            insertionIndexOfTweet: function(a) {\n                for (var b = 0, c = this.items.length; ((b < c)); b++) {\n                    if (!this.items[b].isPromoted()) {\n                        var d = a.id, e = this.items[b].id;\n                        if (((twttr.natcompare(d, e) >= 0))) {\n                            return b;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                };\n            ;\n                return b;\n            }\n        }).deciderKey(\"tweet_stream_home\").pollingDeciderKey(\"tweet_stream_home_polling\"), ((twttr.isT1 ? twttr.streams.Home.methods({\n            _setTitle: function(a) {\n                a(_(\"Tweets\"));\n            },\n            _getEmptyStreamHtml: function() {\n                return (new twttr.views.EmptyTimelineMessage).html();\n            }\n        }) : twttr.streams.Home.methods({\n            _getEmptyStreamComponent: function() {\n                var a = new twttr.components.EmptyHome, b = \"newItemsCountChanged.EmptyHomeComponent\", c = this;\n                return this.bind(b, function(d, e) {\n                    ((((!e && !c.isEmpty())) && (a.destroy(), c.unbind(b), c._alreadyMarkedEnd = !1, c.markStreamEnd())));\n                }), a;\n            }\n        }))), a();\n    });\n});\nprovide(\"streams/StreamManager\", function(a) {\n    using(\"_\", \"mixins/serverRenderableObject\").as(function(b, _, c) {\n        var d = twttr.klass(\"twttr.streams.StreamManager\", function(a, b) {\n            var c = this, d = \"\";\n            if (a) {\n                var e = ((a + \"-stream-manager\"));\n                d = ((((\" id=\\\"\" + e)) + \"\\\"\")), this.domNodeSelector = ((\"#\" + e));\n            }\n        ;\n        ;\n            this.$node = this.$domNode(((((\"\\u003Cdiv class=\\\"js-stream-manager\\\" \" + d)) + \"\\u003E\\u003Cdiv class=\\\"stream-title\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"stream-container\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"))), this.$page = ((b || $())), ((twttr.decider.isInfiniteScroll() || (this.$moreButton = (new twttr.views.MoreButton).$html().appendTo(this.$node).click(function(a) {\n                c.getMoreOldItems(function(a) {\n                    scribble(\"stream-more-button\", {\n                        page: a._cacheKey,\n                        stream: a._cacheKey,\n                        focused_tweet_id: ((a.focusedItemId || \"\"))\n                    });\n                }), a.stopPropagation(), a.preventDefault();\n            })))), this.resetCache(), ((((twttr.loggedIn && ((twttr.decider.isAvailable(\"route_timing\") || twttr.util.params().routetimer)))) && (c.bind(\"switchingToStream didNotSwitch\", function(a, b) {\n                twttr.RouteTimer.streamSwitch(b);\n            }), c.bind(\"afterSwitchingTo\", function(a, b, c) {\n                twttr.RouteTimer.streamAfterSwitch(b, c);\n            })))), ((window.ttft && c.bind(\"afterSwitchingTo\", function() {\n                window.ttft.clientRendered(twttr.app.currentPageName());\n            })));\n        }).statics({\n            cacheKeyForStream: function(a) {\n                return a._cacheKey;\n            },\n            cacheKeyForStreamClass: function(a, b) {\n                var c = a._name;\n                if (((b && !$.isEmptyObject(b)))) {\n                    var d = twttr.filter(b, function(a, b) {\n                        return ((!twttr.is.fn(b) && !twttr.is.object(b)));\n                    });\n                    c += JSON.stringify(d);\n                }\n            ;\n            ;\n                return encodeURIComponent(c);\n            }\n        }).methods(twttr.EventProvider).mixin(c).methods({\n            $find: function() {\n                return this.$node.JSBNG__find.apply(this.$node, arguments);\n            },\n            getCurrent: function() {\n                return this.streams.current;\n            },\n            setCurrent: function(a) {\n                this.streams.current = a;\n            },\n            getStream: function(a, b) {\n                var c = twttr.streams.StreamManager.cacheKeyForStreamClass(a, b);\n                return this.streams[c];\n            },\n            JSBNG__onSwitchAway: function() {\n                var a = this.getCurrent();\n                ((a && a.beforeSwitchingAway()));\n            },\n            switchOut: function() {\n                var a = this.getCurrent();\n                ((a && (a.beforeSwitchingAway(), a.dom().detach()))), this.$headerContainer().empty(), this.titleContainer().empty();\n            },\n            switchTo: function(a, b, c) {\n                var d = null;\n                ((((b && ((b.initialItems !== undefined)))) && (d = b.initialItems, delete b.initialItems)));\n                var e = this, f = twttr.streams.StreamManager.cacheKeyForStreamClass(a, b), g = this.getCurrent(), i, j = !1, k = function(a) {\n                    return function() {\n                        e.trigger(\"afterSwitchingTo\", [a,j,]), ((c && c.apply(this, arguments)));\n                    };\n                };\n                _scribble(\"stream-view\", {\n                    stream_name: a._name\n                }), b = ((b || {\n                }));\n                if (g) {\n                    var l = twttr.streams.StreamManager.cacheKeyForStream(g);\n                    if (((l === f))) {\n                        return this.trigger(\"didNotSwitch\", g), j = !0, g.afterSwitchingToAgain(k(g)), g;\n                    }\n                ;\n                ;\n                    this.switchOut();\n                }\n            ;\n            ;\n                this.trigger(\"switchTo\"), ((((this.streams[f] && ((!d || b.cacheWithInitialItems)))) ? (i = this.streams[f], j = !0) : (i = new a(b, d, this), i._cacheKey = f, i.bind(\"newItemsCountChanged\", twttr.bind(this, function(a, b) {\n                    ((((i === this.getCurrent())) && this.trigger(\"newItemsCountChanged\", [b,])));\n                })), i.bind(\"reloadCurrentStream\", twttr.bind(this, function(a, b) {\n                    i.unbindEvents(), this.clearFromCache(b), this.$node.JSBNG__find(\"div.stream-container\").empty(), delete this.streams.current, this.switchTo(b);\n                })), i.bind(\"notFound\", twttr.bind(this, function(a) {\n                    this.trigger(\"notFound\");\n                })), ((i._shouldCache && (this.streams[f] = i))), i.bind(\"governmentSearch\", function(a, b) {\n                    twttr.router.routeTo(twttr.router.governmentSearchByZipPath({\n                        zipCode: b\n                    }));\n                })))), this.trigger(\"switchingToStream\", i);\n                var m = this.$node.JSBNG__find(\"div.stream-container\");\n                ((((m.has(i.$node).length === 0)) && m.prepend(i.$node))), this.setHeader(i, b);\n                if (e.$moreButton) {\n                    function n() {\n                        e.$moreButton.toggle(((!i._alreadyMarkedEnd && !i._errorComponent)));\n                    };\n                ;\n                    i.bind(\"streamEnd doneLoadingMore\", n), n();\n                }\n            ;\n            ;\n                return i.bind(\"doneLoadingMore\", function() {\n                    e.trigger(\"doneLoadingMore\");\n                }), this.setCurrent(i), this.trigger(\"newItemsCountChanged\", [i.newItemsCount,]), ((j ? i.afterSwitchingToAgain(k(i)) : i.afterFirstSwitchingTo(k(i)))), ((twttr.decider.isInfiniteScroll() && i.showLoadingSpinner())), ((((((this.preRendered && !i.preRendered)) && !twttr.app.fullyLoaded())) && signal(\"\\u003EwokeUp\"))), i;\n            },\n            setTitle: function(a) {\n                var b = this.titleContainer();\n                b.empty(), a._setTitle(twttr.bind(this, function(a) {\n                    if (!a) {\n                        return;\n                    }\n                ;\n                ;\n                    this.setTitleHTML(a);\n                }));\n            },\n            getMoreOldItems: function(a) {\n                ((this.getCurrent() && this.getCurrent().getMoreOldItems(a)));\n            },\n            resetCache: function() {\n                this.streams = {\n                }, this.setCurrent(null);\n            },\n            $headerContainer: function() {\n                return this.$page.JSBNG__find(\"div.js-stream-header\");\n            },\n            titleContainer: function() {\n                return ((twttr.isT1 ? this.$page.JSBNG__find(\".js-stream-title\") : this.$node.JSBNG__find(\"div.stream-title\")));\n            },\n            clearFromCache: function(a, b) {\n                b = ((b || {\n                }));\n                var c = twttr.streams.StreamManager.cacheKeyForStreamClass(a, b);\n                this.clearKeyFromCache(c);\n            },\n            clearKeyFromCache: function(a) {\n                delete this.streams[a];\n            }\n        });\n        ((twttr.isT1 ? d.methods({\n            setHeader: function(a, b) {\n                if (a._setHeader) {\n                    var c = this;\n                    using(twttr.bundleMore, function() {\n                        a._setHeader(twttr.bind(c, function(d) {\n                            c.renderHeader(a, b, d);\n                        }), b);\n                    });\n                }\n                 else this.renderHeader(a, b, (new twttr.views.StreamHeader(b)).$html());\n            ;\n            ;\n            },\n            renderHeader: function(a, b, c) {\n                this.setHeaderHTML(c), this.setTitle(a), this.setViewToggler(a, b), this.setHeaderButton(a, b);\n            },\n            setHeaderHTML: function(a) {\n                this.$headerContainer().html(a);\n            },\n            setTitleHTML: function(a) {\n                var b = this.titleContainer();\n                ((b && b.html(a)));\n            },\n            setViewToggler: function(a, b) {\n                $viewTogglerContainer = this.$page.JSBNG__find(\"small.js-view-toggler\");\n                if (!$viewTogglerContainer) {\n                    return;\n                }\n            ;\n            ;\n                $viewTogglerContainer.empty(), ((a._setViewToggler && using(twttr.bundleMore, function() {\n                    a._setViewToggler(twttr.bind(this, function(a) {\n                        if (!a) {\n                            return;\n                        }\n                    ;\n                    ;\n                        a.render($viewTogglerContainer);\n                    }), b);\n                })));\n            },\n            setHeaderButton: function(a, b) {\n                $headerButtonContainer = this.$page.JSBNG__find(\"span.js-header-button-container\");\n                if (!$headerButtonContainer) {\n                    return;\n                }\n            ;\n            ;\n                $headerButtonContainer.empty(), ((a._setHeaderButton && using(twttr.bundleMore, function() {\n                    a._setHeaderButton(twttr.bind(this, function(a) {\n                        if (!a) {\n                            return;\n                        }\n                    ;\n                    ;\n                        a.render($headerButtonContainer);\n                    }), b);\n                })));\n            }\n        }) : d.methods({\n            setHeader: function(a, b) {\n                this.setTitle(a);\n            },\n            setTitleHTML: function(a) {\n                this.titleContainer().html(((((\"\\u003Ch2\\u003E\" + a)) + \"\\u003C/h2\\u003E\")));\n            },\n            setViewToggler: twttr.util.noopInP1,\n            setHeaderButton: twttr.util.noopInP1\n        }))), a(d);\n    });\n});\nprovide(\"view\", function(a) {\n    using(\"util\").as(function(b) {\n        twttr.augmentString(\"twttr.views\", {\n            makeDefaultViews: function(a) {\n                twttr.map(a, function(a, c) {\n                    var d = b.util.capitalize(b.util.camelize(c));\n                    twttr.views[d] = ((twttr.views[d] || twttr.view(((\"twttr.views.\" + d)))));\n                }), signal(\"\\u003EdefaultViews\");\n            }\n        }), twttr.view = function(a, b) {\n            ((b || (b = function() {\n                twttr.views.Base.apply(this, arguments);\n            }))), ((((twttr.development && twttr.at(a))) && JSBNG__console.error(\"twttr.view duplicate definition of:\", a)));\n            var c = twttr.klass(a, b);\n            return c.subclassOf(twttr.views.Base), c.template = function(a) {\n                return this._template = a, this;\n            }, twttr.view._setDefaultTemplate(c, a), c._partials = twttr.templates, c;\n        }, twttr.view._setDefaultTemplate = function(a, c) {\n            a.template(twttr.templates[b.util.underscore(c.split(\".\")[2]).toLowerCase()]);\n        }, twttr.klass(\"twttr.ViewStack\", function(a, b) {\n            this.$referenceNode = $(a), this.operation = ((b || \"append\")), this._cache = {\n            }, this._stack = [];\n        }).methods({\n            cached: function(a) {\n                return ((twttr.is.string(a) || (a = a.viewId))), twttr.is.def(this._cache[a]);\n            },\n            size: function() {\n                return this._stack.length;\n            },\n            contains: function(a) {\n                return twttr.is.inArray(a, this._stack);\n            },\n            remove: function(a) {\n                delete this._cache[a.viewId];\n            },\n            JSBNG__top: function(a) {\n                return this._stack[((((this._stack.length - 1)) - ((a || 0))))];\n            },\n            push: function(a) {\n                var b = this.JSBNG__top();\n                return ((((b && b._backLabel)) && (a._backLabel = b._backLabel, b.hide()))), ((this.cached(a) ? (a = this._cache[a.viewId], this._stack.push(a)) : (this._cache[a.viewId] = a, a._viewstack = this, this._stack.push(a), a.render(this.$referenceNode, this.operation)))), a.show(), a;\n            },\n            pop: function(a) {\n                var b = this._stack.pop(), c = this._stack[((this._stack.length - 1))];\n                return ((b && b.hide())), ((((c && !a)) && c.show())), ((b ? b : null));\n            },\n            reset: function(a) {\n                while (this.pop()) {\n                ;\n                };\n            ;\n                if (a) {\n                    return this.push(a);\n                }\n            ;\n            ;\n            }\n        }), a(twttr.view);\n    });\n});\nprovide(\"urlResolver\", function(a) {\n    using().as(function(b) {\n        twttr.augmentString(\"twttr.urlResolver\", function() {\n            var a = {\n            };\n            return {\n                expand: function(b, c) {\n                    var d, e = {\n                    }, f = [];\n                    if (((twttr.decider.isAvailable(\"phoenix_url_resolver\") && twttr.is.array(b)))) {\n                        for (var g = 0, i = b.length; ((g < i)); ++g) {\n                            var j = b[g];\n                            (((d = a[j]) ? e[j] = d : f.push(j)));\n                        };\n                    ;\n                        ((((f.length === 0)) ? c(e) : twttr.API.Urls.resolve(f, function(b) {\n                            $.each(b, function(b, c) {\n                                a[b] = e[b] = c;\n                            }), c(e);\n                        })));\n                    }\n                ;\n                ;\n                }\n            };\n        }()), a(twttr.urlResolver);\n    });\n});\nprovide(\"multiGlobals/core_views\", function(exports) {\n    using(\"util\").as(function(phx) {\n        var logContext = phx.util.params().log_context;\n        twttr.view(\"twttr.views.Base\", function(a, b) {\n            ((twttr.is.string(a) ? (this.viewId = a, this.obj = b) : (this.obj = a, this.viewId = null)));\n            var c = twttr.audit.currentPage();\n            ((c && (this[((((\"in_\" + c)) + \"_page\"))] = !0)));\n            var d = twttr.audit.currentAction();\n            ((d && (this.actionName = twttr.util.underscore(d), this[((((\"in_\" + this.actionName)) + \"_action\"))] = !0)));\n            if (!this.obj) {\n                return;\n            }\n        ;\n        ;\n            this.originalObject = this.obj, this.attach(this.obj);\n        }).statics({\n            formatDeciderMethodName: function(a) {\n                return twttr.util.underscore(((\"\" + a)).replace(/[^A-Z0-9]/gi, \"_\"));\n            },\n            _addBucketTestMethod: function(a, b, c) {\n                var d = ((((b + \"_\")) + this.formatDeciderMethodName(c)));\n                ((((c && !this.prototype[d])) && this.method(d, function() {\n                    return ((c == twttr.abdecider.choose(a)));\n                })));\n            },\n            addABTestMethods: function(a, b, c) {\n                var d = ((\"abtest_\" + this.formatDeciderMethodName(a)));\n                ((this.prototype[d] || this.method(d, function() {\n                    return !!twttr.abdecider.choose(a);\n                })));\n                var e = ((d + \"_any_bucket\"));\n                ((this.prototype[e] || this.method(e, function() {\n                    var b = twttr.abdecider.choose(a);\n                    return ((!!b && ((b != \"control\"))));\n                })));\n                if (c) {\n                    for (var f = 0; ((f < c.length)); f++) {\n                        this._addBucketTestMethod(a, d, c[f]);\n                    ;\n                    };\n                }\n                 else {\n                    this._addBucketTestMethod(a, d, b);\n                }\n            ;\n            ;\n            },\n            addDeciderMethod: function(a) {\n                this.method(((\"decider_\" + twttr.util.underscore(a))), function() {\n                    return twttr.decider.isAvailable(a);\n                });\n            },\n            JSBNG__onDeciderKeyChange: function(a, b) {\n                twttr.views.Base.addDeciderMethod(b.key);\n            },\n            JSBNG__onABTestKeyChange: function(a, b) {\n                ((b.current && twttr.views.Base.addABTestMethods(b.key, b.current.bucket, b.current.bucket_names)));\n            }\n        }).methods({\n            anatomy_world: function() {\n                return !1;\n            },\n            anatomy_world_with_expand: function() {\n                return !1;\n            },\n            change_german_verbs: function() {\n                return ((((((twttr.isT1 && twttr.currentUser)) && ((new JSBNG__Date(2012, 6, 3) < new JSBNG__Date(twttr.currentUser.createdAt))))) && ((twttr.abdecider.choose(\"change_deutsch_verbs_229\") === \"change_verbs\"))));\n            },\n            australian_fav_to_like: function() {\n                var a = ((((twttr.isT1 && twttr.currentUser)) && twttr.abdecider.chooseWithoutImpression(\"rename_favorite_australia_334\"))), b = ((((a === \"fav_to_like_australia\")) || ((((a === \"fav_to_like_australia_new_users\")) && ((new JSBNG__Date(2012, 7, 17) < new JSBNG__Date(twttr.currentUser.createdAt)))))));\n                return ((((b || ((a === \"control\")))) && twttr.abdecider.choose(\"rename_favorite_australia_334\"))), b;\n            },\n            australian_fav_to_star: function() {\n                var a = ((((twttr.isT1 && twttr.currentUser)) && twttr.abdecider.chooseWithoutImpression(\"rename_favorite_australia_334\"))), b = ((((a === \"fav_to_star_australia\")) || ((((a === \"fav_to_star_australia_new_users\")) && ((new JSBNG__Date(2012, 7, 17) < new JSBNG__Date(twttr.currentUser.createdAt)))))));\n                return ((((b || ((a === \"control\")))) && twttr.abdecider.choose(\"rename_favorite_australia_334\"))), b;\n            },\n            \"debugger\": function() {\n                return ((twttr.development && eval(\"debugger;\"))), \"\";\n            },\n            languages: function() {\n                return twttr.languages;\n            },\n            languages_by_own: function() {\n                return twttr.languages.sort(function(a, b) {\n                    var c = a.JSBNG__name.toLowerCase(), d = b.JSBNG__name.toLowerCase();\n                    return ((((c < d)) ? -1 : ((((c === d)) ? 0 : 1))));\n                });\n            },\n            coerce_native_media_to_cards: function() {\n                return twttr.decider.isAvailable(\"platform_coerce_native_media_to_cards\");\n            },\n            media_cards_enabled: function() {\n                return ((twttr.isT1 && twttr.decider.isAvailable(\"platform_enable_cards\")));\n            },\n            render: function(a, b) {\n                this.selector = a, this.operation = ((b || \"html\"));\n                try {\n                    this.$dom = $(this.html());\n                } catch (c) {\n                    if (((!c.message || ((c.message.indexOf(\"Syntax error, unrecognized expression\") != 0))))) {\n                        throw c;\n                    }\n                ;\n                ;\n                    this.$dom = $(\"\");\n                };\n            ;\n                return $(this.selector)[this.operation](this.$dom), this.afterRender(this.$dom), this.$dom;\n            },\n            attach: function(a) {\n                if (((twttr.API.Base && ((a instanceof twttr.API.Base))))) {\n                    throw new Error(((((\"You failed to subclass BaseAPI with this view (\" + this.constructor._name)) + \"), so we're about to clobber all your favorite properties.  Subclass twttr.views.BaseAPI!\")));\n                }\n            ;\n            ;\n                for (var b in a) {\n                    this[b] = a[b];\n                ;\n                };\n            ;\n            },\n            hide: function() {\n                this.$dom.hide(), this.$dom.addClass(\"inactive\").removeClass(\"active\");\n            },\n            show: function() {\n                this.$dom.show(), this.$dom.addClass(\"active\").removeClass(\"inactive\");\n            },\n            refresh: function() {\n                this.$dom = $(this.html(!0)), $(this.selector)[this.operation](this.$dom);\n            },\n            html: function(a) {\n                if (((!a && this._html))) {\n                    return this._html;\n                }\n            ;\n            ;\n                if (!twttr.is.def(this.constructor._template)) {\n                    return JSBNG__console.log(\"Missing template file: \", this, this.constructor._name), \"\";\n                }\n            ;\n            ;\n                if (((((logContext == \"\")) || ((logContext == this.constructor._name))))) {\n                    try {\n                        var b = JSON.stringify(this.obj, null, 2);\n                    } catch (c) {\n                        var b = c.toString();\n                    };\n                ;\n                    JSBNG__console.log(\"View inputs to\", ((this.constructor._name + \":\")), {\n                        originalObject: this,\n                        stringified: b\n                    });\n                }\n            ;\n            ;\n                var d = [this.constructor._template,this,];\n                ((this.constructor._partials && d.push(this.constructor._partials)));\n                try {\n                    this._html = Mustache.to_html.apply(Mustache, d);\n                } catch (c) {\n                    if (c.message) {\n                        throw ((twttr.development && JSBNG__console.error(((\"Error rendering \" + this.constructor._name)), c.message))), c;\n                    }\n                ;\n                ;\n                };\n            ;\n                return this.afterHtml(this._html), this._html;\n            },\n            $html: function(a) {\n                return $(this.html());\n            },\n            rendering_on_server: !1,\n            swift: !1,\n            afterHtml: function(a) {\n            \n            },\n            afterRender: function(a) {\n            \n            },\n            subview: function(a, b) {\n                return this[a] = b, this;\n            },\n            logged_in: function() {\n                return !!twttr.currentUser;\n            },\n            is_ssl: function() {\n                return ((twttr.proto == \"https\"));\n            },\n            is_mobile: function() {\n                return !!twttr.isMobile;\n            },\n            t1_actions_eligible: function() {\n                return twttr.t1_actions_eligible;\n            },\n            form_authenticity_token: function() {\n                return twttr.anywhere.api.config.postAuthenticityToken;\n            },\n            plural_rules: {\n                r0: function() {\n                    return \"other\";\n                },\n                r1: function(a) {\n                    return ((((a === 1)) ? \"JSBNG__one\" : \"other\"));\n                },\n                r2: function(a) {\n                    return ((((a <= 1)) ? \"JSBNG__one\" : \"other\"));\n                },\n                r3: function(a) {\n                    if (((parseInt(a) === a))) {\n                        switch (((a % 10))) {\n                          case 1:\n                            if (((a === 11))) {\n                                break;\n                            }\n                        ;\n                        ;\n                            return \"JSBNG__one\";\n                          case 2:\n                        \n                          case 3:\n                        \n                          case 4:\n                            if (((((a >= 12)) && ((a <= 14))))) {\n                                break;\n                            }\n                        ;\n                        ;\n                            return \"few\";\n                        };\n                    ;\n                        return \"many\";\n                    }\n                ;\n                ;\n                    return \"other\";\n                },\n                r4: function(a) {\n                    switch (a) {\n                      case 0:\n                        return \"zero\";\n                      case 1:\n                        return \"JSBNG__one\";\n                      case 2:\n                        return \"two\";\n                      default:\n                        var b = ((a % 100));\n                        return ((((b >= 11)) ? \"many\" : ((((((b >= 3)) && ((b <= 10)))) ? \"few\" : \"other\"))));\n                    };\n                ;\n                }\n            },\n            lang_to_rule: {\n                ar: \"r4\",\n                da: \"r1\",\n                de: \"r1\",\n                en: \"r1\",\n                es: \"r1\",\n                fa: \"r0\",\n                fil: \"r2\",\n                fr: \"r2\",\n                he: \"r1\",\n                hi: \"r2\",\n                hu: \"r0\",\n                id: \"r0\",\n                it: \"r1\",\n                ja: \"r0\",\n                ko: \"r0\",\n                msa: \"r0\",\n                nl: \"r1\",\n                pt: \"r1\",\n                ru: \"r3\",\n                sv: \"r1\",\n                tr: \"r0\",\n                ur: \"r1\",\n                \"zh-cn\": \"r0\",\n                \"zh-tw\": \"r0\"\n            },\n            lookup_missing_property: function(a, b) {\n                var c = a.lastIndexOf(\"_\");\n                if (((c !== -1))) {\n                    var d = a.substring(((c + 1)));\n                    switch (d) {\n                      case \"zero\":\n                    \n                      case \"JSBNG__one\":\n                    \n                      case \"two\":\n                    \n                      case \"few\":\n                    \n                      case \"many\":\n                    \n                      case \"other\":\n                        var e = a.substring(0, c);\n                        if (((e in b))) {\n                            function f(a) {\n                                return ((((a || ((a === !1)))) || ((a === 0))));\n                            };\n                        ;\n                            var g = this.plural_rules[((this.lang_to_rule[twttr.pageLocale] || \"r0\"))];\n                            function i() {\n                                var a;\n                                return ((f(this[e]) && (a = this[e]))), ((((typeof a == \"function\")) && (a = a.apply(this)))), ((d === g(a)));\n                            };\n                        ;\n                            var j = null;\n                            ((Object.getPrototypeOf ? j = Object.getPrototypeOf(b) : ((b.__proto__ && (j = b.__proto__)))));\n                            if (((!j || ((j === Object.prototype))))) {\n                                j = b;\n                            }\n                        ;\n                        ;\n                            return j[a] = i, i.apply(b);\n                        }\n                    ;\n                    ;\n                        break;\n                      default:\n                    \n                    };\n                ;\n                }\n            ;\n            ;\n                return undefined;\n            },\n            render_page_content: !0\n        }), function() {\n            for (var a in twttr.decider.features()) {\n                twttr.views.Base.addDeciderMethod(a);\n            ;\n            };\n        ;\n            var b = twttr.abdecider.experiments();\n            for (var c in b) {\n                var d = b[c];\n                ((((d && d.bucket)) && twttr.views.Base.addABTestMethods(c, d.bucket, d.bucket_names)));\n            };\n        ;\n        }(), twttr.decider.bind(\"keyChanged\", twttr.views.Base.JSBNG__onDeciderKeyChange), twttr.abdecider.bind(\"keyChanged\", twttr.views.Base.JSBNG__onABTestKeyChange), twttr.view(\"twttr.views.BaseAPI\").methods({\n            attach: function(a) {\n                var b = ((a.attributes || a));\n                for (var c in b) {\n                    this[c] = b[c];\n                ;\n                };\n            ;\n            }\n        }), twttr.view(\"twttr.views.UserLink\").subclassOf(twttr.views.BaseAPI), twttr.view(\"twttr.views.BaseTweet\", function() {\n            twttr.views.BaseAPI.apply(this, arguments), this.user = new twttr.views.BaseUser({\n                attributes: this.user\n            });\n        }).subclassOf(twttr.views.BaseAPI).mixin(twttr.mixins.userActionable).methods({\n            impression_cookie: function() {\n                if (!this.impression_id) {\n                    return;\n                }\n            ;\n            ;\n                var a = [];\n                return JSON.stringify([this.id,this.impression_id,this.disclosure_type,this.disclosure_text,a,]);\n            },\n            full_timestamp: function() {\n                return twttr.helpers.timeAgo(this.actual_timestamp(), !0);\n            },\n            short_timestamp: function() {\n                return twttr.helpers.timeAgo(this.actual_timestamp());\n            },\n            explicit_timestamp: function() {\n                return twttr.helpers.prettyTime(this.actual_timestamp());\n            },\n            actual_timestamp: function() {\n                return twttr.helpers.parseDateString(this.created_at);\n            },\n            linkified_text: function() {\n                if (!this.text) {\n                    return \"\";\n                }\n            ;\n            ;\n                var a = this.text;\n                return ((((this.is_withheld() && this.is_current_user())) && (a = this.withheld_text))), a = twttr.util.linkify(a, {\n                    nofollow: !0\n                }), a = twttr.util.linkifyEntities(a, this), ((this.render_withheld() && ((this.is_withheld_copyright() ? a += ((((((((\"  \\u003Ca href=\\\"\" + twttr.router.withheldCopyrightHelpPath())) + \"\\\" target=\\\"_blank\\\"\\u003E\")) + _(\"Learn more\"))) + \"\\u003C/a\\u003E\")) : a += ((((((((\"  \\u003Ca href=\\\"\" + twttr.router.withheldHelpPath())) + \"\\\" target=\\\"_blank\\\"\\u003E\")) + _(\"Learn more\"))) + \"\\u003C/a\\u003E\")))))), ((this.query ? twttr.util.queryHighlight(this.query, a) : a));\n            },\n            is_withheld: function() {\n                return ((this.is_tweet_withheld() || this.is_user_withheld()));\n            },\n            is_tweet_withheld: function() {\n                return ((((twttr.decider.isAvailable(\"phoenix_pctd\") && !!this.withheld_scope)) && ((this.withheld_scope == \"JSBNG__status\"))));\n            },\n            is_user_withheld: function() {\n                return ((((twttr.decider.isAvailable(\"phoenix_pctd\") && !!this.withheld_scope)) && ((this.withheld_scope == \"user\"))));\n            },\n            is_withheld_copyright: function() {\n                return ((this.is_tweet_withheld_copyright() || this.is_user_withheld_copyright()));\n            },\n            is_tweet_withheld_copyright: function() {\n                return ((((((twttr.decider.isAvailable(\"phoenix_pctd\") && !!this.withheld_scope)) && ((this.withheld_scope == \"JSBNG__status\")))) && !!this.withheld_copyright));\n            },\n            is_user_withheld_copyright: function() {\n                return ((((((twttr.decider.isAvailable(\"phoenix_pctd\") && !!this.withheld_scope)) && ((this.withheld_scope == \"user\")))) && !!this.withheld_copyright));\n            },\n            is_current_user: function() {\n                return twttr.helpers.isCurrentUser(this.user);\n            },\n            is_current_user_withheld: function() {\n                return ((this.is_withheld() && this.is_current_user()));\n            },\n            render_withheld: function() {\n                return ((this.is_withheld() && !this.is_current_user()));\n            },\n            is_top_tweet: function() {\n                return ((this.result_category === \"popular\"));\n            },\n            is_sponsored: function() {\n                return !!this.impression_id;\n            },\n            tweet_impression_id: function() {\n                return ((this.impression_id ? Mustache.to_html(\"data-impression-id=\\\"{{id}}\\\" \", {\n                    id: this.impression_id\n                }) : \"\"));\n            },\n            promoted_badge_class: function() {\n                return ((\"badge-\" + ((this.disclosure_type || \"promoted\"))));\n            },\n            social_context: function() {\n                if (((this.socialContext && this.socialContext.length))) {\n                    this.user.socialContext = this.socialContext, this.user.screenName = this.user.screen_name;\n                    var a = this.makeSocialContextHtml(this.user, !1);\n                    return _(\"\\u003Cspan class=\\\"icon-link social-context\\\"\\u003E{{{social_context}}}\\u003C/span\\u003E\", {\n                        social_context: a\n                    });\n                }\n            ;\n            ;\n                return \"\";\n            },\n            has_native_media: function() {\n                return twttr.Cards.prototype.hasCardPhotoEntities(this);\n            },\n            has_visible_cards: function() {\n                return twttr.Cards.prototype.hasCards(this);\n            },\n            advertiser_name: function() {\n                return ((this.was_retweeted ? this.retweeting_status.user.JSBNG__name : this.user.JSBNG__name));\n            },\n            allowed_to_retweet: function() {\n                return ((!this.user[\"protected\"] && !twttr.helpers.isCurrentUser(this.user)));\n            },\n            retweet_count_text: function() {\n                var a = this.retweet_count;\n                return ((((a === 1)) ? _(\"{{retweet_count}} Retweet\", {\n                    retweet_count: a\n                }) : _(\"{{retweet_count}} Retweets\", {\n                    retweet_count: twttr.util.formatNumber(a, twttr.pageLocale)\n                })));\n            },\n            activity_count: function(a) {\n                var b = ((((this.activities && this.activities[a])) && ((this.activities[a] !== \"0\"))));\n                return ((b ? ((((\"(\" + this.activities[a])) + \")\")) : \"\"));\n            },\n            favoriter_count: function() {\n                return this.activity_count(\"favoriters_count\");\n            },\n            retweeter_count: function() {\n                return this.activity_count(\"retweeters_count\");\n            },\n            has_retweet_count: function() {\n                return ((this.retweet_count > 0));\n            },\n            replier_count: function() {\n                return this.activity_count(\"repliers_count\");\n            },\n            is_retweeted_by_current_user: function() {\n                return !!this.current_user_retweet;\n            },\n            is_my_tweet: function() {\n                return twttr.helpers.isCurrentUser(this.user);\n            },\n            show_trashcan: function() {\n                return ((twttr.helpers.isCurrentUser(this.user) || ((twttr.admin && twttr.admin.showTrashcan()))));\n            },\n            show_not_relevant_action: function() {\n                return ((twttr.decider.isAvailable(\"phoenix_search_relevance_not_relevant_action\") && ((this.result_category === \"relevance\"))));\n            },\n            contributor: function() {\n                return ((this.contributors ? this.contributors[0] : null));\n            },\n            can_view: function() {\n                return this.user.can_view();\n            },\n            retweet_source_screen_name_link: function() {\n                if (this.retweeting_status) {\n                    var a = this.retweeting_status.text.match(/^RT @?([0-9A-Za-z_]*):/).pop();\n                    return Mustache.to_html(\"\\u003Ca href='{{path}}' class='latest-status-retweeted-user'\\u003E{{screen_name}}\\u003C/a\\u003E\", {\n                        path: twttr.router.profilePath({\n                            screen_name: a\n                        }),\n                        screen_name: a\n                    });\n                }\n            ;\n            ;\n            },\n            css_classes: function() {\n                var a = \"\";\n                return $.each({\n                    is_top_tweet: \"top-tweet\",\n                    is_sponsored: \"promoted-tweet\",\n                    current_user_retweet: \"retweeted\",\n                    favorited: \"favorited\"\n                }, twttr.bind(this, function(b, c) {\n                    if (((twttr.is.fn(this[b]) ? this[b]() : this[b]))) {\n                        a += ((c + \" \"));\n                    }\n                ;\n                ;\n                })), a;\n            },\n            permalink_path: function() {\n                return twttr.router.permalinkPath({\n                    screen_name: this.user.screen_name,\n                    id: this.id\n                });\n            },\n            embed_dialog_permalink_path: function() {\n                return twttr.router.embedDialogPermalinkPath({\n                    screen_name: this.user.screen_name,\n                    id: this.id\n                });\n            },\n            place_path: function() {\n                return twttr.router.placePath({\n                    place_id: this.place.id\n                });\n            },\n            truncated_text: function() {\n                return twttr.helpers.truncate(this.text, 50);\n            },\n            can_expand: function() {\n                return twttr.decider.isExpando();\n            },\n            in_reply_to_path: function() {\n                return twttr.router.permalinkPath({\n                    screen_name: this.in_reply_to_screen_name,\n                    id: this.in_reply_to_status_id\n                });\n            },\n            in_reply_to_name: function() {\n                var a = this.in_reply_to_screen_name, b = ((this.entities && this.entities.user_mentions));\n                if (b) {\n                    for (var c = 0, d = b.length; ((c < d)); c++) {\n                        if (((b[c].screen_name === a))) {\n                            return b[c].JSBNG__name;\n                        }\n                    ;\n                    ;\n                    };\n                }\n            ;\n            ;\n                return ((\"@\" + a));\n            }\n        }), twttr.view(\"twttr.views.BaseUser\", function() {\n            twttr.views.BaseAPI.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPI).mixin(twttr.mixins.i18nTweet).methods({\n            defaultAvatarRegEx: /default_profile_\\d/,\n            defaultAvatar: function(a) {\n                return ((((this.profile_image_url.match(this.defaultAvatarRegEx) && this.is_current_user())) ? ((a ? twttr.assets.path(\"/images/default_profile_add_photo.png\") : twttr.router.settingsProfilePath())) : !1));\n            },\n            raw_profile_image_url: function() {\n                return ((this.defaultAvatar(!1) || twttr.helpers.transformProfileImageUrl(this.profile_image_url)));\n            },\n            bigger_profile_image_url: function() {\n                return ((this.defaultAvatar(!1) || twttr.helpers.transformProfileImageUrl(this.profile_image_url, \"bigger\")));\n            },\n            mini_profile_image_url: function() {\n                return ((this.defaultAvatar(!1) || twttr.helpers.transformProfileImageUrl(this.profile_image_url, \"mini\")));\n            },\n            reasonably_small_profile_image_url: function() {\n                return ((this.defaultAvatar(!0) || twttr.helpers.transformProfileImageUrl(this.profile_image_url, \"reasonably_small\")));\n            },\n            right_image_size: function() {\n                return twttr.helpers.transformProfileImageUrl(this.profile_image_url, \"bigger\");\n            },\n            account_profile_image_path: function() {\n                return ((\"/account/profile_image/\" + this.screen_name));\n            },\n            description_is_rtl: function() {\n                if (!this.description) {\n                    return !1;\n                }\n            ;\n            ;\n                var a = this.getMachedRtlChars(this.description);\n                return ((a && this.shouldBeRTL(this.description, a)));\n            },\n            linkified_description: function() {\n                var a = this.description;\n                ((((this.is_withheld() && this.is_current_user())) && (a = this.withheld_description)));\n                if (!a) {\n                    return \"\";\n                }\n            ;\n            ;\n                var b = twttr.util.linkifyEntities(twttr.util.linkify(a, {\n                    nofollow: !0\n                }), this);\n                return ((this.query ? twttr.util.queryHighlight(this.query, b) : b));\n            },\n            display_url_or_url: function() {\n                return ((this.url ? twttr.txt.htmlEscape(((this.display_url || this.url))) : \"\"));\n            },\n            is_withheld: function() {\n                return ((((twttr.decider.isAvailable(\"phoenix_pctd\") && !!this.withheld_scope)) && ((this.withheld_scope == \"user\"))));\n            },\n            is_current_user_withheld: function() {\n                return ((this.is_withheld() && this.is_current_user()));\n            },\n            is_withheld_copyright: function() {\n                return ((((((twttr.decider.isAvailable(\"phoenix_pctd\") && !!this.withheld_scope)) && ((this.withheld_scope == \"user\")))) && !!this.withheld_copyright));\n            },\n            is_current_user_withheld_copyright: function() {\n                return ((this.is_withheld_copyright() && this.is_current_user()));\n            },\n            is_current_user: function() {\n                return twttr.helpers.isCurrentUser(this.id);\n            },\n            can_view: function() {\n                return twttr.helpers.canViewUser(this);\n            },\n            is_sponsored: function() {\n                return !!this.promoted_content;\n            },\n            promoted_badge_class: function() {\n                return ((\"badge-\" + ((this.promoted_content.disclosure_type || \"promoted\"))));\n            },\n            translation_tool_path: function() {\n                return ((twttr.decider.isAvailable(\"i18n_new_translation_center\") ? \"http://translate.twttr.com\" : this.translate_path()));\n            },\n            account_impression_id: function() {\n                var a = this.promoted_content;\n                return ((a ? Mustache.to_html(\"data-impression-id='{{id}}' \", {\n                    id: a.impression_id\n                }) : \"\"));\n            },\n            feedback_token: function() {\n                return ((this.feedback ? Mustache.to_html(\"data-feedback-token='{{feedback}}' \", {\n                    feedback: this.feedback\n                }) : \"\"));\n            },\n            mini_profile_image_url: function() {\n                return twttr.helpers.transformProfileImageUrl(this.profile_image_url, \"mini\");\n            }\n        }), twttr.view(\"twttr.views.StreamTweet\", function() {\n            twttr.views.BaseTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseTweet).mixin(twttr.mixins.serverRenderableObject).methods({\n            wakeUp: function() {\n                this.initDomNode();\n                var a = this.$node.children().remove();\n                this.$node.html(twttr.views.BaseTweet.prototype.html.call(this, !0)), ((this.render_withheld() && this.$node.addClass(\"withheld-item\")));\n                var b = $(\"\\u003Cdiv style=\\\"display:none;\\\" class=\\\"js-old-content\\\" /\\u003E\").append(a);\n                this.$node.append(b);\n                var c = b[0];\n                using(\"\\u003EactionQueueEmpty\", function() {\n                    c.parentNode.removeChild(c);\n                });\n            },\n            initDomNode: function() {\n                if (this.$node) {\n                    return;\n                }\n            ;\n            ;\n                var a = this;\n                this.$node = this.$domNode(function() {\n                    return twttr.views.BaseTweet.prototype.html.apply(a, arguments);\n                });\n            },\n            html: function(a) {\n                return ((a && (this.$node = null))), this.initDomNode(), ((this.preRendered ? this.$node.html() : twttr.views.Base.prototype.html.apply(this, arguments)));\n            },\n            domNodeSelector: function() {\n                var a = this.id;\n                return ((this.impression_id && (a += \"-promoted\"))), ((\"#stream-item-tweet-\" + a));\n            }\n        }), twttr.view(\"twttr.views.TweetActions\", function() {\n            twttr.views.BaseTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseTweet), twttr.view(\"twttr.views.TweetDogear\", function() {\n            twttr.views.BaseTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseTweet), twttr.view(\"twttr.views.DetailsPane\").methods({\n            closable: !0,\n            back_label: function() {\n                return this._backLabel;\n            },\n            popable: function() {\n                return ((this._viewstack && ((this._viewstack.size() > 1))));\n            },\n            hide: function() {\n                this.$dom.addClass(\"inactive\").removeClass(\"active\"), this.$dom.JSBNG__find(\"div.tweet-media\").trigger(\"hideMedia\"), this.$dom = this.$dom.detach();\n            },\n            show: function() {\n                $(this.selector)[this.operation](this.$dom), this.$dom.JSBNG__find(\"div.tweet-media\").trigger(\"showMedia\"), this.$dom.addClass(\"active\").removeClass(\"inactive\");\n            }\n        }), twttr.view(\"twttr.views.MessageDrawer\").statics({\n            isOpen: !1,\n            close: function() {\n                twttr.views.MessageDrawer.isOpen = !1, $(\"#message-drawer .message\").remove();\n            }\n        }), twttr.view(\"twttr.views.UserCss\", function() {\n            twttr.views.BaseAPI.apply(this, arguments);\n            var a = [\"profile_background_color\",\"profile_text_color\",\"profile_link_color\",\"profile_sidebar_fill_color\",];\n            for (var b = 0; ((b < a.length)); b++) {\n                this[a[b]] = twttr.helpers.sanitizeCssColor(this[a[b]]);\n            ;\n            };\n        ;\n        }).subclassOf(twttr.views.BaseAPI).methods({\n            rgba_sidebar_color: function() {\n                if (!this.profile_sidebar_fill_color) {\n                    return;\n                }\n            ;\n            ;\n                return twttr.helpers.hexToRGBA(this.profile_sidebar_fill_color, \"0.9\");\n            },\n            rgba_tweet_background_color: function() {\n                if (!this.profile_link_color) {\n                    return;\n                }\n            ;\n            ;\n                return twttr.helpers.hexToRGBA(this.profile_link_color, \"0.1\");\n            },\n            rgba_tweet_border_color: function() {\n                if (!this.profile_link_color) {\n                    return;\n                }\n            ;\n            ;\n                return twttr.helpers.hexToRGBA(this.profile_link_color, \"0.15\");\n            },\n            rgba_newtweets_background_color: function() {\n                if (!this.profile_link_color) {\n                    return;\n                }\n            ;\n            ;\n                return twttr.helpers.hexToRGBA(this.profile_link_color, \"0.2\");\n            },\n            rgba_newtweets_border_color: function() {\n                if (!this.profile_link_color) {\n                    return;\n                }\n            ;\n            ;\n                return twttr.helpers.hexToRGBA(this.profile_link_color, \"0.25\");\n            },\n            rgba_text_color: function() {\n                if (!this.profile_text_color) {\n                    return;\n                }\n            ;\n            ;\n                return twttr.helpers.hexToRGBA(this.profile_text_color, \"0.6\");\n            },\n            profile_pretty_link_color: function() {\n                if (!this.profile_link_color) {\n                    return;\n                }\n            ;\n            ;\n                return twttr.helpers.blendHexColor(this.profile_link_color, \"FFF\", 535648);\n            },\n            profile_pretty_link_sidebar_color: function() {\n                if (((!this.profile_link_color || !this.profile_sidebar_fill_color))) {\n                    return;\n                }\n            ;\n            ;\n                return twttr.helpers.blendHexColor(this.profile_link_color, this.profile_sidebar_fill_color, 535858);\n            }\n        }), twttr.view(\"twttr.views.UserCssP1\", function() {\n            twttr.views.UserCss.apply(this, arguments);\n        }).subclassOf(twttr.views.UserCss), twttr.view(\"twttr.views.UserCssT1\", function(a) {\n            twttr.inputUser = a, twttr.views.UserCss.apply(this, arguments);\n        }).subclassOf(twttr.views.UserCss).methods({\n            style_namespace: function() {\n                return ((this.screen_name ? this.screen_name : \"twttr\"));\n            },\n            has_hovers_in_css: function() {\n                return !!twttr.hasHoversInCss;\n            },\n            colon_hover: function() {\n                return ((twttr.hasHoversInCss ? \":hover\" : \"\"));\n            }\n        }), twttr.view(\"twttr.views.BgImgCss\", function() {\n            twttr.views.BaseAPI.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseAPI), twttr.view(\"twttr.views.BaseStats\", function(a) {\n            twttr.views.BaseUser.apply(this, arguments), ((a.JSBNG__status && (this.JSBNG__status = new twttr.views.BaseTweet(a.JSBNG__status), this.JSBNG__status.user = this)));\n        }).subclassOf(twttr.views.BaseUser).methods({\n            statuses_count_commaized: function() {\n                return phx.util.formatNumber(this.statuses_count, twttr.pageLocale);\n            },\n            following_nobody: function(a) {\n                return ((this.friends_count === 0));\n            },\n            friends_count_commaized: function() {\n                return ((((this.screen_name === \"toptweets\")) ? _(\"everyone!\") : phx.util.formatNumber(this.friends_count, twttr.pageLocale)));\n            },\n            followers_count_commaized: function() {\n                return phx.util.formatNumber(this.followers_count, twttr.pageLocale);\n            },\n            favorites_count_commaized: function() {\n                return ((((this.favourites_count && ((parseInt(this.favourites_count, 10) > 0)))) ? phx.util.formatNumber(this.favourites_count, twttr.pageLocale) : 0));\n            },\n            listed_count_commaized: function() {\n                return ((((this.listed_count && ((parseInt(this.listed_count, 10) > 0)))) ? phx.util.formatNumber(this.listed_count, twttr.pageLocale) : 0));\n            },\n            can_view: function() {\n                return twttr.helpers.canViewUser(this);\n            },\n            source_impression_id: function() {\n                var a = this.impression_id;\n                return ((a ? Mustache.to_html(\"data-impression-id=\\\"{{id}}\\\" \", {\n                    id: a\n                }) : \"\"));\n            },\n            translator_profile_path: function() {\n                return ((twttr.decider.isAvailable(\"i18n_new_translation_center\") ? ((((this.translation_tool_path() + \"/user/\")) + this.screen_name)) : this.translation_tool_path()));\n            }\n        }), twttr.view(\"twttr.views.MessageNotification\").statics({\n            isOpen: !1,\n            close: function() {\n                twttr.views.MessageNotification.isOpen = !1, $(\"#message-notification .notification\").remove();\n            }\n        }), twttr.view(\"twttr.views.StreamActivity\").statics({\n            maxItems: 2,\n            sentences: {\n                favorites: [_(\"Favorited by {{{screen_name_0}}}\"),_(\"Favorited by {{{screen_name_0}}} and {{{screen_name_1}}}\"),],\n                retweets: [_(\"Retweeted by {{{screen_name_0}}}\"),_(\"Retweeted by {{{screen_name_0}}} and {{{screen_name_1}}}\"),]\n            }\n        }).methods({\n            sentence: function() {\n                var a = this.constructor.sentences[this.item_type], b = this.items.slice(0, this.constructor.maxItems);\n                return ((((!b.length || !a)) ? \"\" : Mustache.to_html(a[((b.length - 1))], twttr.inject(b, {\n                }, function(a, b, c) {\n                    return a[((\"screen_name_\" + b))] = (new twttr.views.UserLink(c.attributes)).html(), a;\n                }))));\n            }\n        }), exports();\n    });\n});\nprovide(\"multiGlobals/core_views_t1\", function(a) {\n    using(\"util\").as(function(b) {\n        twttr.view(\"twttr.views.StreamTweeter\", function() {\n            twttr.views.BaseTweet.apply(this, arguments);\n        }).subclassOf(twttr.views.BaseTweet), a();\n    });\n});\nprovide(\"router_t1\", function(a) {\n    using(\"util\", \"\\u003EdeciderFeaturesFromBootstrap\").as(function(b) {\n        function c(a) {\n            function b(b) {\n                var d = twttr.app.switchToPage(a);\n                ((((d && c)) && d.send(c, Array.prototype.slice.apply(arguments))));\n            };\n        ;\n            var c;\n            return b.action = function(a) {\n                return this.actionName = c = a, b;\n            }, b.pageName = a, b;\n        };\n    ;\n        function d(a, b, c) {\n            m(((\"hashbang\" + twttr.util.capitalize(a))), ((\"/#!\" + b)), function() {\n                twttr.themes.loadLoadingTheme(), twttr.Router.performRedirect(((c || b)));\n            });\n        };\n    ;\n        function e(a, b) {\n            d(a, b), m(a, b, $.noop);\n        };\n    ;\n        function f(a, b) {\n            var c = ((((twttr.isLocalhost ? \"\" : ((\"https://\" + JSBNG__location.hostname)))) + b));\n            d(a, b, c), n(a, c);\n        };\n    ;\n        function g(a, b, c, d, e) {\n            var f = ((i(d) ? e : b));\n            twttr.router.swiftRoutes[a] = {\n                decider: d,\n                path: e\n            }, m(a, f, c);\n        };\n    ;\n        function i(a) {\n            var b = twttr.util.params(window.JSBNG__location.search);\n            return ((twttr.is.def(b.render_on_server) ? ((((b[\"render_on_server\"] == \"1\")) || ((b[\"render_on_server\"] == \"true\")))) : twttr.decider.isAvailable(a)));\n        };\n    ;\n        function j(a) {\n            return ((twttr.loggedIn ? a.loggedIn : ((a.loggedOut || k()))));\n        };\n    ;\n        function k() {\n            return ((twttr.ScribeBuffer && twttr.ScribeBuffer.instance.send())), c(\"Login\").action(\"loginRequired\");\n        };\n    ;\n        function l() {\n            var a = twttr.router.shouldRedirectToCanonicalUrl(twttr.router.getCurrentRoute());\n            if (a) {\n                return twttr.router.routingEnabled = !1, window.JSBNG__location.replace(a), !0;\n            }\n        ;\n        ;\n        };\n    ;\n        twttr.router = new twttr.Router;\n        var m = twttr.bind(twttr.router, twttr.router.route), n = twttr.bind(twttr.router, twttr.router.staticRoute), o = twttr.bind(twttr.router, twttr.router.redirectRoute);\n        twttr.router.bind(\"routeAdded\", function(a, c, d) {\n            twttr.views.Base.method(b.util.underscore(c), function() {\n                return d(this);\n            });\n        }), e(\"about\", \"/about\"), e(\"jobs\", \"/jobs\"), e(\"tos\", \"/tos\"), e(\"privacy\", \"/privacy\"), e(\"deactivated\", \"/account/deactivated\"), e(\"deactivate\", \"/account/deactivate\"), e(\"suspendedHelp\", \"/account/suspended_help\"), e(\"suspended\", \"/suspended\"), e(\"settings\", \"/settings/account\"), e(\"design\", \"/settings/design\"), e(\"settingsProfile\", \"/settings/profile\"), e(\"devices\", \"/devices\"), e(\"invitationEmailPreview\", \"/invitations/email_preview\"), e(\"campaigns\", \"/account/campaigns\"), e(\"resources\", \"/about/resources\"), e(\"translate\", \"/translate\"), e(\"whatsNew\", \"/newtwitter\"), e(\"changeLocale\", \"/sessions/change_locale\"), e(\"resendPassword\", \"/account/resend_password\"), e(\"mobileComplete\", \"/account/complete\"), e(\"turnPhxOff\", \"/account/use_phx?setting=false&format=html\"), e(\"mobileGallery\", \"/download\"), o(\"terms\", \"/#!/terms\", \"tos\"), o(\"admin\", \"/#!/admin\", \"JSBNG__home\"), f(\"sessions\", \"/sessions?phx=1\"), f(\"signup\", \"/signup\"), g(\"login\", \"/#!/login\", c(\"login\").action(\"index\"), \"swift_login\", \"/login\"), g(\"sessionsNew\", \"/#!/sessions/new\", c(\"login\").action(\"index\"), \"swift_login\", \"/sessions/new\"), g(\"loginRedirect\", \"/#!/login/redirect/:redirect_after_login\", c(\"login\").action(\"index\"), \"swift_login\", \"/login?redirect_after_login=:redirect_after_login\"), g(\"loginError\", \"/#!/login/:error\", c(\"login\").action(\"error\"), \"swift_login\", \"/login/:error\"), m(\"logout\", \"/#!/logout\", c(\"logout\").action(\"index\")), e(\"logout_action\", \"/logout\"), n(\"support\", \"//support.twitter.com\"), n(\"blog\", twttr.localize({\n            ja: \"http://blog.jp.twitter.com\",\n            es: \"http://blog.es.twitter.com\",\n            fr: \"http://blog.fr.twitter.com\",\n            de: \"http://blog.de.twitter.com\",\n            pt: \"http://blog.pt.twitter.com\",\n            ko: \"http://blog.kr.twitter.com\",\n            it: \"http://blog.it.twitter.com\",\n            ru: \"http://blog.ru.twitter.com\"\n        }, \"http://blog.twitter.com\")), n(\"JSBNG__status\", twttr.localize({\n            ja: \"http://status.twitter.jp\"\n        }, \"http://status.twitter.com\")), n(\"developers\", \"//dev.twitter.com\"), n(\"businesses\", ((((\"//business.twitter.com/index_\" + twttr.pageLocale)) + \".html\"))), n(\"advertisers\", ((((\"//business.twitter.com/\" + twttr.pageLocale)) + \"/advertise/start\"))), n(\"partnerships\", \"http://media.twitter.com\"), n(\"helpPromotedTweets\", \"//support.twitter.com/articles/142101\"), n(\"helpPromotedAccounts\", \"//support.twitter.com/articles/282154\"), n(\"helpPromotedTrends\", \"//support.twitter.com/articles/282142\"), n(\"spamLearnMore\", \"//support.twitter.com/articles/64986-how-to-report-spam-on-twitter\"), n(\"malwareLearnMore\", \"//support.twitter.com/articles/90491-my-website-is-being-flagged-as-malware-or-spam\"), n(\"suspendedLearnMore\", \"//support.twitter.com/articles/15790-my-account-is-suspended\"), n(\"dailyLimitLearnMore\", \"//support.twitter.com/articles/15364-about-twitter-limits-update-api-dm-and-following\"), n(\"savedSearchesHelp\", \"//support.twitter.com/articles/96646-how-to-save-searches\"), n(\"listsHelp\", \"//support.twitter.com/articles/76460-how-to-use-twitter-lists\"), n(\"emailHelp\", \"//support.twitter.com/articles/82050-i-m-having-trouble-confirming-my-email\"), n(\"changeEmail\", \"//twitter.com/settings/account?change_email=true\"), n(\"mobile\", \"//mobile.twitter.com\"), n(\"mobileHelp\", \"//support.twitter.com/groups/34-mobile\"), n(\"mobileHelpFaq\", \"//support.twitter.com/groups/34-mobile/topics/123-getting-started/articles/14014-twitter-phone-faqs\"), n(\"shortCodeHelp\", \"//support.twitter.com/articles/14226-how-to-find-your-twitter-short-code\"), n(\"smsHelp\", \"//support.twitter.com/articles/14020-about-twitter-sms-commands\"), n(\"pushHelp\", \"//support.twitter.com/articles/20169887\"), n(\"helpDiscovery\", \"//support.twitter.com/articles/14022\"), n(\"analytics\", \"//analytics.twitter.com/\"), n(\"turkeySupport\", \"https://support.twitter.com/articles/20156423\"), n(\"flagTurkeySupport\", \"https://support.twitter.com/articles/20069937\"), n(\"twirefoxSupport\", \"https://support.twitter.com/articles/20167003-about-firefox-with-twitter\"), n(\"tweetIntent\", \"https://twitter.com/share\"), n(\"withheldCopyrightHelp\", \"https://support.twitter.com/articles/15795\"), n(\"withheldHelp\", \"https://support.twitter.com/articles/20169222\"), n(\"followLimitReachedLearnMore\", \"https://support.twitter.com/articles/66885\"), n(\"blockedFromFollowingLearnMore\", \"https://support.twitter.com/articles/117063\"), n(\"listNameErrorLearnMore\", \"https://support.twitter.com/articles/20169276\"), n(\"cookiePersonalizationLearnMore\", \"https://support.twitter.com/articles/20169421\"), n(\"embedDocumentation\", \"//dev.twitter.com/docs/embedded-tweets\"), n(\"directMessageLearnMore\", \"http://support.twitter.com/groups/31-twitter-basics/topics/109-tweets-messages/articles/14606-what-is-a-direct-message-dm\"), g(\"JSBNG__home\", \"/#!/\", j({\n            loggedIn: c(\"JSBNG__home\").action(\"JSBNG__home\"),\n            loggedOut: c(\"front\").action(\"index\")\n        }), \"swift_home_timeline\", \"/\"), g(\"homeIndex\", \"/#!/\", j({\n            loggedIn: c(\"JSBNG__home\").action(\"JSBNG__home\"),\n            loggedOut: c(\"front\").action(\"index\")\n        }), \"swift_home_timeline\", \"/\"), m(\"savedSearches\", \"/#!/saved-search\", j({\n            loggedIn: c(\"JSBNG__home\").action(\"savedSearches\")\n        })), g(\"listsFollowingYou\", \"/#!/lists/memberships\", j({\n            loggedIn: c(\"JSBNG__home\").action(\"memberships\")\n        }), \"swift_lists\", \"/lists/memberships\"), g(\"listsYouFollow\", \"/#!/lists/subscriptions\", j({\n            loggedIn: c(\"JSBNG__home\").action(\"subscriptions\")\n        }), \"swift_lists\", \"/lists/subscriptions\"), m(\"messages\", \"/#!/messages\", j({\n            loggedIn: c(\"JSBNG__home\").action(\"messages\")\n        })), m(\"messageCreate\", \"/#!/messages/create/:screen_name\", j({\n            loggedIn: c(\"JSBNG__home\").action(\"messages\")\n        })), m(\"inbox\", \"/#!/inbox\", j({\n            loggedIn: c(\"JSBNG__home\").action(\"messages\")\n        })), m(\"sent\", \"/#!/sent\", j({\n            loggedIn: c(\"JSBNG__home\").action(\"messages\")\n        })), m(\"createDm\", \"/#!/direct_messages/create/:screen_name\", j({\n            loggedIn: c(\"JSBNG__home\").action(\"messages\")\n        }));\n        if (((twttr.griffin && twttr.griffin.current))) {\n            for (var p = 0; ((p < twttr.griffin.current.length)); p++) {\n                var q = twttr.griffin.current[p];\n                e(((q + \"Static\")), ((\"/hashtag/\" + q))), o(q, ((\"/#\" + q)), ((q + \"Static\")));\n            };\n        ;\n            m(\"searchNoReroute\", \"/#!/search/:query/show\", c(\"search\").action(\"searchShow\")), m(\"eventsGrid\", \"/#!/hashtag/:query/grid/:mode\", c(\"eventsMediaGallery\").action(\"grid\")), m(\"eventsSlideshow\", \"/#!/hashtag/:query/slideshow/:mode\", c(\"eventsMediaGallery\").action(\"slideshow\"));\n        }\n    ;\n    ;\n        o(\"retweetsByOthers\", \"/#!/retweets_by_others\", \"connect\"), o(\"retweetsOfMine\", \"/#!/retweeted_of_mine\", \"connect\"), m(\"rateLimit\", \"/#!/twttr/rate_limit\", c(\"rateLimit\").action(\"tooMuch\")), g(\"discover\", \"/#!/i/discover\", j({\n            loggedIn: c(\"discover\").action(\"discover\")\n        }), \"swift_discover\", \"/i/discover\"), m(\"networkActivity\", \"/#!/activity\", j({\n            loggedIn: c(\"discover\").action(\"networkActivity\")\n        })), m(\"whoToFollow\", \"/#!/who_to_follow\", j({\n            loggedIn: c(\"discover\").action(\"suggestions\")\n        })), m(\"whoToFollowSuggestions\", \"/#!/who_to_follow/suggestions\", j({\n            loggedIn: c(\"discover\").action(\"suggestions\")\n        })), m(\"whoToFollowSuggestionsSearch\", \"/#!/who_to_follow/suggestions/search/:query\", j({\n            loggedIn: c(\"discover\").action(\"suggestions_search\")\n        })), m(\"whoToFollowSuggestionsSearchForm\", \"/#!/who_to_follow/suggestions/search/\", j({\n            loggedIn: c(\"discover\").action(\"suggestions_search\")\n        })), m(\"whoToFollowLifeline\", \"/#!/who_to_follow/lifeline\", j({\n            loggedIn: c(\"discover\").action(\"lifeline\")\n        })), m(\"whoToFollowLifelineSearch\", \"/#!/who_to_follow/lifeline/search/:query\", j({\n            loggedIn: c(\"discover\").action(\"lifeline_search\")\n        })), m(\"whoToFollowImport\", \"/#!/who_to_follow/import\", j({\n            loggedIn: c(\"discover\").action(\"find_friends\")\n        })), m(\"whoToFollowImportMatches\", \"/#!/who_to_follow/matches\", j({\n            loggedIn: c(\"discover\").action(\"matches\")\n        })), m(\"whoToFollowImportSearch\", \"/#!/who_to_follow/import/search/:query\", j({\n            loggedIn: c(\"discover\").action(\"find_friends_search\")\n        })), m(\"whoToFollowImportSearchForm\", \"/#!/who_to_follow/import/search/\", j({\n            loggedIn: c(\"discover\").action(\"find_friends_search\")\n        })), m(\"whoToFollowInterests\", \"/#!/who_to_follow/interests\", j({\n            loggedIn: c(\"discover\").action(\"interests\")\n        })), m(\"whoToFollowInterestsSearch\", \"/#!/who_to_follow/interests/search/:query\", j({\n            loggedIn: c(\"discover\").action(\"interests_search\")\n        })), m(\"whoToFollowInterestsSearchForm\", \"/#!/who_to_follow/interests/search\", j({\n            loggedIn: c(\"discover\").action(\"interests_search\")\n        })), m(\"whoToFollowInterestsCategory\", \"/#!/who_to_follow/interests/:category\", j({\n            loggedIn: c(\"discover\").action(\"category\")\n        })), m(\"governmentSearchByZip\", \"/#!/who_to_follow/government_by_zip/:zipCode\", j({\n            loggedIn: c(\"discover\").action(\"government_by_zip\")\n        })), m(\"personalizationPreview\", \"/#!/who_to_follow/web_personalized\", c(\"WebPersonalizationPreview\").action(\"preview\")), g(\"searchHome\", \"/#!/search-home\", c(\"searchHome\").action(\"index\"), \"swift_search\", \"/search-home\"), g(\"searchAdvanced\", \"/#!/search-advanced\", c(\"searchHome\").action(\"advanced\"), \"swift_search\", \"/search-advanced\"), g(\"formSearchResults\", \"/#!/search\", c(\"search\").action(\"search\"), \"swift_search\", \"/search\"), g(\"searchResults\", \"/#!/search/:query\", c(\"search\").action(\"search\"), \"swift_search\", \"/search/:query\"), m(\"searchRealtime\", \"/#!/search/realtime/:query\", c(\"search\").action(\"realtime\")), m(\"searchTimeline\", \"/#!/search/timeline/:query\", c(\"search\").action(\"timeline\")), m(\"userSearch\", \"/#!/search/users/:query\", c(\"search\").action(\"people\")), m(\"savedSearch\", \"/#!/saved-search/:query\", c(\"search\").action(\"search\")), m(\"searchFacetsGrid\", \"/#!/search/:query/grid/:mode\", c(\"facetsMediaGallery\").action(\"grid\")), m(\"searchFacetsSlideshow\", \"/#!/search/:query/slideshow/:mode\", c(\"facetsMediaGallery\").action(\"slideshow\")), m(\"searchFacetsGridDefault\", \"/#!/search/:query/grid\", c(\"facetsMediaGallery\").action(\"grid\")), m(\"searchFacetsSlideshowDefault\", \"/#!/search/:query/slideshow\", c(\"facetsMediaGallery\").action(\"slideshow\")), m(\"place\", \"/#!/places/:place_id\", c(\"PlaceT1\").action(\"tweets\")), m(\"trends\", \"/#!/trends\", c(\"trends\").action(\"trends\")), g(\"connect\", \"/#!/i/connect\", j({\n            loggedIn: c(\"Connect\").action(\"connect\")\n        }), \"swift_interactions\", \"/i/connect\"), g(\"mentions\", \"/#!/mentions\", j({\n            loggedIn: c(\"Connect\").action(\"mentions\")\n        }), \"swift_mentions\", \"/mentions\"), g(\"replies\", \"/#!/replies\", j({\n            loggedIn: c(\"Connect\").action(\"mentions\")\n        }), \"swift_mentions\", \"/replies\"), g(\"permalink\", \"/#!/:screen_name/status/:id\", c(\"permalink\").action(\"permalink\"), \"swift_permalink\", \"/:screen_name/status/:id\"), g(\"permalinkOld\", \"/#!/:screen_name/statuses/:id\", c(\"permalink\").action(\"permalink\"), \"swift_permalink\", \"/:screen_name/statuses/:id\"), g(\"photoPermalink\", \"/#!/:screen_name/status/:id/photo/:photo_index\", c(\"permalink\").action(\"permalink\"), \"swift_permalink\", \"/:screen_name/status/:id/photo/:photo_index\"), g(\"bigPhotoPermalink\", \"/#!/:screen_name/status/:id/photo/:photo_index/large\", c(\"bigPhotoPermalink\").action(\"permalink\"), \"swift_permalink\", \"/:screen_name/status/:id/photo/:photo_index/large\"), m(\"embedDialogPermalink\", \"/#!/:screen_name/status/:id/embed\", c(\"permalink\").action(\"permalinkWithEmbedDialog\")), m(\"welcome\", \"/#!/welcome\", j({\n            loggedIn: c(\"welcome\").action(\"welcome\")\n        })), m(\"welcomeSearch\", \"/#!/welcome/search/:query\", j({\n            loggedIn: c(\"welcome\").action(\"search\")\n        })), m(\"welcomeSearchTop\", \"/#!/welcome/search_top/:query\", j({\n            loggedIn: c(\"welcome\").action(\"searchTop\")\n        })), m(\"welcomeSearchForm\", \"/#!/welcome/search\", j({\n            loggedIn: c(\"welcome\").action(\"search\")\n        })), m(\"welcomeLifelineSearch\", \"/#!/welcome/lifeline/search/:query\", j({\n            loggedIn: c(\"welcome\").action(\"searchByZipcode\")\n        })), m(\"welcomeIntro\", \"/#!/welcome/intro\", j({\n            loggedIn: c(\"welcome\").action(\"intro\")\n        })), m(\"welcomeInterests\", \"/#!/welcome/interests\", j({\n            loggedIn: c(\"welcome\").action(\"interests\")\n        })), m(\"welcomeLifeline\", \"/#!/welcome/lifeline\", j({\n            loggedIn: c(\"welcome\").action(\"lifeline\")\n        })), m(\"welcomeInterestsCategory\", \"/#!/welcome/interests/:category\", j({\n            loggedIn: c(\"welcome\").action(\"category\")\n        })), m(\"welcomeImport\", \"/#!/welcome/import\", j({\n            loggedIn: c(\"welcome\").action(\"import\")\n        })), m(\"welcomeImportMatches\", \"/#!/welcome/matches\", j({\n            loggedIn: c(\"welcome\").action(\"matches\")\n        })), m(\"welcomeRecommendations\", \"/#!/welcome/recommendations\", j({\n            loggedIn: c(\"welcome\").action(\"recommendations\")\n        })), m(\"welcomeResurrect\", \"/#!/welcome/return\", j({\n            loggedIn: c(\"welcome\").action(\"resurrect\")\n        })), m(\"welcomeProfile\", \"/#!/welcome/profile\", j({\n            loggedIn: c(\"welcome\").action(\"profile\")\n        })), m(\"welcomeTweets\", \"/#!/welcome/tweets\", j({\n            loggedIn: c(\"welcome\").action(\"tweets\")\n        })), m(\"welcomePreview\", \"/#!/welcome/preview\", j({\n            loggedIn: c(\"welcome\").action(\"preview\")\n        })), m(\"welcomeEdit\", \"/#!/welcome/edit\", j({\n            loggedIn: c(\"welcome\").action(\"edit\")\n        })), g(\"followers\", \"/#!/followers\", j({\n            loggedIn: c(\"profile\").action(\"followers\")\n        }), \"swift_followers\", \"/followers\"), g(\"following\", \"/#!/following\", j({\n            loggedIn: c(\"profile\").action(\"following\")\n        }), \"swift_following\", \"/following\"), g(\"favorites\", \"/#!/favorites\", j({\n            loggedIn: c(\"profile\").action(\"favorites\")\n        }), \"swift_favorites\", \"/favorites\"), g(\"friends\", \"/#!/friends\", j({\n            loggedIn: c(\"profile\").action(\"following\")\n        }), \"swift_following\", \"/following\"), g(\"lists\", \"/#!/lists\", j({\n            loggedIn: c(\"profile\").action(\"lists\")\n        }), \"swift_lists\", \"/lists\"), g(\"followersYouFollow\", \"/#!/:screen_name/followers_you_follow\", c(\"profile\").action(\"followersYouFollow\"), \"swift_followers_you_follow\", \"/:screen_name/followers_you_follow\"), g(\"memberships\", \"/#!/:screen_name/lists/memberships\", c(\"profile\").action(\"memberships\"), \"swift_lists\", \"/:screen_name/lists/memberships\"), g(\"subscriptions\", \"/#!/:screen_name/lists\", c(\"profile\").action(\"allLists\"), \"swift_lists\", \"/:screen_name/lists\"), g(\"profile\", \"/#!/:screen_name\", c(\"profile\").action(\"profile\"), \"swift_profile\", \"/:screen_name\"), g(\"profileWithReplies\", \"/#!/:screen_name/with_replies\", c(\"profile\").action(\"with_replies\"), \"swift_profile\", \"/:screen_name/with_replies\"), g(\"userFavorites\", \"/#!/:screen_name/favorites\", c(\"profile\").action(\"favorites\"), \"swift_favorites\", \"/:screen_name/favorites\"), g(\"userFollowers\", \"/#!/:screen_name/followers\", c(\"profile\").action(\"followers\"), \"swift_followers\", \"/:screen_name/followers\"), m(\"userMediaGrid\", \"/#!/:screen_name/media/grid\", c(\"userMediaGallery\").action(\"grid\")), m(\"userMediaSlideshow\", \"/#!/:screen_name/media/slideshow\", c(\"userMediaGallery\").action(\"slideshow\")), g(\"userFollowing\", \"/#!/:screen_name/following\", c(\"profile\").action(\"following\"), \"swift_following\", \"/:screen_name/following\"), g(\"userLists\", \"/#!/:screen_name/userlists\", c(\"profile\").action(\"lists\"), \"swift_lists\", \"/:screen_name/userlists\"), g(\"followerRequests\", \"/#!/:screen_name/follower_requests\", c(\"profile\").action(\"followerRequests\"), \"swift_follower_requests\", \"/:screen_name/follower_requests\"), g(\"similarTo\", \"/#!/similar_to/:screen_name\", c(\"profile\").action(\"similarTo\"), \"swift_similar_to\", \"/similar_to/:screen_name\"), m(\"userList\", \"/#!/:screen_name/:list_slug\", c(\"list\").action(\"list\")), m(\"listMembers\", \"/#!/:screen_name/:list_slug/members\", c(\"list\").action(\"members\")), m(\"listSubscribers\", \"/#!/:screen_name/:list_slug/subscribers\", c(\"list\").action(\"followers\")), ((l() || (twttr.router.bind(\"routeFollowed\", l), a())));\n    });\n});\nprovide(\"audit\", function(a) {\n    using().as(function(b) {\n        twttr.klass(\"twttr.AuditTrail\", function() {\n            this.array = [];\n        }).methods({\n            MAX_LENGTH: 20,\n            add: function(a) {\n                this.array.unshift(a), ((((this.array.length > this.MAX_LENGTH)) && (this.array = this.array.slice(0, this.MAX_LENGTH))));\n            },\n            trail: function() {\n                return this.array;\n            },\n            currentPage: function() {\n                return this.page(0);\n            },\n            currentAction: function() {\n                return this.action(0);\n            },\n            currentPath: function() {\n                return this.path(0);\n            },\n            page: function(a) {\n                var b = this._routes();\n                return ((b[a] && b[a].page));\n            },\n            action: function(a) {\n                var b = this._routes();\n                return ((b[a] && b[a].action));\n            },\n            path: function(a) {\n                var b = this._routes();\n                return ((b[a] && b[a].path));\n            },\n            _routes: function() {\n                return twttr.filter(this.array, function(a, b) {\n                    return ((a.type === \"route\"));\n                });\n            }\n        }), twttr.audit = new twttr.AuditTrail, twttr.router.bind(\"routeFollowed\", function(a, b, c) {\n            var d = b.fn.pageName;\n            twttr.audit.add({\n                action: b.fn.actionName,\n                page: d,\n                path: c,\n                type: \"route\"\n            }), ((window.JSBNG__sessionStorage && JSBNG__sessionStorage.setItem(\"ScribeTransport.internal_referer\", c)));\n            var e = $(\"#doc\").removeClass();\n            ((d && e.addClass(((\"route-\" + d.replace(/_/g, \"-\"))))));\n        }), a(twttr.audit);\n    });\n});\nprovide(\"multiGlobals/ClickTrail\", function(a) {\n    using(\"util\").as(function(b) {\n        twttr.klass(\"twttr.ClickTrail\", function() {\n            this.array = [];\n        }).methods({\n            MAX_LENGTH: 5,\n            add: function(a) {\n                this.array.unshift(a), ((((this.array.length > this.MAX_LENGTH)) && (this.array = this.array.slice(0, this.MAX_LENGTH))));\n            },\n            lastClick: function() {\n                if (this.array.length) {\n                    return this.array[0].eventName;\n                }\n            ;\n            ;\n            },\n            trail: function() {\n                return this.array;\n            }\n        }), twttr.clicks = new twttr.ClickTrail, twttr.app.waitForSignal(\"init\", function() {\n            $(\"body\").mousedown(function(a) {\n                var c = $(a.target), d = c.closest(\"[data-element-term]\"), e = c.closest(\"[data-component-term]\"), f = c.closest(\"[data-section-term]\"), g = twttr.Scribbler.getElementEventNameTerms(c), i = twttr.audit.currentPage(), j = c.closest(\"[href]\").attr(\"href\");\n                ((g.section || (g.section = b.util.underscore(twttr.audit.currentAction())))), ((((((g.component && g.section)) && i)) && (g.client = \"web\", g.page = b.util.underscore(i), g.action = \"JSBNG__navigate\", twttr.clicks.add({\n                    eventName: twttr.Scribbler.clientAppEventNameGenerator(g),\n                    eventTerms: g,\n                    path: j,\n                    target: c\n                }))));\n            }), twttr.router.bind(\"routeFollowed\", function(a, b, c) {\n                var d = twttr.clicks.trail()[0];\n                ((((d && ((d.path == c)))) && trackClient(d.eventTerms, {\n                    url: c\n                })));\n            });\n        }), a(twttr.clicks);\n    });\n});\nprovide(\"run/defaultViews\", function(a) {\n    using().as(function(b) {\n        using(\"\\u003Epayload\", function() {\n            ((twttr.payload.conditionalTemplates && ($.each(twttr.payload.conditionalTemplates, function(a, b) {\n                twttr.templates[a] = b;\n            }), twttr.views.makeDefaultViews(twttr.templates))));\n        }), twttr.views.makeDefaultViews(twttr.templates), a();\n    });\n});\nprovide(\"TrendLocations\", function(a) {\n    using(\"_\", \"constants\").as(function(b, _) {\n        twttr.klass(\"twttr.TrendLocations\", function(a) {\n            this.getLocation(a);\n        }).statics({\n            LOGGED_OUT_TREND_LOCATION_COOKIE: \"trend_location\",\n            install: function(a) {\n                ((twttr.trendLocations ? twttr.trendLocations.getLocation(a) : twttr.trendLocations = new twttr.TrendLocations(a)));\n            }\n        }).methods({\n            getLocation: function(a) {\n                var b = this;\n                twttr.API.Trend.locations({\n                    lang: twttr.pageLocale,\n                    success: function(c) {\n                        b.all = c;\n                        if (twttr.currentUser) twttr.currentUser.trendLocation().first(function(c) {\n                            ((c ? b.current = c : b.current = b.worldwide())), a(b.current);\n                        });\n                         else {\n                            var d = parseInt($.cookie(b.constructor.LOGGED_OUT_TREND_LOCATION_COOKIE), 10);\n                            b.current = ((b.locationForWoeid(d) || b.worldwide())), a(b.current);\n                        }\n                    ;\n                    ;\n                    }\n                });\n            },\n            allLocations: function() {\n                return this.all.array;\n            },\n            ancestorsOf: function(a) {\n                if (!a.parentid) {\n                    return [];\n                }\n            ;\n            ;\n                var b = this.locationForWoeid(a.parentid);\n                return [b,].concat(this.ancestorsOf(b));\n            },\n            withAncestorsOf: function(a) {\n                return [a,].concat(this.ancestorsOf(a));\n            },\n            currentAncestors: function() {\n                return this.ancestorsOf(this.current);\n            },\n            withCurrentAncestors: function() {\n                return this.withAncestorsOf(this.current);\n            },\n            withFilterAncestors: function() {\n                return this.withAncestorsOf(this.currentFilter());\n            },\n            childrenOf: function(a) {\n                return twttr.filter(this.allLocations(), function(b) {\n                    return ((b.parentid === a.woeid));\n                });\n            },\n            currentChildren: function() {\n                return ((this.current.isPersonalized ? this.childrenOf(this.currentFilter(this.worldwide())) : this.childrenOf(this.currentFilter())));\n            },\n            locationForWoeid: function(a) {\n                return ((a ? twttr.filter(this.allLocations(), function(b) {\n                    return ((b.woeid == a));\n                })[0] : null));\n            },\n            locationsForWoeids: function(a) {\n                var b = this;\n                return twttr.map(a, function(a) {\n                    return b.locationForWoeid(a);\n                });\n            },\n            worldwide: function() {\n                return this.locationForWoeid(1);\n            },\n            currentFilter: function(a) {\n                var c = ((a || this.current));\n                return ((((((c.placeType.code === b.constants.placeTypes.city)) || ((this.childrenOf(c).length === 0)))) ? this._currentFilterWoeid = c.parentid : this._currentFilterWoeid = c.woeid)), this.locationForWoeid(this._currentFilterWoeid);\n            },\n            setPersonalized: function(a) {\n                this.current = $.extend(this.current, {\n                    isPersonalized: a\n                });\n            },\n            setCurrent: function(a) {\n                this.current = ((this.locationForWoeid(a.woeid) || this.current)), this.setPersonalized(a.isPersonalized), ((twttr.currentUser ? twttr.currentUser.setTrendLocation(a.woeid, a.isPersonalized) : (twttr.API.CurrentUser.trigger(\"changedLocation_success\"), $.cookie(this.constructor.LOGGED_OUT_TREND_LOCATION_COOKIE, a.woeid)))), scribble(\"switch-trend-location\", {\n                    woeid: a.woeid,\n                    input: \"click\",\n                    origin: a.origin\n                });\n            }\n        }), a(twttr.TrendLocations);\n    });\n});\nprovide(\"mixins/sideNavigationT1\", function(a) {\n    using().as(function(b) {\n        var c = twttr.klass.mixin(function() {\n            this.methods({\n                selectCurrentSideNav: function() {\n                    this.selectSideNav(twttr.router.getCurrentRoute().JSBNG__name);\n                },\n                selectSideNav: function(a) {\n                    var b = this.$find(((((\"li.js-sidenav-link[data-name='\" + a)) + \"']\")));\n                    this.$find(\"li.js-sidenav-link\").removeClass(\"active\"), ((b.length && b.addClass(\"active\")));\n                },\n                setSideNavBadge: function(a, b) {\n                    var c = $(JSBNG__document).JSBNG__find(((((\"li.js-sidenav-link a[href='\" + a)) + \"']\")));\n                    c.JSBNG__find(\"[class=\\\"unread\\\"]\").remove(), ((b && c.append(\"\\u003Ci class=\\\"unread\\\"\\u003E\\u003Ci\\u003E\")));\n                }\n            });\n        });\n        a(c);\n    });\n});\nprovide(\"components/PagePromise\", function(a) {\n    using(\"mixins/serverRenderableObject\").as(function(b, c) {\n        twttr.klass(\"twttr.PagePromise\", function(a) {\n            this._queue = [], this._unavailableQueue = [], this._isUnavailable = !1, this._name = a, this.pageNodeId = ((\"page-node-\" + twttr.util.underscore(a))), this.$node = this.$domNode(\"\\u003Cdiv/\\u003E\");\n        }).mixin(c).methods({\n            domNodeSelector: function() {\n                return ((\"#\" + this.pageNodeId));\n            },\n            build: function() {\n                var a = this, b = twttr.components.pages[this._name];\n                ((b ? a._build(a._name) : using(twttr.bundleMore, function() {\n                    a._build(a._name);\n                })));\n            },\n            send: function(a, b, c, d) {\n                ((((typeof b == \"function\")) && (error = c, c = b, b = [])));\n                var e = {\n                    JSBNG__name: a,\n                    args: b,\n                    cb: c,\n                    missing: d\n                };\n                ((this._instance ? this._execute(e) : this._enqueue(e)));\n            },\n            getInstanceProperty: function(a) {\n                if (((this._instance && this._instance[a]))) {\n                    return this._instance[a];\n                }\n            ;\n            ;\n            },\n            bind: function() {\n                this.send(\"bind\", Array.prototype.slice.apply(arguments));\n            },\n            JSBNG__one: function() {\n                this.send(\"JSBNG__one\", Array.prototype.slice.apply(arguments));\n            },\n            trigger: function() {\n                this.send(\"trigger\", Array.prototype.slice.apply(arguments));\n            },\n            $find: function() {\n                return this.$node.JSBNG__find.apply(this.$node, ((arguments || [])));\n            },\n            _build: function(a) {\n                var b = twttr.components.pages[a];\n                ((b ? (this._instance = new b(this.$node, this.preRendered), ((b.isAvailable() ? this._flush() : this._unavailable()))) : this._unavailable()));\n            },\n            whenUnavailable: function(a) {\n                ((this._isUnavailable ? a() : this._unavailableQueue.push(a)));\n            },\n            _unavailable: function() {\n                this._isUnavailable = !0;\n                for (var a = 0; ((a < this._unavailableQueue.length)); a++) {\n                    this._unavailableQueue[a].call(null);\n                ;\n                };\n            ;\n                this._unavailableQueue = [];\n            },\n            _enqueue: function(a) {\n                this._queue.push(a);\n            },\n            _execute: function(a) {\n                var b = this._instance[a.JSBNG__name];\n                if (b) {\n                    var c = b.apply(this._instance, ((a.args || [])));\n                    ((a.cb && a.cb.call(null, c)));\n                }\n                 else ((a.missing && a.missing.apply(null)));\n            ;\n            ;\n            },\n            _flush: function() {\n                for (var a = 0; ((a < this._queue.length)); a++) {\n                    this._execute(this._queue[a]);\n                ;\n                };\n            ;\n                this._queue = [];\n            }\n        }), a();\n    });\n});\nprovide(\"components/Page\", function(a) {\n    using(((twttr.isT1 ? \"mixins/sideNavigationT1\" : \"mixins/sideNavigationP1\")), \"util\", \"constants\", \"mixins/serverRenderableObject\").as(function(b, c) {\n        twttr.klass(\"twttr.components.Page\", function(a, b) {\n            var c = this._namespace.match(/\\.([^.]+)$/)[1];\n            this.pageNameUnderscore = twttr.util.underscore(c), this.$node = ((a || this.$domNode(\"\\u003Cdiv/\\u003E\"))), this.preRendered = !!b, ((b || signal(\"\\u003EwokeUp\"))), this._isOpen = !1, this.initComponentEvents();\n        }).statics({\n            view: function(a) {\n                return this.prototype._View = a, this;\n            },\n            containerCssClass: function(a) {\n                return this._containerCssClass = a, this;\n            },\n            deciderKey: function(a) {\n                return this._deciderKey = a, this;\n            },\n            isAvailable: function() {\n                return ((!this._deciderKey || twttr.decider.isAvailable(this._deciderKey)));\n            }\n        }).mixin(twttr.mixins.componentEvents).methods(twttr.EventProvider).mixin(b.mixins.serverRenderableObject).methods({\n            _isActive: function() {\n                return ((twttr.app.currentPageName().toLowerCase() === this.constructor._name.toLowerCase()));\n            },\n            $find: function() {\n                return this.$node.JSBNG__find.apply(this.$node, arguments);\n            },\n            keyevent: function(a, c) {\n                if (twttr.helpers.isModifier(a)) {\n                    return;\n                }\n            ;\n            ;\n                var d;\n                ((((a.keyCode === b.constants.keyCodes.esc)) ? d = \"esc\" : ((((a.keyCode === b.constants.keyCodes.enter)) ? d = \"return\" : ((((a.which === b.constants.which.period)) ? d = \"period\" : ((((a.keyCode === b.constants.keyCodes.leftArrow)) ? d = \"left\" : ((((a.keyCode === b.constants.keyCodes.rightArrow)) ? d = \"right\" : ((((a.keyCode === b.constants.keyCodes.upArrow)) ? d = \"up\" : ((((a.keyCode === b.constants.keyCodes.downArrow)) ? d = \"down\" : d = String.fromCharCode(a.which).toLowerCase()))))))))))))));\n                if (((((((this[((\"_\" + c))] && this[((\"_\" + c))][d])) && ((((a.which < 111)) || ((a.which > 118)))))) && !twttr.shortcuts.currentKey))) {\n                    return this[((\"_\" + c))][d].call(this, a);\n                }\n            ;\n            ;\n            },\n            render: function(a) {\n                this.beforeRender();\n                var b = $.extend(this.viewData(), a);\n                return ((this.preRendered || (this.$node.empty(), ((((twttr.development && !this._View)) && JSBNG__console.log(((\"Missing view for page \" + this.constructor.JSBNG__name))))), this.$node.html((new this._View(b)).html())))), this.afterRender(), this.trigger(\"rendered\", [this,]), this;\n            },\n            JSBNG__onkeydown: function(a) {\n                this.keyevent(a, \"keydown\");\n            },\n            JSBNG__onkeypress: function(a) {\n                this.keyevent(a, \"keypress\");\n            },\n            JSBNG__onkeyup: function(a) {\n                this.keyevent(a, \"keyup\");\n            },\n            addContainerComponent: function(a, b, c) {\n                ((((c == null)) ? a.append(b.$node) : ((twttr.is.number(c) ? a.children(((((\":nth-child(\" + c)) + \")\"))).before(b.$node) : a[c](b.$node))))), b.bind(\"notRendered\", twttr.bind(this, function(a) {\n                    this.componentNotRendered(b, a);\n                })), b.trigger(\"addedToPage\", [b,]);\n            },\n            addTopContentComponent: function(a, b) {\n                ((this.$topContent || (this.$topContent = this.$find(\"div.js-content-top\")))), this.addContainerComponent(this.$topContent, a, b);\n            },\n            addDashboardComponent: function(a, b) {\n                ((this.$dashboard || (this.$dashboard = this.$find(\".dashboard\")))), ((a && this.addContainerComponent(this.$dashboard, a, b)));\n            },\n            addDashboardComponents: function(a) {\n                var b = this;\n                twttr.each(a, function(a) {\n                    b.addDashboardComponent(a);\n                });\n            },\n            componentNotRendered: function(a, b) {\n            \n            },\n            updatePageTitle: function(a) {\n                ((twttr.isPreflight && (a = ((\"PREFLIGHT :: \" + a))))), this._pageTitle = a, ((this._isActive() && (JSBNG__document.title = a)));\n            },\n            hasNewItems: function(a) {\n                ((a ? ($(\"#global-actions .active\").addClass(\"new\"), JSBNG__document.title = ((((((\"(\" + a)) + \") \")) + this._pageTitle))) : ($(\"#global-actions .active\").removeClass(\"new\"), JSBNG__document.title = this._pageTitle)));\n            },\n            shouldAutoRender: function() {\n                return !this.noAutoRender;\n            },\n            addImpressionData: function(a) {\n            \n            }\n        }), twttr.klass.page = function(a, b) {\n            return twttr.klass(a, b).subclassOf(twttr.components.Page);\n        }, $.each([\"beforeRender\",\"afterRender\",\"JSBNG__onFirstSwitch\",\"viewData\",\"JSBNG__onSwitchAway\",\"JSBNG__onSwitchTo\",], function(a, b) {\n            var c = ((b.charAt(0).toUpperCase() + b.slice(1))), d = ((\"_\" + b));\n            twttr.components.Page[((\"add\" + c))] = function(a) {\n                var b = [], c = this.prototype[d];\n                if (c) {\n                    for (var e = 0; ((e < c.length)); e++) {\n                        b.push(c[e]);\n                    ;\n                    };\n                }\n            ;\n            ;\n                return b.push(a), this.prototype[d] = b, this;\n            }, twttr.components.Page.prototype[b] = function() {\n                var a = this, b = {\n                };\n                return $.each(((this[d] || [])), function(c, d) {\n                    twttr.aug(b, d.call(a));\n                }), b;\n            };\n        }), twttr.components.Page.addOnSwitchTo(function() {\n            ((this.constructor._containerCssClass && $(\"#page-container\").addClass(this.constructor._containerCssClass)));\n        }).addOnSwitchAway(function() {\n            ((this.constructor._containerCssClass && $(\"#page-container\").removeClass(this.constructor._containerCssClass))), $(\"div.tipsy\").remove();\n        }).addBeforeRender(function() {\n            $(\"div.tipsy\").remove();\n        }).addAfterRender(function() {\n            this.$topContent = this.$find(\"div.js-content-top\"), $(\"div.tipsy\").remove();\n        }).addBeforeRender(function() {\n            twttr.isRendering = ((twttr.is.def(twttr.isRendering) ? ((twttr.isRendering + 1)) : 1));\n        }).addAfterRender(function() {\n            twttr.isRendering = ((twttr.is.def(twttr.isRendering) ? ((twttr.isRendering - 1)) : 0));\n        }).addAfterRender(function() {\n            ((((twttr.currentUser && twttr.currentUser.facebookProfileId)) && window.JSBNG__setTimeout(function() {\n                if ((($(\"#facebook-token\").length == 0))) {\n                    var a = $(\"\\u003Ciframe style=\\\"display: none\\\"/\\u003E\");\n                    a.attr(\"src\", ((\"/settings/facebook/token?profile_id=\" + twttr.currentUser.facebookProfileId))), $(\"body\").append(a);\n                }\n            ;\n            ;\n            }, 3000)));\n        }).mixin(twttr.mixins.listActionable, c).click({\n            \"[data-modal='list-new']\": function(a, b) {\n                (new twttr.widget.ListDialog({\n                })).open(), trackElement(b, \"click\");\n            }\n        }), a(twttr.components.Page);\n    });\n});\nprovide(\"components/pages/mixins/homeT1\", function(a) {\n    using(\"util\", \"mixins/t1/emptyTimelineRecommendations\").as(function(b, c, d) {\n        var e = twttr.klass.mixin(\"twttr.components.pages.mixins.homeT1\", function() {\n            this.view(twttr.views.Page), this.methods({\n                insertTweetbox: twttr.util.noopInT1,\n                insertPromptbirdPrompt: function() {\n                    var a = this;\n                    using([twttr.bundleMore,\"promptbird\",]).as(function(a) {\n                        var b = a.promptbird.getPrompt();\n                        if (!b) {\n                            return;\n                        }\n                    ;\n                    ;\n                        var c = a.promptbird.renderComponentFromPrompt(b);\n                        if (!c) {\n                            return;\n                        }\n                    ;\n                    ;\n                        var d = ((((\"#js-promptbird-\" + b.JSBNG__prompt.format.replace(/_/g, \"-\"))) + \"-hook\"));\n                        $(d).html(c.$node);\n                    });\n                },\n                selectDashboardComponents: function() {\n                    return this.trendsComponent = new twttr.components.Trends, [new twttr.components.PromptbirdDashboardPlaceholder,new twttr.components.t1.dashboard.MiniHomeProfile(!0),((twttr.at(\"twttr.currentUser.protected\") && new twttr.components.FollowerRequestLink)),new twttr.components.JapaneseAd,new twttr.components.UserRecommendations({\n                        showLinks: twttr.decider.isAvailable(\"wtf_home_timeline_show_links\")\n                    }),this.trendsComponent,new twttr.components.Footer,];\n                },\n                getTweetBoxOptions: function() {\n                    return {\n                        condensedContent: _(\"Compose new Tweet...\"),\n                        autocompleteSuggestionLimit: ((twttr.isT1 ? 5 : 10))\n                    };\n                },\n                JSBNG__home: function(a, b) {\n                    var c = this, e = twttr.util.params().badLinkRecipient;\n                    ((((e && !this.warnedOfBadLink)) && (this.warnedOfBadLink = !0, twttr.API.User.JSBNG__find(+e, function(a) {\n                        twttr.showError(_(\"Sorry, you must be logged in as @{{screenName}} to use this link!\", a));\n                    })))), this.selectCurrentSideNav(), this.insertEmptyTimeline({\n                        reloadStream: !0,\n                        JSBNG__onDestroyCb: function() {\n                            c.trigger(\"emptyTimelineModuleDestroyed\");\n                        }\n                    }), this.waitForSignal(\"emptyTimelineModuleLogicCompleted\", function() {\n                        var a = c.$find(\".component[data-component-term=\\\"user_recommendations\\\"]\"), b = function() {\n                            ((((a.length === 1)) && ((d.showing ? a.hide() : a.show()))));\n                        };\n                        b(), c.bind(\"emptyTimelineModuleDestroyed\", function() {\n                            b();\n                        });\n                    }), this.loadPage(_(\"Twitter / Home\"), \"JSBNG__home\", \"Home\"), this.insertPromptbirdPrompt(), this._maybeShowReplyDialog(b);\n                },\n                networkActivity: function(a) {\n                    this.selectCurrentSideNav(), this.loadPage(_(\"Twitter / Activity\"), \"activity\", \"ActivityByNetworkStream\");\n                },\n                memberships: function(a) {\n                    var b = this;\n                    this.selectSideNav(\"lists\"), this.loadPage(_(\"Twitter / Lists following you\"), \"listFollowingYou\", \"Memberships\", {\n                        screenName: twttr.currentUser.screenName\n                    });\n                },\n                subscriptions: function(a) {\n                    var b = this;\n                    this.selectSideNav(\"lists\"), this.loadPage(_(\"Twitter / Lists you follow\"), \"listYouFollow\", \"AllSubscriptions\", {\n                        screenName: twttr.currentUser.screenName\n                    });\n                },\n                messages: function(a) {\n                    var b = this;\n                    using([twttr.bundleMore,\"components/t1/DirectMessageDialog\",], function(c, d) {\n                        b.JSBNG__home(a), ((a.screen_name ? (new d(twttr.widget.DirectMessageDialog.views.conversation, a.screen_name)).open() : (new d).open()));\n                    });\n                },\n                savedSearches: function(a) {\n                    this.selectCurrentSideNav(), this.loadPage(_(\"Twitter / Saved Searches\"), \"savedSearches\", \"SavedSearches\");\n                }\n            });\n        });\n        a(e);\n    });\n});\nprovide(\"components/pages/Home\", function(a) {\n    using(\"_\", ((twttr.isT1 ? \"components/pages/mixins/homeT1\" : \"components/pages/mixins/homeP1\")), ((twttr.isT1 ? \"mixins/t1/emptyTimelineRecommendations\" : \"mixins/emptyTimelineRecommendations\")), \"util\", \"constants\").as(function(b, _, c, d) {\n        var e = twttr.klass(\"twttr.components.pages.Home\").subclassOf(twttr.components.Page).mixin(twttr.mixins.streamablePage, twttr.mixins.welcomeScribing, d).view(twttr.views.HomePage).containerCssClass(\"home-container\").addOnSwitchTo(function() {\n            var a = this;\n            using([twttr.bundleMore,\"TweetBox\",], function() {\n                ((a._hasRendered && a.insertTweetbox())), twttr.TweetBox.bind(\"tweetSuccess\", function(b, c) {\n                    var d = a.streamManager.getCurrent().trigger(\"didTweet\", [c,]);\n                });\n            });\n            var b = twttr.currentUser.states;\n            if (((((b && b.pending_email)) && !$.cookie(\"abtest_email_verification_18\")))) {\n                var c = twttr.abdecider.choose(\"email_verification-18\", !0);\n                ((((c && ((c != \"control\")))) && using([twttr.bundleMore,\"dialogs\",], function() {\n                    twttr.dialogs.verifyEmail(c).open();\n                })));\n            }\n        ;\n        ;\n            ((this.scrollTop && twttr.$win.scrollTop(this.scrollTop))), $(\".promptbird\").show(), this.maybeScribeWelcomeSkip();\n        }).addOnSwitchAway(function() {\n            using([twttr.bundleMore,\"TweetBox\",], function() {\n                twttr.TweetBox.unbind(\"tweetSuccess\");\n            }), $(\".promptbird\").hide();\n        }).addViewData(function() {\n            return {\n                current_user_screen_name: twttr.currentUser.screenName\n            };\n        }).methods({\n            loadPage: function(a, b, c, d) {\n                function e() {\n                    f.streamManager.switchTo(twttr.streams[c], ((d || {\n                    })));\n                };\n            ;\n                var f = this;\n                this.updatePageTitle(a), twttr.themes.loadCurrentUserStyle(), ((twttr.streams[c] ? e() : (this.streamManager.switchOut(), using(twttr.bundleMore, function() {\n                    e();\n                })))), ((b && (this.focusStreamTab(b), ((((((((b == \"JSBNG__home\")) && ((twttr.currentUser.friendsCount == 0)))) && ((twttr.abdecider.choose(\"show_wtf_recs_in_timeline_105\", true) == \"show_wtf\")))) && this.$find(\".stream-tab.stream-tab-home.active a\").text(\"Who To Follow\")))))), this.unfocusStreamItem(), ((twttr.components.JapaneseAd && twttr.components.JapaneseAd.refreshAds())), ((twttr.isT1 || trackClient({\n                    action: \"impression\"\n                })));\n            },\n            shouldShowSubtabs: function() {\n                return window.JSBNG__location.search.match(/subtabs\\=1/);\n            },\n            componentNotRendered: function(a, b) {\n                ((((a._namespace == \"twttr.components.UserRecommendations\")) && this.$dashboard.JSBNG__find(\"div.trends-inner\").addClass(\"wide-trends\")));\n            },\n            JSBNG__onFirstSwitch: function() {\n                using([twttr.bundleMore,\"photo/turkey\",], function() {\n                    ((twttr.decider.isAvailable(\"turkey\") && twttr.turkey.showFirstTimeTurkey()));\n                });\n            },\n            getTweetbox: function() {\n                return this.tweetBox;\n            },\n            _maybeShowReplyDialog: function(a) {\n                ((((((a && a.in_reply_to_status_id)) && a.screen_name)) && (defaultContent = ((a.JSBNG__status || \"\")), using([twttr.bundleMore,\"dialogs\",], function() {\n                    twttr.dialogs.reply({\n                        tweetId: a.in_reply_to_status_id,\n                        screenName: a.screen_name,\n                        dataFields: {\n                            defaultContent: defaultContent,\n                            multiple: ((defaultContent.split(/@/).length > 2))\n                        }\n                    }).open();\n                }), (($.browser.msie || window.JSBNG__location.replace(twttr.router.homePath()))))));\n            },\n            insertPromptbirdPrompt: function() {\n                var a = this;\n                using([twttr.bundleMore,\"promptbird\",]).as(function(b) {\n                    var c = twttr.promptbird.getPrompt();\n                    if (!c) {\n                        return;\n                    }\n                ;\n                ;\n                    var d = twttr.promptbird.renderComponentFromPrompt(c);\n                    if (!d) {\n                        return;\n                    }\n                ;\n                ;\n                    switch (c.JSBNG__prompt.format) {\n                      case \"dashboard_narrow\":\n                        a.addDashboardComponent(d, 1);\n                        break;\n                      case \"below_black_bar\":\n                        ((a._isActive() && twttr.app.addComponentToAppBody(d)));\n                    };\n                ;\n                });\n            },\n            scrollEnd: function(a) {\n                this.scrollTop = a, ((((((a > 100)) && twttr.components.pages.Home.scribeScroll)) && (trackClient({\n                    action: \"JSBNG__scroll\"\n                }), twttr.components.pages.Home.scribeScroll = !1)));\n            }\n        }).addAfterRender(function() {\n            var a = this;\n            this._hasRendered = !0, using([twttr.bundleMore,\"TweetBox\",], function() {\n                a.insertTweetbox();\n            }), using(twttr.bundleMore, function() {\n                ((a.preRendered && a.$find(\"div.dashboard, section.dashboard\").empty())), a.addDashboardComponents(a.selectDashboardComponents()), a.signal(\"dashboardComponentsAdded\");\n            }), this.waitForSignal(\"dashboardComponentsAdded\", function() {\n                a.insertPromptbirdPrompt();\n            });\n        }).click({\n            \".done-right\": function(a, b) {\n                ((((twttr.currentUser.friendsCount > 0)) ? (twttr.abdecider.track(\"show_wtf_recs_in_timeline_105\", \"User clicked done button and is following accounts\"), window.JSBNG__location = \"/\") : (twttr.abdecider.track(\"show_wtf_recs_in_timeline_105\", \"User clicked done button and is not following any accounts\"), this.$find(\".stream-tab.stream-tab-home.active a\").text(\"Timeline\"), this.$find(\".stream-title\").css(\"border-bottom\", \"none\"), this.loadPage(_(\"Twitter / Home\"), \"JSBNG__home\", \"Home\"))));\n            }\n        });\n        e.mixin(c), a(e);\n    });\n});\nprovide(\"themes\", function(a) {\n    using().as(function(b) {\n        twttr.themes = {\n            loadUserStyleFor: function(a) {\n                ((twttr.helpers.isCurrentUser(a) && (a = twttr.currentUser)));\n                if (((a && !this._hasBrokenDefaults(a)))) {\n                    this._setTheme(((\"user-style-\" + a.screenName)));\n                    if ((($(((\"style#user-style-\" + a.screenName))).length === 0))) {\n                        $(\"head style.js-user-style\").remove();\n                        var b = ((twttr.isT1 ? twttr.views.UserCssT1 : twttr.views.UserCssP1));\n                        (new b(a)).render(\"head\", \"append\");\n                    }\n                ;\n                ;\n                    (((($(((((\"style#user-style-\" + a.screenName)) + \"-bg-img\"))).length === 0)) && ($(\"head style.js-user-style-bg-img\").remove(), (new twttr.views.BgImgCss(a)).render(\"head\", \"append\"))));\n                }\n                 else this.loadDefaultTheme();\n            ;\n            ;\n            },\n            loadCurrentUserStyle: function() {\n                this.loadUserStyleFor(twttr.currentUser);\n            },\n            loadDefaultTheme: function() {\n                ((twttr.isT1 ? this._setTheme(\"default-theme\") : this._setTheme(\"user-style-twttr\")));\n            },\n            loadFrontPageTheme: function() {\n                this._setTheme(\"front-page\");\n            },\n            loadLoadingTheme: function() {\n                this._setTheme(\"loading-body\");\n            },\n            clear: function() {\n                this._setTheme(!1);\n            },\n            _setTheme: function(a) {\n                var b = $(\"body\");\n                this._clearExistingTheme(), ((a && b.addClass(a)));\n            },\n            _brokenTheme: {\n                profileBackgroundColor: \"9ae4e8\",\n                profileBackgroundImageUrl: /\\/images\\/themes\\/theme1\\/bg.png$/i,\n                profileBackgroundTile: !1,\n                profileLinkColor: \"0000ff\",\n                profileSidebarBorderColor: \"87bc44\",\n                profileSidebarFillColor: \"e0ff92\",\n                profileTextColor: \"000000\",\n                profileUseBackgroundImage: !0\n            },\n            _hasBrokenDefaults: function(a) {\n                for (var b in this._brokenTheme) {\n                    var c = this._brokenTheme[b], d = a[b], e = !1;\n                    ((twttr.is.regex(c) ? e = !!d.match(c) : e = ((c === d))));\n                    if (!e) {\n                        return !1;\n                    }\n                ;\n                ;\n                };\n            ;\n                return !0;\n            },\n            _clearExistingTheme: function() {\n                var a = $(\"body\");\n                $(\"style[id^=user-style]\").each(function() {\n                    a.removeClass(this.id);\n                }), a.removeClass(\"loading-body front-page default-theme\"), ((twttr.isT1 || a.removeClass(\"static-page user-style-twttr\")));\n            }\n        }, ((twttr.isT1 || twttr.aug(twttr.themes, {\n            loadStaticPageTheme: function() {\n                this._setTheme(\"static-page\");\n            }\n        }))), a(twttr.themes);\n    });\n});\nprovide(\"Profiler\", function(a) {\n    using(\"util\").as(function(b) {\n        var c = 0, d = b.util.params().profiling, e = twttr.klass(\"twttr.Profiler\", function(a) {\n            if (!e.isEnabled()) {\n                this.waypoint = $.noop, this.waitFor = $.noop, this.done = $.noop, this.addBeforeScribbleFilter = $.noop, this.doneAfterCallback = function(a) {\n                    return a;\n                };\n                return;\n            }\n        ;\n        ;\n            this.id = ++c, this.description = a, this.pendingProfilers = 0, this.subProfilers = [], this.startTime = new JSBNG__Date, this.endTime = null, this.isDone = !1, this.isComplete = !1, this.runawayProfilerTimeout = JSBNG__setTimeout(twttr.bind(this, this._giveUp), e.timeoutAfter), this.timedOut = !1, this.timedOutSubProfilers = [], this.beforeScribbleFilters = [], this.profilerType = e.types.GENERIC, ((d && JSBNG__console.log(\"%s started\", this.description)));\n        }).methods(twttr.EventProvider).statics({\n            isEnabled: function() {\n                return ((!!twttr.payload.profiling || !!d));\n            },\n            logPreviousEvent: function(a, b, c) {\n                var d = new e(a);\n                d.addBeforeScribbleFilter(function(a) {\n                    return a.start_time_ms = b, a.end_time_ms = c, a.duration_ms = ((c - b)), a;\n                }), d.done();\n            },\n            logDataSet: function(a, b, c) {\n                var d = new e(a);\n                d.startTime = b, $.each(c, function(a, b) {\n                    d.waypoint(b.JSBNG__name, b.timestamp);\n                }), d.done();\n            },\n            timeoutAfter: 15000,\n            types: {\n                GENERIC: 0,\n                FIRST_PAGE_LOAD: 1\n            }\n        }).methods({\n            addBeforeScribbleFilter: function(a) {\n                this.beforeScribbleFilters.push(a);\n            },\n            doneAfterCallback: function(a) {\n                var b = this, c = function(a) {\n                    return function() {\n                        ((twttr.is.fn(a) || JSBNG__console.warn(\"Invalid call to doneAfterCallback\")));\n                        var c = a.apply(this, arguments);\n                        return b.done(), c;\n                    };\n                };\n                return ((twttr.is.fn(a) ? c(a) : (a.cancel = ((a.cancel || $.noop)), a.cancel = c(a.cancel), a.complete = ((a.complete || $.noop)), a.complete = c(a.complete), a)));\n            },\n            waitFor: function() {\n                ((this.isDone && JSBNG__console.warn(\".waitFor called on a profiler that's already complete\", this)));\n                var a = this;\n                $(arguments).each(function(b, c) {\n                    if (((!c || !((c instanceof e))))) {\n                        if (!twttr.is.def(c.profiler)) {\n                            JSBNG__console.error(\"Non-profiler passed in, and it doesn't have a .profiler property\");\n                            return;\n                        }\n                    ;\n                    ;\n                        c = c.profiler;\n                    }\n                ;\n                ;\n                    if (c.isComplete) {\n                        return;\n                    }\n                ;\n                ;\n                    ((d && JSBNG__console.log(\"%s waiting for %o\", a.description, c))), a.pendingProfilers++, a.subProfilers.push(c), c.bind(\"complete\", function(b, c, e) {\n                        ((d && ((e ? JSBNG__console.log(\"%s noticed that %o timed out\", a.description, c) : JSBNG__console.log(\"%s noticed that %o finished\", a.description, c))))), a.pendingProfilers--, ((e && a.timedOutSubProfilers.push(c))), ((((((a.pendingProfilers === 0)) && a.isDone)) && a._complete()));\n                    });\n                });\n            },\n            done: function() {\n                if (this.isDone) {\n                    return;\n                }\n            ;\n            ;\n                ((d && JSBNG__console.log(\"%s is done\", this.description))), this.isDone = !0, JSBNG__clearTimeout(this.runawayProfilerTimeout), this.runawayProfilerTimeout = null, ((((((this.pendingProfilers === 0)) && !this.isComplete)) && this._complete()));\n            },\n            _complete: function() {\n                ((d && JSBNG__console.log(\"%s is complete\", this.description))), this.isComplete = !0, this.endTime = new JSBNG__Date, this.waypoint(\"complete\"), this.trigger(\"complete\", [this,this.timedOut,]);\n            },\n            _giveUp: function() {\n                JSBNG__console.warn(\"Runaway profiler detected!\", this), this.timedOut = !0, this.done();\n            },\n            waypoint: function(a, c) {\n                c = ((c || new JSBNG__Date));\n                var e = {\n                    profiler_type: this.profilerType,\n                    product: \"webclient\",\n                    start_time_ms: twttr.appStartTime,\n                    impression_id: ((((twttr.session && twttr.session.impressionId)) ? twttr.session.impressionId.toString() : null)),\n                    id: this.id,\n                    description: this.description\n                };\n                ((this.isComplete ? (e.end_time_ms = this.endTime.getTime(), e.duration_ms = ((this.endTime - this.startTime))) : (e.waypoint_time_ms = c.getTime(), e.duration_ms = ((e.waypoint_time_ms - this.startTime)), e.waypoint_key = a))), ((this.timedOut && (e.timed_out = !0)));\n                var f = this;\n                $.each([\"subProfilers\",\"timedOutSubProfilers\",], function(a, c) {\n                    ((((f[c].length > 0)) && (e[b.util.underscore(c)] = twttr.map(f[c], function(a) {\n                        return a.description;\n                    }))));\n                }), $.each(this.beforeScribbleFilters, function(a, b) {\n                    e = b.call(f, e);\n                }), scribble(\"profiler_waypoint\", e, \"perftown\"), ((d && ((this.isComplete ? JSBNG__console.log(\"%s: complete after %d ms; data %o\", this.description, e.duration_ms, e) : JSBNG__console.log(\"%s: %s waypoint after %d ms; data %o\", this.description, a, ((e.waypoint_time_ms - this.startTime)), e)))));\n            }\n        });\n        e.verboseProfiling = d, a(e);\n    });\n});\nprovide(\"RouteTimer\", function(a) {\n    using(\"util\").as(function(b) {\n        twttr.provide(\"twttr.RouteTimer\", {\n            previousRoute: null,\n            previousPath: null,\n            trackedRoute: null,\n            trackedPath: null,\n            trackedStream: null,\n            trackAjax: !1,\n            prestreamAjaxCount: 0,\n            poststreamAjax: {\n            },\n            routeTiming: {\n            },\n            timeoutId: 0,\n            routeStart: function(a, b) {\n                var c = this;\n                this.routeTiming.next_time = (new JSBNG__Date).getTime(), this._scribeResultsAndReset(), this.previousRoute = ((this.trackedRoute || a)), this.previousPath = ((this.trackedPath || b)), this.trackedRoute = a, this.trackedPath = b, this.trackedStream = null, this.routeTiming.start_time = (new JSBNG__Date).getTime(), this.timeoutId = window.JSBNG__setTimeout(function() {\n                    c._scribeResultsAndReset();\n                }, 20000);\n            },\n            streamSwitch: function(a) {\n                var b = this, c = twttr.router.getCurrentRoute(), d = twttr.Router.getCurrentPath();\n                if (((((((!this.routeTiming.start_time || !this._routesEqual(c, this.trackedRoute))) || ((d !== this.trackedPath)))) || ((this._routesEqual(this.previousRoute, this.trackedRoute) && ((this.previousPath === this.trackedPath))))))) {\n                    this._reset();\n                    return;\n                }\n            ;\n            ;\n                this.routeTiming.stream_switch_time = (new JSBNG__Date).getTime(), this.trackedStream = a;\n            },\n            streamAfterSwitch: function(a, b) {\n                ((((((this.trackedStream === a)) && this.routeTiming.stream_switch_time)) ? (this.routeTiming.stream_complete_time = (new JSBNG__Date).getTime(), this.routeTiming.cached = b, this._startAjaxTracking()) : this._reset()));\n            },\n            JSBNG__onAjaxComplete: function(a, b) {\n                if (((!this.trackAjax || ((this.prestreamAjaxCount == 0))))) {\n                    return;\n                }\n            ;\n            ;\n                if (((b && ((b.url in this.poststreamAjax))))) {\n                    for (i = 0; ((i < this.poststreamAjax[b.url].length)); i++) {\n                        if (((b === this.poststreamAjax[b.url][i]))) {\n                            this.poststreamAjax[b.url].splice(i, 1);\n                            return;\n                        }\n                    ;\n                    ;\n                    };\n                }\n            ;\n            ;\n                this.prestreamAjaxCount--;\n                if (((((this.prestreamAjaxCount == 0)) || (($.active == 0))))) {\n                    this.trackAjax = !1, this.routeTiming.ajax_complete_time = (new JSBNG__Date).getTime(), this._scribeResultsAndReset();\n                }\n            ;\n            ;\n            },\n            JSBNG__onAjaxSend: function(a, b) {\n                ((((((this.trackAjax && b)) && b.url)) && (((this.poststreamAjax[b.url] || (this.poststreamAjax[b.url] = []))), this.poststreamAjax[b.url].push(b))));\n            },\n            _scribeResultsAndReset: function() {\n                var a = this;\n                if (this.routeTiming) {\n                    var c = !0;\n                    $.each([\"start_time\",\"stream_switch_time\",\"stream_complete_time\",\"cached\",], function(b, d) {\n                        ((((d in a.routeTiming)) || (c = !1)));\n                    }), ((c && (((b.util.params().routetimer && twttr.showMessage(((((((((((((((\"switch: \" + ((this.routeTiming.stream_switch_time - this.routeTiming.start_time)))) + \"\\u003Cbr\\u003Estream: \")) + ((this.routeTiming.stream_complete_time - this.routeTiming.start_time)))) + \"\\u003Cbr\\u003Eajax: \")) + ((this.routeTiming.ajax_complete_time - this.routeTiming.start_time)))) + \"\\u003Cbr\\u003Ecached: \")) + this.routeTiming.cached)), !0))), scribble(\"route_time\", $.extend({\n                        source_page: this.previousRoute.fn.pageName,\n                        source_action: this.previousRoute.fn.actionName,\n                        source_path: this.previousPath,\n                        dest_page: this.trackedRoute.fn.pageName,\n                        dest_action: this.trackedRoute.fn.actionName,\n                        dest_path: this.trackedPath\n                    }, this.routeTiming), \"route_timing\"))));\n                }\n            ;\n            ;\n                this._reset();\n            },\n            _startAjaxTracking: function() {\n                var a = this;\n                this.routeTiming.ajax_count = this.prestreamAjaxCount = $.active, ((((this.prestreamAjaxCount == 0)) ? (this.routeTiming.ajax_complete_time = (new JSBNG__Date).getTime(), this._scribeResultsAndReset()) : this.trackAjax = !0));\n            },\n            _routesEqual: function(a, b) {\n                return ((((a.JSBNG__name === b.JSBNG__name)) && ((a.path === b.path))));\n            },\n            _reset: function() {\n                this.routeTiming = {\n                }, this.trackAjax = !1, this.prestreamAjaxCount = 0, this.poststreamAjax = {\n                }, ((this.timeoutId && window.JSBNG__clearTimeout(this.timeoutId))), this.timeoutId = 0;\n            }\n        }), ((((twttr.loggedIn && ((twttr.decider.isAvailable(\"route_timing\") || b.util.params().routetimer)))) && (twttr.router.bind(\"routeFollowed\", function(a, b, c) {\n            twttr.RouteTimer.routeStart(b, c);\n        }), $(JSBNG__document).ajaxComplete(function(a, b, c) {\n            twttr.RouteTimer.JSBNG__onAjaxComplete(b, c);\n        }), $(JSBNG__document).ajaxSend(function(a, b, c) {\n            twttr.RouteTimer.JSBNG__onAjaxSend(b, c);\n        })))), a(twttr.RouteTimer);\n    });\n});\nprovide(\"bundle/t1-core\", function(a) {\n    using([\"$lib/jquery-1.7.1.js\",\"libwrap/jquery\",\"$lib/json2.js\",\"libwrap/json\",\"$lib/hogan.js\",\"libwrap/hogan\",\"run/base\",\"_\",\"/account/templates_t1_core.js\",\"EventProvider\",\"bluejs/init\",\"bluejs/config/endpoints\",\"bluejs/util/request_helpers\",\"bluejs/util/local_storage_cache\",\"bluejs/util/object_cache\",\"bluejs/util/request_cache\",\"bluejs/util/helpers\",\"bluejs/util/model\",\"bluejs/util/remote_request\",\"bluejs/util/base_collection\",\"bluejs/mixins/status_actions\",\"bluejs/mixins/phoenix/user\",\"bluejs/mixins/phoenix/current_user\",\"bluejs/mixins/phoenix/status\",\"bluejs/mixins/phoenix/rate_user_recommendation\",\"bluejs/models/base\",\"bluejs/models/user\",\"bluejs/models/direct_message\",\"bluejs/models/saved_search\",\"bluejs/models/list\",\"bluejs/models/location\",\"bluejs/models/trend\",\"bluejs/models/status\",\"bluejs/models/promptbird\",\"bluejs/models/search_result\",\"bluejs/models/place\",\"bluejs/models/user_recommendation\",\"bluejs/models/suggestion_category\",\"bluejs/models/related_tweets\",\"bluejs/models/related_result\",\"bluejs/util/promoted_content\",\"bluejs/models/address_book\",\"bluejs/models/promo\",\"bluejs/models/urls\",\"bluejs/models/blob\",\"bluejs/models/device\",\"bluejs/models/search\",\"bluejs/models/conversation\",\"bluejs/models/activity\",\"bluejs/models/topic_story\",\"bluejs/models/news_article\",\"bluejs/models/news_story\",\"bluejs/models/user_story\",\"bluejs/models/tweet_story\",\"bluejs/models/story\",\"bluejs/models/search_story\",\"bluejs/models/stories\",\"bluejs/models/discovery\",\"bluejs/models/sports_story\",\"bluejs/models/soccer_events\",\"bluejs/models/us_political_rep\",\"bluejs/models/social_proof\",\"bluejs/models/referenced_by\",\"extendAPI\",\"bluejs/api\",\"$lib/jquery.color.js\",\"$lib/modernizr-1.5.js\",\"$lib/jquery.hashchange.js\",\"$lib/jquery.cookie.js\",\"$lib/jquery.tipsy.js\",\"$lib/jquery.cssanimation.js\",\"div\",\"util\",\"constants\",\"cache\",\"singletons/namespaced_store\",\"singletons/promoted_account_store\",\"singletons/promoted_tweet_store\",\"decider\",\"multiGlobals/scribble\",\"abdecider\",\"app\",\"singletons/external_url_store\",\"singletons/Router\",\"streams/Stream\",\"scribbles\",\"Cards\",\"multiGlobals/client_app_tracking\",\"mixins/streamablePageDetailsPane\",\"mixins/streamablePageDropdownEdition\",\"mixins/streamablePageWithInlineMedia\",\"mixins/itemActionableScribing\",\"mixins/streamablePage\",\"mixins/userActionableT1\",\"mixins/userActionable\",\"mixins/profilePopupActionable\",\"mixins/listActionable\",\"mixins/tweetActionable\",\"mixins/pendingActions\",\"mixins/i18nTweet\",\"mixins/i18nTweetBox\",\"mixins/promotedTweetStream\",\"mixins/componentEvents\",\"mixins/protectedUserActionable\",\"mixins/serverRenderableObject\",\"mixins/welcomeScribing\",\"mixins/t1/emptyTimelineRecommendations\",\"lib/natcompare\",\"$lib/twitter-text-1.5.0.js\",\"setup\",\"search\",\"helpers\",\"errors\",\"viewHelpers\",\"components/Base\",\"idleDetector\",\"interface\",\"run/topbarDropdown\",\"tco\",\"streams/TweetStream\",\"streams/Home\",\"streams/StreamManager\",\"view\",\"urlResolver\",\"multiGlobals/core_views\",\"multiGlobals/core_views_t1\",\"router_t1\",\"audit\",\"multiGlobals/ClickTrail\",\"run/defaultViews\",\"TrendLocations\",\"mixins/sideNavigationT1\",\"components/PagePromise\",\"components/Page\",\"components/pages/mixins/homeT1\",\"components/pages/Home\",\"themes\",\"Profiler\",\"RouteTimer\",], function() {\n        a();\n    });\n});");
// 7603
cb(); return null; }
finalize(); })();
